# 1 "<built-in>" 1
# 1 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp" 1
/*
 #
 #  File        : gmic.cpp
 #                ( C++ source file )
 #
 #  Description : GREYC's Magic for Image Computing - G'MIC Language interpreter
 #                ( http://gmic.sourceforge.net )
 #                This file is also a part of the CImg Library project.
 #                ( http://cimg.sourceforge.net )
 #
 #  Copyright   : David Tschumperle
 #                ( http://tschumperle.users.greyc.fr/ )
 #
 #  License     : CeCILL v2.0
 #                ( http://www.cecill.info/licences/Licence_CeCILL_V2-en.html )
 #
 #  This software is governed by the CeCILL  license under French law and
 #  abiding by the rules of distribution of free software.  You can  use,
 #  modify and/ or redistribute the software under the terms of the CeCILL
 #  license as circulated by CEA, CNRS and INRIA at the following URL
 #  "http://www.cecill.info".
 #
 #  As a counterpart to the access to the source code and  rights to copy,
 #  modify and redistribute granted by the license, users are provided only
 #  with a limited warranty  and the software's author,  the holder of the
 #  economic rights,  and the successive licensors  have only  limited
 #  liability.
 #
 #  In this respect, the user's attention is drawn to the risks associated
 #  with loading,  using,  modifying and/or developing or reproducing the
 #  software by the user in light of its specific status of free software,
 #  that may mean  that it is complicated to manipulate,  and  that  also
 #  therefore means  that it is reserved for developers  and  experienced
 #  professionals having in-depth computer knowledge. Users are therefore
 #  encouraged to load and test the software's suitability as regards their
 #  requirements in conditions enabling the security of their systems and/or
 #  data to be ensured and,  more generally, to use and operate it in the
 #  same conditions as regards security.
 #
 #  The fact that you are presently reading this means that you have had
 #  knowledge of the CeCILL license and that you accept its terms.
 #
*/

// Add G'MIC-specific methods to the CImg library.
//------------------------------------------------
#ifdef cimg_plugin

// Additional arithmetic/boolean operators.

template<typename t>
CImg<T>& operator_eq(const t val) {
  cimg_for(*this,ptrd,T) *ptrd = (T)(*ptrd == (T)val);
  return *this;
}

CImg<T>& operator_eq(const char *const expression) {
  const unsigned int omode = cimg::exception_mode();
  cimg::exception_mode() = 0;
  try {
    const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(),
      &base = _base?_base:*this;
    _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator_eq");
    T *ptrd = *expression=='<'?end()-1:_data;
    if (*expression=='<')
      cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd == (T)mp.eval(x,y,z,c)); --ptrd; }
    else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd == (T)mp.eval(x,y,z,c)); ++ptrd; }
  } catch (CImgException&) {
    cimg::exception_mode() = omode;
    CImg<T> values(_width,_height,_depth,_spectrum);
    values = expression;
    operator_eq(values);
  }
  cimg::exception_mode() = omode;
  return *this;
}

template<typename t>
CImg<T>& operator_eq(const CImg<t>& img) {
  const unsigned long siz = size(), isiz = img.size();
  if (siz && isiz) {
    if (is_overlapped(img)) return operator_eq(+img);
    T *ptrd = _data, *const ptre = _data + siz;
    if (siz>isiz)
      for (unsigned long n = siz/isiz; n; --n)
        for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd)
          *ptrd = (T)(*ptrd == (T)*(ptrs++));
    for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)(*ptrd == (T)*(ptrs++));
  }
  return *this;
}

template<typename t>
CImg<T>& operator_neq(const t val) {
  cimg_for(*this,ptrd,T) *ptrd = (T)(*ptrd != (T)val);
  return *this;
}

CImg<T>& operator_neq(const char *const expression) {
  const unsigned int omode = cimg::exception_mode();
  cimg::exception_mode() = 0;
  try {
    const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(),
      &base = _base?_base:*this;
    _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator_neq");
    T *ptrd = *expression=='<'?end()-1:_data;
    if (*expression=='<')
      cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd != (T)mp.eval(x,y,z,c)); --ptrd; }
    else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd != (T)mp.eval(x,y,z,c)); ++ptrd; }
  } catch (CImgException&) {
    cimg::exception_mode() = omode;
    CImg<T> values(_width,_height,_depth,_spectrum);
    values = expression;
    operator_neq(values);
  }
  cimg::exception_mode() = omode;
  return *this;
}

template<typename t>
CImg<T>& operator_neq(const CImg<t>& img) {
  const unsigned long siz = size(), isiz = img.size();
  if (siz && isiz) {
    if (is_overlapped(img)) return operator_neq(+img);
    T *ptrd = _data, *const ptre = _data + siz;
    if (siz>isiz)
      for (unsigned long n = siz/isiz; n; --n)
        for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd)
          *ptrd = (T)(*ptrd != (T)*(ptrs++));
    for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)(*ptrd != (T)*(ptrs++));
  }
  return *this;
}

template<typename t>
CImg<T>& operator_gt(const t val) {
  cimg_for(*this,ptrd,T) *ptrd = (T)(*ptrd > (T)val);
  return *this;
}

CImg<T>& operator_gt(const char *const expression) {
  const unsigned int omode = cimg::exception_mode();
  cimg::exception_mode() = 0;
  try {
    const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(),
      &base = _base?_base:*this;
    _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator_gt");
    T *ptrd = *expression=='<'?end()-1:_data;
    if (*expression=='<')
      cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd > (T)mp.eval(x,y,z,c)); --ptrd; }
    else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd > (T)mp.eval(x,y,z,c)); ++ptrd; }
  } catch (CImgException&) {
    cimg::exception_mode() = omode;
    CImg<T> values(_width,_height,_depth,_spectrum);
    values = expression;
    operator_gt(values);
  }
  cimg::exception_mode() = omode;
  return *this;
}

template<typename t>
CImg<T>& operator_gt(const CImg<t>& img) {
  const unsigned long siz = size(), isiz = img.size();
  if (siz && isiz) {
    if (is_overlapped(img)) return operator_gt(+img);
    T *ptrd = _data, *const ptre = _data + siz;
    if (siz>isiz)
      for (unsigned long n = siz/isiz; n; --n)
        for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd)
          *ptrd = (T)(*ptrd > (T)*(ptrs++));
    for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)(*ptrd > (T)*(ptrs++));
  }
  return *this;
}

template<typename t>
CImg<T>& operator_ge(const t val) {
  cimg_for(*this,ptrd,T) *ptrd = (T)(*ptrd >= (T)val);
  return *this;
}

CImg<T>& operator_ge(const char *const expression) {
  const unsigned int omode = cimg::exception_mode();
  cimg::exception_mode() = 0;
  try {
    const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(),
      &base = _base?_base:*this;
    _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator_ge");
    T *ptrd = *expression=='<'?end()-1:_data;
    if (*expression=='<')
      cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd >= (T)mp.eval(x,y,z,c)); --ptrd; }
    else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd >= (T)mp.eval(x,y,z,c)); ++ptrd; }
  } catch (CImgException&) {
    cimg::exception_mode() = omode;
    CImg<T> values(_width,_height,_depth,_spectrum);
    values = expression;
    operator_ge(values);
  }
  cimg::exception_mode() = omode;
  return *this;
}

template<typename t>
CImg<T>& operator_ge(const CImg<t>& img) {
  const unsigned long siz = size(), isiz = img.size();
  if (siz && isiz) {
    if (is_overlapped(img)) return operator_ge(+img);
    T *ptrd = _data, *const ptre = _data + siz;
    if (siz>isiz)
      for (unsigned long n = siz/isiz; n; --n)
        for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd)
          *ptrd = (T)(*ptrd >= (T)*(ptrs++));
    for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)(*ptrd >= (T)*(ptrs++));
  }
  return *this;
}

template<typename t>
CImg<T>& operator_lt(const t val) {
  cimg_for(*this,ptrd,T) *ptrd = (T)(*ptrd < (T)val);
  return *this;
}

CImg<T>& operator_lt(const char *const expression) {
  const unsigned int omode = cimg::exception_mode();
  cimg::exception_mode() = 0;
  try {
    const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(),
      &base = _base?_base:*this;
    _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator_lt");
    T *ptrd = *expression=='<'?end()-1:_data;
    if (*expression=='<')
      cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd < (T)mp.eval(x,y,z,c)); --ptrd; }
    else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd < (T)mp.eval(x,y,z,c)); ++ptrd; }
  } catch (CImgException&) {
    cimg::exception_mode() = omode;
    CImg<T> values(_width,_height,_depth,_spectrum);
    values = expression;
    operator_lt(values);
  }
  cimg::exception_mode() = omode;
  return *this;
}

template<typename t>
CImg<T>& operator_lt(const CImg<t>& img) {
  const unsigned long siz = size(), isiz = img.size();
  if (siz && isiz) {
    if (is_overlapped(img)) return operator_lt(+img);
    T *ptrd = _data, *const ptre = _data + siz;
    if (siz>isiz)
      for (unsigned long n = siz/isiz; n; --n)
        for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd)
          *ptrd = (T)(*ptrd < (T)*(ptrs++));
    for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)(*ptrd < (T)*(ptrs++));
  }
  return *this;
}

template<typename t>
CImg<T>& operator_le(const t val) {
  cimg_for(*this,ptrd,T) *ptrd = (T)(*ptrd <= (T)val);
  return *this;
}

CImg<T>& operator_le(const char *const expression) {
  const unsigned int omode = cimg::exception_mode();
  cimg::exception_mode() = 0;
  try {
    const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(),
      &base = _base?_base:*this;
    _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator_le");
    T *ptrd = *expression=='<'?end()-1:_data;
    if (*expression=='<')
      cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd <= (T)mp.eval(x,y,z,c)); --ptrd; }
    else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd <= (T)mp.eval(x,y,z,c)); ++ptrd; }
  } catch (CImgException&) {
    cimg::exception_mode() = omode;
    CImg<T> values(_width,_height,_depth,_spectrum);
    values = expression;
    operator_le(values);
  }
  cimg::exception_mode() = omode;
  return *this;
}

template<typename t>
CImg<T>& operator_le(const CImg<t>& img) {
  const unsigned long siz = size(), isiz = img.size();
  if (siz && isiz) {
    if (is_overlapped(img)) return operator_le(+img);
    T *ptrd = _data, *const ptre = _data + siz;
    if (siz>isiz)
      for (unsigned long n = siz/isiz; n; --n)
        for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd)
          *ptrd = (T)(*ptrd <= (T)*(ptrs++));
    for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)(*ptrd <= (T)*(ptrs++));
  }
  return *this;
}

CImg<T>& mul(const char *const expression) {
  return operator*=(expression);
}

CImg<T> get_mul(const char *const expression) const {
  return (+*this).mul(expression);
}

CImg<T>& div(const char *const expression) {
  return operator/=(expression);
}

CImg<T> get_div(const char *const expression) const {
  return (+*this).div(expression);
}

template<typename t>
const CImg<T>& gmic_symmetric_eigen(CImg<t>& val, CImg<t>& vec) const {
  if (spectrum()!=3 && spectrum()!=6) return symmetric_eigen(val,vec);
  val.assign(width(),height(),depth(),spectrum()==3?2:3);
  vec.assign(width(),height(),depth(),spectrum()==3?2:6);
  CImg<t> _val, _vec;
  cimg_forXYZ(*this,x,y,z) {
    get_tensor_at(x,y,z).symmetric_eigen(_val,_vec);
    val.set_vector_at(_val,x,y,z);
    if (spectrum()==3) {
      vec(x,y,z,0) = _vec(0,0);
      vec(x,y,z,1) = _vec(0,1);
    } else {
      vec(x,y,z,0) = _vec(0,0);
      vec(x,y,z,1) = _vec(0,1);
      vec(x,y,z,2) = _vec(0,2);

      vec(x,y,z,3) = _vec(1,0);
      vec(x,y,z,4) = _vec(1,1);
      vec(x,y,z,5) = _vec(1,2);
    }
  }
  return *this;
}

// Additional geometric and drawing operators.

template<typename t>
CImg<T>& replace(CImg<t>& img) {
  return img.move_to(*this);
}

template<typename t>
CImg<T> get_replace(const CImg<t>& img) const {
  return +img;
}

CImg<T>& gmic_autocrop(const CImg<T>& color=CImg<T>::empty()) {
  if (color.width()==1) autocrop(*color);
  else autocrop(color);
  return *this;
}

CImg<T> get_gmic_autocrop(const CImg<T>& color=CImg<T>::empty()) {
  return (+*this).gmic_autocrop(color);
}

CImg<T> get_gmic_set(const double value,
                     const int x, const int y, const int z, const int v) const {
  return (+*this).gmic_set(value,x,y,z,v);
}

CImg<T>& gmic_set(const double value,
                  const int x, const int y, const int z, const int v) {
  (*this).atXYZC(x,y,z,v,0) = (T)value;
  return *this;
}

CImg<T> get_draw_point(const int x, const int y, const int z, const T *const col,
                       const float opacity) const {
  return (+*this).draw_point(x,y,z,col,opacity);
}

CImg<T> get_draw_line(const int x0, const int y0, const int x1, const int y1, const T *const col,
                      const float opacity, const unsigned int pattern) const {
  return (+*this).draw_line(x0,y0,x1,y1,col,opacity,pattern);
}

template<typename t>
CImg<T> get_draw_polygon(const CImg<t>& pts, const T *const col, const float opacity) const {
  return (+*this).draw_polygon(pts,col,opacity);
}

template<typename t>
CImg<T> get_draw_polygon(const CImg<t>& pts, const T *const col, const float opacity,
                         const unsigned int pattern) const {
  return (+*this).draw_polygon(pts,col,opacity,pattern);
}

CImg<T> get_draw_circle(const int x, const int y, const int r, const T *const col,
                        const float opacity) const {
  return (+*this).draw_circle(x,y,r,col,opacity);
}

CImg<T> get_draw_circle(const int x, const int y, const int r, const T *const col,
                        const float opacity,
                        const unsigned int pattern) const {
  return (+*this).draw_circle(x,y,r,col,opacity,pattern);
}

CImg<T> get_draw_ellipse(const int x, const int y, const float r0, const float r1,
                         const float angle, const T *const col, const float opacity) const {
  return (+*this).draw_ellipse(x,y,r0,r1,angle,col,opacity);
}

CImg<T> get_draw_ellipse(const int x, const int y, const float r0, const float r1,
                         const float angle, const T *const col, const float opacity,
                         const unsigned int pattern) const {
  return (+*this).draw_ellipse(x,y,r0,r1,angle,col,opacity,pattern);
}

CImg<T>& gmic_draw_text(const int x, const int y,
                        const char *const text, const T *const col,
                        const int bg, const float opacity, const unsigned int siz,
                        const unsigned int nb_cols) {
  if (is_empty()) {
    const T one[] = { 1 };
    assign().draw_text(x,y,"%s",one,0,opacity,siz,text).resize(-100,-100,1,nb_cols);
    cimg_forC(*this,c) get_shared_channel(c)*=col[c];
  } else draw_text(x,y,"%s",col,bg,opacity,siz,text);
  return *this;
}

CImg<T> get_gmic_draw_text(const int x, const int y,
                           const char *const text, const T *const col,
                           const int bg, const float opacity, const unsigned int siz,
                           const unsigned int nb_cols) const {
  return (+*this).gmic_draw_text(x,y,text,col,bg,opacity,siz,nb_cols);
}

CImg<T> get_draw_image(const int x, const int y, const int z, const int c,
                       const CImg<T>& sprite, const CImg<T>& mask, const float opacity,
                       const float max_opacity_mask) const {
  return (+*this).draw_image(x,y,z,c,sprite,mask,opacity,max_opacity_mask);
}

CImg<T> get_draw_image(const int x, const int y, const int z, const int c,
                       const CImg<T>& sprite, const float opacity) const {
  return (+*this).draw_image(x,y,z,c,sprite,opacity);
}

CImg<T> get_draw_plasma(const float alpha, const float beta, const unsigned int scale) const {
  return (+*this).draw_plasma(alpha,beta,scale);
}

CImg<T> get_draw_mandelbrot(const CImg<T>& color_palette, const float opacity,
                            const double z0r, const double z0i, const double z1r, const double z1i,
                            const unsigned int itermax, const bool normalized_iteration,
                            const bool julia_set, const double paramr, const double parami) const {
  return (+*this).draw_mandelbrot(color_palette,opacity,z0r,z0i,z1r,z1i,itermax,
                                  normalized_iteration,julia_set,paramr,parami);
}

template<typename t, typename tc>
CImg<T> get_draw_graph(const CImg<t>& data,
                       const tc *const color, const float opacity=1,
                       const unsigned int plot_type=1, const int vertex_type=1,
                       const double ymin=0, const double ymax=0,
                       const unsigned int pattern=~0U) const {
  return (+*this).draw_graph(data,color,opacity,plot_type,vertex_type,ymin,ymax,pattern);
}

template<typename tc>
CImg<T> get_draw_axes(const float x0, const float x1, const float y0, const float y1,
                      const tc *const color, const float opacity=1,
                      const int subdivisionx=-60, const int subdivisiony=-60,
                      const float precisionx=0, const float precisiony=0,
                      const unsigned int patternx=~0U, const unsigned int patterny=~0U,
                      const unsigned int font_height=13) const {
  return (+*this).draw_axes(x0,x1,y0,y1,color,opacity,subdivisionx,subdivisiony,
                            precisionx,precisiony,patternx,patterny,font_height);
}

template<typename tc>
CImg<T> get_draw_grid(const float sizex, const float sizey,
                      const float offsetx, const float offsety,
                      const bool invertx, const bool inverty,
                      const tc *const color, const float opacity=1,
                      const unsigned int patternx=~0U, const unsigned int patterny=~0U) {
  return (+*this).draw_grid(sizex,sizey,offsetx,offsety,invertx,inverty,color,opacity,
                            patternx,patterny);
}

template<typename t1, typename t2>
CImg<T> get_draw_quiver(const CImg<t1>& flow,
                        const t2 *const color, const float opacity=1,
                        const unsigned int sampling=25, const float factor=-20,
                        const bool arrows=true, const unsigned int pattern=~0U) const {
  return (+*this).draw_quiver(flow,color,opacity,sampling,factor,arrows,pattern);
}

CImg<T> get_draw_fill(const int x, const int y, const int z,
                      const T *const col, const float opacity,
                      const float tolerance, const bool is_high_connectivity) const {
  return (+*this).draw_fill(x,y,z,col,opacity,tolerance,is_high_connectivity);
}

static bool is_almost(const T x, const T c) {
  return x>=c && x<c+1;
}

template<typename tp, typename tf, typename tc, typename to>
CImg<T> get_draw_object3d(const float x0, const float y0, const float z0,
                          const CImg<tp>& vertices, const CImgList<tf>& primitives,
                          const CImgList<tc>& colors, const CImgList<to>& opacities,
                          const unsigned int render_mode, const bool double_sided,
                          const float focale,
                          const float light_x, const float light_y,const float light_z,
                          const float specular_light, const float specular_shine,
                          CImg<floatT>& zbuffer) const {
  return (+*this).draw_object3d(x0,y0,z0,vertices,primitives,colors,opacities,render_mode,
                                double_sided,focale,light_x,light_y,light_z,specular_light,
                                specular_shine,zbuffer);
}

// Additional 3d objects operators.

CImgList<T> get_split_CImg3d() const {
  char error_message[1024] = { 0 };
  if (!is_CImg3d(false,error_message))
    throw CImgInstanceException(_cimg_instance
                                "get_split_CImg3d(): image instance is not a CImg3d (%s).",
                                cimg_instance,error_message);
  CImgList<T> res;
  const T *ptr0 = _data, *ptr = ptr0 + 6;
  CImg<T>(ptr0,1,ptr-ptr0,1,1).move_to(res); // Header.
  ptr0 = ptr;
  const unsigned int nbv = (unsigned int)*(ptr++), nbp = (unsigned int)*(ptr++);
  CImg<T>(ptr0,1,ptr-ptr0,1,1).move_to(res); // Nb vertices and primitives.
  ptr0 = ptr; ptr+=3*nbv;
  CImg<T>(ptr0,1,ptr-ptr0,1,1).move_to(res); // Vertices.
  ptr0 = ptr;
  for (unsigned int i = 0; i<nbp; ++i) ptr+=(unsigned int)(*ptr) + 1;
  CImg<T>(ptr0,1,ptr-ptr0,1,1).move_to(res); // Primitives.
  ptr0 = ptr;
  for (unsigned int i = 0; i<nbp; ++i) {
    const T val = *(ptr++);
    if (val!=-128) ptr+=2;
    else {
      const unsigned int
        w = (unsigned int)*(ptr++),
        h = (unsigned int)*(ptr++),
        s = (unsigned int)*(ptr++);
      if (w*h*s!=0) ptr+=w*h*s;
    }
  }
  CImg<T>(ptr0,1,ptr-ptr0,1,1).move_to(res); // Colors/Textures.
  ptr0 = ptr;
  for (unsigned int i = 0; i<nbp; ++i) {
    const T val = *(ptr++);
    if (val==-128) {
      const unsigned int
        w = (unsigned int)*(ptr++),
        h = (unsigned int)*(ptr++),
        s = (unsigned int)*(ptr++);
      if (w*h*s!=0) ptr+=w*h*s;
    }
  }
  CImg<T>(ptr0,1,ptr-ptr0,1,1).move_to(res); // Opacities.
  return res;
}

static CImg<T> append_CImg3d(const CImgList<T>& images) {
  if (!images) return CImg<T>();
  if (images.size()==1) return +images[0];
  char error_message[1024] = { 0 };
  unsigned int nbv = 0, nbp = 0;
  unsigned long siz = 0;
  cimglist_for(images,l) {
    const CImg<T>& img = images[l];
    if (!img.is_CImg3d(false,error_message))
      throw CImgArgumentException("append_CImg3d(): image [%d] (%u,%u,%u,%u,%p) "
                                  "is not a CImg3d (%s).",
                                  img._width,img._height,img._depth,img._spectrum,img._data,
                                  error_message);
    siz+=img.size() - 8;
    nbv+=cimg::float2uint((float)img[6]);
    nbp+=cimg::float2uint((float)img[7]);
  }

  CImg<T> res(1,siz + 8);
  const T **const ptrs = new const T*[images.size()];
  T *ptrd = res._data;
  *(ptrd++) = (T)('C' + 0.5f); *(ptrd++) = (T)('I' + 0.5f); // Create object header.
  *(ptrd++) = (T)('m' + 0.5f); *(ptrd++) = (T)('g' + 0.5f);
  *(ptrd++) = (T)('3' + 0.5f); *(ptrd++) = (T)('d' + 0.5f);
  *(ptrd++) = (T)nbv;
  *(ptrd++) = (T)nbp;
  cimglist_for(images,l) { // Merge object points.
    const CImg<T>& img = images[l];
    const unsigned int nbv = cimg::float2uint((float)img[6]);
    std::memcpy(ptrd,img._data + 8,3*nbv*sizeof(T));
    ptrd+=3*nbv;
    ptrs[l] = img._data + 8 + 3*nbv;
  }
  unsigned long poff = 0;
  cimglist_for(images,l) { // Merge object primitives.
    const unsigned int
      nbv = cimg::float2uint((float)images[l][6]),
      nbp = cimg::float2uint((float)images[l][7]);
    for (unsigned int p = 0; p<nbp; ++p) {
      const unsigned int
        nbi = cimg::float2uint((float)*(ptrs[l]++)),
        _nbi = nbi<5?nbi:nbi==5?2:nbi/3;
      *(ptrd++) = (T)cimg::uint2float(nbi);
      for (unsigned int i = 0; i<_nbi; ++i) *(ptrd++) = (T)(*(ptrs[l]++) + poff);
      for (unsigned int i = nbi-_nbi; i; --i) *(ptrd++) = *(ptrs[l]++);
    }
    poff+=nbv;
  }
  unsigned long voff = 0;
  cimglist_for(images,l) { // Merge object colors.
    const unsigned int nbc = cimg::float2uint((float)images[l][7]);
    for (unsigned int c = 0; c<nbc; ++c)
      if (*(ptrs[l])==(T)-128) {
        *(ptrd++) = *(ptrs[l]++);
        const unsigned int
          w = (unsigned int)*(ptrs[l]++),
          h = (unsigned int)*(ptrs[l]++),
          s = (unsigned int)*(ptrs[l]++);
        if (!h && !s) { *(ptrd++) = (T)(w + voff); *(ptrd++) = 0; *(ptrd++) = 0; }
        else {
          *(ptrd++) = (T)w; *(ptrd++) = (T)h; *(ptrd++) = (T)s;
          const unsigned long whs = (unsigned long)w*h*s;
          std::memcpy(ptrd,ptrs[l],whs*sizeof(T));
          ptrs[l]+=whs; ptrd+=whs;
        }
      } else { *(ptrd++) = *(ptrs[l]++); *(ptrd++) = *(ptrs[l]++); *(ptrd++) = *(ptrs[l]++); }
    voff+=nbc;
  }
  voff = 0;
  cimglist_for(images,l) { // Merge object opacities.
    const unsigned int nbo = cimg::float2uint((float)images[l][7]);
    for (unsigned int o = 0; o<nbo; ++o)
      if (*(ptrs[l])==(T)-128) {
        *(ptrd++) = *(ptrs[l]++);
        const unsigned int
          w = (unsigned int)*(ptrs[l]++),
          h = (unsigned int)*(ptrs[l]++),
          s = (unsigned int)*(ptrs[l]++);
        if (!h && !s) { *(ptrd++) = (T)(w + voff); *(ptrd++) = 0; *(ptrd++) = 0; }
        else {
          *(ptrd++) = (T)w; *(ptrd++) = (T)h; *(ptrd++) = (T)s;
          const unsigned long whs = (unsigned long)w*h*s;
          std::memcpy(ptrd,ptrs[l],whs*sizeof(T));
          ptrs[l]+=whs; ptrd+=whs;
        }
      } else *(ptrd++) = *(ptrs[l]++);
    voff+=nbo;
  }
  delete[] ptrs;
  return res;
}

template<typename t>
CImg<T>& rotate_CImg3d(const CImg<t>& rot) {
  char error_message[1024] = { 0 };
  if (!is_CImg3d(false,error_message))
    throw CImgInstanceException(_cimg_instance
                                "rotate_CImg3d(): image instance is not a CImg3d (%s).",
                                cimg_instance,error_message);
  const unsigned int nbv = cimg::float2uint((float)(*this)[6]);
  const T *ptrs = data() + 8;
  const float
    a = (float)rot(0,0), b = (float)rot(1,0), c = (float)rot(2,0),
    d = (float)rot(0,1), e = (float)rot(1,1), f = (float)rot(2,1),
    g = (float)rot(0,2), h = (float)rot(1,2), i = (float)rot(2,2);
  T *ptrd = data() + 8;
  for (unsigned int j = 0; j<nbv; ++j) {
    const float x = (float)*(ptrs++), y = (float)*(ptrs++), z = (float)*(ptrs++);
    *(ptrd++) = (T)(a*x + b*y + c*z);
    *(ptrd++) = (T)(d*x + e*y + f*z);
    *(ptrd++) = (T)(g*x + h*y + i*z);
  }
  return *this;
}

template<typename t>
CImg<T> get_rotate_CImg3d(const CImg<t>& rot) const {
  return (+*this).rotate_CImg3d(rot);
}

CImg<T>& shift_CImg3d(const float tx, const float ty, const float tz) {
  char error_message[1024] = { 0 };
  if (!is_CImg3d(false,error_message))
    throw CImgInstanceException(_cimg_instance
                                "shift_CImg3d(): image instance is not a CImg3d (%s).",
                                cimg_instance,error_message);
  const unsigned int nbv = cimg::float2uint((float)(*this)[6]);
  T *ptrd = data() + 8;
  for (unsigned int j = 0; j<nbv; ++j) { *(ptrd++)+=(T)tx; *(ptrd++)+=(T)ty; *(ptrd++)+=(T)tz; }
  return *this;
}

CImg<T> get_shift_CImg3d(const float tx, const float ty, const float tz) const {
  return (+*this).shift_CImg3d(tx,ty,tz);
}

CImg<T>& scale_CImg3d(const float sx, const float sy, const float sz) {
  char error_message[1024] = { 0 };
  if (!is_CImg3d(false,error_message))
    throw CImgInstanceException(_cimg_instance
                                "scale_CImg3d(): image instance is not a CImg3d (%s).",
                                cimg_instance,error_message);
  const unsigned int nbv = cimg::float2uint((float)(*this)[6]);
  T *ptrd = data() + 8;
  for (unsigned int j = 0; j<nbv; ++j) { *(ptrd++)*=(T)sx; *(ptrd++)*=(T)sy; *(ptrd++)*=(T)sz; }
  return *this;
}

CImg<T> get_scale_CImg3d(const float sx, const float sy, const float sz) const {
  return (+*this).scale_CImg3d(sx,sy,sz);
}

CImg<T>& reverse_CImg3d() {
  char error_message[1024] = { 0 };
  if (!is_CImg3d(false,error_message))
    throw CImgInstanceException(_cimg_instance
                                "reverse_CImg3d(): image instance is not a CImg3d (%s).",
                                cimg_instance,error_message);
  T *p = _data + 6;
  const unsigned int nbv = (unsigned int)*(p++), nbp = (unsigned int)*(p++);
  p+=3*nbv;
  for (unsigned int i = 0; i<nbp; ++i) {
    const unsigned int nb = (unsigned int)*(p++);
    switch(nb) {
    case 2: case 3: cimg::swap(p[0],p[1]); break;
    case 6: cimg::swap(p[0],p[1],p[2],p[4],p[3],p[5]); break;
    case 9: cimg::swap(p[0],p[1],p[3],p[5],p[4],p[6]); break;
    case 4: cimg::swap(p[0],p[1],p[2],p[3]); break;
    case 12: cimg::swap(p[0],p[1],p[2],p[3],p[4],p[6],p[5],p[7],p[8],p[10],p[9],p[11]); break;
    }
    p+=nb;
  }
  return *this;
}

CImg<T> get_reverse_CImg3d() const {
  return (+*this).reverse_CImg3d();
}

CImg<T>& color_CImg3d(const float R, const float G, const float B, const float opacity,
                      const bool set_RGB, const bool set_opacity) {
  char error_message[1024] = { 0 };
  if (!is_CImg3d(false,error_message))
    throw CImgInstanceException(_cimg_instance
                                "color_CImg3d(): image instance is not a CImg3d (%s).",
                                cimg_instance,error_message);
  T *ptrd = data() + 6;
  const unsigned int
    nbv = cimg::float2uint((float)*(ptrd++)),
    nbp = cimg::float2uint((float)*(ptrd++));
  ptrd+=3*nbv;
  for (unsigned int i = 0; i<nbp; ++i) { const unsigned int N = (unsigned int)*(ptrd++); ptrd+=N; }
  for (unsigned int c = 0; c<nbp; ++c)
    if (*ptrd==(T)-128) {
      ++ptrd;
      const unsigned int
        w = (unsigned int)*(ptrd++),
        h = (unsigned int)*(ptrd++),
        s = (unsigned int)*(ptrd++);
      ptrd+=w*h*s;
    } else if (set_RGB) { *(ptrd++) = (T)R; *(ptrd++) = (T)G; *(ptrd++) = (T)B; } else ptrd+=3;
  if (set_opacity)
    for (unsigned int o = 0; o<nbp; ++o) {
      if (*ptrd==(T)-128) {
        ++ptrd;
        const unsigned int
          w = (unsigned int)*(ptrd++),
          h = (unsigned int)*(ptrd++),
          s = (unsigned int)*(ptrd++);
        ptrd+=w*h*s;
      } else *(ptrd++) = (T)opacity;
    }
  return *this;
}

CImg<T> get_color_CImg3d(const float R, const float G, const float B,
                         const float opacity, const bool set_RGB, const bool set_opacity) const {
  return (+*this).color_CImg3d(R,G,B,opacity,set_RGB,set_opacity);
}

CImg<T>& texturize_CImg3d(const CImg<T>& texture, const CImg<T>& coords) {
  return get_texturize_CImg3d(texture,coords).move_to(*this);
}

CImg<T> get_texturize_CImg3d(const CImg<T>& texture, const CImg<T>& coords) const {
  CImgList<uintT> primitives;
  CImgList<T> colors;
  CImgList<floatT> opacities;
  const CImg<floatT> points = get_CImg3dtoobject3d(primitives,colors,opacities,false);
  points.texturize_object3d(primitives,colors,texture,coords);
  return points.get_object3dtoCImg3d(primitives,colors,opacities,false);
}

CImg<T>& convert_primitives_CImg3d(const unsigned int mode) {
  char error_message[1024] = { 0 };
  if (!is_CImg3d(false,error_message))
    throw CImgInstanceException(_cimg_instance
                                "convert_primitives_CImg3d(): image instance is not a CImg3d (%s).",
                                cimg_instance,error_message);
  CImgList<uintT> primitives;
  CImgList<floatT> colors, opacities;
  CImg3dtoobject3d(primitives,colors,opacities,false);
  const unsigned int psiz = primitives.size();
  CImg<uintT> P;
  CImg<floatT> C, O;
  for (unsigned int p = 0; p<psiz; ++p) {
    primitives[p].move_to(P);
    colors[p].move_to(C);
    opacities[p].move_to(O);
    switch (P.size()) {
    case 1 : // Point.
      P.move_to(primitives);
      if (mode==2) {
        if (C.size()==3) C.move_to(colors);
        else C.get_vector_at(C.width()/2,C.height()/2).move_to(colors);
        if (O.size()==1) O.move_to(opacities);
        else O.get_vector_at(O.width()/2,O.height()/2).move_to(opacities);
      } else { C.move_to(colors); O.move_to(opacities); }
      break;
    case 2 : // Colored segment.
      if (mode) { P.move_to(primitives); C.move_to(colors); O.move_to(opacities); }
      else {
        CImg<uintT>::vector(P[0]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[1]).move_to(primitives);
        C.move_to(colors); O.move_to(opacities);
      }
      break;
    case 3 : // Colored triangle.
      if (mode==2) {
        P.move_to(primitives); C.move_to(colors); O.move_to(opacities);
      } else if (mode==1) {
        CImg<uintT>::vector(P[0],P[1]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[1],P[2]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[2],P[0]).move_to(primitives);
        C.move_to(colors); O.move_to(opacities);
      } else {
        CImg<uintT>::vector(P[0]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[1]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[2]).move_to(primitives);
        C.move_to(colors); O.move_to(opacities);
      }
      break;
    case 4 : // Colored quadrangle.
      if (mode==2) {
        P.move_to(primitives); C.move_to(colors); O.move_to(opacities);
      } else if (mode==1) {
        CImg<uintT>::vector(P[0],P[1]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[1],P[2]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[2],P[3]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[3],P[0]).move_to(primitives);
        C.move_to(colors); O.move_to(opacities);
      } else {
        CImg<uintT>::vector(P[0]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[1]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[2]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[3]).move_to(primitives);
        C.move_to(colors); O.move_to(opacities);
      }
      break;
    case 5 : // Sphere.
      if (mode==2) {
        P.move_to(primitives); C.move_to(colors); O.move_to(opacities);
      } else if (mode==1) {
        CImg<uintT>::vector(P[0],P[1]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
      } else {
        CImg<uintT>::vector(P[0]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[1]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
      }
      break;
    case 6 : // Textured segment.
      if (mode==2) {
        CImg<uintT>::vector(P[0],P[1]).move_to(primitives);
        C.get_vector_at(P[2],P[3]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[2],P[3])).move_to(opacities);
        else O.move_to(opacities);
      } else if (mode==1) {
        P.move_to(primitives); C.move_to(colors); O.move_to(opacities);
      } else {
        CImg<uintT>::vector(P[0]).move_to(primitives);
        C.get_vector_at(P[2],P[3]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[2],P[3])).move_to(opacities);
        else opacities.insert(O);
        CImg<uintT>::vector(P[1]).move_to(primitives);
        C.get_vector_at(P[4],P[5]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[4],P[5])).move_to(opacities);
        else O.move_to(opacities);
      }
      break;
    case 9 : // Textured triangle.
      if (mode==2) {
        CImg<uintT>::vector(P[0],P[1],P[2]).move_to(primitives);
        C.get_vector_at(P[3],P[4]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[3],P[4])).move_to(opacities);
        else O.move_to(opacities);
      } else if (mode==1) {
        CImg<uintT>::vector(P[0],P[1],P[3],P[4],P[5],P[6]).
          move_to(primitives);
        C.move_to(colors); opacities.insert(O);
        CImg<uintT>::vector(P[1],P[2],P[3],P[4],P[7],P[8]).
          move_to(primitives);
        colors.insert(colors.back(),~0U,true); opacities.insert(O);
        CImg<uintT>::vector(P[2],P[0],P[7],P[8],P[1],P[3]).
          move_to(primitives);
        colors.insert(colors.back(),~0U,true); O.move_to(opacities);
      } else {
        CImg<uintT>::vector(P[0]).move_to(primitives);
        C.get_vector_at(P[3],P[4]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[3],P[4])).move_to(opacities);
        else opacities.insert(O);
        CImg<uintT>::vector(P[1]).move_to(primitives);
        C.get_vector_at(P[5],P[6]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[5],P[6])).move_to(opacities);
        else opacities.insert(O);
        CImg<uintT>::vector(P[2]).move_to(primitives);
        C.get_vector_at(P[7],P[8]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[7],P[8])).move_to(opacities);
        else O.move_to(opacities);
      }
      break;
    case 12 : // Textured quadrangle.
      if (mode==2) {
        CImg<uintT>::vector(P[0],P[1],P[2],P[3]).move_to(primitives);
        C.get_vector_at(P[4],P[5]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[4],P[5])).move_to(opacities);
        else O.move_to(opacities);
      } else if (mode==1) {
        CImg<uintT>::vector(P[0],P[1],P[4],P[5],P[6],P[7]).
          move_to(primitives);
        C.move_to(colors); opacities.insert(O);
        CImg<uintT>::vector(P[1],P[2],P[6],P[7],P[8],P[9]).
          move_to(primitives);
        colors.insert(colors.back(),~0U,true); opacities.insert(O);
        CImg<uintT>::vector(P[2],P[3],P[8],P[9],P[10],P[11]).
          move_to(primitives);
        colors.insert(colors.back(),~0U,true); opacities.insert(O);
        CImg<uintT>::vector(P[3],P[0],P[10],P[11],P[4],P[5]).
          move_to(primitives);
        colors.insert(colors.back(),~0U,true); O.move_to(opacities);
      } else {
        CImg<uintT>::vector(P[0]).move_to(primitives);
        C.get_vector_at(P[4],P[5]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[4],P[5])).move_to(opacities);
        else opacities.insert(O);
        CImg<uintT>::vector(P[1]).move_to(primitives);
        C.get_vector_at(P[6],P[7]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[6],P[7])).move_to(opacities);
        else opacities.insert(O);
        CImg<uintT>::vector(P[2]).move_to(primitives);
        C.get_vector_at(P[8],P[9]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[8],P[9])).move_to(opacities);
        else opacities.insert(O);
        CImg<uintT>::vector(P[3]).move_to(primitives);
        C.get_vector_at(P[10],P[11]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[10],P[11])).move_to(opacities);
        else O.move_to(opacities);
      }
      break;
    default : // Other primitives.
      P.move_to(primitives);
      C.move_to(colors);
      O.move_to(opacities);
    }
  }
  if (psiz) {
    primitives.remove(0,psiz-1);
    colors.remove(0,psiz-1);
    opacities.remove(0,psiz-1);
  }
  object3dtoCImg3d(primitives,colors,opacities,false);
  return *this;
}

CImg<T> get_convert_primitives_CImg3d(const unsigned int mode) const {
  return (+*this).convert_primitives_CImg3d(mode);
}

// Additional filters.

template<typename t>
CImg<T>& inpaint(const CImg<t>& mask, const unsigned int method=1) {
  if (!is_sameXYZ(mask))
    throw CImgArgumentException("CImg<%s>::inpaint(): Invalid mask (%u,%u,%u,%u,%p) for "
                                "instance image (%u,%u,%u,%u,%p).",
                                pixel_type(),mask._width,mask._height,mask._depth,
                                mask._spectrum,mask._data,
                                _width,_height,_depth,_spectrum,_data);
  CImg<t> _mask(mask,false), _nmask(mask,false);
  bool is_pixel = false;

  do {
    is_pixel = false;

    if (depth()==1) { // 2d image.
      CImg_3x3(M,t);
      CImg_3x3(I,T);

      switch (method) {
      case 0: // Average 2d (low-connectivity).
        cimg_for3x3(_mask,x,y,0,0,M,t) if (Mcc && (!Mcp || !Mpc || !Mnc || !Mcn)) {
          is_pixel = true;
          const unsigned int wcp = Mcp?0:1, wpc = Mpc?0:1, wnc = Mnc?0:1, wcn = Mcn?0:1,
            sumw = wcp + wpc + wnc + wcn;
          cimg_forC(*this,k) {
            cimg_get3x3(*this,x,y,0,k,I,T);
            (*this)(x,y,k) = (T)((wcp*Icp + wpc*Ipc + wnc*Inc + wcn*Icn)/(float)sumw);
          }
          _nmask(x,y) = 0;
        }
        break;

      case 1: // Average 2d (high-connectivity).
        cimg_for3x3(_mask,x,y,0,0,M,t) if (Mcc && (!Mpp || !Mcp || !Mnp || !Mpc || !Mnc || !Mpn || !Mcn || !Mnn)) {
          is_pixel = true;
          const unsigned int
            wpp = Mpp?0:1, wcp = Mcp?0:2, wnp = Mnp?0:1,
            wpc = Mpc?0:2, wnc = Mnc?0:2,
            wpn = Mpn?0:1, wcn = Mcn?0:2, wnn = Mnn?0:1,
            sumw = wpp + wcp + wnp + wpc + wnc + wpn + wcn + wnn;
          cimg_forC(*this,k) {
            cimg_get3x3(*this,x,y,0,k,I,T);
            (*this)(x,y,k) = (T)((wpp*Ipp + wcp*Icp + wnp*Inp + wpc*Ipc + wnc*Inc + wpn*Ipn + wcn*Icn + wnn*Inn)/(float)sumw);
          }
          _nmask(x,y) = 0;
        }
        break;

      case 2: { // Median 2d (low-connectivity).
        T J[4];
        cimg_for3x3(_mask,x,y,0,0,M,t)
          if (Mcc && (!Mcp || !Mpc || !Mnc || !Mcn)) {
            is_pixel = true;
            cimg_forC(*this,k) {
              cimg_get3x3(*this,x,y,0,k,I,T);
              unsigned int ind = 0;
              if (!Mcp) J[ind++] = Icp;
              if (!Mpc) J[ind++] = Ipc;
              if (!Mnc) J[ind++] = Inc;
              if (!Mcn) J[ind++] = Icn;
              (*this)(x,y,k) = CImg<T>(J,ind,1,1,1,true).kth_smallest(ind>>1);
            }
            _nmask(x,y) = 0;
          }
      } break;

      default: // Median 2d (high-connectivity).
        T J[8];
        cimg_for3x3(_mask,x,y,0,0,M,t) if (Mcc && (!Mpp || !Mcp || !Mnp || !Mpc || !Mnc || !Mpn || !Mcn || !Mnn)) {
          is_pixel = true;
          cimg_forC(*this,k) {
            cimg_get3x3(*this,x,y,0,k,I,T);
            unsigned int ind = 0;
            if (!Mpp) J[ind++] = Ipp; if (!Mcp) J[ind++] = Icp; if (!Mnp) J[ind++] = Inp;
            if (!Mpc) J[ind++] = Ipc; if (!Mnc) J[ind++] = Inc;
            if (!Mpn) J[ind++] = Ipn; if (!Mcn) J[ind++] = Icn; if (!Mnn) J[ind++] = Inn;
            (*this)(x,y,k) = CImg<T>(J,ind,1,1,1,true).kth_smallest(ind>>1);
          }
          _nmask(x,y) = 0;
        }
      }

    } else { // 3d image.
      CImg_3x3x3(M,t);
      CImg_3x3x3(I,T);

      switch (method) {
      case 0: // Average 3d (low-connectivity).
        cimg_for3x3x3(_mask,x,y,z,0,M,t) if (Mccc && (!Mccp || !Mcpc || !Mpcc || !Mncc || !Mcnc || !Mccn)) {
          is_pixel = true;
          const unsigned int
            wccp = Mccp?0:1, wcpc = Mcpc?0:1, wpcc = Mpcc?0:1,
            wncc = Mncc?0:1, wcnc = Mcnc?0:1, wccn = Mccn?0:1,
            sumw = wcpc + wpcc + wccp + wncc + wcnc + wccn;
          cimg_forC(*this,k) {
            cimg_get3x3x3(*this,x,y,z,k,I,T);
            (*this)(x,y,z,k) = (T)((wccp*Iccp + wcpc*Icpc + wpcc*Ipcc + wncc*Incc + wcnc*Icnc + wccn*Iccn)/(float)sumw);
          }
          _nmask(x,y,z) = 0;
        }
        break;

      case 1: // Average 3d (high-connectivity).
        cimg_for3x3x3(_mask,x,y,z,0,M,t)
          if (Mccc && (!Mppp || !Mcpp || !Mnpp || !Mpcp || !Mccp || !Mncp || !Mpnp || !Mcnp || !Mnnp ||
                       !Mppc || !Mcpc || !Mnpc || !Mpcc || !Mncc || !Mpnc || !Mcnc || !Mnnc ||
                       !Mppn || !Mcpn || !Mnpn || !Mpcn || !Mccn || !Mncn || !Mpnn || !Mcnn || !Mnnn)) {
            is_pixel = true;
            const unsigned int
              wppp = Mppp?0:1, wcpp = Mcpp?0:2, wnpp = Mnpp?0:1,
              wpcp = Mpcp?0:2, wccp = Mccp?0:4, wncp = Mncp?0:2,
              wpnp = Mpnp?0:1, wcnp = Mcnp?0:2, wnnp = Mnnp?0:1,
              wppc = Mppc?0:2, wcpc = Mcpc?0:4, wnpc = Mnpc?0:2,
              wpcc = Mpcc?0:4, wncc = Mncc?0:4,
              wpnc = Mpnc?0:2, wcnc = Mcnc?0:4, wnnc = Mnnc?0:2,
              wppn = Mppn?0:1, wcpn = Mcpn?0:2, wnpn = Mnpn?0:1,
              wpcn = Mpcn?0:2, wccn = Mccn?0:4, wncn = Mncn?0:2,
              wpnn = Mpnn?0:1, wcnn = Mcnn?0:2, wnnn = Mnnn?0:1,
              sumw = wppp + wcpp + wnpp + wpcp + wccp + wncp + wpnp + wcnp + wnnp +
              wppc + wcpc + wnpc + wpcc + wncc + wpnc + wcnc + wnnc +
              wppn + wcpn + wnpn + wpcn + wccn + wncn + wpnn + wcnn + wnnn;
            cimg_forC(*this,k) {
              cimg_get3x3x3(*this,x,y,z,k,I,T);
              (*this)(x,y,z,k) = (T)((wppp*Ippp + wcpp*Icpp + wnpp*Inpp +
                                      wpcp*Ipcp + wccp*Iccp + wncp*Incp +
                                      wpnp*Ipnp + wcnp*Icnp + wnnp*Innp +
                                      wppc*Ippc + wcpc*Icpc + wnpc*Inpc +
                                      wpcc*Ipcc + wncc*Incc +
                                      wpnc*Ipnc + wcnc*Icnc + wnnc*Innc +
                                      wppn*Ippn + wcpn*Icpn + wnpn*Inpn +
                                      wpcn*Ipcn + wccn*Iccn + wncn*Incn +
                                      wpnn*Ipnn + wcnn*Icnn + wnnn*Innn)/(float)sumw);
            }
            _nmask(x,y,z) = 0;
          }
        break;

      case 2: { // Median 3d (low-connectivity).
        T J[6];
        cimg_for3x3x3(_mask,x,y,z,0,M,t)
          if (Mccc && (!Mccp || !Mcpc || !Mpcc || !Mncc || !Mcnc || !Mccn)) {
            is_pixel = true;
            cimg_forC(*this,k) {
              cimg_get3x3x3(*this,x,y,z,k,I,T);
              unsigned int ind = 0;
              if (!Mccp) J[ind++] = Iccp; if (!Mcpc) J[ind++] = Icpc; if (!Mpcc) J[ind++] = Ipcc;
              if (!Mncc) J[ind++] = Incc; if (!Mcnc) J[ind++] = Icnc; if (!Mccn) J[ind++] = Iccn;
              (*this)(x,y,z,k) = CImg<T>(J,ind,1,1,1,true).kth_smallest(ind>>1);
            }
            _nmask(x,y,z) = 0;
          }
      } break;

      default: { // Median 3d (high-connectivity).
        T J[26];
        cimg_for3x3x3(_mask,x,y,z,0,M,t)
          if (Mccc && (!Mppp || !Mcpp || !Mnpp || !Mpcp || !Mccp || !Mncp || !Mpnp || !Mcnp || !Mnnp ||
                       !Mppc || !Mcpc || !Mnpc || !Mpcc || !Mncc || !Mpnc || !Mcnc || !Mnnc ||
                       !Mppn || !Mcpn || !Mnpn || !Mpcn || !Mccn || !Mncn || !Mpnn || !Mcnn || !Mnnn)) {
            is_pixel = true;
            cimg_forC(*this,k) {
              cimg_get3x3x3(*this,x,y,z,k,I,T);
              unsigned int ind = 0;
              if (!Mppp) J[ind++] = Ippp; if (!Mcpp) J[ind++] = Icpp; if (!Mnpp) J[ind++] = Inpp;
              if (!Mpcp) J[ind++] = Ipcp; if (!Mccp) J[ind++] = Iccp; if (!Mncp) J[ind++] = Incp;
              if (!Mpnp) J[ind++] = Ipnp; if (!Mcnp) J[ind++] = Icnp; if (!Mnnp) J[ind++] = Innp;
              if (!Mppc) J[ind++] = Ippc; if (!Mcpc) J[ind++] = Icpc; if (!Mnpc) J[ind++] = Inpc;
              if (!Mpcc) J[ind++] = Ipcc; if (!Mncc) J[ind++] = Incc;
              if (!Mpnc) J[ind++] = Ipnc; if (!Mcnc) J[ind++] = Icnc; if (!Mnnc) J[ind++] = Innc;
              if (!Mppn) J[ind++] = Ippn; if (!Mcpn) J[ind++] = Icpn; if (!Mnpn) J[ind++] = Inpn;
              if (!Mpcn) J[ind++] = Ipcn; if (!Mccn) J[ind++] = Iccn; if (!Mncn) J[ind++] = Incn;
              if (!Mpnn) J[ind++] = Ipnn; if (!Mcnn) J[ind++] = Icnn; if (!Mnnn) J[ind++] = Innn;
              (*this)(x,y,z,k) = CImg<T>(J,ind,1,1,1,true).kth_smallest(ind>>1);
            }
            _nmask(x,y,z) = 0;
          }
      } break;
      }
    }

    _mask = _nmask;
  } while (is_pixel);
  return *this;
}

template<typename t>
CImg<T> get_inpaint(const CImg<t>& mask, const unsigned int method=1) const {
  return (+*this).inpaint(mask,method);
}

template<typename t>
CImg<T>& inpaint_patch(const CImg<t>& mask, const unsigned int patch_size=11,
                       const unsigned int lookup_size=22, const float lookup_factor=1,
                       const unsigned int lookup_increment=1,
                       const unsigned int blend_size=0, const float blend_threshold=0.5f,
                       const float blend_decay=0.02, const unsigned int blend_scales=10,
                       const bool is_blend_outer=false) {
  if (depth()>1)
    throw CImgInstanceException(_cimg_instance
                                "inpaint_patch(): Instance image is volumetric (should be 2d).",
                                cimg_instance);
  if (!is_sameXYZ(mask))
    throw CImgArgumentException(_cimg_instance
                                "inpaint_patch() : Sizes of instance image and specified mask "
                                "(%u,%u,%u,%u) do not match.",
                                cimg_instance,
                                mask._width,mask._height,mask._depth,mask._spectrum);
  if (!patch_size)
    throw CImgArgumentException(_cimg_instance
                                "inpaint_patch() : Specified patch size is 0, must be strictly "
                                "positive.",
                                cimg_instance);
  if (!lookup_size)
    throw CImgArgumentException(_cimg_instance
                                "inpaint_patch() : Specified lookup size is 0, must be strictly "
                                "positive.",
                                cimg_instance);
  if (lookup_factor<0)
    throw CImgArgumentException(_cimg_instance
                                "inpaint_patch() : Specified lookup factor %g is negative, must be "
                                "positive.",
                                cimg_instance,
                                lookup_factor);
  if (!lookup_increment)
    throw CImgArgumentException(_cimg_instance
                                "inpaint_patch() : Specified lookup increment is 0, must be strictly "
                                "positive.",
                                cimg_instance);
  if (blend_decay<0)
    throw CImgArgumentException(_cimg_instance
                                "inpaint_patch() : Specified blend decay %g is negative, must be "
                                "positive.",
                                cimg_instance,
                                blend_decay);

  // Find (dilated by 2) bounding box for the inpainting mask.
  unsigned int xm0 = _width, ym0 = _height, xm1 = 0, ym1 = 0;
  bool is_mask_found = false;
  cimg_forXY(mask,x,y) if (mask(x,y)) {
    is_mask_found = true;
    if (x<(int)xm0) xm0 = (unsigned int)x;
    if (x>(int)xm1) xm1 = (unsigned int)x;
    if (y<(int)ym0) ym0 = (unsigned int)y;
    if (y>(int)ym1) ym1 = (unsigned int)y;
  }
  if (!is_mask_found) return *this;
  xm0 = xm0>2?xm0-2:0;
  ym0 = ym0>2?ym0-2:0;
  xm1 = xm1<_width-3?xm1+2:_width-1;
  ym1 = ym1<_height-3?ym1+2:_height-1;
  int ox = xm0, oy = ym0;
  unsigned int dx = xm1 - xm0 + 1U, dy = ym1 - ym0 + 1U;

  // Construct normalized version of the mask.
  CImg<ucharT> nmask(dx,dy);
  unsigned char *ptrM = nmask.data();
  cimg_for_inXY(mask,xm0,ym0,xm1,ym1,x,y) *(ptrM++) = mask(x,y)?0:1;
  xm0 = ym0 = 0; xm1 = dx - 1; ym1 = dy - 1;

  // Start patch filling algorithm.
  const int p2 = (int)patch_size/2, p1 = (int)patch_size - p2 - 1;
  const unsigned int patch_size2 = patch_size*patch_size;
  unsigned int _lookup_size = lookup_size, nb_lookups = 0, nb_fails = 0, nb_saved_patches = 0;
  bool is_strict_search = true;
  const float one = 1;

  CImg<floatT> confidences(nmask), priorities(dx,dy,1,2,-1), pC;
  CImg<unsigned int> saved_patches(4,256), is_visited(width(),height(),1,1,0);
  CImg<ucharT> pM, pN;  // Pre-declare patch variables (avoid iterative memory alloc/dealloc).
  CImg<T> pP, pbest;
  CImg<floatT> weights(patch_size,patch_size,1,1,0);
  weights.draw_gaussian((float)p1,(float)p1,patch_size/15.0f,&one)/=patch_size2;
  unsigned int target_index = 0;

  while (true) {

    // Extract mask border points and compute priorities to find target point.
    unsigned int nb_border_points = 0;
    float target_confidence = -1, target_priority = -1;
    int target_x = -1, target_y = -1;
    CImg_5x5(M,unsigned char);

    cimg_for_in5x5(nmask,xm0,ym0,xm1,ym1,x,y,0,0,M,unsigned char)
      if (!Mcc && (Mcp || Mcn || Mpc || Mnc)) { // Found mask border point.

        float confidence_term = -1, data_term = -1;
        if (priorities(x,y)>=0) { // If priority has already been computed.
          confidence_term = priorities(x,y,0);
          data_term = priorities(x,y,1);
        } else { // If priority must be computed/updated.

          // Compute smoothed normal vector.
          const float
            Npc = (4.0f*Mpc + 2.0f*Mbc + 2.0f*Mcc + 2.0f*Mpp + 2.0f*Mpn + Mbp + Mbn + Mcp + Mcn)/16,  // N = smoothed 3x3 neighborhood of M.
            Nnc = (4.0f*Mnc + 2.0f*Mac + 2.0f*Mcc + 2.0f*Mnp + 2.0f*Mnn + Map + Man + Mcp + Mcn)/16,
            Ncp = (4.0f*Mcp + 2.0f*Mcb + 2.0f*Mcc + 2.0f*Mpp + 2.0f*Mnp + Mpb + Mnb + Mpc + Mnc)/16,
            Ncn = (4.0f*Mcn + 2.0f*Mca + 2.0f*Mcc + 2.0f*Mpn + 2.0f*Mnn + Mpa + Mna + Mpc + Mnc)/16,
            _nx = 0.5f*(Nnc - Npc),
            _ny = 0.5f*(Ncn - Ncp),
            nn = std::sqrt(1e-8f + _nx*_nx + _ny*_ny),
            nx = _nx/nn,
            ny = _ny/nn;

          // Compute confidence term.
          nmask._inpaint_patch_crop(x-p1,y-p1,x+p2,y+p2,1).move_to(pM);
          confidences._inpaint_patch_crop(x-p1,y-p1,x+p2,y+p2,1).move_to(pC);
          confidence_term = 0;
          const unsigned char *ptrM = pM.data();
          cimg_for(pC,ptrC,float) confidence_term+=*ptrC**(ptrM++);
          confidence_term/=patch_size2;
          priorities(x,y,0) = confidence_term;

          // Compute data term.
          _inpaint_patch_crop(ox+x-p1,oy+y-p1,ox+x+p2,oy+y+p2,2).move_to(pP);
          float mean_ix2 = 0, mean_ixiy = 0, mean_iy2 = 0;

          CImg_3x3(I,T);
          CImg_3x3(_M, unsigned char);
          cimg_forC(pP,c) cimg_for3x3(pP,p,q,0,c,I,T) { // Compute weight-mean of structure tensor inside patch.
            cimg_get3x3(pM,p,q,0,0,_M,unsigned char);
            const float
              ixf = (float)(_Mnc*_Mcc*(Inc-Icc)),
              iyf = (float)(_Mcn*_Mcc*(Icn-Icc)),
              ixb = (float)(_Mcc*_Mpc*(Icc-Ipc)),
              iyb = (float)(_Mcc*_Mcp*(Icc-Icp)),
              ix = cimg::abs(ixf)>cimg::abs(ixb)?ixf:ixb,
              iy = cimg::abs(iyf)>cimg::abs(iyb)?iyf:iyb,
              w = weights(p,q);
            mean_ix2 += w*ix*ix;
            mean_ixiy += w*ix*iy;
            mean_iy2 += w*iy*iy;
          }
          const float // Compute tensor-directed data term.
            ux = mean_ix2*(-ny) + mean_ixiy*nx,
            uy = mean_ixiy*(-ny) + mean_iy2*nx;
          data_term = std::sqrt(ux*ux + uy*uy);
          priorities(x,y,1) = data_term;
        }
        const float priority = confidence_term*data_term;
        if (priority>target_priority) {
          target_priority = priority; target_confidence = confidence_term;
          target_x = ox + x; target_y = oy + y;
        }
        ++nb_border_points;
      }
    if (!nb_border_points) break; // No more mask border points to inpaint!

    // Locate already reconstructed neighbors (if any), to get good origins for patch lookup.
    CImg<unsigned int> lookup_candidates(2,256);
    unsigned int nb_lookup_candidates = 0, *ptr_lookup_candidates = lookup_candidates.data();
    const unsigned int *ptr_saved_patches = saved_patches.data();
    const int
      x0 = target_x - (int)patch_size, y0 = target_y - (int)patch_size,
      x1 = target_x + (int)patch_size, y1 = target_y + (int)patch_size;
    for (unsigned int k = 0; k<nb_saved_patches; ++k) {
      const unsigned int
        src_x = *(ptr_saved_patches++), src_y = *(ptr_saved_patches++),
        dest_x = *(ptr_saved_patches++), dest_y = *(ptr_saved_patches++);
      if ((int)dest_x>=x0 && (int)dest_y>=y0 && (int)dest_x<=x1 && (int)dest_y<=y1) {
        const int off_x = target_x - dest_x, off_y = target_y - dest_y;
        *(ptr_lookup_candidates++) = src_x + off_x;
        *(ptr_lookup_candidates++) = src_y + off_y;
        if (++nb_lookup_candidates>=lookup_candidates._height) lookup_candidates.resize(2,-200,1,1,0);
      }
    }
    *(ptr_lookup_candidates++) = target_x;  // Add also target point as a center for the patch lookup.
    *(ptr_lookup_candidates++) = target_y;
    ++nb_lookup_candidates;

    // Divide size of lookup regions if several lookup sources have been detected.
    unsigned int final_lookup_size = _lookup_size;
    if (nb_lookup_candidates>1) {
      const unsigned int _final_lookup_size = (unsigned int)cimg::round(_lookup_size*lookup_factor/std::sqrt((float)nb_lookup_candidates),1,1);
      final_lookup_size = _final_lookup_size + 1 - (_final_lookup_size%2);
    }
    const int l2 = (int)final_lookup_size/2, l1 = (int)final_lookup_size - l2 - 1;

#ifdef gmic_debug
    CImg<ucharT> visu(*this,false);
    for (unsigned int C = 0; C<nb_lookup_candidates; ++C) {
      const int
        xl = lookup_candidates(0,C),
        yl = lookup_candidates(1,C);
      visu.draw_rectangle(xl-l1,yl-l1,xl+l2,yl+l2,CImg<ucharT>::vector(0,255,0).data(),0.2f);
    }
    visu.draw_rectangle(target_x-p1,target_y-p1,target_x+p2,target_y+p2,CImg<ucharT>::vector(255,0,0).data(),0.5f);
    static int foo = 0;
    if (!(foo%1)) {
      //      visu.save("video.ppm",foo);
      static CImgDisplay disp_debug;
      disp_debug.display(visu).set_title("DEBUG");
    }
    ++foo;
#endif
# 1397 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

    // Find best patch candidate to fill target point.
    _inpaint_patch_crop(target_x-p1,target_y-p1,target_x+p2,target_y+p2,0).move_to(pP);
    nmask._inpaint_patch_crop(target_x-ox-p1,target_y-oy-p1,target_x-ox+p2,target_y-oy+p2,0).
      move_to(pM);
    float best_ssd = cimg::type<float>::max();
    int best_x = -1, best_y = -1;
    ++target_index;

    ptr_lookup_candidates = lookup_candidates.data();
    for (unsigned int C = 0; C<nb_lookup_candidates; ++C) {
      const int
        xl = (int)*(ptr_lookup_candidates++),
        yl = (int)*(ptr_lookup_candidates++),
        x0 = cimg::max(p1,xl-l1), y0 = cimg::max(p1,yl-l1),
        x1 = cimg::min(width()-1-p2,xl+l2), y1 = cimg::min(height()-1-p2,yl+l2);
      for (int y = y0; y<=y1; y+=lookup_increment)
        for (int x = x0; x<=x1; x+=lookup_increment) if (is_visited(x,y)!=target_index) {
            if (is_strict_search) mask._inpaint_patch_crop(x-p1,y-p1,x+p2,y+p2,1).move_to(pN);
            else nmask._inpaint_patch_crop(x-ox-p1,y-oy-p1,x-ox+p2,y-oy+p2,0).move_to(pN);
            if ((is_strict_search && pN.sum()==0) || (!is_strict_search && pN.sum()==patch_size2)) {
              _inpaint_patch_crop(x-p1,y-p1,x+p2,y+p2,0).move_to(pC);
              float ssd = 0;
              const T *_pP = pP._data;
              const float *_pC = pC._data;
              cimg_for(pM,_pM,unsigned char) { if (*_pM) {
                  cimg_forC(pC,c) { ssd+=cimg::sqr((Tfloat)*_pC-(Tfloat)*_pP); _pC+=patch_size2; _pP+=patch_size2; }
                  if (ssd>=best_ssd) break;
                  _pC-=pC._spectrum*patch_size2;
                  _pP-=pC._spectrum*patch_size2;
                }
                ++_pC; ++_pP;
              }
              if (ssd<best_ssd) { best_ssd = ssd; best_x = x; best_y = y; }
            }
            is_visited(x,y) = target_index;
          }
    }

    if (best_x<0) { // If no best patch found.
      priorities(target_x-ox,target_y-oy,0)/=10; // Reduce its priority (lower data_term).
      if (++nb_fails>=4) { // If too much consecutive fails :
        nb_fails = 0;
        _lookup_size+=_lookup_size/2; // Try to expand the lookup size.
        if (++nb_lookups>=3) {
          if (is_strict_search) { // If still fails, switch to non-strict search mode.
            is_strict_search = false;
            _lookup_size = lookup_size;
            nb_lookups = 0;
          }
          else return *this; // Pathological case, probably a weird mask.
        }
      }
    } else { // Best patch found -> reconstruct missing part on the target patch.
      _lookup_size = lookup_size;
      nb_lookups = nb_fails = 0;
      _inpaint_patch_crop(best_x-p1,best_y-p1,best_x+p2,best_y+p2,0).move_to(pbest);
      nmask._inpaint_patch_crop(target_x-ox-p1,target_y-oy-p1,target_x-ox+p2,target_y-oy+p2,1).
        move_to(pM);
      cimg_for(pM,ptr,unsigned char) *ptr=1-*ptr;
      draw_image(target_x-p1,target_y-p1,pbest,pM,1,1);
      confidences.draw_image(target_x-ox-p1,target_y-oy-p1,pC.fill(target_confidence),pM,1,1);
      nmask.draw_rectangle(target_x-ox-p1,target_y-oy-p1,0,0,target_x-ox+p2,target_y-oy+p2,0,0,1);
      priorities.draw_rectangle(target_x-ox-(int)patch_size,
                                target_y-oy-(int)patch_size,0,0,
                                target_x-ox+3*p2/2,
                                target_y-oy+3*p2/2,0,0,-1);
      // Remember patch positions.
      unsigned int *ptr_saved_patches = saved_patches.data(0,nb_saved_patches);
      *(ptr_saved_patches++) = best_x;
      *(ptr_saved_patches++) = best_y;
      *(ptr_saved_patches++) = target_x;
      *ptr_saved_patches = target_y;
      if (++nb_saved_patches>=saved_patches._height) saved_patches.resize(4,-200,1,1,0);
    }
  }
  nmask.assign();  // Free some unused memory resources.
  priorities.assign();
  confidences.assign();
  is_visited.assign();

  // Blend inpainting result (if requested), using multi-scale blending algorithm.
  if (blend_size && blend_scales) {
    const float _blend_threshold = cimg::max(0.0f,cimg::min(1.0f,blend_threshold));
    saved_patches._height = nb_saved_patches;

    // Re-crop image and mask if outer blending is activated.
    if (is_blend_outer) {
      const int
        b2 = (int)blend_size/2, b1 = (int)blend_size - b2 - 1,
        xb0 = cimg::max(0,ox-b1),
        yb0 = cimg::max(0,oy-b1),
        xb1 = cimg::min(_width-1,xb0 + dx + b1 + b2),
        yb1 = cimg::min(_height-1,yb0 + dy + b1 + b2);
      ox = xb0; oy = yb0; dx = xb1 - xb0 + 1U, dy = yb1 - yb0 + 1U;
    }

    // Generate map of source offsets.
    CImg<unsigned int> offsets(dx,dy,1,2);
    unsigned int *ptr = saved_patches.end();
    cimg_forY(saved_patches,i) {
      const unsigned int yd = *(--ptr), xd = *(--ptr), ys = *(--ptr), xs = *(--ptr);
      for (int l=-p1; l<=p2; ++l)
        for (int k=-p1; k<=p2; ++k) {
          const int xdk = xd+k, ydl = yd+l;
          if (xdk>=0 && xdk<=width()-1 && ydl>=0 && ydl<=height()-1 && mask(xd+k,yd+l)) {
            offsets(xd-ox+k,yd-oy+l,0) = xs+k;
            offsets(xd-ox+k,yd-oy+l,1) = ys+l;
          }
        }
    }
    unsigned int *ptrx = offsets.data(0,0,0,0), *ptry = offsets.data(0,0,0,1);
    cimg_forXY(offsets,x,y) {
      if (!mask(x+ox,y+oy)) { *ptrx = x+ox; *ptry = y+oy; }
      ++ptrx; ++ptry;
    }

    // Generate map of local blending amplitudes.
    CImg<floatT> blend_map(dx,dy,1,1,0);
    CImg_3x3(I,float);
    cimg_for3XY(offsets,x,y) if (mask(x+ox,y+oy)) {
      const float
        iox = cimg::max((float)offsets(_n1x,y,0)-offsets(x,y,0),
                        (float)offsets(x,y,0)-offsets(_p1x,y,0)),
        ioy = cimg::max((float)offsets(x,_n1y,1)-offsets(x,y,1),
                        (float)offsets(x,y,1)-offsets(x,_p1y,1)),
        ion = std::sqrt(iox*iox+ioy*ioy);
      float iin = 0;
      cimg_forC(*this,c) {
        cimg_get3x3(*this,x,y,0,c,I,float);
        const float
          iix = (float)cimg::max(Inc-Icc,Icc-Ipc),
          iiy = (float)cimg::max(Icn-Icc,Icc-Icp);
        iin+=std::log(1+iix*iix+iiy*iiy);
      }
      iin/=_spectrum;
      blend_map(x,y) = ion*iin;
    }
    blend_map.threshold(blend_map.max()*_blend_threshold).distance(1);
    cimg_forXY(blend_map,x,y) blend_map(x,y) = 1/(1+blend_decay*blend_map(x,y));
    blend_map.quantize(blend_scales+1,false);
    float bm, bM = blend_map.max_min(bm);
    if (bm==bM) blend_map.fill((float)blend_scales);

    // Generate blending scales.
    CImg<T> result = _inpaint_patch_crop(ox,oy,ox+dx-1,oy+dy-1,0);
    for (unsigned int blend_iter = 1; blend_iter<=blend_scales; ++blend_iter) {
      const unsigned int
        _blend_width = blend_iter*blend_size/blend_scales,
        blend_width = _blend_width?_blend_width+1-(_blend_width%2):0;
      if (!blend_width) continue;
      const int b2 = (int)blend_width/2, b1 = (int)blend_width - b2 - 1;
      CImg<floatT>
        blended = _inpaint_patch_crop(ox,oy,ox+dx-1,oy+dy-1,0),
        cumul(dx,dy,1,1);
      weights.assign(blend_width,blend_width,1,1,0).
        draw_gaussian((float)b1,(float)b1,blend_width/4.0f,&one);
      cimg_forXY(cumul,x,y) cumul(x,y) = mask(x+ox,y+oy)?0.0f:1.0f;
      blended.mul(cumul);

      unsigned int *ptr = saved_patches.data();
      cimg_forY(saved_patches,l) {
        const int xs = (int)*(ptr++), ys = (int)*(ptr++), xd = (int)*(ptr++), yd = (int)*(ptr++);
        if (xs-b1<0 || ys-b1<0 || xs+b2>=width() || ys+b2>=height()) { // Blend with partial patch.
          const int
            xs0 = cimg::max(0,xs - b1),
            ys0 = cimg::max(0,ys - b1),
            xs1 = cimg::min(width()-1,xs + b2),
            ys1 = cimg::min(height()-1,ys + b2);
          _inpaint_patch_crop(xs0,ys0,xs1,ys1,0).move_to(pP);
          weights._inpaint_patch_crop(xs0-xs+b1,ys0-ys+b1,xs1-xs+b1,ys1-ys+b1,0).move_to(pC);
          blended.draw_image(xd+xs0-xs-ox,yd+ys0-ys-oy,pP,pC,-1);
          cumul.draw_image(xd+xs0-xs-ox,yd+ys0-ys-oy,pC,-1);
        } else { // Blend with full-size patch.
          _inpaint_patch_crop(xs-b1,ys-b1,xs+b2,ys+b2,0).move_to(pP);
          blended.draw_image(xd-b1-ox,yd-b1-oy,pP,weights,-1);
          cumul.draw_image(xd-b1-ox,yd-b1-oy,weights,-1);
        }
      }

      if (is_blend_outer) {
        cimg_forXY(blended,x,y) if (blend_map(x,y)==blend_iter) {
          const float cum = cumul(x,y);
          if (cum>0) cimg_forC(*this,c) result(x,y,c) = (T)(blended(x,y,c)/cum);
        }
      } else { cimg_forXY(blended,x,y) if (mask(x+ox,y+oy) && blend_map(x,y)==blend_iter) {
          const float cum = cumul(x,y);
          if (cum>0) cimg_forC(*this,c) result(x,y,c) = (T)(blended(x,y,c)/cum);
        }
      }
    }
    if (is_blend_outer) draw_image(ox,oy,result);
    else cimg_forXY(result,x,y) if (mask(x+ox,y+oy))
           cimg_forC(*this,c) (*this)(x+ox,y+oy,c) = (T)result(x,y,c);
  }
  return *this;
}

// Special crop function that supports more boundary conditions :
// 0=dirichlet (with value 0), 1=dirichlet (with value 1) and 2=neumann.
CImg<T> _inpaint_patch_crop(const int x0, const int y0, const int x1, const int y1,
                            const unsigned int boundary=0) const {
  const int
    nx0 = x0<x1?x0:x1, nx1 = x0^x1^nx0,
    ny0 = y0<y1?y0:y1, ny1 = y0^y1^ny0;
  CImg<T> res(1U + nx1 - nx0,1U + ny1 - ny0,1,_spectrum);
  if (nx0<0 || nx1>=width() || ny0<0 || ny1>=height()) {
    if (boundary>=2) cimg_forXYZC(res,x,y,z,c) res(x,y,z,c) = _atXY(nx0+x,ny0+y,z,c);
    else res.fill((T)boundary).draw_image(-nx0,-ny0,*this);
  } else res.draw_image(-nx0,-ny0,*this);
  return res;
}

template<typename t>
CImg<T> get_inpaint_patch(const CImg<t>& mask, const unsigned int patch_size=11,
                          const unsigned int lookup_size=22, const float lookup_factor=1,
                          const unsigned int lookup_increment=1,
                          const unsigned int blend_size=0, const float blend_threshold=0.5,
                          const float blend_decay=0.02f, const unsigned int blend_scales=10,
                          const bool is_blend_outer=false) const {
  return (+*this).inpaint_patch(mask,patch_size,lookup_size,lookup_factor,lookup_increment,
                                blend_size,blend_threshold,blend_decay,blend_scales,is_blend_outer);
}

// Additional convenience functions.

CImg<T>& mark() {
  unsigned int siz = _width;
  if (siz<2) assign(siz=2,1,1,1,0); else if (_data[siz-2]) resize(++siz,1,1,1,0);
  T &last = _data[siz-1];
  if (last<cimg::type<T>::max()) ++last;
  return *this;
}

CImg<T> get_mark() const {
  return (+*this).mark();
}

CImg<T>& copymark() {
  return get_copymark().move_to(*this);
}

CImg<T> get_copymark() const {
  if (is_empty()) return CImg<T>::string("~");
  CImg<T> res = get_resize(_width+1,1,1,1,0);
  const char *const ext = cimg::split_filename(_data);
  if (*ext) {
    const int l = (int)(ext - _data - 1);
    if (l>0) {
      if (_data[l-1]=='~') return +*this;
      std::memcpy(res._data,_data,l);
    }
    res[l] = '~'; res[l+1] = '.';
    std::memcpy(res._data+l+2,ext,_data+_width-ext);
  } else {
    const unsigned int l = (int)(ext - _data);
    if (_data[l-1]=='~' || (l>1 && _data[l-1]==']' && _data[l-2]=='~')) return +*this;
    std::memcpy(res._data,_data,l);
    res[l] = '~';
    if (ext>_data && *(ext-1)==']') cimg::swap(res[l],res[l-1]);
    std::memcpy(res._data+l+1,ext,_data+_width-ext);
  }
  return res;
}

const CImg<T>& gmic_print(const char *const title, const bool is_debug,
                          const bool is_valid) const {
  CImg<doubleT> st;
  if (is_valid && !is_empty()) st = get_stats();
  const unsigned long siz = size(), msiz = _is_shared?0:siz*sizeof(T), siz1 = siz-1,
    mdisp = msiz<8*1024?0:(msiz<8*1024*1024?1:2),
    wh = _width*_height, whd = _width*_height*_depth,
    w1 = _width-1, wh1 = _width*_height-1, whd1 = _width*_height*_depth-1;

  std::fprintf(cimg::output(),"%s%s%s%s:\n  %ssize%s = (%u,%u,%u,%u) [%lu %s].\n  %sdata%s = %s",
               cimg::t_magenta,cimg::t_bold,title,cimg::t_normal,
               cimg::t_bold,cimg::t_normal,_width,_height,_depth,_spectrum,
               mdisp==0?msiz:(mdisp==1?(msiz>>10):(msiz>>20)),
               mdisp==0?"b":(mdisp==1?"Kio":"Mio"),
               cimg::t_bold,cimg::t_normal,
               is_debug?"":"(");
  if (is_debug) std::fprintf(cimg::output(),"%p = (",_data);

  if (is_valid) {
    if (is_empty()) std::fprintf(cimg::output(),") [%s].\n",
                                 pixel_type());
    else {
      cimg_foroff(*this,off) {
        std::fprintf(cimg::output(),cimg::type<T>::format(),cimg::type<T>::format(_data[off]));
        if (off!=siz1) std::fprintf(cimg::output(),"%s",
                                    off%whd==whd1?"^":
                                    off%wh==wh1?"\\":
                                    off%_width==w1?";":",");
        if (off==11 && siz>24) { off = siz1-12; std::fprintf(cimg::output(),"... "); }
      }
      std::fprintf(cimg::output(),") [%s%s].\n  %smin%s = %g, %smax%s = %g, %smean%s = %g, "
                   "%sstd%s = %g, %scoords_min%s = (%u,%u,%u,%u), "
                   "%scoords_max%s = (%u,%u,%u,%u).\n",
                   _is_shared?"shared ":"",pixel_type(),
                   cimg::t_bold,cimg::t_normal,st[0],
                   cimg::t_bold,cimg::t_normal,st[1],
                   cimg::t_bold,cimg::t_normal,st[2],
                   cimg::t_bold,cimg::t_normal,std::sqrt(st[3]),
                   cimg::t_bold,cimg::t_normal,(int)st[4],(int)st[5],(int)st[6],(int)st[7],
                   cimg::t_bold,cimg::t_normal,(int)st[8],(int)st[9],(int)st[10],(int)st[11]);
    }
  } else std::fprintf(cimg::output(),"%s%sinvalid pointer%s) [shared %s].\n",
                      cimg::t_red,cimg::t_bold,cimg::t_normal,
                      pixel_type());
  std::fflush(cimg::output());
  return *this;
}

//--------------- End of CImg plug-in ----------------------------

#else // #ifdef cimg_plugin
# 1713 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

#if 0 /* expanded by -frewrite-includes */
#include "gmic.h"
#endif /* expanded by -frewrite-includes */
# 1 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.h" 1
/*
 #
 #  File        : gmic.h
 #                ( C++ header file )
 #
 #  Description : GREYC's Magic for Image Computing
 #                ( http://gmic.sourceforge.net )
 #                This file is also a part of the CImg Library project.
 #                ( http://cimg.sourceforge.net )
 #
 #  Note        : Include this file in your C++ source code, if you
 #                want to use the G'MIC interpreter in your own program.
 #
 #  Copyright   : David Tschumperle
 #                ( http://tschumperle.users.greyc.fr/ )
 #
 #  License     : CeCILL v2.0
 #                ( http://www.cecill.info/licences/Licence_CeCILL_V2-en.html )
 #
 #  This software is governed by the CeCILL  license under French law and
 #  abiding by the rules of distribution of free software.  You can  use,
 #  modify and/ or redistribute the software under the terms of the CeCILL
 #  license as circulated by CEA, CNRS and INRIA at the following URL
 #  "http://www.cecill.info".
 #
 #  As a counterpart to the access to the source code and  rights to copy,
 #  modify and redistribute granted by the license, users are provided only
 #  with a limited warranty  and the software's author,  the holder of the
 #  economic rights,  and the successive licensors  have only  limited
 #  liability.
 #
 #  In this respect, the user's attention is drawn to the risks associated
 #  with loading,  using,  modifying and/or developing or reproducing the
 #  software by the user in light of its specific status of free software,
 #  that may mean  that it is complicated to manipulate,  and  that  also
 #  therefore means  that it is reserved for developers  and  experienced
 #  professionals having in-depth computer knowledge. Users are therefore
 #  encouraged to load and test the software's suitability as regards their
 #  requirements in conditions enabling the security of their systems and/or
 #  data to be ensured and,  more generally, to use and operate it in the
 #  same conditions as regards security.
 #
 #  The fact that you are presently reading this means that you have had
 #  knowledge of the CeCILL license and that you accept its terms.
 #
*/
#if 0 /* expanded by -frewrite-includes */
#include <locale>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/locale" 1 3
// -*- C++ -*-
//===-------------------------- locale ------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_LOCALE
#define _LIBCPP_LOCALE

/*
    locale synopsis

namespace std
{

class locale
{
public:
    // types:
    class facet;
    class id;

    typedef int category;
    static const category // values assigned here are for exposition only
        none     = 0x000,
        collate  = 0x010,
        ctype    = 0x020,
        monetary = 0x040,
        numeric  = 0x080,
        time     = 0x100,
        messages = 0x200,
        all = collate | ctype | monetary | numeric | time | messages;

    // construct/copy/destroy:
    locale() noexcept;
    locale(const locale& other) noexcept;
    explicit locale(const char* std_name);
    explicit locale(const string& std_name);
    locale(const locale& other, const char* std_name, category);
    locale(const locale& other, const string& std_name, category);
    template <class Facet> locale(const locale& other, Facet* f);
    locale(const locale& other, const locale& one, category);

    ~locale(); // not virtual

    const locale& operator=(const locale& other) noexcept;

    template <class Facet> locale combine(const locale& other) const;

    // locale operations:
    basic_string<char> name() const;
    bool operator==(const locale& other) const;
    bool operator!=(const locale& other) const;
    template <class charT, class Traits, class Allocator>
      bool operator()(const basic_string<charT,Traits,Allocator>& s1,
                      const basic_string<charT,Traits,Allocator>& s2) const;

    // global locale objects:
    static locale global(const locale&);
    static const locale& classic();
};

template <class Facet> const Facet& use_facet(const locale&);
template <class Facet> bool has_facet(const locale&) noexcept;

// 22.3.3, convenience interfaces:
template <class charT> bool isspace (charT c, const locale& loc);
template <class charT> bool isprint (charT c, const locale& loc);
template <class charT> bool iscntrl (charT c, const locale& loc);
template <class charT> bool isupper (charT c, const locale& loc);
template <class charT> bool islower (charT c, const locale& loc);
template <class charT> bool isalpha (charT c, const locale& loc);
template <class charT> bool isdigit (charT c, const locale& loc);
template <class charT> bool ispunct (charT c, const locale& loc);
template <class charT> bool isxdigit(charT c, const locale& loc);
template <class charT> bool isalnum (charT c, const locale& loc);
template <class charT> bool isgraph (charT c, const locale& loc);
template <class charT> charT toupper(charT c, const locale& loc);
template <class charT> charT tolower(charT c, const locale& loc);

template<class Codecvt, class Elem = wchar_t,
         class Wide_alloc = allocator<Elem>,
         class Byte_alloc = allocator<char>>
class wstring_convert
{
public:
    typedef basic_string<char, char_traits<char>, Byte_alloc> byte_string;
    typedef basic_string<Elem, char_traits<Elem>, Wide_alloc> wide_string;
    typedef typename Codecvt::state_type                      state_type;
    typedef typename wide_string::traits_type::int_type       int_type;

    explicit wstring_convert(Codecvt* pcvt = new Codecvt);          // explicit in C++14
    wstring_convert(Codecvt* pcvt, state_type state);
    explicit wstring_convert(const byte_string& byte_err,           // explicit in C++14
                    const wide_string& wide_err = wide_string());
    wstring_convert(const wstring_convert&) = delete;               // C++14
    wstring_convert & operator=(const wstring_convert &) = delete;  // C++14
    ~wstring_convert();

    wide_string from_bytes(char byte);
    wide_string from_bytes(const char* ptr);
    wide_string from_bytes(const byte_string& str);
    wide_string from_bytes(const char* first, const char* last);

    byte_string to_bytes(Elem wchar);
    byte_string to_bytes(const Elem* wptr);
    byte_string to_bytes(const wide_string& wstr);
    byte_string to_bytes(const Elem* first, const Elem* last);

    size_t converted() const; // noexcept in C++14
    state_type state() const;
};

template <class Codecvt, class Elem = wchar_t, class Tr = char_traits<Elem>>
class wbuffer_convert
    : public basic_streambuf<Elem, Tr>
{
public:
    typedef typename Tr::state_type state_type;

    explicit wbuffer_convert(streambuf* bytebuf = 0, Codecvt* pcvt = new Codecvt,
                    state_type state = state_type());       // explicit in C++14
    wbuffer_convert(const wbuffer_convert&) = delete;               // C++14
    wbuffer_convert & operator=(const wbuffer_convert &) = delete;  // C++14
    ~wbuffer_convert();                                             // C++14
    
    streambuf* rdbuf() const;
    streambuf* rdbuf(streambuf* bytebuf);

    state_type state() const;
};

// 22.4.1 and 22.4.1.3, ctype:
class ctype_base;
template <class charT> class ctype;
template <> class ctype<char>; // specialization
template <class charT> class ctype_byname;
template <> class ctype_byname<char>; // specialization

class codecvt_base;
template <class internT, class externT, class stateT> class codecvt;
template <class internT, class externT, class stateT> class codecvt_byname;

// 22.4.2 and 22.4.3, numeric:
template <class charT, class InputIterator> class num_get;
template <class charT, class OutputIterator> class num_put;
template <class charT> class numpunct;
template <class charT> class numpunct_byname;

// 22.4.4, col lation:
template <class charT> class collate;
template <class charT> class collate_byname;

// 22.4.5, date and time:
class time_base;
template <class charT, class InputIterator> class time_get;
template <class charT, class InputIterator> class time_get_byname;
template <class charT, class OutputIterator> class time_put;
template <class charT, class OutputIterator> class time_put_byname;

// 22.4.6, money:
class money_base;
template <class charT, class InputIterator> class money_get;
template <class charT, class OutputIterator> class money_put;
template <class charT, bool Intl> class moneypunct;
template <class charT, bool Intl> class moneypunct_byname;

// 22.4.7, message retrieval:
class messages_base;
template <class charT> class messages;
template <class charT> class messages_byname;

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/__config" 1 3
// -*- C++ -*-
//===--------------------------- __config ---------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CONFIG
#define _LIBCPP_CONFIG

#if !defined(_MSC_VER) || defined(__clang__)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 16 "/usr/include/c++/v1/__config" 3
#endif
# 17 "/usr/include/c++/v1/__config" 3

#ifdef __GNUC__
#define _GNUC_VER (__GNUC__ * 100 + __GNUC_MINOR__)
#endif
# 21 "/usr/include/c++/v1/__config" 3

#define _LIBCPP_VERSION 1101

#define _LIBCPP_ABI_VERSION 1

#define _LIBCPP_CONCAT1(_LIBCPP_X,_LIBCPP_Y) _LIBCPP_X##_LIBCPP_Y
#define _LIBCPP_CONCAT(_LIBCPP_X,_LIBCPP_Y) _LIBCPP_CONCAT1(_LIBCPP_X,_LIBCPP_Y)

#define _LIBCPP_NAMESPACE _LIBCPP_CONCAT(__,_LIBCPP_ABI_VERSION)

#ifdef __LITTLE_ENDIAN__
#if __LITTLE_ENDIAN__
#define _LIBCPP_LITTLE_ENDIAN 1
#define _LIBCPP_BIG_ENDIAN    0
#endif  // __LITTLE_ENDIAN__
# 36 "/usr/include/c++/v1/__config" 3
#endif  // __LITTLE_ENDIAN__
# 37 "/usr/include/c++/v1/__config" 3

#ifdef __BIG_ENDIAN__
#if __BIG_ENDIAN__
#define _LIBCPP_LITTLE_ENDIAN 0
#define _LIBCPP_BIG_ENDIAN    1
#endif  // __BIG_ENDIAN__
# 43 "/usr/include/c++/v1/__config" 3
#endif  // __BIG_ENDIAN__
# 44 "/usr/include/c++/v1/__config" 3

#ifdef __FreeBSD__
#if 0 /* expanded by -frewrite-includes */
# include <sys/endian.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/sys/endian.h" 1 3 4
/*-
 * Copyright (c) 2002 Thomas Moestl <tmm@FreeBSD.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/sys/sys/endian.h 208331 2010-05-20 06:16:13Z phk $
 */

#ifndef _SYS_ENDIAN_H_
#define _SYS_ENDIAN_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/sys/cdefs.h" 1 3 4
/*-
 * Copyright (c) 1991, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * This code is derived from software contributed to Berkeley by
 * Berkeley Software Design, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)cdefs.h	8.8 (Berkeley) 1/9/95
 * $FreeBSD: head/sys/sys/cdefs.h 271155 2014-09-05 05:36:32Z ed $
 */

#ifndef	_SYS_CDEFS_H_
#define	_SYS_CDEFS_H_

/*
 * Testing against Clang-specific extensions.
 */

#ifndef	__has_extension
#define	__has_extension		__has_feature
#endif
# 46 "/usr/include/sys/cdefs.h" 3 4
#ifndef	__has_feature
#define	__has_feature(x)	0
#endif
# 49 "/usr/include/sys/cdefs.h" 3 4
#ifndef	__has_include
#define	__has_include(x)	0
#endif
# 52 "/usr/include/sys/cdefs.h" 3 4
#ifndef	__has_builtin
#define	__has_builtin(x)	0
#endif
# 55 "/usr/include/sys/cdefs.h" 3 4

#if defined(__cplusplus)
#define	__BEGIN_DECLS	extern "C" {
#define	__END_DECLS	}
#else
# 60 "/usr/include/sys/cdefs.h" 3 4
#define	__BEGIN_DECLS
#define	__END_DECLS
#endif
# 63 "/usr/include/sys/cdefs.h" 3 4

/*
 * This code has been put in place to help reduce the addition of
 * compiler specific defines in FreeBSD code.  It helps to aid in
 * having a compiler-agnostic source tree.
 */

#if defined(__GNUC__) || defined(__INTEL_COMPILER)

#if __GNUC__ >= 3 || defined(__INTEL_COMPILER)
#define __GNUCLIKE_ASM 3
#define __GNUCLIKE_MATH_BUILTIN_CONSTANTS
#else
# 76 "/usr/include/sys/cdefs.h" 3 4
#define __GNUCLIKE_ASM 2
#endif
# 78 "/usr/include/sys/cdefs.h" 3 4
#define __GNUCLIKE___TYPEOF 1
#define __GNUCLIKE___OFFSETOF 1
#define __GNUCLIKE___SECTION 1

#ifndef __INTEL_COMPILER
# define __GNUCLIKE_CTOR_SECTION_HANDLING 1
#endif
# 85 "/usr/include/sys/cdefs.h" 3 4

#define __GNUCLIKE_BUILTIN_CONSTANT_P 1
# if defined(__INTEL_COMPILER) && defined(__cplusplus) \
    && __INTEL_COMPILER < 800
#  undef __GNUCLIKE_BUILTIN_CONSTANT_P
# endif
# 91 "/usr/include/sys/cdefs.h" 3 4

#if (__GNUC_MINOR__ > 95 || __GNUC__ >= 3) && !defined(__INTEL_COMPILER)
# define __GNUCLIKE_BUILTIN_VARARGS 1
# define __GNUCLIKE_BUILTIN_STDARG 1
# define __GNUCLIKE_BUILTIN_VAALIST 1
#endif
# 97 "/usr/include/sys/cdefs.h" 3 4

#if defined(__GNUC__)
# define __GNUC_VA_LIST_COMPATIBILITY 1
#endif
# 101 "/usr/include/sys/cdefs.h" 3 4

/*
 * Compiler memory barriers, specific to gcc and clang.
 */
#if defined(__GNUC__)
#define	__compiler_membar()	__asm __volatile(" " : : : "memory")
#endif
# 108 "/usr/include/sys/cdefs.h" 3 4

#ifndef __INTEL_COMPILER
# define __GNUCLIKE_BUILTIN_NEXT_ARG 1
# define __GNUCLIKE_MATH_BUILTIN_RELOPS
#endif
# 113 "/usr/include/sys/cdefs.h" 3 4

#define __GNUCLIKE_BUILTIN_MEMCPY 1

/* XXX: if __GNUC__ >= 2: not tested everywhere originally, where replaced */
#define __CC_SUPPORTS_INLINE 1
#define __CC_SUPPORTS___INLINE 1
#define __CC_SUPPORTS___INLINE__ 1

#define __CC_SUPPORTS___FUNC__ 1
#define __CC_SUPPORTS_WARNING 1

#define __CC_SUPPORTS_VARADIC_XXX 1 /* see varargs.h */

#define __CC_SUPPORTS_DYNAMIC_ARRAY_INIT 1

#endif /* __GNUC__ || __INTEL_COMPILER */
# 129 "/usr/include/sys/cdefs.h" 3 4

/*
 * Macro to test if we're using a specific version of gcc or later.
 */
#if defined(__GNUC__) && !defined(__INTEL_COMPILER)
#define	__GNUC_PREREQ__(ma, mi)	\
	(__GNUC__ > (ma) || __GNUC__ == (ma) && __GNUC_MINOR__ >= (mi))
#else
# 137 "/usr/include/sys/cdefs.h" 3 4
#define	__GNUC_PREREQ__(ma, mi)	0
#endif
# 139 "/usr/include/sys/cdefs.h" 3 4

/*
 * The __CONCAT macro is used to concatenate parts of symbol names, e.g.
 * with "#define OLD(foo) __CONCAT(old,foo)", OLD(foo) produces oldfoo.
 * The __CONCAT macro is a bit tricky to use if it must work in non-ANSI
 * mode -- there must be no spaces between its arguments, and for nested
 * __CONCAT's, all the __CONCAT's must be at the left.  __CONCAT can also
 * concatenate double-quoted strings produced by the __STRING macro, but
 * this only works with ANSI C.
 *
 * __XSTRING is like __STRING, but it expands any macros in its argument
 * first.  It is only available with ANSI C.
 */
#if defined(__STDC__) || defined(__cplusplus)
#define	__P(protos)	protos		/* full-blown ANSI C */
#define	__CONCAT1(x,y)	x ## y
#define	__CONCAT(x,y)	__CONCAT1(x,y)
#define	__STRING(x)	#x		/* stringify without expanding x */
#define	__XSTRING(x)	__STRING(x)	/* expand x, then stringify */

#define	__const		const		/* define reserved names to standard */
#define	__signed	signed
#define	__volatile	volatile
#if defined(__cplusplus)
#define	__inline	inline		/* convert to C++ keyword */
#else
# 165 "/usr/include/sys/cdefs.h" 3 4
#if !(defined(__CC_SUPPORTS___INLINE))
#define	__inline			/* delete GCC keyword */
#endif /* ! __CC_SUPPORTS___INLINE */
# 168 "/usr/include/sys/cdefs.h" 3 4
#endif /* !__cplusplus */
# 169 "/usr/include/sys/cdefs.h" 3 4

#else	/* !(__STDC__ || __cplusplus) */
# 171 "/usr/include/sys/cdefs.h" 3 4
#define	__P(protos)	()		/* traditional C preprocessor */
#define	__CONCAT(x,y)	x/**/y
#define	__STRING(x)	"x"

#if !defined(__CC_SUPPORTS___INLINE)
#define	__const				/* delete pseudo-ANSI C keywords */
#define	__inline
#define	__signed
#define	__volatile
/*
 * In non-ANSI C environments, new programs will want ANSI-only C keywords
 * deleted from the program and old programs will want them left alone.
 * When using a compiler other than gcc, programs using the ANSI C keywords
 * const, inline etc. as normal identifiers should define -DNO_ANSI_KEYWORDS.
 * When using "gcc -traditional", we assume that this is the intent; if
 * __GNUC__ is defined but __STDC__ is not, we leave the new keywords alone.
 */
#ifndef	NO_ANSI_KEYWORDS
#define	const				/* delete ANSI C keywords */
#define	inline
#define	signed
#define	volatile
#endif	/* !NO_ANSI_KEYWORDS */
# 194 "/usr/include/sys/cdefs.h" 3 4
#endif	/* !__CC_SUPPORTS___INLINE */
# 195 "/usr/include/sys/cdefs.h" 3 4
#endif	/* !(__STDC__ || __cplusplus) */
# 196 "/usr/include/sys/cdefs.h" 3 4

/*
 * Compiler-dependent macros to help declare dead (non-returning) and
 * pure (no side effects) functions, and unused variables.  They are
 * null except for versions of gcc that are known to support the features
 * properly (old versions of gcc-2 supported the dead and pure features
 * in a different (wrong) way).  If we do not provide an implementation
 * for a given compiler, let the compile fail if it is told to use
 * a feature that we cannot live without.
 */
#ifdef lint
#define	__dead2
#define	__pure2
#define	__unused
#define	__packed
#define	__aligned(x)
#define	__section(x)
#define	__weak
#else
# 215 "/usr/include/sys/cdefs.h" 3 4
#define	__weak		__attribute__((__weak__))
#if !__GNUC_PREREQ__(2, 5) && !defined(__INTEL_COMPILER)
#define	__dead2
#define	__pure2
#define	__unused
#endif
# 221 "/usr/include/sys/cdefs.h" 3 4
#if __GNUC__ == 2 && __GNUC_MINOR__ >= 5 && __GNUC_MINOR__ < 7 && !defined(__INTEL_COMPILER)
#define	__dead2		__attribute__((__noreturn__))
#define	__pure2		__attribute__((__const__))
#define	__unused
/* XXX Find out what to do for __packed, __aligned and __section */
#endif
# 227 "/usr/include/sys/cdefs.h" 3 4
#if __GNUC_PREREQ__(2, 7)
#define	__dead2		__attribute__((__noreturn__))
#define	__pure2		__attribute__((__const__))
#define	__unused	__attribute__((__unused__))
#define	__used		__attribute__((__used__))
#define	__packed	__attribute__((__packed__))
#define	__aligned(x)	__attribute__((__aligned__(x)))
#define	__section(x)	__attribute__((__section__(x)))
#endif
# 236 "/usr/include/sys/cdefs.h" 3 4
#if defined(__INTEL_COMPILER)
#define __dead2		__attribute__((__noreturn__))
#define __pure2		__attribute__((__const__))
#define __unused	__attribute__((__unused__))
#define __used		__attribute__((__used__))
#define __packed	__attribute__((__packed__))
#define __aligned(x)	__attribute__((__aligned__(x)))
#define __section(x)	__attribute__((__section__(x)))
#endif
# 245 "/usr/include/sys/cdefs.h" 3 4
#endif
# 246 "/usr/include/sys/cdefs.h" 3 4

#if !__GNUC_PREREQ__(2, 95)
#define	__alignof(x)	__offsetof(struct { char __a; x __b; }, __b)
#endif
# 250 "/usr/include/sys/cdefs.h" 3 4

/*
 * Keywords added in C11.
 */

#if !defined(__STDC_VERSION__) || __STDC_VERSION__ < 201112L

#if !__has_extension(c_alignas)
#if (defined(__cplusplus) && __cplusplus >= 201103L) || \
    __has_extension(cxx_alignas)
#define	_Alignas(x)		alignas(x)
#else
# 262 "/usr/include/sys/cdefs.h" 3 4
/* XXX: Only emulates _Alignas(constant-expression); not _Alignas(type-name). */
#define	_Alignas(x)		__aligned(x)
#endif
# 265 "/usr/include/sys/cdefs.h" 3 4
#endif
# 266 "/usr/include/sys/cdefs.h" 3 4

#if defined(__cplusplus) && __cplusplus >= 201103L
#define	_Alignof(x)		alignof(x)
#else
# 270 "/usr/include/sys/cdefs.h" 3 4
#define	_Alignof(x)		__alignof(x)
#endif
# 272 "/usr/include/sys/cdefs.h" 3 4

#if !__has_extension(c_atomic) && !__has_extension(cxx_atomic)
/*
 * No native support for _Atomic(). Place object in structure to prevent
 * most forms of direct non-atomic access.
 */
#define	_Atomic(T)		struct { T volatile __val; }
#endif
# 280 "/usr/include/sys/cdefs.h" 3 4

#if defined(__cplusplus) && __cplusplus >= 201103L
#define	_Noreturn		[[noreturn]]
#else
# 284 "/usr/include/sys/cdefs.h" 3 4
#define	_Noreturn		__dead2
#endif
# 286 "/usr/include/sys/cdefs.h" 3 4

#if !__has_extension(c_static_assert)
#if (defined(__cplusplus) && __cplusplus >= 201103L) || \
    __has_extension(cxx_static_assert)
#define	_Static_assert(x, y)	static_assert(x, y)
#elif defined(__COUNTER__)
# 292 "/usr/include/sys/cdefs.h" 3 4
#define	_Static_assert(x, y)	__Static_assert(x, __COUNTER__)
#define	__Static_assert(x, y)	___Static_assert(x, y)
#define	___Static_assert(x, y)	typedef char __assert_ ## y[(x) ? 1 : -1]
#else
# 296 "/usr/include/sys/cdefs.h" 3 4
#define	_Static_assert(x, y)	struct __hack
#endif
# 298 "/usr/include/sys/cdefs.h" 3 4
#endif
# 299 "/usr/include/sys/cdefs.h" 3 4

#if !__has_extension(c_thread_local)
/*
 * XXX: Some compilers (Clang 3.3, GCC 4.7) falsely announce C++11 mode
 * without actually supporting the thread_local keyword. Don't check for
 * the presence of C++11 when defining _Thread_local.
 */
#if /* (defined(__cplusplus) && __cplusplus >= 201103L) || */ \
    __has_extension(cxx_thread_local)
#define	_Thread_local		thread_local
#else
# 310 "/usr/include/sys/cdefs.h" 3 4
#define	_Thread_local		__thread
#endif
# 312 "/usr/include/sys/cdefs.h" 3 4
#endif
# 313 "/usr/include/sys/cdefs.h" 3 4

#endif /* __STDC_VERSION__ || __STDC_VERSION__ < 201112L */
# 315 "/usr/include/sys/cdefs.h" 3 4

/*
 * Emulation of C11 _Generic().  Unlike the previously defined C11
 * keywords, it is not possible to implement this using exactly the same
 * syntax.  Therefore implement something similar under the name
 * __generic().  Unlike _Generic(), this macro can only distinguish
 * between a single type, so it requires nested invocations to
 * distinguish multiple cases.
 */

#if (defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) || \
    __has_extension(c_generic_selections)
#define	__generic(expr, t, yes, no)					\
	_Generic(expr, t: yes, default: no)
#elif __GNUC_PREREQ__(3, 1) && !defined(__cplusplus)
# 330 "/usr/include/sys/cdefs.h" 3 4
#define	__generic(expr, t, yes, no)					\
	__builtin_choose_expr(						\
	    __builtin_types_compatible_p(__typeof(expr), t), yes, no)
#endif
# 334 "/usr/include/sys/cdefs.h" 3 4

#if __GNUC_PREREQ__(2, 96)
#define	__malloc_like	__attribute__((__malloc__))
#define	__pure		__attribute__((__pure__))
#else
# 339 "/usr/include/sys/cdefs.h" 3 4
#define	__malloc_like
#define	__pure
#endif
# 342 "/usr/include/sys/cdefs.h" 3 4

#if __GNUC_PREREQ__(3, 1) || (defined(__INTEL_COMPILER) && __INTEL_COMPILER >= 800)
#define	__always_inline	__attribute__((__always_inline__))
#else
# 346 "/usr/include/sys/cdefs.h" 3 4
#define	__always_inline
#endif
# 348 "/usr/include/sys/cdefs.h" 3 4

#if __GNUC_PREREQ__(3, 1)
#define	__noinline	__attribute__ ((__noinline__))
#else
# 352 "/usr/include/sys/cdefs.h" 3 4
#define	__noinline
#endif
# 354 "/usr/include/sys/cdefs.h" 3 4

#if __GNUC_PREREQ__(3, 3)
#define __nonnull(x)	__attribute__((__nonnull__(x)))
#else
# 358 "/usr/include/sys/cdefs.h" 3 4
#define __nonnull(x)
#endif
# 360 "/usr/include/sys/cdefs.h" 3 4

#if __GNUC_PREREQ__(3, 4)
#define	__fastcall	__attribute__((__fastcall__))
#else
# 364 "/usr/include/sys/cdefs.h" 3 4
#define	__fastcall
#endif
# 366 "/usr/include/sys/cdefs.h" 3 4

#if __GNUC_PREREQ__(4, 1)
#define	__returns_twice	__attribute__((__returns_twice__))
#else
# 370 "/usr/include/sys/cdefs.h" 3 4
#define	__returns_twice
#endif
# 372 "/usr/include/sys/cdefs.h" 3 4

/* XXX: should use `#if __STDC_VERSION__ < 199901'. */
#if !__GNUC_PREREQ__(2, 7) && !defined(__INTEL_COMPILER)
#define	__func__	NULL
#endif
# 377 "/usr/include/sys/cdefs.h" 3 4

#if (defined(__INTEL_COMPILER) || (defined(__GNUC__) && __GNUC__ >= 2)) && !defined(__STRICT_ANSI__) || __STDC_VERSION__ >= 199901
#define	__LONG_LONG_SUPPORTED
#endif
# 381 "/usr/include/sys/cdefs.h" 3 4

/* C++11 exposes a load of C99 stuff */
#if defined(__cplusplus) && __cplusplus >= 201103L
#define	__LONG_LONG_SUPPORTED
#ifndef	__STDC_LIMIT_MACROS
#define	__STDC_LIMIT_MACROS
#endif
# 388 "/usr/include/sys/cdefs.h" 3 4
#ifndef	__STDC_CONSTANT_MACROS
#define	__STDC_CONSTANT_MACROS
#endif
# 391 "/usr/include/sys/cdefs.h" 3 4
#endif
# 392 "/usr/include/sys/cdefs.h" 3 4

/*
 * GCC 2.95 provides `__restrict' as an extension to C90 to support the
 * C99-specific `restrict' type qualifier.  We happen to use `__restrict' as
 * a way to define the `restrict' type qualifier without disturbing older
 * software that is unaware of C99 keywords.
 */
#if !(__GNUC__ == 2 && __GNUC_MINOR__ == 95)
#if !defined(__STDC_VERSION__) || __STDC_VERSION__ < 199901 || defined(lint)
#define	__restrict
#else
# 403 "/usr/include/sys/cdefs.h" 3 4
#define	__restrict	restrict
#endif
# 405 "/usr/include/sys/cdefs.h" 3 4
#endif
# 406 "/usr/include/sys/cdefs.h" 3 4

/*
 * GNU C version 2.96 adds explicit branch prediction so that
 * the CPU back-end can hint the processor and also so that
 * code blocks can be reordered such that the predicted path
 * sees a more linear flow, thus improving cache behavior, etc.
 *
 * The following two macros provide us with a way to utilize this
 * compiler feature.  Use __predict_true() if you expect the expression
 * to evaluate to true, and __predict_false() if you expect the
 * expression to evaluate to false.
 *
 * A few notes about usage:
 *
 *	* Generally, __predict_false() error condition checks (unless
 *	  you have some _strong_ reason to do otherwise, in which case
 *	  document it), and/or __predict_true() `no-error' condition
 *	  checks, assuming you want to optimize for the no-error case.
 *
 *	* Other than that, if you don't know the likelihood of a test
 *	  succeeding from empirical or other `hard' evidence, don't
 *	  make predictions.
 *
 *	* These are meant to be used in places that are run `a lot'.
 *	  It is wasteful to make predictions in code that is run
 *	  seldomly (e.g. at subsystem initialization time) as the
 *	  basic block reordering that this affects can often generate
 *	  larger code.
 */
#if __GNUC_PREREQ__(2, 96)
#define __predict_true(exp)     __builtin_expect((exp), 1)
#define __predict_false(exp)    __builtin_expect((exp), 0)
#else
# 439 "/usr/include/sys/cdefs.h" 3 4
#define __predict_true(exp)     (exp)
#define __predict_false(exp)    (exp)
#endif
# 442 "/usr/include/sys/cdefs.h" 3 4

#if __GNUC_PREREQ__(4, 2)
#define	__hidden	__attribute__((__visibility__("hidden")))
#define	__exported	__attribute__((__visibility__("default")))
#else
# 447 "/usr/include/sys/cdefs.h" 3 4
#define	__hidden
#define	__exported
#endif
# 450 "/usr/include/sys/cdefs.h" 3 4

/*
 * We define this here since <stddef.h>, <sys/queue.h>, and <sys/types.h>
 * require it.
 */
#if __GNUC_PREREQ__(4, 1)
#define __offsetof(type, field)	 __builtin_offsetof(type, field)
#else
# 458 "/usr/include/sys/cdefs.h" 3 4
#ifndef __cplusplus
#define	__offsetof(type, field) \
	((__size_t)(__uintptr_t)((const volatile void *)&((type *)0)->field))
#else
# 462 "/usr/include/sys/cdefs.h" 3 4
#define __offsetof(type, field)					\
  (__offsetof__ (reinterpret_cast <__size_t>			\
                 (&reinterpret_cast <const volatile char &>	\
                  (static_cast<type *> (0)->field))))
#endif
# 467 "/usr/include/sys/cdefs.h" 3 4
#endif
# 468 "/usr/include/sys/cdefs.h" 3 4
#define	__rangeof(type, start, end) \
	(__offsetof(type, end) - __offsetof(type, start))

/*
 * Given the pointer x to the member m of the struct s, return
 * a pointer to the containing structure.  When using GCC, we first
 * assign pointer x to a local variable, to check that its type is
 * compatible with member m.
 */
#if __GNUC_PREREQ__(3, 1)
#define	__containerof(x, s, m) ({					\
	const volatile __typeof(((s *)0)->m) *__x = (x);		\
	__DEQUALIFY(s *, (const volatile char *)__x - __offsetof(s, m));\
})
#else
# 483 "/usr/include/sys/cdefs.h" 3 4
#define	__containerof(x, s, m)						\
	__DEQUALIFY(s *, (const volatile char *)(x) - __offsetof(s, m))
#endif
# 486 "/usr/include/sys/cdefs.h" 3 4

/*
 * Compiler-dependent macros to declare that functions take printf-like
 * or scanf-like arguments.  They are null except for versions of gcc
 * that are known to support the features properly (old versions of gcc-2
 * didn't permit keeping the keywords out of the application namespace).
 */
#if !__GNUC_PREREQ__(2, 7) && !defined(__INTEL_COMPILER)
#define	__printflike(fmtarg, firstvararg)
#define	__scanflike(fmtarg, firstvararg)
#define	__format_arg(fmtarg)
#define	__strfmonlike(fmtarg, firstvararg)
#define	__strftimelike(fmtarg, firstvararg)
#else
# 500 "/usr/include/sys/cdefs.h" 3 4
#define	__printflike(fmtarg, firstvararg) \
	    __attribute__((__format__ (__printf__, fmtarg, firstvararg)))
#define	__scanflike(fmtarg, firstvararg) \
	    __attribute__((__format__ (__scanf__, fmtarg, firstvararg)))
#define	__format_arg(fmtarg)	__attribute__((__format_arg__ (fmtarg)))
#define	__strfmonlike(fmtarg, firstvararg) \
	    __attribute__((__format__ (__strfmon__, fmtarg, firstvararg)))
#define	__strftimelike(fmtarg, firstvararg) \
	    __attribute__((__format__ (__strftime__, fmtarg, firstvararg)))
#endif
# 510 "/usr/include/sys/cdefs.h" 3 4

/* Compiler-dependent macros that rely on FreeBSD-specific extensions. */
#if defined(__FreeBSD_cc_version) && __FreeBSD_cc_version >= 300001 && \
    defined(__GNUC__) && !defined(__INTEL_COMPILER)
#define	__printf0like(fmtarg, firstvararg) \
	    __attribute__((__format__ (__printf0__, fmtarg, firstvararg)))
#else
# 517 "/usr/include/sys/cdefs.h" 3 4
#define	__printf0like(fmtarg, firstvararg)
#endif
# 519 "/usr/include/sys/cdefs.h" 3 4

#if defined(__GNUC__) || defined(__INTEL_COMPILER)
#ifndef __INTEL_COMPILER
#define	__strong_reference(sym,aliassym)	\
	extern __typeof (sym) aliassym __attribute__ ((__alias__ (#sym)))
#endif
# 525 "/usr/include/sys/cdefs.h" 3 4
#ifdef __STDC__
#define	__weak_reference(sym,alias)	\
	__asm__(".weak " #alias);	\
	__asm__(".equ "  #alias ", " #sym)
#define	__warn_references(sym,msg)	\
	__asm__(".section .gnu.warning." #sym);	\
	__asm__(".asciz \"" msg "\"");	\
	__asm__(".previous")
#define	__sym_compat(sym,impl,verid)	\
	__asm__(".symver " #impl ", " #sym "@" #verid)
#define	__sym_default(sym,impl,verid)	\
	__asm__(".symver " #impl ", " #sym "@@" #verid)
#else
# 538 "/usr/include/sys/cdefs.h" 3 4
#define	__weak_reference(sym,alias)	\
	__asm__(".weak alias");		\
	__asm__(".equ alias, sym")
#define	__warn_references(sym,msg)	\
	__asm__(".section .gnu.warning.sym"); \
	__asm__(".asciz \"msg\"");	\
	__asm__(".previous")
#define	__sym_compat(sym,impl,verid)	\
	__asm__(".symver impl, sym@verid")
#define	__sym_default(impl,sym,verid)	\
	__asm__(".symver impl, sym@@verid")
#endif	/* __STDC__ */
# 550 "/usr/include/sys/cdefs.h" 3 4
#endif	/* __GNUC__ || __INTEL_COMPILER */
# 551 "/usr/include/sys/cdefs.h" 3 4

#define	__GLOBL1(sym)	__asm__(".globl " #sym)
#define	__GLOBL(sym)	__GLOBL1(sym)

#if defined(__GNUC__) || defined(__INTEL_COMPILER)
#define	__IDSTRING(name,string)	__asm__(".ident\t\"" string "\"")
#else
# 558 "/usr/include/sys/cdefs.h" 3 4
/*
 * The following definition might not work well if used in header files,
 * but it should be better than nothing.  If you want a "do nothing"
 * version, then it should generate some harmless declaration, such as:
 *    #define __IDSTRING(name,string)	struct __hack
 */
#define	__IDSTRING(name,string)	static const char name[] __unused = string
#endif
# 566 "/usr/include/sys/cdefs.h" 3 4

/*
 * Embed the rcs id of a source file in the resulting library.  Note that in
 * more recent ELF binutils, we use .ident allowing the ID to be stripped.
 * Usage:
 *	__FBSDID("$FreeBSD: head/sys/sys/cdefs.h 271155 2014-09-05 05:36:32Z ed $");
 */
#ifndef	__FBSDID
#if !defined(lint) && !defined(STRIP_FBSDID)
#define	__FBSDID(s)	__IDSTRING(__CONCAT(__rcsid_,__LINE__),s)
#else
# 577 "/usr/include/sys/cdefs.h" 3 4
#define	__FBSDID(s)	struct __hack
#endif
# 579 "/usr/include/sys/cdefs.h" 3 4
#endif
# 580 "/usr/include/sys/cdefs.h" 3 4

#ifndef	__RCSID
#ifndef	NO__RCSID
#define	__RCSID(s)	__IDSTRING(__CONCAT(__rcsid_,__LINE__),s)
#else
# 585 "/usr/include/sys/cdefs.h" 3 4
#define	__RCSID(s)	struct __hack
#endif
# 587 "/usr/include/sys/cdefs.h" 3 4
#endif
# 588 "/usr/include/sys/cdefs.h" 3 4

#ifndef	__RCSID_SOURCE
#ifndef	NO__RCSID_SOURCE
#define	__RCSID_SOURCE(s)	__IDSTRING(__CONCAT(__rcsid_source_,__LINE__),s)
#else
# 593 "/usr/include/sys/cdefs.h" 3 4
#define	__RCSID_SOURCE(s)	struct __hack
#endif
# 595 "/usr/include/sys/cdefs.h" 3 4
#endif
# 596 "/usr/include/sys/cdefs.h" 3 4

#ifndef	__SCCSID
#ifndef	NO__SCCSID
#define	__SCCSID(s)	__IDSTRING(__CONCAT(__sccsid_,__LINE__),s)
#else
# 601 "/usr/include/sys/cdefs.h" 3 4
#define	__SCCSID(s)	struct __hack
#endif
# 603 "/usr/include/sys/cdefs.h" 3 4
#endif
# 604 "/usr/include/sys/cdefs.h" 3 4

#ifndef	__COPYRIGHT
#ifndef	NO__COPYRIGHT
#define	__COPYRIGHT(s)	__IDSTRING(__CONCAT(__copyright_,__LINE__),s)
#else
# 609 "/usr/include/sys/cdefs.h" 3 4
#define	__COPYRIGHT(s)	struct __hack
#endif
# 611 "/usr/include/sys/cdefs.h" 3 4
#endif
# 612 "/usr/include/sys/cdefs.h" 3 4

#ifndef	__DECONST
#define	__DECONST(type, var)	((type)(__uintptr_t)(const void *)(var))
#endif
# 616 "/usr/include/sys/cdefs.h" 3 4

#ifndef	__DEVOLATILE
#define	__DEVOLATILE(type, var)	((type)(__uintptr_t)(volatile void *)(var))
#endif
# 620 "/usr/include/sys/cdefs.h" 3 4

#ifndef	__DEQUALIFY
#define	__DEQUALIFY(type, var)	((type)(__uintptr_t)(const volatile void *)(var))
#endif
# 624 "/usr/include/sys/cdefs.h" 3 4

/*-
 * The following definitions are an extension of the behavior originally
 * implemented in <sys/_posix.h>, but with a different level of granularity.
 * POSIX.1 requires that the macros we test be defined before any standard
 * header file is included.
 *
 * Here's a quick run-down of the versions:
 *  defined(_POSIX_SOURCE)		1003.1-1988
 *  _POSIX_C_SOURCE == 1		1003.1-1990
 *  _POSIX_C_SOURCE == 2		1003.2-1992 C Language Binding Option
 *  _POSIX_C_SOURCE == 199309		1003.1b-1993
 *  _POSIX_C_SOURCE == 199506		1003.1c-1995, 1003.1i-1995,
 *					and the omnibus ISO/IEC 9945-1: 1996
 *  _POSIX_C_SOURCE == 200112		1003.1-2001
 *  _POSIX_C_SOURCE == 200809		1003.1-2008
 *
 * In addition, the X/Open Portability Guide, which is now the Single UNIX
 * Specification, defines a feature-test macro which indicates the version of
 * that specification, and which subsumes _POSIX_C_SOURCE.
 *
 * Our macros begin with two underscores to avoid namespace screwage.
 */

/* Deal with IEEE Std. 1003.1-1990, in which _POSIX_C_SOURCE == 1. */
#if defined(_POSIX_C_SOURCE) && _POSIX_C_SOURCE == 1
#undef _POSIX_C_SOURCE		/* Probably illegal, but beyond caring now. */
#define	_POSIX_C_SOURCE		199009
#endif
# 653 "/usr/include/sys/cdefs.h" 3 4

/* Deal with IEEE Std. 1003.2-1992, in which _POSIX_C_SOURCE == 2. */
#if defined(_POSIX_C_SOURCE) && _POSIX_C_SOURCE == 2
#undef _POSIX_C_SOURCE
#define	_POSIX_C_SOURCE		199209
#endif
# 659 "/usr/include/sys/cdefs.h" 3 4

/* Deal with various X/Open Portability Guides and Single UNIX Spec. */
#ifdef _XOPEN_SOURCE
#if _XOPEN_SOURCE - 0 >= 700
#define	__XSI_VISIBLE		700
#undef _POSIX_C_SOURCE
#define	_POSIX_C_SOURCE		200809
#elif _XOPEN_SOURCE - 0 >= 600
# 667 "/usr/include/sys/cdefs.h" 3 4
#define	__XSI_VISIBLE		600
#undef _POSIX_C_SOURCE
#define	_POSIX_C_SOURCE		200112
#elif _XOPEN_SOURCE - 0 >= 500
# 671 "/usr/include/sys/cdefs.h" 3 4
#define	__XSI_VISIBLE		500
#undef _POSIX_C_SOURCE
#define	_POSIX_C_SOURCE		199506
#endif
# 675 "/usr/include/sys/cdefs.h" 3 4
#endif
# 676 "/usr/include/sys/cdefs.h" 3 4

/*
 * Deal with all versions of POSIX.  The ordering relative to the tests above is
 * important.
 */
#if defined(_POSIX_SOURCE) && !defined(_POSIX_C_SOURCE)
#define	_POSIX_C_SOURCE		198808
#endif
# 684 "/usr/include/sys/cdefs.h" 3 4
#ifdef _POSIX_C_SOURCE
#if _POSIX_C_SOURCE >= 200809
#define	__POSIX_VISIBLE		200809
#define	__ISO_C_VISIBLE		1999
#elif _POSIX_C_SOURCE >= 200112
# 689 "/usr/include/sys/cdefs.h" 3 4
#define	__POSIX_VISIBLE		200112
#define	__ISO_C_VISIBLE		1999
#elif _POSIX_C_SOURCE >= 199506
# 692 "/usr/include/sys/cdefs.h" 3 4
#define	__POSIX_VISIBLE		199506
#define	__ISO_C_VISIBLE		1990
#elif _POSIX_C_SOURCE >= 199309
# 695 "/usr/include/sys/cdefs.h" 3 4
#define	__POSIX_VISIBLE		199309
#define	__ISO_C_VISIBLE		1990
#elif _POSIX_C_SOURCE >= 199209
# 698 "/usr/include/sys/cdefs.h" 3 4
#define	__POSIX_VISIBLE		199209
#define	__ISO_C_VISIBLE		1990
#elif _POSIX_C_SOURCE >= 199009
# 701 "/usr/include/sys/cdefs.h" 3 4
#define	__POSIX_VISIBLE		199009
#define	__ISO_C_VISIBLE		1990
#else
# 704 "/usr/include/sys/cdefs.h" 3 4
#define	__POSIX_VISIBLE		198808
#define	__ISO_C_VISIBLE		0
#endif /* _POSIX_C_SOURCE */
# 707 "/usr/include/sys/cdefs.h" 3 4
#else
# 708 "/usr/include/sys/cdefs.h" 3 4
/*-
 * Deal with _ANSI_SOURCE:
 * If it is defined, and no other compilation environment is explicitly
 * requested, then define our internal feature-test macros to zero.  This
 * makes no difference to the preprocessor (undefined symbols in preprocessing
 * expressions are defined to have value zero), but makes it more convenient for
 * a test program to print out the values.
 *
 * If a program mistakenly defines _ANSI_SOURCE and some other macro such as
 * _POSIX_C_SOURCE, we will assume that it wants the broader compilation
 * environment (and in fact we will never get here).
 */
#if defined(_ANSI_SOURCE)	/* Hide almost everything. */
#define	__POSIX_VISIBLE		0
#define	__XSI_VISIBLE		0
#define	__BSD_VISIBLE		0
#define	__ISO_C_VISIBLE		1990
#elif defined(_C99_SOURCE)	/* Localism to specify strict C99 env. */
# 726 "/usr/include/sys/cdefs.h" 3 4
#define	__POSIX_VISIBLE		0
#define	__XSI_VISIBLE		0
#define	__BSD_VISIBLE		0
#define	__ISO_C_VISIBLE		1999
#elif defined(_C11_SOURCE)	/* Localism to specify strict C11 env. */
# 731 "/usr/include/sys/cdefs.h" 3 4
#define	__POSIX_VISIBLE		0
#define	__XSI_VISIBLE		0
#define	__BSD_VISIBLE		0
#define	__ISO_C_VISIBLE		2011
#else				/* Default environment: show everything. */
# 736 "/usr/include/sys/cdefs.h" 3 4
#define	__POSIX_VISIBLE		200809
#define	__XSI_VISIBLE		700
#define	__BSD_VISIBLE		1
#define	__ISO_C_VISIBLE		2011
#endif
# 741 "/usr/include/sys/cdefs.h" 3 4
#endif
# 742 "/usr/include/sys/cdefs.h" 3 4

#if defined(__mips) || defined(__powerpc64__)
#define __NO_TLS 1
#endif
# 746 "/usr/include/sys/cdefs.h" 3 4

/*
 * Lock annotations.
 *
 * Clang provides support for doing basic thread-safety tests at
 * compile-time, by marking which locks will/should be held when
 * entering/leaving a functions.
 *
 * Furthermore, it is also possible to annotate variables and structure
 * members to enforce that they are only accessed when certain locks are
 * held.
 */

#if __has_extension(c_thread_safety_attributes)
#define	__lock_annotate(x)	__attribute__((x))
#else
# 762 "/usr/include/sys/cdefs.h" 3 4
#define	__lock_annotate(x)
#endif
# 764 "/usr/include/sys/cdefs.h" 3 4

/* Structure implements a lock. */
#define	__lockable		__lock_annotate(lockable)

/* Function acquires an exclusive or shared lock. */
#define	__locks_exclusive(...) \
	__lock_annotate(exclusive_lock_function(__VA_ARGS__))
#define	__locks_shared(...) \
	__lock_annotate(shared_lock_function(__VA_ARGS__))

/* Function attempts to acquire an exclusive or shared lock. */
#define	__trylocks_exclusive(...) \
	__lock_annotate(exclusive_trylock_function(__VA_ARGS__))
#define	__trylocks_shared(...) \
	__lock_annotate(shared_trylock_function(__VA_ARGS__))

/* Function releases a lock. */
#define	__unlocks(...)		__lock_annotate(unlock_function(__VA_ARGS__))

/* Function asserts that an exclusive or shared lock is held. */
#define	__asserts_exclusive(...) \
	__lock_annotate(assert_exclusive_lock(__VA_ARGS__))
#define	__asserts_shared(...) \
	__lock_annotate(assert_shared_lock(__VA_ARGS__))

/* Function requires that an exclusive or shared lock is or is not held. */
#define	__requires_exclusive(...) \
	__lock_annotate(exclusive_locks_required(__VA_ARGS__))
#define	__requires_shared(...) \
	__lock_annotate(shared_locks_required(__VA_ARGS__))
#define	__requires_unlocked(...) \
	__lock_annotate(locks_excluded(__VA_ARGS__))

/* Function should not be analyzed. */
#define	__no_lock_analysis	__lock_annotate(no_thread_safety_analysis)

/* Guard variables and structure members by lock. */
#define	__guarded_by(x)		__lock_annotate(guarded_by(x))
#define	__pt_guarded_by(x)	__lock_annotate(pt_guarded_by(x))

#endif /* !_SYS_CDEFS_H_ */
# 805 "/usr/include/sys/cdefs.h" 3 4
# 33 "/usr/include/sys/endian.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/sys/_types.h" 1 3 4
/*-
 * Copyright (c) 2002 Mike Barcroft <mike@FreeBSD.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/sys/sys/_types.h 255219 2013-09-05 00:09:56Z pjd $
 */

#ifndef _SYS__TYPES_H_
#define _SYS__TYPES_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 33 "/usr/include/sys/_types.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/machine/_types.h" 1 3 4
/*-
 * This file is in the public domain.
 */
/* $FreeBSD: head/sys/amd64/include/_types.h 232261 2012-02-28 18:15:28Z tijl $ */

#if 0 /* expanded by -frewrite-includes */
#include <x86/_types.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/x86/_types.h" 1 3 4
/*-
 * Copyright (c) 2002 Mike Barcroft <mike@FreeBSD.org>
 * Copyright (c) 1990, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	From: @(#)ansi.h	8.2 (Berkeley) 1/4/94
 *	From: @(#)types.h	8.3 (Berkeley) 1/5/94
 * $FreeBSD: head/sys/x86/include/_types.h 263998 2014-04-01 14:46:11Z tijl $
 */

#ifndef _MACHINE__TYPES_H_
#define	_MACHINE__TYPES_H_

#ifndef _SYS_CDEFS_H_
#error this file needs sys/cdefs.h as a prerequisite
#endif
# 45 "/usr/include/x86/_types.h" 3 4

#define __NO_STRICT_ALIGNMENT

/*
 * Basic types upon which most other types are built.
 */
typedef	signed char		__int8_t;
typedef	unsigned char		__uint8_t;
typedef	short			__int16_t;
typedef	unsigned short		__uint16_t;
typedef	int			__int32_t;
typedef	unsigned int		__uint32_t;
#ifdef	__LP64__
typedef	long			__int64_t;
typedef	unsigned long		__uint64_t;
#else
# 61 "/usr/include/x86/_types.h" 3 4
#ifndef lint
__extension__
#endif
# 64 "/usr/include/x86/_types.h" 3 4
/* LONGLONG */
typedef	long long		__int64_t;
#ifndef lint
__extension__
#endif
# 69 "/usr/include/x86/_types.h" 3 4
/* LONGLONG */
typedef	unsigned long long	__uint64_t;
#endif
# 72 "/usr/include/x86/_types.h" 3 4

/*
 * Standard type definitions.
 */
#ifdef	__LP64__
typedef	__int32_t	__clock_t;		/* clock()... */
typedef	__int64_t	__critical_t;
typedef	double		__double_t;
typedef	float		__float_t;
typedef	__int64_t	__intfptr_t;
typedef	__int64_t	__intptr_t;
#else
# 84 "/usr/include/x86/_types.h" 3 4
typedef	unsigned long	__clock_t;
typedef	__int32_t	__critical_t;
typedef	long double	__double_t;
typedef	long double	__float_t;
typedef	__int32_t	__intfptr_t;
typedef	__int32_t	__intptr_t;
#endif
# 91 "/usr/include/x86/_types.h" 3 4
typedef	__int64_t	__intmax_t;
typedef	__int32_t	__int_fast8_t;
typedef	__int32_t	__int_fast16_t;
typedef	__int32_t	__int_fast32_t;
typedef	__int64_t	__int_fast64_t;
typedef	__int8_t	__int_least8_t;
typedef	__int16_t	__int_least16_t;
typedef	__int32_t	__int_least32_t;
typedef	__int64_t	__int_least64_t;
#ifdef	__LP64__
typedef	__int64_t	__ptrdiff_t;		/* ptr1 - ptr2 */
typedef	__int64_t	__register_t;
typedef	__int64_t	__segsz_t;		/* segment size (in pages) */
typedef	__uint64_t	__size_t;		/* sizeof() */
typedef	__int64_t	__ssize_t;		/* byte count or error */
typedef	__int64_t	__time_t;		/* time()... */
typedef	__uint64_t	__uintfptr_t;
typedef	__uint64_t	__uintptr_t;
#else
# 110 "/usr/include/x86/_types.h" 3 4
typedef	__int32_t	__ptrdiff_t;
typedef	__int32_t	__register_t;
typedef	__int32_t	__segsz_t;
typedef	__uint32_t	__size_t;
typedef	__int32_t	__ssize_t;
typedef	__int32_t	__time_t;
typedef	__uint32_t	__uintfptr_t;
typedef	__uint32_t	__uintptr_t;
#endif
# 119 "/usr/include/x86/_types.h" 3 4
typedef	__uint64_t	__uintmax_t;
typedef	__uint32_t	__uint_fast8_t;
typedef	__uint32_t	__uint_fast16_t;
typedef	__uint32_t	__uint_fast32_t;
typedef	__uint64_t	__uint_fast64_t;
typedef	__uint8_t	__uint_least8_t;
typedef	__uint16_t	__uint_least16_t;
typedef	__uint32_t	__uint_least32_t;
typedef	__uint64_t	__uint_least64_t;
#ifdef	__LP64__
typedef	__uint64_t	__u_register_t;
typedef	__uint64_t	__vm_offset_t;
typedef	__uint64_t	__vm_paddr_t;
typedef	__uint64_t	__vm_size_t;
#else
# 134 "/usr/include/x86/_types.h" 3 4
typedef	__uint32_t	__u_register_t;
typedef	__uint32_t	__vm_offset_t;
#ifdef PAE
typedef	__uint64_t	__vm_paddr_t;
#else
# 139 "/usr/include/x86/_types.h" 3 4
typedef	__uint32_t	__vm_paddr_t;
#endif
# 141 "/usr/include/x86/_types.h" 3 4
typedef	__uint32_t	__vm_size_t;
#endif
# 143 "/usr/include/x86/_types.h" 3 4
typedef	__int64_t	__vm_ooffset_t;
typedef	__uint64_t	__vm_pindex_t;
typedef	int		___wchar_t;

#define	__WCHAR_MIN	__INT_MIN	/* min value for a wchar_t */
#define	__WCHAR_MAX	__INT_MAX	/* max value for a wchar_t */

/*
 * Unusual type definitions.
 */
#ifdef __GNUCLIKE_BUILTIN_VARARGS
typedef	__builtin_va_list	__va_list;	/* internally known to gcc */
#elif defined(lint)
# 156 "/usr/include/x86/_types.h" 3 4
typedef	char *			__va_list;	/* pretend */
#endif
# 158 "/usr/include/x86/_types.h" 3 4
#if defined(__GNUC_VA_LIST_COMPATIBILITY) && !defined(__GNUC_VA_LIST) \
    && !defined(__NO_GNUC_VA_LIST)
#define __GNUC_VA_LIST
typedef __va_list		__gnuc_va_list;	/* compatibility w/GNU headers*/
#endif
# 163 "/usr/include/x86/_types.h" 3 4

#endif /* !_MACHINE__TYPES_H_ */
# 165 "/usr/include/x86/_types.h" 3 4
# 7 "/usr/include/machine/_types.h" 2 3 4
# 34 "/usr/include/sys/_types.h" 2 3 4

/*
 * Standard type definitions.
 */
typedef	__uint32_t	__blksize_t;	/* file block size */
typedef	__int64_t	__blkcnt_t;	/* file block count */
typedef	__int32_t	__clockid_t;	/* clock_gettime()... */
typedef	__uint32_t	__fflags_t;	/* file flags */
typedef	__uint64_t	__fsblkcnt_t;
typedef	__uint64_t	__fsfilcnt_t;
typedef	__uint32_t	__gid_t;
typedef	__int64_t	__id_t;		/* can hold a gid_t, pid_t, or uid_t */
typedef	__uint32_t	__ino_t;	/* inode number */
typedef	long		__key_t;	/* IPC key (for Sys V IPC) */
typedef	__int32_t	__lwpid_t;	/* Thread ID (a.k.a. LWP) */
typedef	__uint16_t	__mode_t;	/* permissions */
typedef	int		__accmode_t;	/* access permissions */
typedef	int		__nl_item;
typedef	__uint16_t	__nlink_t;	/* link count */
typedef	__int64_t	__off_t;	/* file offset */
typedef	__int32_t	__pid_t;	/* process [group] */
typedef	__int64_t	__rlim_t;	/* resource limit - intentionally */
					/* signed, because of legacy code */
					/* that uses -1 for RLIM_INFINITY */
typedef	__uint8_t	__sa_family_t;
typedef	__uint32_t	__socklen_t;
typedef	long		__suseconds_t;	/* microseconds (signed) */
typedef	struct __timer	*__timer_t;	/* timer_gettime()... */
typedef	struct __mq	*__mqd_t;	/* mq_open()... */
typedef	__uint32_t	__uid_t;
typedef	unsigned int	__useconds_t;	/* microseconds (unsigned) */
typedef	int		__cpuwhich_t;	/* which parameter for cpuset. */
typedef	int		__cpulevel_t;	/* level parameter for cpuset. */
typedef int		__cpusetid_t;	/* cpuset identifier. */

/*
 * Unusual type definitions.
 */
/*
 * rune_t is declared to be an ``int'' instead of the more natural
 * ``unsigned long'' or ``long''.  Two things are happening here.  It is not
 * unsigned so that EOF (-1) can be naturally assigned to it and used.  Also,
 * it looks like 10646 will be a 31 bit standard.  This means that if your
 * ints cannot hold 32 bits, you will be in trouble.  The reason an int was
 * chosen over a long is that the is*() and to*() routines take ints (says
 * ANSI C), but they use __ct_rune_t instead of int.
 *
 * NOTE: rune_t is not covered by ANSI nor other standards, and should not
 * be instantiated outside of lib/libc/locale.  Use wchar_t.  wint_t and
 * rune_t must be the same type.  Also, wint_t should be able to hold all
 * members of the largest character set plus one extra value (WEOF), and
 * must be at least 16 bits.
 */
typedef	int		__ct_rune_t;	/* arg type for ctype funcs */
typedef	__ct_rune_t	__rune_t;	/* rune_t (see above) */
typedef	__ct_rune_t	__wint_t;	/* wint_t (see above) */

/* Clang already provides these types as built-ins, but only in C++ mode. */
#if !defined(__clang__) || !defined(__cplusplus)
typedef	__uint_least16_t __char16_t;
typedef	__uint_least32_t __char32_t;
#endif
# 96 "/usr/include/sys/_types.h" 3 4
/* In C++11, char16_t and char32_t are built-in types. */
#if defined(__cplusplus) && __cplusplus >= 201103L
#define	_CHAR16_T_DECLARED
#define	_CHAR32_T_DECLARED
#endif
# 101 "/usr/include/sys/_types.h" 3 4

typedef	__uint32_t	__dev_t;	/* device number */

typedef	__uint32_t	__fixpt_t;	/* fixed point number */

/*
 * mbstate_t is an opaque object to keep conversion state during multibyte
 * stream conversions.
 */
typedef union {
	char		__mbstate8[128];
	__int64_t	_mbstateL;	/* for alignment */
} __mbstate_t;

#endif /* !_SYS__TYPES_H_ */
# 116 "/usr/include/sys/_types.h" 3 4
# 34 "/usr/include/sys/endian.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <machine/endian.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/machine/endian.h" 1 3 4
/*-
 * This file is in the public domain.
 */
/* $FreeBSD: head/sys/amd64/include/endian.h 232266 2012-02-28 19:39:54Z tijl $ */

#if 0 /* expanded by -frewrite-includes */
#include <x86/endian.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/x86/endian.h" 1 3 4
/*-
 * Copyright (c) 1987, 1991 Regents of the University of California.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)endian.h	7.8 (Berkeley) 4/3/91
 * $FreeBSD: head/sys/x86/include/endian.h 233684 2012-03-29 23:31:48Z dim $
 */

#ifndef _MACHINE_ENDIAN_H_
#define	_MACHINE_ENDIAN_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 37 "/usr/include/x86/endian.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 38 "/usr/include/x86/endian.h" 3 4

/*
 * Define the order of 32-bit words in 64-bit words.
 */
#define	_QUAD_HIGHWORD 1
#define	_QUAD_LOWWORD 0

/*
 * Definitions for byte order, according to byte significance from low
 * address to high.
 */
#define	_LITTLE_ENDIAN	1234	/* LSB first: i386, vax */
#define	_BIG_ENDIAN	4321	/* MSB first: 68000, ibm, net */
#define	_PDP_ENDIAN	3412	/* LSB first in word, MSW first in long */

#define	_BYTE_ORDER	_LITTLE_ENDIAN

/*
 * Deprecated variants that don't have enough underscores to be useful in more
 * strict namespaces.
 */
#if __BSD_VISIBLE
#define	LITTLE_ENDIAN	_LITTLE_ENDIAN
#define	BIG_ENDIAN	_BIG_ENDIAN
#define	PDP_ENDIAN	_PDP_ENDIAN
#define	BYTE_ORDER	_BYTE_ORDER
#endif
# 65 "/usr/include/x86/endian.h" 3 4

#define	__bswap16_gen(x)	(__uint16_t)((x) << 8 | (x) >> 8)
#define	__bswap32_gen(x)		\
	(((__uint32_t)__bswap16((x) & 0xffff) << 16) | __bswap16((x) >> 16))
#define	__bswap64_gen(x)		\
	(((__uint64_t)__bswap32((x) & 0xffffffff) << 32) | __bswap32((x) >> 32))

#ifdef __GNUCLIKE_BUILTIN_CONSTANT_P
#define	__bswap16(x)				\
	((__uint16_t)(__builtin_constant_p(x) ?	\
	    __bswap16_gen((__uint16_t)(x)) : __bswap16_var(x)))
#define	__bswap32(x)			\
	(__builtin_constant_p(x) ?	\
	    __bswap32_gen((__uint32_t)(x)) : __bswap32_var(x))
#define	__bswap64(x)			\
	(__builtin_constant_p(x) ?	\
	    __bswap64_gen((__uint64_t)(x)) : __bswap64_var(x))
#else
# 83 "/usr/include/x86/endian.h" 3 4
/* XXX these are broken for use in static initializers. */
#define	__bswap16(x)	__bswap16_var(x)
#define	__bswap32(x)	__bswap32_var(x)
#define	__bswap64(x)	__bswap64_var(x)
#endif
# 88 "/usr/include/x86/endian.h" 3 4

/* These are defined as functions to avoid multiple evaluation of x. */

static __inline __uint16_t
__bswap16_var(__uint16_t _x)
{

	return (__bswap16_gen(_x));
}

static __inline __uint32_t
__bswap32_var(__uint32_t _x)
{

#ifdef __GNUCLIKE_ASM
	__asm("bswap %0" : "+r" (_x));
	return (_x);
#else
# 106 "/usr/include/x86/endian.h" 3 4
	return (__bswap32_gen(_x));
#endif
# 108 "/usr/include/x86/endian.h" 3 4
}

static __inline __uint64_t
__bswap64_var(__uint64_t _x)
{

#if defined(__amd64__) && defined(__GNUCLIKE_ASM)
	__asm("bswap %0" : "+r" (_x));
	return (_x);
#else
# 118 "/usr/include/x86/endian.h" 3 4
	/*
	 * It is important for the optimizations that the following is not
	 * really generic, but expands to 2 __bswap32_var()'s.
	 */
	return (__bswap64_gen(_x));
#endif
# 124 "/usr/include/x86/endian.h" 3 4
}

#define	__htonl(x)	__bswap32(x)
#define	__htons(x)	__bswap16(x)
#define	__ntohl(x)	__bswap32(x)
#define	__ntohs(x)	__bswap16(x)

#endif /* !_MACHINE_ENDIAN_H_ */
# 132 "/usr/include/x86/endian.h" 3 4
# 7 "/usr/include/machine/endian.h" 2 3 4
# 35 "/usr/include/sys/endian.h" 2 3 4

#ifndef _UINT8_T_DECLARED
typedef	__uint8_t	uint8_t;
#define	_UINT8_T_DECLARED
#endif
# 40 "/usr/include/sys/endian.h" 3 4
 
#ifndef _UINT16_T_DECLARED
typedef	__uint16_t	uint16_t;
#define	_UINT16_T_DECLARED
#endif
# 45 "/usr/include/sys/endian.h" 3 4
 
#ifndef _UINT32_T_DECLARED
typedef	__uint32_t	uint32_t;
#define	_UINT32_T_DECLARED
#endif
# 50 "/usr/include/sys/endian.h" 3 4
 
#ifndef _UINT64_T_DECLARED
typedef	__uint64_t	uint64_t;
#define	_UINT64_T_DECLARED
#endif
# 55 "/usr/include/sys/endian.h" 3 4
 
/*
 * General byte order swapping functions.
 */
#define	bswap16(x)	__bswap16(x)
#define	bswap32(x)	__bswap32(x)
#define	bswap64(x)	__bswap64(x)

/*
 * Host to big endian, host to little endian, big endian to host, and little
 * endian to host byte order functions as detailed in byteorder(9).
 */
#if _BYTE_ORDER == _LITTLE_ENDIAN
#define	htobe16(x)	bswap16((x))
#define	htobe32(x)	bswap32((x))
#define	htobe64(x)	bswap64((x))
#define	htole16(x)	((uint16_t)(x))
#define	htole32(x)	((uint32_t)(x))
#define	htole64(x)	((uint64_t)(x))

#define	be16toh(x)	bswap16((x))
#define	be32toh(x)	bswap32((x))
#define	be64toh(x)	bswap64((x))
#define	le16toh(x)	((uint16_t)(x))
#define	le32toh(x)	((uint32_t)(x))
#define	le64toh(x)	((uint64_t)(x))
#else /* _BYTE_ORDER != _LITTLE_ENDIAN */
# 82 "/usr/include/sys/endian.h" 3 4
#define	htobe16(x)	((uint16_t)(x))
#define	htobe32(x)	((uint32_t)(x))
#define	htobe64(x)	((uint64_t)(x))
#define	htole16(x)	bswap16((x))
#define	htole32(x)	bswap32((x))
#define	htole64(x)	bswap64((x))

#define	be16toh(x)	((uint16_t)(x))
#define	be32toh(x)	((uint32_t)(x))
#define	be64toh(x)	((uint64_t)(x))
#define	le16toh(x)	bswap16((x))
#define	le32toh(x)	bswap32((x))
#define	le64toh(x)	bswap64((x))
#endif /* _BYTE_ORDER == _LITTLE_ENDIAN */
# 96 "/usr/include/sys/endian.h" 3 4

/* Alignment-agnostic encode/decode bytestream to/from little/big endian. */

static __inline uint16_t
be16dec(const void *pp)
{
	uint8_t const *p = (uint8_t const *)pp;

	return ((p[0] << 8) | p[1]);
}

static __inline uint32_t
be32dec(const void *pp)
{
	uint8_t const *p = (uint8_t const *)pp;

	return (((unsigned)p[0] << 24) | (p[1] << 16) | (p[2] << 8) | p[3]);
}

static __inline uint64_t
be64dec(const void *pp)
{
	uint8_t const *p = (uint8_t const *)pp;

	return (((uint64_t)be32dec(p) << 32) | be32dec(p + 4));
}

static __inline uint16_t
le16dec(const void *pp)
{
	uint8_t const *p = (uint8_t const *)pp;

	return ((p[1] << 8) | p[0]);
}

static __inline uint32_t
le32dec(const void *pp)
{
	uint8_t const *p = (uint8_t const *)pp;

	return (((unsigned)p[3] << 24) | (p[2] << 16) | (p[1] << 8) | p[0]);
}

static __inline uint64_t
le64dec(const void *pp)
{
	uint8_t const *p = (uint8_t const *)pp;

	return (((uint64_t)le32dec(p + 4) << 32) | le32dec(p));
}

static __inline void
be16enc(void *pp, uint16_t u)
{
	uint8_t *p = (uint8_t *)pp;

	p[0] = (u >> 8) & 0xff;
	p[1] = u & 0xff;
}

static __inline void
be32enc(void *pp, uint32_t u)
{
	uint8_t *p = (uint8_t *)pp;

	p[0] = (u >> 24) & 0xff;
	p[1] = (u >> 16) & 0xff;
	p[2] = (u >> 8) & 0xff;
	p[3] = u & 0xff;
}

static __inline void
be64enc(void *pp, uint64_t u)
{
	uint8_t *p = (uint8_t *)pp;

	be32enc(p, (uint32_t)(u >> 32));
	be32enc(p + 4, (uint32_t)(u & 0xffffffffU));
}

static __inline void
le16enc(void *pp, uint16_t u)
{
	uint8_t *p = (uint8_t *)pp;

	p[0] = u & 0xff;
	p[1] = (u >> 8) & 0xff;
}

static __inline void
le32enc(void *pp, uint32_t u)
{
	uint8_t *p = (uint8_t *)pp;

	p[0] = u & 0xff;
	p[1] = (u >> 8) & 0xff;
	p[2] = (u >> 16) & 0xff;
	p[3] = (u >> 24) & 0xff;
}

static __inline void
le64enc(void *pp, uint64_t u)
{
	uint8_t *p = (uint8_t *)pp;

	le32enc(p, (uint32_t)(u & 0xffffffffU));
	le32enc(p + 4, (uint32_t)(u >> 32));
}

#endif	/* _SYS_ENDIAN_H_ */
# 206 "/usr/include/sys/endian.h" 3 4
# 47 "/usr/include/c++/v1/__config" 2 3
#  if _BYTE_ORDER == _LITTLE_ENDIAN
#   define _LIBCPP_LITTLE_ENDIAN 1
#   define _LIBCPP_BIG_ENDIAN    0
# else  // _BYTE_ORDER == _LITTLE_ENDIAN
# 51 "/usr/include/c++/v1/__config" 3
#   define _LIBCPP_LITTLE_ENDIAN 0
#   define _LIBCPP_BIG_ENDIAN    1
# endif  // _BYTE_ORDER == _LITTLE_ENDIAN
# 54 "/usr/include/c++/v1/__config" 3
# ifndef __LONG_LONG_SUPPORTED
#  define _LIBCPP_HAS_NO_LONG_LONG
# endif  // __LONG_LONG_SUPPORTED
# 57 "/usr/include/c++/v1/__config" 3
#endif  // __FreeBSD__
# 58 "/usr/include/c++/v1/__config" 3

#ifdef __NetBSD__
#if 0 /* expanded by -frewrite-includes */
# include <sys/endian.h>
#endif /* expanded by -frewrite-includes */
# 61 "/usr/include/c++/v1/__config" 3
#  if _BYTE_ORDER == _LITTLE_ENDIAN
#   define _LIBCPP_LITTLE_ENDIAN 1
#   define _LIBCPP_BIG_ENDIAN    0
# else  // _BYTE_ORDER == _LITTLE_ENDIAN
# 65 "/usr/include/c++/v1/__config" 3
#   define _LIBCPP_LITTLE_ENDIAN 0
#   define _LIBCPP_BIG_ENDIAN    1
# endif  // _BYTE_ORDER == _LITTLE_ENDIAN
# 68 "/usr/include/c++/v1/__config" 3
# define _LIBCPP_HAS_QUICK_EXIT
#endif  // __NetBSD__
# 70 "/usr/include/c++/v1/__config" 3

#ifdef _WIN32
#  define _LIBCPP_LITTLE_ENDIAN 1
#  define _LIBCPP_BIG_ENDIAN    0
// Compiler intrinsics (GCC or MSVC)
#  if defined(__clang__) \
   || (defined(_MSC_VER) && _MSC_VER >= 1400) \
   || (defined(__GNUC__) && _GNUC_VER > 403)
#    define _LIBCPP_HAS_IS_BASE_OF
#  endif
# 80 "/usr/include/c++/v1/__config" 3
#  if defined(_MSC_VER) && !defined(__clang__)
#    define _LIBCPP_MSVC // Using Microsoft Visual C++ compiler
#    define _LIBCPP_TOSTRING2(x) #x
#    define _LIBCPP_TOSTRING(x) _LIBCPP_TOSTRING2(x)
#    define _LIBCPP_WARNING(x) __pragma(message(__FILE__ "(" _LIBCPP_TOSTRING(__LINE__) ") : warning note: " x))
#  endif
# 86 "/usr/include/c++/v1/__config" 3
#  // If mingw not explicitly detected, assume using MS C runtime only.
#  ifndef __MINGW32__
#    define _LIBCPP_MSVCRT // Using Microsoft's C Runtime library
#  endif
# 90 "/usr/include/c++/v1/__config" 3
#endif  // _WIN32
# 91 "/usr/include/c++/v1/__config" 3

#ifdef __linux__
#  if defined(__GNUC__) && _GNUC_VER >= 403
#    define _LIBCPP_HAS_IS_BASE_OF
#  endif
# 96 "/usr/include/c++/v1/__config" 3
#endif
# 97 "/usr/include/c++/v1/__config" 3

#ifdef __sun__
#if 0 /* expanded by -frewrite-includes */
# include <sys/isa_defs.h>
#endif /* expanded by -frewrite-includes */
# 100 "/usr/include/c++/v1/__config" 3
# ifdef _LITTLE_ENDIAN
#   define _LIBCPP_LITTLE_ENDIAN 1
#   define _LIBCPP_BIG_ENDIAN    0
# else
# 104 "/usr/include/c++/v1/__config" 3
#   define _LIBCPP_LITTLE_ENDIAN 0
#   define _LIBCPP_BIG_ENDIAN    1
# endif
# 107 "/usr/include/c++/v1/__config" 3
#endif // __sun__
# 108 "/usr/include/c++/v1/__config" 3

#if !defined(_LIBCPP_LITTLE_ENDIAN) || !defined(_LIBCPP_BIG_ENDIAN)
#if 0 /* expanded by -frewrite-includes */
# include <endian.h>
#endif /* expanded by -frewrite-includes */
# 111 "/usr/include/c++/v1/__config" 3
# if __BYTE_ORDER == __LITTLE_ENDIAN
#  define _LIBCPP_LITTLE_ENDIAN 1
#  define _LIBCPP_BIG_ENDIAN    0
# elif __BYTE_ORDER == __BIG_ENDIAN
# 115 "/usr/include/c++/v1/__config" 3
#  define _LIBCPP_LITTLE_ENDIAN 0
#  define _LIBCPP_BIG_ENDIAN    1
# else  // __BYTE_ORDER == __BIG_ENDIAN
# 118 "/usr/include/c++/v1/__config" 3
#  error unable to determine endian
# endif
# 120 "/usr/include/c++/v1/__config" 3
#endif  // !defined(_LIBCPP_LITTLE_ENDIAN) || !defined(_LIBCPP_BIG_ENDIAN)
# 121 "/usr/include/c++/v1/__config" 3

#ifdef _WIN32

// only really useful for a DLL
#ifdef _LIBCPP_DLL // this should be a compiler builtin define ideally...
# ifdef cxx_EXPORTS
#  define _LIBCPP_HIDDEN
#  define _LIBCPP_FUNC_VIS __declspec(dllexport)
#  define _LIBCPP_TYPE_VIS __declspec(dllexport)
# else
# 131 "/usr/include/c++/v1/__config" 3
#  define _LIBCPP_HIDDEN
#  define _LIBCPP_FUNC_VIS __declspec(dllimport)
#  define _LIBCPP_TYPE_VIS __declspec(dllimport)
# endif
# 135 "/usr/include/c++/v1/__config" 3
#else
# 136 "/usr/include/c++/v1/__config" 3
# define _LIBCPP_HIDDEN
# define _LIBCPP_FUNC_VIS
# define _LIBCPP_TYPE_VIS
#endif
# 140 "/usr/include/c++/v1/__config" 3

#define _LIBCPP_TYPE_VIS_ONLY
#define _LIBCPP_FUNC_VIS_ONLY

#ifndef _LIBCPP_INLINE_VISIBILITY
# ifdef _LIBCPP_MSVC
#  define _LIBCPP_INLINE_VISIBILITY __forceinline
# else // MinGW GCC and Clang
# 148 "/usr/include/c++/v1/__config" 3
#  define _LIBCPP_INLINE_VISIBILITY __attribute__ ((__always_inline__))
# endif
# 150 "/usr/include/c++/v1/__config" 3
#endif
# 151 "/usr/include/c++/v1/__config" 3

#ifndef _LIBCPP_EXCEPTION_ABI
#define _LIBCPP_EXCEPTION_ABI _LIBCPP_TYPE_VIS
#endif
# 155 "/usr/include/c++/v1/__config" 3

#ifndef _LIBCPP_ALWAYS_INLINE
# ifdef _LIBCPP_MSVC
#  define _LIBCPP_ALWAYS_INLINE __forceinline
# endif
# 160 "/usr/include/c++/v1/__config" 3
#endif
# 161 "/usr/include/c++/v1/__config" 3

#endif // _WIN32
# 163 "/usr/include/c++/v1/__config" 3

#ifndef __has_attribute
#define __has_attribute(__x) 0
#endif
# 167 "/usr/include/c++/v1/__config" 3

#ifndef _LIBCPP_HIDDEN
#define _LIBCPP_HIDDEN __attribute__ ((__visibility__("hidden")))
#endif
# 171 "/usr/include/c++/v1/__config" 3

#ifndef _LIBCPP_FUNC_VIS
#define _LIBCPP_FUNC_VIS __attribute__ ((__visibility__("default")))
#endif
# 175 "/usr/include/c++/v1/__config" 3

#ifndef _LIBCPP_TYPE_VIS
#  if __has_attribute(__type_visibility__)
#    define _LIBCPP_TYPE_VIS __attribute__ ((__type_visibility__("default")))
#  else
# 180 "/usr/include/c++/v1/__config" 3
#    define _LIBCPP_TYPE_VIS __attribute__ ((__visibility__("default")))
#  endif
# 182 "/usr/include/c++/v1/__config" 3
#endif
# 183 "/usr/include/c++/v1/__config" 3

#ifndef _LIBCPP_TYPE_VIS_ONLY
# define _LIBCPP_TYPE_VIS_ONLY _LIBCPP_TYPE_VIS
#endif
# 187 "/usr/include/c++/v1/__config" 3

#ifndef _LIBCPP_FUNC_VIS_ONLY
# define _LIBCPP_FUNC_VIS_ONLY _LIBCPP_FUNC_VIS
#endif
# 191 "/usr/include/c++/v1/__config" 3

#ifndef _LIBCPP_INLINE_VISIBILITY
#define _LIBCPP_INLINE_VISIBILITY __attribute__ ((__visibility__("hidden"), __always_inline__))
#endif
# 195 "/usr/include/c++/v1/__config" 3

#ifndef _LIBCPP_EXCEPTION_ABI
#define _LIBCPP_EXCEPTION_ABI _LIBCPP_TYPE_VIS
#endif
# 199 "/usr/include/c++/v1/__config" 3

#ifndef _LIBCPP_ALWAYS_INLINE
#define _LIBCPP_ALWAYS_INLINE  __attribute__ ((__visibility__("hidden"), __always_inline__))
#endif
# 203 "/usr/include/c++/v1/__config" 3

#if defined(__clang__)

#if __has_feature(cxx_alignas)
#  define _ALIGNAS_TYPE(x) alignas(x)
#  define _ALIGNAS(x) alignas(x)
#else
# 210 "/usr/include/c++/v1/__config" 3
#  define _ALIGNAS_TYPE(x) __attribute__((__aligned__(__alignof(x))))
#  define _ALIGNAS(x) __attribute__((__aligned__(x)))
#endif
# 213 "/usr/include/c++/v1/__config" 3

#if !__has_feature(cxx_alias_templates)
#define _LIBCPP_HAS_NO_TEMPLATE_ALIASES
#endif
# 217 "/usr/include/c++/v1/__config" 3

#ifndef __GXX_EXPERIMENTAL_CXX0X__
#ifdef __linux__
#define _LIBCPP_HAS_NO_UNICODE_CHARS
#else
# 222 "/usr/include/c++/v1/__config" 3
typedef __char16_t char16_t;
typedef __char32_t char32_t;
#endif
# 225 "/usr/include/c++/v1/__config" 3
#endif
# 226 "/usr/include/c++/v1/__config" 3

#if !(__has_feature(cxx_exceptions))
#define _LIBCPP_NO_EXCEPTIONS
#endif
# 230 "/usr/include/c++/v1/__config" 3

#if !(__has_feature(cxx_rtti))
#define _LIBCPP_NO_RTTI
#endif
# 234 "/usr/include/c++/v1/__config" 3

#if !(__has_feature(cxx_strong_enums))
#define _LIBCPP_HAS_NO_STRONG_ENUMS
#endif
# 238 "/usr/include/c++/v1/__config" 3

#if !(__has_feature(cxx_decltype))
#define _LIBCPP_HAS_NO_DECLTYPE
#endif
# 242 "/usr/include/c++/v1/__config" 3

#if __has_feature(cxx_attributes)
#  define _LIBCPP_NORETURN [[noreturn]]
#else
# 246 "/usr/include/c++/v1/__config" 3
#  define _LIBCPP_NORETURN __attribute__ ((noreturn))
#endif
# 248 "/usr/include/c++/v1/__config" 3

#if !(__has_feature(cxx_defaulted_functions))
#define _LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS
#endif  // !(__has_feature(cxx_defaulted_functions))
# 252 "/usr/include/c++/v1/__config" 3

#if !(__has_feature(cxx_deleted_functions))
#define _LIBCPP_HAS_NO_DELETED_FUNCTIONS
#endif  // !(__has_feature(cxx_deleted_functions))
# 256 "/usr/include/c++/v1/__config" 3

#if !(__has_feature(cxx_lambdas))
#define _LIBCPP_HAS_NO_LAMBDAS
#endif
# 260 "/usr/include/c++/v1/__config" 3

#if !(__has_feature(cxx_nullptr))
#define _LIBCPP_HAS_NO_NULLPTR
#endif
# 264 "/usr/include/c++/v1/__config" 3

#if !(__has_feature(cxx_rvalue_references))
#define _LIBCPP_HAS_NO_RVALUE_REFERENCES
#endif
# 268 "/usr/include/c++/v1/__config" 3

#if !(__has_feature(cxx_static_assert))
#define _LIBCPP_HAS_NO_STATIC_ASSERT
#endif
# 272 "/usr/include/c++/v1/__config" 3

#if !(__has_feature(cxx_auto_type))
#define _LIBCPP_HAS_NO_AUTO_TYPE
#endif
# 276 "/usr/include/c++/v1/__config" 3

#if !(__has_feature(cxx_access_control_sfinae)) || !__has_feature(cxx_trailing_return)
#define _LIBCPP_HAS_NO_ADVANCED_SFINAE
#endif
# 280 "/usr/include/c++/v1/__config" 3

#if !(__has_feature(cxx_variadic_templates))
#define _LIBCPP_HAS_NO_VARIADICS
#endif
# 284 "/usr/include/c++/v1/__config" 3

#if !(__has_feature(cxx_trailing_return))
#define _LIBCPP_HAS_NO_TRAILING_RETURN
#endif
# 288 "/usr/include/c++/v1/__config" 3

#if !(__has_feature(cxx_generalized_initializers))
#define _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
#endif
# 292 "/usr/include/c++/v1/__config" 3

#if __has_feature(is_base_of)
#  define _LIBCPP_HAS_IS_BASE_OF
#endif
# 296 "/usr/include/c++/v1/__config" 3

// Objective-C++ features (opt-in)
#if __has_feature(objc_arc)
#define _LIBCPP_HAS_OBJC_ARC
#endif
# 301 "/usr/include/c++/v1/__config" 3

#if __has_feature(objc_arc_weak)
#define _LIBCPP_HAS_OBJC_ARC_WEAK
#define _LIBCPP_HAS_NO_STRONG_ENUMS
#endif
# 306 "/usr/include/c++/v1/__config" 3

#if !(__has_feature(cxx_constexpr))
#define _LIBCPP_HAS_NO_CONSTEXPR
#endif
# 310 "/usr/include/c++/v1/__config" 3

#if __ISO_C_VISIBLE >= 2011 || __cplusplus >= 201103L
#if defined(__FreeBSD__)
#define _LIBCPP_HAS_QUICK_EXIT
#define _LIBCPP_HAS_C11_FEATURES
#elif defined(__linux__)
# 316 "/usr/include/c++/v1/__config" 3
#if 0 /* expanded by -frewrite-includes */
#include <features.h>
#endif /* expanded by -frewrite-includes */
# 317 "/usr/include/c++/v1/__config" 3
#if __GLIBC_PREREQ(2, 15)
#define _LIBCPP_HAS_QUICK_EXIT
#endif
# 320 "/usr/include/c++/v1/__config" 3
#if __GLIBC_PREREQ(2, 17)
#define _LIBCPP_HAS_C11_FEATURES
#endif
# 323 "/usr/include/c++/v1/__config" 3
#endif
# 324 "/usr/include/c++/v1/__config" 3
#endif
# 325 "/usr/include/c++/v1/__config" 3

#if (__has_feature(cxx_noexcept))
#  define _NOEXCEPT noexcept
#  define _NOEXCEPT_(x) noexcept(x)
#else
# 330 "/usr/include/c++/v1/__config" 3
#  define _NOEXCEPT throw()
#  define _NOEXCEPT_(x)
#endif
# 333 "/usr/include/c++/v1/__config" 3

#if __has_feature(underlying_type)
#  define _LIBCXX_UNDERLYING_TYPE(T) __underlying_type(T)
#endif
# 337 "/usr/include/c++/v1/__config" 3

// Inline namespaces are available in Clang regardless of C++ dialect.
#define _LIBCPP_BEGIN_NAMESPACE_STD namespace std {inline namespace _LIBCPP_NAMESPACE {
#define _LIBCPP_END_NAMESPACE_STD  } }
#define _VSTD std::_LIBCPP_NAMESPACE

namespace std {
  inline namespace _LIBCPP_NAMESPACE {
  }
}

#elif defined(__GNUC__)
# 349 "/usr/include/c++/v1/__config" 3

#define _ALIGNAS(x) __attribute__((__aligned__(x)))
#define _ALIGNAS_TYPE(x) __attribute__((__aligned__(__alignof(x))))

#define _LIBCPP_NORETURN __attribute__((noreturn))

#if !__EXCEPTIONS
#define _LIBCPP_NO_EXCEPTIONS
#endif
# 358 "/usr/include/c++/v1/__config" 3

#define _LIBCPP_HAS_NO_TEMPLATE_ALIASES
#define _LIBCPP_HAS_NO_CONSTEXPR

#define _NOEXCEPT throw()
#define _NOEXCEPT_(x)

#ifndef __GXX_EXPERIMENTAL_CXX0X__

#define _LIBCPP_HAS_NO_ADVANCED_SFINAE
#define _LIBCPP_HAS_NO_DECLTYPE
#define _LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS
#define _LIBCPP_HAS_NO_DELETED_FUNCTIONS
#define _LIBCPP_HAS_NO_NULLPTR
#define _LIBCPP_HAS_NO_STATIC_ASSERT
#define _LIBCPP_HAS_NO_UNICODE_CHARS
#define _LIBCPP_HAS_NO_VARIADICS
#define _LIBCPP_HAS_NO_RVALUE_REFERENCES
#define _LIBCPP_HAS_NO_ALWAYS_INLINE_VARIADICS

#else  // __GXX_EXPERIMENTAL_CXX0X__
# 379 "/usr/include/c++/v1/__config" 3

#define _LIBCPP_HAS_NO_TRAILING_RETURN
#define _LIBCPP_HAS_NO_ALWAYS_INLINE_VARIADICS

#if _GNUC_VER < 403
#define _LIBCPP_HAS_NO_RVALUE_REFERENCES
#endif
# 386 "/usr/include/c++/v1/__config" 3

#if _GNUC_VER < 403
#define _LIBCPP_HAS_NO_STATIC_ASSERT
#endif
# 390 "/usr/include/c++/v1/__config" 3

#if _GNUC_VER < 404
#define _LIBCPP_HAS_NO_ADVANCED_SFINAE
#define _LIBCPP_HAS_NO_DECLTYPE
#define _LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS
#define _LIBCPP_HAS_NO_DELETED_FUNCTIONS
#define _LIBCPP_HAS_NO_UNICODE_CHARS
#define _LIBCPP_HAS_NO_VARIADICS
#define _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
#endif  // _GNUC_VER < 404
# 400 "/usr/include/c++/v1/__config" 3

#if _GNUC_VER < 406
#define _LIBCPP_HAS_NO_NULLPTR
#endif
# 404 "/usr/include/c++/v1/__config" 3

#endif  // __GXX_EXPERIMENTAL_CXX0X__
# 406 "/usr/include/c++/v1/__config" 3

#define _LIBCPP_BEGIN_NAMESPACE_STD namespace std { namespace _LIBCPP_NAMESPACE {
#define _LIBCPP_END_NAMESPACE_STD  } }
#define _VSTD std::_LIBCPP_NAMESPACE

namespace std {
namespace _LIBCPP_NAMESPACE {
}
using namespace _LIBCPP_NAMESPACE __attribute__((__strong__));
}

#elif defined(_LIBCPP_MSVC)
# 418 "/usr/include/c++/v1/__config" 3

#define _LIBCPP_HAS_NO_TEMPLATE_ALIASES
#define _LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER
#define _LIBCPP_HAS_NO_CONSTEXPR
#define _LIBCPP_HAS_NO_UNICODE_CHARS
#define _LIBCPP_HAS_NO_DELETED_FUNCTIONS
#define _LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS
#define __alignof__ __alignof
#define _LIBCPP_NORETURN __declspec(noreturn)
#define _ALIGNAS(x) __declspec(align(x))
#define _LIBCPP_HAS_NO_VARIADICS

#define _NOEXCEPT throw()
#define _NOEXCEPT_(x)

#define _LIBCPP_BEGIN_NAMESPACE_STD namespace std {
#define _LIBCPP_END_NAMESPACE_STD  }
#define _VSTD std

#  define _LIBCPP_WEAK
namespace std {
}

#elif defined(__IBMCPP__)
# 442 "/usr/include/c++/v1/__config" 3

#define _ALIGNAS(x) __attribute__((__aligned__(x)))
#define _ALIGNAS_TYPE(x) __attribute__((__aligned__(__alignof(x))))
#define _ATTRIBUTE(x) __attribute__((x))
#define _LIBCPP_NORETURN __attribute__((noreturn))

#define _NOEXCEPT throw()
#define _NOEXCEPT_(x)

#define _LIBCPP_HAS_NO_TEMPLATE_ALIASES
#define _LIBCPP_HAS_NO_ADVANCED_SFINAE
#define _LIBCPP_HAS_NO_ALWAYS_INLINE_VARIADICS
#define _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
#define _LIBCPP_HAS_NO_NULLPTR
#define _LIBCPP_HAS_NO_UNICODE_CHARS
#define _LIBCPP_HAS_NO_STRONG_ENUMS
#define _LIBCPP_HAS_IS_BASE_OF

#if defined(_AIX)
#define __MULTILOCALE_API
#endif
# 463 "/usr/include/c++/v1/__config" 3

#define _LIBCPP_BEGIN_NAMESPACE_STD namespace std {inline namespace _LIBCPP_NAMESPACE {
#define _LIBCPP_END_NAMESPACE_STD  } }
#define _VSTD std::_LIBCPP_NAMESPACE

namespace std {
  inline namespace _LIBCPP_NAMESPACE {
  }
}

#endif // __clang__ || __GNUC___ || _MSC_VER || __IBMCPP__
# 474 "/usr/include/c++/v1/__config" 3

#ifdef _LIBCPP_HAS_NO_UNICODE_CHARS
typedef unsigned short char16_t;
typedef unsigned int   char32_t;
#endif  // _LIBCPP_HAS_NO_UNICODE_CHARS
# 479 "/usr/include/c++/v1/__config" 3

#ifdef _LIBCPP_HAS_NO_STATIC_ASSERT

template <bool> struct __static_assert_test;
template <> struct __static_assert_test<true> {};
template <unsigned> struct __static_assert_check {};
#define static_assert(__b, __m) \
    typedef __static_assert_check<sizeof(__static_assert_test<(__b)>)> \
    _LIBCPP_CONCAT(__t, __LINE__)

#endif  // _LIBCPP_HAS_NO_STATIC_ASSERT
# 490 "/usr/include/c++/v1/__config" 3

#ifdef _LIBCPP_HAS_NO_DECLTYPE
#define decltype(x) __typeof__(x)
#endif
# 494 "/usr/include/c++/v1/__config" 3

#ifdef _LIBCPP_HAS_NO_CONSTEXPR
#define _LIBCPP_CONSTEXPR
#else
# 498 "/usr/include/c++/v1/__config" 3
#define _LIBCPP_CONSTEXPR constexpr
#endif
# 500 "/usr/include/c++/v1/__config" 3

#ifdef _LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS
#define _LIBCPP_DEFAULT {}
#else
# 504 "/usr/include/c++/v1/__config" 3
#define _LIBCPP_DEFAULT = default;
#endif
# 506 "/usr/include/c++/v1/__config" 3

#ifdef __GNUC__
#define _NOALIAS __attribute__((__malloc__))
#else
# 510 "/usr/include/c++/v1/__config" 3
#define _NOALIAS
#endif
# 512 "/usr/include/c++/v1/__config" 3

#ifndef __has_feature
#define __has_feature(__x) 0
#endif
# 516 "/usr/include/c++/v1/__config" 3

#if __has_feature(cxx_explicit_conversions)
#   define _LIBCPP_EXPLICIT explicit
#else
# 520 "/usr/include/c++/v1/__config" 3
#   define _LIBCPP_EXPLICIT
#endif
# 522 "/usr/include/c++/v1/__config" 3

#ifdef _LIBCPP_HAS_NO_STRONG_ENUMS
#define _LIBCPP_DECLARE_STRONG_ENUM(x) struct _LIBCPP_TYPE_VIS x { enum __lx
#define _LIBCPP_DECLARE_STRONG_ENUM_EPILOG(x) \
    __lx __v_; \
    _LIBCPP_ALWAYS_INLINE x(__lx __v) : __v_(__v) {} \
    _LIBCPP_ALWAYS_INLINE explicit x(int __v) : __v_(static_cast<__lx>(__v)) {} \
    _LIBCPP_ALWAYS_INLINE operator int() const {return __v_;} \
    };
#else  // _LIBCPP_HAS_NO_STRONG_ENUMS
# 532 "/usr/include/c++/v1/__config" 3
#define _LIBCPP_DECLARE_STRONG_ENUM(x) enum class _LIBCPP_TYPE_VIS x
#define _LIBCPP_DECLARE_STRONG_ENUM_EPILOG(x)
#endif  // _LIBCPP_HAS_NO_STRONG_ENUMS
# 535 "/usr/include/c++/v1/__config" 3

#ifdef _LIBCPP_DEBUG
#   if _LIBCPP_DEBUG == 0
#       define _LIBCPP_DEBUG_LEVEL 1
#   elif _LIBCPP_DEBUG == 1
# 540 "/usr/include/c++/v1/__config" 3
#       define _LIBCPP_DEBUG_LEVEL 2
#   else
# 542 "/usr/include/c++/v1/__config" 3
#       error Supported values for _LIBCPP_DEBUG are 0 and 1
#   endif
# 544 "/usr/include/c++/v1/__config" 3
#   define _LIBCPP_EXTERN_TEMPLATE(...)
#endif
# 546 "/usr/include/c++/v1/__config" 3

#ifndef _LIBCPP_EXTERN_TEMPLATE
#define _LIBCPP_EXTERN_TEMPLATE(...)
#endif
# 550 "/usr/include/c++/v1/__config" 3

#ifndef _LIBCPP_EXTERN_TEMPLATE2
#define _LIBCPP_EXTERN_TEMPLATE2(...) extern template __VA_ARGS__;
#endif
# 554 "/usr/include/c++/v1/__config" 3

#if defined(__APPLE__) || defined(__FreeBSD__) || defined(_WIN32) || defined(__sun__) || defined(__NetBSD__)
#define _LIBCPP_LOCALE__L_EXTENSIONS 1
#endif
# 558 "/usr/include/c++/v1/__config" 3
#ifdef __FreeBSD__
#define _DECLARE_C99_LDBL_MATH 1
#endif
# 561 "/usr/include/c++/v1/__config" 3

#if defined(__APPLE__) || defined(__FreeBSD__)
#define _LIBCPP_HAS_DEFAULTRUNELOCALE
#endif
# 565 "/usr/include/c++/v1/__config" 3

#if defined(__APPLE__) || defined(__FreeBSD__) || defined(__sun__)
#define _LIBCPP_WCTYPE_IS_MASK
#endif
# 569 "/usr/include/c++/v1/__config" 3

#if defined(__APPLE__) || defined(__FreeBSD__)
#ifndef _LIBCPP_TRIVIAL_PAIR_COPY_CTOR
#  define _LIBCPP_TRIVIAL_PAIR_COPY_CTOR 0
#endif
# 574 "/usr/include/c++/v1/__config" 3
#endif
# 575 "/usr/include/c++/v1/__config" 3

#ifndef _LIBCPP_TRIVIAL_PAIR_COPY_CTOR
#  define _LIBCPP_TRIVIAL_PAIR_COPY_CTOR 1
#endif
# 579 "/usr/include/c++/v1/__config" 3

#ifndef _LIBCPP_STD_VER
#  if  __cplusplus <= 201103L
#    define _LIBCPP_STD_VER 11
#  else
# 584 "/usr/include/c++/v1/__config" 3
#    define _LIBCPP_STD_VER 13  // current year, or date of c++14 ratification
#  endif
# 586 "/usr/include/c++/v1/__config" 3
#endif  // _LIBCPP_STD_VER
# 587 "/usr/include/c++/v1/__config" 3

#if _LIBCPP_STD_VER > 11
#define _LIBCPP_DEPRECATED [[deprecated]]
#else
# 591 "/usr/include/c++/v1/__config" 3
#define _LIBCPP_DEPRECATED
#endif
# 593 "/usr/include/c++/v1/__config" 3

#if _LIBCPP_STD_VER <= 11
#define _LIBCPP_CONSTEXPR_AFTER_CXX11
#define _LIBCPP_EXPLICIT_AFTER_CXX11
#define _LIBCPP_DEPRECATED_AFTER_CXX11
#else
# 599 "/usr/include/c++/v1/__config" 3
#define _LIBCPP_CONSTEXPR_AFTER_CXX11 constexpr
#define _LIBCPP_EXPLICIT_AFTER_CXX11 explicit
#define _LIBCPP_DEPRECATED_AFTER_CXX11 [[deprecated]]
#endif
# 603 "/usr/include/c++/v1/__config" 3

// Try to find out if RTTI is disabled.
// g++ and cl.exe have RTTI on by default and define a macro when it is.
// g++ only defines the macro in 4.3.2 and onwards.
#if !defined(_LIBCPP_NO_RTTI)
#  if defined(__GNUG__) && (__GNUC__ >= 4 && \
   (__GNUC_MINOR__ >= 3 || __GNUC_PATCHLEVEL__ >= 2)) && !defined(__GXX_RTTI)
#    define _LIBCPP_NO_RTTI
#  elif (defined(_MSC_VER) && !defined(__clang__)) && !defined(_CPPRTTI)
# 612 "/usr/include/c++/v1/__config" 3
#    define _LIBCPP_NO_RTTI
#  endif
# 614 "/usr/include/c++/v1/__config" 3
#endif
# 615 "/usr/include/c++/v1/__config" 3

#ifndef _LIBCPP_WEAK
#  define _LIBCPP_WEAK __attribute__((__weak__))
#endif
# 619 "/usr/include/c++/v1/__config" 3

#endif  // _LIBCPP_CONFIG
# 621 "/usr/include/c++/v1/__config" 3
# 182 "/usr/include/c++/v1/locale" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <__locale>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/__locale" 1 3
// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP___LOCALE
#define _LIBCPP___LOCALE

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 15 "/usr/include/c++/v1/__locale" 3
#if 0 /* expanded by -frewrite-includes */
#include <string>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/string" 1 3
// -*- C++ -*-
//===--------------------------- string -----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is distributed under the University of Illinois Open Source
// License. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_STRING
#define _LIBCPP_STRING

/*
    string synopsis

namespace std
{

template <class stateT>
class fpos
{
private:
    stateT st;
public:
    fpos(streamoff = streamoff());

    operator streamoff() const;

    stateT state() const;
    void state(stateT);

    fpos& operator+=(streamoff);
    fpos  operator+ (streamoff) const;
    fpos& operator-=(streamoff);
    fpos  operator- (streamoff) const;
};

template <class stateT> streamoff operator-(const fpos<stateT>& x, const fpos<stateT>& y);

template <class stateT> bool operator==(const fpos<stateT>& x, const fpos<stateT>& y);
template <class stateT> bool operator!=(const fpos<stateT>& x, const fpos<stateT>& y);

template <class charT>
struct char_traits
{
    typedef charT     char_type;
    typedef ...       int_type;
    typedef streamoff off_type;
    typedef streampos pos_type;
    typedef mbstate_t state_type;

    static void assign(char_type& c1, const char_type& c2) noexcept;
    static constexpr bool eq(char_type c1, char_type c2) noexcept;
    static constexpr bool lt(char_type c1, char_type c2) noexcept;

    static int              compare(const char_type* s1, const char_type* s2, size_t n);
    static size_t           length(const char_type* s);
    static const char_type* find(const char_type* s, size_t n, const char_type& a);
    static char_type*       move(char_type* s1, const char_type* s2, size_t n);
    static char_type*       copy(char_type* s1, const char_type* s2, size_t n);
    static char_type*       assign(char_type* s, size_t n, char_type a);

    static constexpr int_type  not_eof(int_type c) noexcept;
    static constexpr char_type to_char_type(int_type c) noexcept;
    static constexpr int_type  to_int_type(char_type c) noexcept;
    static constexpr bool      eq_int_type(int_type c1, int_type c2) noexcept;
    static constexpr int_type  eof() noexcept;
};

template <> struct char_traits<char>;
template <> struct char_traits<wchar_t>;

template<class charT, class traits = char_traits<charT>, class Allocator = allocator<charT> >
class basic_string
{
public:
// types:
    typedef traits traits_type;
    typedef typename traits_type::char_type value_type;
    typedef Allocator allocator_type;
    typedef typename allocator_type::size_type size_type;
    typedef typename allocator_type::difference_type difference_type;
    typedef typename allocator_type::reference reference;
    typedef typename allocator_type::const_reference const_reference;
    typedef typename allocator_type::pointer pointer;
    typedef typename allocator_type::const_pointer const_pointer;
    typedef implementation-defined iterator;
    typedef implementation-defined const_iterator;
    typedef std::reverse_iterator<iterator> reverse_iterator;
    typedef std::reverse_iterator<const_iterator> const_reverse_iterator;

    static const size_type npos = -1;

    basic_string()
        noexcept(is_nothrow_default_constructible<allocator_type>::value);
    explicit basic_string(const allocator_type& a);
    basic_string(const basic_string& str);
    basic_string(basic_string&& str)
        noexcept(is_nothrow_move_constructible<allocator_type>::value);
    basic_string(const basic_string& str, size_type pos, size_type n = npos,
                 const allocator_type& a = allocator_type());
    basic_string(const value_type* s, const allocator_type& a = allocator_type());
    basic_string(const value_type* s, size_type n, const allocator_type& a = allocator_type());
    basic_string(size_type n, value_type c, const allocator_type& a = allocator_type());
    template<class InputIterator>
        basic_string(InputIterator begin, InputIterator end,
                     const allocator_type& a = allocator_type());
    basic_string(initializer_list<value_type>, const Allocator& = Allocator());
    basic_string(const basic_string&, const Allocator&);
    basic_string(basic_string&&, const Allocator&);

    ~basic_string();

    basic_string& operator=(const basic_string& str);
    basic_string& operator=(basic_string&& str)
        noexcept(
             allocator_type::propagate_on_container_move_assignment::value &&
             is_nothrow_move_assignable<allocator_type>::value);
    basic_string& operator=(const value_type* s);
    basic_string& operator=(value_type c);
    basic_string& operator=(initializer_list<value_type>);

    iterator       begin() noexcept;
    const_iterator begin() const noexcept;
    iterator       end() noexcept;
    const_iterator end() const noexcept;

    reverse_iterator       rbegin() noexcept;
    const_reverse_iterator rbegin() const noexcept;
    reverse_iterator       rend() noexcept;
    const_reverse_iterator rend() const noexcept;

    const_iterator         cbegin() const noexcept;
    const_iterator         cend() const noexcept;
    const_reverse_iterator crbegin() const noexcept;
    const_reverse_iterator crend() const noexcept;

    size_type size() const noexcept;
    size_type length() const noexcept;
    size_type max_size() const noexcept;
    size_type capacity() const noexcept;

    void resize(size_type n, value_type c);
    void resize(size_type n);

    void reserve(size_type res_arg = 0);
    void shrink_to_fit();
    void clear() noexcept;
    bool empty() const noexcept;

    const_reference operator[](size_type pos) const;
    reference       operator[](size_type pos);

    const_reference at(size_type n) const;
    reference       at(size_type n);

    basic_string& operator+=(const basic_string& str);
    basic_string& operator+=(const value_type* s);
    basic_string& operator+=(value_type c);
    basic_string& operator+=(initializer_list<value_type>);

    basic_string& append(const basic_string& str);
    basic_string& append(const basic_string& str, size_type pos, size_type n);
    basic_string& append(const value_type* s, size_type n);
    basic_string& append(const value_type* s);
    basic_string& append(size_type n, value_type c);
    template<class InputIterator>
        basic_string& append(InputIterator first, InputIterator last);
    basic_string& append(initializer_list<value_type>);

    void push_back(value_type c);
    void pop_back();
    reference       front();
    const_reference front() const;
    reference       back();
    const_reference back() const;

    basic_string& assign(const basic_string& str);
    basic_string& assign(basic_string&& str);
    basic_string& assign(const basic_string& str, size_type pos, size_type n);
    basic_string& assign(const value_type* s, size_type n);
    basic_string& assign(const value_type* s);
    basic_string& assign(size_type n, value_type c);
    template<class InputIterator>
        basic_string& assign(InputIterator first, InputIterator last);
    basic_string& assign(initializer_list<value_type>);

    basic_string& insert(size_type pos1, const basic_string& str);
    basic_string& insert(size_type pos1, const basic_string& str,
                         size_type pos2, size_type n);
    basic_string& insert(size_type pos, const value_type* s, size_type n);
    basic_string& insert(size_type pos, const value_type* s);
    basic_string& insert(size_type pos, size_type n, value_type c);
    iterator      insert(const_iterator p, value_type c);
    iterator      insert(const_iterator p, size_type n, value_type c);
    template<class InputIterator>
        iterator insert(const_iterator p, InputIterator first, InputIterator last);
    iterator      insert(const_iterator p, initializer_list<value_type>);

    basic_string& erase(size_type pos = 0, size_type n = npos);
    iterator      erase(const_iterator position);
    iterator      erase(const_iterator first, const_iterator last);

    basic_string& replace(size_type pos1, size_type n1, const basic_string& str);
    basic_string& replace(size_type pos1, size_type n1, const basic_string& str,
                          size_type pos2, size_type n2);
    basic_string& replace(size_type pos, size_type n1, const value_type* s, size_type n2);
    basic_string& replace(size_type pos, size_type n1, const value_type* s);
    basic_string& replace(size_type pos, size_type n1, size_type n2, value_type c);
    basic_string& replace(const_iterator i1, const_iterator i2, const basic_string& str);
    basic_string& replace(const_iterator i1, const_iterator i2, const value_type* s, size_type n);
    basic_string& replace(const_iterator i1, const_iterator i2, const value_type* s);
    basic_string& replace(const_iterator i1, const_iterator i2, size_type n, value_type c);
    template<class InputIterator>
        basic_string& replace(const_iterator i1, const_iterator i2, InputIterator j1, InputIterator j2);
    basic_string& replace(const_iterator i1, const_iterator i2, initializer_list<value_type>);

    size_type copy(value_type* s, size_type n, size_type pos = 0) const;
    basic_string substr(size_type pos = 0, size_type n = npos) const;

    void swap(basic_string& str)
        noexcept(!allocator_type::propagate_on_container_swap::value ||
                 __is_nothrow_swappable<allocator_type>::value)

    const value_type* c_str() const noexcept;
    const value_type* data() const noexcept;

    allocator_type get_allocator() const noexcept;

    size_type find(const basic_string& str, size_type pos = 0) const noexcept;
    size_type find(const value_type* s, size_type pos, size_type n) const noexcept;
    size_type find(const value_type* s, size_type pos = 0) const noexcept;
    size_type find(value_type c, size_type pos = 0) const noexcept;

    size_type rfind(const basic_string& str, size_type pos = npos) const noexcept;
    size_type rfind(const value_type* s, size_type pos, size_type n) const noexcept;
    size_type rfind(const value_type* s, size_type pos = npos) const noexcept;
    size_type rfind(value_type c, size_type pos = npos) const noexcept;

    size_type find_first_of(const basic_string& str, size_type pos = 0) const noexcept;
    size_type find_first_of(const value_type* s, size_type pos, size_type n) const noexcept;
    size_type find_first_of(const value_type* s, size_type pos = 0) const noexcept;
    size_type find_first_of(value_type c, size_type pos = 0) const noexcept;

    size_type find_last_of(const basic_string& str, size_type pos = npos) const noexcept;
    size_type find_last_of(const value_type* s, size_type pos, size_type n) const noexcept;
    size_type find_last_of(const value_type* s, size_type pos = npos) const noexcept;
    size_type find_last_of(value_type c, size_type pos = npos) const noexcept;

    size_type find_first_not_of(const basic_string& str, size_type pos = 0) const noexcept;
    size_type find_first_not_of(const value_type* s, size_type pos, size_type n) const noexcept;
    size_type find_first_not_of(const value_type* s, size_type pos = 0) const noexcept;
    size_type find_first_not_of(value_type c, size_type pos = 0) const noexcept;

    size_type find_last_not_of(const basic_string& str, size_type pos = npos) const noexcept;
    size_type find_last_not_of(const value_type* s, size_type pos, size_type n) const noexcept;
    size_type find_last_not_of(const value_type* s, size_type pos = npos) const noexcept;
    size_type find_last_not_of(value_type c, size_type pos = npos) const noexcept;

    int compare(const basic_string& str) const noexcept;
    int compare(size_type pos1, size_type n1, const basic_string& str) const;
    int compare(size_type pos1, size_type n1, const basic_string& str,
                size_type pos2, size_type n2) const;
    int compare(const value_type* s) const noexcept;
    int compare(size_type pos1, size_type n1, const value_type* s) const;
    int compare(size_type pos1, size_type n1, const value_type* s, size_type n2) const;

    bool __invariants() const;
};

template<class charT, class traits, class Allocator>
basic_string<charT, traits, Allocator>
operator+(const basic_string<charT, traits, Allocator>& lhs,
          const basic_string<charT, traits, Allocator>& rhs);

template<class charT, class traits, class Allocator>
basic_string<charT, traits, Allocator>
operator+(const charT* lhs , const basic_string<charT,traits,Allocator>&rhs);

template<class charT, class traits, class Allocator>
basic_string<charT, traits, Allocator>
operator+(charT lhs, const basic_string<charT,traits,Allocator>& rhs);

template<class charT, class traits, class Allocator>
basic_string<charT, traits, Allocator>
operator+(const basic_string<charT, traits, Allocator>& lhs, const charT* rhs);

template<class charT, class traits, class Allocator>
basic_string<charT, traits, Allocator>
operator+(const basic_string<charT, traits, Allocator>& lhs, charT rhs);

template<class charT, class traits, class Allocator>
bool operator==(const basic_string<charT, traits, Allocator>& lhs,
                const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator==(const charT* lhs, const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator==(const basic_string<charT,traits,Allocator>& lhs, const charT* rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator!=(const basic_string<charT,traits,Allocator>& lhs,
                const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator!=(const charT* lhs, const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator!=(const basic_string<charT, traits, Allocator>& lhs, const charT* rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator< (const basic_string<charT, traits, Allocator>& lhs,
                const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator< (const basic_string<charT, traits, Allocator>& lhs, const charT* rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator< (const charT* lhs, const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator> (const basic_string<charT, traits, Allocator>& lhs,
                const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator> (const basic_string<charT, traits, Allocator>& lhs, const charT* rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator> (const charT* lhs, const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator<=(const basic_string<charT, traits, Allocator>& lhs,
                const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator<=(const basic_string<charT, traits, Allocator>& lhs, const charT* rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator<=(const charT* lhs, const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator>=(const basic_string<charT, traits, Allocator>& lhs,
                const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator>=(const basic_string<charT, traits, Allocator>& lhs, const charT* rhs) noexcept;

template<class charT, class traits, class Allocator>
bool operator>=(const charT* lhs, const basic_string<charT, traits, Allocator>& rhs) noexcept;

template<class charT, class traits, class Allocator>
void swap(basic_string<charT, traits, Allocator>& lhs,
          basic_string<charT, traits, Allocator>& rhs)
            noexcept(noexcept(lhs.swap(rhs)));

template<class charT, class traits, class Allocator>
basic_istream<charT, traits>&
operator>>(basic_istream<charT, traits>& is, basic_string<charT, traits, Allocator>& str);

template<class charT, class traits, class Allocator>
basic_ostream<charT, traits>&
operator<<(basic_ostream<charT, traits>& os, const basic_string<charT, traits, Allocator>& str);

template<class charT, class traits, class Allocator>
basic_istream<charT, traits>&
getline(basic_istream<charT, traits>& is, basic_string<charT, traits, Allocator>& str,
        charT delim);

template<class charT, class traits, class Allocator>
basic_istream<charT, traits>&
getline(basic_istream<charT, traits>& is, basic_string<charT, traits, Allocator>& str);

typedef basic_string<char>    string;
typedef basic_string<wchar_t> wstring;
typedef basic_string<char16_t> u16string;
typedef basic_string<char32_t> u32string;

int                stoi  (const string& str, size_t* idx = 0, int base = 10);
long               stol  (const string& str, size_t* idx = 0, int base = 10);
unsigned long      stoul (const string& str, size_t* idx = 0, int base = 10);
long long          stoll (const string& str, size_t* idx = 0, int base = 10);
unsigned long long stoull(const string& str, size_t* idx = 0, int base = 10);

float       stof (const string& str, size_t* idx = 0);
double      stod (const string& str, size_t* idx = 0);
long double stold(const string& str, size_t* idx = 0);

string to_string(int val);
string to_string(unsigned val);
string to_string(long val);
string to_string(unsigned long val);
string to_string(long long val);
string to_string(unsigned long long val);
string to_string(float val);
string to_string(double val);
string to_string(long double val);

int                stoi  (const wstring& str, size_t* idx = 0, int base = 10);
long               stol  (const wstring& str, size_t* idx = 0, int base = 10);
unsigned long      stoul (const wstring& str, size_t* idx = 0, int base = 10);
long long          stoll (const wstring& str, size_t* idx = 0, int base = 10);
unsigned long long stoull(const wstring& str, size_t* idx = 0, int base = 10);

float       stof (const wstring& str, size_t* idx = 0);
double      stod (const wstring& str, size_t* idx = 0);
long double stold(const wstring& str, size_t* idx = 0);

wstring to_wstring(int val);
wstring to_wstring(unsigned val);
wstring to_wstring(long val);
wstring to_wstring(unsigned long val);
wstring to_wstring(long long val);
wstring to_wstring(unsigned long long val);
wstring to_wstring(float val);
wstring to_wstring(double val);
wstring to_wstring(long double val);

template <> struct hash<string>;
template <> struct hash<u16string>;
template <> struct hash<u32string>;
template <> struct hash<wstring>;

basic_string<char>     operator "" s( const char *str,     size_t len ); // C++14
basic_string<wchar_t>  operator "" s( const wchar_t *str,  size_t len ); // C++14
basic_string<char16_t> operator "" s( const char16_t *str, size_t len ); // C++14
basic_string<char32_t> operator "" s( const char32_t *str, size_t len ); // C++14

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 435 "/usr/include/c++/v1/string" 3
#if 0 /* expanded by -frewrite-includes */
#include <iosfwd>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/iosfwd" 1 3
// -*- C++ -*-
//===--------------------------- iosfwd -----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_IOSFWD
#define _LIBCPP_IOSFWD

/*
    iosfwd synopsis

namespace std
{

template<class charT> struct char_traits;
template<class T>     class allocator;

class ios_base;
template <class charT, class traits = char_traits<charT> > class basic_ios;

template <class charT, class traits = char_traits<charT> > class basic_streambuf;
template <class charT, class traits = char_traits<charT> > class basic_istream;
template <class charT, class traits = char_traits<charT> > class basic_ostream;
template <class charT, class traits = char_traits<charT> > class basic_iostream;

template <class charT, class traits = char_traits<charT>, class Allocator = allocator<charT> >
    class basic_stringbuf;
template <class charT, class traits = char_traits<charT>, class Allocator = allocator<charT> >
    class basic_istringstream;
template <class charT, class traits = char_traits<charT>, class Allocator = allocator<charT> >
    class basic_ostringstream;
template <class charT, class traits = char_traits<charT>, class Allocator = allocator<charT> >
    class basic_stringstream;

template <class charT, class traits = char_traits<charT> > class basic_filebuf;
template <class charT, class traits = char_traits<charT> > class basic_ifstream;
template <class charT, class traits = char_traits<charT> > class basic_ofstream;
template <class charT, class traits = char_traits<charT> > class basic_fstream;

template <class charT, class traits = char_traits<charT> > class istreambuf_iterator;
template <class charT, class traits = char_traits<charT> > class ostreambuf_iterator;

typedef basic_ios<char>              ios;
typedef basic_ios<wchar_t>           wios;

typedef basic_streambuf<char>        streambuf;
typedef basic_istream<char>          istream;
typedef basic_ostream<char>          ostream;
typedef basic_iostream<char>         iostream;

typedef basic_stringbuf<char>        stringbuf;
typedef basic_istringstream<char>    istringstream;
typedef basic_ostringstream<char>    ostringstream;
typedef basic_stringstream<char>     stringstream;

typedef basic_filebuf<char>          filebuf;
typedef basic_ifstream<char>         ifstream;
typedef basic_ofstream<char>         ofstream;
typedef basic_fstream<char>          fstream;

typedef basic_streambuf<wchar_t>     wstreambuf;
typedef basic_istream<wchar_t>       wistream;
typedef basic_ostream<wchar_t>       wostream;
typedef basic_iostream<wchar_t>      wiostream;

typedef basic_stringbuf<wchar_t>     wstringbuf;
typedef basic_istringstream<wchar_t> wistringstream;
typedef basic_ostringstream<wchar_t> wostringstream;
typedef basic_stringstream<wchar_t>  wstringstream;

typedef basic_filebuf<wchar_t>       wfilebuf;
typedef basic_ifstream<wchar_t>      wifstream;
typedef basic_ofstream<wchar_t>      wofstream;
typedef basic_fstream<wchar_t>       wfstream;

template <class state> class fpos;
typedef fpos<char_traits<char>::state_type>    streampos;
typedef fpos<char_traits<wchar_t>::state_type> wstreampos;

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 90 "/usr/include/c++/v1/iosfwd" 3
#if 0 /* expanded by -frewrite-includes */
#include <wchar.h>  // for mbstate_t
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/wchar.h" 1 3 4
/*-
 * Copyright (c)1999 Citrus Project,
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/include/wchar.h 265878 2014-05-11 13:48:21Z jilles $
 */

/*-
 * Copyright (c) 1999, 2000 The NetBSD Foundation, Inc.
 * All rights reserved.
 *
 * This code is derived from software contributed to The NetBSD Foundation
 * by Julian Coleman.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 *	$NetBSD: wchar.h,v 1.8 2000/12/22 05:31:42 itojun Exp $
 */

#ifndef _WCHAR_H_
#define _WCHAR_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 64 "/usr/include/wchar.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_null.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/sys/_null.h" 1 3 4
/*-
 * Copyright (c) 2003 Marcel Moolenaar
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $FreeBSD: head/sys/sys/_null.h 228918 2011-12-27 21:36:31Z theraven $
 */

#ifndef NULL

#if !defined(__cplusplus)
#define	NULL	((void *)0)
#else
# 34 "/usr/include/sys/_null.h" 3 4
#if __cplusplus >= 201103L
#define	NULL	nullptr
#elif defined(__GNUG__) && defined(__GNUC__) && __GNUC__ >= 4
# 37 "/usr/include/sys/_null.h" 3 4
#define	NULL	__null
#else
# 39 "/usr/include/sys/_null.h" 3 4
#if defined(__LP64__)
#define	NULL	(0L)
#else
# 42 "/usr/include/sys/_null.h" 3 4
#define	NULL	0
#endif	/* __LP64__ */
# 44 "/usr/include/sys/_null.h" 3 4
#endif	/* __GNUG__ */
# 45 "/usr/include/sys/_null.h" 3 4
#endif	/* !__cplusplus */
# 46 "/usr/include/sys/_null.h" 3 4

#endif
# 48 "/usr/include/sys/_null.h" 3 4
# 65 "/usr/include/wchar.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 66 "/usr/include/wchar.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <machine/_limits.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/machine/_limits.h" 1 3 4
/*-
 * This file is in the public domain.
 */
/* $FreeBSD: head/sys/amd64/include/_limits.h 232262 2012-02-28 18:24:28Z tijl $ */

#if 0 /* expanded by -frewrite-includes */
#include <x86/_limits.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/x86/_limits.h" 1 3 4
/*-
 * Copyright (c) 1988, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)limits.h	8.3 (Berkeley) 1/4/94
 * $FreeBSD: head/sys/x86/include/_limits.h 235939 2012-05-24 21:44:46Z obrien $
 */

#ifndef	_MACHINE__LIMITS_H_
#define	_MACHINE__LIMITS_H_

/*
 * According to ANSI (section 2.2.4.2), the values below must be usable by
 * #if preprocessing directives.  Additionally, the expression must have the
 * same type as would an expression that is an object of the corresponding
 * type converted according to the integral promotions.  The subtraction for
 * INT_MIN, etc., is so the value is not unsigned; e.g., 0x80000000 is an
 * unsigned int for 32-bit two's complement ANSI compilers (section 3.1.3.2).
 */

#define	__CHAR_BIT	8		/* number of bits in a char */

#define	__SCHAR_MAX	0x7f		/* max value for a signed char */
#define	__SCHAR_MIN	(-0x7f - 1)	/* min value for a signed char */

#define	__UCHAR_MAX	0xff		/* max value for an unsigned char */

#define	__USHRT_MAX	0xffff		/* max value for an unsigned short */
#define	__SHRT_MAX	0x7fff		/* max value for a short */
#define	__SHRT_MIN	(-0x7fff - 1)	/* min value for a short */

#define	__UINT_MAX	0xffffffff	/* max value for an unsigned int */
#define	__INT_MAX	0x7fffffff	/* max value for an int */
#define	__INT_MIN	(-0x7fffffff - 1)	/* min value for an int */

#ifdef	__LP64__
#define	__ULONG_MAX	0xffffffffffffffff	/* max for an unsigned long */
#define	__LONG_MAX	0x7fffffffffffffff	/* max for a long */
#define	__LONG_MIN	(-0x7fffffffffffffff - 1) /* min for a long */
#else
# 65 "/usr/include/x86/_limits.h" 3 4
#define	__ULONG_MAX	0xffffffffUL
#define	__LONG_MAX	0x7fffffffL
#define	__LONG_MIN	(-0x7fffffffL - 1)
#endif
# 69 "/usr/include/x86/_limits.h" 3 4

			/* max value for an unsigned long long */
#define	__ULLONG_MAX	0xffffffffffffffffULL
#define	__LLONG_MAX	0x7fffffffffffffffLL	/* max value for a long long */
#define	__LLONG_MIN	(-0x7fffffffffffffffLL - 1)  /* min for a long long */

#ifdef	__LP64__
#define	__SSIZE_MAX	__LONG_MAX	/* max value for a ssize_t */
#define	__SIZE_T_MAX	__ULONG_MAX	/* max value for a size_t */
#define	__OFF_MAX	__LONG_MAX	/* max value for an off_t */
#define	__OFF_MIN	__LONG_MIN	/* min value for an off_t */
/* Quads and longs are the same on the amd64.  Ensure they stay in sync. */
#define	__UQUAD_MAX	__ULONG_MAX	/* max value for a uquad_t */
#define	__QUAD_MAX	__LONG_MAX	/* max value for a quad_t */
#define	__QUAD_MIN	__LONG_MIN	/* min value for a quad_t */
#define	__LONG_BIT	64
#else
# 86 "/usr/include/x86/_limits.h" 3 4
#define	__SSIZE_MAX	__INT_MAX
#define	__SIZE_T_MAX	__UINT_MAX
#define	__OFF_MAX	__LLONG_MAX
#define	__OFF_MIN	__LLONG_MIN
#define	__UQUAD_MAX	__ULLONG_MAX
#define	__QUAD_MAX	__LLONG_MAX
#define	__QUAD_MIN	__LLONG_MIN
#define	__LONG_BIT	32
#endif
# 95 "/usr/include/x86/_limits.h" 3 4

#define	__WORD_BIT	32

/* Minimum signal stack size. */
#define	__MINSIGSTKSZ	(512 * 4)

#endif /* !_MACHINE__LIMITS_H_ */
# 102 "/usr/include/x86/_limits.h" 3 4
# 7 "/usr/include/machine/_limits.h" 2 3 4
# 67 "/usr/include/wchar.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <_ctype.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/_ctype.h" 1 3 4
/*
 * Copyright (c) 1989, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * This code is derived from software contributed to Berkeley by
 * Paul Borman at Krystal Technologies.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * From @(#)ctype.h	8.4 (Berkeley) 1/21/94
 * From FreeBSD: src/include/ctype.h,v 1.27 2004/06/23 07:11:39 tjr Exp
 * $FreeBSD: head/include/_ctype.h 203964 2010-02-16 19:39:50Z imp $
 */

#ifndef __CTYPE_H_
#define	__CTYPE_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 46 "/usr/include/_ctype.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 47 "/usr/include/_ctype.h" 3 4

#define	_CTYPE_A	0x00000100L		/* Alpha */
#define	_CTYPE_C	0x00000200L		/* Control */
#define	_CTYPE_D	0x00000400L		/* Digit */
#define	_CTYPE_G	0x00000800L		/* Graph */
#define	_CTYPE_L	0x00001000L		/* Lower */
#define	_CTYPE_P	0x00002000L		/* Punct */
#define	_CTYPE_S	0x00004000L		/* Space */
#define	_CTYPE_U	0x00008000L		/* Upper */
#define	_CTYPE_X	0x00010000L		/* X digit */
#define	_CTYPE_B	0x00020000L		/* Blank */
#define	_CTYPE_R	0x00040000L		/* Print */
#define	_CTYPE_I	0x00080000L		/* Ideogram */
#define	_CTYPE_T	0x00100000L		/* Special */
#define	_CTYPE_Q	0x00200000L		/* Phonogram */
#define	_CTYPE_SW0	0x20000000L		/* 0 width character */
#define	_CTYPE_SW1	0x40000000L		/* 1 width character */
#define	_CTYPE_SW2	0x80000000L		/* 2 width character */
#define	_CTYPE_SW3	0xc0000000L		/* 3 width character */
#define	_CTYPE_SWM	0xe0000000L		/* Mask for screen width data */
#define	_CTYPE_SWS	30			/* Bits to shift to get width */

/* See comments in <sys/_types.h> about __ct_rune_t. */
__BEGIN_DECLS
unsigned long	___runetype(__ct_rune_t) __pure;
__ct_rune_t	___tolower(__ct_rune_t) __pure;
__ct_rune_t	___toupper(__ct_rune_t) __pure;
__END_DECLS

/*
 * _EXTERNALIZE_CTYPE_INLINES_ is defined in locale/nomacros.c to tell us
 * to generate code for extern versions of all our inline functions.
 */
#ifdef _EXTERNALIZE_CTYPE_INLINES_
#define	_USE_CTYPE_INLINE_
#define	static
#define	__inline
#endif
# 85 "/usr/include/_ctype.h" 3 4

extern int __mb_sb_limit;

/*
 * Use inline functions if we are allowed to and the compiler supports them.
 */
#if !defined(_DONT_USE_CTYPE_INLINE_) && \
    (defined(_USE_CTYPE_INLINE_) || defined(__GNUC__) || defined(__cplusplus))

#if 0 /* expanded by -frewrite-includes */
#include <runetype.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/runetype.h" 1 3 4
/*-
 * Copyright (c) 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * This code is derived from software contributed to Berkeley by
 * Paul Borman at Krystal Technologies.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)runetype.h	8.1 (Berkeley) 6/2/93
 * $FreeBSD: head/include/runetype.h 232620 2012-03-06 20:15:23Z dim $
 */

#ifndef	_RUNETYPE_H_
#define	_RUNETYPE_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 40 "/usr/include/runetype.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 41 "/usr/include/runetype.h" 3 4

#define	_CACHED_RUNES	(1 <<8 )	/* Must be a power of 2 */
#define	_CRMASK		(~(_CACHED_RUNES - 1))

/*
 * The lower 8 bits of runetype[] contain the digit value of the rune.
 */
typedef struct {
	__rune_t	__min;		/* First rune of the range */
	__rune_t	__max;		/* Last rune (inclusive) of the range */
	__rune_t	__map;		/* What first maps to in maps */
	unsigned long	*__types;	/* Array of types in range */
} _RuneEntry;

typedef struct {
	int		__nranges;	/* Number of ranges stored */
	_RuneEntry	*__ranges;	/* Pointer to the ranges */
} _RuneRange;

typedef struct {
	char		__magic[8];	/* Magic saying what version we are */
	char		__encoding[32];	/* ASCII name of this encoding */

	__rune_t	(*__sgetrune)(const char *, __size_t, char const **);
	int		(*__sputrune)(__rune_t, char *, __size_t, char **);
	__rune_t	__invalid_rune;

	unsigned long	__runetype[_CACHED_RUNES];
	__rune_t	__maplower[_CACHED_RUNES];
	__rune_t	__mapupper[_CACHED_RUNES];

	/*
	 * The following are to deal with Runes larger than _CACHED_RUNES - 1.
	 * Their data is actually contiguous with this structure so as to make
	 * it easier to read/write from/to disk.
	 */
	_RuneRange	__runetype_ext;
	_RuneRange	__maplower_ext;
	_RuneRange	__mapupper_ext;

	void		*__variable;	/* Data which depends on the encoding */
	int		__variable_len;	/* how long that data is */
} _RuneLocale;

#define	_RUNE_MAGIC_1	"RuneMagi"	/* Indicates version 0 of RuneLocale */
__BEGIN_DECLS
extern const _RuneLocale _DefaultRuneLocale;
extern const _RuneLocale *_CurrentRuneLocale;
#if defined(__NO_TLS) || defined(__RUNETYPE_INTERNAL)
extern const _RuneLocale *__getCurrentRuneLocale(void);
#else
# 92 "/usr/include/runetype.h" 3 4
extern _Thread_local const _RuneLocale *_ThreadRuneLocale;
static __inline const _RuneLocale *__getCurrentRuneLocale(void)
{

	if (_ThreadRuneLocale) 
		return _ThreadRuneLocale;
	if (_CurrentRuneLocale) 
		return _CurrentRuneLocale;
	return &_DefaultRuneLocale;
}
#endif /* __NO_TLS || __RUNETYPE_INTERNAL */
# 103 "/usr/include/runetype.h" 3 4
#define _CurrentRuneLocale (__getCurrentRuneLocale())
__END_DECLS

#endif	/* !_RUNETYPE_H_ */
# 107 "/usr/include/runetype.h" 3 4
# 95 "/usr/include/_ctype.h" 2 3 4

static __inline int
__maskrune(__ct_rune_t _c, unsigned long _f)
{
	return ((_c < 0 || _c >= _CACHED_RUNES) ? ___runetype(_c) :
		_CurrentRuneLocale->__runetype[_c]) & _f;
}

static __inline int
__sbmaskrune(__ct_rune_t _c, unsigned long _f)
{
	return (_c < 0 || _c >= __mb_sb_limit) ? 0 :
	       _CurrentRuneLocale->__runetype[_c] & _f;
}

static __inline int
__istype(__ct_rune_t _c, unsigned long _f)
{
	return (!!__maskrune(_c, _f));
}

static __inline int
__sbistype(__ct_rune_t _c, unsigned long _f)
{
	return (!!__sbmaskrune(_c, _f));
}

static __inline int
__isctype(__ct_rune_t _c, unsigned long _f)
{
	return (_c < 0 || _c >= 128) ? 0 :
	       !!(_DefaultRuneLocale.__runetype[_c] & _f);
}

static __inline __ct_rune_t
__toupper(__ct_rune_t _c)
{
	return (_c < 0 || _c >= _CACHED_RUNES) ? ___toupper(_c) :
	       _CurrentRuneLocale->__mapupper[_c];
}

static __inline __ct_rune_t
__sbtoupper(__ct_rune_t _c)
{
	return (_c < 0 || _c >= __mb_sb_limit) ? _c :
	       _CurrentRuneLocale->__mapupper[_c];
}

static __inline __ct_rune_t
__tolower(__ct_rune_t _c)
{
	return (_c < 0 || _c >= _CACHED_RUNES) ? ___tolower(_c) :
	       _CurrentRuneLocale->__maplower[_c];
}

static __inline __ct_rune_t
__sbtolower(__ct_rune_t _c)
{
	return (_c < 0 || _c >= __mb_sb_limit) ? _c :
	       _CurrentRuneLocale->__maplower[_c];
}

static __inline int
__wcwidth(__ct_rune_t _c)
{
	unsigned int _x;

	if (_c == 0)
		return (0);
	_x = (unsigned int)__maskrune(_c, _CTYPE_SWM|_CTYPE_R);
	if ((_x & _CTYPE_SWM) != 0)
		return ((_x & _CTYPE_SWM) >> _CTYPE_SWS);
	return ((_x & _CTYPE_R) != 0 ? 1 : -1);
}

#else /* not using inlines */
# 171 "/usr/include/_ctype.h" 3 4

__BEGIN_DECLS
int		__maskrune(__ct_rune_t, unsigned long);
int		__sbmaskrune(__ct_rune_t, unsigned long);
int		__istype(__ct_rune_t, unsigned long);
int		__sbistype(__ct_rune_t, unsigned long);
int		__isctype(__ct_rune_t, unsigned long);
__ct_rune_t	__toupper(__ct_rune_t);
__ct_rune_t	__sbtoupper(__ct_rune_t);
__ct_rune_t	__tolower(__ct_rune_t);
__ct_rune_t	__sbtolower(__ct_rune_t);
int		__wcwidth(__ct_rune_t);
__END_DECLS
#endif /* using inlines */
# 185 "/usr/include/_ctype.h" 3 4

#endif /* !__CTYPE_H_ */
# 187 "/usr/include/_ctype.h" 3 4
# 68 "/usr/include/wchar.h" 2 3 4

#ifndef _MBSTATE_T_DECLARED
typedef	__mbstate_t	mbstate_t;
#define	_MBSTATE_T_DECLARED
#endif
# 73 "/usr/include/wchar.h" 3 4

#ifndef _SIZE_T_DECLARED
typedef	__size_t	size_t;
#define	_SIZE_T_DECLARED
#endif
# 78 "/usr/include/wchar.h" 3 4

#ifndef	__cplusplus
#ifndef _WCHAR_T_DECLARED
typedef	___wchar_t	wchar_t;
#define	_WCHAR_T_DECLARED
#endif
# 84 "/usr/include/wchar.h" 3 4
#endif
# 85 "/usr/include/wchar.h" 3 4

#ifndef _WINT_T_DECLARED
typedef	__wint_t	wint_t;
#define	_WINT_T_DECLARED
#endif
# 90 "/usr/include/wchar.h" 3 4

#define	WCHAR_MIN	__WCHAR_MIN
#define	WCHAR_MAX	__WCHAR_MAX

#ifndef WEOF
#define	WEOF 	((wint_t)-1)
#endif
# 97 "/usr/include/wchar.h" 3 4

#ifndef _STDFILE_DECLARED
#define _STDFILE_DECLARED
typedef struct __sFILE FILE;
#endif
# 102 "/usr/include/wchar.h" 3 4
struct tm;

__BEGIN_DECLS
wint_t	btowc(int);
wint_t	fgetwc(FILE *);
wchar_t	*
	fgetws(wchar_t * __restrict, int, FILE * __restrict);
wint_t	fputwc(wchar_t, FILE *);
int	fputws(const wchar_t * __restrict, FILE * __restrict);
int	fwide(FILE *, int);
int	fwprintf(FILE * __restrict, const wchar_t * __restrict, ...);
int	fwscanf(FILE * __restrict, const wchar_t * __restrict, ...);
wint_t	getwc(FILE *);
wint_t	getwchar(void);
size_t	mbrlen(const char * __restrict, size_t, mbstate_t * __restrict);
size_t	mbrtowc(wchar_t * __restrict, const char * __restrict, size_t,
	    mbstate_t * __restrict);
int	mbsinit(const mbstate_t *);
size_t	mbsrtowcs(wchar_t * __restrict, const char ** __restrict, size_t,
	    mbstate_t * __restrict);
wint_t	putwc(wchar_t, FILE *);
wint_t	putwchar(wchar_t);
int	swprintf(wchar_t * __restrict, size_t n, const wchar_t * __restrict,
	    ...);
int	swscanf(const wchar_t * __restrict, const wchar_t * __restrict, ...);
wint_t	ungetwc(wint_t, FILE *);
int	vfwprintf(FILE * __restrict, const wchar_t * __restrict,
	    __va_list);
int	vswprintf(wchar_t * __restrict, size_t n, const wchar_t * __restrict,
	    __va_list);
int	vwprintf(const wchar_t * __restrict, __va_list);
size_t	wcrtomb(char * __restrict, wchar_t, mbstate_t * __restrict);
wchar_t	*wcscat(wchar_t * __restrict, const wchar_t * __restrict);
wchar_t	*wcschr(const wchar_t *, wchar_t) __pure;
int	wcscmp(const wchar_t *, const wchar_t *) __pure;
int	wcscoll(const wchar_t *, const wchar_t *);
wchar_t	*wcscpy(wchar_t * __restrict, const wchar_t * __restrict);
size_t	wcscspn(const wchar_t *, const wchar_t *) __pure;
size_t	wcsftime(wchar_t * __restrict, size_t, const wchar_t * __restrict,
	    const struct tm * __restrict);
size_t	wcslen(const wchar_t *) __pure;
wchar_t	*wcsncat(wchar_t * __restrict, const wchar_t * __restrict,
	    size_t);
int	wcsncmp(const wchar_t *, const wchar_t *, size_t) __pure;
wchar_t	*wcsncpy(wchar_t * __restrict , const wchar_t * __restrict, size_t);
wchar_t	*wcspbrk(const wchar_t *, const wchar_t *) __pure;
wchar_t	*wcsrchr(const wchar_t *, wchar_t) __pure;
size_t	wcsrtombs(char * __restrict, const wchar_t ** __restrict, size_t,
	    mbstate_t * __restrict);
size_t	wcsspn(const wchar_t *, const wchar_t *) __pure;
wchar_t	*wcsstr(const wchar_t * __restrict, const wchar_t * __restrict)
	    __pure;
size_t	wcsxfrm(wchar_t * __restrict, const wchar_t * __restrict, size_t);
int	wctob(wint_t);
double	wcstod(const wchar_t * __restrict, wchar_t ** __restrict);
wchar_t	*wcstok(wchar_t * __restrict, const wchar_t * __restrict,
	    wchar_t ** __restrict);
long	 wcstol(const wchar_t * __restrict, wchar_t ** __restrict, int);
unsigned long
	 wcstoul(const wchar_t * __restrict, wchar_t ** __restrict, int);
wchar_t	*wmemchr(const wchar_t *, wchar_t, size_t) __pure;
int	wmemcmp(const wchar_t *, const wchar_t *, size_t) __pure;
wchar_t	*wmemcpy(wchar_t * __restrict, const wchar_t * __restrict, size_t);
wchar_t	*wmemmove(wchar_t *, const wchar_t *, size_t);
wchar_t	*wmemset(wchar_t *, wchar_t, size_t);
int	wprintf(const wchar_t * __restrict, ...);
int	wscanf(const wchar_t * __restrict, ...);

#ifndef _STDSTREAM_DECLARED
extern FILE *__stdinp;
extern FILE *__stdoutp;
extern FILE *__stderrp;
#define	_STDSTREAM_DECLARED
#endif
# 176 "/usr/include/wchar.h" 3 4

#define	getwc(fp)	fgetwc(fp)
#define	getwchar()	fgetwc(__stdinp)
#define	putwc(wc, fp)	fputwc(wc, fp)
#define	putwchar(wc)	fputwc(wc, __stdoutp)

#if __ISO_C_VISIBLE >= 1999
int	vfwscanf(FILE * __restrict, const wchar_t * __restrict,
	    __va_list);
int	vswscanf(const wchar_t * __restrict, const wchar_t * __restrict,
	    __va_list);
int	vwscanf(const wchar_t * __restrict, __va_list);
float	wcstof(const wchar_t * __restrict, wchar_t ** __restrict);
long double
	wcstold(const wchar_t * __restrict, wchar_t ** __restrict);
#ifdef __LONG_LONG_SUPPORTED
/* LONGLONG */
long long
	wcstoll(const wchar_t * __restrict, wchar_t ** __restrict, int);
/* LONGLONG */
unsigned long long
	 wcstoull(const wchar_t * __restrict, wchar_t ** __restrict, int);
#endif
# 199 "/usr/include/wchar.h" 3 4
#endif	/* __ISO_C_VISIBLE >= 1999 */
# 200 "/usr/include/wchar.h" 3 4

#if __XSI_VISIBLE
int	wcswidth(const wchar_t *, size_t);
int	wcwidth(wchar_t);
#define	wcwidth(_c)	__wcwidth(_c)
#endif
# 206 "/usr/include/wchar.h" 3 4

#if __POSIX_VISIBLE >= 200809
size_t	mbsnrtowcs(wchar_t * __restrict, const char ** __restrict, size_t,
	    size_t, mbstate_t * __restrict);
FILE	*open_wmemstream(wchar_t **, size_t *);
wchar_t	*wcpcpy(wchar_t * __restrict, const wchar_t * __restrict);
wchar_t	*wcpncpy(wchar_t * __restrict, const wchar_t * __restrict, size_t);
wchar_t	*wcsdup(const wchar_t *) __malloc_like;
int	wcscasecmp(const wchar_t *, const wchar_t *);
int	wcsncasecmp(const wchar_t *, const wchar_t *, size_t n);
size_t	wcsnlen(const wchar_t *, size_t) __pure;
size_t	wcsnrtombs(char * __restrict, const wchar_t ** __restrict, size_t,
	    size_t, mbstate_t * __restrict);
#endif
# 220 "/usr/include/wchar.h" 3 4

#if __BSD_VISIBLE
wchar_t	*fgetwln(FILE * __restrict, size_t * __restrict);
size_t	wcslcat(wchar_t *, const wchar_t *, size_t);
size_t	wcslcpy(wchar_t *, const wchar_t *, size_t);
#endif
# 226 "/usr/include/wchar.h" 3 4

#if __POSIX_VISIBLE >= 200809 || defined(_XLOCALE_H_)
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_wchar.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/xlocale/_wchar.h" 1 3 4
/*-
 * Copyright (c) 2011, 2012 The FreeBSD Foundation
 * All rights reserved.
 *
 * This software was developed by David Chisnall under sponsorship from
 * the FreeBSD Foundation.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/include/xlocale/_wchar.h 231673 2012-02-14 12:03:23Z theraven $
 */

#ifndef _LOCALE_T_DEFINED
#define _LOCALE_T_DEFINED
typedef struct	_xlocale *locale_t;
#endif
# 36 "/usr/include/xlocale/_wchar.h" 3 4

#ifndef _XLOCALE_WCHAR1_H
#define _XLOCALE_WCHAR1_H
int			 wcscasecmp_l(const wchar_t *, const wchar_t *,
			   locale_t);
int			 wcsncasecmp_l(const wchar_t *, const wchar_t *, size_t,
			   locale_t);
int			 wcscoll_l(const wchar_t *, const wchar_t *, locale_t);
size_t			 wcsxfrm_l(wchar_t * __restrict,
			   const wchar_t * __restrict, size_t, locale_t);

#endif /* _XLOCALE_WCHAR1_H */
# 48 "/usr/include/xlocale/_wchar.h" 3 4

/*
 * Only declare the non-POSIX functions if we're included from xlocale.h.
 */

#ifdef _XLOCALE_H_
#ifndef _XLOCALE_WCHAR2_H
#define _XLOCALE_WCHAR2_H

wint_t			 btowc_l(int, locale_t);
wint_t			 fgetwc_l(FILE *, locale_t);
wchar_t			*fgetws_l(wchar_t * __restrict, int, FILE * __restrict,
			    locale_t);
wint_t			 fputwc_l(wchar_t, FILE *, locale_t);
int			 fputws_l(const wchar_t * __restrict, FILE * __restrict,
			   locale_t);
int			 fwprintf_l(FILE * __restrict, locale_t,
			    const wchar_t * __restrict, ...);
int			 fwscanf_l(FILE * __restrict, locale_t,
			    const wchar_t * __restrict, ...);
wint_t			 getwc_l(FILE *, locale_t);
wint_t			 getwchar_l(locale_t);
size_t			 mbrlen_l(const char * __restrict, size_t,
			   mbstate_t * __restrict, locale_t);
size_t			 mbrtowc_l(wchar_t * __restrict,
			    const char * __restrict, size_t,
			    mbstate_t * __restrict, locale_t);
int			 mbsinit_l(const mbstate_t *, locale_t);
size_t			 mbsrtowcs_l(wchar_t * __restrict,
			    const char ** __restrict, size_t,
			    mbstate_t * __restrict, locale_t);
wint_t			 putwc_l(wchar_t, FILE *, locale_t);
wint_t			 putwchar_l(wchar_t, locale_t);
int			 swprintf_l(wchar_t * __restrict, size_t n, locale_t,
			    const wchar_t * __restrict, ...);
int			 swscanf_l(const wchar_t * __restrict, locale_t,
			   const wchar_t * __restrict, ...);
wint_t			 ungetwc_l(wint_t, FILE *, locale_t);
int			 vfwprintf_l(FILE * __restrict, locale_t,
			    const wchar_t * __restrict, __va_list);
int			 vswprintf_l(wchar_t * __restrict, size_t n, locale_t,
			    const wchar_t * __restrict, __va_list);
int			 vwprintf_l(locale_t, const wchar_t * __restrict,
			    __va_list);
size_t			 wcrtomb_l(char * __restrict, wchar_t,
			    mbstate_t * __restrict, locale_t);
size_t			 wcsftime_l(wchar_t * __restrict, size_t,
			    const wchar_t * __restrict,
			    const struct tm * __restrict, locale_t);
size_t			 wcsrtombs_l(char * __restrict,
			    const wchar_t ** __restrict, size_t,
			    mbstate_t * __restrict, locale_t);
double			 wcstod_l(const wchar_t * __restrict,
			    wchar_t ** __restrict, locale_t);
long			 wcstol_l(const wchar_t * __restrict,
			    wchar_t ** __restrict, int, locale_t);
unsigned long		 wcstoul_l(const wchar_t * __restrict,
			    wchar_t ** __restrict, int, locale_t);
int			 wcswidth_l(const wchar_t *, size_t, locale_t);
int			 wctob_l(wint_t, locale_t);
int			 wcwidth_l(wchar_t, locale_t);
int			 wprintf_l(locale_t, const wchar_t * __restrict, ...);
int			 wscanf_l(locale_t, const wchar_t * __restrict, ...);
int			 vfwscanf_l(FILE * __restrict, locale_t,
			    const wchar_t * __restrict, __va_list);
int			 vswscanf_l(const wchar_t * __restrict, locale_t,
			    const wchar_t *__restrict, __va_list);
int			 vwscanf_l(locale_t, const wchar_t * __restrict,
			    __va_list);
float			 wcstof_l(const wchar_t * __restrict,
			    wchar_t ** __restrict, locale_t);
long double		 wcstold_l(const wchar_t * __restrict,
			    wchar_t ** __restrict, locale_t);
long long		 wcstoll_l(const wchar_t * __restrict,
			    wchar_t ** __restrict, int, locale_t);
unsigned long long	 wcstoull_l(const wchar_t * __restrict,
			    wchar_t ** __restrict, int, locale_t);
size_t			 mbsnrtowcs_l(wchar_t * __restrict,
			    const char ** __restrict, size_t, size_t,
			    mbstate_t * __restrict, locale_t);
size_t			 wcsnrtombs_l(char * __restrict,
			    const wchar_t ** __restrict, size_t, size_t,
			    mbstate_t * __restrict, locale_t);

#endif /* _XLOCALE_WCHAR_H */
# 133 "/usr/include/xlocale/_wchar.h" 3 4
#endif /* _XLOCALE_H_ */
# 134 "/usr/include/xlocale/_wchar.h" 3 4
# 229 "/usr/include/wchar.h" 2 3 4
#endif
# 230 "/usr/include/wchar.h" 3 4
__END_DECLS

#endif /* !_WCHAR_H_ */
# 233 "/usr/include/wchar.h" 3 4
# 91 "/usr/include/c++/v1/iosfwd" 2 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 94 "/usr/include/c++/v1/iosfwd" 3
#endif
# 95 "/usr/include/c++/v1/iosfwd" 3

_LIBCPP_BEGIN_NAMESPACE_STD

class _LIBCPP_TYPE_VIS ios_base;

template<class _CharT>  struct _LIBCPP_TYPE_VIS_ONLY char_traits;
template<class _Tp>     class _LIBCPP_TYPE_VIS_ONLY allocator;

template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TYPE_VIS_ONLY basic_ios;

template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TYPE_VIS_ONLY basic_streambuf;
template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TYPE_VIS_ONLY basic_istream;
template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TYPE_VIS_ONLY basic_ostream;
template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TYPE_VIS_ONLY basic_iostream;

template <class _CharT, class _Traits = char_traits<_CharT>,
          class _Allocator = allocator<_CharT> >
    class _LIBCPP_TYPE_VIS_ONLY basic_stringbuf;
template <class _CharT, class _Traits = char_traits<_CharT>,
          class _Allocator = allocator<_CharT> >
    class _LIBCPP_TYPE_VIS_ONLY basic_istringstream;
template <class _CharT, class _Traits = char_traits<_CharT>,
          class _Allocator = allocator<_CharT> >
    class _LIBCPP_TYPE_VIS_ONLY basic_ostringstream;
template <class _CharT, class _Traits = char_traits<_CharT>,
          class _Allocator = allocator<_CharT> >
    class _LIBCPP_TYPE_VIS_ONLY basic_stringstream;

template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TYPE_VIS_ONLY basic_filebuf;
template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TYPE_VIS_ONLY basic_ifstream;
template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TYPE_VIS_ONLY basic_ofstream;
template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TYPE_VIS_ONLY basic_fstream;

template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TYPE_VIS_ONLY istreambuf_iterator;
template <class _CharT, class _Traits = char_traits<_CharT> >
    class _LIBCPP_TYPE_VIS_ONLY ostreambuf_iterator;

typedef basic_ios<char>              ios;
typedef basic_ios<wchar_t>           wios;

typedef basic_streambuf<char>        streambuf;
typedef basic_istream<char>          istream;
typedef basic_ostream<char>          ostream;
typedef basic_iostream<char>         iostream;

typedef basic_stringbuf<char>        stringbuf;
typedef basic_istringstream<char>    istringstream;
typedef basic_ostringstream<char>    ostringstream;
typedef basic_stringstream<char>     stringstream;

typedef basic_filebuf<char>          filebuf;
typedef basic_ifstream<char>         ifstream;
typedef basic_ofstream<char>         ofstream;
typedef basic_fstream<char>          fstream;

typedef basic_streambuf<wchar_t>     wstreambuf;
typedef basic_istream<wchar_t>       wistream;
typedef basic_ostream<wchar_t>       wostream;
typedef basic_iostream<wchar_t>      wiostream;

typedef basic_stringbuf<wchar_t>     wstringbuf;
typedef basic_istringstream<wchar_t> wistringstream;
typedef basic_ostringstream<wchar_t> wostringstream;
typedef basic_stringstream<wchar_t>  wstringstream;

typedef basic_filebuf<wchar_t>       wfilebuf;
typedef basic_ifstream<wchar_t>      wifstream;
typedef basic_ofstream<wchar_t>      wofstream;
typedef basic_fstream<wchar_t>       wfstream;

template <class _State>             class _LIBCPP_TYPE_VIS_ONLY fpos;
typedef fpos<mbstate_t>    streampos;
typedef fpos<mbstate_t>    wstreampos;
#ifndef _LIBCPP_HAS_NO_UNICODE_CHARS
typedef fpos<mbstate_t>    u16streampos;
typedef fpos<mbstate_t>    u32streampos;
#endif  // _LIBCPP_HAS_NO_UNICODE_CHARS
# 182 "/usr/include/c++/v1/iosfwd" 3

typedef long long streamoff;        // for char_traits in <string>

template <class _CharT,             // for <stdexcept>
          class _Traits = char_traits<_CharT>,
          class _Allocator = allocator<_CharT> >
    class _LIBCPP_TYPE_VIS_ONLY basic_string;
typedef basic_string<char, char_traits<char>, allocator<char> > string;
typedef basic_string<wchar_t, char_traits<wchar_t>, allocator<wchar_t> > wstring;

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_IOSFWD
# 195 "/usr/include/c++/v1/iosfwd" 3
# 436 "/usr/include/c++/v1/string" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <cstring>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/cstring" 1 3
// -*- C++ -*-
//===--------------------------- cstring ----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is distributed under the University of Illinois Open Source
// License. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CSTRING
#define _LIBCPP_CSTRING

/*
    cstring synopsis

Macros:

    NULL

namespace std
{

Types:

    size_t

void* memcpy(void* restrict s1, const void* restrict s2, size_t n);
void* memmove(void* s1, const void* s2, size_t n);
char* strcpy (char* restrict s1, const char* restrict s2);
char* strncpy(char* restrict s1, const char* restrict s2, size_t n);
char* strcat (char* restrict s1, const char* restrict s2);
char* strncat(char* restrict s1, const char* restrict s2, size_t n);
int memcmp(const void* s1, const void* s2, size_t n);
int strcmp (const char* s1, const char* s2);
int strncmp(const char* s1, const char* s2, size_t n);
int strcoll(const char* s1, const char* s2);
size_t strxfrm(char* restrict s1, const char* restrict s2, size_t n);
const void* memchr(const void* s, int c, size_t n);
      void* memchr(      void* s, int c, size_t n);
const char* strchr(const char* s, int c);
      char* strchr(      char* s, int c);
size_t strcspn(const char* s1, const char* s2);
const char* strpbrk(const char* s1, const char* s2);
      char* strpbrk(      char* s1, const char* s2);
const char* strrchr(const char* s, int c);
      char* strrchr(      char* s, int c);
size_t strspn(const char* s1, const char* s2);
const char* strstr(const char* s1, const char* s2);
      char* strstr(      char* s1, const char* s2);
char* strtok(char* restrict s1, const char* restrict s2);
void* memset(void* s, int c, size_t n);
char* strerror(int errnum);
size_t strlen(const char* s);

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 61 "/usr/include/c++/v1/cstring" 3
#if 0 /* expanded by -frewrite-includes */
#include <string.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/string.h" 1 3 4
/*-
 * Copyright (c) 1990, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)string.h	8.1 (Berkeley) 6/2/93
 * $FreeBSD: head/include/string.h 265878 2014-05-11 13:48:21Z jilles $
 */

#ifndef _STRING_H_
#define	_STRING_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 37 "/usr/include/string.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_null.h>
#endif /* expanded by -frewrite-includes */
# 38 "/usr/include/string.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 39 "/usr/include/string.h" 3 4

/*
 * Prototype functions which were historically defined in <string.h>, but
 * are required by POSIX to be prototyped in <strings.h>.
 */
#if __BSD_VISIBLE
#if 0 /* expanded by -frewrite-includes */
#include <strings.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/strings.h" 1 3 4
/*-
 * Copyright (c) 2002 Mike Barcroft <mike@FreeBSD.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/include/strings.h 266865 2014-05-30 01:09:07Z pfg $
 */

#ifndef _STRINGS_H_
#define	_STRINGS_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 33 "/usr/include/strings.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 34 "/usr/include/strings.h" 3 4

#ifndef _SIZE_T_DECLARED
typedef	__size_t	size_t;
#define	_SIZE_T_DECLARED
#endif
# 39 "/usr/include/strings.h" 3 4

__BEGIN_DECLS
#if __BSD_VISIBLE || __POSIX_VISIBLE <= 200112
int	 bcmp(const void *, const void *, size_t) __pure;	/* LEGACY */
void	 bcopy(const void *, void *, size_t);			/* LEGACY */
void	 bzero(void *, size_t);					/* LEGACY */
#endif
# 46 "/usr/include/strings.h" 3 4
#if __XSI_VISIBLE
int	 ffs(int) __pure2;
#endif
# 49 "/usr/include/strings.h" 3 4
#if __BSD_VISIBLE
int	 ffsl(long) __pure2;
int	 ffsll(long long) __pure2;
int	 fls(int) __pure2;
int	 flsl(long) __pure2;
int	 flsll(long long) __pure2;
#endif
# 56 "/usr/include/strings.h" 3 4
#if __BSD_VISIBLE || __POSIX_VISIBLE <= 200112
char	*index(const char *, int) __pure;			/* LEGACY */
char	*rindex(const char *, int) __pure;			/* LEGACY */
#endif
# 60 "/usr/include/strings.h" 3 4
int	 strcasecmp(const char *, const char *) __pure;
int	 strncasecmp(const char *, const char *, size_t) __pure;

#if __POSIX_VISIBLE >= 200809 || defined(_XLOCALE_H_)
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_strings.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/xlocale/_strings.h" 1 3 4
/*-
 * Copyright (c) 2011, 2012 The FreeBSD Foundation
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/include/xlocale/_strings.h 266865 2014-05-30 01:09:07Z pfg $
 */

#ifndef _LOCALE_T_DEFINED
#define _LOCALE_T_DEFINED
typedef struct	_xlocale *locale_t;
#endif
# 33 "/usr/include/xlocale/_strings.h" 3 4

/*
 * This file is included from both strings.h and xlocale.h.  We need to expose
 * the declarations unconditionally if we are included from xlocale.h, but only
 * if we are in POSIX2008 mode if included from string.h.
 */

#ifndef _XLOCALE_STRINGS1_H
#define _XLOCALE_STRINGS1_H

/*
 * POSIX2008 functions
 */
int	 strcasecmp_l(const char *, const char *, locale_t);
int	 strncasecmp_l(const char *, const char *, size_t, locale_t);
#endif /* _XLOCALE_STRINGS1_H */
# 49 "/usr/include/xlocale/_strings.h" 3 4
# 65 "/usr/include/strings.h" 2 3 4
#endif
# 66 "/usr/include/strings.h" 3 4
__END_DECLS

#endif /* _STRINGS_H_ */
# 69 "/usr/include/strings.h" 3 4
# 46 "/usr/include/string.h" 2 3 4
#endif
# 47 "/usr/include/string.h" 3 4

#ifndef _SIZE_T_DECLARED
typedef	__size_t	size_t;
#define	_SIZE_T_DECLARED
#endif
# 52 "/usr/include/string.h" 3 4

__BEGIN_DECLS
#if __XSI_VISIBLE >= 600
void	*memccpy(void * __restrict, const void * __restrict, int, size_t);
#endif
# 57 "/usr/include/string.h" 3 4
void	*memchr(const void *, int, size_t) __pure;
#if __BSD_VISIBLE
void	*memrchr(const void *, int, size_t) __pure;
#endif
# 61 "/usr/include/string.h" 3 4
int	 memcmp(const void *, const void *, size_t) __pure;
void	*memcpy(void * __restrict, const void * __restrict, size_t);
#if __BSD_VISIBLE
void	*memmem(const void *, size_t, const void *, size_t) __pure;
#endif
# 66 "/usr/include/string.h" 3 4
void	*memmove(void *, const void *, size_t);
void	*memset(void *, int, size_t);
#if __POSIX_VISIBLE >= 200809
char	*stpcpy(char * __restrict, const char * __restrict);
char	*stpncpy(char * __restrict, const char * __restrict, size_t);
#endif
# 72 "/usr/include/string.h" 3 4
#if __BSD_VISIBLE
char	*strcasestr(const char *, const char *) __pure;
#endif
# 75 "/usr/include/string.h" 3 4
char	*strcat(char * __restrict, const char * __restrict);
char	*strchr(const char *, int) __pure;
#if __BSD_VISIBLE
char	*strchrnul(const char*, int) __pure;
#endif
# 80 "/usr/include/string.h" 3 4
int	 strcmp(const char *, const char *) __pure;
int	 strcoll(const char *, const char *);
char	*strcpy(char * __restrict, const char * __restrict);
size_t	 strcspn(const char *, const char *) __pure;
#if __POSIX_VISIBLE >= 200112 || __XSI_VISIBLE
char	*strdup(const char *) __malloc_like;
#endif
# 87 "/usr/include/string.h" 3 4
char	*strerror(int);
#if __POSIX_VISIBLE >= 200112
int	 strerror_r(int, char *, size_t);
#endif
# 91 "/usr/include/string.h" 3 4
#if __BSD_VISIBLE
size_t	 strlcat(char * __restrict, const char * __restrict, size_t);
size_t	 strlcpy(char * __restrict, const char * __restrict, size_t);
#endif
# 95 "/usr/include/string.h" 3 4
size_t	 strlen(const char *) __pure;
#if __BSD_VISIBLE
void	 strmode(int, char *);
#endif
# 99 "/usr/include/string.h" 3 4
char	*strncat(char * __restrict, const char * __restrict, size_t);
int	 strncmp(const char *, const char *, size_t) __pure;
char	*strncpy(char * __restrict, const char * __restrict, size_t);
#if __POSIX_VISIBLE >= 200809
char	*strndup(const char *, size_t) __malloc_like;
size_t	 strnlen(const char *, size_t) __pure;
#endif
# 106 "/usr/include/string.h" 3 4
#if __BSD_VISIBLE
char	*strnstr(const char *, const char *, size_t) __pure;
#endif
# 109 "/usr/include/string.h" 3 4
char	*strpbrk(const char *, const char *) __pure;
char	*strrchr(const char *, int) __pure;
#if __BSD_VISIBLE
char	*strsep(char **, const char *);
#endif
# 114 "/usr/include/string.h" 3 4
#if __POSIX_VISIBLE >= 200809
char	*strsignal(int);
#endif
# 117 "/usr/include/string.h" 3 4
size_t	 strspn(const char *, const char *) __pure;
char	*strstr(const char *, const char *) __pure;
char	*strtok(char * __restrict, const char * __restrict);
#if __POSIX_VISIBLE >= 199506 || __XSI_VISIBLE >= 500
char	*strtok_r(char *, const char *, char **);
#endif
# 123 "/usr/include/string.h" 3 4
size_t	 strxfrm(char * __restrict, const char * __restrict, size_t);
#if __BSD_VISIBLE

#ifndef _SWAB_DECLARED
#define _SWAB_DECLARED

#ifndef _SSIZE_T_DECLARED
typedef	__ssize_t	ssize_t;
#define	_SSIZE_T_DECLARED
#endif /* _SIZE_T_DECLARED */
# 133 "/usr/include/string.h" 3 4

void	 swab(const void * __restrict, void * __restrict, ssize_t);
#endif /* _SWAB_DECLARED */
# 136 "/usr/include/string.h" 3 4

#endif /* __BSD_VISIBLE */
# 138 "/usr/include/string.h" 3 4

#if __POSIX_VISIBLE >= 200809 || defined(_XLOCALE_H_)
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_string.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/xlocale/_string.h" 1 3 4
/*-
 * Copyright (c) 2011, 2012 The FreeBSD Foundation
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/include/xlocale/_string.h 266865 2014-05-30 01:09:07Z pfg $
 */

#ifndef _LOCALE_T_DEFINED
#define _LOCALE_T_DEFINED
typedef struct	_xlocale *locale_t;
#endif
# 33 "/usr/include/xlocale/_string.h" 3 4

/*
 * This file is included from both string.h and xlocale.h.  We need to expose
 * the declarations unconditionally if we are included from xlocale.h, but only
 * if we are in POSIX2008 mode if included from string.h.
 */

#ifndef _XLOCALE_STRING1_H
#define _XLOCALE_STRING1_H

/*
 * POSIX2008 functions
 */
int	 strcoll_l(const char *, const char *, locale_t);
size_t	 strxfrm_l(char *, const char *, size_t, locale_t);
#endif /* _XLOCALE_STRING1_H */
# 49 "/usr/include/xlocale/_string.h" 3 4

/*
 * xlocale extensions
 */
#ifdef _XLOCALE_H_
#ifndef _XLOCALE_STRING2_H
#define _XLOCALE_STRING2_H
char	*strcasestr_l(const char *, const char *, locale_t);

#endif /* _XLOCALE_STRING2_H */
# 59 "/usr/include/xlocale/_string.h" 3 4
#endif /* _XLOCALE_H_ */
# 60 "/usr/include/xlocale/_string.h" 3 4
# 141 "/usr/include/string.h" 2 3 4
#endif
# 142 "/usr/include/string.h" 3 4
__END_DECLS

#endif /* _STRING_H_ */
# 145 "/usr/include/string.h" 3 4
# 62 "/usr/include/c++/v1/cstring" 2 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 65 "/usr/include/c++/v1/cstring" 3
#endif
# 66 "/usr/include/c++/v1/cstring" 3

_LIBCPP_BEGIN_NAMESPACE_STD

using ::size_t;
using ::memcpy;
using ::memmove;
using ::strcpy;
using ::strncpy;
using ::strcat;
using ::strncat;
using ::memcmp;
using ::strcmp;
using ::strncmp;
using ::strcoll;
using ::strxfrm;

using ::memchr;

using ::strchr;

using ::strcspn;

using ::strpbrk;

using ::strrchr;

using ::strspn;

using ::strstr;

// MSVCRT, GNU libc and its derivates already have the correct prototype in <string.h> #ifdef __cplusplus
#if !defined(__GLIBC__) && !defined(_LIBCPP_MSVCRT) && !defined(__sun__) && !defined(_STRING_H_CPLUSPLUS_98_CONFORMANCE_)
inline _LIBCPP_INLINE_VISIBILITY       char* strchr(      char* __s, int __c) {return ::strchr(__s, __c);}
inline _LIBCPP_INLINE_VISIBILITY       char* strpbrk(      char* __s1, const char* __s2) {return ::strpbrk(__s1, __s2);}
inline _LIBCPP_INLINE_VISIBILITY       char* strrchr(      char* __s, int __c) {return ::strrchr(__s, __c);}
inline _LIBCPP_INLINE_VISIBILITY       void* memchr(      void* __s, int __c, size_t __n) {return ::memchr(__s, __c, __n);}
inline _LIBCPP_INLINE_VISIBILITY       char* strstr(      char* __s1, const char* __s2) {return ::strstr(__s1, __s2);}
#endif
# 104 "/usr/include/c++/v1/cstring" 3

using ::strtok;
using ::memset;
using ::strerror;
using ::strlen;

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_CSTRING
# 113 "/usr/include/c++/v1/cstring" 3
# 437 "/usr/include/c++/v1/string" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <cstdio>  // For EOF.
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/cstdio" 1 3
// -*- C++ -*-
//===---------------------------- cstdio ----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CSTDIO
#define _LIBCPP_CSTDIO

/*
    cstdio synopsis

Macros:

    BUFSIZ
    EOF
    FILENAME_MAX
    FOPEN_MAX
    L_tmpnam
    NULL
    SEEK_CUR
    SEEK_END
    SEEK_SET
    TMP_MAX
    _IOFBF
    _IOLBF
    _IONBF
    stderr
    stdin
    stdout

namespace std
{

Types:

FILE
fpos_t
size_t

int remove(const char* filename);
int rename(const char* old, const char* new);
FILE* tmpfile(void);
char* tmpnam(char* s);
int fclose(FILE* stream);
int fflush(FILE* stream);
FILE* fopen(const char* restrict filename, const char* restrict mode);
FILE* freopen(const char* restrict filename, const char * restrict mode,
              FILE * restrict stream);
void setbuf(FILE* restrict stream, char* restrict buf);
int setvbuf(FILE* restrict stream, char* restrict buf, int mode, size_t size);
int fprintf(FILE* restrict stream, const char* restrict format, ...);
int fscanf(FILE* restrict stream, const char * restrict format, ...);
int printf(const char* restrict format, ...);
int scanf(const char* restrict format, ...);
int snprintf(char* restrict s, size_t n, const char* restrict format, ...);    // C99
int sprintf(char* restrict s, const char* restrict format, ...);
int sscanf(const char* restrict s, const char* restrict format, ...);
int vfprintf(FILE* restrict stream, const char* restrict format, va_list arg);
int vfscanf(FILE* restrict stream, const char* restrict format, va_list arg);  // C99
int vprintf(const char* restrict format, va_list arg);
int vscanf(const char* restrict format, va_list arg);                          // C99
int vsnprintf(char* restrict s, size_t n, const char* restrict format,         // C99
              va_list arg);
int vsprintf(char* restrict s, const char* restrict format, va_list arg);
int vsscanf(const char* restrict s, const char* restrict format, va_list arg); // C99
int fgetc(FILE* stream);
char* fgets(char* restrict s, int n, FILE* restrict stream);
int fputc(int c, FILE* stream);
int fputs(const char* restrict s, FILE* restrict stream);
int getc(FILE* stream);
int getchar(void);
char* gets(char* s);  // removed in C++14
int putc(int c, FILE* stream);
int putchar(int c);
int puts(const char* s);
int ungetc(int c, FILE* stream);
size_t fread(void* restrict ptr, size_t size, size_t nmemb,
             FILE* restrict stream);
size_t fwrite(const void* restrict ptr, size_t size, size_t nmemb,
              FILE* restrict stream);
int fgetpos(FILE* restrict stream, fpos_t* restrict pos);
int fseek(FILE* stream, long offset, int whence);
int fsetpos(FILE*stream, const fpos_t* pos);
long ftell(FILE* stream);
void rewind(FILE* stream);
void clearerr(FILE* stream);
int feof(FILE* stream);
int ferror(FILE* stream);
void perror(const char* s);

}  // std
*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 100 "/usr/include/c++/v1/cstdio" 3
#if 0 /* expanded by -frewrite-includes */
#include <stdio.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/stdio.h" 1 3 4
/*-
 * Copyright (c) 1990, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * This code is derived from software contributed to Berkeley by
 * Chris Torek.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)stdio.h	8.5 (Berkeley) 4/29/95
 * $FreeBSD: head/include/stdio.h 265881 2014-05-11 16:34:17Z jilles $
 */

#ifndef	_STDIO_H_
#define	_STDIO_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 40 "/usr/include/stdio.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_null.h>
#endif /* expanded by -frewrite-includes */
# 41 "/usr/include/stdio.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 42 "/usr/include/stdio.h" 3 4

typedef	__off_t		fpos_t;

#ifndef _SIZE_T_DECLARED
typedef	__size_t	size_t;
#define	_SIZE_T_DECLARED
#endif
# 49 "/usr/include/stdio.h" 3 4

#if __POSIX_VISIBLE >= 200809
#ifndef _OFF_T_DECLARED
#define	_OFF_T_DECLARED
typedef	__off_t		off_t;
#endif
# 55 "/usr/include/stdio.h" 3 4
#ifndef _SSIZE_T_DECLARED
#define	_SSIZE_T_DECLARED
typedef	__ssize_t	ssize_t;
#endif
# 59 "/usr/include/stdio.h" 3 4
#endif
# 60 "/usr/include/stdio.h" 3 4

#if __POSIX_VISIBLE >= 200112 || __XSI_VISIBLE
#ifndef _VA_LIST_DECLARED
typedef	__va_list	va_list;
#define	_VA_LIST_DECLARED
#endif
# 66 "/usr/include/stdio.h" 3 4
#endif
# 67 "/usr/include/stdio.h" 3 4

#define	_FSTDIO			/* Define for new stdio with functions. */

/*
 * NB: to fit things in six character monocase externals, the stdio
 * code uses the prefix `__s' for stdio objects, typically followed
 * by a three-character attempt at a mnemonic.
 */

/* stdio buffers */
struct __sbuf {
	unsigned char *_base;
	int	_size;
};

/*
 * stdio state variables.
 *
 * The following always hold:
 *
 *	if (_flags&(__SLBF|__SWR)) == (__SLBF|__SWR),
 *		_lbfsize is -_bf._size, else _lbfsize is 0
 *	if _flags&__SRD, _w is 0
 *	if _flags&__SWR, _r is 0
 *
 * This ensures that the getc and putc macros (or inline functions) never
 * try to write or read from a file that is in `read' or `write' mode.
 * (Moreover, they can, and do, automatically switch from read mode to
 * write mode, and back, on "r+" and "w+" files.)
 *
 * _lbfsize is used only to make the inline line-buffered output stream
 * code as compact as possible.
 *
 * _ub, _up, and _ur are used when ungetc() pushes back more characters
 * than fit in the current _bf, or when ungetc() pushes back a character
 * that does not match the previous one in _bf.  When this happens,
 * _ub._base becomes non-nil (i.e., a stream has ungetc() data iff
 * _ub._base!=NULL) and _up and _ur save the current values of _p and _r.
 *
 * Certain members of __sFILE are accessed directly via macros or
 * inline functions.  To preserve ABI compat, these members must not
 * be disturbed.  These members are marked below with (*).
 */
struct __sFILE {
	unsigned char *_p;	/* (*) current position in (some) buffer */
	int	_r;		/* (*) read space left for getc() */
	int	_w;		/* (*) write space left for putc() */
	short	_flags;		/* (*) flags, below; this FILE is free if 0 */
	short	_file;		/* (*) fileno, if Unix descriptor, else -1 */
	struct	__sbuf _bf;	/* (*) the buffer (at least 1 byte, if !NULL) */
	int	_lbfsize;	/* (*) 0 or -_bf._size, for inline putc */

	/* operations */
	void	*_cookie;	/* (*) cookie passed to io functions */
	int	(*_close)(void *);
	int	(*_read)(void *, char *, int);
	fpos_t	(*_seek)(void *, fpos_t, int);
	int	(*_write)(void *, const char *, int);

	/* separate buffer for long sequences of ungetc() */
	struct	__sbuf _ub;	/* ungetc buffer */
	unsigned char	*_up;	/* saved _p when _p is doing ungetc data */
	int	_ur;		/* saved _r when _r is counting ungetc data */

	/* tricks to meet minimum requirements even when malloc() fails */
	unsigned char _ubuf[3];	/* guarantee an ungetc() buffer */
	unsigned char _nbuf[1];	/* guarantee a getc() buffer */

	/* separate buffer for fgetln() when line crosses buffer boundary */
	struct	__sbuf _lb;	/* buffer for fgetln() */

	/* Unix stdio files get aligned to block boundaries on fseek() */
	int	_blksize;	/* stat.st_blksize (may be != _bf._size) */
	fpos_t	_offset;	/* current lseek offset */

	struct pthread_mutex *_fl_mutex;	/* used for MT-safety */
	struct pthread *_fl_owner;	/* current owner */
	int	_fl_count;	/* recursive lock count */
	int	_orientation;	/* orientation for fwide() */
	__mbstate_t _mbstate;	/* multibyte conversion state */
};
#ifndef _STDFILE_DECLARED
#define _STDFILE_DECLARED
typedef struct __sFILE FILE;
#endif
# 152 "/usr/include/stdio.h" 3 4
#ifndef _STDSTREAM_DECLARED
__BEGIN_DECLS
extern FILE *__stdinp;
extern FILE *__stdoutp;
extern FILE *__stderrp;
__END_DECLS
#define	_STDSTREAM_DECLARED
#endif
# 160 "/usr/include/stdio.h" 3 4

#define	__SLBF	0x0001		/* line buffered */
#define	__SNBF	0x0002		/* unbuffered */
#define	__SRD	0x0004		/* OK to read */
#define	__SWR	0x0008		/* OK to write */
	/* RD and WR are never simultaneously asserted */
#define	__SRW	0x0010		/* open for reading & writing */
#define	__SEOF	0x0020		/* found EOF */
#define	__SERR	0x0040		/* found error */
#define	__SMBF	0x0080		/* _buf is from malloc */
#define	__SAPP	0x0100		/* fdopen()ed in append mode */
#define	__SSTR	0x0200		/* this is an sprintf/snprintf string */
#define	__SOPT	0x0400		/* do fseek() optimization */
#define	__SNPT	0x0800		/* do not do fseek() optimization */
#define	__SOFF	0x1000		/* set iff _offset is in fact correct */
#define	__SMOD	0x2000		/* true => fgetln modified _p text */
#define	__SALC	0x4000		/* allocate string space dynamically */
#define	__SIGN	0x8000		/* ignore this file in _fwalk */

/*
 * The following three definitions are for ANSI C, which took them
 * from System V, which brilliantly took internal interface macros and
 * made them official arguments to setvbuf(), without renaming them.
 * Hence, these ugly _IOxxx names are *supposed* to appear in user code.
 *
 * Although numbered as their counterparts above, the implementation
 * does not rely on this.
 */
#define	_IOFBF	0		/* setvbuf should set fully buffered */
#define	_IOLBF	1		/* setvbuf should set line buffered */
#define	_IONBF	2		/* setvbuf should set unbuffered */

#define	BUFSIZ	1024		/* size of buffer used by setbuf */
#define	EOF	(-1)

/*
 * FOPEN_MAX is a minimum maximum, and is the number of streams that
 * stdio can provide without attempting to allocate further resources
 * (which could fail).  Do not use this for anything.
 */
				/* must be == _POSIX_STREAM_MAX <limits.h> */
#ifndef FOPEN_MAX
#define	FOPEN_MAX	20	/* must be <= OPEN_MAX <sys/syslimits.h> */
#endif
# 204 "/usr/include/stdio.h" 3 4
#define	FILENAME_MAX	1024	/* must be <= PATH_MAX <sys/syslimits.h> */

/* System V/ANSI C; this is the wrong way to do this, do *not* use these. */
#if __XSI_VISIBLE
#define	P_tmpdir	"/tmp/"
#endif
# 210 "/usr/include/stdio.h" 3 4
#define	L_tmpnam	1024	/* XXX must be == PATH_MAX */
#define	TMP_MAX		308915776

#ifndef SEEK_SET
#define	SEEK_SET	0	/* set file offset to offset */
#endif
# 216 "/usr/include/stdio.h" 3 4
#ifndef SEEK_CUR
#define	SEEK_CUR	1	/* set file offset to current plus offset */
#endif
# 219 "/usr/include/stdio.h" 3 4
#ifndef SEEK_END
#define	SEEK_END	2	/* set file offset to EOF plus offset */
#endif
# 222 "/usr/include/stdio.h" 3 4

#define	stdin	__stdinp
#define	stdout	__stdoutp
#define	stderr	__stderrp

__BEGIN_DECLS
#ifdef _XLOCALE_H_
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_stdio.h>
#endif /* expanded by -frewrite-includes */
# 230 "/usr/include/stdio.h" 3 4
#endif
# 231 "/usr/include/stdio.h" 3 4
/*
 * Functions defined in ANSI C standard.
 */
void	 clearerr(FILE *);
int	 fclose(FILE *);
int	 feof(FILE *);
int	 ferror(FILE *);
int	 fflush(FILE *);
int	 fgetc(FILE *);
int	 fgetpos(FILE * __restrict, fpos_t * __restrict);
char	*fgets(char * __restrict, int, FILE * __restrict);
FILE	*fopen(const char * __restrict, const char * __restrict);
int	 fprintf(FILE * __restrict, const char * __restrict, ...);
int	 fputc(int, FILE *);
int	 fputs(const char * __restrict, FILE * __restrict);
size_t	 fread(void * __restrict, size_t, size_t, FILE * __restrict);
FILE	*freopen(const char * __restrict, const char * __restrict, FILE * __restrict);
int	 fscanf(FILE * __restrict, const char * __restrict, ...);
int	 fseek(FILE *, long, int);
int	 fsetpos(FILE *, const fpos_t *);
long	 ftell(FILE *);
size_t	 fwrite(const void * __restrict, size_t, size_t, FILE * __restrict);
int	 getc(FILE *);
int	 getchar(void);
char	*gets(char *);
void	 perror(const char *);
int	 printf(const char * __restrict, ...);
int	 putc(int, FILE *);
int	 putchar(int);
int	 puts(const char *);
int	 remove(const char *);
int	 rename(const char *, const char *);
void	 rewind(FILE *);
int	 scanf(const char * __restrict, ...);
void	 setbuf(FILE * __restrict, char * __restrict);
int	 setvbuf(FILE * __restrict, char * __restrict, int, size_t);
int	 sprintf(char * __restrict, const char * __restrict, ...);
int	 sscanf(const char * __restrict, const char * __restrict, ...);
FILE	*tmpfile(void);
char	*tmpnam(char *);
int	 ungetc(int, FILE *);
int	 vfprintf(FILE * __restrict, const char * __restrict,
	    __va_list);
int	 vprintf(const char * __restrict, __va_list);
int	 vsprintf(char * __restrict, const char * __restrict,
	    __va_list);

#if __ISO_C_VISIBLE >= 1999
int	 snprintf(char * __restrict, size_t, const char * __restrict,
	    ...) __printflike(3, 4);
int	 vfscanf(FILE * __restrict, const char * __restrict, __va_list)
	    __scanflike(2, 0);
int	 vscanf(const char * __restrict, __va_list) __scanflike(1, 0);
int	 vsnprintf(char * __restrict, size_t, const char * __restrict,
	    __va_list) __printflike(3, 0);
int	 vsscanf(const char * __restrict, const char * __restrict, __va_list)
	    __scanflike(2, 0);
#endif
# 289 "/usr/include/stdio.h" 3 4

/*
 * Functions defined in all versions of POSIX 1003.1.
 */
#if __BSD_VISIBLE || (__POSIX_VISIBLE && __POSIX_VISIBLE <= 199506)
#define	L_cuserid	17	/* size for cuserid(3); MAXLOGNAME, legacy */
#endif
# 296 "/usr/include/stdio.h" 3 4

#if __POSIX_VISIBLE
#define	L_ctermid	1024	/* size for ctermid(3); PATH_MAX */

char	*ctermid(char *);
FILE	*fdopen(int, const char *);
int	 fileno(FILE *);
#endif /* __POSIX_VISIBLE */
# 304 "/usr/include/stdio.h" 3 4

#if __POSIX_VISIBLE >= 199209
int	 pclose(FILE *);
FILE	*popen(const char *, const char *);
#endif
# 309 "/usr/include/stdio.h" 3 4

#if __POSIX_VISIBLE >= 199506
int	 ftrylockfile(FILE *);
void	 flockfile(FILE *);
void	 funlockfile(FILE *);

/*
 * These are normally used through macros as defined below, but POSIX
 * requires functions as well.
 */
int	 getc_unlocked(FILE *);
int	 getchar_unlocked(void);
int	 putc_unlocked(int, FILE *);
int	 putchar_unlocked(int);
#endif
# 324 "/usr/include/stdio.h" 3 4
#if __BSD_VISIBLE
void	 clearerr_unlocked(FILE *);
int	 feof_unlocked(FILE *);
int	 ferror_unlocked(FILE *);
int	 fileno_unlocked(FILE *);
#endif
# 330 "/usr/include/stdio.h" 3 4

#if __POSIX_VISIBLE >= 200112
int	 fseeko(FILE *, __off_t, int);
__off_t	 ftello(FILE *);
#endif
# 335 "/usr/include/stdio.h" 3 4

#if __BSD_VISIBLE || __XSI_VISIBLE > 0 && __XSI_VISIBLE < 600
int	 getw(FILE *);
int	 putw(int, FILE *);
#endif /* BSD or X/Open before issue 6 */
# 340 "/usr/include/stdio.h" 3 4

#if __XSI_VISIBLE
char	*tempnam(const char *, const char *);
#endif
# 344 "/usr/include/stdio.h" 3 4

#if __POSIX_VISIBLE >= 200809
FILE	*fmemopen(void * __restrict, size_t, const char * __restrict);
ssize_t	 getdelim(char ** __restrict, size_t * __restrict, int,
	    FILE * __restrict);
FILE	*open_memstream(char **, size_t *);
int	 renameat(int, const char *, int, const char *);
int	 vdprintf(int, const char * __restrict, __va_list);

/*
 * Every programmer and his dog wrote functions called getline() and dprintf()
 * before POSIX.1-2008 came along and decided to usurp the names, so we
 * don't prototype them by default unless one of the following is true:
 *   a) the app has requested them specifically by defining _WITH_GETLINE or
 *      _WITH_DPRINTF, respectively
 *   b) the app has requested a POSIX.1-2008 environment via _POSIX_C_SOURCE
 *   c) the app defines a GNUism such as _BSD_SOURCE or _GNU_SOURCE
 */
#ifndef _WITH_GETLINE
#if defined(_BSD_SOURCE) || defined(_GNU_SOURCE)
#define	_WITH_GETLINE
#elif defined(_POSIX_C_SOURCE)
# 366 "/usr/include/stdio.h" 3 4
#if _POSIX_C_SOURCE >= 200809
#define	_WITH_GETLINE
#endif
# 369 "/usr/include/stdio.h" 3 4
#endif
# 370 "/usr/include/stdio.h" 3 4
#endif
# 371 "/usr/include/stdio.h" 3 4

#ifdef _WITH_GETLINE
ssize_t	 getline(char ** __restrict, size_t * __restrict, FILE * __restrict);
#endif
# 375 "/usr/include/stdio.h" 3 4

#ifndef _WITH_DPRINTF
#if defined(_BSD_SOURCE) || defined(_GNU_SOURCE)
#define	_WITH_DPRINTF
#elif defined(_POSIX_C_SOURCE)
# 380 "/usr/include/stdio.h" 3 4
#if _POSIX_C_SOURCE >= 200809
#define	_WITH_DPRINTF
#endif
# 383 "/usr/include/stdio.h" 3 4
#endif
# 384 "/usr/include/stdio.h" 3 4
#endif
# 385 "/usr/include/stdio.h" 3 4

#ifdef _WITH_DPRINTF
int	 (dprintf)(int, const char * __restrict, ...);
#endif
# 389 "/usr/include/stdio.h" 3 4

#endif /* __POSIX_VISIBLE >= 200809 */
# 391 "/usr/include/stdio.h" 3 4

/*
 * Routines that are purely local.
 */
#if __BSD_VISIBLE
int	 asprintf(char **, const char *, ...) __printflike(2, 3);
char	*ctermid_r(char *);
void	 fcloseall(void);
char	*fgetln(FILE *, size_t *);
const char *fmtcheck(const char *, const char *) __format_arg(2);
int	 fpurge(FILE *);
void	 setbuffer(FILE *, char *, int);
int	 setlinebuf(FILE *);
int	 vasprintf(char **, const char *, __va_list)
	    __printflike(2, 0);

/*
 * The system error table contains messages for the first sys_nerr
 * positive errno values.  Use strerror() or strerror_r() from <string.h>
 * instead.
 */
extern const int sys_nerr;
extern const char * const sys_errlist[];

/*
 * Stdio function-access interface.
 */
FILE	*funopen(const void *,
	    int (*)(void *, char *, int),
	    int (*)(void *, const char *, int),
	    fpos_t (*)(void *, fpos_t, int),
	    int (*)(void *));
#define	fropen(cookie, fn) funopen(cookie, fn, 0, 0, 0)
#define	fwopen(cookie, fn) funopen(cookie, 0, fn, 0, 0)

/*
 * Portability hacks.  See <sys/types.h>.
 */
#ifndef _FTRUNCATE_DECLARED
#define	_FTRUNCATE_DECLARED
int	 ftruncate(int, __off_t);
#endif
# 433 "/usr/include/stdio.h" 3 4
#ifndef _LSEEK_DECLARED
#define	_LSEEK_DECLARED
__off_t	 lseek(int, __off_t, int);
#endif
# 437 "/usr/include/stdio.h" 3 4
#ifndef _MMAP_DECLARED
#define	_MMAP_DECLARED
void	*mmap(void *, size_t, int, int, int, __off_t);
#endif
# 441 "/usr/include/stdio.h" 3 4
#ifndef _TRUNCATE_DECLARED
#define	_TRUNCATE_DECLARED
int	 truncate(const char *, __off_t);
#endif
# 445 "/usr/include/stdio.h" 3 4
#endif /* __BSD_VISIBLE */
# 446 "/usr/include/stdio.h" 3 4

/*
 * Functions internal to the implementation.
 */
int	__srget(FILE *);
int	__swbuf(int, FILE *);

/*
 * The __sfoo macros are here so that we can
 * define function versions in the C library.
 */
#define	__sgetc(p) (--(p)->_r < 0 ? __srget(p) : (int)(*(p)->_p++))
#if defined(__GNUC__) && defined(__STDC__)
static __inline int __sputc(int _c, FILE *_p) {
	if (--_p->_w >= 0 || (_p->_w >= _p->_lbfsize && (char)_c != '\n'))
		return (*_p->_p++ = _c);
	else
		return (__swbuf(_c, _p));
}
#else
# 466 "/usr/include/stdio.h" 3 4
/*
 * This has been tuned to generate reasonable code on the vax using pcc.
 */
#define	__sputc(c, p) \
	(--(p)->_w < 0 ? \
		(p)->_w >= (p)->_lbfsize ? \
			(*(p)->_p = (c)), *(p)->_p != '\n' ? \
				(int)*(p)->_p++ : \
				__swbuf('\n', p) : \
			__swbuf((int)(c), p) : \
		(*(p)->_p = (c), (int)*(p)->_p++))
#endif
# 478 "/usr/include/stdio.h" 3 4

extern int __isthreaded;

#ifndef __cplusplus

#define	__sfeof(p)	(((p)->_flags & __SEOF) != 0)
#define	__sferror(p)	(((p)->_flags & __SERR) != 0)
#define	__sclearerr(p)	((void)((p)->_flags &= ~(__SERR|__SEOF)))
#define	__sfileno(p)	((p)->_file)


#define	feof(p)		(!__isthreaded ? __sfeof(p) : (feof)(p))
#define	ferror(p)	(!__isthreaded ? __sferror(p) : (ferror)(p))
#define	clearerr(p)	(!__isthreaded ? __sclearerr(p) : (clearerr)(p))

#if __POSIX_VISIBLE
#define	fileno(p)	(!__isthreaded ? __sfileno(p) : (fileno)(p))
#endif
# 496 "/usr/include/stdio.h" 3 4

#define	getc(fp)	(!__isthreaded ? __sgetc(fp) : (getc)(fp))
#define	putc(x, fp)	(!__isthreaded ? __sputc(x, fp) : (putc)(x, fp))

#define	getchar()	getc(stdin)
#define	putchar(x)	putc(x, stdout)

#if __BSD_VISIBLE
/*
 * See ISO/IEC 9945-1 ANSI/IEEE Std 1003.1 Second Edition 1996-07-12
 * B.8.2.7 for the rationale behind the *_unlocked() macros.
 */
#define	feof_unlocked(p)	__sfeof(p)
#define	ferror_unlocked(p)	__sferror(p)
#define	clearerr_unlocked(p)	__sclearerr(p)
#define	fileno_unlocked(p)	__sfileno(p)
#endif
# 513 "/usr/include/stdio.h" 3 4
#if __POSIX_VISIBLE >= 199506
#define	getc_unlocked(fp)	__sgetc(fp)
#define	putc_unlocked(x, fp)	__sputc(x, fp)

#define	getchar_unlocked()	getc_unlocked(stdin)
#define	putchar_unlocked(x)	putc_unlocked(x, stdout)
#endif
# 520 "/usr/include/stdio.h" 3 4
#endif /* __cplusplus */
# 521 "/usr/include/stdio.h" 3 4

__END_DECLS
#endif /* !_STDIO_H_ */
# 524 "/usr/include/stdio.h" 3 4
# 101 "/usr/include/c++/v1/cstdio" 2 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 104 "/usr/include/c++/v1/cstdio" 3
#endif
# 105 "/usr/include/c++/v1/cstdio" 3

// snprintf
#if defined(_LIBCPP_MSVCRT)
#if 0 /* expanded by -frewrite-includes */
#include "support/win32/support.h"
#endif /* expanded by -frewrite-includes */
# 109 "/usr/include/c++/v1/cstdio" 3
#endif
# 110 "/usr/include/c++/v1/cstdio" 3

#ifdef getc
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_getc(FILE* __stream) {return getc(__stream);}
#undef getc
inline _LIBCPP_INLINE_VISIBILITY int getc(FILE* __stream) {return __libcpp_getc(__stream);}
#endif  // getc
# 116 "/usr/include/c++/v1/cstdio" 3

#ifdef putc
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_putc(int __c, FILE* __stream) {return putc(__c, __stream);}
#undef putc
inline _LIBCPP_INLINE_VISIBILITY int putc(int __c, FILE* __stream) {return __libcpp_putc(__c, __stream);}
#endif  // putc
# 122 "/usr/include/c++/v1/cstdio" 3

_LIBCPP_BEGIN_NAMESPACE_STD

using ::FILE;
using ::fpos_t;
using ::size_t;

using ::remove;
using ::rename;
using ::tmpfile;
using ::tmpnam;
using ::fclose;
using ::fflush;
using ::fopen;
using ::freopen;
using ::setbuf;
using ::setvbuf;
using ::fprintf;
using ::fscanf;
using ::printf;
using ::scanf;
using ::snprintf;
using ::sprintf;
using ::sscanf;
#ifndef _LIBCPP_MSVCRT
using ::vfprintf;
using ::vfscanf;
using ::vscanf;
using ::vsscanf;
#endif // _LIBCPP_MSVCRT
# 152 "/usr/include/c++/v1/cstdio" 3
using ::vprintf;
using ::vsnprintf;
using ::vsprintf;
using ::fgetc;
using ::fgets;
using ::fputc;
using ::fputs;
using ::getc;
using ::getchar;
#if _LIBCPP_STD_VER <= 11
using ::gets;
#endif
# 164 "/usr/include/c++/v1/cstdio" 3
using ::putc;
using ::putchar;
using ::puts;
using ::ungetc;
using ::fread;
using ::fwrite;
using ::fgetpos;
using ::fseek;
using ::fsetpos;
using ::ftell;
using ::rewind;
using ::clearerr;
using ::feof;
using ::ferror;
using ::perror;

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_CSTDIO
# 183 "/usr/include/c++/v1/cstdio" 3
# 438 "/usr/include/c++/v1/string" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <cwchar>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/cwchar" 1 3
// -*- C++ -*-
//===--------------------------- cwchar -----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CWCHAR
#define _LIBCPP_CWCHAR

/*
    cwchar synopsis

Macros:

    NULL
    WCHAR_MAX
    WCHAR_MIN
    WEOF

namespace std
{

Types:

    mbstate_t
    size_t
    tm
    wint_t

int fwprintf(FILE* restrict stream, const wchar_t* restrict format, ...);
int fwscanf(FILE* restrict stream, const wchar_t* restrict format, ...);
int swprintf(wchar_t* restrict s, size_t n, const wchar_t* restrict format, ...);
int swscanf(const wchar_t* restrict s, const wchar_t* restrict format, ...);
int vfwprintf(FILE* restrict stream, const wchar_t* restrict format, va_list arg);
int vfwscanf(FILE* restrict stream, const wchar_t* restrict format, va_list arg);  // C99
int vswprintf(wchar_t* restrict s, size_t n, const wchar_t* restrict format, va_list arg);
int vswscanf(const wchar_t* restrict s, const wchar_t* restrict format, va_list arg);  // C99
int vwprintf(const wchar_t* restrict format, va_list arg);
int vwscanf(const wchar_t* restrict format, va_list arg);  // C99
int wprintf(const wchar_t* restrict format, ...);
int wscanf(const wchar_t* restrict format, ...);
wint_t fgetwc(FILE* stream);
wchar_t* fgetws(wchar_t* restrict s, int n, FILE* restrict stream);
wint_t fputwc(wchar_t c, FILE* stream);
int fputws(const wchar_t* restrict s, FILE* restrict stream);
int fwide(FILE* stream, int mode);
wint_t getwc(FILE* stream);
wint_t getwchar();
wint_t putwc(wchar_t c, FILE* stream);
wint_t putwchar(wchar_t c);
wint_t ungetwc(wint_t c, FILE* stream);
double wcstod(const wchar_t* restrict nptr, wchar_t** restrict endptr);
float wcstof(const wchar_t* restrict nptr, wchar_t** restrict endptr);         // C99
long double wcstold(const wchar_t* restrict nptr, wchar_t** restrict endptr);  // C99
long wcstol(const wchar_t* restrict nptr, wchar_t** restrict endptr, int base);
long long wcstoll(const wchar_t* restrict nptr, wchar_t** restrict endptr, int base);  // C99
unsigned long wcstoul(const wchar_t* restrict nptr, wchar_t** restrict endptr, int base);
unsigned long long wcstoull(const wchar_t* restrict nptr, wchar_t** restrict endptr, int base);  // C99
wchar_t* wcscpy(wchar_t* restrict s1, const wchar_t* restrict s2);
wchar_t* wcsncpy(wchar_t* restrict s1, const wchar_t* restrict s2, size_t n);
wchar_t* wcscat(wchar_t* restrict s1, const wchar_t* restrict s2);
wchar_t* wcsncat(wchar_t* restrict s1, const wchar_t* restrict s2, size_t n);
int wcscmp(const wchar_t* s1, const wchar_t* s2);
int wcscoll(const wchar_t* s1, const wchar_t* s2);
int wcsncmp(const wchar_t* s1, const wchar_t* s2, size_t n);
size_t wcsxfrm(wchar_t* restrict s1, const wchar_t* restrict s2, size_t n);
const wchar_t* wcschr(const wchar_t* s, wchar_t c);
      wchar_t* wcschr(      wchar_t* s, wchar_t c);
size_t wcscspn(const wchar_t* s1, const wchar_t* s2);
size_t wcslen(const wchar_t* s);
const wchar_t* wcspbrk(const wchar_t* s1, const wchar_t* s2);
      wchar_t* wcspbrk(      wchar_t* s1, const wchar_t* s2);
const wchar_t* wcsrchr(const wchar_t* s, wchar_t c);
      wchar_t* wcsrchr(      wchar_t* s, wchar_t c);
size_t wcsspn(const wchar_t* s1, const wchar_t* s2);
const wchar_t* wcsstr(const wchar_t* s1, const wchar_t* s2);
      wchar_t* wcsstr(      wchar_t* s1, const wchar_t* s2);
wchar_t* wcstok(wchar_t* restrict s1, const wchar_t* restrict s2, wchar_t** restrict ptr);
const wchar_t* wmemchr(const wchar_t* s, wchar_t c, size_t n);
      wchar_t* wmemchr(      wchar_t* s, wchar_t c, size_t n);
int wmemcmp(wchar_t* restrict s1, const wchar_t* restrict s2, size_t n);
wchar_t* wmemcpy(wchar_t* restrict s1, const wchar_t* restrict s2, size_t n);
wchar_t* wmemmove(wchar_t* s1, const wchar_t* s2, size_t n);
wchar_t* wmemset(wchar_t* s, wchar_t c, size_t n);
size_t wcsftime(wchar_t* restrict s, size_t maxsize, const wchar_t* restrict format,
                const tm* restrict timeptr);
wint_t btowc(int c);
int wctob(wint_t c);
int mbsinit(const mbstate_t* ps);
size_t mbrlen(const char* restrict s, size_t n, mbstate_t* restrict ps);
size_t mbrtowc(wchar_t* restrict pwc, const char* restrict s, size_t n, mbstate_t* restrict ps);
size_t wcrtomb(char* restrict s, wchar_t wc, mbstate_t* restrict ps);
size_t mbsrtowcs(wchar_t* restrict dst, const char** restrict src, size_t len,
                 mbstate_t* restrict ps);
size_t wcsrtombs(char* restrict dst, const wchar_t** restrict src, size_t len,
                 mbstate_t* restrict ps);

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 107 "/usr/include/c++/v1/cwchar" 3
#if 0 /* expanded by -frewrite-includes */
#include <cwctype>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/cwctype" 1 3
// -*- C++ -*-
//===--------------------------- cwctype ----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CWCTYPE
#define _LIBCPP_CWCTYPE

/*
    cwctype synopsis

Macros:

    WEOF

namespace std
{

Types:

    wint_t
    wctrans_t
    wctype_t

int iswalnum(wint_t wc);
int iswalpha(wint_t wc);
int iswblank(wint_t wc);  // C99
int iswcntrl(wint_t wc);
int iswdigit(wint_t wc);
int iswgraph(wint_t wc);
int iswlower(wint_t wc);
int iswprint(wint_t wc);
int iswpunct(wint_t wc);
int iswspace(wint_t wc);
int iswupper(wint_t wc);
int iswxdigit(wint_t wc);
int iswctype(wint_t wc, wctype_t desc);
wctype_t wctype(const char* property);
wint_t towlower(wint_t wc);
wint_t towupper(wint_t wc);
wint_t towctrans(wint_t wc, wctrans_t desc);
wctrans_t wctrans(const char* property);

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 54 "/usr/include/c++/v1/cwctype" 3
#if 0 /* expanded by -frewrite-includes */
#include <cctype>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/cctype" 1 3
// -*- C++ -*-
//===---------------------------- cctype ----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CCTYPE
#define _LIBCPP_CCTYPE

/*
    cctype synopsis

namespace std
{

int isalnum(int c);
int isalpha(int c);
int isblank(int c);  // C99
int iscntrl(int c);
int isdigit(int c);
int isgraph(int c);
int islower(int c);
int isprint(int c);
int ispunct(int c);
int isspace(int c);
int isupper(int c);
int isxdigit(int c);
int tolower(int c);
int toupper(int c);

}  // std
*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 39 "/usr/include/c++/v1/cctype" 3
#if 0 /* expanded by -frewrite-includes */
#include <ctype.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/ctype.h" 1 3 4
/*
 * Copyright (c) 1989, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * This code is derived from software contributed to Berkeley by
 * Paul Borman at Krystal Technologies.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)ctype.h	8.4 (Berkeley) 1/21/94
 *      $FreeBSD: head/include/ctype.h 233600 2012-03-28 12:11:54Z theraven $
 */

#ifndef _CTYPE_H_
#define	_CTYPE_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 45 "/usr/include/ctype.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 46 "/usr/include/ctype.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <_ctype.h>
#endif /* expanded by -frewrite-includes */
# 47 "/usr/include/ctype.h" 3 4

__BEGIN_DECLS
int	isalnum(int);
int	isalpha(int);
int	iscntrl(int);
int	isdigit(int);
int	isgraph(int);
int	islower(int);
int	isprint(int);
int	ispunct(int);
int	isspace(int);
int	isupper(int);
int	isxdigit(int);
int	tolower(int);
int	toupper(int);

#if __XSI_VISIBLE
int	isascii(int);
int	toascii(int);
#endif
# 67 "/usr/include/ctype.h" 3 4

#if __ISO_C_VISIBLE >= 1999
int	isblank(int);
#endif
# 71 "/usr/include/ctype.h" 3 4

#if __BSD_VISIBLE
int	digittoint(int);
int	ishexnumber(int);
int	isideogram(int);
int	isnumber(int);
int	isphonogram(int);
int	isrune(int);
int	isspecial(int);
#endif
# 81 "/usr/include/ctype.h" 3 4

#if __POSIX_VISIBLE >= 200809 || defined(_XLOCALE_H_)
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_ctype.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/xlocale/_ctype.h" 1 3 4
/*-
 * Copyright (c) 2011 The FreeBSD Foundation
 * All rights reserved.
 *
 * This software was developed by David Chisnall under sponsorship from
 * the FreeBSD Foundation.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/include/xlocale/_ctype.h 243032 2012-11-14 17:44:37Z demon $
 */


#if	(defined(_XLOCALE_WCTYPES) && !defined(_XLOCALE_WCTYPE_H)) || \
	(!defined(_XLOCALE_WCTYPES) && !defined(_XLOCALE_CTYPE_H))

#ifdef _XLOCALE_WCTYPES
#define _XLOCALE_WCTYPE_H
#else
# 39 "/usr/include/xlocale/_ctype.h" 3 4
#define _XLOCALE_CTYPE_H
#endif
# 41 "/usr/include/xlocale/_ctype.h" 3 4

#ifndef _LOCALE_T_DEFINED
#define _LOCALE_T_DEFINED
typedef struct	_xlocale *locale_t;
#endif
# 46 "/usr/include/xlocale/_ctype.h" 3 4

#ifndef _XLOCALE_RUN_FUNCTIONS_DEFINED
#define _XLOCALE_RUN_FUNCTIONS_DEFINED 1
unsigned long	 ___runetype_l(__ct_rune_t, locale_t) __pure;
__ct_rune_t	 ___tolower_l(__ct_rune_t, locale_t) __pure;
__ct_rune_t	 ___toupper_l(__ct_rune_t, locale_t) __pure;
_RuneLocale	*__runes_for_locale(locale_t, int*);
#endif
# 54 "/usr/include/xlocale/_ctype.h" 3 4

#ifndef _XLOCALE_INLINE
#if defined(__GNUC__) && !defined(__GNUC_STDC_INLINE__)
/* GNU89 inline has nonstandard semantics. */
#define _XLOCALE_INLINE extern __inline
#else
# 60 "/usr/include/xlocale/_ctype.h" 3 4
/* Hack to work around people who define inline away */
#ifdef inline
#define _XLOCALE_INLINE static __inline
#else
# 64 "/usr/include/xlocale/_ctype.h" 3 4
/* Define with C++ / C99 compatible semantics */
#define _XLOCALE_INLINE inline
#endif
# 67 "/usr/include/xlocale/_ctype.h" 3 4
#endif
# 68 "/usr/include/xlocale/_ctype.h" 3 4
#endif /* _XLOCALE_INLINE */
# 69 "/usr/include/xlocale/_ctype.h" 3 4

#ifdef _XLOCALE_WCTYPES
_XLOCALE_INLINE int
__maskrune_l(__ct_rune_t __c, unsigned long __f, locale_t __loc);
_XLOCALE_INLINE int
__istype_l(__ct_rune_t __c, unsigned long __f, locale_t __loc);

_XLOCALE_INLINE int
__maskrune_l(__ct_rune_t __c, unsigned long __f, locale_t __loc)
{
	int __limit;
	_RuneLocale *runes = __runes_for_locale(__loc, &__limit);
	return ((__c < 0 || __c >= _CACHED_RUNES) ? ___runetype_l(__c, __loc) :
	        runes->__runetype[__c]) & __f;
}

_XLOCALE_INLINE int
__istype_l(__ct_rune_t __c, unsigned long __f, locale_t __loc)
{
	return (!!__maskrune_l(__c, __f, __loc));
}

#define XLOCALE_ISCTYPE(fname, cat) \
		_XLOCALE_INLINE int isw##fname##_l(int, locale_t);\
		_XLOCALE_INLINE int isw##fname##_l(int __c, locale_t __l)\
		{ return __istype_l(__c, cat, __l); }
#else
# 96 "/usr/include/xlocale/_ctype.h" 3 4
_XLOCALE_INLINE int
__sbmaskrune_l(__ct_rune_t __c, unsigned long __f, locale_t __loc);
_XLOCALE_INLINE int
__sbistype_l(__ct_rune_t __c, unsigned long __f, locale_t __loc);

_XLOCALE_INLINE int
__sbmaskrune_l(__ct_rune_t __c, unsigned long __f, locale_t __loc)
{
	int __limit;
	_RuneLocale *runes = __runes_for_locale(__loc, &__limit);
	return (__c < 0 || __c >= __limit) ? 0 :
	       runes->__runetype[__c] & __f;
}

_XLOCALE_INLINE int
__sbistype_l(__ct_rune_t __c, unsigned long __f, locale_t __loc)
{
	return (!!__sbmaskrune_l(__c, __f, __loc));
}

#define XLOCALE_ISCTYPE(__fname, __cat) \
		_XLOCALE_INLINE int is##__fname##_l(int, locale_t); \
		_XLOCALE_INLINE int is##__fname##_l(int __c, locale_t __l)\
		{ return __sbistype_l(__c, __cat, __l); }
#endif
# 121 "/usr/include/xlocale/_ctype.h" 3 4

XLOCALE_ISCTYPE(alnum, _CTYPE_A|_CTYPE_D)
XLOCALE_ISCTYPE(alpha, _CTYPE_A)
XLOCALE_ISCTYPE(blank, _CTYPE_B)
XLOCALE_ISCTYPE(cntrl, _CTYPE_C)
XLOCALE_ISCTYPE(digit, _CTYPE_D)
XLOCALE_ISCTYPE(graph, _CTYPE_G)
XLOCALE_ISCTYPE(hexnumber, _CTYPE_X)
XLOCALE_ISCTYPE(ideogram, _CTYPE_I)
XLOCALE_ISCTYPE(lower, _CTYPE_L)
XLOCALE_ISCTYPE(number, _CTYPE_D)
XLOCALE_ISCTYPE(phonogram, _CTYPE_Q)
XLOCALE_ISCTYPE(print, _CTYPE_R)
XLOCALE_ISCTYPE(punct, _CTYPE_P)
XLOCALE_ISCTYPE(rune, 0xFFFFFF00L)
XLOCALE_ISCTYPE(space, _CTYPE_S)
XLOCALE_ISCTYPE(special, _CTYPE_T)
XLOCALE_ISCTYPE(upper, _CTYPE_U)
XLOCALE_ISCTYPE(xdigit, _CTYPE_X)
#undef XLOCALE_ISCTYPE

#ifdef _XLOCALE_WCTYPES
_XLOCALE_INLINE int towlower_l(int, locale_t);
_XLOCALE_INLINE int __wcwidth_l(__ct_rune_t, locale_t);
_XLOCALE_INLINE int towupper_l(int, locale_t);

_XLOCALE_INLINE int towlower_l(int __c, locale_t __l)
{
	int __limit;
	_RuneLocale *__runes = __runes_for_locale(__l, &__limit);
	return (__c < 0 || __c >= _CACHED_RUNES) ? ___tolower_l(__c, __l) :
	       __runes->__maplower[__c];
}
_XLOCALE_INLINE int towupper_l(int __c, locale_t __l)
{
	int __limit;
	_RuneLocale *__runes = __runes_for_locale(__l, &__limit);
	return (__c < 0 || __c >= _CACHED_RUNES) ? ___toupper_l(__c, __l) :
	       __runes->__mapupper[__c];
}
_XLOCALE_INLINE int
__wcwidth_l(__ct_rune_t _c, locale_t __l)
{
	unsigned int _x;

	if (_c == 0)
		return (0);
	_x = (unsigned int)__maskrune_l(_c, _CTYPE_SWM|_CTYPE_R, __l);
	if ((_x & _CTYPE_SWM) != 0)
		return ((_x & _CTYPE_SWM) >> _CTYPE_SWS);
	return ((_x & _CTYPE_R) != 0 ? 1 : -1);
}
int iswctype_l(wint_t __wc, wctype_t __charclass, locale_t __l);
wctype_t wctype_l(const char *property, locale_t __l);
wint_t towctrans_l(wint_t __wc, wctrans_t desc, locale_t __l);
wint_t nextwctype_l(wint_t __wc, wctype_t wct, locale_t __l);
wctrans_t wctrans_l(const char *__charclass, locale_t __l);
#undef _XLOCALE_WCTYPES
#else
# 180 "/usr/include/xlocale/_ctype.h" 3 4
_XLOCALE_INLINE int digittoint_l(int, locale_t);
_XLOCALE_INLINE int tolower_l(int, locale_t);
_XLOCALE_INLINE int toupper_l(int, locale_t);

_XLOCALE_INLINE int digittoint_l(int __c, locale_t __l)
{ return __sbmaskrune_l((__c), 0xFF, __l); }

_XLOCALE_INLINE int tolower_l(int __c, locale_t __l)
{
	int __limit;
	_RuneLocale *__runes = __runes_for_locale(__l, &__limit);
	return (__c < 0 || __c >= __limit) ? __c :
	       __runes->__maplower[__c];
}
_XLOCALE_INLINE int toupper_l(int __c, locale_t __l)
{
	int __limit;
	_RuneLocale *__runes = __runes_for_locale(__l, &__limit);
	return (__c < 0 || __c >= __limit) ? __c :
	       __runes->__mapupper[__c];
}
#endif
# 202 "/usr/include/xlocale/_ctype.h" 3 4
#endif /* (defined(_XLOCALE_WCTYPES) && !defined(_XLOCALE_WCTYPE_H)) || \
	(!defined(_XLOCALE_WCTYPES) && !defined(_XLOCALE_CTYPE_H)) */
# 204 "/usr/include/xlocale/_ctype.h" 3 4
# 84 "/usr/include/ctype.h" 2 3 4
#endif
# 85 "/usr/include/ctype.h" 3 4
__END_DECLS

#ifndef __cplusplus
#define	isalnum(c)	__sbistype((c), _CTYPE_A|_CTYPE_D)
#define	isalpha(c)	__sbistype((c), _CTYPE_A)
#define	iscntrl(c)	__sbistype((c), _CTYPE_C)
#define	isdigit(c)	__isctype((c), _CTYPE_D) /* ANSI -- locale independent */
#define	isgraph(c)	__sbistype((c), _CTYPE_G)
#define	islower(c)	__sbistype((c), _CTYPE_L)
#define	isprint(c)	__sbistype((c), _CTYPE_R)
#define	ispunct(c)	__sbistype((c), _CTYPE_P)
#define	isspace(c)	__sbistype((c), _CTYPE_S)
#define	isupper(c)	__sbistype((c), _CTYPE_U)
#define	isxdigit(c)	__isctype((c), _CTYPE_X) /* ANSI -- locale independent */
#define	tolower(c)	__sbtolower(c)
#define	toupper(c)	__sbtoupper(c)
#endif /* !__cplusplus */
# 102 "/usr/include/ctype.h" 3 4

#if __XSI_VISIBLE
/*
 * POSIX.1-2001 specifies _tolower() and _toupper() to be macros equivalent to
 * tolower() and toupper() respectively, minus extra checking to ensure that
 * the argument is a lower or uppercase letter respectively.  We've chosen to
 * implement these macros with the same error checking as tolower() and
 * toupper() since this doesn't violate the specification itself, only its
 * intent.  We purposely leave _tolower() and _toupper() undocumented to
 * discourage their use.
 *
 * XXX isascii() and toascii() should similarly be undocumented.
 */
#define	_tolower(c)	__sbtolower(c)
#define	_toupper(c)	__sbtoupper(c)
#define	isascii(c)	(((c) & ~0x7F) == 0)
#define	toascii(c)	((c) & 0x7F)
#endif
# 120 "/usr/include/ctype.h" 3 4

#if __ISO_C_VISIBLE >= 1999 && !defined(__cplusplus)
#define	isblank(c)	__sbistype((c), _CTYPE_B)
#endif
# 124 "/usr/include/ctype.h" 3 4

#if __BSD_VISIBLE
#define	digittoint(c)	__sbmaskrune((c), 0xFF)
#define	ishexnumber(c)	__sbistype((c), _CTYPE_X)
#define	isideogram(c)	__sbistype((c), _CTYPE_I)
#define	isnumber(c)	__sbistype((c), _CTYPE_D)
#define	isphonogram(c)	__sbistype((c), _CTYPE_Q)
#define	isrune(c)	__sbistype((c), 0xFFFFFF00L)
#define	isspecial(c)	__sbistype((c), _CTYPE_T)
#endif
# 134 "/usr/include/ctype.h" 3 4

#endif /* !_CTYPE_H_ */
# 136 "/usr/include/ctype.h" 3 4
# 40 "/usr/include/c++/v1/cctype" 2 3
#if defined(_LIBCPP_MSVCRT)
#if 0 /* expanded by -frewrite-includes */
#include "support/win32/support.h"
#endif /* expanded by -frewrite-includes */
# 42 "/usr/include/c++/v1/cctype" 3
#endif // _LIBCPP_MSVCRT
# 43 "/usr/include/c++/v1/cctype" 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 46 "/usr/include/c++/v1/cctype" 3
#endif
# 47 "/usr/include/c++/v1/cctype" 3

_LIBCPP_BEGIN_NAMESPACE_STD

#ifdef isalnum
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_isalnum(int __c) {return isalnum(__c);}
#undef isalnum
inline _LIBCPP_INLINE_VISIBILITY int isalnum(int __c) {return __libcpp_isalnum(__c);}
#else  // isalnum
# 55 "/usr/include/c++/v1/cctype" 3
using ::isalnum;
#endif  // isalnum
# 57 "/usr/include/c++/v1/cctype" 3

#ifdef isalpha
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_isalpha(int __c) {return isalpha(__c);}
#undef isalpha
inline _LIBCPP_INLINE_VISIBILITY int isalpha(int __c) {return __libcpp_isalpha(__c);}
#else  // isalpha
# 63 "/usr/include/c++/v1/cctype" 3
using ::isalpha;
#endif  // isalpha
# 65 "/usr/include/c++/v1/cctype" 3

#ifdef isblank
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_isblank(int __c) {return isblank(__c);}
#undef isblank
inline _LIBCPP_INLINE_VISIBILITY int isblank(int __c) {return __libcpp_isblank(__c);}
#else  // isblank
# 71 "/usr/include/c++/v1/cctype" 3
using ::isblank;
#endif  // isblank
# 73 "/usr/include/c++/v1/cctype" 3

#ifdef iscntrl
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_iscntrl(int __c) {return iscntrl(__c);}
#undef iscntrl
inline _LIBCPP_INLINE_VISIBILITY int iscntrl(int __c) {return __libcpp_iscntrl(__c);}
#else  // iscntrl
# 79 "/usr/include/c++/v1/cctype" 3
using ::iscntrl;
#endif  // iscntrl
# 81 "/usr/include/c++/v1/cctype" 3

#ifdef isdigit
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_isdigit(int __c) {return isdigit(__c);}
#undef isdigit
inline _LIBCPP_INLINE_VISIBILITY int isdigit(int __c) {return __libcpp_isdigit(__c);}
#else  // isdigit
# 87 "/usr/include/c++/v1/cctype" 3
using ::isdigit;
#endif  // isdigit
# 89 "/usr/include/c++/v1/cctype" 3

#ifdef isgraph
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_isgraph(int __c) {return isgraph(__c);}
#undef isgraph
inline _LIBCPP_INLINE_VISIBILITY int isgraph(int __c) {return __libcpp_isgraph(__c);}
#else  // isgraph
# 95 "/usr/include/c++/v1/cctype" 3
using ::isgraph;
#endif  // isgraph
# 97 "/usr/include/c++/v1/cctype" 3

#ifdef islower
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_islower(int __c) {return islower(__c);}
#undef islower
inline _LIBCPP_INLINE_VISIBILITY int islower(int __c) {return __libcpp_islower(__c);}
#else  // islower
# 103 "/usr/include/c++/v1/cctype" 3
using ::islower;
#endif  // islower
# 105 "/usr/include/c++/v1/cctype" 3

#ifdef isprint
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_isprint(int __c) {return isprint(__c);}
#undef isprint
inline _LIBCPP_INLINE_VISIBILITY int isprint(int __c) {return __libcpp_isprint(__c);}
#else  // isprint
# 111 "/usr/include/c++/v1/cctype" 3
using ::isprint;
#endif  // isprint
# 113 "/usr/include/c++/v1/cctype" 3

#ifdef ispunct
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_ispunct(int __c) {return ispunct(__c);}
#undef ispunct
inline _LIBCPP_INLINE_VISIBILITY int ispunct(int __c) {return __libcpp_ispunct(__c);}
#else  // ispunct
# 119 "/usr/include/c++/v1/cctype" 3
using ::ispunct;
#endif  // ispunct
# 121 "/usr/include/c++/v1/cctype" 3

#ifdef isspace
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_isspace(int __c) {return isspace(__c);}
#undef isspace
inline _LIBCPP_INLINE_VISIBILITY int isspace(int __c) {return __libcpp_isspace(__c);}
#else  // isspace
# 127 "/usr/include/c++/v1/cctype" 3
using ::isspace;
#endif  // isspace
# 129 "/usr/include/c++/v1/cctype" 3

#ifdef isupper
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_isupper(int __c) {return isupper(__c);}
#undef isupper
inline _LIBCPP_INLINE_VISIBILITY int isupper(int __c) {return __libcpp_isupper(__c);}
#else  // isupper
# 135 "/usr/include/c++/v1/cctype" 3
using ::isupper;
#endif  // isupper
# 137 "/usr/include/c++/v1/cctype" 3

#ifdef isxdigit
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_isxdigit(int __c) {return isxdigit(__c);}
#undef isxdigit
inline _LIBCPP_INLINE_VISIBILITY int isxdigit(int __c) {return __libcpp_isxdigit(__c);}
#else  // isxdigit
# 143 "/usr/include/c++/v1/cctype" 3
using ::isxdigit;
#endif  // isxdigit
# 145 "/usr/include/c++/v1/cctype" 3

#ifdef tolower
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_tolower(int __c) {return tolower(__c);}
#undef tolower
inline _LIBCPP_INLINE_VISIBILITY int tolower(int __c) {return __libcpp_tolower(__c);}
#else  // tolower
# 151 "/usr/include/c++/v1/cctype" 3
using ::tolower;
#endif  // tolower
# 153 "/usr/include/c++/v1/cctype" 3

#ifdef toupper
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_toupper(int __c) {return toupper(__c);}
#undef toupper
inline _LIBCPP_INLINE_VISIBILITY int toupper(int __c) {return __libcpp_toupper(__c);}
#else  // toupper
# 159 "/usr/include/c++/v1/cctype" 3
using ::toupper;
#endif  // toupper
# 161 "/usr/include/c++/v1/cctype" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_CCTYPE
# 165 "/usr/include/c++/v1/cctype" 3
# 55 "/usr/include/c++/v1/cwctype" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <wctype.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/wctype.h" 1 3 4
/*-
 * Copyright (c)1999 Citrus Project,
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	citrus Id: wctype.h,v 1.4 2000/12/21 01:50:21 itojun Exp
 *	$NetBSD: wctype.h,v 1.3 2000/12/22 14:16:16 itojun Exp $
 * $FreeBSD: head/include/wctype.h 232498 2012-03-04 15:31:13Z theraven $
 */

#ifndef _WCTYPE_H_
#define	_WCTYPE_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 35 "/usr/include/wctype.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 36 "/usr/include/wctype.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <_ctype.h>
#endif /* expanded by -frewrite-includes */
# 38 "/usr/include/wctype.h" 3 4

#ifndef _WCTRANS_T
typedef	int	wctrans_t;
#define	_WCTRANS_T
#endif
# 43 "/usr/include/wctype.h" 3 4

#ifndef _WCTYPE_T
typedef	unsigned long	wctype_t;
#define	_WCTYPE_T
#endif
# 48 "/usr/include/wctype.h" 3 4

#ifndef _WINT_T_DECLARED
typedef	__wint_t	wint_t;
#define	_WINT_T_DECLARED
#endif
# 53 "/usr/include/wctype.h" 3 4

#ifndef WEOF
#define	WEOF	((wint_t)-1)
#endif
# 57 "/usr/include/wctype.h" 3 4

__BEGIN_DECLS
int	iswalnum(wint_t);
int	iswalpha(wint_t);
int	iswblank(wint_t);
int	iswcntrl(wint_t);
int	iswctype(wint_t, wctype_t);
int	iswdigit(wint_t);
int	iswgraph(wint_t);
int	iswlower(wint_t);
int	iswprint(wint_t);
int	iswpunct(wint_t);
int	iswspace(wint_t);
int	iswupper(wint_t);
int	iswxdigit(wint_t);
wint_t	towctrans(wint_t, wctrans_t);
wint_t	towlower(wint_t);
wint_t	towupper(wint_t);
wctrans_t
	wctrans(const char *);
wctype_t
	wctype(const char *);

#if __BSD_VISIBLE
wint_t	iswascii(wint_t);
wint_t	iswhexnumber(wint_t);
wint_t	iswideogram(wint_t);
wint_t	iswnumber(wint_t);
wint_t	iswphonogram(wint_t);
wint_t	iswrune(wint_t);
wint_t	iswspecial(wint_t);
wint_t	nextwctype(wint_t, wctype_t);
#endif
# 90 "/usr/include/wctype.h" 3 4

#if __POSIX_VISIBLE >= 200809
#define _XLOCALE_WCTYPES 1
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_ctype.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/xlocale/_ctype.h" 1 3 4
/*-
 * Copyright (c) 2011 The FreeBSD Foundation
 * All rights reserved.
 *
 * This software was developed by David Chisnall under sponsorship from
 * the FreeBSD Foundation.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/include/xlocale/_ctype.h 243032 2012-11-14 17:44:37Z demon $
 */


#if	(defined(_XLOCALE_WCTYPES) && !defined(_XLOCALE_WCTYPE_H)) || \
	(!defined(_XLOCALE_WCTYPES) && !defined(_XLOCALE_CTYPE_H))

#ifdef _XLOCALE_WCTYPES
#define _XLOCALE_WCTYPE_H
#else
# 39 "/usr/include/xlocale/_ctype.h" 3 4
#define _XLOCALE_CTYPE_H
#endif
# 41 "/usr/include/xlocale/_ctype.h" 3 4

#ifndef _LOCALE_T_DEFINED
#define _LOCALE_T_DEFINED
typedef struct	_xlocale *locale_t;
#endif
# 46 "/usr/include/xlocale/_ctype.h" 3 4

#ifndef _XLOCALE_RUN_FUNCTIONS_DEFINED
#define _XLOCALE_RUN_FUNCTIONS_DEFINED 1
unsigned long	 ___runetype_l(__ct_rune_t, locale_t) __pure;
__ct_rune_t	 ___tolower_l(__ct_rune_t, locale_t) __pure;
__ct_rune_t	 ___toupper_l(__ct_rune_t, locale_t) __pure;
_RuneLocale	*__runes_for_locale(locale_t, int*);
#endif
# 54 "/usr/include/xlocale/_ctype.h" 3 4

#ifndef _XLOCALE_INLINE
#if defined(__GNUC__) && !defined(__GNUC_STDC_INLINE__)
/* GNU89 inline has nonstandard semantics. */
#define _XLOCALE_INLINE extern __inline
#else
# 60 "/usr/include/xlocale/_ctype.h" 3 4
/* Hack to work around people who define inline away */
#ifdef inline
#define _XLOCALE_INLINE static __inline
#else
# 64 "/usr/include/xlocale/_ctype.h" 3 4
/* Define with C++ / C99 compatible semantics */
#define _XLOCALE_INLINE inline
#endif
# 67 "/usr/include/xlocale/_ctype.h" 3 4
#endif
# 68 "/usr/include/xlocale/_ctype.h" 3 4
#endif /* _XLOCALE_INLINE */
# 69 "/usr/include/xlocale/_ctype.h" 3 4

#ifdef _XLOCALE_WCTYPES
_XLOCALE_INLINE int
__maskrune_l(__ct_rune_t __c, unsigned long __f, locale_t __loc);
_XLOCALE_INLINE int
__istype_l(__ct_rune_t __c, unsigned long __f, locale_t __loc);

_XLOCALE_INLINE int
__maskrune_l(__ct_rune_t __c, unsigned long __f, locale_t __loc)
{
	int __limit;
	_RuneLocale *runes = __runes_for_locale(__loc, &__limit);
	return ((__c < 0 || __c >= _CACHED_RUNES) ? ___runetype_l(__c, __loc) :
	        runes->__runetype[__c]) & __f;
}

_XLOCALE_INLINE int
__istype_l(__ct_rune_t __c, unsigned long __f, locale_t __loc)
{
	return (!!__maskrune_l(__c, __f, __loc));
}

#define XLOCALE_ISCTYPE(fname, cat) \
		_XLOCALE_INLINE int isw##fname##_l(int, locale_t);\
		_XLOCALE_INLINE int isw##fname##_l(int __c, locale_t __l)\
		{ return __istype_l(__c, cat, __l); }
#else
# 96 "/usr/include/xlocale/_ctype.h" 3 4
_XLOCALE_INLINE int
__sbmaskrune_l(__ct_rune_t __c, unsigned long __f, locale_t __loc);
_XLOCALE_INLINE int
__sbistype_l(__ct_rune_t __c, unsigned long __f, locale_t __loc);

_XLOCALE_INLINE int
__sbmaskrune_l(__ct_rune_t __c, unsigned long __f, locale_t __loc)
{
	int __limit;
	_RuneLocale *runes = __runes_for_locale(__loc, &__limit);
	return (__c < 0 || __c >= __limit) ? 0 :
	       runes->__runetype[__c] & __f;
}

_XLOCALE_INLINE int
__sbistype_l(__ct_rune_t __c, unsigned long __f, locale_t __loc)
{
	return (!!__sbmaskrune_l(__c, __f, __loc));
}

#define XLOCALE_ISCTYPE(__fname, __cat) \
		_XLOCALE_INLINE int is##__fname##_l(int, locale_t); \
		_XLOCALE_INLINE int is##__fname##_l(int __c, locale_t __l)\
		{ return __sbistype_l(__c, __cat, __l); }
#endif
# 121 "/usr/include/xlocale/_ctype.h" 3 4

XLOCALE_ISCTYPE(alnum, _CTYPE_A|_CTYPE_D)
XLOCALE_ISCTYPE(alpha, _CTYPE_A)
XLOCALE_ISCTYPE(blank, _CTYPE_B)
XLOCALE_ISCTYPE(cntrl, _CTYPE_C)
XLOCALE_ISCTYPE(digit, _CTYPE_D)
XLOCALE_ISCTYPE(graph, _CTYPE_G)
XLOCALE_ISCTYPE(hexnumber, _CTYPE_X)
XLOCALE_ISCTYPE(ideogram, _CTYPE_I)
XLOCALE_ISCTYPE(lower, _CTYPE_L)
XLOCALE_ISCTYPE(number, _CTYPE_D)
XLOCALE_ISCTYPE(phonogram, _CTYPE_Q)
XLOCALE_ISCTYPE(print, _CTYPE_R)
XLOCALE_ISCTYPE(punct, _CTYPE_P)
XLOCALE_ISCTYPE(rune, 0xFFFFFF00L)
XLOCALE_ISCTYPE(space, _CTYPE_S)
XLOCALE_ISCTYPE(special, _CTYPE_T)
XLOCALE_ISCTYPE(upper, _CTYPE_U)
XLOCALE_ISCTYPE(xdigit, _CTYPE_X)
#undef XLOCALE_ISCTYPE

#ifdef _XLOCALE_WCTYPES
_XLOCALE_INLINE int towlower_l(int, locale_t);
_XLOCALE_INLINE int __wcwidth_l(__ct_rune_t, locale_t);
_XLOCALE_INLINE int towupper_l(int, locale_t);

_XLOCALE_INLINE int towlower_l(int __c, locale_t __l)
{
	int __limit;
	_RuneLocale *__runes = __runes_for_locale(__l, &__limit);
	return (__c < 0 || __c >= _CACHED_RUNES) ? ___tolower_l(__c, __l) :
	       __runes->__maplower[__c];
}
_XLOCALE_INLINE int towupper_l(int __c, locale_t __l)
{
	int __limit;
	_RuneLocale *__runes = __runes_for_locale(__l, &__limit);
	return (__c < 0 || __c >= _CACHED_RUNES) ? ___toupper_l(__c, __l) :
	       __runes->__mapupper[__c];
}
_XLOCALE_INLINE int
__wcwidth_l(__ct_rune_t _c, locale_t __l)
{
	unsigned int _x;

	if (_c == 0)
		return (0);
	_x = (unsigned int)__maskrune_l(_c, _CTYPE_SWM|_CTYPE_R, __l);
	if ((_x & _CTYPE_SWM) != 0)
		return ((_x & _CTYPE_SWM) >> _CTYPE_SWS);
	return ((_x & _CTYPE_R) != 0 ? 1 : -1);
}
int iswctype_l(wint_t __wc, wctype_t __charclass, locale_t __l);
wctype_t wctype_l(const char *property, locale_t __l);
wint_t towctrans_l(wint_t __wc, wctrans_t desc, locale_t __l);
wint_t nextwctype_l(wint_t __wc, wctype_t wct, locale_t __l);
wctrans_t wctrans_l(const char *__charclass, locale_t __l);
#undef _XLOCALE_WCTYPES
#else
# 180 "/usr/include/xlocale/_ctype.h" 3 4
_XLOCALE_INLINE int digittoint_l(int, locale_t);
_XLOCALE_INLINE int tolower_l(int, locale_t);
_XLOCALE_INLINE int toupper_l(int, locale_t);

_XLOCALE_INLINE int digittoint_l(int __c, locale_t __l)
{ return __sbmaskrune_l((__c), 0xFF, __l); }

_XLOCALE_INLINE int tolower_l(int __c, locale_t __l)
{
	int __limit;
	_RuneLocale *__runes = __runes_for_locale(__l, &__limit);
	return (__c < 0 || __c >= __limit) ? __c :
	       __runes->__maplower[__c];
}
_XLOCALE_INLINE int toupper_l(int __c, locale_t __l)
{
	int __limit;
	_RuneLocale *__runes = __runes_for_locale(__l, &__limit);
	return (__c < 0 || __c >= __limit) ? __c :
	       __runes->__mapupper[__c];
}
#endif
# 202 "/usr/include/xlocale/_ctype.h" 3 4
#endif /* (defined(_XLOCALE_WCTYPES) && !defined(_XLOCALE_WCTYPE_H)) || \
	(!defined(_XLOCALE_WCTYPES) && !defined(_XLOCALE_CTYPE_H)) */
# 204 "/usr/include/xlocale/_ctype.h" 3 4
# 94 "/usr/include/wctype.h" 2 3 4
#endif /* __POSIX_VISIBLE >= 200809 */
# 95 "/usr/include/wctype.h" 3 4
__END_DECLS

#ifndef __cplusplus
#define	iswalnum(wc)		__istype((wc), _CTYPE_A|_CTYPE_D)
#define	iswalpha(wc)		__istype((wc), _CTYPE_A)
#define	iswblank(wc)		__istype((wc), _CTYPE_B)
#define	iswcntrl(wc)		__istype((wc), _CTYPE_C)
#define	iswctype(wc, charclass)	__istype((wc), (charclass))
#define	iswdigit(wc)		__isctype((wc), _CTYPE_D)
#define	iswgraph(wc)		__istype((wc), _CTYPE_G)
#define	iswlower(wc)		__istype((wc), _CTYPE_L)
#define	iswprint(wc)		__istype((wc), _CTYPE_R)
#define	iswpunct(wc)		__istype((wc), _CTYPE_P)
#define	iswspace(wc)		__istype((wc), _CTYPE_S)
#define	iswupper(wc)		__istype((wc), _CTYPE_U)
#define	iswxdigit(wc)		__isctype((wc), _CTYPE_X)
#define	towlower(wc)		__tolower(wc)
#define	towupper(wc)		__toupper(wc)

#if __BSD_VISIBLE
#define	iswascii(wc)		(((wc) & ~0x7F) == 0)
#define	iswhexnumber(wc)	__istype((wc), _CTYPE_X)
#define	iswideogram(wc)		__istype((wc), _CTYPE_I)
#define	iswnumber(wc)		__istype((wc), _CTYPE_D)
#define	iswphonogram(wc)	__istype((wc), _CTYPE_Q)
#define	iswrune(wc)		__istype((wc), 0xFFFFFF00L)
#define	iswspecial(wc)		__istype((wc), _CTYPE_T)
#endif /* __BSD_VISIBLE */
# 123 "/usr/include/wctype.h" 3 4
#endif /* __cplusplus */
# 124 "/usr/include/wctype.h" 3 4

#endif		/* _WCTYPE_H_ */
# 126 "/usr/include/wctype.h" 3 4
# 56 "/usr/include/c++/v1/cwctype" 2 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 59 "/usr/include/c++/v1/cwctype" 3
#endif
# 60 "/usr/include/c++/v1/cwctype" 3

_LIBCPP_BEGIN_NAMESPACE_STD

using ::wint_t;
using ::wctrans_t;
using ::wctype_t;

#ifdef iswalnum
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_iswalnum(wint_t __wc) {return iswalnum(__wc);}
#undef iswalnum
inline _LIBCPP_INLINE_VISIBILITY int iswalnum(wint_t __wc) {return __libcpp_iswalnum(__wc);}
#else  // iswalnum
# 72 "/usr/include/c++/v1/cwctype" 3
using ::iswalnum;
#endif
# 74 "/usr/include/c++/v1/cwctype" 3

#ifdef iswalpha
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_iswalpha(wint_t __wc) {return iswalpha(__wc);}
#undef iswalpha
inline _LIBCPP_INLINE_VISIBILITY int iswalpha(wint_t __wc) {return __libcpp_iswalpha(__wc);}
#else  // iswalpha
# 80 "/usr/include/c++/v1/cwctype" 3
using ::iswalpha;
#endif
# 82 "/usr/include/c++/v1/cwctype" 3

#ifdef iswblank
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_iswblank(wint_t __wc) {return iswblank(__wc);}
#undef iswblank
inline _LIBCPP_INLINE_VISIBILITY int iswblank(wint_t __wc) {return __libcpp_iswblank(__wc);}
#else  // iswblank
# 88 "/usr/include/c++/v1/cwctype" 3
using ::iswblank;
#endif
# 90 "/usr/include/c++/v1/cwctype" 3

#ifdef iswcntrl
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_iswcntrl(wint_t __wc) {return iswcntrl(__wc);}
#undef iswcntrl
inline _LIBCPP_INLINE_VISIBILITY int iswcntrl(wint_t __wc) {return __libcpp_iswcntrl(__wc);}
#else  // iswcntrl
# 96 "/usr/include/c++/v1/cwctype" 3
using ::iswcntrl;
#endif
# 98 "/usr/include/c++/v1/cwctype" 3

#ifdef iswdigit
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_iswdigit(wint_t __wc) {return iswdigit(__wc);}
#undef iswdigit
inline _LIBCPP_INLINE_VISIBILITY int iswdigit(wint_t __wc) {return __libcpp_iswdigit(__wc);}
#else  // iswdigit
# 104 "/usr/include/c++/v1/cwctype" 3
using ::iswdigit;
#endif
# 106 "/usr/include/c++/v1/cwctype" 3

#ifdef iswgraph
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_iswgraph(wint_t __wc) {return iswgraph(__wc);}
#undef iswgraph
inline _LIBCPP_INLINE_VISIBILITY int iswgraph(wint_t __wc) {return __libcpp_iswgraph(__wc);}
#else  // iswgraph
# 112 "/usr/include/c++/v1/cwctype" 3
using ::iswgraph;
#endif
# 114 "/usr/include/c++/v1/cwctype" 3

#ifdef iswlower
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_iswlower(wint_t __wc) {return iswlower(__wc);}
#undef iswlower
inline _LIBCPP_INLINE_VISIBILITY int iswlower(wint_t __wc) {return __libcpp_iswlower(__wc);}
#else  // iswlower
# 120 "/usr/include/c++/v1/cwctype" 3
using ::iswlower;
#endif
# 122 "/usr/include/c++/v1/cwctype" 3

#ifdef iswprint
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_iswprint(wint_t __wc) {return iswprint(__wc);}
#undef iswprint
inline _LIBCPP_INLINE_VISIBILITY int iswprint(wint_t __wc) {return __libcpp_iswprint(__wc);}
#else  // iswprint
# 128 "/usr/include/c++/v1/cwctype" 3
using ::iswprint;
#endif
# 130 "/usr/include/c++/v1/cwctype" 3

#ifdef iswpunct
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_iswpunct(wint_t __wc) {return iswpunct(__wc);}
#undef iswpunct
inline _LIBCPP_INLINE_VISIBILITY int iswpunct(wint_t __wc) {return __libcpp_iswpunct(__wc);}
#else  // iswpunct
# 136 "/usr/include/c++/v1/cwctype" 3
using ::iswpunct;
#endif
# 138 "/usr/include/c++/v1/cwctype" 3

#ifdef iswspace
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_iswspace(wint_t __wc) {return iswspace(__wc);}
#undef iswspace
inline _LIBCPP_INLINE_VISIBILITY int iswspace(wint_t __wc) {return __libcpp_iswspace(__wc);}
#else  // iswspace
# 144 "/usr/include/c++/v1/cwctype" 3
using ::iswspace;
#endif
# 146 "/usr/include/c++/v1/cwctype" 3

#ifdef iswupper
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_iswupper(wint_t __wc) {return iswupper(__wc);}
#undef iswupper
inline _LIBCPP_INLINE_VISIBILITY int iswupper(wint_t __wc) {return __libcpp_iswupper(__wc);}
#else  // iswupper
# 152 "/usr/include/c++/v1/cwctype" 3
using ::iswupper;
#endif
# 154 "/usr/include/c++/v1/cwctype" 3

#ifdef iswxdigit
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_iswxdigit(wint_t __wc) {return iswxdigit(__wc);}
#undef iswxdigit
inline _LIBCPP_INLINE_VISIBILITY int iswxdigit(wint_t __wc) {return __libcpp_iswxdigit(__wc);}
#else  // iswxdigit
# 160 "/usr/include/c++/v1/cwctype" 3
using ::iswxdigit;
#endif
# 162 "/usr/include/c++/v1/cwctype" 3

#ifdef iswctype
inline _LIBCPP_INLINE_VISIBILITY int __libcpp_iswctype(wint_t __w, wctype_t __d) {return iswctype(__w, __d);}
#undef iswctype
inline _LIBCPP_INLINE_VISIBILITY int iswctype(wint_t __w, wctype_t __d) {return __libcpp_iswctype(__w, __d);}
#else  // iswctype
# 168 "/usr/include/c++/v1/cwctype" 3
using ::iswctype;
#endif
# 170 "/usr/include/c++/v1/cwctype" 3

#ifdef wctype
inline _LIBCPP_INLINE_VISIBILITY wctype_t __libcpp_wctype(const char* __p) {return wctype(__p);}
#undef wctype
inline _LIBCPP_INLINE_VISIBILITY wctype_t wctype(const char* __p) {return __libcpp_wctype(__p);}
#else  // wctype
# 176 "/usr/include/c++/v1/cwctype" 3
using ::wctype;
#endif
# 178 "/usr/include/c++/v1/cwctype" 3

#ifdef towlower
inline _LIBCPP_INLINE_VISIBILITY wint_t __libcpp_towlower(wint_t __wc) {return towlower(__wc);}
#undef towlower
inline _LIBCPP_INLINE_VISIBILITY wint_t towlower(wint_t __wc) {return __libcpp_towlower(__wc);}
#else  // towlower
# 184 "/usr/include/c++/v1/cwctype" 3
using ::towlower;
#endif
# 186 "/usr/include/c++/v1/cwctype" 3

#ifdef towupper
inline _LIBCPP_INLINE_VISIBILITY wint_t __libcpp_towupper(wint_t __wc) {return towupper(__wc);}
#undef towupper
inline _LIBCPP_INLINE_VISIBILITY wint_t towupper(wint_t __wc) {return __libcpp_towupper(__wc);}
#else  // towupper
# 192 "/usr/include/c++/v1/cwctype" 3
using ::towupper;
#endif
# 194 "/usr/include/c++/v1/cwctype" 3

#ifdef towctrans
inline _LIBCPP_INLINE_VISIBILITY wint_t __libcpp_towctrans(wint_t __wc, wctype_t __d) {return towctrans(__wc, __d);}
#undef towctrans
inline _LIBCPP_INLINE_VISIBILITY wint_t towctrans(wint_t __wc, wctype_t __d) {return __libcpp_towctrans(__wc, __d);}
#else  // towctrans
# 200 "/usr/include/c++/v1/cwctype" 3
using ::towctrans;
#endif
# 202 "/usr/include/c++/v1/cwctype" 3

#ifdef wctrans
inline _LIBCPP_INLINE_VISIBILITY wctrans_t __libcpp_wctrans(const char* __p) {return wctrans(__p);}
#undef wctrans
inline _LIBCPP_INLINE_VISIBILITY wctrans_t wctrans(const char* __p) {return __libcpp_wctrans(__p);}
#else  // wctrans
# 208 "/usr/include/c++/v1/cwctype" 3
using ::wctrans;
#endif
# 210 "/usr/include/c++/v1/cwctype" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_CWCTYPE
# 214 "/usr/include/c++/v1/cwctype" 3
# 108 "/usr/include/c++/v1/cwchar" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <wchar.h>
#endif /* expanded by -frewrite-includes */
# 109 "/usr/include/c++/v1/cwchar" 3
#if defined(_LIBCPP_MSVCRT) || defined(__MINGW32__)
#if 0 /* expanded by -frewrite-includes */
#include <support/win32/support.h> // pull in *swprintf defines
#endif /* expanded by -frewrite-includes */
# 111 "/usr/include/c++/v1/cwchar" 3
#endif // _LIBCPP_MSVCRT
# 112 "/usr/include/c++/v1/cwchar" 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 115 "/usr/include/c++/v1/cwchar" 3
#endif
# 116 "/usr/include/c++/v1/cwchar" 3

_LIBCPP_BEGIN_NAMESPACE_STD

using ::mbstate_t;
using ::size_t;
using ::tm;
using ::wint_t;
using ::FILE;
using ::fwprintf;
using ::fwscanf;
using ::swprintf;
using ::vfwprintf;
using ::vswprintf;
using ::vwprintf;
#ifndef _LIBCPP_MSVCRT
using ::swscanf;
using ::vfwscanf;
using ::vswscanf;
using ::vwscanf;
#endif // _LIBCPP_MSVCRT
# 136 "/usr/include/c++/v1/cwchar" 3
using ::wprintf;
using ::wscanf;
using ::fgetwc;
using ::fgetws;
using ::fputwc;
using ::fputws;
using ::fwide;
using ::getwc;
using ::getwchar;
using ::putwc;
using ::putwchar;
using ::ungetwc;
using ::wcstod;
#ifndef _LIBCPP_MSVCRT
using ::wcstof;
using ::wcstold;
#endif // _LIBCPP_MSVCRT
# 153 "/usr/include/c++/v1/cwchar" 3
using ::wcstol;
#ifndef _LIBCPP_HAS_NO_LONG_LONG
using ::wcstoll;
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 157 "/usr/include/c++/v1/cwchar" 3
using ::wcstoul;
#ifndef _LIBCPP_HAS_NO_LONG_LONG
using ::wcstoull;
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 161 "/usr/include/c++/v1/cwchar" 3
using ::wcscpy;
using ::wcsncpy;
using ::wcscat;
using ::wcsncat;
using ::wcscmp;
using ::wcscoll;
using ::wcsncmp;
using ::wcsxfrm;

#if defined(_WCHAR_H_CPLUSPLUS_98_CONFORMANCE_)

using ::wcschr;
using ::wcspbrk;
using ::wcsrchr;
using ::wcsstr;
using ::wmemchr;

#else
# 179 "/usr/include/c++/v1/cwchar" 3

inline _LIBCPP_INLINE_VISIBILITY const wchar_t* wcschr(const wchar_t* __s, wchar_t __c) {return ::wcschr(__s, __c);}
inline _LIBCPP_INLINE_VISIBILITY       wchar_t* wcschr(      wchar_t* __s, wchar_t __c) {return ::wcschr(__s, __c);}

inline _LIBCPP_INLINE_VISIBILITY const wchar_t* wcspbrk(const wchar_t* __s1, const wchar_t* __s2) {return ::wcspbrk(__s1, __s2);}
inline _LIBCPP_INLINE_VISIBILITY       wchar_t* wcspbrk(      wchar_t* __s1, const wchar_t* __s2) {return ::wcspbrk(__s1, __s2);}

inline _LIBCPP_INLINE_VISIBILITY const wchar_t* wcsrchr(const wchar_t* __s, wchar_t __c) {return ::wcsrchr(__s, __c);}
inline _LIBCPP_INLINE_VISIBILITY       wchar_t* wcsrchr(      wchar_t* __s, wchar_t __c) {return ::wcsrchr(__s, __c);}

inline _LIBCPP_INLINE_VISIBILITY const wchar_t* wcsstr(const wchar_t* __s1, const wchar_t* __s2) {return ::wcsstr(__s1, __s2);}
inline _LIBCPP_INLINE_VISIBILITY       wchar_t* wcsstr(      wchar_t* __s1, const wchar_t* __s2) {return ::wcsstr(__s1, __s2);}

inline _LIBCPP_INLINE_VISIBILITY const wchar_t* wmemchr(const wchar_t* __s, wchar_t __c, size_t __n) {return ::wmemchr(__s, __c, __n);}
inline _LIBCPP_INLINE_VISIBILITY       wchar_t* wmemchr(      wchar_t* __s, wchar_t __c, size_t __n) {return ::wmemchr(__s, __c, __n);}

#endif
# 196 "/usr/include/c++/v1/cwchar" 3

using ::wcscspn;
using ::wcslen;
using ::wcsspn;
using ::wcstok;
using ::wmemcmp;
using ::wmemcpy;
using ::wmemmove;
using ::wmemset;
using ::wcsftime;
using ::btowc;
using ::wctob;
using ::mbsinit;
using ::mbrlen;
using ::mbrtowc;
using ::wcrtomb;
using ::mbsrtowcs;
using ::wcsrtombs;

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_CWCHAR
# 218 "/usr/include/c++/v1/cwchar" 3
# 439 "/usr/include/c++/v1/string" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/algorithm" 1 3
// -*- C++ -*-
//===-------------------------- algorithm ---------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_ALGORITHM
#define _LIBCPP_ALGORITHM

/*
    algorithm synopsis

#include <initializer_list>

namespace std
{

template <class InputIterator, class Predicate>
    bool
    all_of(InputIterator first, InputIterator last, Predicate pred);

template <class InputIterator, class Predicate>
    bool
    any_of(InputIterator first, InputIterator last, Predicate pred);

template <class InputIterator, class Predicate>
    bool
    none_of(InputIterator first, InputIterator last, Predicate pred);

template <class InputIterator, class Function>
    Function
    for_each(InputIterator first, InputIterator last, Function f);

template <class InputIterator, class T>
    InputIterator
    find(InputIterator first, InputIterator last, const T& value);

template <class InputIterator, class Predicate>
    InputIterator
    find_if(InputIterator first, InputIterator last, Predicate pred);

template<class InputIterator, class Predicate>
    InputIterator
    find_if_not(InputIterator first, InputIterator last, Predicate pred);

template <class ForwardIterator1, class ForwardIterator2>
    ForwardIterator1
    find_end(ForwardIterator1 first1, ForwardIterator1 last1,
             ForwardIterator2 first2, ForwardIterator2 last2);

template <class ForwardIterator1, class ForwardIterator2, class BinaryPredicate>
    ForwardIterator1
    find_end(ForwardIterator1 first1, ForwardIterator1 last1,
             ForwardIterator2 first2, ForwardIterator2 last2, BinaryPredicate pred);

template <class ForwardIterator1, class ForwardIterator2>
    ForwardIterator1
    find_first_of(ForwardIterator1 first1, ForwardIterator1 last1,
                  ForwardIterator2 first2, ForwardIterator2 last2);

template <class ForwardIterator1, class ForwardIterator2, class BinaryPredicate>
    ForwardIterator1
    find_first_of(ForwardIterator1 first1, ForwardIterator1 last1,
                  ForwardIterator2 first2, ForwardIterator2 last2, BinaryPredicate pred);

template <class ForwardIterator>
    ForwardIterator
    adjacent_find(ForwardIterator first, ForwardIterator last);

template <class ForwardIterator, class BinaryPredicate>
    ForwardIterator
    adjacent_find(ForwardIterator first, ForwardIterator last, BinaryPredicate pred);

template <class InputIterator, class T>
    typename iterator_traits<InputIterator>::difference_type
    count(InputIterator first, InputIterator last, const T& value);

template <class InputIterator, class Predicate>
    typename iterator_traits<InputIterator>::difference_type
    count_if(InputIterator first, InputIterator last, Predicate pred);

template <class InputIterator1, class InputIterator2>
    pair<InputIterator1, InputIterator2>
    mismatch(InputIterator1 first1, InputIterator1 last1, InputIterator2 first2);

template <class InputIterator1, class InputIterator2>
    pair<InputIterator1, InputIterator2>
    mismatch(InputIterator1 first1, InputIterator1 last1, 
             InputIterator2 first2, InputIterator2 last2); // **C++14**

template <class InputIterator1, class InputIterator2, class BinaryPredicate>
    pair<InputIterator1, InputIterator2>
    mismatch(InputIterator1 first1, InputIterator1 last1,
             InputIterator2 first2, BinaryPredicate pred);

template <class InputIterator1, class InputIterator2, class BinaryPredicate>
    pair<InputIterator1, InputIterator2>
    mismatch(InputIterator1 first1, InputIterator1 last1,
             InputIterator2 first2, InputIterator2 last2,
             BinaryPredicate pred); // **C++14**

template <class InputIterator1, class InputIterator2>
    bool
    equal(InputIterator1 first1, InputIterator1 last1, InputIterator2 first2);

template <class InputIterator1, class InputIterator2>
    bool
    equal(InputIterator1 first1, InputIterator1 last1, 
          InputIterator2 first2, InputIterator2 last2); // **C++14**

template <class InputIterator1, class InputIterator2, class BinaryPredicate>
    bool
    equal(InputIterator1 first1, InputIterator1 last1,
          InputIterator2 first2, BinaryPredicate pred);

template <class InputIterator1, class InputIterator2, class BinaryPredicate>
    bool
    equal(InputIterator1 first1, InputIterator1 last1,
          InputIterator2 first2, InputIterator2 last2,
          BinaryPredicate pred); // **C++14**

template<class ForwardIterator1, class ForwardIterator2>
    bool
    is_permutation(ForwardIterator1 first1, ForwardIterator1 last1,
                   ForwardIterator2 first2);

template<class ForwardIterator1, class ForwardIterator2>
    bool
    is_permutation(ForwardIterator1 first1, ForwardIterator1 last1,
                   ForwardIterator2 first2, ForwardIterator2 last2); // **C++14**

template<class ForwardIterator1, class ForwardIterator2, class BinaryPredicate>
    bool
    is_permutation(ForwardIterator1 first1, ForwardIterator1 last1,
                   ForwardIterator2 first2, BinaryPredicate pred);

template<class ForwardIterator1, class ForwardIterator2, class BinaryPredicate>
    bool
    is_permutation(ForwardIterator1 first1, ForwardIterator1 last1,
                   ForwardIterator2 first2, ForwardIterator2 last2,
                   BinaryPredicate pred);  // **C++14**

template <class ForwardIterator1, class ForwardIterator2>
    ForwardIterator1
    search(ForwardIterator1 first1, ForwardIterator1 last1,
           ForwardIterator2 first2, ForwardIterator2 last2);

template <class ForwardIterator1, class ForwardIterator2, class BinaryPredicate>
    ForwardIterator1
    search(ForwardIterator1 first1, ForwardIterator1 last1,
           ForwardIterator2 first2, ForwardIterator2 last2, BinaryPredicate pred);

template <class ForwardIterator, class Size, class T>
    ForwardIterator
    search_n(ForwardIterator first, ForwardIterator last, Size count, const T& value);

template <class ForwardIterator, class Size, class T, class BinaryPredicate>
    ForwardIterator
    search_n(ForwardIterator first, ForwardIterator last,
             Size count, const T& value, BinaryPredicate pred);

template <class InputIterator, class OutputIterator>
    OutputIterator
    copy(InputIterator first, InputIterator last, OutputIterator result);

template<class InputIterator, class OutputIterator, class Predicate>
    OutputIterator
    copy_if(InputIterator first, InputIterator last,
            OutputIterator result, Predicate pred);

template<class InputIterator, class Size, class OutputIterator>
    OutputIterator
    copy_n(InputIterator first, Size n, OutputIterator result);

template <class BidirectionalIterator1, class BidirectionalIterator2>
    BidirectionalIterator2
    copy_backward(BidirectionalIterator1 first, BidirectionalIterator1 last,
                  BidirectionalIterator2 result);

template <class ForwardIterator1, class ForwardIterator2>
    ForwardIterator2
    swap_ranges(ForwardIterator1 first1, ForwardIterator1 last1, ForwardIterator2 first2);

template <class ForwardIterator1, class ForwardIterator2>
    void
    iter_swap(ForwardIterator1 a, ForwardIterator2 b);

template <class InputIterator, class OutputIterator, class UnaryOperation>
    OutputIterator
    transform(InputIterator first, InputIterator last, OutputIterator result, UnaryOperation op);

template <class InputIterator1, class InputIterator2, class OutputIterator, class BinaryOperation>
    OutputIterator
    transform(InputIterator1 first1, InputIterator1 last1, InputIterator2 first2,
              OutputIterator result, BinaryOperation binary_op);

template <class ForwardIterator, class T>
    void
    replace(ForwardIterator first, ForwardIterator last, const T& old_value, const T& new_value);

template <class ForwardIterator, class Predicate, class T>
    void
    replace_if(ForwardIterator first, ForwardIterator last, Predicate pred, const T& new_value);

template <class InputIterator, class OutputIterator, class T>
    OutputIterator
    replace_copy(InputIterator first, InputIterator last, OutputIterator result,
                 const T& old_value, const T& new_value);

template <class InputIterator, class OutputIterator, class Predicate, class T>
    OutputIterator
    replace_copy_if(InputIterator first, InputIterator last, OutputIterator result, Predicate pred, const T& new_value);

template <class ForwardIterator, class T>
    void
    fill(ForwardIterator first, ForwardIterator last, const T& value);

template <class OutputIterator, class Size, class T>
    OutputIterator
    fill_n(OutputIterator first, Size n, const T& value);

template <class ForwardIterator, class Generator>
    void
    generate(ForwardIterator first, ForwardIterator last, Generator gen);

template <class OutputIterator, class Size, class Generator>
    OutputIterator
    generate_n(OutputIterator first, Size n, Generator gen);

template <class ForwardIterator, class T>
    ForwardIterator
    remove(ForwardIterator first, ForwardIterator last, const T& value);

template <class ForwardIterator, class Predicate>
    ForwardIterator
    remove_if(ForwardIterator first, ForwardIterator last, Predicate pred);

template <class InputIterator, class OutputIterator, class T>
    OutputIterator
    remove_copy(InputIterator first, InputIterator last, OutputIterator result, const T& value);

template <class InputIterator, class OutputIterator, class Predicate>
    OutputIterator
    remove_copy_if(InputIterator first, InputIterator last, OutputIterator result, Predicate pred);

template <class ForwardIterator>
    ForwardIterator
    unique(ForwardIterator first, ForwardIterator last);

template <class ForwardIterator, class BinaryPredicate>
    ForwardIterator
    unique(ForwardIterator first, ForwardIterator last, BinaryPredicate pred);

template <class InputIterator, class OutputIterator>
    OutputIterator
    unique_copy(InputIterator first, InputIterator last, OutputIterator result);

template <class InputIterator, class OutputIterator, class BinaryPredicate>
    OutputIterator
    unique_copy(InputIterator first, InputIterator last, OutputIterator result, BinaryPredicate pred);

template <class BidirectionalIterator>
    void
    reverse(BidirectionalIterator first, BidirectionalIterator last);

template <class BidirectionalIterator, class OutputIterator>
    OutputIterator
    reverse_copy(BidirectionalIterator first, BidirectionalIterator last, OutputIterator result);

template <class ForwardIterator>
    ForwardIterator
    rotate(ForwardIterator first, ForwardIterator middle, ForwardIterator last);

template <class ForwardIterator, class OutputIterator>
    OutputIterator
    rotate_copy(ForwardIterator first, ForwardIterator middle, ForwardIterator last, OutputIterator result);

template <class RandomAccessIterator>
    void
    random_shuffle(RandomAccessIterator first, RandomAccessIterator last);

template <class RandomAccessIterator, class RandomNumberGenerator>
    void
    random_shuffle(RandomAccessIterator first, RandomAccessIterator last, RandomNumberGenerator& rand);

template<class RandomAccessIterator, class UniformRandomNumberGenerator>
    void shuffle(RandomAccessIterator first, RandomAccessIterator last,
                 UniformRandomNumberGenerator&& g);

template <class InputIterator, class Predicate>
    bool
    is_partitioned(InputIterator first, InputIterator last, Predicate pred);

template <class ForwardIterator, class Predicate>
    ForwardIterator
    partition(ForwardIterator first, ForwardIterator last, Predicate pred);

template <class InputIterator, class OutputIterator1,
          class OutputIterator2, class Predicate>
    pair<OutputIterator1, OutputIterator2>
    partition_copy(InputIterator first, InputIterator last,
                   OutputIterator1 out_true, OutputIterator2 out_false,
                   Predicate pred);

template <class ForwardIterator, class Predicate>
    ForwardIterator
    stable_partition(ForwardIterator first, ForwardIterator last, Predicate pred);

template<class ForwardIterator, class Predicate>
    ForwardIterator
    partition_point(ForwardIterator first, ForwardIterator last, Predicate pred);

template <class ForwardIterator>
    bool
    is_sorted(ForwardIterator first, ForwardIterator last);

template <class ForwardIterator, class Compare>
    bool
    is_sorted(ForwardIterator first, ForwardIterator last, Compare comp);

template<class ForwardIterator>
    ForwardIterator
    is_sorted_until(ForwardIterator first, ForwardIterator last);

template <class ForwardIterator, class Compare>
    ForwardIterator
    is_sorted_until(ForwardIterator first, ForwardIterator last, Compare comp);

template <class RandomAccessIterator>
    void
    sort(RandomAccessIterator first, RandomAccessIterator last);

template <class RandomAccessIterator, class Compare>
    void
    sort(RandomAccessIterator first, RandomAccessIterator last, Compare comp);

template <class RandomAccessIterator>
    void
    stable_sort(RandomAccessIterator first, RandomAccessIterator last);

template <class RandomAccessIterator, class Compare>
    void
    stable_sort(RandomAccessIterator first, RandomAccessIterator last, Compare comp);

template <class RandomAccessIterator>
    void
    partial_sort(RandomAccessIterator first, RandomAccessIterator middle, RandomAccessIterator last);

template <class RandomAccessIterator, class Compare>
    void
    partial_sort(RandomAccessIterator first, RandomAccessIterator middle, RandomAccessIterator last, Compare comp);

template <class InputIterator, class RandomAccessIterator>
    RandomAccessIterator
    partial_sort_copy(InputIterator first, InputIterator last,
                      RandomAccessIterator result_first, RandomAccessIterator result_last);

template <class InputIterator, class RandomAccessIterator, class Compare>
    RandomAccessIterator
    partial_sort_copy(InputIterator first, InputIterator last,
                      RandomAccessIterator result_first, RandomAccessIterator result_last, Compare comp);

template <class RandomAccessIterator>
    void
    nth_element(RandomAccessIterator first, RandomAccessIterator nth, RandomAccessIterator last);

template <class RandomAccessIterator, class Compare>
    void
    nth_element(RandomAccessIterator first, RandomAccessIterator nth, RandomAccessIterator last, Compare comp);

template <class ForwardIterator, class T>
    ForwardIterator
    lower_bound(ForwardIterator first, ForwardIterator last, const T& value);

template <class ForwardIterator, class T, class Compare>
    ForwardIterator
    lower_bound(ForwardIterator first, ForwardIterator last, const T& value, Compare comp);

template <class ForwardIterator, class T>
    ForwardIterator
    upper_bound(ForwardIterator first, ForwardIterator last, const T& value);

template <class ForwardIterator, class T, class Compare>
    ForwardIterator
    upper_bound(ForwardIterator first, ForwardIterator last, const T& value, Compare comp);

template <class ForwardIterator, class T>
    pair<ForwardIterator, ForwardIterator>
    equal_range(ForwardIterator first, ForwardIterator last, const T& value);

template <class ForwardIterator, class T, class Compare>
    pair<ForwardIterator, ForwardIterator>
    equal_range(ForwardIterator first, ForwardIterator last, const T& value, Compare comp);

template <class ForwardIterator, class T>
    bool
    binary_search(ForwardIterator first, ForwardIterator last, const T& value);

template <class ForwardIterator, class T, class Compare>
    bool
    binary_search(ForwardIterator first, ForwardIterator last, const T& value, Compare comp);

template <class InputIterator1, class InputIterator2, class OutputIterator>
    OutputIterator
    merge(InputIterator1 first1, InputIterator1 last1,
          InputIterator2 first2, InputIterator2 last2, OutputIterator result);

template <class InputIterator1, class InputIterator2, class OutputIterator, class Compare>
    OutputIterator
    merge(InputIterator1 first1, InputIterator1 last1,
          InputIterator2 first2, InputIterator2 last2, OutputIterator result, Compare comp);

template <class BidirectionalIterator>
    void
    inplace_merge(BidirectionalIterator first, BidirectionalIterator middle, BidirectionalIterator last);

template <class BidirectionalIterator, class Compare>
    void
    inplace_merge(BidirectionalIterator first, BidirectionalIterator middle, BidirectionalIterator last, Compare comp);

template <class InputIterator1, class InputIterator2>
    bool
    includes(InputIterator1 first1, InputIterator1 last1, InputIterator2 first2, InputIterator2 last2);

template <class InputIterator1, class InputIterator2, class Compare>
    bool
    includes(InputIterator1 first1, InputIterator1 last1, InputIterator2 first2, InputIterator2 last2, Compare comp);

template <class InputIterator1, class InputIterator2, class OutputIterator>
    OutputIterator
    set_union(InputIterator1 first1, InputIterator1 last1,
              InputIterator2 first2, InputIterator2 last2, OutputIterator result);

template <class InputIterator1, class InputIterator2, class OutputIterator, class Compare>
    OutputIterator
    set_union(InputIterator1 first1, InputIterator1 last1,
              InputIterator2 first2, InputIterator2 last2, OutputIterator result, Compare comp);

template <class InputIterator1, class InputIterator2, class OutputIterator>
    OutputIterator
    set_intersection(InputIterator1 first1, InputIterator1 last1,
                     InputIterator2 first2, InputIterator2 last2, OutputIterator result);

template <class InputIterator1, class InputIterator2, class OutputIterator, class Compare>
    OutputIterator
    set_intersection(InputIterator1 first1, InputIterator1 last1,
                     InputIterator2 first2, InputIterator2 last2, OutputIterator result, Compare comp);

template <class InputIterator1, class InputIterator2, class OutputIterator>
    OutputIterator
    set_difference(InputIterator1 first1, InputIterator1 last1,
                   InputIterator2 first2, InputIterator2 last2, OutputIterator result);

template <class InputIterator1, class InputIterator2, class OutputIterator, class Compare>
    OutputIterator
    set_difference(InputIterator1 first1, InputIterator1 last1,
                   InputIterator2 first2, InputIterator2 last2, OutputIterator result, Compare comp);

template <class InputIterator1, class InputIterator2, class OutputIterator>
    OutputIterator
    set_symmetric_difference(InputIterator1 first1, InputIterator1 last1,
                             InputIterator2 first2, InputIterator2 last2, OutputIterator result);

template <class InputIterator1, class InputIterator2, class OutputIterator, class Compare>
    OutputIterator
    set_symmetric_difference(InputIterator1 first1, InputIterator1 last1,
                             InputIterator2 first2, InputIterator2 last2, OutputIterator result, Compare comp);

template <class RandomAccessIterator>
    void
    push_heap(RandomAccessIterator first, RandomAccessIterator last);

template <class RandomAccessIterator, class Compare>
    void
    push_heap(RandomAccessIterator first, RandomAccessIterator last, Compare comp);

template <class RandomAccessIterator>
    void
    pop_heap(RandomAccessIterator first, RandomAccessIterator last);

template <class RandomAccessIterator, class Compare>
    void
    pop_heap(RandomAccessIterator first, RandomAccessIterator last, Compare comp);

template <class RandomAccessIterator>
    void
    make_heap(RandomAccessIterator first, RandomAccessIterator last);

template <class RandomAccessIterator, class Compare>
    void
    make_heap(RandomAccessIterator first, RandomAccessIterator last, Compare comp);

template <class RandomAccessIterator>
    void
    sort_heap(RandomAccessIterator first, RandomAccessIterator last);

template <class RandomAccessIterator, class Compare>
    void
    sort_heap(RandomAccessIterator first, RandomAccessIterator last, Compare comp);

template <class RandomAccessIterator>
    bool
    is_heap(RandomAccessIterator first, RandomAccessiterator last);

template <class RandomAccessIterator, class Compare>
    bool
    is_heap(RandomAccessIterator first, RandomAccessiterator last, Compare comp);

template <class RandomAccessIterator>
    RandomAccessIterator
    is_heap_until(RandomAccessIterator first, RandomAccessiterator last);

template <class RandomAccessIterator, class Compare>
    RandomAccessIterator
    is_heap_until(RandomAccessIterator first, RandomAccessiterator last, Compare comp);

template <class ForwardIterator>
    ForwardIterator
    min_element(ForwardIterator first, ForwardIterator last);

template <class ForwardIterator, class Compare>
    ForwardIterator
    min_element(ForwardIterator first, ForwardIterator last, Compare comp);

template <class T>
    const T&
    min(const T& a, const T& b);

template <class T, class Compare>
    const T&
    min(const T& a, const T& b, Compare comp);

template<class T>
    T
    min(initializer_list<T> t);

template<class T, class Compare>
    T
    min(initializer_list<T> t, Compare comp);

template <class ForwardIterator>
    ForwardIterator
    max_element(ForwardIterator first, ForwardIterator last);

template <class ForwardIterator, class Compare>
    ForwardIterator
    max_element(ForwardIterator first, ForwardIterator last, Compare comp);

template <class T>
    const T&
    max(const T& a, const T& b);

template <class T, class Compare>
    const T&
    max(const T& a, const T& b, Compare comp);

template<class T>
    T
    max(initializer_list<T> t);

template<class T, class Compare>
    T
    max(initializer_list<T> t, Compare comp);

template<class ForwardIterator>
    pair<ForwardIterator, ForwardIterator>
    minmax_element(ForwardIterator first, ForwardIterator last);

template<class ForwardIterator, class Compare>
    pair<ForwardIterator, ForwardIterator>
    minmax_element(ForwardIterator first, ForwardIterator last, Compare comp);

template<class T>
    pair<const T&, const T&>
    minmax(const T& a, const T& b);

template<class T, class Compare>
    pair<const T&, const T&>
    minmax(const T& a, const T& b, Compare comp);

template<class T>
    pair<T, T>
    minmax(initializer_list<T> t);

template<class T, class Compare>
    pair<T, T>
    minmax(initializer_list<T> t, Compare comp);

template <class InputIterator1, class InputIterator2>
    bool
    lexicographical_compare(InputIterator1 first1, InputIterator1 last1, InputIterator2 first2, InputIterator2 last2);

template <class InputIterator1, class InputIterator2, class Compare>
    bool
    lexicographical_compare(InputIterator1 first1, InputIterator1 last1,
                            InputIterator2 first2, InputIterator2 last2, Compare comp);

template <class BidirectionalIterator>
    bool
    next_permutation(BidirectionalIterator first, BidirectionalIterator last);

template <class BidirectionalIterator, class Compare>
    bool
    next_permutation(BidirectionalIterator first, BidirectionalIterator last, Compare comp);

template <class BidirectionalIterator>
    bool
    prev_permutation(BidirectionalIterator first, BidirectionalIterator last);

template <class BidirectionalIterator, class Compare>
    bool
    prev_permutation(BidirectionalIterator first, BidirectionalIterator last, Compare comp);

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 623 "/usr/include/c++/v1/algorithm" 3
#if 0 /* expanded by -frewrite-includes */
#include <initializer_list>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/initializer_list" 1 3
// -*- C++ -*-
//===----------------------- initializer_list -----------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_INITIALIZER_LIST
#define _LIBCPP_INITIALIZER_LIST

/*
    initializer_list synopsis

namespace std
{

template<class E>
class initializer_list
{
public:
    typedef E        value_type;
    typedef const E& reference;
    typedef const E& const_reference;
    typedef size_t   size_type;

    typedef const E* iterator;
    typedef const E* const_iterator;

    initializer_list() noexcept; // constexpr in C++14

    size_t   size()  const noexcept; // constexpr in C++14
    const E* begin() const noexcept; // constexpr in C++14
    const E* end()   const noexcept; // constexpr in C++14
};

template<class E> const E* begin(initializer_list<E> il) noexcept; // constexpr in C++14
template<class E> const E* end(initializer_list<E> il) noexcept; // constexpr in C++14

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 47 "/usr/include/c++/v1/initializer_list" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/cstddef" 1 3
// -*- C++ -*-
//===--------------------------- cstddef ----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CSTDDEF
#define _LIBCPP_CSTDDEF

/*
    cstddef synopsis

Macros:

    offsetof(type,member-designator)
    NULL

namespace std
{

Types:

    ptrdiff_t
    size_t
    max_align_t
    nullptr_t

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 37 "/usr/include/c++/v1/cstddef" 3

#ifdef __GLIBC__
#define __need_NULL
#define __need_ptrdiff_t
#define __need_size_t
#endif  // __GLIBC__
# 43 "/usr/include/c++/v1/cstddef" 3

#if 0 /* expanded by -frewrite-includes */
#include <stddef.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/stddef.h" 1 3 4
/*-
 * Copyright (c) 1990, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)stddef.h	8.1 (Berkeley) 6/2/93
 *
 * $FreeBSD: head/include/stddef.h 270277 2014-08-21 15:10:10Z kan $
 */

#ifndef _STDDEF_H_
#define _STDDEF_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 38 "/usr/include/stddef.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_null.h>
#endif /* expanded by -frewrite-includes */
# 39 "/usr/include/stddef.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 40 "/usr/include/stddef.h" 3 4

#ifndef _PTRDIFF_T_DECLARED
typedef	__ptrdiff_t	ptrdiff_t;
#define	_PTRDIFF_T_DECLARED
#endif
# 45 "/usr/include/stddef.h" 3 4

#if __BSD_VISIBLE
#ifndef _RUNE_T_DECLARED
typedef	__rune_t	rune_t;
#define	_RUNE_T_DECLARED
#endif
# 51 "/usr/include/stddef.h" 3 4
#endif
# 52 "/usr/include/stddef.h" 3 4

#ifndef _SIZE_T_DECLARED
typedef	__size_t	size_t;
#define	_SIZE_T_DECLARED
#endif
# 57 "/usr/include/stddef.h" 3 4

#ifndef	__cplusplus
#ifndef _WCHAR_T_DECLARED
typedef	___wchar_t	wchar_t;
#define	_WCHAR_T_DECLARED
#endif
# 63 "/usr/include/stddef.h" 3 4
#endif
# 64 "/usr/include/stddef.h" 3 4

#define	offsetof(type, member)	__offsetof(type, member)

#endif /* _STDDEF_H_ */
# 68 "/usr/include/stddef.h" 3 4
# 45 "/usr/include/c++/v1/cstddef" 2 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 48 "/usr/include/c++/v1/cstddef" 3
#endif
# 49 "/usr/include/c++/v1/cstddef" 3

_LIBCPP_BEGIN_NAMESPACE_STD

using ::ptrdiff_t;
using ::size_t;

typedef long double max_align_t;

#ifdef _LIBCPP_HAS_NO_NULLPTR

struct _LIBCPP_TYPE_VIS_ONLY nullptr_t
{
    void* __lx;

    struct __nat {int __for_bool_;};

    _LIBCPP_ALWAYS_INLINE _LIBCPP_CONSTEXPR nullptr_t() : __lx(0) {}
    _LIBCPP_ALWAYS_INLINE _LIBCPP_CONSTEXPR nullptr_t(int __nat::*) : __lx(0) {}

    _LIBCPP_ALWAYS_INLINE _LIBCPP_CONSTEXPR operator int __nat::*() const {return 0;}

    template <class _Tp>
        _LIBCPP_ALWAYS_INLINE _LIBCPP_CONSTEXPR
        operator _Tp* () const {return 0;}

    template <class _Tp, class _Up>
        _LIBCPP_ALWAYS_INLINE
        operator _Tp _Up::* () const {return 0;}

    friend _LIBCPP_ALWAYS_INLINE _LIBCPP_CONSTEXPR bool operator==(nullptr_t, nullptr_t) {return true;}
    friend _LIBCPP_ALWAYS_INLINE _LIBCPP_CONSTEXPR bool operator!=(nullptr_t, nullptr_t) {return false;}
    friend _LIBCPP_ALWAYS_INLINE _LIBCPP_CONSTEXPR bool operator<(nullptr_t, nullptr_t) {return false;}
    friend _LIBCPP_ALWAYS_INLINE _LIBCPP_CONSTEXPR bool operator<=(nullptr_t, nullptr_t) {return true;}
    friend _LIBCPP_ALWAYS_INLINE _LIBCPP_CONSTEXPR bool operator>(nullptr_t, nullptr_t) {return false;}
    friend _LIBCPP_ALWAYS_INLINE _LIBCPP_CONSTEXPR bool operator>=(nullptr_t, nullptr_t) {return true;}
};

inline _LIBCPP_ALWAYS_INLINE _LIBCPP_CONSTEXPR nullptr_t __get_nullptr_t() {return nullptr_t(0);}

#define nullptr _VSTD::__get_nullptr_t()

#endif  // _LIBCPP_HAS_NO_NULLPTR
# 91 "/usr/include/c++/v1/cstddef" 3

_LIBCPP_END_NAMESPACE_STD

#ifndef _LIBCPP_HAS_NO_NULLPTR

namespace std
{
    typedef decltype(nullptr) nullptr_t;
}

#endif  // _LIBCPP_HAS_NO_NULLPTR
# 102 "/usr/include/c++/v1/cstddef" 3

#endif  // _LIBCPP_CSTDDEF
# 104 "/usr/include/c++/v1/cstddef" 3
# 48 "/usr/include/c++/v1/initializer_list" 2 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 51 "/usr/include/c++/v1/initializer_list" 3
#endif
# 52 "/usr/include/c++/v1/initializer_list" 3

namespace std  // purposefully not versioned
{

#ifndef _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS

template<class _Ep>
class _LIBCPP_TYPE_VIS_ONLY initializer_list
{
    const _Ep* __begin_;
    size_t    __size_;

    _LIBCPP_ALWAYS_INLINE
    _LIBCPP_CONSTEXPR_AFTER_CXX11
    initializer_list(const _Ep* __b, size_t __s) _NOEXCEPT
        : __begin_(__b),
          __size_(__s)
        {}
public:
    typedef _Ep        value_type;
    typedef const _Ep& reference;
    typedef const _Ep& const_reference;
    typedef size_t    size_type;

    typedef const _Ep* iterator;
    typedef const _Ep* const_iterator;

    _LIBCPP_ALWAYS_INLINE
    _LIBCPP_CONSTEXPR_AFTER_CXX11
    initializer_list() _NOEXCEPT : __begin_(nullptr), __size_(0) {}

    _LIBCPP_ALWAYS_INLINE
    _LIBCPP_CONSTEXPR_AFTER_CXX11
    size_t    size()  const _NOEXCEPT {return __size_;}
    
    _LIBCPP_ALWAYS_INLINE
    _LIBCPP_CONSTEXPR_AFTER_CXX11
    const _Ep* begin() const _NOEXCEPT {return __begin_;}

    _LIBCPP_ALWAYS_INLINE
    _LIBCPP_CONSTEXPR_AFTER_CXX11
    const _Ep* end()   const _NOEXCEPT {return __begin_ + __size_;}
};

template<class _Ep>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR_AFTER_CXX11
const _Ep*
begin(initializer_list<_Ep> __il) _NOEXCEPT
{
    return __il.begin();
}

template<class _Ep>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR_AFTER_CXX11
const _Ep*
end(initializer_list<_Ep> __il) _NOEXCEPT
{
    return __il.end();
}

#endif  // _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
# 115 "/usr/include/c++/v1/initializer_list" 3

}  // std

#endif  // _LIBCPP_INITIALIZER_LIST
# 119 "/usr/include/c++/v1/initializer_list" 3
# 624 "/usr/include/c++/v1/algorithm" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/type_traits" 1 3
// -*- C++ -*-
//===------------------------ type_traits ---------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_TYPE_TRAITS
#define _LIBCPP_TYPE_TRAITS

/*
    type_traits synopsis

namespace std
{

    // helper class:
    template <class T, T v> struct integral_constant;
    typedef integral_constant<bool, true>  true_type;
    typedef integral_constant<bool, false> false_type;

    // helper traits
    template <bool, class T = void> struct enable_if;
    template <bool, class T, class F> struct conditional;

    // Primary classification traits:
    template <class T> struct is_void;
    template <class T> struct is_null_pointer;  // C++14
    template <class T> struct is_integral;
    template <class T> struct is_floating_point;
    template <class T> struct is_array;
    template <class T> struct is_pointer;
    template <class T> struct is_lvalue_reference;
    template <class T> struct is_rvalue_reference;
    template <class T> struct is_member_object_pointer;
    template <class T> struct is_member_function_pointer;
    template <class T> struct is_enum;
    template <class T> struct is_union;
    template <class T> struct is_class;
    template <class T> struct is_function;

    // Secondary classification traits:
    template <class T> struct is_reference;
    template <class T> struct is_arithmetic;
    template <class T> struct is_fundamental;
    template <class T> struct is_member_pointer;
    template <class T> struct is_scalar;
    template <class T> struct is_object;
    template <class T> struct is_compound;

    // Const-volatile properties and transformations:
    template <class T> struct is_const;
    template <class T> struct is_volatile;
    template <class T> struct remove_const;
    template <class T> struct remove_volatile;
    template <class T> struct remove_cv;
    template <class T> struct add_const;
    template <class T> struct add_volatile;
    template <class T> struct add_cv;

    // Reference transformations:
    template <class T> struct remove_reference;
    template <class T> struct add_lvalue_reference;
    template <class T> struct add_rvalue_reference;

    // Pointer transformations:
    template <class T> struct remove_pointer;
    template <class T> struct add_pointer;

    // Integral properties:
    template <class T> struct is_signed;
    template <class T> struct is_unsigned;
    template <class T> struct make_signed;
    template <class T> struct make_unsigned;

    // Array properties and transformations:
    template <class T> struct rank;
    template <class T, unsigned I = 0> struct extent;
    template <class T> struct remove_extent;
    template <class T> struct remove_all_extents;

    // Member introspection:
    template <class T> struct is_pod;
    template <class T> struct is_trivial;
    template <class T> struct is_trivially_copyable;
    template <class T> struct is_standard_layout;
    template <class T> struct is_literal_type;
    template <class T> struct is_empty;
    template <class T> struct is_polymorphic;
    template <class T> struct is_abstract;

    template <class T, class... Args> struct is_constructible;
    template <class T>                struct is_default_constructible;
    template <class T>                struct is_copy_constructible;
    template <class T>                struct is_move_constructible;
    template <class T, class U>       struct is_assignable;
    template <class T>                struct is_copy_assignable;
    template <class T>                struct is_move_assignable;
    template <class T>                struct is_destructible;

    template <class T, class... Args> struct is_trivially_constructible;
    template <class T>                struct is_trivially_default_constructible;
    template <class T>                struct is_trivially_copy_constructible;
    template <class T>                struct is_trivially_move_constructible;
    template <class T, class U>       struct is_trivially_assignable;
    template <class T>                struct is_trivially_copy_assignable;
    template <class T>                struct is_trivially_move_assignable;
    template <class T>                struct is_trivially_destructible;

    template <class T, class... Args> struct is_nothrow_constructible;
    template <class T>                struct is_nothrow_default_constructible;
    template <class T>                struct is_nothrow_copy_constructible;
    template <class T>                struct is_nothrow_move_constructible;
    template <class T, class U>       struct is_nothrow_assignable;
    template <class T>                struct is_nothrow_copy_assignable;
    template <class T>                struct is_nothrow_move_assignable;
    template <class T>                struct is_nothrow_destructible;

    template <class T> struct has_virtual_destructor;

    // Relationships between types:
    template <class T, class U> struct is_same;
    template <class Base, class Derived> struct is_base_of;
    template <class From, class To> struct is_convertible;

    // Alignment properties and transformations:
    template <class T> struct alignment_of;
    template <size_t Len, size_t Align = most_stringent_alignment_requirement>
        struct aligned_storage;
    template <size_t Len, class... Types> struct aligned_union;

    template <class T> struct decay;
    template <class... T> struct common_type;
    template <class T> struct underlying_type;
    template <class> class result_of; // undefined
    template <class Fn, class... ArgTypes> class result_of<Fn(ArgTypes...)>;

    // const-volatile modifications:
    template <class T>
      using remove_const_t    = typename remove_const<T>::type;  // C++14
    template <class T>
      using remove_volatile_t = typename remove_volatile<T>::type;  // C++14
    template <class T>
      using remove_cv_t       = typename remove_cv<T>::type;  // C++14
    template <class T>
      using add_const_t       = typename add_const<T>::type;  // C++14
    template <class T>
      using add_volatile_t    = typename add_volatile<T>::type;  // C++14
    template <class T>
      using add_cv_t          = typename add_cv<T>::type;  // C++14
  
    // reference modifications:
    template <class T>
      using remove_reference_t     = typename remove_reference<T>::type;  // C++14
    template <class T>
      using add_lvalue_reference_t = typename add_lvalue_reference<T>::type;  // C++14
    template <class T>
      using add_rvalue_reference_t = typename add_rvalue_reference<T>::type;  // C++14
  
    // sign modifications:
    template <class T>
      using make_signed_t   = typename make_signed<T>::type;  // C++14
    template <class T>
      using make_unsigned_t = typename make_unsigned<T>::type;  // C++14
  
    // array modifications:
    template <class T>
      using remove_extent_t      = typename remove_extent<T>::type;  // C++14
    template <class T>
      using remove_all_extents_t = typename remove_all_extents<T>::type;  // C++14

    // pointer modifications:
    template <class T>
      using remove_pointer_t = typename remove_pointer<T>::type;  // C++14
    template <class T>
      using add_pointer_t    = typename add_pointer<T>::type;  // C++14

    // other transformations:
    template <size_t Len, std::size_t Align=default-alignment>
      using aligned_storage_t = typename aligned_storage<Len,Align>::type;  // C++14
    template <std::size_t Len, class... Types>
      using aligned_union_t   = typename aligned_union<Len,Types...>::type;  // C++14
    template <class T>
      using decay_t           = typename decay<T>::type;  // C++14
    template <bool b, class T=void>
      using enable_if_t       = typename enable_if<b,T>::type;  // C++14
    template <bool b, class T, class F>
      using conditional_t     = typename conditional<b,T,F>::type;  // C++14
    template <class... T>
      using common_type_t     = typename common_type<T...>::type;  // C++14
    template <class T>
      using underlying_type_t = typename underlying_type<T>::type;  // C++14
    template <class F, class... ArgTypes>
      using result_of_t       = typename result_of<F(ArgTypes...)>::type;  // C++14

}  // std

*/
#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 203 "/usr/include/c++/v1/type_traits" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 204 "/usr/include/c++/v1/type_traits" 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 207 "/usr/include/c++/v1/type_traits" 3
#endif
# 208 "/usr/include/c++/v1/type_traits" 3

_LIBCPP_BEGIN_NAMESPACE_STD

template <bool _Bp, class _If, class _Then>
    struct _LIBCPP_TYPE_VIS_ONLY conditional {typedef _If type;};
template <class _If, class _Then>
    struct _LIBCPP_TYPE_VIS_ONLY conditional<false, _If, _Then> {typedef _Then type;};

#if _LIBCPP_STD_VER > 11
template <bool _Bp, class _If, class _Then> using conditional_t = typename conditional<_Bp, _If, _Then>::type;
#endif
# 219 "/usr/include/c++/v1/type_traits" 3

template <bool, class _Tp = void> struct _LIBCPP_TYPE_VIS_ONLY enable_if {};
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY enable_if<true, _Tp> {typedef _Tp type;};

#if _LIBCPP_STD_VER > 11
template <bool _Bp, class _Tp = void> using enable_if_t = typename enable_if<_Bp, _Tp>::type;
#endif
# 226 "/usr/include/c++/v1/type_traits" 3


struct __two {char __lx[2];};

// helper class:

template <class _Tp, _Tp __v>
struct _LIBCPP_TYPE_VIS_ONLY integral_constant
{
    static _LIBCPP_CONSTEXPR const _Tp      value = __v;
    typedef _Tp               value_type;
    typedef integral_constant type;
    _LIBCPP_INLINE_VISIBILITY
        _LIBCPP_CONSTEXPR operator value_type() const {return value;}
#if _LIBCPP_STD_VER > 11
    _LIBCPP_INLINE_VISIBILITY
         constexpr value_type operator ()() const {return value;}
#endif
# 244 "/usr/include/c++/v1/type_traits" 3
};

template <class _Tp, _Tp __v>
_LIBCPP_CONSTEXPR const _Tp integral_constant<_Tp, __v>::value;

typedef integral_constant<bool, true>  true_type;
typedef integral_constant<bool, false> false_type;

// is_const

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_const            : public false_type {};
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_const<_Tp const> : public true_type {};

// is_volatile

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_volatile               : public false_type {};
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_volatile<_Tp volatile> : public true_type {};

// remove_const

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY remove_const            {typedef _Tp type;};
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY remove_const<const _Tp> {typedef _Tp type;};
#if _LIBCPP_STD_VER > 11
template <class _Tp> using remove_const_t = typename remove_const<_Tp>::type;
#endif
# 269 "/usr/include/c++/v1/type_traits" 3

// remove_volatile

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY remove_volatile               {typedef _Tp type;};
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY remove_volatile<volatile _Tp> {typedef _Tp type;};
#if _LIBCPP_STD_VER > 11
template <class _Tp> using remove_volatile_t = typename remove_volatile<_Tp>::type;
#endif
# 277 "/usr/include/c++/v1/type_traits" 3

// remove_cv

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY remove_cv
{typedef typename remove_volatile<typename remove_const<_Tp>::type>::type type;};
#if _LIBCPP_STD_VER > 11
template <class _Tp> using remove_cv_t = typename remove_cv<_Tp>::type;
#endif
# 285 "/usr/include/c++/v1/type_traits" 3

// is_void

template <class _Tp> struct __libcpp_is_void       : public false_type {};
template <>          struct __libcpp_is_void<void> : public true_type {};

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_void
    : public __libcpp_is_void<typename remove_cv<_Tp>::type> {};

// __is_nullptr_t

template <class _Tp> struct __libcpp___is_nullptr       : public false_type {};
template <>          struct __libcpp___is_nullptr<nullptr_t> : public true_type {};

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY __is_nullptr_t
    : public __libcpp___is_nullptr<typename remove_cv<_Tp>::type> {};

#if _LIBCPP_STD_VER > 11
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_null_pointer
    : public __libcpp___is_nullptr<typename remove_cv<_Tp>::type> {};
#endif
# 306 "/usr/include/c++/v1/type_traits" 3

// is_integral

template <class _Tp> struct __libcpp_is_integral                     : public false_type {};
template <>          struct __libcpp_is_integral<bool>               : public true_type {};
template <>          struct __libcpp_is_integral<char>               : public true_type {};
template <>          struct __libcpp_is_integral<signed char>        : public true_type {};
template <>          struct __libcpp_is_integral<unsigned char>      : public true_type {};
template <>          struct __libcpp_is_integral<wchar_t>            : public true_type {};
#ifndef _LIBCPP_HAS_NO_UNICODE_CHARS
template <>          struct __libcpp_is_integral<char16_t>           : public true_type {};
template <>          struct __libcpp_is_integral<char32_t>           : public true_type {};
#endif  // _LIBCPP_HAS_NO_UNICODE_CHARS
# 319 "/usr/include/c++/v1/type_traits" 3
template <>          struct __libcpp_is_integral<short>              : public true_type {};
template <>          struct __libcpp_is_integral<unsigned short>     : public true_type {};
template <>          struct __libcpp_is_integral<int>                : public true_type {};
template <>          struct __libcpp_is_integral<unsigned int>       : public true_type {};
template <>          struct __libcpp_is_integral<long>               : public true_type {};
template <>          struct __libcpp_is_integral<unsigned long>      : public true_type {};
template <>          struct __libcpp_is_integral<long long>          : public true_type {};
template <>          struct __libcpp_is_integral<unsigned long long> : public true_type {};

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_integral
    : public __libcpp_is_integral<typename remove_cv<_Tp>::type> {};

// is_floating_point

template <class _Tp> struct __libcpp_is_floating_point              : public false_type {};
template <>          struct __libcpp_is_floating_point<float>       : public true_type {};
template <>          struct __libcpp_is_floating_point<double>      : public true_type {};
template <>          struct __libcpp_is_floating_point<long double> : public true_type {};

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_floating_point
    : public __libcpp_is_floating_point<typename remove_cv<_Tp>::type> {};

// is_array

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_array
    : public false_type {};
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_array<_Tp[]>
    : public true_type {};
template <class _Tp, size_t _Np> struct _LIBCPP_TYPE_VIS_ONLY is_array<_Tp[_Np]>
    : public true_type {};

// is_pointer

template <class _Tp> struct __libcpp_is_pointer       : public false_type {};
template <class _Tp> struct __libcpp_is_pointer<_Tp*> : public true_type {};

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_pointer
    : public __libcpp_is_pointer<typename remove_cv<_Tp>::type> {};

// is_reference

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_lvalue_reference       : public false_type {};
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_lvalue_reference<_Tp&> : public true_type {};

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_rvalue_reference        : public false_type {};
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_rvalue_reference<_Tp&&> : public true_type {};
#endif
# 367 "/usr/include/c++/v1/type_traits" 3

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_reference        : public false_type {};
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_reference<_Tp&>  : public true_type {};
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_reference<_Tp&&> : public true_type {};
#endif
# 373 "/usr/include/c++/v1/type_traits" 3

#if defined(__clang__) || (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3)
#define _LIBCPP_HAS_TYPE_TRAITS
#endif
# 377 "/usr/include/c++/v1/type_traits" 3

// is_union

#if __has_feature(is_union) || (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3)

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_union
    : public integral_constant<bool, __is_union(_Tp)> {};

#else
# 386 "/usr/include/c++/v1/type_traits" 3

template <class _Tp> struct __libcpp_union : public false_type {};
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_union
    : public __libcpp_union<typename remove_cv<_Tp>::type> {};

#endif
# 392 "/usr/include/c++/v1/type_traits" 3

// is_class

#if __has_feature(is_class) || (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3)

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_class
    : public integral_constant<bool, __is_class(_Tp)> {};

#else
# 401 "/usr/include/c++/v1/type_traits" 3

namespace __is_class_imp
{
template <class _Tp> char  __test(int _Tp::*);
template <class _Tp> __two __test(...);
}

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_class
    : public integral_constant<bool, sizeof(__is_class_imp::__test<_Tp>(0)) == 1 && !is_union<_Tp>::value> {};

#endif
# 412 "/usr/include/c++/v1/type_traits" 3

// is_same

template <class _Tp, class _Up> struct _LIBCPP_TYPE_VIS_ONLY is_same           : public false_type {};
template <class _Tp>            struct _LIBCPP_TYPE_VIS_ONLY is_same<_Tp, _Tp> : public true_type {};

// is_function

namespace __is_function_imp
{
template <class _Tp> char  __test(_Tp*);
template <class _Tp> __two __test(...);
template <class _Tp> _Tp&  __source();
}

template <class _Tp, bool = is_class<_Tp>::value ||
                            is_union<_Tp>::value ||
                            is_void<_Tp>::value  ||
                            is_reference<_Tp>::value ||
                            __is_nullptr_t<_Tp>::value >
struct __libcpp_is_function
    : public integral_constant<bool, sizeof(__is_function_imp::__test<_Tp>(__is_function_imp::__source<_Tp>())) == 1>
    {};
template <class _Tp> struct __libcpp_is_function<_Tp, true> : public false_type {};

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_function
    : public __libcpp_is_function<_Tp> {};

// is_member_function_pointer

template <class _Tp> struct            __libcpp_is_member_function_pointer             : public false_type {};
template <class _Tp, class _Up> struct __libcpp_is_member_function_pointer<_Tp _Up::*> : public is_function<_Tp> {};

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_member_function_pointer
    : public __libcpp_is_member_function_pointer<typename remove_cv<_Tp>::type> {};

// is_member_pointer

template <class _Tp>            struct __libcpp_is_member_pointer             : public false_type {};
template <class _Tp, class _Up> struct __libcpp_is_member_pointer<_Tp _Up::*> : public true_type {};

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_member_pointer
    : public __libcpp_is_member_pointer<typename remove_cv<_Tp>::type> {};

// is_member_object_pointer

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_member_object_pointer
    : public integral_constant<bool, is_member_pointer<_Tp>::value &&
                                    !is_member_function_pointer<_Tp>::value> {};

// is_enum

#if __has_feature(is_enum) || (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3)

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_enum
    : public integral_constant<bool, __is_enum(_Tp)> {};

#else
# 470 "/usr/include/c++/v1/type_traits" 3

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_enum
    : public integral_constant<bool, !is_void<_Tp>::value             &&
                                     !is_integral<_Tp>::value         &&
                                     !is_floating_point<_Tp>::value   &&
                                     !is_array<_Tp>::value            &&
                                     !is_pointer<_Tp>::value          &&
                                     !is_reference<_Tp>::value        &&
                                     !is_member_pointer<_Tp>::value   &&
                                     !is_union<_Tp>::value            &&
                                     !is_class<_Tp>::value            &&
                                     !is_function<_Tp>::value         > {};

#endif
# 484 "/usr/include/c++/v1/type_traits" 3

// is_arithmetic

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_arithmetic
    : public integral_constant<bool, is_integral<_Tp>::value      ||
                                     is_floating_point<_Tp>::value> {};

// is_fundamental

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_fundamental
    : public integral_constant<bool, is_void<_Tp>::value        ||
                                     __is_nullptr_t<_Tp>::value ||
                                     is_arithmetic<_Tp>::value> {};

// is_scalar

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_scalar
    : public integral_constant<bool, is_arithmetic<_Tp>::value     ||
                                     is_member_pointer<_Tp>::value ||
                                     is_pointer<_Tp>::value        ||
                                     __is_nullptr_t<_Tp>::value    ||
                                     is_enum<_Tp>::value           > {};

template <> struct _LIBCPP_TYPE_VIS_ONLY is_scalar<nullptr_t> : public true_type {};

// is_object

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_object
    : public integral_constant<bool, is_scalar<_Tp>::value ||
                                     is_array<_Tp>::value  ||
                                     is_union<_Tp>::value  ||
                                     is_class<_Tp>::value  > {};

// is_compound

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_compound
    : public integral_constant<bool, !is_fundamental<_Tp>::value> {};

// add_const

template <class _Tp, bool = is_reference<_Tp>::value ||
                            is_function<_Tp>::value  ||
                            is_const<_Tp>::value     >
struct __add_const             {typedef _Tp type;};

template <class _Tp>
struct __add_const<_Tp, false> {typedef const _Tp type;};

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY add_const
    {typedef typename __add_const<_Tp>::type type;};

#if _LIBCPP_STD_VER > 11
template <class _Tp> using add_const_t = typename add_const<_Tp>::type;
#endif
# 538 "/usr/include/c++/v1/type_traits" 3

// add_volatile

template <class _Tp, bool = is_reference<_Tp>::value ||
                            is_function<_Tp>::value  ||
                            is_volatile<_Tp>::value  >
struct __add_volatile             {typedef _Tp type;};

template <class _Tp>
struct __add_volatile<_Tp, false> {typedef volatile _Tp type;};

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY add_volatile
    {typedef typename __add_volatile<_Tp>::type type;};

#if _LIBCPP_STD_VER > 11
template <class _Tp> using add_volatile_t = typename add_volatile<_Tp>::type;
#endif
# 555 "/usr/include/c++/v1/type_traits" 3

// add_cv

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY add_cv
    {typedef typename add_const<typename add_volatile<_Tp>::type>::type type;};

#if _LIBCPP_STD_VER > 11
template <class _Tp> using add_cv_t = typename add_cv<_Tp>::type;
#endif
# 564 "/usr/include/c++/v1/type_traits" 3

// remove_reference

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY remove_reference        {typedef _Tp type;};
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY remove_reference<_Tp&>  {typedef _Tp type;};
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY remove_reference<_Tp&&> {typedef _Tp type;};
#endif
# 572 "/usr/include/c++/v1/type_traits" 3

#if _LIBCPP_STD_VER > 11
template <class _Tp> using remove_reference_t = typename remove_reference<_Tp>::type;
#endif
# 576 "/usr/include/c++/v1/type_traits" 3

// add_lvalue_reference

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY add_lvalue_reference                      {typedef _Tp& type;};
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY add_lvalue_reference<_Tp&>                {typedef _Tp& type;};  // for older compiler
template <>          struct _LIBCPP_TYPE_VIS_ONLY add_lvalue_reference<void>                {typedef void type;};
template <>          struct _LIBCPP_TYPE_VIS_ONLY add_lvalue_reference<const void>          {typedef const void type;};
template <>          struct _LIBCPP_TYPE_VIS_ONLY add_lvalue_reference<volatile void>       {typedef volatile void type;};
template <>          struct _LIBCPP_TYPE_VIS_ONLY add_lvalue_reference<const volatile void> {typedef const volatile void type;};

#if _LIBCPP_STD_VER > 11
template <class _Tp> using add_lvalue_reference_t = typename add_lvalue_reference<_Tp>::type;
#endif
# 589 "/usr/include/c++/v1/type_traits" 3

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY  add_rvalue_reference                     {typedef _Tp&& type;};
template <>          struct _LIBCPP_TYPE_VIS_ONLY add_rvalue_reference<void>                {typedef void type;};
template <>          struct _LIBCPP_TYPE_VIS_ONLY add_rvalue_reference<const void>          {typedef const void type;};
template <>          struct _LIBCPP_TYPE_VIS_ONLY add_rvalue_reference<volatile void>       {typedef volatile void type;};
template <>          struct _LIBCPP_TYPE_VIS_ONLY add_rvalue_reference<const volatile void> {typedef const volatile void type;};

#if _LIBCPP_STD_VER > 11
template <class _Tp> using add_rvalue_reference_t = typename add_rvalue_reference<_Tp>::type;
#endif
# 601 "/usr/include/c++/v1/type_traits" 3

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 603 "/usr/include/c++/v1/type_traits" 3

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template <class _Tp>
typename add_rvalue_reference<_Tp>::type
declval() _NOEXCEPT;

#else  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 611 "/usr/include/c++/v1/type_traits" 3

template <class _Tp>
typename add_lvalue_reference<_Tp>::type
declval();

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 617 "/usr/include/c++/v1/type_traits" 3

struct __any
{
    __any(...);
};

// remove_pointer

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY remove_pointer                      {typedef _Tp type;};
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY remove_pointer<_Tp*>                {typedef _Tp type;};
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY remove_pointer<_Tp* const>          {typedef _Tp type;};
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY remove_pointer<_Tp* volatile>       {typedef _Tp type;};
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY remove_pointer<_Tp* const volatile> {typedef _Tp type;};

#if _LIBCPP_STD_VER > 11
template <class _Tp> using remove_pointer_t = typename remove_pointer<_Tp>::type;
#endif
# 634 "/usr/include/c++/v1/type_traits" 3

// add_pointer

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY add_pointer
    {typedef typename remove_reference<_Tp>::type* type;};

#if _LIBCPP_STD_VER > 11
template <class _Tp> using add_pointer_t = typename add_pointer<_Tp>::type;
#endif
# 643 "/usr/include/c++/v1/type_traits" 3

// is_signed

template <class _Tp, bool = is_integral<_Tp>::value>
struct ___is_signed : public integral_constant<bool, _Tp(-1) < _Tp(0)> {};

template <class _Tp>
struct ___is_signed<_Tp, false> : public true_type {};  // floating point

template <class _Tp, bool = is_arithmetic<_Tp>::value>
struct __libcpp_is_signed : public ___is_signed<_Tp> {};

template <class _Tp> struct __libcpp_is_signed<_Tp, false> : public false_type {};

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_signed : public __libcpp_is_signed<_Tp> {};

// is_unsigned

template <class _Tp, bool = is_integral<_Tp>::value>
struct ___is_unsigned : public integral_constant<bool, _Tp(0) < _Tp(-1)> {};

template <class _Tp>
struct ___is_unsigned<_Tp, false> : public false_type {};  // floating point

template <class _Tp, bool = is_arithmetic<_Tp>::value>
struct __libcpp_is_unsigned : public ___is_unsigned<_Tp> {};

template <class _Tp> struct __libcpp_is_unsigned<_Tp, false> : public false_type {};

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_unsigned : public __libcpp_is_unsigned<_Tp> {};

// rank

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY rank
    : public integral_constant<size_t, 0> {};
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY rank<_Tp[]>
    : public integral_constant<size_t, rank<_Tp>::value + 1> {};
template <class _Tp, size_t _Np> struct _LIBCPP_TYPE_VIS_ONLY rank<_Tp[_Np]>
    : public integral_constant<size_t, rank<_Tp>::value + 1> {};

// extent

template <class _Tp, unsigned _Ip = 0> struct _LIBCPP_TYPE_VIS_ONLY extent
    : public integral_constant<size_t, 0> {};
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY extent<_Tp[], 0>
    : public integral_constant<size_t, 0> {};
template <class _Tp, unsigned _Ip> struct _LIBCPP_TYPE_VIS_ONLY extent<_Tp[], _Ip>
    : public integral_constant<size_t, extent<_Tp, _Ip-1>::value> {};
template <class _Tp, size_t _Np> struct _LIBCPP_TYPE_VIS_ONLY extent<_Tp[_Np], 0>
    : public integral_constant<size_t, _Np> {};
template <class _Tp, size_t _Np, unsigned _Ip> struct _LIBCPP_TYPE_VIS_ONLY extent<_Tp[_Np], _Ip>
    : public integral_constant<size_t, extent<_Tp, _Ip-1>::value> {};

// remove_extent

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY remove_extent
    {typedef _Tp type;};
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY remove_extent<_Tp[]>
    {typedef _Tp type;};
template <class _Tp, size_t _Np> struct _LIBCPP_TYPE_VIS_ONLY remove_extent<_Tp[_Np]>
    {typedef _Tp type;};

#if _LIBCPP_STD_VER > 11
template <class _Tp> using remove_extent_t = typename remove_extent<_Tp>::type;
#endif
# 708 "/usr/include/c++/v1/type_traits" 3

// remove_all_extents

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY remove_all_extents
    {typedef _Tp type;};
template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY remove_all_extents<_Tp[]>
    {typedef typename remove_all_extents<_Tp>::type type;};
template <class _Tp, size_t _Np> struct _LIBCPP_TYPE_VIS_ONLY remove_all_extents<_Tp[_Np]>
    {typedef typename remove_all_extents<_Tp>::type type;};

#if _LIBCPP_STD_VER > 11
template <class _Tp> using remove_all_extents_t = typename remove_all_extents<_Tp>::type;
#endif
# 721 "/usr/include/c++/v1/type_traits" 3

// decay

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY decay
{
private:
    typedef typename remove_reference<_Tp>::type _Up;
public:
    typedef typename conditional
                     <
                         is_array<_Up>::value,
                         typename remove_extent<_Up>::type*,
                         typename conditional
                         <
                              is_function<_Up>::value,
                              typename add_pointer<_Up>::type,
                              typename remove_cv<_Up>::type
                         >::type
                     >::type type;
};

#if _LIBCPP_STD_VER > 11
template <class _Tp> using decay_t = typename decay<_Tp>::type;
#endif
# 746 "/usr/include/c++/v1/type_traits" 3

// is_abstract

namespace __is_abstract_imp
{
template <class _Tp> char  __test(_Tp (*)[1]);
template <class _Tp> __two __test(...);
}

template <class _Tp, bool = is_class<_Tp>::value>
struct __libcpp_abstract : public integral_constant<bool, sizeof(__is_abstract_imp::__test<_Tp>(0)) != 1> {};

template <class _Tp> struct __libcpp_abstract<_Tp, false> : public false_type {};

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_abstract : public __libcpp_abstract<_Tp> {};

// is_base_of

#ifdef _LIBCPP_HAS_IS_BASE_OF

template <class _Bp, class _Dp>
struct _LIBCPP_TYPE_VIS_ONLY is_base_of
    : public integral_constant<bool, __is_base_of(_Bp, _Dp)> {};

#else  // __has_feature(is_base_of)
# 771 "/usr/include/c++/v1/type_traits" 3

namespace __is_base_of_imp
{
template <class _Tp>
struct _Dst
{
    _Dst(const volatile _Tp &);
};
template <class _Tp>
struct _Src
{
    operator const volatile _Tp &();
    template <class _Up> operator const _Dst<_Up> &();
};
template <size_t> struct __one { typedef char type; };
template <class _Bp, class _Dp> typename __one<sizeof(_Dst<_Bp>(declval<_Src<_Dp> >()))>::type __test(int);
template <class _Bp, class _Dp> __two __test(...);
}

template <class _Bp, class _Dp>
struct _LIBCPP_TYPE_VIS_ONLY is_base_of
    : public integral_constant<bool, is_class<_Bp>::value &&
                                     sizeof(__is_base_of_imp::__test<_Bp, _Dp>(0)) == 2> {};

#endif  // __has_feature(is_base_of)
# 796 "/usr/include/c++/v1/type_traits" 3

// is_convertible

#if __has_feature(is_convertible_to)

template <class _T1, class _T2> struct _LIBCPP_TYPE_VIS_ONLY is_convertible
    : public integral_constant<bool, __is_convertible_to(_T1, _T2) &&
                                     !is_abstract<_T2>::value> {};

#else  // __has_feature(is_convertible_to)
# 806 "/usr/include/c++/v1/type_traits" 3

namespace __is_convertible_imp
{
template <class _Tp> char  __test(_Tp);
template <class _Tp> __two __test(...);
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
template <class _Tp> _Tp&& __source();
#else
# 814 "/usr/include/c++/v1/type_traits" 3
template <class _Tp> typename remove_reference<_Tp>::type& __source();
#endif
# 816 "/usr/include/c++/v1/type_traits" 3

template <class _Tp, bool _IsArray =    is_array<_Tp>::value,
                     bool _IsFunction = is_function<_Tp>::value,
                     bool _IsVoid =     is_void<_Tp>::value>
                     struct __is_array_function_or_void                          {enum {value = 0};};
template <class _Tp> struct __is_array_function_or_void<_Tp, true, false, false> {enum {value = 1};};
template <class _Tp> struct __is_array_function_or_void<_Tp, false, true, false> {enum {value = 2};};
template <class _Tp> struct __is_array_function_or_void<_Tp, false, false, true> {enum {value = 3};};
}

template <class _Tp,
    unsigned = __is_convertible_imp::__is_array_function_or_void<typename remove_reference<_Tp>::type>::value>
struct __is_convertible_check
{
    static const size_t __v = 0;
};

template <class _Tp>
struct __is_convertible_check<_Tp, 0>
{
    static const size_t __v = sizeof(_Tp);
};

template <class _T1, class _T2,
    unsigned _T1_is_array_function_or_void = __is_convertible_imp::__is_array_function_or_void<_T1>::value,
    unsigned _T2_is_array_function_or_void = __is_convertible_imp::__is_array_function_or_void<_T2>::value>
struct __is_convertible
    : public integral_constant<bool,
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
        sizeof(__is_convertible_imp::__test<_T2>(__is_convertible_imp::__source<_T1>())) == 1
#else
# 847 "/usr/include/c++/v1/type_traits" 3
        sizeof(__is_convertible_imp::__test<_T2>(__is_convertible_imp::__source<_T1>())) == 1
         && !(!is_function<_T1>::value && !is_reference<_T1>::value && is_reference<_T2>::value
              && (!is_const<typename remove_reference<_T2>::type>::value
                  || is_volatile<typename remove_reference<_T2>::type>::value)
                  && (is_same<typename remove_cv<_T1>::type,
                              typename remove_cv<typename remove_reference<_T2>::type>::type>::value
                      || is_base_of<typename remove_reference<_T2>::type, _T1>::value))
#endif
# 855 "/usr/include/c++/v1/type_traits" 3
    >
{};

template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 1, 0> : false_type {};

template <class _T1> struct __is_convertible<_T1, const _T1&, 1, 0> : true_type {};
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
template <class _T1> struct __is_convertible<_T1, _T1&&, 1, 0> : true_type {};
template <class _T1> struct __is_convertible<_T1, const _T1&&, 1, 0> : true_type {};
template <class _T1> struct __is_convertible<_T1, volatile _T1&&, 1, 0> : true_type {};
template <class _T1> struct __is_convertible<_T1, const volatile _T1&&, 1, 0> : true_type {};
#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 867 "/usr/include/c++/v1/type_traits" 3

template <class _T1, class _T2> struct __is_convertible<_T1, _T2*, 1, 0>
    : public integral_constant<bool, __is_convertible<typename remove_all_extents<_T1>::type*, _T2*>::value> {};

template <class _T1, class _T2> struct __is_convertible<_T1, _T2* const, 1, 0>
    : public integral_constant<bool, __is_convertible<typename remove_all_extents<_T1>::type*, _T2*const>::value> {};

template <class _T1, class _T2> struct __is_convertible<_T1, _T2* volatile, 1, 0>
    : public integral_constant<bool, __is_convertible<typename remove_all_extents<_T1>::type*, _T2*volatile>::value> {};

template <class _T1, class _T2> struct __is_convertible<_T1, _T2* const volatile, 1, 0>
    : public integral_constant<bool, __is_convertible<typename remove_all_extents<_T1>::type*, _T2*const volatile>::value> {};

template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 2, 0>                : public false_type {};
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
template <class _T1>            struct __is_convertible<_T1, _T1&&, 2, 0>               : public true_type {};
#endif
# 884 "/usr/include/c++/v1/type_traits" 3
template <class _T1>            struct __is_convertible<_T1, _T1&, 2, 0>               : public true_type {};
template <class _T1>            struct __is_convertible<_T1, _T1*, 2, 0>               : public true_type {};
template <class _T1>            struct __is_convertible<_T1, _T1*const, 2, 0>          : public true_type {};
template <class _T1>            struct __is_convertible<_T1, _T1*volatile, 2, 0>       : public true_type {};
template <class _T1>            struct __is_convertible<_T1, _T1*const volatile, 2, 0> : public true_type {};

template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 3, 0> : public false_type {};

template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 0, 1> : public false_type {};
template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 1, 1> : public false_type {};
template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 2, 1> : public false_type {};
template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 3, 1> : public false_type {};

template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 0, 2> : public false_type {};
template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 1, 2> : public false_type {};
template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 2, 2> : public false_type {};
template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 3, 2> : public false_type {};

template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 0, 3> : public false_type {};
template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 1, 3> : public false_type {};
template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 2, 3> : public false_type {};
template <class _T1, class _T2> struct __is_convertible<_T1, _T2, 3, 3> : public true_type {};

template <class _T1, class _T2> struct _LIBCPP_TYPE_VIS_ONLY is_convertible
    : public __is_convertible<_T1, _T2>
{
    static const size_t __complete_check1 = __is_convertible_check<_T1>::__v;
    static const size_t __complete_check2 = __is_convertible_check<_T2>::__v;
};

#endif  // __has_feature(is_convertible_to)
# 915 "/usr/include/c++/v1/type_traits" 3

// is_empty

#if __has_feature(is_empty)

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_empty
    : public integral_constant<bool, __is_empty(_Tp)> {};

#else  // __has_feature(is_empty)
# 925 "/usr/include/c++/v1/type_traits" 3

template <class _Tp>
struct __is_empty1
    : public _Tp
{
    double __lx;
};

struct __is_empty2
{
    double __lx;
};

template <class _Tp, bool = is_class<_Tp>::value>
struct __libcpp_empty : public integral_constant<bool, sizeof(__is_empty1<_Tp>) == sizeof(__is_empty2)> {};

template <class _Tp> struct __libcpp_empty<_Tp, false> : public false_type {};

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_empty : public __libcpp_empty<_Tp> {};

#endif  // __has_feature(is_empty)
# 946 "/usr/include/c++/v1/type_traits" 3

// is_polymorphic

#if __has_feature(is_polymorphic)

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_polymorphic
    : public integral_constant<bool, __is_polymorphic(_Tp)> {};

#else
# 956 "/usr/include/c++/v1/type_traits" 3

template<typename _Tp> char &__is_polymorphic_impl(
    typename enable_if<sizeof((_Tp*)dynamic_cast<const volatile void*>(declval<_Tp*>())) != 0,
                       int>::type);
template<typename _Tp> __two &__is_polymorphic_impl(...);

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_polymorphic
    : public integral_constant<bool, sizeof(__is_polymorphic_impl<_Tp>(0)) == 1> {};

#endif // __has_feature(is_polymorphic)
# 966 "/usr/include/c++/v1/type_traits" 3

// has_virtual_destructor

#if __has_feature(has_virtual_destructor) || (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3)

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY has_virtual_destructor
    : public integral_constant<bool, __has_virtual_destructor(_Tp)> {};

#else  // _LIBCPP_HAS_TYPE_TRAITS
# 975 "/usr/include/c++/v1/type_traits" 3

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY has_virtual_destructor
    : public false_type {};

#endif  // _LIBCPP_HAS_TYPE_TRAITS
# 980 "/usr/include/c++/v1/type_traits" 3

// alignment_of

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY alignment_of
    : public integral_constant<size_t, __alignof__(_Tp)> {};

// aligned_storage

template <class _Hp, class _Tp>
struct __type_list
{
    typedef _Hp _Head;
    typedef _Tp _Tail;
};

struct __nat
{
#ifndef _LIBCPP_HAS_NO_DELETED_FUNCTIONS
    __nat() = delete;
    __nat(const __nat&) = delete;
    __nat& operator=(const __nat&) = delete;
    ~__nat() = delete;
#endif
# 1003 "/usr/include/c++/v1/type_traits" 3
};

template <class _Tp>
struct __align_type
{
    static const size_t value = alignment_of<_Tp>::value;
    typedef _Tp type;
};

struct __struct_double {long double __lx;};
struct __struct_double4 {double __lx[4];};

typedef
    __type_list<__align_type<unsigned char>,
    __type_list<__align_type<unsigned short>,
    __type_list<__align_type<unsigned int>,
    __type_list<__align_type<unsigned long>,
    __type_list<__align_type<unsigned long long>,
    __type_list<__align_type<double>,
    __type_list<__align_type<long double>,
    __type_list<__align_type<__struct_double>,
    __type_list<__align_type<__struct_double4>,
    __type_list<__align_type<int*>,
    __nat
    > > > > > > > > > > __all_types;

template <class _TL, size_t _Align> struct __find_pod;

template <class _Hp, size_t _Align>
struct __find_pod<__type_list<_Hp, __nat>, _Align>
{
    typedef typename conditional<
                             _Align == _Hp::value,
                             typename _Hp::type,
                             void
                         >::type type;
};

template <class _Hp, class _Tp, size_t _Align>
struct __find_pod<__type_list<_Hp, _Tp>, _Align>
{
    typedef typename conditional<
                             _Align == _Hp::value,
                             typename _Hp::type,
                             typename __find_pod<_Tp, _Align>::type
                         >::type type;
};

template <class _TL, size_t _Len> struct __find_max_align;

template <class _Hp, size_t _Len>
struct __find_max_align<__type_list<_Hp, __nat>, _Len> : public integral_constant<size_t, _Hp::value> {};

template <size_t _Len, size_t _A1, size_t _A2>
struct __select_align
{
private:
    static const size_t __min = _A2 < _A1 ? _A2 : _A1;
    static const size_t __max = _A1 < _A2 ? _A2 : _A1;
public:
    static const size_t value = _Len < __max ? __min : __max;
};

template <class _Hp, class _Tp, size_t _Len>
struct __find_max_align<__type_list<_Hp, _Tp>, _Len>
    : public integral_constant<size_t, __select_align<_Len, _Hp::value, __find_max_align<_Tp, _Len>::value>::value> {};

template <size_t _Len, size_t _Align = __find_max_align<__all_types, _Len>::value>
struct _LIBCPP_TYPE_VIS_ONLY aligned_storage
{
    typedef typename __find_pod<__all_types, _Align>::type _Aligner;
    static_assert(!is_void<_Aligner>::value, "");
    union type
    {
        _Aligner __align;
        unsigned char __data[_Len];
    };
};

#if _LIBCPP_STD_VER > 11
template <size_t _Len, size_t _Align = __find_max_align<__all_types, _Len>::value>
    using aligned_storage_t = typename aligned_storage<_Len, _Align>::type;
#endif
# 1086 "/usr/include/c++/v1/type_traits" 3

#define _CREATE_ALIGNED_STORAGE_SPECIALIZATION(n) \
template <size_t _Len>\
struct _LIBCPP_TYPE_VIS_ONLY aligned_storage<_Len, n>\
{\
    struct _ALIGNAS(n) type\
    {\
        unsigned char __lx[_Len];\
    };\
}

_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x1);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x2);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x4);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x8);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x10);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x20);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x40);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x80);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x100);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x200);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x400);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x800);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x1000);
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x2000);
// MSDN says that MSVC does not support alignment beyond 8192 (=0x2000)
#if !defined(_LIBCPP_MSVC)
_CREATE_ALIGNED_STORAGE_SPECIALIZATION(0x4000);
#endif // !_LIBCPP_MSVC
# 1115 "/usr/include/c++/v1/type_traits" 3

#undef _CREATE_ALIGNED_STORAGE_SPECIALIZATION

#ifndef _LIBCPP_HAS_NO_VARIADICS

// aligned_union

template <size_t _I0, size_t ..._In>
struct __static_max;

template <size_t _I0>
struct __static_max<_I0>
{
    static const size_t value = _I0;
};

template <size_t _I0, size_t _I1, size_t ..._In>
struct __static_max<_I0, _I1, _In...>
{
    static const size_t value = _I0 >= _I1 ? __static_max<_I0, _In...>::value :
                                             __static_max<_I1, _In...>::value;
};

template <size_t _Len, class _Type0, class ..._Types>
struct aligned_union
{
    static const size_t alignment_value = __static_max<__alignof__(_Type0),
                                                       __alignof__(_Types)...>::value;
    static const size_t __len = __static_max<_Len, sizeof(_Type0),
                                             sizeof(_Types)...>::value;
    typedef typename aligned_storage<__len, alignment_value>::type type;
};

#if _LIBCPP_STD_VER > 11
template <size_t _Len, class ..._Types> using aligned_union_t = typename aligned_union<_Len, _Types...>::type;
#endif
# 1151 "/usr/include/c++/v1/type_traits" 3

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 1153 "/usr/include/c++/v1/type_traits" 3

// __promote

template <class _A1, class _A2 = void, class _A3 = void,
          bool = (is_arithmetic<_A1>::value || is_void<_A1>::value) &&
                 (is_arithmetic<_A2>::value || is_void<_A2>::value) &&
                 (is_arithmetic<_A3>::value || is_void<_A3>::value)>
class __promote {};

template <class _A1, class _A2, class _A3>
class __promote<_A1, _A2, _A3, true>
{
private:
    typedef typename __promote<_A1>::type __type1;
    typedef typename __promote<_A2>::type __type2;
    typedef typename __promote<_A3>::type __type3;
public:
    typedef decltype(__type1() + __type2() + __type3()) type;
};

template <class _A1, class _A2>
class __promote<_A1, _A2, void, true>
{
private:
    typedef typename __promote<_A1>::type __type1;
    typedef typename __promote<_A2>::type __type2;
public:
    typedef decltype(__type1() + __type2()) type;
};

template <class _A1>
class __promote<_A1, void, void, true>
{
public:
    typedef typename conditional<is_arithmetic<_A1>::value,
                     typename conditional<is_integral<_A1>::value, double, _A1>::type,
                     void
            >::type type;
};

#ifdef _LIBCPP_STORE_AS_OPTIMIZATION

// __transform

template <class _Tp, size_t = sizeof(_Tp), bool = is_scalar<_Tp>::value> struct __transform {typedef _Tp type;};
template <class _Tp> struct __transform<_Tp, 1, true> {typedef unsigned char      type;};
template <class _Tp> struct __transform<_Tp, 2, true> {typedef unsigned short     type;};
template <class _Tp> struct __transform<_Tp, 4, true> {typedef unsigned int       type;};
template <class _Tp> struct __transform<_Tp, 8, true> {typedef unsigned long long type;};

#endif  // _LIBCPP_STORE_AS_OPTIMIZATION
# 1204 "/usr/include/c++/v1/type_traits" 3

// make_signed / make_unsigned

typedef
    __type_list<signed char,
    __type_list<signed short,
    __type_list<signed int,
    __type_list<signed long,
    __type_list<signed long long,
    __nat
    > > > > > __signed_types;

typedef
    __type_list<unsigned char,
    __type_list<unsigned short,
    __type_list<unsigned int,
    __type_list<unsigned long,
    __type_list<unsigned long long,
    __nat
    > > > > > __unsigned_types;

template <class _TypeList, size_t _Size, bool = _Size <= sizeof(typename _TypeList::_Head)> struct __find_first;

template <class _Hp, class _Tp, size_t _Size>
struct __find_first<__type_list<_Hp, _Tp>, _Size, true>
{
    typedef _Hp type;
};

template <class _Hp, class _Tp, size_t _Size>
struct __find_first<__type_list<_Hp, _Tp>, _Size, false>
{
    typedef typename __find_first<_Tp, _Size>::type type;
};

template <class _Tp, class _Up, bool = is_const<typename remove_reference<_Tp>::type>::value,
                             bool = is_volatile<typename remove_reference<_Tp>::type>::value>
struct __apply_cv
{
    typedef _Up type;
};

template <class _Tp, class _Up>
struct __apply_cv<_Tp, _Up, true, false>
{
    typedef const _Up type;
};

template <class _Tp, class _Up>
struct __apply_cv<_Tp, _Up, false, true>
{
    typedef volatile _Up type;
};

template <class _Tp, class _Up>
struct __apply_cv<_Tp, _Up, true, true>
{
    typedef const volatile _Up type;
};

template <class _Tp, class _Up>
struct __apply_cv<_Tp&, _Up, false, false>
{
    typedef _Up& type;
};

template <class _Tp, class _Up>
struct __apply_cv<_Tp&, _Up, true, false>
{
    typedef const _Up& type;
};

template <class _Tp, class _Up>
struct __apply_cv<_Tp&, _Up, false, true>
{
    typedef volatile _Up& type;
};

template <class _Tp, class _Up>
struct __apply_cv<_Tp&, _Up, true, true>
{
    typedef const volatile _Up& type;
};

template <class _Tp, bool = is_integral<_Tp>::value || is_enum<_Tp>::value>
struct __make_signed {};

template <class _Tp>
struct __make_signed<_Tp, true>
{
    typedef typename __find_first<__signed_types, sizeof(_Tp)>::type type;
};

template <> struct __make_signed<bool,               true> {};
template <> struct __make_signed<  signed short,     true> {typedef short     type;};
template <> struct __make_signed<unsigned short,     true> {typedef short     type;};
template <> struct __make_signed<  signed int,       true> {typedef int       type;};
template <> struct __make_signed<unsigned int,       true> {typedef int       type;};
template <> struct __make_signed<  signed long,      true> {typedef long      type;};
template <> struct __make_signed<unsigned long,      true> {typedef long      type;};
template <> struct __make_signed<  signed long long, true> {typedef long long type;};
template <> struct __make_signed<unsigned long long, true> {typedef long long type;};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY make_signed
{
    typedef typename __apply_cv<_Tp, typename __make_signed<typename remove_cv<_Tp>::type>::type>::type type;
};

#if _LIBCPP_STD_VER > 11
template <class _Tp> using make_signed_t = typename make_signed<_Tp>::type;
#endif
# 1316 "/usr/include/c++/v1/type_traits" 3

template <class _Tp, bool = is_integral<_Tp>::value || is_enum<_Tp>::value>
struct __make_unsigned {};

template <class _Tp>
struct __make_unsigned<_Tp, true>
{
    typedef typename __find_first<__unsigned_types, sizeof(_Tp)>::type type;
};

template <> struct __make_unsigned<bool,               true> {};
template <> struct __make_unsigned<  signed short,     true> {typedef unsigned short     type;};
template <> struct __make_unsigned<unsigned short,     true> {typedef unsigned short     type;};
template <> struct __make_unsigned<  signed int,       true> {typedef unsigned int       type;};
template <> struct __make_unsigned<unsigned int,       true> {typedef unsigned int       type;};
template <> struct __make_unsigned<  signed long,      true> {typedef unsigned long      type;};
template <> struct __make_unsigned<unsigned long,      true> {typedef unsigned long      type;};
template <> struct __make_unsigned<  signed long long, true> {typedef unsigned long long type;};
template <> struct __make_unsigned<unsigned long long, true> {typedef unsigned long long type;};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY make_unsigned
{
    typedef typename __apply_cv<_Tp, typename __make_unsigned<typename remove_cv<_Tp>::type>::type>::type type;
};

#if _LIBCPP_STD_VER > 11
template <class _Tp> using make_unsigned_t = typename make_unsigned<_Tp>::type;
#endif
# 1345 "/usr/include/c++/v1/type_traits" 3

#ifdef _LIBCPP_HAS_NO_VARIADICS

template <class _Tp, class _Up = void, class V = void>
struct _LIBCPP_TYPE_VIS_ONLY common_type
{
public:
    typedef typename common_type<typename common_type<_Tp, _Up>::type, V>::type type;
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY common_type<_Tp, void, void>
{
public:
    typedef _Tp type;
};

template <class _Tp, class _Up>
struct _LIBCPP_TYPE_VIS_ONLY common_type<_Tp, _Up, void>
{
private:
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    static _Tp&& __t();
    static _Up&& __u();
#else  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 1370 "/usr/include/c++/v1/type_traits" 3
    static _Tp __t();
    static _Up __u();
#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 1373 "/usr/include/c++/v1/type_traits" 3
public:
    typedef typename remove_reference<decltype(true ? __t() : __u())>::type type;
};

#else  // _LIBCPP_HAS_NO_VARIADICS
# 1378 "/usr/include/c++/v1/type_traits" 3

template <class ..._Tp> struct common_type;

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY common_type<_Tp>
{
    typedef typename decay<_Tp>::type type;
};

template <class _Tp, class _Up>
struct _LIBCPP_TYPE_VIS_ONLY common_type<_Tp, _Up>
{
private:
    static _Tp&& __t();
    static _Up&& __u();
    static bool __f();
public:
    typedef typename decay<decltype(__f() ? __t() : __u())>::type type;
};

template <class _Tp, class _Up, class ..._Vp>
struct _LIBCPP_TYPE_VIS_ONLY common_type<_Tp, _Up, _Vp...>
{
    typedef typename common_type<typename common_type<_Tp, _Up>::type, _Vp...>::type type;
};

#if _LIBCPP_STD_VER > 11
template <class ..._Tp> using common_type_t = typename common_type<_Tp...>::type;
#endif
# 1407 "/usr/include/c++/v1/type_traits" 3

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 1409 "/usr/include/c++/v1/type_traits" 3

// is_assignable

template<typename, typename _Tp> struct __select_2nd { typedef _Tp type; };

template <class _Tp, class _Arg>
typename __select_2nd<decltype((_VSTD::declval<_Tp>() = _VSTD::declval<_Arg>())), true_type>::type
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
__is_assignable_test(_Tp&&, _Arg&&);
#else
# 1419 "/usr/include/c++/v1/type_traits" 3
__is_assignable_test(_Tp, _Arg&);
#endif
# 1421 "/usr/include/c++/v1/type_traits" 3

template <class _Arg>
false_type
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
__is_assignable_test(__any, _Arg&&);
#else
# 1427 "/usr/include/c++/v1/type_traits" 3
__is_assignable_test(__any, _Arg&);
#endif
# 1429 "/usr/include/c++/v1/type_traits" 3

template <class _Tp, class _Arg, bool = is_void<_Tp>::value || is_void<_Arg>::value>
struct __is_assignable_imp
    : public common_type
        <
            decltype(__is_assignable_test(declval<_Tp>(), declval<_Arg>()))
        >::type {};

template <class _Tp, class _Arg>
struct __is_assignable_imp<_Tp, _Arg, true>
    : public false_type
{
};

template <class _Tp, class _Arg>
struct is_assignable
    : public __is_assignable_imp<_Tp, _Arg> {};

// is_copy_assignable

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_copy_assignable
    : public is_assignable<typename add_lvalue_reference<_Tp>::type,
                     const typename add_lvalue_reference<_Tp>::type> {};

// is_move_assignable

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_move_assignable
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    : public is_assignable<typename add_lvalue_reference<_Tp>::type,
                     const typename add_rvalue_reference<_Tp>::type> {};
#else
# 1460 "/usr/include/c++/v1/type_traits" 3
    : public is_copy_assignable<_Tp> {};
#endif
# 1462 "/usr/include/c++/v1/type_traits" 3

// is_destructible

template <class _Tp>
struct __destructible_test
{
    _Tp __t;
};

template <class _Tp>
decltype((_VSTD::declval<__destructible_test<_Tp> >().~__destructible_test<_Tp>(), true_type()))
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
__is_destructible_test(_Tp&&);
#else
# 1476 "/usr/include/c++/v1/type_traits" 3
__is_destructible_test(_Tp&);
#endif
# 1478 "/usr/include/c++/v1/type_traits" 3

false_type
__is_destructible_test(__any);

template <class _Tp, bool = is_void<_Tp>::value || is_abstract<_Tp>::value
                                                || is_function<_Tp>::value>
struct __destructible_imp
    : public common_type
        <
            decltype(__is_destructible_test(declval<_Tp>()))
        >::type {};

template <class _Tp>
struct __destructible_imp<_Tp, true>
    : public false_type {};

template <class _Tp>
struct is_destructible
    : public __destructible_imp<_Tp> {};

template <class _Tp>
struct is_destructible<_Tp[]>
    : public false_type {};

// move

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
typename remove_reference<_Tp>::type&&
move(_Tp&& __t) _NOEXCEPT
{
    typedef typename remove_reference<_Tp>::type _Up;
    return static_cast<_Up&&>(__t);
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
_Tp&&
forward(typename std::remove_reference<_Tp>::type& __t) _NOEXCEPT
{
    return static_cast<_Tp&&>(__t);
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
_Tp&&
forward(typename std::remove_reference<_Tp>::type&& __t) _NOEXCEPT
{
    static_assert(!std::is_lvalue_reference<_Tp>::value,
                  "Can not forward an rvalue as an lvalue.");
    return static_cast<_Tp&&>(__t);
}

#else  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 1534 "/usr/include/c++/v1/type_traits" 3

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_Tp&
move(_Tp& __t)
{
    return __t;
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
const _Tp&
move(const _Tp& __t)
{
    return __t;
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_Tp&
forward(typename std::remove_reference<_Tp>::type& __t) _NOEXCEPT
{
    return __t;
}


template <class _Tp>
class __rv
{
    typedef typename remove_reference<_Tp>::type _Trr;
    _Trr& t_;
public:
    _LIBCPP_INLINE_VISIBILITY
    _Trr* operator->() {return &t_;}
    _LIBCPP_INLINE_VISIBILITY
    explicit __rv(_Trr& __t) : t_(__t) {}
};

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 1573 "/usr/include/c++/v1/type_traits" 3

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
typename decay<_Tp>::type
__decay_copy(_Tp&& __t)
{
    return _VSTD::forward<_Tp>(__t);
}

#else
# 1585 "/usr/include/c++/v1/type_traits" 3

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
typename decay<_Tp>::type
__decay_copy(const _Tp& __t)
{
    return _VSTD::forward<_Tp>(__t);
}

#endif
# 1595 "/usr/include/c++/v1/type_traits" 3

template <class _MP, bool _IsMemberFuctionPtr, bool _IsMemberObjectPtr>
struct __member_pointer_traits_imp
{
};

#ifndef _LIBCPP_HAS_NO_VARIADICS

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...), true, false>
{
    typedef _Class _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) const, true, false>
{
    typedef _Class const _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) volatile, true, false>
{
    typedef _Class volatile _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) const volatile, true, false>
{
    typedef _Class const volatile _ClassType;
    typedef _Rp _ReturnType;
};

#if __has_feature(cxx_reference_qualified_functions)

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) &, true, false>
{
    typedef _Class& _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) const&, true, false>
{
    typedef _Class const& _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) volatile&, true, false>
{
    typedef _Class volatile& _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) const volatile&, true, false>
{
    typedef _Class const volatile& _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) &&, true, false>
{
    typedef _Class&& _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) const&&, true, false>
{
    typedef _Class const&& _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) volatile&&, true, false>
{
    typedef _Class volatile&& _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class ..._Param>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_Param...) const volatile&&, true, false>
{
    typedef _Class const volatile&& _ClassType;
    typedef _Rp _ReturnType;
};

#endif  // __has_feature(cxx_reference_qualified_functions)
# 1690 "/usr/include/c++/v1/type_traits" 3

#else  // _LIBCPP_HAS_NO_VARIADICS
# 1692 "/usr/include/c++/v1/type_traits" 3

template <class _Rp, class _Class>
struct __member_pointer_traits_imp<_Rp (_Class::*)(), true, false>
{
    typedef _Class _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class _P0>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_P0), true, false>
{
    typedef _Class _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class _P0, class _P1>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_P0, _P1), true, false>
{
    typedef _Class _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class _P0, class _P1, class _P2>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_P0, _P1, _P2), true, false>
{
    typedef _Class _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class>
struct __member_pointer_traits_imp<_Rp (_Class::*)() const, true, false>
{
    typedef _Class const _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class _P0>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_P0) const, true, false>
{
    typedef _Class const _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class _P0, class _P1>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_P0, _P1) const, true, false>
{
    typedef _Class const _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class _P0, class _P1, class _P2>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_P0, _P1, _P2) const, true, false>
{
    typedef _Class const _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class>
struct __member_pointer_traits_imp<_Rp (_Class::*)() volatile, true, false>
{
    typedef _Class volatile _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class _P0>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_P0) volatile, true, false>
{
    typedef _Class volatile _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class _P0, class _P1>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_P0, _P1) volatile, true, false>
{
    typedef _Class volatile _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class _P0, class _P1, class _P2>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_P0, _P1, _P2) volatile, true, false>
{
    typedef _Class volatile _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class>
struct __member_pointer_traits_imp<_Rp (_Class::*)() const volatile, true, false>
{
    typedef _Class const volatile _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class _P0>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_P0) const volatile, true, false>
{
    typedef _Class const volatile _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class _P0, class _P1>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_P0, _P1) const volatile, true, false>
{
    typedef _Class const volatile _ClassType;
    typedef _Rp _ReturnType;
};

template <class _Rp, class _Class, class _P0, class _P1, class _P2>
struct __member_pointer_traits_imp<_Rp (_Class::*)(_P0, _P1, _P2) const volatile, true, false>
{
    typedef _Class const volatile _ClassType;
    typedef _Rp _ReturnType;
};

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 1806 "/usr/include/c++/v1/type_traits" 3

template <class _Rp, class _Class>
struct __member_pointer_traits_imp<_Rp _Class::*, false, true>
{
    typedef _Class _ClassType;
    typedef _Rp _ReturnType;
};

template <class _MP>
struct __member_pointer_traits
    : public __member_pointer_traits_imp<typename remove_cv<_MP>::type,
                    is_member_function_pointer<_MP>::value,
                    is_member_object_pointer<_MP>::value>
{
//     typedef ... _ClassType;
//     typedef ... _ReturnType;
};

// result_of

template <class _Callable> class result_of;

#ifdef _LIBCPP_HAS_NO_VARIADICS

template <class _Fn, bool, bool>
class __result_of
{
};

template <class _Fn>
class __result_of<_Fn(), true, false>
{
public:
    typedef decltype(declval<_Fn>()()) type;
};

template <class _Fn, class _A0>
class __result_of<_Fn(_A0), true, false>
{
public:
    typedef decltype(declval<_Fn>()(declval<_A0>())) type;
};

template <class _Fn, class _A0, class _A1>
class __result_of<_Fn(_A0, _A1), true, false>
{
public:
    typedef decltype(declval<_Fn>()(declval<_A0>(), declval<_A1>())) type;
};

template <class _Fn, class _A0, class _A1, class _A2>
class __result_of<_Fn(_A0, _A1, _A2), true, false>
{
public:
    typedef decltype(declval<_Fn>()(declval<_A0>(), declval<_A1>(), declval<_A2>())) type;
};

template <class _MP, class _Tp, bool _IsMemberFunctionPtr>
struct __result_of_mp;

// member function pointer

template <class _MP, class _Tp>
struct __result_of_mp<_MP, _Tp, true>
    : public common_type<typename __member_pointer_traits<_MP>::_ReturnType>
{
};

// member data pointer

template <class _MP, class _Tp, bool>
struct __result_of_mdp;

template <class _Rp, class _Class, class _Tp>
struct __result_of_mdp<_Rp _Class::*, _Tp, false>
{
    typedef typename __apply_cv<decltype(*_VSTD::declval<_Tp>()), _Rp>::type& type;
};

template <class _Rp, class _Class, class _Tp>
struct __result_of_mdp<_Rp _Class::*, _Tp, true>
{
    typedef typename __apply_cv<_Tp, _Rp>::type& type;
};

template <class _Rp, class _Class, class _Tp>
struct __result_of_mp<_Rp _Class::*, _Tp, false>
    : public __result_of_mdp<_Rp _Class::*, _Tp,
            is_base_of<_Class, typename remove_reference<_Tp>::type>::value>
{
};



template <class _Fn, class _Tp>
class __result_of<_Fn(_Tp), false, true>  // _Fn must be member pointer
    : public __result_of_mp<typename remove_reference<_Fn>::type,
                            _Tp,
                            is_member_function_pointer<typename remove_reference<_Fn>::type>::value>
{
};

template <class _Fn, class _Tp, class _A0>
class __result_of<_Fn(_Tp, _A0), false, true>  // _Fn must be member pointer
    : public __result_of_mp<typename remove_reference<_Fn>::type,
                            _Tp,
                            is_member_function_pointer<typename remove_reference<_Fn>::type>::value>
{
};

template <class _Fn, class _Tp, class _A0, class _A1>
class __result_of<_Fn(_Tp, _A0, _A1), false, true>  // _Fn must be member pointer
    : public __result_of_mp<typename remove_reference<_Fn>::type,
                            _Tp,
                            is_member_function_pointer<typename remove_reference<_Fn>::type>::value>
{
};

template <class _Fn, class _Tp, class _A0, class _A1, class _A2>
class __result_of<_Fn(_Tp, _A0, _A1, _A2), false, true>  // _Fn must be member pointer
    : public __result_of_mp<typename remove_reference<_Fn>::type,
                            _Tp,
                            is_member_function_pointer<typename remove_reference<_Fn>::type>::value>
{
};

// result_of

template <class _Fn>
class _LIBCPP_TYPE_VIS_ONLY result_of<_Fn()>
    : public __result_of<_Fn(),
                         is_class<typename remove_reference<_Fn>::type>::value ||
                         is_function<typename remove_reference<_Fn>::type>::value,
                         is_member_pointer<typename remove_reference<_Fn>::type>::value
                        >
{
};

template <class _Fn, class _A0>
class _LIBCPP_TYPE_VIS_ONLY result_of<_Fn(_A0)>
    : public __result_of<_Fn(_A0),
                         is_class<typename remove_reference<_Fn>::type>::value ||
                         is_function<typename remove_reference<_Fn>::type>::value,
                         is_member_pointer<typename remove_reference<_Fn>::type>::value
                        >
{
};

template <class _Fn, class _A0, class _A1>
class _LIBCPP_TYPE_VIS_ONLY result_of<_Fn(_A0, _A1)>
    : public __result_of<_Fn(_A0, _A1),
                         is_class<typename remove_reference<_Fn>::type>::value ||
                         is_function<typename remove_reference<_Fn>::type>::value,
                         is_member_pointer<typename remove_reference<_Fn>::type>::value
                        >
{
};

template <class _Fn, class _A0, class _A1, class _A2>
class _LIBCPP_TYPE_VIS_ONLY result_of<_Fn(_A0, _A1, _A2)>
    : public __result_of<_Fn(_A0, _A1, _A2),
                         is_class<typename remove_reference<_Fn>::type>::value ||
                         is_function<typename remove_reference<_Fn>::type>::value,
                         is_member_pointer<typename remove_reference<_Fn>::type>::value
                        >
{
};

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 1975 "/usr/include/c++/v1/type_traits" 3

#ifndef _LIBCPP_HAS_NO_VARIADICS

// template <class T, class... Args> struct is_constructible;

//      main is_constructible test

template <class _Tp, class ..._Args>
typename __select_2nd<decltype(_VSTD::move(_Tp(_VSTD::declval<_Args>()...))), true_type>::type
__is_constructible_test(_Tp&&, _Args&& ...);

template <class ..._Args>
false_type
__is_constructible_test(__any, _Args&& ...);

template <bool, class _Tp, class... _Args>
struct __is_constructible // false, _Tp is not a scalar
    : public common_type
             <
                 decltype(__is_constructible_test(declval<_Tp>(), declval<_Args>()...))
             >::type
    {};

//      function types are not constructible

template <class _Rp, class... _A1, class... _A2>
struct __is_constructible<false, _Rp(_A1...), _A2...>
    : public false_type
    {};

//      handle scalars and reference types

//      Scalars are default constructible, references are not

template <class _Tp>
struct __is_constructible<true, _Tp>
    : public is_scalar<_Tp>
    {};

//      Scalars and references are constructible from one arg if that arg is
//          implicitly convertible to the scalar or reference.

template <class _Tp>
struct __is_constructible_ref
{
    true_type static __lxx(_Tp);
    false_type static __lxx(...);
};

template <class _Tp, class _A0>
struct __is_constructible<true, _Tp, _A0>
    : public common_type
             <
                 decltype(__is_constructible_ref<_Tp>::__lxx(declval<_A0>()))
             >::type
    {};

//      Scalars and references are not constructible from multiple args.

template <class _Tp, class _A0, class ..._Args>
struct __is_constructible<true, _Tp, _A0, _Args...>
    : public false_type
    {};

//      Treat scalars and reference types separately

template <bool, class _Tp, class... _Args>
struct __is_constructible_void_check
    : public __is_constructible<is_scalar<_Tp>::value || is_reference<_Tp>::value,
                                _Tp, _Args...>
    {};

//      If any of T or Args is void, is_constructible should be false

template <class _Tp, class... _Args>
struct __is_constructible_void_check<true, _Tp, _Args...>
    : public false_type
    {};

template <class ..._Args> struct __contains_void;

template <> struct __contains_void<> : false_type {};

template <class _A0, class ..._Args>
struct __contains_void<_A0, _Args...>
{
    static const bool value = is_void<_A0>::value ||
                              __contains_void<_Args...>::value;
};

//      is_constructible entry point

template <class _Tp, class... _Args>
struct _LIBCPP_TYPE_VIS_ONLY is_constructible
    : public __is_constructible_void_check<__contains_void<_Tp, _Args...>::value
                                        || is_abstract<_Tp>::value,
                                           _Tp, _Args...>
    {};

//      Array types are default constructible if their element type
//      is default constructible

template <class _Ap, size_t _Np>
struct __is_constructible<false, _Ap[_Np]>
    : public is_constructible<typename remove_all_extents<_Ap>::type>
    {};

//      Otherwise array types are not constructible by this syntax

template <class _Ap, size_t _Np, class ..._Args>
struct __is_constructible<false, _Ap[_Np], _Args...>
    : public false_type
    {};

//      Incomplete array types are not constructible

template <class _Ap, class ..._Args>
struct __is_constructible<false, _Ap[], _Args...>
    : public false_type
    {};

#else  // _LIBCPP_HAS_NO_VARIADICS
# 2097 "/usr/include/c++/v1/type_traits" 3

// template <class T> struct is_constructible0;

//      main is_constructible0 test

template <class _Tp>
decltype((_Tp(), true_type()))
__is_constructible0_test(_Tp&);

false_type
__is_constructible0_test(__any);

template <class _Tp, class _A0>
decltype((_Tp(_VSTD::declval<_A0>()), true_type()))
__is_constructible1_test(_Tp&, _A0&);

template <class _A0>
false_type
__is_constructible1_test(__any, _A0&);

template <class _Tp, class _A0, class _A1>
decltype((_Tp(_VSTD::declval<_A0>(), _VSTD::declval<_A1>()), true_type()))
__is_constructible2_test(_Tp&, _A0&, _A1&);

template <class _A0, class _A1>
false_type
__is_constructible2_test(__any, _A0&, _A1&);

template <bool, class _Tp>
struct __is_constructible0_imp // false, _Tp is not a scalar
    : public common_type
             <
                 decltype(__is_constructible0_test(declval<_Tp&>()))
             >::type
    {};

template <bool, class _Tp, class _A0>
struct __is_constructible1_imp // false, _Tp is not a scalar
    : public common_type
             <
                 decltype(__is_constructible1_test(declval<_Tp&>(), declval<_A0&>()))
             >::type
    {};

template <bool, class _Tp, class _A0, class _A1>
struct __is_constructible2_imp // false, _Tp is not a scalar
    : public common_type
             <
                 decltype(__is_constructible2_test(declval<_Tp&>(), declval<_A0>(), declval<_A1>()))
             >::type
    {};

//      handle scalars and reference types

//      Scalars are default constructible, references are not

template <class _Tp>
struct __is_constructible0_imp<true, _Tp>
    : public is_scalar<_Tp>
    {};

template <class _Tp, class _A0>
struct __is_constructible1_imp<true, _Tp, _A0>
    : public is_convertible<_A0, _Tp>
    {};

template <class _Tp, class _A0, class _A1>
struct __is_constructible2_imp<true, _Tp, _A0, _A1>
    : public false_type
    {};

//      Treat scalars and reference types separately

template <bool, class _Tp>
struct __is_constructible0_void_check
    : public __is_constructible0_imp<is_scalar<_Tp>::value || is_reference<_Tp>::value,
                                _Tp>
    {};

template <bool, class _Tp, class _A0>
struct __is_constructible1_void_check
    : public __is_constructible1_imp<is_scalar<_Tp>::value || is_reference<_Tp>::value,
                                _Tp, _A0>
    {};

template <bool, class _Tp, class _A0, class _A1>
struct __is_constructible2_void_check
    : public __is_constructible2_imp<is_scalar<_Tp>::value || is_reference<_Tp>::value,
                                _Tp, _A0, _A1>
    {};

//      If any of T or Args is void, is_constructible should be false

template <class _Tp>
struct __is_constructible0_void_check<true, _Tp>
    : public false_type
    {};

template <class _Tp, class _A0>
struct __is_constructible1_void_check<true, _Tp, _A0>
    : public false_type
    {};

template <class _Tp, class _A0, class _A1>
struct __is_constructible2_void_check<true, _Tp, _A0, _A1>
    : public false_type
    {};

//      is_constructible entry point

namespace __is_construct
{

struct __nat {};

}

template <class _Tp, class _A0 = __is_construct::__nat,
                     class _A1 = __is_construct::__nat>
struct _LIBCPP_TYPE_VIS_ONLY is_constructible
    : public __is_constructible2_void_check<is_void<_Tp>::value
                                        || is_abstract<_Tp>::value
                                        || is_function<_Tp>::value
                                        || is_void<_A0>::value
                                        || is_void<_A1>::value,
                                           _Tp, _A0, _A1>
    {};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_constructible<_Tp, __is_construct::__nat, __is_construct::__nat>
    : public __is_constructible0_void_check<is_void<_Tp>::value
                                        || is_abstract<_Tp>::value
                                        || is_function<_Tp>::value,
                                           _Tp>
    {};

template <class _Tp, class _A0>
struct _LIBCPP_TYPE_VIS_ONLY is_constructible<_Tp, _A0, __is_construct::__nat>
    : public __is_constructible1_void_check<is_void<_Tp>::value
                                        || is_abstract<_Tp>::value
                                        || is_function<_Tp>::value
                                        || is_void<_A0>::value,
                                           _Tp, _A0>
    {};

//      Array types are default constructible if their element type
//      is default constructible

template <class _Ap, size_t _Np>
struct __is_constructible0_imp<false, _Ap[_Np]>
    : public is_constructible<typename remove_all_extents<_Ap>::type>
    {};

template <class _Ap, size_t _Np, class _A0>
struct __is_constructible1_imp<false, _Ap[_Np], _A0>
    : public false_type
    {};

template <class _Ap, size_t _Np, class _A0, class _A1>
struct __is_constructible2_imp<false, _Ap[_Np], _A0, _A1>
    : public false_type
    {};

//      Incomplete array types are not constructible

template <class _Ap>
struct __is_constructible0_imp<false, _Ap[]>
    : public false_type
    {};

template <class _Ap, class _A0>
struct __is_constructible1_imp<false, _Ap[], _A0>
    : public false_type
    {};

template <class _Ap, class _A0, class _A1>
struct __is_constructible2_imp<false, _Ap[], _A0, _A1>
    : public false_type
    {};

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 2278 "/usr/include/c++/v1/type_traits" 3

// is_default_constructible

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_default_constructible
    : public is_constructible<_Tp>
    {};

// is_copy_constructible

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_copy_constructible
    : public is_constructible<_Tp, const typename add_lvalue_reference<_Tp>::type>
    {};

// is_move_constructible

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_move_constructible
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    : public is_constructible<_Tp, typename add_rvalue_reference<_Tp>::type>
#else
# 2300 "/usr/include/c++/v1/type_traits" 3
    : public is_copy_constructible<_Tp>
#endif
# 2302 "/usr/include/c++/v1/type_traits" 3
    {};

// is_trivially_constructible

#ifndef _LIBCPP_HAS_NO_VARIADICS

#if __has_feature(is_trivially_constructible)

template <class _Tp, class... _Args>
struct _LIBCPP_TYPE_VIS_ONLY is_trivially_constructible
    : integral_constant<bool, __is_trivially_constructible(_Tp, _Args...)>
{
};

#else  // !__has_feature(is_trivially_constructible)
# 2317 "/usr/include/c++/v1/type_traits" 3

template <class _Tp, class... _Args>
struct _LIBCPP_TYPE_VIS_ONLY is_trivially_constructible
    : false_type
{
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_trivially_constructible<_Tp>
#if __has_feature(has_trivial_constructor) || (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3)
    : integral_constant<bool, __has_trivial_constructor(_Tp)>
#else
# 2329 "/usr/include/c++/v1/type_traits" 3
    : integral_constant<bool, is_scalar<_Tp>::value>
#endif
# 2331 "/usr/include/c++/v1/type_traits" 3
{
};

template <class _Tp>
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
struct _LIBCPP_TYPE_VIS_ONLY is_trivially_constructible<_Tp, _Tp&&>
#else
# 2338 "/usr/include/c++/v1/type_traits" 3
struct _LIBCPP_TYPE_VIS_ONLY is_trivially_constructible<_Tp, _Tp>
#endif
# 2340 "/usr/include/c++/v1/type_traits" 3
    : integral_constant<bool, is_scalar<_Tp>::value>
{
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_trivially_constructible<_Tp, const _Tp&>
    : integral_constant<bool, is_scalar<_Tp>::value>
{
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_trivially_constructible<_Tp, _Tp&>
    : integral_constant<bool, is_scalar<_Tp>::value>
{
};

#endif  // !__has_feature(is_trivially_constructible)
# 2357 "/usr/include/c++/v1/type_traits" 3

#else  // _LIBCPP_HAS_NO_VARIADICS
# 2359 "/usr/include/c++/v1/type_traits" 3

template <class _Tp, class _A0 = __is_construct::__nat,
                     class _A1 = __is_construct::__nat>
struct _LIBCPP_TYPE_VIS_ONLY is_trivially_constructible
    : false_type
{
};

#if __has_feature(is_trivially_constructible)

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_trivially_constructible<_Tp, __is_construct::__nat,
                                                       __is_construct::__nat>
    : integral_constant<bool, __is_trivially_constructible(_Tp)>
{
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_trivially_constructible<_Tp, _Tp,
                                                       __is_construct::__nat>
    : integral_constant<bool, __is_trivially_constructible(_Tp, _Tp)>
{
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_trivially_constructible<_Tp, const _Tp&,
                                                       __is_construct::__nat>
    : integral_constant<bool, __is_trivially_constructible(_Tp, const _Tp&)>
{
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_trivially_constructible<_Tp, _Tp&,
                                                       __is_construct::__nat>
    : integral_constant<bool, __is_trivially_constructible(_Tp, _Tp&)>
{
};

#else  // !__has_feature(is_trivially_constructible)
# 2398 "/usr/include/c++/v1/type_traits" 3

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_trivially_constructible<_Tp, __is_construct::__nat,
                                                       __is_construct::__nat>
    : integral_constant<bool, is_scalar<_Tp>::value>
{
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_trivially_constructible<_Tp, _Tp,
                                                       __is_construct::__nat>
    : integral_constant<bool, is_scalar<_Tp>::value>
{
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_trivially_constructible<_Tp, const _Tp&,
                                                       __is_construct::__nat>
    : integral_constant<bool, is_scalar<_Tp>::value>
{
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_trivially_constructible<_Tp, _Tp&,
                                                       __is_construct::__nat>
    : integral_constant<bool, is_scalar<_Tp>::value>
{
};

#endif  // !__has_feature(is_trivially_constructible)
# 2428 "/usr/include/c++/v1/type_traits" 3

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 2430 "/usr/include/c++/v1/type_traits" 3

// is_trivially_default_constructible

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_trivially_default_constructible
    : public is_trivially_constructible<_Tp>
    {};

// is_trivially_copy_constructible

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_trivially_copy_constructible
    : public is_trivially_constructible<_Tp, typename add_lvalue_reference<const _Tp>::type>
    {};

// is_trivially_move_constructible

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_trivially_move_constructible
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    : public is_trivially_constructible<_Tp, typename add_rvalue_reference<_Tp>::type>
#else
# 2449 "/usr/include/c++/v1/type_traits" 3
    : public is_trivially_copy_constructible<_Tp>
#endif
# 2451 "/usr/include/c++/v1/type_traits" 3
    {};

// is_trivially_assignable

#if __has_feature(is_trivially_constructible)

template <class _Tp, class _Arg>
struct is_trivially_assignable
    : integral_constant<bool, __is_trivially_assignable(_Tp, _Arg)>
{
};

#else  // !__has_feature(is_trivially_constructible)
# 2464 "/usr/include/c++/v1/type_traits" 3

template <class _Tp, class _Arg>
struct is_trivially_assignable
    : public false_type {};

template <class _Tp>
struct is_trivially_assignable<_Tp&, _Tp>
    : integral_constant<bool, is_scalar<_Tp>::value> {};

template <class _Tp>
struct is_trivially_assignable<_Tp&, _Tp&>
    : integral_constant<bool, is_scalar<_Tp>::value> {};

template <class _Tp>
struct is_trivially_assignable<_Tp&, const _Tp&>
    : integral_constant<bool, is_scalar<_Tp>::value> {};

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template <class _Tp>
struct is_trivially_assignable<_Tp&, _Tp&&>
    : integral_constant<bool, is_scalar<_Tp>::value> {};

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 2488 "/usr/include/c++/v1/type_traits" 3

#endif  // !__has_feature(is_trivially_constructible)
# 2490 "/usr/include/c++/v1/type_traits" 3

// is_trivially_copy_assignable

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_trivially_copy_assignable
    : public is_trivially_assignable<typename add_lvalue_reference<_Tp>::type,
                               const typename add_lvalue_reference<_Tp>::type>
    {};

// is_trivially_move_assignable

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_trivially_move_assignable
    : public is_trivially_assignable<typename add_lvalue_reference<_Tp>::type,
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
                                     typename add_rvalue_reference<_Tp>::type>
#else
# 2505 "/usr/include/c++/v1/type_traits" 3
                                     typename add_lvalue_reference<_Tp>::type>
#endif
# 2507 "/usr/include/c++/v1/type_traits" 3
    {};

// is_trivially_destructible

#if __has_feature(has_trivial_destructor) || (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3)

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_trivially_destructible
    : public integral_constant<bool, __has_trivial_destructor(_Tp)> {};

#else  // _LIBCPP_HAS_TYPE_TRAITS
# 2517 "/usr/include/c++/v1/type_traits" 3

template <class _Tp> struct __libcpp_trivial_destructor
    : public integral_constant<bool, is_scalar<_Tp>::value ||
                                     is_reference<_Tp>::value> {};

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_trivially_destructible
    : public __libcpp_trivial_destructor<typename remove_all_extents<_Tp>::type> {};

#endif  // _LIBCPP_HAS_TYPE_TRAITS
# 2526 "/usr/include/c++/v1/type_traits" 3

// is_nothrow_constructible

#ifndef _LIBCPP_HAS_NO_VARIADICS

#if __has_feature(cxx_noexcept)

template <bool, class _Tp, class... _Args> struct __is_nothrow_constructible;

template <class _Tp, class... _Args>
struct __is_nothrow_constructible<true, _Tp, _Args...>
    : public integral_constant<bool, noexcept(_Tp(declval<_Args>()...))>
{
};

template <class _Tp, class... _Args>
struct __is_nothrow_constructible<false, _Tp, _Args...>
    : public false_type
{
};

template <class _Tp, class... _Args>
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_constructible
    : __is_nothrow_constructible<is_constructible<_Tp, _Args...>::value, _Tp, _Args...>
{
};

template <class _Tp, size_t _Ns>
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_constructible<_Tp[_Ns]>
    : __is_nothrow_constructible<is_constructible<_Tp>::value, _Tp>
{
};

#else  // __has_feature(cxx_noexcept)
# 2560 "/usr/include/c++/v1/type_traits" 3

template <class _Tp, class... _Args>
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_constructible
    : false_type
{
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_constructible<_Tp>
#if __has_feature(has_nothrow_constructor) || (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3)
    : integral_constant<bool, __has_nothrow_constructor(_Tp)>
#else
# 2572 "/usr/include/c++/v1/type_traits" 3
    : integral_constant<bool, is_scalar<_Tp>::value>
#endif
# 2574 "/usr/include/c++/v1/type_traits" 3
{
};

template <class _Tp>
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_constructible<_Tp, _Tp&&>
#else
# 2581 "/usr/include/c++/v1/type_traits" 3
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_constructible<_Tp, _Tp>
#endif
# 2583 "/usr/include/c++/v1/type_traits" 3
#if __has_feature(has_nothrow_copy) || (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3)
    : integral_constant<bool, __has_nothrow_copy(_Tp)>
#else
# 2586 "/usr/include/c++/v1/type_traits" 3
    : integral_constant<bool, is_scalar<_Tp>::value>
#endif
# 2588 "/usr/include/c++/v1/type_traits" 3
{
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_constructible<_Tp, const _Tp&>
#if __has_feature(has_nothrow_copy) || (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3)
    : integral_constant<bool, __has_nothrow_copy(_Tp)>
#else
# 2596 "/usr/include/c++/v1/type_traits" 3
    : integral_constant<bool, is_scalar<_Tp>::value>
#endif
# 2598 "/usr/include/c++/v1/type_traits" 3
{
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_constructible<_Tp, _Tp&>
#if __has_feature(has_nothrow_copy) || (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3)
    : integral_constant<bool, __has_nothrow_copy(_Tp)>
#else
# 2606 "/usr/include/c++/v1/type_traits" 3
    : integral_constant<bool, is_scalar<_Tp>::value>
#endif
# 2608 "/usr/include/c++/v1/type_traits" 3
{
};

#endif  // __has_feature(cxx_noexcept)
# 2612 "/usr/include/c++/v1/type_traits" 3

#else  // _LIBCPP_HAS_NO_VARIADICS
# 2614 "/usr/include/c++/v1/type_traits" 3

template <class _Tp, class _A0 = __is_construct::__nat,
                     class _A1 = __is_construct::__nat>
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_constructible
    : false_type
{
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_constructible<_Tp, __is_construct::__nat,
                                                       __is_construct::__nat>
#if __has_feature(has_nothrow_constructor) || (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3)
    : integral_constant<bool, __has_nothrow_constructor(_Tp)>
#else
# 2628 "/usr/include/c++/v1/type_traits" 3
    : integral_constant<bool, is_scalar<_Tp>::value>
#endif
# 2630 "/usr/include/c++/v1/type_traits" 3
{
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_constructible<_Tp, _Tp,
                                                       __is_construct::__nat>
#if __has_feature(has_nothrow_copy) || (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3)
    : integral_constant<bool, __has_nothrow_copy(_Tp)>
#else
# 2639 "/usr/include/c++/v1/type_traits" 3
    : integral_constant<bool, is_scalar<_Tp>::value>
#endif
# 2641 "/usr/include/c++/v1/type_traits" 3
{
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_constructible<_Tp, const _Tp&,
                                                       __is_construct::__nat>
#if __has_feature(has_nothrow_copy) || (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3)
    : integral_constant<bool, __has_nothrow_copy(_Tp)>
#else
# 2650 "/usr/include/c++/v1/type_traits" 3
    : integral_constant<bool, is_scalar<_Tp>::value>
#endif
# 2652 "/usr/include/c++/v1/type_traits" 3
{
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_constructible<_Tp, _Tp&,
                                                       __is_construct::__nat>
#if __has_feature(has_nothrow_copy) || (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3)
    : integral_constant<bool, __has_nothrow_copy(_Tp)>
#else
# 2661 "/usr/include/c++/v1/type_traits" 3
    : integral_constant<bool, is_scalar<_Tp>::value>
#endif
# 2663 "/usr/include/c++/v1/type_traits" 3
{
};

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 2667 "/usr/include/c++/v1/type_traits" 3

// is_nothrow_default_constructible

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_default_constructible
    : public is_nothrow_constructible<_Tp>
    {};

// is_nothrow_copy_constructible

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_copy_constructible
    : public is_nothrow_constructible<_Tp, const typename add_lvalue_reference<_Tp>::type>
    {};

// is_nothrow_move_constructible

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_move_constructible
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    : public is_nothrow_constructible<_Tp, typename add_rvalue_reference<_Tp>::type>
#else
# 2686 "/usr/include/c++/v1/type_traits" 3
    : public is_nothrow_copy_constructible<_Tp>
#endif
# 2688 "/usr/include/c++/v1/type_traits" 3
    {};

// is_nothrow_assignable

#if __has_feature(cxx_noexcept)

template <bool, class _Tp, class _Arg> struct __is_nothrow_assignable;

template <class _Tp, class _Arg>
struct __is_nothrow_assignable<false, _Tp, _Arg>
    : public false_type
{
};

template <class _Tp, class _Arg>
struct __is_nothrow_assignable<true, _Tp, _Arg>
    : public integral_constant<bool, noexcept(_VSTD::declval<_Tp>() = _VSTD::declval<_Arg>()) >
{
};

template <class _Tp, class _Arg>
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_assignable
    : public __is_nothrow_assignable<is_assignable<_Tp, _Arg>::value, _Tp, _Arg>
{
};

#else  // __has_feature(cxx_noexcept)
# 2715 "/usr/include/c++/v1/type_traits" 3

template <class _Tp, class _Arg>
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_assignable
    : public false_type {};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_assignable<_Tp&, _Tp>
#if __has_feature(has_nothrow_assign) || (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3)
    : integral_constant<bool, __has_nothrow_assign(_Tp)> {};
#else
# 2725 "/usr/include/c++/v1/type_traits" 3
    : integral_constant<bool, is_scalar<_Tp>::value> {};
#endif
# 2727 "/usr/include/c++/v1/type_traits" 3

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_assignable<_Tp&, _Tp&>
#if __has_feature(has_nothrow_assign) || (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3)
    : integral_constant<bool, __has_nothrow_assign(_Tp)> {};
#else
# 2733 "/usr/include/c++/v1/type_traits" 3
    : integral_constant<bool, is_scalar<_Tp>::value> {};
#endif
# 2735 "/usr/include/c++/v1/type_traits" 3

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_assignable<_Tp&, const _Tp&>
#if __has_feature(has_nothrow_assign) || (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3)
    : integral_constant<bool, __has_nothrow_assign(_Tp)> {};
#else
# 2741 "/usr/include/c++/v1/type_traits" 3
    : integral_constant<bool, is_scalar<_Tp>::value> {};
#endif
# 2743 "/usr/include/c++/v1/type_traits" 3

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template <class _Tp>
struct is_nothrow_assignable<_Tp&, _Tp&&>
#if __has_feature(has_nothrow_assign) || (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3)
    : integral_constant<bool, __has_nothrow_assign(_Tp)> {};
#else
# 2751 "/usr/include/c++/v1/type_traits" 3
    : integral_constant<bool, is_scalar<_Tp>::value> {};
#endif
# 2753 "/usr/include/c++/v1/type_traits" 3

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 2755 "/usr/include/c++/v1/type_traits" 3

#endif  // __has_feature(cxx_noexcept)
# 2757 "/usr/include/c++/v1/type_traits" 3

// is_nothrow_copy_assignable

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_copy_assignable
    : public is_nothrow_assignable<typename add_lvalue_reference<_Tp>::type,
                               const typename add_lvalue_reference<_Tp>::type>
    {};

// is_nothrow_move_assignable

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_move_assignable
    : public is_nothrow_assignable<typename add_lvalue_reference<_Tp>::type,
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
                                     typename add_rvalue_reference<_Tp>::type>
#else
# 2772 "/usr/include/c++/v1/type_traits" 3
                                     typename add_lvalue_reference<_Tp>::type>
#endif
# 2774 "/usr/include/c++/v1/type_traits" 3
    {};

// is_nothrow_destructible

#if __has_feature(cxx_noexcept)

template <bool, class _Tp> struct __is_nothrow_destructible;

template <class _Tp>
struct __is_nothrow_destructible<false, _Tp>
    : public false_type
{
};

template <class _Tp>
struct __is_nothrow_destructible<true, _Tp>
    : public integral_constant<bool, noexcept(_VSTD::declval<_Tp>().~_Tp()) >
{
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_destructible
    : public __is_nothrow_destructible<is_destructible<_Tp>::value, _Tp>
{
};

template <class _Tp, size_t _Ns>
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_destructible<_Tp[_Ns]>
    : public is_nothrow_destructible<_Tp>
{
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_destructible<_Tp&>
    : public true_type
{
};

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_destructible<_Tp&&>
    : public true_type
{
};

#endif
# 2821 "/usr/include/c++/v1/type_traits" 3

#else
# 2823 "/usr/include/c++/v1/type_traits" 3

template <class _Tp> struct __libcpp_nothrow_destructor
    : public integral_constant<bool, is_scalar<_Tp>::value ||
                                     is_reference<_Tp>::value> {};

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_nothrow_destructible
    : public __libcpp_nothrow_destructor<typename remove_all_extents<_Tp>::type> {};

#endif
# 2832 "/usr/include/c++/v1/type_traits" 3

// is_pod

#if __has_feature(is_pod) || (__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3)

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_pod
    : public integral_constant<bool, __is_pod(_Tp)> {};

#else  // _LIBCPP_HAS_TYPE_TRAITS
# 2841 "/usr/include/c++/v1/type_traits" 3

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_pod
    : public integral_constant<bool, is_trivially_default_constructible<_Tp>::value   &&
                                     is_trivially_copy_constructible<_Tp>::value      &&
                                     is_trivially_copy_assignable<_Tp>::value    &&
                                     is_trivially_destructible<_Tp>::value> {};

#endif  // _LIBCPP_HAS_TYPE_TRAITS
# 2849 "/usr/include/c++/v1/type_traits" 3

// is_literal_type;

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_literal_type
#if __has_feature(is_literal)
    : public integral_constant<bool, __is_literal(_Tp)>
#else
# 2856 "/usr/include/c++/v1/type_traits" 3
    : integral_constant<bool, is_scalar<typename remove_all_extents<_Tp>::type>::value ||
                              is_reference<typename remove_all_extents<_Tp>::type>::value>
#endif
# 2859 "/usr/include/c++/v1/type_traits" 3
    {};
    
// is_standard_layout;

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_standard_layout
#if __has_feature(is_standard_layout)
    : public integral_constant<bool, __is_standard_layout(_Tp)>
#else
# 2867 "/usr/include/c++/v1/type_traits" 3
    : integral_constant<bool, is_scalar<typename remove_all_extents<_Tp>::type>::value>
#endif
# 2869 "/usr/include/c++/v1/type_traits" 3
    {};
    
// is_trivially_copyable;

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_trivially_copyable
#if __has_feature(is_trivially_copyable)
    : public integral_constant<bool, __is_trivially_copyable(_Tp)>
#else
# 2877 "/usr/include/c++/v1/type_traits" 3
    : integral_constant<bool, is_scalar<typename remove_all_extents<_Tp>::type>::value>
#endif
# 2879 "/usr/include/c++/v1/type_traits" 3
    {};
    
// is_trivial;

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_trivial
#if __has_feature(is_trivial)
    : public integral_constant<bool, __is_trivial(_Tp)>
#else
# 2887 "/usr/include/c++/v1/type_traits" 3
    : integral_constant<bool, is_trivially_copyable<_Tp>::value &&
                                 is_trivially_default_constructible<_Tp>::value>
#endif
# 2890 "/usr/include/c++/v1/type_traits" 3
    {};

#ifndef _LIBCPP_HAS_NO_VARIADICS

// Check for complete types

template <class ..._Tp> struct __check_complete;

template <>
struct __check_complete<>
{
};

template <class _Hp, class _T0, class ..._Tp>
struct __check_complete<_Hp, _T0, _Tp...>
    : private __check_complete<_Hp>,
      private __check_complete<_T0, _Tp...>
{
};

template <class _Hp>
struct __check_complete<_Hp, _Hp>
    : private __check_complete<_Hp>
{
};

template <class _Tp>
struct __check_complete<_Tp>
{
    static_assert(sizeof(_Tp) > 0, "Type must be complete.");
};

template <class _Tp>
struct __check_complete<_Tp&>
    : private __check_complete<_Tp>
{
};

template <class _Tp>
struct __check_complete<_Tp&&>
    : private __check_complete<_Tp>
{
};

template <class _Rp, class ..._Param>
struct __check_complete<_Rp (*)(_Param...)>
    : private __check_complete<_Rp>
{
};

template <class ..._Param>
struct __check_complete<void (*)(_Param...)>
{
};

template <class _Rp, class ..._Param>
struct __check_complete<_Rp (_Param...)>
    : private __check_complete<_Rp>
{
};

template <class ..._Param>
struct __check_complete<void (_Param...)>
{
};

template <class _Rp, class _Class, class ..._Param>
struct __check_complete<_Rp (_Class::*)(_Param...)>
    : private __check_complete<_Class>
{
};

template <class _Rp, class _Class, class ..._Param>
struct __check_complete<_Rp (_Class::*)(_Param...) const>
    : private __check_complete<_Class>
{
};

template <class _Rp, class _Class, class ..._Param>
struct __check_complete<_Rp (_Class::*)(_Param...) volatile>
    : private __check_complete<_Class>
{
};

template <class _Rp, class _Class, class ..._Param>
struct __check_complete<_Rp (_Class::*)(_Param...) const volatile>
    : private __check_complete<_Class>
{
};

#if __has_feature(cxx_reference_qualified_functions)

template <class _Rp, class _Class, class ..._Param>
struct __check_complete<_Rp (_Class::*)(_Param...) &>
    : private __check_complete<_Class>
{
};

template <class _Rp, class _Class, class ..._Param>
struct __check_complete<_Rp (_Class::*)(_Param...) const&>
    : private __check_complete<_Class>
{
};

template <class _Rp, class _Class, class ..._Param>
struct __check_complete<_Rp (_Class::*)(_Param...) volatile&>
    : private __check_complete<_Class>
{
};

template <class _Rp, class _Class, class ..._Param>
struct __check_complete<_Rp (_Class::*)(_Param...) const volatile&>
    : private __check_complete<_Class>
{
};

template <class _Rp, class _Class, class ..._Param>
struct __check_complete<_Rp (_Class::*)(_Param...) &&>
    : private __check_complete<_Class>
{
};

template <class _Rp, class _Class, class ..._Param>
struct __check_complete<_Rp (_Class::*)(_Param...) const&&>
    : private __check_complete<_Class>
{
};

template <class _Rp, class _Class, class ..._Param>
struct __check_complete<_Rp (_Class::*)(_Param...) volatile&&>
    : private __check_complete<_Class>
{
};

template <class _Rp, class _Class, class ..._Param>
struct __check_complete<_Rp (_Class::*)(_Param...) const volatile&&>
    : private __check_complete<_Class>
{
};

#endif
# 3031 "/usr/include/c++/v1/type_traits" 3

template <class _Rp, class _Class>
struct __check_complete<_Rp _Class::*>
    : private __check_complete<_Class>
{
};

// __invoke forward declarations

// fall back - none of the bullets

template <class ..._Args>
auto
__invoke(__any, _Args&& ...__args)
    -> __nat;

// bullets 1 and 2

template <class _Fp, class _A0, class ..._Args,
            class = typename enable_if
            <
                is_member_function_pointer<typename remove_reference<_Fp>::type>::value &&
                is_base_of<typename __member_pointer_traits<typename remove_reference<_Fp>::type>::_ClassType,
                           typename remove_reference<_A0>::type>::value
            >::type
         >
_LIBCPP_INLINE_VISIBILITY
auto
__invoke(_Fp&& __f, _A0&& __a0, _Args&& ...__args)
    -> decltype((_VSTD::forward<_A0>(__a0).*__f)(_VSTD::forward<_Args>(__args)...));

template <class _Fp, class _A0, class ..._Args,
            class = typename enable_if
            <
                is_member_function_pointer<typename remove_reference<_Fp>::type>::value &&
                !is_base_of<typename __member_pointer_traits<typename remove_reference<_Fp>::type>::_ClassType,
                           typename remove_reference<_A0>::type>::value
            >::type
         >
_LIBCPP_INLINE_VISIBILITY
auto
__invoke(_Fp&& __f, _A0&& __a0, _Args&& ...__args)
    -> decltype(((*_VSTD::forward<_A0>(__a0)).*__f)(_VSTD::forward<_Args>(__args)...));

// bullets 3 and 4

template <class _Fp, class _A0,
            class = typename enable_if
            <
                is_member_object_pointer<typename remove_reference<_Fp>::type>::value &&
                is_base_of<typename __member_pointer_traits<typename remove_reference<_Fp>::type>::_ClassType,
                           typename remove_reference<_A0>::type>::value
            >::type
         >
_LIBCPP_INLINE_VISIBILITY
auto
__invoke(_Fp&& __f, _A0&& __a0)
    -> decltype(_VSTD::forward<_A0>(__a0).*__f);

template <class _Fp, class _A0,
            class = typename enable_if
            <
                is_member_object_pointer<typename remove_reference<_Fp>::type>::value &&
                !is_base_of<typename __member_pointer_traits<typename remove_reference<_Fp>::type>::_ClassType,
                           typename remove_reference<_A0>::type>::value
            >::type
         >
_LIBCPP_INLINE_VISIBILITY
auto
__invoke(_Fp&& __f, _A0&& __a0)
    -> decltype((*_VSTD::forward<_A0>(__a0)).*__f);

// bullet 5

template <class _Fp, class ..._Args>
_LIBCPP_INLINE_VISIBILITY
auto
__invoke(_Fp&& __f, _Args&& ...__args)
    -> decltype(_VSTD::forward<_Fp>(__f)(_VSTD::forward<_Args>(__args)...));

// __invokable

template <class _Fp, class ..._Args>
struct __invokable_imp
    : private __check_complete<_Fp>
{
    typedef decltype(
            __invoke(_VSTD::declval<_Fp>(), _VSTD::declval<_Args>()...)
                    ) type;
    static const bool value = !is_same<type, __nat>::value;
};

template <class _Fp, class ..._Args>
struct __invokable
    : public integral_constant<bool,
          __invokable_imp<_Fp, _Args...>::value>
{
};

// __invoke_of

template <bool _Invokable, class _Fp, class ..._Args>
struct __invoke_of_imp  // false
{
};

template <class _Fp, class ..._Args>
struct __invoke_of_imp<true, _Fp, _Args...>
{
    typedef typename __invokable_imp<_Fp, _Args...>::type type;
};

template <class _Fp, class ..._Args>
struct __invoke_of
    : public __invoke_of_imp<__invokable<_Fp, _Args...>::value, _Fp, _Args...>
{
};

template <class _Fp, class ..._Args>
class _LIBCPP_TYPE_VIS_ONLY result_of<_Fp(_Args...)>
    : public __invoke_of<_Fp, _Args...>
{
};

#if _LIBCPP_STD_VER > 11
template <class _Tp> using result_of_t = typename result_of<_Tp>::type;
#endif
# 3158 "/usr/include/c++/v1/type_traits" 3

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 3160 "/usr/include/c++/v1/type_traits" 3

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
#ifndef _LIBCPP_HAS_NO_ADVANCED_SFINAE
typename enable_if
<
    is_move_constructible<_Tp>::value &&
    is_move_assignable<_Tp>::value
>::type
#else
# 3170 "/usr/include/c++/v1/type_traits" 3
void
#endif
# 3172 "/usr/include/c++/v1/type_traits" 3
swap(_Tp& __x, _Tp& __y) _NOEXCEPT_(is_nothrow_move_constructible<_Tp>::value &&
                                    is_nothrow_move_assignable<_Tp>::value)
{
    _Tp __t(_VSTD::move(__x));
    __x = _VSTD::move(__y);
    __y = _VSTD::move(__t);
}

template <class _ForwardIterator1, class _ForwardIterator2>
inline _LIBCPP_INLINE_VISIBILITY
void
iter_swap(_ForwardIterator1 __a, _ForwardIterator2 __b)
    //                                  _NOEXCEPT_(_NOEXCEPT_(swap(*__a, *__b)))
               _NOEXCEPT_(_NOEXCEPT_(swap(*_VSTD::declval<_ForwardIterator1>(),
                                          *_VSTD::declval<_ForwardIterator2>())))
{
    swap(*__a, *__b);
}

// __swappable

namespace __detail
{

using _VSTD::swap;
__nat swap(__any, __any);

template <class _Tp>
struct __swappable
{
    typedef decltype(swap(_VSTD::declval<_Tp&>(), _VSTD::declval<_Tp&>())) type;
    static const bool value = !is_same<type, __nat>::value;
};

}  // __detail

template <class _Tp>
struct __is_swappable
    : public integral_constant<bool, __detail::__swappable<_Tp>::value>
{
};

#if __has_feature(cxx_noexcept)

template <bool, class _Tp>
struct __is_nothrow_swappable_imp
    : public integral_constant<bool, noexcept(swap(_VSTD::declval<_Tp&>(),
                                                   _VSTD::declval<_Tp&>()))>
{
};

template <class _Tp>
struct __is_nothrow_swappable_imp<false, _Tp>
    : public false_type
{
};

template <class _Tp>
struct __is_nothrow_swappable
    : public __is_nothrow_swappable_imp<__is_swappable<_Tp>::value, _Tp>
{
};

#else  // __has_feature(cxx_noexcept)
# 3236 "/usr/include/c++/v1/type_traits" 3

template <class _Tp>
struct __is_nothrow_swappable
    : public false_type
{
};

#endif  // __has_feature(cxx_noexcept)
# 3244 "/usr/include/c++/v1/type_traits" 3

#ifdef _LIBCXX_UNDERLYING_TYPE

template <class _Tp>
struct underlying_type
{
    typedef _LIBCXX_UNDERLYING_TYPE(_Tp) type;
};

#if _LIBCPP_STD_VER > 11
template <class _Tp> using underlying_type_t = typename underlying_type<_Tp>::type;
#endif
# 3256 "/usr/include/c++/v1/type_traits" 3

#else  // _LIBCXX_UNDERLYING_TYPE
# 3258 "/usr/include/c++/v1/type_traits" 3

template <class _Tp, bool _Support = false>
struct underlying_type
{
    static_assert(_Support, "The underyling_type trait requires compiler "
                            "support. Either no such support exists or "
                            "libc++ does not know how to use it.");
};

#endif // _LIBCXX_UNDERLYING_TYPE
# 3268 "/usr/include/c++/v1/type_traits" 3

#ifndef _LIBCPP_HAS_NO_ADVANCED_SFINAE

template <class _Tp>
struct __has_operator_addressof_imp
{
    template <class>
        static auto __test(__any) -> false_type;
    template <class _Up>
        static auto __test(_Up* __u)
            -> typename __select_2nd<decltype(__u->operator&()), true_type>::type;

    static const bool value = decltype(__test<_Tp>(nullptr))::value;
};

template <class _Tp>
struct __has_operator_addressof
    : public integral_constant<bool, __has_operator_addressof_imp<_Tp>::value>
{};

#endif  // _LIBCPP_HAS_NO_ADVANCED_SFINAE
# 3289 "/usr/include/c++/v1/type_traits" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_TYPE_TRAITS
# 3293 "/usr/include/c++/v1/type_traits" 3
# 625 "/usr/include/c++/v1/algorithm" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <cstring>
#endif /* expanded by -frewrite-includes */
# 626 "/usr/include/c++/v1/algorithm" 3
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/utility" 1 3
// -*- C++ -*-
//===-------------------------- utility -----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_UTILITY
#define _LIBCPP_UTILITY

/*
    utility synopsis

namespace std
{

template <class T>
    void
    swap(T& a, T& b);

namespace rel_ops
{
    template<class T> bool operator!=(const T&, const T&);
    template<class T> bool operator> (const T&, const T&);
    template<class T> bool operator<=(const T&, const T&);
    template<class T> bool operator>=(const T&, const T&);
}

template<class T>
void
swap(T& a, T& b) noexcept(is_nothrow_move_constructible<T>::value &&
                          is_nothrow_move_assignable<T>::value);

template <class T, size_t N>
void
swap(T (&a)[N], T (&b)[N]) noexcept(noexcept(swap(*a, *b)));

template <class T> T&& forward(typename remove_reference<T>::type& t) noexcept;  // constexpr in C++14
template <class T> T&& forward(typename remove_reference<T>::type&& t) noexcept; // constexpr in C++14

template <class T> typename remove_reference<T>::type&& move(T&&) noexcept;      // constexpr in C++14

template <class T>
    typename conditional
    <
        !is_nothrow_move_constructible<T>::value && is_copy_constructible<T>::value,
        const T&,
        T&&
    >::type
    move_if_noexcept(T& x) noexcept; // constexpr in C++14

template <class T> typename add_rvalue_reference<T>::type declval() noexcept;

template <class T1, class T2>
struct pair
{
    typedef T1 first_type;
    typedef T2 second_type;

    T1 first;
    T2 second;

    pair(const pair&) = default;
    pair(pair&&) = default;
    constexpr pair();
    pair(const T1& x, const T2& y);                          // constexpr in C++14
    template <class U, class V> pair(U&& x, V&& y);          // constexpr in C++14
    template <class U, class V> pair(const pair<U, V>& p);   // constexpr in C++14
    template <class U, class V> pair(pair<U, V>&& p);        // constexpr in C++14
    template <class... Args1, class... Args2>
        pair(piecewise_construct_t, tuple<Args1...> first_args,
             tuple<Args2...> second_args);

    template <class U, class V> pair& operator=(const pair<U, V>& p);
    pair& operator=(pair&& p) noexcept(is_nothrow_move_assignable<T1>::value &&
                                       is_nothrow_move_assignable<T2>::value);
    template <class U, class V> pair& operator=(pair<U, V>&& p);

    void swap(pair& p) noexcept(noexcept(swap(first, p.first)) &&
                                noexcept(swap(second, p.second)));
};

template <class T1, class T2> bool operator==(const pair<T1,T2>&, const pair<T1,T2>&); // constexpr in C++14
template <class T1, class T2> bool operator!=(const pair<T1,T2>&, const pair<T1,T2>&); // constexpr in C++14
template <class T1, class T2> bool operator< (const pair<T1,T2>&, const pair<T1,T2>&); // constexpr in C++14
template <class T1, class T2> bool operator> (const pair<T1,T2>&, const pair<T1,T2>&); // constexpr in C++14
template <class T1, class T2> bool operator>=(const pair<T1,T2>&, const pair<T1,T2>&); // constexpr in C++14
template <class T1, class T2> bool operator<=(const pair<T1,T2>&, const pair<T1,T2>&); // constexpr in C++14

template <class T1, class T2> pair<V1, V2> make_pair(T1&&, T2&&);   // constexpr in C++14
template <class T1, class T2>
void
swap(pair<T1, T2>& x, pair<T1, T2>& y) noexcept(noexcept(x.swap(y)));

struct piecewise_construct_t { };
constexpr piecewise_construct_t piecewise_construct = piecewise_construct_t();

template <class T> class tuple_size;
template <size_t I, class T> class tuple_element;

template <class T1, class T2> struct tuple_size<std::pair<T1, T2> >;
template <class T1, class T2> struct tuple_element<0, std::pair<T1, T2> >;
template <class T1, class T2> struct tuple_element<1, std::pair<T1, T2> >;

template<size_t I, class T1, class T2>
    typename tuple_element<I, std::pair<T1, T2> >::type&
    get(std::pair<T1, T2>&) noexcept; // constexpr in C++14

template<size_t I, class T1, class T2>
    const typename const tuple_element<I, std::pair<T1, T2> >::type&
    get(const std::pair<T1, T2>&) noexcept; // constexpr in C++14

template<size_t I, class T1, class T2>
    typename tuple_element<I, std::pair<T1, T2> >::type&&
    get(std::pair<T1, T2>&&) noexcept; // constexpr in C++14

template<class T1, class T2>
    constexpr T1& get(std::pair<T1, T2>&) noexcept; // C++14

template<size_t I, class T1, class T2>
    constexpr T1 const& get(std::pair<T1, T2> const &) noexcept; // C++14

template<size_t I, class T1, class T2>
    constexpr T1&& get(std::pair<T1, T2>&&) noexcept; // C++14

// C++14

template<class T, T... I>
struct integer_sequence
{
    typedef T value_type;

    static constexpr size_t size() noexcept;
};

template<size_t... I>
  using index_sequence = integer_sequence<size_t, I...>;

template<class T, T N>
  using make_integer_sequence = integer_sequence<T, 0, 1, ..., N-1>;
template<size_t N>
  using make_index_sequence = make_integer_sequence<size_t, N>;

template<class... T>
  using index_sequence_for = make_index_sequence<sizeof...(T)>;

template<class T, class U=T> 
    T exchange(T& obj, U&& new_value);
}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 157 "/usr/include/c++/v1/utility" 3
#if 0 /* expanded by -frewrite-includes */
#include <__tuple>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/__tuple" 1 3
// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP___TUPLE
#define _LIBCPP___TUPLE

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 15 "/usr/include/c++/v1/__tuple" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 16 "/usr/include/c++/v1/__tuple" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 17 "/usr/include/c++/v1/__tuple" 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 20 "/usr/include/c++/v1/__tuple" 3
#endif
# 21 "/usr/include/c++/v1/__tuple" 3

#ifdef _LIBCPP_HAS_NO_VARIADICS

#if 0 /* expanded by -frewrite-includes */
#include <__tuple_03>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/__tuple_03" 1 3
// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP___TUPLE_03
#define _LIBCPP___TUPLE_03

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 15 "/usr/include/c++/v1/__tuple_03" 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 18 "/usr/include/c++/v1/__tuple_03" 3
#endif
# 19 "/usr/include/c++/v1/__tuple_03" 3

_LIBCPP_BEGIN_NAMESPACE_STD

template <class _Tp> class _LIBCPP_TYPE_VIS_ONLY tuple_size;
template <size_t _Ip, class _Tp> class _LIBCPP_TYPE_VIS_ONLY tuple_element;

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP___TUPLE_03
# 28 "/usr/include/c++/v1/__tuple_03" 3
# 25 "/usr/include/c++/v1/__tuple" 2 3

#else  // _LIBCPP_HAS_NO_VARIADICS
# 27 "/usr/include/c++/v1/__tuple" 3

_LIBCPP_BEGIN_NAMESPACE_STD

template <class _Tp> class _LIBCPP_TYPE_VIS_ONLY tuple_size;

template <class _Tp>
class _LIBCPP_TYPE_VIS_ONLY tuple_size<const _Tp>
    : public tuple_size<_Tp> {};

template <class _Tp>
class _LIBCPP_TYPE_VIS_ONLY tuple_size<volatile _Tp>
    : public tuple_size<_Tp> {};

template <class _Tp>
class _LIBCPP_TYPE_VIS_ONLY tuple_size<const volatile _Tp>
    : public tuple_size<_Tp> {};

template <size_t _Ip, class _Tp> class _LIBCPP_TYPE_VIS_ONLY tuple_element;

template <size_t _Ip, class _Tp>
class _LIBCPP_TYPE_VIS_ONLY tuple_element<_Ip, const _Tp>
{
public:
    typedef typename add_const<typename tuple_element<_Ip, _Tp>::type>::type type;
};

template <size_t _Ip, class _Tp>
class _LIBCPP_TYPE_VIS_ONLY tuple_element<_Ip, volatile _Tp>
{
public:
    typedef typename add_volatile<typename tuple_element<_Ip, _Tp>::type>::type type;
};

template <size_t _Ip, class _Tp>
class _LIBCPP_TYPE_VIS_ONLY tuple_element<_Ip, const volatile _Tp>
{
public:
    typedef typename add_cv<typename tuple_element<_Ip, _Tp>::type>::type type;
};

template <class ..._Tp> class _LIBCPP_TYPE_VIS_ONLY tuple;
template <class _T1, class _T2> struct _LIBCPP_TYPE_VIS_ONLY pair;
template <class _Tp, size_t _Size> struct _LIBCPP_TYPE_VIS_ONLY array;

template <class _Tp> struct __tuple_like : false_type {};

template <class _Tp> struct __tuple_like<const _Tp> : public __tuple_like<_Tp> {};
template <class _Tp> struct __tuple_like<volatile _Tp> : public __tuple_like<_Tp> {};
template <class _Tp> struct __tuple_like<const volatile _Tp> : public __tuple_like<_Tp> {};

template <class... _Tp> struct __tuple_like<tuple<_Tp...> > : true_type {};
template <class _T1, class _T2> struct __tuple_like<pair<_T1, _T2> > : true_type {};
template <class _Tp, size_t _Size> struct __tuple_like<array<_Tp, _Size> > : true_type {};

template <size_t _Ip, class ..._Tp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
typename tuple_element<_Ip, tuple<_Tp...> >::type&
get(tuple<_Tp...>&) _NOEXCEPT;

template <size_t _Ip, class ..._Tp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
const typename tuple_element<_Ip, tuple<_Tp...> >::type&
get(const tuple<_Tp...>&) _NOEXCEPT;

template <size_t _Ip, class ..._Tp>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
typename tuple_element<_Ip, tuple<_Tp...> >::type&&
get(tuple<_Tp...>&&) _NOEXCEPT;

template <size_t _Ip, class _T1, class _T2>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
typename tuple_element<_Ip, pair<_T1, _T2> >::type&
get(pair<_T1, _T2>&) _NOEXCEPT;

template <size_t _Ip, class _T1, class _T2>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
const typename tuple_element<_Ip, pair<_T1, _T2> >::type&
get(const pair<_T1, _T2>&) _NOEXCEPT;

template <size_t _Ip, class _T1, class _T2>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
typename tuple_element<_Ip, pair<_T1, _T2> >::type&&
get(pair<_T1, _T2>&&) _NOEXCEPT;

template <size_t _Ip, class _Tp, size_t _Size>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
_Tp&
get(array<_Tp, _Size>&) _NOEXCEPT;

template <size_t _Ip, class _Tp, size_t _Size>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
const _Tp&
get(const array<_Tp, _Size>&) _NOEXCEPT;

template <size_t _Ip, class _Tp, size_t _Size>
_LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
_Tp&&
get(array<_Tp, _Size>&&) _NOEXCEPT;

// __make_tuple_indices

template <size_t...> struct __tuple_indices {};

template <size_t _Sp, class _IntTuple, size_t _Ep>
struct __make_indices_imp;

template <size_t _Sp, size_t ..._Indices, size_t _Ep>
struct __make_indices_imp<_Sp, __tuple_indices<_Indices...>, _Ep>
{
    typedef typename __make_indices_imp<_Sp+1, __tuple_indices<_Indices..., _Sp>, _Ep>::type type;
};

template <size_t _Ep, size_t ..._Indices>
struct __make_indices_imp<_Ep, __tuple_indices<_Indices...>, _Ep>
{
    typedef __tuple_indices<_Indices...> type;
};

template <size_t _Ep, size_t _Sp = 0>
struct __make_tuple_indices
{
    static_assert(_Sp <= _Ep, "__make_tuple_indices input error");
    typedef typename __make_indices_imp<_Sp, __tuple_indices<>, _Ep>::type type;
};

// __tuple_types

template <class ..._Tp> struct __tuple_types {};

template <size_t _Ip>
class _LIBCPP_TYPE_VIS_ONLY tuple_element<_Ip, __tuple_types<> >
{
public:
    static_assert(_Ip == 0, "tuple_element index out of range");
    static_assert(_Ip != 0, "tuple_element index out of range");
};

template <class _Hp, class ..._Tp>
class _LIBCPP_TYPE_VIS_ONLY tuple_element<0, __tuple_types<_Hp, _Tp...> >
{
public:
    typedef _Hp type;
};

template <size_t _Ip, class _Hp, class ..._Tp>
class _LIBCPP_TYPE_VIS_ONLY tuple_element<_Ip, __tuple_types<_Hp, _Tp...> >
{
public:
    typedef typename tuple_element<_Ip-1, __tuple_types<_Tp...> >::type type;
};

template <class ..._Tp>
class _LIBCPP_TYPE_VIS_ONLY tuple_size<__tuple_types<_Tp...> >
    : public integral_constant<size_t, sizeof...(_Tp)>
{
};

template <class... _Tp> struct __tuple_like<__tuple_types<_Tp...> > : true_type {};

// __make_tuple_types

// __make_tuple_types<_Tuple<_Types...>, _Ep, _Sp>::type is a
// __tuple_types<_Types...> using only those _Types in the range [_Sp, _Ep).
// _Sp defaults to 0 and _Ep defaults to tuple_size<_Tuple>.  If _Tuple is a
// lvalue_reference type, then __tuple_types<_Types&...> is the result.

template <class _TupleTypes, class _Tp, size_t _Sp, size_t _Ep>
struct __make_tuple_types_imp;

template <class ..._Types, class _Tp, size_t _Sp, size_t _Ep>
struct __make_tuple_types_imp<__tuple_types<_Types...>, _Tp, _Sp, _Ep>
{
    typedef typename remove_reference<_Tp>::type _Tpr;
    typedef typename __make_tuple_types_imp<__tuple_types<_Types...,
                                            typename conditional<is_lvalue_reference<_Tp>::value,
                                                typename tuple_element<_Sp, _Tpr>::type&,
                                                typename tuple_element<_Sp, _Tpr>::type>::type>,
                                            _Tp, _Sp+1, _Ep>::type type;
};

template <class ..._Types, class _Tp, size_t _Ep>
struct __make_tuple_types_imp<__tuple_types<_Types...>, _Tp, _Ep, _Ep>
{
    typedef __tuple_types<_Types...> type;
};

template <class _Tp, size_t _Ep = tuple_size<typename remove_reference<_Tp>::type>::value, size_t _Sp = 0>
struct __make_tuple_types
{
    static_assert(_Sp <= _Ep, "__make_tuple_types input error");
    typedef typename __make_tuple_types_imp<__tuple_types<>, _Tp, _Sp, _Ep>::type type;
};

// __tuple_convertible

template <bool, class _Tp, class _Up>
struct __tuple_convertible_imp : public false_type {};

template <class _Tp0, class ..._Tp, class _Up0, class ..._Up>
struct __tuple_convertible_imp<true, __tuple_types<_Tp0, _Tp...>, __tuple_types<_Up0, _Up...> >
    : public integral_constant<bool,
                               is_convertible<_Tp0, _Up0>::value &&
                               __tuple_convertible_imp<true, __tuple_types<_Tp...>, __tuple_types<_Up...> >::value> {};

template <>
struct __tuple_convertible_imp<true, __tuple_types<>, __tuple_types<> >
    : public true_type {};

template <class _Tp, class _Up, bool = __tuple_like<typename remove_reference<_Tp>::type>::value,
                                bool = __tuple_like<_Up>::value>
struct __tuple_convertible
    : public false_type {};

template <class _Tp, class _Up>
struct __tuple_convertible<_Tp, _Up, true, true>
    : public __tuple_convertible_imp<tuple_size<typename remove_reference<_Tp>::type>::value ==
                                     tuple_size<_Up>::value,
             typename __make_tuple_types<_Tp>::type, typename __make_tuple_types<_Up>::type>
{};

// __tuple_constructible

template <bool, class _Tp, class _Up>
struct __tuple_constructible_imp : public false_type {};

template <class _Tp0, class ..._Tp, class _Up0, class ..._Up>
struct __tuple_constructible_imp<true, __tuple_types<_Tp0, _Tp...>, __tuple_types<_Up0, _Up...> >
    : public integral_constant<bool,
                               is_constructible<_Up0, _Tp0>::value &&
                               __tuple_constructible_imp<true, __tuple_types<_Tp...>, __tuple_types<_Up...> >::value> {};

template <>
struct __tuple_constructible_imp<true, __tuple_types<>, __tuple_types<> >
    : public true_type {};

template <class _Tp, class _Up, bool = __tuple_like<typename remove_reference<_Tp>::type>::value,
                                bool = __tuple_like<_Up>::value>
struct __tuple_constructible
    : public false_type {};

template <class _Tp, class _Up>
struct __tuple_constructible<_Tp, _Up, true, true>
    : public __tuple_constructible_imp<tuple_size<typename remove_reference<_Tp>::type>::value ==
                                     tuple_size<_Up>::value,
             typename __make_tuple_types<_Tp>::type, typename __make_tuple_types<_Up>::type>
{};

// __tuple_assignable

template <bool, class _Tp, class _Up>
struct __tuple_assignable_imp : public false_type {};

template <class _Tp0, class ..._Tp, class _Up0, class ..._Up>
struct __tuple_assignable_imp<true, __tuple_types<_Tp0, _Tp...>, __tuple_types<_Up0, _Up...> >
    : public integral_constant<bool,
                               is_assignable<_Up0&, _Tp0>::value &&
                               __tuple_assignable_imp<true, __tuple_types<_Tp...>, __tuple_types<_Up...> >::value> {};

template <>
struct __tuple_assignable_imp<true, __tuple_types<>, __tuple_types<> >
    : public true_type {};

template <class _Tp, class _Up, bool = __tuple_like<typename remove_reference<_Tp>::type>::value,
                                bool = __tuple_like<_Up>::value>
struct __tuple_assignable
    : public false_type {};

template <class _Tp, class _Up>
struct __tuple_assignable<_Tp, _Up, true, true>
    : public __tuple_assignable_imp<tuple_size<typename remove_reference<_Tp>::type>::value ==
                                    tuple_size<_Up>::value,
             typename __make_tuple_types<_Tp>::type, typename __make_tuple_types<_Up>::type>
{};

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 304 "/usr/include/c++/v1/__tuple" 3

#endif  // _LIBCPP___TUPLE
# 306 "/usr/include/c++/v1/__tuple" 3
# 158 "/usr/include/c++/v1/utility" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 159 "/usr/include/c++/v1/utility" 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 162 "/usr/include/c++/v1/utility" 3
#endif
# 163 "/usr/include/c++/v1/utility" 3

_LIBCPP_BEGIN_NAMESPACE_STD

namespace rel_ops
{

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const _Tp& __x, const _Tp& __y)
{
    return !(__x == __y);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator> (const _Tp& __x, const _Tp& __y)
{
    return __y < __x;
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const _Tp& __x, const _Tp& __y)
{
    return !(__y < __x);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const _Tp& __x, const _Tp& __y)
{
    return !(__x < __y);
}

}  // rel_ops

// swap_ranges

template <class _ForwardIterator1, class _ForwardIterator2>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator2
swap_ranges(_ForwardIterator1 __first1, _ForwardIterator1 __last1, _ForwardIterator2 __first2)
{
    for(; __first1 != __last1; ++__first1, ++__first2)
        swap(*__first1, *__first2);
    return __first2;
}

template<class _Tp, size_t _Np>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(_Tp (&__a)[_Np], _Tp (&__b)[_Np]) _NOEXCEPT_(__is_nothrow_swappable<_Tp>::value)
{
    _VSTD::swap_ranges(__a, __a + _Np, __b);
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
typename conditional
<
    !is_nothrow_move_constructible<_Tp>::value && is_copy_constructible<_Tp>::value,
    const _Tp&,
    _Tp&&
>::type
#else  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 233 "/usr/include/c++/v1/utility" 3
const _Tp&
#endif
# 235 "/usr/include/c++/v1/utility" 3
move_if_noexcept(_Tp& __x) _NOEXCEPT
{
    return _VSTD::move(__x);
}

struct _LIBCPP_TYPE_VIS_ONLY piecewise_construct_t { };
#if defined(_LIBCPP_HAS_NO_CONSTEXPR) || defined(_LIBCPP_BUILDING_UTILITY)
extern const piecewise_construct_t piecewise_construct;// = piecewise_construct_t();
#else
# 244 "/usr/include/c++/v1/utility" 3
constexpr piecewise_construct_t piecewise_construct = piecewise_construct_t();
#endif
# 246 "/usr/include/c++/v1/utility" 3

template <class _T1, class _T2>
struct _LIBCPP_TYPE_VIS_ONLY pair
{
    typedef _T1 first_type;
    typedef _T2 second_type;

    _T1 first;
    _T2 second;

    // pair(const pair&) = default;
    // pair(pair&&) = default;

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR pair() : first(), second() {}

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    pair(const _T1& __x, const _T2& __y)
        : first(__x), second(__y) {}

    template<class _U1, class _U2>
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        pair(const pair<_U1, _U2>& __p
#ifndef _LIBCPP_HAS_NO_ADVANCED_SFINAE
                 ,typename enable_if<is_convertible<const _U1&, _T1>::value &&
                                    is_convertible<const _U2&, _T2>::value>::type* = 0
#endif
# 272 "/usr/include/c++/v1/utility" 3
                                      )
            : first(__p.first), second(__p.second) {}

#if !defined(_LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS) && _LIBCPP_TRIVIAL_PAIR_COPY_CTOR
    _LIBCPP_INLINE_VISIBILITY
    pair(const pair& __p) = default;
#elif !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES) || !_LIBCPP_TRIVIAL_PAIR_COPY_CTOR
# 279 "/usr/include/c++/v1/utility" 3
    _LIBCPP_INLINE_VISIBILITY
    pair(const pair& __p)
        _NOEXCEPT_(is_nothrow_copy_constructible<first_type>::value &&
                   is_nothrow_copy_constructible<second_type>::value)
        : first(__p.first),
          second(__p.second)
    {
    }
#endif
# 288 "/usr/include/c++/v1/utility" 3

    _LIBCPP_INLINE_VISIBILITY
    pair& operator=(const pair& __p)
        _NOEXCEPT_(is_nothrow_copy_assignable<first_type>::value &&
                   is_nothrow_copy_assignable<second_type>::value)
    {
        first = __p.first;
        second = __p.second;
        return *this;
    }

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

    template <class _U1, class _U2,
              class = typename enable_if<is_convertible<_U1, first_type>::value &&
                                         is_convertible<_U2, second_type>::value>::type>
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        pair(_U1&& __u1, _U2&& __u2)
            : first(_VSTD::forward<_U1>(__u1)),
              second(_VSTD::forward<_U2>(__u2))
            {}

    template<class _U1, class _U2>
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        pair(pair<_U1, _U2>&& __p,
                 typename enable_if<is_convertible<_U1, _T1>::value &&
                                    is_convertible<_U2, _T2>::value>::type* = 0)
            : first(_VSTD::forward<_U1>(__p.first)),
              second(_VSTD::forward<_U2>(__p.second)) {}

#ifndef _LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS
    _LIBCPP_INLINE_VISIBILITY
    pair(pair&& __p) = default;
#else
# 322 "/usr/include/c++/v1/utility" 3
    _LIBCPP_INLINE_VISIBILITY
    pair(pair&& __p) _NOEXCEPT_(is_nothrow_move_constructible<first_type>::value &&
                                is_nothrow_move_constructible<second_type>::value)
        : first(_VSTD::forward<first_type>(__p.first)),
          second(_VSTD::forward<second_type>(__p.second))
    {
    }
#endif
# 330 "/usr/include/c++/v1/utility" 3

    _LIBCPP_INLINE_VISIBILITY
    pair&
    operator=(pair&& __p) _NOEXCEPT_(is_nothrow_move_assignable<first_type>::value &&
                                     is_nothrow_move_assignable<second_type>::value)
    {
        first = _VSTD::forward<first_type>(__p.first);
        second = _VSTD::forward<second_type>(__p.second);
        return *this;
    }

#ifndef _LIBCPP_HAS_NO_VARIADICS

    template<class _Tuple,
             class = typename enable_if<__tuple_convertible<_Tuple, pair>::value>::type>
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        pair(_Tuple&& __p)
            : first(_VSTD::forward<typename tuple_element<0,
                                  typename __make_tuple_types<_Tuple>::type>::type>(get<0>(__p))),
              second(_VSTD::forward<typename tuple_element<1,
                                   typename __make_tuple_types<_Tuple>::type>::type>(get<1>(__p)))
            {}



    template <class... _Args1, class... _Args2>
        _LIBCPP_INLINE_VISIBILITY
        pair(piecewise_construct_t __pc, tuple<_Args1...> __first_args,
                                    tuple<_Args2...> __second_args)
            : pair(__pc, __first_args, __second_args,
                   typename __make_tuple_indices<sizeof...(_Args1)>::type(),
                   typename __make_tuple_indices<sizeof...(_Args2) >::type())
            {}

    template <class _Tuple,
              class = typename enable_if<__tuple_assignable<_Tuple, pair>::value>::type>
        _LIBCPP_INLINE_VISIBILITY
        pair&
        operator=(_Tuple&& __p)
        {
            typedef typename __make_tuple_types<_Tuple>::type _TupleRef;
            typedef typename tuple_element<0, _TupleRef>::type _U0;
            typedef typename tuple_element<1, _TupleRef>::type _U1;
            first  = _VSTD::forward<_U0>(_VSTD::get<0>(__p));
            second = _VSTD::forward<_U1>(_VSTD::get<1>(__p));
            return *this;
        }

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 379 "/usr/include/c++/v1/utility" 3

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 381 "/usr/include/c++/v1/utility" 3
    _LIBCPP_INLINE_VISIBILITY
    void
    swap(pair& __p) _NOEXCEPT_(__is_nothrow_swappable<first_type>::value &&
                               __is_nothrow_swappable<second_type>::value)
    {
        _VSTD::iter_swap(&first, &__p.first);
        _VSTD::iter_swap(&second, &__p.second);
    }
private:

#ifndef _LIBCPP_HAS_NO_VARIADICS
    template <class... _Args1, class... _Args2, size_t... _I1, size_t... _I2>
        _LIBCPP_INLINE_VISIBILITY
        pair(piecewise_construct_t,
             tuple<_Args1...>& __first_args, tuple<_Args2...>& __second_args,
             __tuple_indices<_I1...>, __tuple_indices<_I2...>);
#endif  // _LIBCPP_HAS_NO_VARIADICS
# 398 "/usr/include/c++/v1/utility" 3
};

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator==(const pair<_T1,_T2>& __x, const pair<_T1,_T2>& __y)
{
    return __x.first == __y.first && __x.second == __y.second;
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator!=(const pair<_T1,_T2>& __x, const pair<_T1,_T2>& __y)
{
    return !(__x == __y);
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator< (const pair<_T1,_T2>& __x, const pair<_T1,_T2>& __y)
{
    return __x.first < __y.first || (!(__y.first < __x.first) && __x.second < __y.second);
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator> (const pair<_T1,_T2>& __x, const pair<_T1,_T2>& __y)
{
    return __y < __x;
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator>=(const pair<_T1,_T2>& __x, const pair<_T1,_T2>& __y)
{
    return !(__x < __y);
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator<=(const pair<_T1,_T2>& __x, const pair<_T1,_T2>& __y)
{
    return !(__y < __x);
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    __is_swappable<_T1>::value &&
    __is_swappable<_T2>::value,
    void
>::type
swap(pair<_T1, _T2>& __x, pair<_T1, _T2>& __y)
                     _NOEXCEPT_((__is_nothrow_swappable<_T1>::value &&
                                 __is_nothrow_swappable<_T2>::value))
{
    __x.swap(__y);
}

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template <class _Tp> class _LIBCPP_TYPE_VIS_ONLY reference_wrapper;

template <class _Tp>
struct ___make_pair_return
{
    typedef _Tp type;
};

template <class _Tp>
struct ___make_pair_return<reference_wrapper<_Tp>>
{
    typedef _Tp& type;
};

template <class _Tp>
struct __make_pair_return
{
    typedef typename ___make_pair_return<typename decay<_Tp>::type>::type type;
};

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
pair<typename __make_pair_return<_T1>::type, typename __make_pair_return<_T2>::type>
make_pair(_T1&& __t1, _T2&& __t2)
{
    return pair<typename __make_pair_return<_T1>::type, typename __make_pair_return<_T2>::type>
               (_VSTD::forward<_T1>(__t1), _VSTD::forward<_T2>(__t2));
}

#else  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 495 "/usr/include/c++/v1/utility" 3

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY
pair<_T1,_T2>
make_pair(_T1 __x, _T2 __y)
{
    return pair<_T1, _T2>(__x, __y);
}

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 505 "/usr/include/c++/v1/utility" 3

template <class _T1, class _T2>
  class _LIBCPP_TYPE_VIS_ONLY tuple_size<pair<_T1, _T2> >
    : public integral_constant<size_t, 2> {};

template <class _T1, class _T2>
  class _LIBCPP_TYPE_VIS_ONLY tuple_size<const pair<_T1, _T2> >
    : public integral_constant<size_t, 2> {};

template <class _T1, class _T2>
class _LIBCPP_TYPE_VIS_ONLY tuple_element<0, pair<_T1, _T2> >
{
public:
    typedef _T1 type;
};

template <class _T1, class _T2>
class _LIBCPP_TYPE_VIS_ONLY tuple_element<1, pair<_T1, _T2> >
{
public:
    typedef _T2 type;
};

template <class _T1, class _T2>
class _LIBCPP_TYPE_VIS_ONLY tuple_element<0, const pair<_T1, _T2> >
{
public:
    typedef const _T1 type;
};

template <class _T1, class _T2>
class _LIBCPP_TYPE_VIS_ONLY tuple_element<1, const pair<_T1, _T2> >
{
public:
    typedef const _T2 type;
};

template <size_t _Ip> struct __get_pair;

template <>
struct __get_pair<0>
{
    template <class _T1, class _T2>
    static
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    _T1&
    get(pair<_T1, _T2>& __p) _NOEXCEPT {return __p.first;}

    template <class _T1, class _T2>
    static
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    const _T1&
    get(const pair<_T1, _T2>& __p) _NOEXCEPT {return __p.first;}

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

    template <class _T1, class _T2>
    static
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    _T1&&
    get(pair<_T1, _T2>&& __p) _NOEXCEPT {return _VSTD::forward<_T1>(__p.first);}

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 568 "/usr/include/c++/v1/utility" 3
};

template <>
struct __get_pair<1>
{
    template <class _T1, class _T2>
    static
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    _T2&
    get(pair<_T1, _T2>& __p) _NOEXCEPT {return __p.second;}

    template <class _T1, class _T2>
    static
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    const _T2&
    get(const pair<_T1, _T2>& __p) _NOEXCEPT {return __p.second;}

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

    template <class _T1, class _T2>
    static
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    _T2&&
    get(pair<_T1, _T2>&& __p) _NOEXCEPT {return _VSTD::forward<_T2>(__p.second);}

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 594 "/usr/include/c++/v1/utility" 3
};

template <size_t _Ip, class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
typename tuple_element<_Ip, pair<_T1, _T2> >::type&
get(pair<_T1, _T2>& __p) _NOEXCEPT
{
    return __get_pair<_Ip>::get(__p);
}

template <size_t _Ip, class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
const typename tuple_element<_Ip, pair<_T1, _T2> >::type&
get(const pair<_T1, _T2>& __p) _NOEXCEPT
{
    return __get_pair<_Ip>::get(__p);
}

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template <size_t _Ip, class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
typename tuple_element<_Ip, pair<_T1, _T2> >::type&&
get(pair<_T1, _T2>&& __p) _NOEXCEPT
{
    return __get_pair<_Ip>::get(_VSTD::move(__p));
}

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 623 "/usr/include/c++/v1/utility" 3

#if _LIBCPP_STD_VER > 11
template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _T1 & get(pair<_T1, _T2>& __p) _NOEXCEPT
{
    return __get_pair<0>::get(__p);
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _T1 const & get(pair<_T1, _T2> const& __p) _NOEXCEPT
{
    return __get_pair<0>::get(__p);
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _T1 && get(pair<_T1, _T2>&& __p) _NOEXCEPT
{
    return __get_pair<0>::get(_VSTD::move(__p));
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _T1 & get(pair<_T2, _T1>& __p) _NOEXCEPT
{
    return __get_pair<1>::get(__p);
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _T1 const & get(pair<_T2, _T1> const& __p) _NOEXCEPT
{
    return __get_pair<1>::get(__p);
}

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _T1 && get(pair<_T2, _T1>&& __p) _NOEXCEPT
{
    return __get_pair<1>::get(_VSTD::move(__p));
}

#endif
# 668 "/usr/include/c++/v1/utility" 3

#if _LIBCPP_STD_VER > 11

template<class _Tp, _Tp... _Ip>
struct _LIBCPP_TYPE_VIS_ONLY integer_sequence
{
    typedef _Tp value_type;
    static_assert( is_integral<_Tp>::value,
                  "std::integer_sequence can only be instantiated with an integral type" );
    static
    _LIBCPP_INLINE_VISIBILITY
    constexpr
    size_t
    size() noexcept { return sizeof...(_Ip); }
};

template<size_t... _Ip>
    using index_sequence = integer_sequence<size_t, _Ip...>;

namespace __detail {

template<typename _Tp, size_t ..._Extra> struct __repeat;
template<typename _Tp, _Tp ..._Np, size_t ..._Extra> struct __repeat<integer_sequence<_Tp, _Np...>, _Extra...> {
  typedef integer_sequence<_Tp,
                           _Np...,
                           sizeof...(_Np) + _Np...,
                           2 * sizeof...(_Np) + _Np...,
                           3 * sizeof...(_Np) + _Np...,
                           4 * sizeof...(_Np) + _Np...,
                           5 * sizeof...(_Np) + _Np...,
                           6 * sizeof...(_Np) + _Np...,
                           7 * sizeof...(_Np) + _Np...,
                           _Extra...> type;
};

template<size_t _Np> struct __parity;
template<size_t _Np> struct __make : __parity<_Np % 8>::template __pmake<_Np> {};

template<> struct __make<0> { typedef integer_sequence<size_t> type; };
template<> struct __make<1> { typedef integer_sequence<size_t, 0> type; };
template<> struct __make<2> { typedef integer_sequence<size_t, 0, 1> type; };
template<> struct __make<3> { typedef integer_sequence<size_t, 0, 1, 2> type; };
template<> struct __make<4> { typedef integer_sequence<size_t, 0, 1, 2, 3> type; };
template<> struct __make<5> { typedef integer_sequence<size_t, 0, 1, 2, 3, 4> type; };
template<> struct __make<6> { typedef integer_sequence<size_t, 0, 1, 2, 3, 4, 5> type; };
template<> struct __make<7> { typedef integer_sequence<size_t, 0, 1, 2, 3, 4, 5, 6> type; };

template<> struct __parity<0> { template<size_t _Np> struct __pmake : __repeat<typename __make<_Np / 8>::type> {}; };
template<> struct __parity<1> { template<size_t _Np> struct __pmake : __repeat<typename __make<_Np / 8>::type, _Np - 1> {}; };
template<> struct __parity<2> { template<size_t _Np> struct __pmake : __repeat<typename __make<_Np / 8>::type, _Np - 2, _Np - 1> {}; };
template<> struct __parity<3> { template<size_t _Np> struct __pmake : __repeat<typename __make<_Np / 8>::type, _Np - 3, _Np - 2, _Np - 1> {}; };
template<> struct __parity<4> { template<size_t _Np> struct __pmake : __repeat<typename __make<_Np / 8>::type, _Np - 4, _Np - 3, _Np - 2, _Np - 1> {}; };
template<> struct __parity<5> { template<size_t _Np> struct __pmake : __repeat<typename __make<_Np / 8>::type, _Np - 5, _Np - 4, _Np - 3, _Np - 2, _Np - 1> {}; };
template<> struct __parity<6> { template<size_t _Np> struct __pmake : __repeat<typename __make<_Np / 8>::type, _Np - 6, _Np - 5, _Np - 4, _Np - 3, _Np - 2, _Np - 1> {}; };
template<> struct __parity<7> { template<size_t _Np> struct __pmake : __repeat<typename __make<_Np / 8>::type, _Np - 7, _Np - 6, _Np - 5, _Np - 4, _Np - 3, _Np - 2, _Np - 1> {}; };

template<typename _Tp, typename _Up> struct __convert {
  template<typename> struct __result;
  template<_Tp ..._Np> struct __result<integer_sequence<_Tp, _Np...> > { typedef integer_sequence<_Up, _Np...> type; };
};
template<typename _Tp> struct __convert<_Tp, _Tp> { template<typename _Up> struct __result { typedef _Up type; }; };

}

template<typename _Tp, _Tp _Np> using __make_integer_sequence_unchecked =
  typename __detail::__convert<size_t, _Tp>::template __result<typename __detail::__make<_Np>::type>::type;

template <class _Tp, _Tp _Ep>
struct __make_integer_sequence
{
    static_assert(is_integral<_Tp>::value,
                  "std::make_integer_sequence can only be instantiated with an integral type" );
    static_assert(0 <= _Ep, "std::make_integer_sequence input shall not be negative");
    typedef __make_integer_sequence_unchecked<_Tp, _Ep> type;
};

template<class _Tp, _Tp _Np>
    using make_integer_sequence = typename __make_integer_sequence<_Tp, _Np>::type;

template<size_t _Np>
    using make_index_sequence = make_integer_sequence<size_t, _Np>;

template<class... _Tp>
    using index_sequence_for = make_index_sequence<sizeof...(_Tp)>;
  
#endif  // _LIBCPP_STD_VER > 11
# 754 "/usr/include/c++/v1/utility" 3

#if _LIBCPP_STD_VER > 11
template<class _T1, class _T2 = _T1>
inline _LIBCPP_INLINE_VISIBILITY
_T1 exchange(_T1& __obj, _T2 && __new_value)
{
    _T1 __old_value = _VSTD::move(__obj);
    __obj = _VSTD::forward<_T2>(__new_value);
    return __old_value;
}    
#endif  // _LIBCPP_STD_VER > 11
# 765 "/usr/include/c++/v1/utility" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_UTILITY
# 769 "/usr/include/c++/v1/utility" 3
# 627 "/usr/include/c++/v1/algorithm" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/memory" 1 3
// -*- C++ -*-
//===-------------------------- memory ------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_MEMORY
#define _LIBCPP_MEMORY

/*
    memory synopsis

namespace std
{

struct allocator_arg_t { };
constexpr allocator_arg_t allocator_arg = allocator_arg_t();

template <class T, class Alloc> struct uses_allocator;

template <class Ptr>
struct pointer_traits
{
    typedef Ptr pointer;
    typedef <details> element_type;
    typedef <details> difference_type;

    template <class U> using rebind = <details>;

    static pointer pointer_to(<details>);
};

template <class T>
struct pointer_traits<T*>
{
    typedef T* pointer;
    typedef T element_type;
    typedef ptrdiff_t difference_type;

    template <class U> using rebind = U*;

    static pointer pointer_to(<details>) noexcept;
};

template <class Alloc>
struct allocator_traits
{
    typedef Alloc                        allocator_type;
    typedef typename allocator_type::value_type
                                         value_type;

    typedef Alloc::pointer | value_type* pointer;
    typedef Alloc::const_pointer
          | pointer_traits<pointer>::rebind<const value_type>
                                         const_pointer;
    typedef Alloc::void_pointer
          | pointer_traits<pointer>::rebind<void>
                                         void_pointer;
    typedef Alloc::const_void_pointer
          | pointer_traits<pointer>::rebind<const void>
                                         const_void_pointer;
    typedef Alloc::difference_type
          | pointer_traits<pointer>::difference_type
                                         difference_type;
    typedef Alloc::size_type
          | make_unsigned<difference_type>::type
                                         size_type;
    typedef Alloc::propagate_on_container_copy_assignment
          | false_type                   propagate_on_container_copy_assignment;
    typedef Alloc::propagate_on_container_move_assignment
          | false_type                   propagate_on_container_move_assignment;
    typedef Alloc::propagate_on_container_swap
          | false_type                   propagate_on_container_swap;

    template <class T> using rebind_alloc  = Alloc::rebind<U>::other | Alloc<T, Args...>;
    template <class T> using rebind_traits = allocator_traits<rebind_alloc<T>>;

    static pointer allocate(allocator_type& a, size_type n);
    static pointer allocate(allocator_type& a, size_type n, const_void_pointer hint);

    static void deallocate(allocator_type& a, pointer p, size_type n) noexcept;

    template <class T, class... Args>
        static void construct(allocator_type& a, T* p, Args&&... args);

    template <class T>
        static void destroy(allocator_type& a, T* p);

    static size_type max_size(const allocator_type& a); // noexcept in C++14

    static allocator_type
        select_on_container_copy_construction(const allocator_type& a);
};

template <>
class allocator<void>
{
public:
    typedef void*                                 pointer;
    typedef const void*                           const_pointer;
    typedef void                                  value_type;

    template <class _Up> struct rebind {typedef allocator<_Up> other;};
};

template <class T>
class allocator
{
public:
    typedef size_t                                size_type;
    typedef ptrdiff_t                             difference_type;
    typedef T*                                    pointer;
    typedef const T*                              const_pointer;
    typedef typename add_lvalue_reference<T>::type       reference;
    typedef typename add_lvalue_reference<const T>::type const_reference;
    typedef T                                     value_type;

    template <class U> struct rebind {typedef allocator<U> other;};

    allocator() noexcept;
    allocator(const allocator&) noexcept;
    template <class U> allocator(const allocator<U>&) noexcept;
    ~allocator();
    pointer address(reference x) const noexcept;
    const_pointer address(const_reference x) const noexcept;
    pointer allocate(size_type, allocator<void>::const_pointer hint = 0);
    void deallocate(pointer p, size_type n) noexcept;
    size_type max_size() const noexcept;
    template<class U, class... Args>
        void construct(U* p, Args&&... args);
    template <class U>
        void destroy(U* p);
};

template <class T, class U>
bool operator==(const allocator<T>&, const allocator<U>&) noexcept;

template <class T, class U>
bool operator!=(const allocator<T>&, const allocator<U>&) noexcept;

template <class OutputIterator, class T>
class raw_storage_iterator
    : public iterator<output_iterator_tag,
                      T,                               // purposefully not C++03
                      ptrdiff_t,                       // purposefully not C++03
                      T*,                              // purposefully not C++03
                      raw_storage_iterator&>           // purposefully not C++03
{
public:
    explicit raw_storage_iterator(OutputIterator x);
    raw_storage_iterator& operator*();
    raw_storage_iterator& operator=(const T& element);
    raw_storage_iterator& operator++();
    raw_storage_iterator  operator++(int);
};

template <class T> pair<T*,ptrdiff_t> get_temporary_buffer(ptrdiff_t n) noexcept;
template <class T> void               return_temporary_buffer(T* p) noexcept;

template <class T> T* addressof(T& r) noexcept;

template <class InputIterator, class ForwardIterator>
ForwardIterator
uninitialized_copy(InputIterator first, InputIterator last, ForwardIterator result);

template <class InputIterator, class Size, class ForwardIterator>
ForwardIterator
uninitialized_copy_n(InputIterator first, Size n, ForwardIterator result);

template <class ForwardIterator, class T>
void uninitialized_fill(ForwardIterator first, ForwardIterator last, const T& x);

template <class ForwardIterator, class Size, class T>
ForwardIterator
uninitialized_fill_n(ForwardIterator first, Size n, const T& x);

template <class Y> struct auto_ptr_ref {};

template<class X>
class auto_ptr
{
public:
    typedef X element_type;

    explicit auto_ptr(X* p =0) throw();
    auto_ptr(auto_ptr&) throw();
    template<class Y> auto_ptr(auto_ptr<Y>&) throw();
    auto_ptr& operator=(auto_ptr&) throw();
    template<class Y> auto_ptr& operator=(auto_ptr<Y>&) throw();
    auto_ptr& operator=(auto_ptr_ref<X> r) throw();
    ~auto_ptr() throw();

    typename add_lvalue_reference<X>::type operator*() const throw();
    X* operator->() const throw();
    X* get() const throw();
    X* release() throw();
    void reset(X* p =0) throw();

    auto_ptr(auto_ptr_ref<X>) throw();
    template<class Y> operator auto_ptr_ref<Y>() throw();
    template<class Y> operator auto_ptr<Y>() throw();
};

template <class T>
struct default_delete
{
    constexpr default_delete() noexcept = default;
    template <class U> default_delete(const default_delete<U>&) noexcept;

    void operator()(T*) const noexcept;
};

template <class T>
struct default_delete<T[]>
{
    constexpr default_delete() noexcept = default;
    void operator()(T*) const noexcept;
    template <class U> void operator()(U*) const = delete;
};

template <class T, class D = default_delete<T>>
class unique_ptr
{
public:
    typedef see below pointer;
    typedef T element_type;
    typedef D deleter_type;

    // constructors
    constexpr unique_ptr() noexcept;
    explicit unique_ptr(pointer p) noexcept;
    unique_ptr(pointer p, see below d1) noexcept;
    unique_ptr(pointer p, see below d2) noexcept;
    unique_ptr(unique_ptr&& u) noexcept;
    unique_ptr(nullptr_t) noexcept : unique_ptr() { }
    template <class U, class E>
        unique_ptr(unique_ptr<U, E>&& u) noexcept;
    template <class U>
        unique_ptr(auto_ptr<U>&& u) noexcept;

    // destructor
    ~unique_ptr();

    // assignment
    unique_ptr& operator=(unique_ptr&& u) noexcept;
    template <class U, class E> unique_ptr& operator=(unique_ptr<U, E>&& u) noexcept;
    unique_ptr& operator=(nullptr_t) noexcept;

    // observers
    typename add_lvalue_reference<T>::type operator*() const;
    pointer operator->() const noexcept;
    pointer get() const noexcept;
    deleter_type& get_deleter() noexcept;
    const deleter_type& get_deleter() const noexcept;
    explicit operator bool() const noexcept;

    // modifiers
    pointer release() noexcept;
    void reset(pointer p = pointer()) noexcept;
    void swap(unique_ptr& u) noexcept;
};

template <class T, class D>
class unique_ptr<T[], D>
{
public:
    typedef implementation-defined pointer;
    typedef T element_type;
    typedef D deleter_type;

    // constructors
    constexpr unique_ptr() noexcept;
    explicit unique_ptr(pointer p) noexcept;
    unique_ptr(pointer p, see below d) noexcept;
    unique_ptr(pointer p, see below d) noexcept;
    unique_ptr(unique_ptr&& u) noexcept;
    unique_ptr(nullptr_t) noexcept : unique_ptr() { }

    // destructor
    ~unique_ptr();

    // assignment
    unique_ptr& operator=(unique_ptr&& u) noexcept;
    unique_ptr& operator=(nullptr_t) noexcept;

    // observers
    T& operator[](size_t i) const;
    pointer get() const noexcept;
    deleter_type& get_deleter() noexcept;
    const deleter_type& get_deleter() const noexcept;
    explicit operator bool() const noexcept;

    // modifiers
    pointer release() noexcept;
    void reset(pointer p = pointer()) noexcept;
    void reset(nullptr_t) noexcept;
    template <class U> void reset(U) = delete;
    void swap(unique_ptr& u) noexcept;
};

template <class T, class D>
    void swap(unique_ptr<T, D>& x, unique_ptr<T, D>& y) noexcept;

template <class T1, class D1, class T2, class D2>
    bool operator==(const unique_ptr<T1, D1>& x, const unique_ptr<T2, D2>& y);
template <class T1, class D1, class T2, class D2>
    bool operator!=(const unique_ptr<T1, D1>& x, const unique_ptr<T2, D2>& y);
template <class T1, class D1, class T2, class D2>
    bool operator<(const unique_ptr<T1, D1>& x, const unique_ptr<T2, D2>& y);
template <class T1, class D1, class T2, class D2>
    bool operator<=(const unique_ptr<T1, D1>& x, const unique_ptr<T2, D2>& y);
template <class T1, class D1, class T2, class D2>
    bool operator>(const unique_ptr<T1, D1>& x, const unique_ptr<T2, D2>& y);
template <class T1, class D1, class T2, class D2>
    bool operator>=(const unique_ptr<T1, D1>& x, const unique_ptr<T2, D2>& y);

template <class T, class D>
    bool operator==(const unique_ptr<T, D>& x, nullptr_t) noexcept;
template <class T, class D>
    bool operator==(nullptr_t, const unique_ptr<T, D>& y) noexcept;
template <class T, class D>
    bool operator!=(const unique_ptr<T, D>& x, nullptr_t) noexcept;
template <class T, class D>
    bool operator!=(nullptr_t, const unique_ptr<T, D>& y) noexcept;

template <class T, class D>
    bool operator<(const unique_ptr<T, D>& x, nullptr_t);
template <class T, class D>
    bool operator<(nullptr_t, const unique_ptr<T, D>& y);
template <class T, class D>
    bool operator<=(const unique_ptr<T, D>& x, nullptr_t);
template <class T, class D>
    bool operator<=(nullptr_t, const unique_ptr<T, D>& y);
template <class T, class D>
    bool operator>(const unique_ptr<T, D>& x, nullptr_t);
template <class T, class D>
    bool operator>(nullptr_t, const unique_ptr<T, D>& y);
template <class T, class D>
    bool operator>=(const unique_ptr<T, D>& x, nullptr_t);
template <class T, class D>
    bool operator>=(nullptr_t, const unique_ptr<T, D>& y);

class bad_weak_ptr
    : public std::exception
{
    bad_weak_ptr() noexcept;
};

template<class T, class... Args> unique_ptr<T> make_unique(Args&&... args);     // C++14
template<class T>                unique_ptr<T> make_unique(size_t n);           // C++14
template<class T, class... Args> unspecified   make_unique(Args&&...) = delete; // C++14, T == U[N]

template<class T>
class shared_ptr
{
public:
    typedef T element_type;

    // constructors:
    constexpr shared_ptr() noexcept;
    template<class Y> explicit shared_ptr(Y* p);
    template<class Y, class D> shared_ptr(Y* p, D d);
    template<class Y, class D, class A> shared_ptr(Y* p, D d, A a);
    template <class D> shared_ptr(nullptr_t p, D d);
    template <class D, class A> shared_ptr(nullptr_t p, D d, A a);
    template<class Y> shared_ptr(const shared_ptr<Y>& r, T *p) noexcept;
    shared_ptr(const shared_ptr& r) noexcept;
    template<class Y> shared_ptr(const shared_ptr<Y>& r) noexcept;
    shared_ptr(shared_ptr&& r) noexcept;
    template<class Y> shared_ptr(shared_ptr<Y>&& r) noexcept;
    template<class Y> explicit shared_ptr(const weak_ptr<Y>& r);
    template<class Y> shared_ptr(auto_ptr<Y>&& r);
    template <class Y, class D> shared_ptr(unique_ptr<Y, D>&& r);
    shared_ptr(nullptr_t) : shared_ptr() { }

    // destructor:
    ~shared_ptr();

    // assignment:
    shared_ptr& operator=(const shared_ptr& r) noexcept;
    template<class Y> shared_ptr& operator=(const shared_ptr<Y>& r) noexcept;
    shared_ptr& operator=(shared_ptr&& r) noexcept;
    template<class Y> shared_ptr& operator=(shared_ptr<Y>&& r);
    template<class Y> shared_ptr& operator=(auto_ptr<Y>&& r);
    template <class Y, class D> shared_ptr& operator=(unique_ptr<Y, D>&& r);

    // modifiers:
    void swap(shared_ptr& r) noexcept;
    void reset() noexcept;
    template<class Y> void reset(Y* p);
    template<class Y, class D> void reset(Y* p, D d);
    template<class Y, class D, class A> void reset(Y* p, D d, A a);

    // observers:
    T* get() const noexcept;
    T& operator*() const noexcept;
    T* operator->() const noexcept;
    long use_count() const noexcept;
    bool unique() const noexcept;
    explicit operator bool() const noexcept;
    template<class U> bool owner_before(shared_ptr<U> const& b) const;
    template<class U> bool owner_before(weak_ptr<U> const& b) const;
};

// shared_ptr comparisons:
template<class T, class U>
    bool operator==(shared_ptr<T> const& a, shared_ptr<U> const& b) noexcept;
template<class T, class U>
    bool operator!=(shared_ptr<T> const& a, shared_ptr<U> const& b) noexcept;
template<class T, class U>
    bool operator<(shared_ptr<T> const& a, shared_ptr<U> const& b) noexcept;
template<class T, class U>
    bool operator>(shared_ptr<T> const& a, shared_ptr<U> const& b) noexcept;
template<class T, class U>
    bool operator<=(shared_ptr<T> const& a, shared_ptr<U> const& b) noexcept;
template<class T, class U>
    bool operator>=(shared_ptr<T> const& a, shared_ptr<U> const& b) noexcept;

template <class T>
    bool operator==(const shared_ptr<T>& x, nullptr_t) noexcept;
template <class T>
    bool operator==(nullptr_t, const shared_ptr<T>& y) noexcept;
template <class T>
    bool operator!=(const shared_ptr<T>& x, nullptr_t) noexcept;
template <class T>
    bool operator!=(nullptr_t, const shared_ptr<T>& y) noexcept;
template <class T>
    bool operator<(const shared_ptr<T>& x, nullptr_t) noexcept;
template <class T>
bool operator<(nullptr_t, const shared_ptr<T>& y) noexcept;
template <class T>
    bool operator<=(const shared_ptr<T>& x, nullptr_t) noexcept;
template <class T>
    bool operator<=(nullptr_t, const shared_ptr<T>& y) noexcept;
template <class T>
    bool operator>(const shared_ptr<T>& x, nullptr_t) noexcept;
template <class T>
    bool operator>(nullptr_t, const shared_ptr<T>& y) noexcept;
template <class T>
    bool operator>=(const shared_ptr<T>& x, nullptr_t) noexcept;
template <class T>
    bool operator>=(nullptr_t, const shared_ptr<T>& y) noexcept;

// shared_ptr specialized algorithms:
template<class T> void swap(shared_ptr<T>& a, shared_ptr<T>& b) noexcept;

// shared_ptr casts:
template<class T, class U>
    shared_ptr<T> static_pointer_cast(shared_ptr<U> const& r) noexcept;
template<class T, class U>
    shared_ptr<T> dynamic_pointer_cast(shared_ptr<U> const& r) noexcept;
template<class T, class U>
    shared_ptr<T> const_pointer_cast(shared_ptr<U> const& r) noexcept;

// shared_ptr I/O:
template<class E, class T, class Y>
    basic_ostream<E, T>& operator<< (basic_ostream<E, T>& os, shared_ptr<Y> const& p);

// shared_ptr get_deleter:
template<class D, class T> D* get_deleter(shared_ptr<T> const& p) noexcept;

template<class T, class... Args>
    shared_ptr<T> make_shared(Args&&... args);
template<class T, class A, class... Args>
    shared_ptr<T> allocate_shared(const A& a, Args&&... args);

template<class T>
class weak_ptr
{
public:
    typedef T element_type;

    // constructors
    constexpr weak_ptr() noexcept;
    template<class Y> weak_ptr(shared_ptr<Y> const& r) noexcept;
    weak_ptr(weak_ptr const& r) noexcept;
    template<class Y> weak_ptr(weak_ptr<Y> const& r) noexcept;

    // destructor
    ~weak_ptr();

    // assignment
    weak_ptr& operator=(weak_ptr const& r) noexcept;
    template<class Y> weak_ptr& operator=(weak_ptr<Y> const& r) noexcept;
    template<class Y> weak_ptr& operator=(shared_ptr<Y> const& r) noexcept;

    // modifiers
    void swap(weak_ptr& r) noexcept;
    void reset() noexcept;

    // observers
    long use_count() const noexcept;
    bool expired() const noexcept;
    shared_ptr<T> lock() const noexcept;
    template<class U> bool owner_before(shared_ptr<U> const& b) const;
    template<class U> bool owner_before(weak_ptr<U> const& b) const;
};

// weak_ptr specialized algorithms:
template<class T> void swap(weak_ptr<T>& a, weak_ptr<T>& b) noexcept;

// class owner_less:
template<class T> struct owner_less;

template<class T>
struct owner_less<shared_ptr<T>>
    : binary_function<shared_ptr<T>, shared_ptr<T>, bool>
{
    typedef bool result_type;
    bool operator()(shared_ptr<T> const&, shared_ptr<T> const&) const;
    bool operator()(shared_ptr<T> const&, weak_ptr<T> const&) const;
    bool operator()(weak_ptr<T> const&, shared_ptr<T> const&) const;
};

template<class T>
struct owner_less<weak_ptr<T>>
    : binary_function<weak_ptr<T>, weak_ptr<T>, bool>
{
    typedef bool result_type;
    bool operator()(weak_ptr<T> const&, weak_ptr<T> const&) const;
    bool operator()(shared_ptr<T> const&, weak_ptr<T> const&) const;
    bool operator()(weak_ptr<T> const&, shared_ptr<T> const&) const;
};

template<class T>
class enable_shared_from_this
{
protected:
    constexpr enable_shared_from_this() noexcept;
    enable_shared_from_this(enable_shared_from_this const&) noexcept;
    enable_shared_from_this& operator=(enable_shared_from_this const&) noexcept;
    ~enable_shared_from_this();
public:
    shared_ptr<T> shared_from_this();
    shared_ptr<T const> shared_from_this() const;
};

template<class T>
    bool atomic_is_lock_free(const shared_ptr<T>* p);
template<class T>
    shared_ptr<T> atomic_load(const shared_ptr<T>* p);
template<class T>
    shared_ptr<T> atomic_load_explicit(const shared_ptr<T>* p, memory_order mo);
template<class T>
    void atomic_store(shared_ptr<T>* p, shared_ptr<T> r);
template<class T>
    void atomic_store_explicit(shared_ptr<T>* p, shared_ptr<T> r, memory_order mo);
template<class T>
    shared_ptr<T> atomic_exchange(shared_ptr<T>* p, shared_ptr<T> r);
template<class T>
    shared_ptr<T>
    atomic_exchange_explicit(shared_ptr<T>* p, shared_ptr<T> r, memory_order mo);
template<class T>
    bool
    atomic_compare_exchange_weak(shared_ptr<T>* p, shared_ptr<T>* v, shared_ptr<T> w);
template<class T>
    bool
    atomic_compare_exchange_strong( shared_ptr<T>* p, shared_ptr<T>* v, shared_ptr<T> w);
template<class T>
    bool
    atomic_compare_exchange_weak_explicit(shared_ptr<T>* p, shared_ptr<T>* v,
                                          shared_ptr<T> w, memory_order success,
                                          memory_order failure);
template<class T>
    bool
    atomic_compare_exchange_strong_explicit(shared_ptr<T>* p, shared_ptr<T>* v,
                                            shared_ptr<T> w, memory_order success,
                                            memory_order failure);
// Hash support
template <class T> struct hash;
template <class T, class D> struct hash<unique_ptr<T, D> >;
template <class T> struct hash<shared_ptr<T> >;

// Pointer safety
enum class pointer_safety { relaxed, preferred, strict };
void declare_reachable(void *p);
template <class T> T *undeclare_reachable(T *p);
void declare_no_pointers(char *p, size_t n);
void undeclare_no_pointers(char *p, size_t n);
pointer_safety get_pointer_safety() noexcept;

void* align(size_t alignment, size_t size, void*& ptr, size_t& space);

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 593 "/usr/include/c++/v1/memory" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 594 "/usr/include/c++/v1/memory" 3
#if 0 /* expanded by -frewrite-includes */
#include <typeinfo>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/typeinfo" 1 3
// -*- C++ -*-
//===-------------------------- typeinfo ----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef __LIBCPP_TYPEINFO
#define __LIBCPP_TYPEINFO

/*

    typeinfo synopsis

namespace std {

class type_info
{
public:
    virtual ~type_info();

    bool operator==(const type_info& rhs) const noexcept;
    bool operator!=(const type_info& rhs) const noexcept;

    bool before(const type_info& rhs) const noexcept;
    size_t hash_code() const noexcept;
    const char* name() const noexcept;

    type_info(const type_info& rhs) = delete;
    type_info& operator=(const type_info& rhs) = delete;
};

class bad_cast
    : public exception
{
public:
    bad_cast() noexcept;
    bad_cast(const bad_cast&) noexcept;
    bad_cast& operator=(const bad_cast&) noexcept;
    virtual const char* what() const noexcept;
};

class bad_typeid
    : public exception
{
public:
    bad_typeid() noexcept;
    bad_typeid(const bad_typeid&) noexcept;
    bad_typeid& operator=(const bad_typeid&) noexcept;
    virtual const char* what() const noexcept;
};

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 61 "/usr/include/c++/v1/typeinfo" 3
#if 0 /* expanded by -frewrite-includes */
#include <exception>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/exception" 1 3
// -*- C++ -*-
//===-------------------------- exception ---------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_EXCEPTION
#define _LIBCPP_EXCEPTION

/*
    exception synopsis

namespace std
{

class exception
{
public:
    exception() noexcept;
    exception(const exception&) noexcept;
    exception& operator=(const exception&) noexcept;
    virtual ~exception() noexcept;
    virtual const char* what() const noexcept;
};

class bad_exception
    : public exception
{
public:
    bad_exception() noexcept;
    bad_exception(const bad_exception&) noexcept;
    bad_exception& operator=(const bad_exception&) noexcept;
    virtual ~bad_exception() noexcept;
    virtual const char* what() const noexcept;
};

typedef void (*unexpected_handler)();
unexpected_handler set_unexpected(unexpected_handler  f ) noexcept;
unexpected_handler get_unexpected() noexcept;
[[noreturn]] void unexpected();

typedef void (*terminate_handler)();
terminate_handler set_terminate(terminate_handler  f ) noexcept;
terminate_handler get_terminate() noexcept;
[[noreturn]] void terminate() noexcept;

bool uncaught_exception() noexcept;

typedef unspecified exception_ptr;

exception_ptr current_exception() noexcept;
void rethrow_exception [[noreturn]] (exception_ptr p);
template<class E> exception_ptr make_exception_ptr(E e) noexcept;

class nested_exception
{
public:
    nested_exception() noexcept;
    nested_exception(const nested_exception&) noexcept = default;
    nested_exception& operator=(const nested_exception&) noexcept = default;
    virtual ~nested_exception() = default;

    // access functions
    [[noreturn]] void rethrow_nested() const;
    exception_ptr nested_ptr() const noexcept;
};

template <class T> [[noreturn]] void throw_with_nested(T&& t);
template <class E> void rethrow_if_nested(const E& e);

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 80 "/usr/include/c++/v1/exception" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 81 "/usr/include/c++/v1/exception" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 82 "/usr/include/c++/v1/exception" 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 85 "/usr/include/c++/v1/exception" 3
#endif
# 86 "/usr/include/c++/v1/exception" 3

namespace std  // purposefully not using versioning namespace
{

class _LIBCPP_EXCEPTION_ABI exception
{
public:
    _LIBCPP_INLINE_VISIBILITY exception() _NOEXCEPT {}
    virtual ~exception() _NOEXCEPT;
    virtual const char* what() const _NOEXCEPT;
};

class _LIBCPP_EXCEPTION_ABI bad_exception
    : public exception
{
public:
    _LIBCPP_INLINE_VISIBILITY bad_exception() _NOEXCEPT {}
    virtual ~bad_exception() _NOEXCEPT;
    virtual const char* what() const _NOEXCEPT;
};

typedef void (*unexpected_handler)();
_LIBCPP_FUNC_VIS unexpected_handler set_unexpected(unexpected_handler) _NOEXCEPT;
_LIBCPP_FUNC_VIS unexpected_handler get_unexpected() _NOEXCEPT;
_LIBCPP_NORETURN _LIBCPP_FUNC_VIS void unexpected();

typedef void (*terminate_handler)();
_LIBCPP_FUNC_VIS terminate_handler set_terminate(terminate_handler) _NOEXCEPT;
_LIBCPP_FUNC_VIS terminate_handler get_terminate() _NOEXCEPT;
_LIBCPP_NORETURN _LIBCPP_FUNC_VIS void terminate() _NOEXCEPT;

_LIBCPP_FUNC_VIS bool uncaught_exception() _NOEXCEPT;

class _LIBCPP_TYPE_VIS exception_ptr;

_LIBCPP_FUNC_VIS exception_ptr current_exception() _NOEXCEPT;
_LIBCPP_NORETURN _LIBCPP_FUNC_VIS void rethrow_exception(exception_ptr);

class _LIBCPP_TYPE_VIS exception_ptr
{
    void* __ptr_;
public:
    _LIBCPP_INLINE_VISIBILITY exception_ptr() _NOEXCEPT : __ptr_() {}
    _LIBCPP_INLINE_VISIBILITY exception_ptr(nullptr_t) _NOEXCEPT : __ptr_() {}
    exception_ptr(const exception_ptr&) _NOEXCEPT;
    exception_ptr& operator=(const exception_ptr&) _NOEXCEPT;
    ~exception_ptr() _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_EXPLICIT
        operator bool() const _NOEXCEPT {return __ptr_ != nullptr;}

    friend _LIBCPP_INLINE_VISIBILITY
    bool operator==(const exception_ptr& __x, const exception_ptr& __y) _NOEXCEPT
        {return __x.__ptr_ == __y.__ptr_;}
    friend _LIBCPP_INLINE_VISIBILITY
    bool operator!=(const exception_ptr& __x, const exception_ptr& __y) _NOEXCEPT
        {return !(__x == __y);}

    friend _LIBCPP_FUNC_VIS exception_ptr current_exception() _NOEXCEPT;
    friend _LIBCPP_FUNC_VIS void rethrow_exception(exception_ptr);
};

template<class _Ep>
exception_ptr
make_exception_ptr(_Ep __e) _NOEXCEPT
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    try
    {
        throw __e;
    }
    catch (...)
    {
        return current_exception();
    }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 163 "/usr/include/c++/v1/exception" 3
}

// nested_exception

class _LIBCPP_EXCEPTION_ABI nested_exception
{
    exception_ptr __ptr_;
public:
    nested_exception() _NOEXCEPT;
//     nested_exception(const nested_exception&) noexcept = default;
//     nested_exception& operator=(const nested_exception&) noexcept = default;
    virtual ~nested_exception() _NOEXCEPT;

    // access functions
    _LIBCPP_NORETURN void rethrow_nested() const;
    _LIBCPP_INLINE_VISIBILITY exception_ptr nested_ptr() const _NOEXCEPT {return __ptr_;}
};

template <class _Tp>
struct __nested
    : public _Tp,
      public nested_exception
{
    _LIBCPP_INLINE_VISIBILITY explicit __nested(const _Tp& __t) : _Tp(__t) {}
};

template <class _Tp>
_LIBCPP_NORETURN
void
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
throw_with_nested(_Tp&& __t, typename enable_if<
                  is_class<typename remove_reference<_Tp>::type>::value &&
                  !is_base_of<nested_exception, typename remove_reference<_Tp>::type>::value
                                    >::type* = 0)
#else  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 198 "/usr/include/c++/v1/exception" 3
throw_with_nested (_Tp& __t, typename enable_if<
                  is_class<_Tp>::value && !is_base_of<nested_exception, _Tp>::value
                                    >::type* = 0)
#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 202 "/usr/include/c++/v1/exception" 3
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    throw __nested<typename remove_reference<_Tp>::type>(_VSTD::forward<_Tp>(__t));
#endif
# 206 "/usr/include/c++/v1/exception" 3
}

template <class _Tp>
_LIBCPP_NORETURN
void
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
throw_with_nested(_Tp&& __t, typename enable_if<
                  !is_class<typename remove_reference<_Tp>::type>::value ||
                  is_base_of<nested_exception, typename remove_reference<_Tp>::type>::value
                                    >::type* = 0)
#else  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 217 "/usr/include/c++/v1/exception" 3
throw_with_nested (_Tp& __t, typename enable_if<
                  !is_class<_Tp>::value || is_base_of<nested_exception, _Tp>::value
                                    >::type* = 0)
#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 221 "/usr/include/c++/v1/exception" 3
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    throw _VSTD::forward<_Tp>(__t);
#endif
# 225 "/usr/include/c++/v1/exception" 3
}

template <class _Ep>
inline _LIBCPP_INLINE_VISIBILITY
void
rethrow_if_nested(const _Ep& __e, typename enable_if<
                                   is_polymorphic<_Ep>::value
                                                   >::type* = 0)
{
    const nested_exception* __nep = dynamic_cast<const nested_exception*>(&__e);
    if (__nep)
        __nep->rethrow_nested();
}

template <class _Ep>
inline _LIBCPP_INLINE_VISIBILITY
void
rethrow_if_nested(const _Ep&, typename enable_if<
                                   !is_polymorphic<_Ep>::value
                                                   >::type* = 0)
{
}

}  // std

#endif  // _LIBCPP_EXCEPTION
# 251 "/usr/include/c++/v1/exception" 3
# 62 "/usr/include/c++/v1/typeinfo" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 63 "/usr/include/c++/v1/typeinfo" 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 66 "/usr/include/c++/v1/typeinfo" 3
#endif
# 67 "/usr/include/c++/v1/typeinfo" 3

namespace std  // purposefully not using versioning namespace
{

class _LIBCPP_EXCEPTION_ABI type_info
{
    type_info& operator=(const type_info&);
    type_info(const type_info&);
protected:
    const char* __type_name;

    _LIBCPP_INLINE_VISIBILITY
    explicit type_info(const char* __n)
        : __type_name(__n) {}

public:
    virtual ~type_info();

    _LIBCPP_INLINE_VISIBILITY
    const char* name() const _NOEXCEPT {return __type_name;}

    _LIBCPP_INLINE_VISIBILITY
    bool before(const type_info& __arg) const _NOEXCEPT
        {return __type_name < __arg.__type_name;}
    _LIBCPP_INLINE_VISIBILITY
    size_t hash_code() const _NOEXCEPT
        {return *reinterpret_cast<const size_t*>(&__type_name);}

    _LIBCPP_INLINE_VISIBILITY
    bool operator==(const type_info& __arg) const _NOEXCEPT
        {return __type_name == __arg.__type_name;}
    _LIBCPP_INLINE_VISIBILITY
    bool operator!=(const type_info& __arg) const _NOEXCEPT
        {return !operator==(__arg);}

};

class _LIBCPP_EXCEPTION_ABI bad_cast
    : public exception
{
public:
    bad_cast() _NOEXCEPT;
    virtual ~bad_cast() _NOEXCEPT;
    virtual const char* what() const _NOEXCEPT;
};

class _LIBCPP_EXCEPTION_ABI bad_typeid
    : public exception
{
public:
    bad_typeid() _NOEXCEPT;
    virtual ~bad_typeid() _NOEXCEPT;
    virtual const char* what() const _NOEXCEPT;
};

}  // std

#endif  // __LIBCPP_TYPEINFO
# 125 "/usr/include/c++/v1/typeinfo" 3
# 595 "/usr/include/c++/v1/memory" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 596 "/usr/include/c++/v1/memory" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/cstdint" 1 3
// -*- C++ -*-
//===--------------------------- cstdint ----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CSTDINT
#define _LIBCPP_CSTDINT

/*
    cstdint synopsis

Macros:

    INT8_MIN
    INT16_MIN
    INT32_MIN
    INT64_MIN

    INT8_MAX
    INT16_MAX
    INT32_MAX
    INT64_MAX

    UINT8_MAX
    UINT16_MAX
    UINT32_MAX
    UINT64_MAX

    INT_LEAST8_MIN
    INT_LEAST16_MIN
    INT_LEAST32_MIN
    INT_LEAST64_MIN

    INT_LEAST8_MAX
    INT_LEAST16_MAX
    INT_LEAST32_MAX
    INT_LEAST64_MAX

    UINT_LEAST8_MAX
    UINT_LEAST16_MAX
    UINT_LEAST32_MAX
    UINT_LEAST64_MAX

    INT_FAST8_MIN
    INT_FAST16_MIN
    INT_FAST32_MIN
    INT_FAST64_MIN

    INT_FAST8_MAX
    INT_FAST16_MAX
    INT_FAST32_MAX
    INT_FAST64_MAX

    UINT_FAST8_MAX
    UINT_FAST16_MAX
    UINT_FAST32_MAX
    UINT_FAST64_MAX

    INTPTR_MIN
    INTPTR_MAX
    UINTPTR_MAX

    INTMAX_MIN
    INTMAX_MAX

    UINTMAX_MAX

    PTRDIFF_MIN
    PTRDIFF_MAX

    SIG_ATOMIC_MIN
    SIG_ATOMIC_MAX

    SIZE_MAX

    WCHAR_MIN
    WCHAR_MAX

    WINT_MIN
    WINT_MAX

    INT8_C(value)
    INT16_C(value)
    INT32_C(value)
    INT64_C(value)

    UINT8_C(value)
    UINT16_C(value)
    UINT32_C(value)
    UINT64_C(value)

    INTMAX_C(value)
    UINTMAX_C(value)

namespace std
{

Types:

    int8_t
    int16_t
    int32_t
    int64_t

    uint8_t
    uint16_t
    uint32_t
    uint64_t

    int_least8_t
    int_least16_t
    int_least32_t
    int_least64_t

    uint_least8_t
    uint_least16_t
    uint_least32_t
    uint_least64_t

    int_fast8_t
    int_fast16_t
    int_fast32_t
    int_fast64_t

    uint_fast8_t
    uint_fast16_t
    uint_fast32_t
    uint_fast64_t

    intptr_t
    uintptr_t

    intmax_t
    uintmax_t

}  // std
*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 145 "/usr/include/c++/v1/cstdint" 3
#if 0 /* expanded by -frewrite-includes */
#include <stdint.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/stdint.h" 1 3 4
/*-
 * Copyright (c) 2001 Mike Barcroft <mike@FreeBSD.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/sys/sys/stdint.h 237517 2012-06-24 04:15:58Z andrew $
 */

#ifndef _SYS_STDINT_H_
#define _SYS_STDINT_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 33 "/usr/include/stdint.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 34 "/usr/include/stdint.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <machine/_stdint.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/machine/_stdint.h" 1 3 4
/*-
 * This file is in the public domain.
 */
/* $FreeBSD: head/sys/amd64/include/_stdint.h 232264 2012-02-28 18:38:33Z tijl $ */

#if 0 /* expanded by -frewrite-includes */
#include <x86/_stdint.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/x86/_stdint.h" 1 3 4
/*-
 * Copyright (c) 2001, 2002 Mike Barcroft <mike@FreeBSD.org>
 * Copyright (c) 2001 The NetBSD Foundation, Inc.
 * All rights reserved.
 *
 * This code is derived from software contributed to The NetBSD Foundation
 * by Klaus Klein.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *        This product includes software developed by the NetBSD
 *        Foundation, Inc. and its contributors.
 * 4. Neither the name of The NetBSD Foundation nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * $FreeBSD: head/sys/x86/include/_stdint.h 237517 2012-06-24 04:15:58Z andrew $
 */

#ifndef _MACHINE__STDINT_H_
#define	_MACHINE__STDINT_H_

#if !defined(__cplusplus) || defined(__STDC_CONSTANT_MACROS)

#define	INT8_C(c)		(c)
#define	INT16_C(c)		(c)
#define	INT32_C(c)		(c)

#define	UINT8_C(c)		(c)
#define	UINT16_C(c)		(c)
#define	UINT32_C(c)		(c ## U)

#ifdef	__LP64__
#define	INT64_C(c)		(c ## L)
#define	UINT64_C(c)		(c ## UL)
#else
# 57 "/usr/include/x86/_stdint.h" 3 4
#define	INT64_C(c)		(c ## LL)
#define	UINT64_C(c)		(c ## ULL)
#endif
# 60 "/usr/include/x86/_stdint.h" 3 4

#define	INTMAX_C(c)		INT64_C(c)
#define	UINTMAX_C(c)		UINT64_C(c)

#endif /* !defined(__cplusplus) || defined(__STDC_CONSTANT_MACROS) */
# 65 "/usr/include/x86/_stdint.h" 3 4

#if !defined(__cplusplus) || defined(__STDC_LIMIT_MACROS)

/*
 * ISO/IEC 9899:1999
 * 7.18.2.1 Limits of exact-width integer types
 */
#define	INT8_MIN	(-0x7f-1)
#define	INT16_MIN	(-0x7fff-1)
#define	INT32_MIN	(-0x7fffffff-1)

#define	INT8_MAX	0x7f
#define	INT16_MAX	0x7fff
#define	INT32_MAX	0x7fffffff

#define	UINT8_MAX	0xff
#define	UINT16_MAX	0xffff
#define	UINT32_MAX	0xffffffffU

#ifdef __LP64__
#define	INT64_MIN	(-0x7fffffffffffffff-1)
#define	INT64_MAX	0x7fffffffffffffff
#define	UINT64_MAX	0xffffffffffffffff
#else
# 89 "/usr/include/x86/_stdint.h" 3 4
#define	INT64_MIN	(-0x7fffffffffffffffLL-1)
#define	INT64_MAX	0x7fffffffffffffffLL
#define	UINT64_MAX	0xffffffffffffffffULL
#endif
# 93 "/usr/include/x86/_stdint.h" 3 4

/*
 * ISO/IEC 9899:1999
 * 7.18.2.2  Limits of minimum-width integer types
 */
/* Minimum values of minimum-width signed integer types. */
#define	INT_LEAST8_MIN	INT8_MIN
#define	INT_LEAST16_MIN	INT16_MIN
#define	INT_LEAST32_MIN	INT32_MIN
#define	INT_LEAST64_MIN	INT64_MIN

/* Maximum values of minimum-width signed integer types. */
#define	INT_LEAST8_MAX	INT8_MAX
#define	INT_LEAST16_MAX	INT16_MAX
#define	INT_LEAST32_MAX	INT32_MAX
#define	INT_LEAST64_MAX	INT64_MAX

/* Maximum values of minimum-width unsigned integer types. */
#define	UINT_LEAST8_MAX	 UINT8_MAX
#define	UINT_LEAST16_MAX UINT16_MAX
#define	UINT_LEAST32_MAX UINT32_MAX
#define	UINT_LEAST64_MAX UINT64_MAX

/*
 * ISO/IEC 9899:1999
 * 7.18.2.3  Limits of fastest minimum-width integer types
 */
/* Minimum values of fastest minimum-width signed integer types. */
#define	INT_FAST8_MIN	INT32_MIN
#define	INT_FAST16_MIN	INT32_MIN
#define	INT_FAST32_MIN	INT32_MIN
#define	INT_FAST64_MIN	INT64_MIN

/* Maximum values of fastest minimum-width signed integer types. */
#define	INT_FAST8_MAX	INT32_MAX
#define	INT_FAST16_MAX	INT32_MAX
#define	INT_FAST32_MAX	INT32_MAX
#define	INT_FAST64_MAX	INT64_MAX

/* Maximum values of fastest minimum-width unsigned integer types. */
#define	UINT_FAST8_MAX	UINT32_MAX
#define	UINT_FAST16_MAX	UINT32_MAX
#define	UINT_FAST32_MAX	UINT32_MAX
#define	UINT_FAST64_MAX	UINT64_MAX

/*
 * ISO/IEC 9899:1999
 * 7.18.2.4  Limits of integer types capable of holding object pointers
 */
#ifdef	__LP64__
#define	INTPTR_MIN	INT64_MIN
#define	INTPTR_MAX	INT64_MAX
#define	UINTPTR_MAX	UINT64_MAX
#else
# 147 "/usr/include/x86/_stdint.h" 3 4
#define	INTPTR_MIN	INT32_MIN
#define	INTPTR_MAX	INT32_MAX
#define	UINTPTR_MAX	UINT32_MAX
#endif
# 151 "/usr/include/x86/_stdint.h" 3 4

/*
 * ISO/IEC 9899:1999
 * 7.18.2.5  Limits of greatest-width integer types
 */
#define	INTMAX_MIN	INT64_MIN
#define	INTMAX_MAX	INT64_MAX
#define	UINTMAX_MAX	UINT64_MAX

/*
 * ISO/IEC 9899:1999
 * 7.18.3  Limits of other integer types
 */
#ifdef	__LP64__
/* Limits of ptrdiff_t. */
#define	PTRDIFF_MIN	INT64_MIN	
#define	PTRDIFF_MAX	INT64_MAX

/* Limits of sig_atomic_t. */
#define	SIG_ATOMIC_MIN	LONG_MIN
#define	SIG_ATOMIC_MAX	LONG_MAX

/* Limit of size_t. */
#define	SIZE_MAX	UINT64_MAX
#else
# 176 "/usr/include/x86/_stdint.h" 3 4
#define	PTRDIFF_MIN	INT32_MIN
#define	PTRDIFF_MAX	INT32_MAX
#define	SIG_ATOMIC_MIN	INT32_MIN
#define	SIG_ATOMIC_MAX	INT32_MAX
#define	SIZE_MAX	UINT32_MAX
#endif
# 182 "/usr/include/x86/_stdint.h" 3 4

/* Limits of wint_t. */
#define	WINT_MIN	INT32_MIN
#define	WINT_MAX	INT32_MAX

#endif /* !defined(__cplusplus) || defined(__STDC_LIMIT_MACROS) */
# 188 "/usr/include/x86/_stdint.h" 3 4

#endif /* !_MACHINE__STDINT_H_ */
# 190 "/usr/include/x86/_stdint.h" 3 4
# 7 "/usr/include/machine/_stdint.h" 2 3 4
# 36 "/usr/include/stdint.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_stdint.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/sys/_stdint.h" 1 3 4
/*-
 * Copyright (c) 2011 David E. O'Brien <obrien@FreeBSD.org>
 * Copyright (c) 2001 Mike Barcroft <mike@FreeBSD.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/sys/sys/_stdint.h 222813 2011-06-07 08:46:13Z attilio $
 */

#ifndef _SYS__STDINT_H_
#define _SYS__STDINT_H_

#ifndef _INT8_T_DECLARED
typedef	__int8_t		int8_t;
#define	_INT8_T_DECLARED
#endif
# 37 "/usr/include/sys/_stdint.h" 3 4

#ifndef _INT16_T_DECLARED
typedef	__int16_t		int16_t;
#define	_INT16_T_DECLARED
#endif
# 42 "/usr/include/sys/_stdint.h" 3 4

#ifndef _INT32_T_DECLARED
typedef	__int32_t		int32_t;
#define	_INT32_T_DECLARED
#endif
# 47 "/usr/include/sys/_stdint.h" 3 4

#ifndef _INT64_T_DECLARED
typedef	__int64_t		int64_t;
#define	_INT64_T_DECLARED
#endif
# 52 "/usr/include/sys/_stdint.h" 3 4

#ifndef _UINT8_T_DECLARED
typedef	__uint8_t		uint8_t;
#define	_UINT8_T_DECLARED
#endif
# 57 "/usr/include/sys/_stdint.h" 3 4

#ifndef _UINT16_T_DECLARED
typedef	__uint16_t		uint16_t;
#define	_UINT16_T_DECLARED
#endif
# 62 "/usr/include/sys/_stdint.h" 3 4

#ifndef _UINT32_T_DECLARED
typedef	__uint32_t		uint32_t;
#define	_UINT32_T_DECLARED
#endif
# 67 "/usr/include/sys/_stdint.h" 3 4

#ifndef _UINT64_T_DECLARED
typedef	__uint64_t		uint64_t;
#define	_UINT64_T_DECLARED
#endif
# 72 "/usr/include/sys/_stdint.h" 3 4

#ifndef _INTPTR_T_DECLARED
typedef	__intptr_t		intptr_t;
#define	_INTPTR_T_DECLARED
#endif
# 77 "/usr/include/sys/_stdint.h" 3 4
#ifndef _UINTPTR_T_DECLARED
typedef	__uintptr_t		uintptr_t;
#define	_UINTPTR_T_DECLARED
#endif
# 81 "/usr/include/sys/_stdint.h" 3 4

#endif /* !_SYS__STDINT_H_ */
# 83 "/usr/include/sys/_stdint.h" 3 4
# 37 "/usr/include/stdint.h" 2 3 4

typedef	__int_least8_t		int_least8_t;
typedef	__int_least16_t		int_least16_t;
typedef	__int_least32_t		int_least32_t;
typedef	__int_least64_t		int_least64_t;

typedef	__uint_least8_t		uint_least8_t;
typedef	__uint_least16_t	uint_least16_t;
typedef	__uint_least32_t	uint_least32_t;
typedef	__uint_least64_t	uint_least64_t;

typedef	__int_fast8_t		int_fast8_t;
typedef	__int_fast16_t		int_fast16_t;
typedef	__int_fast32_t		int_fast32_t;
typedef	__int_fast64_t		int_fast64_t;

typedef	__uint_fast8_t		uint_fast8_t;
typedef	__uint_fast16_t		uint_fast16_t;
typedef	__uint_fast32_t		uint_fast32_t;
typedef	__uint_fast64_t		uint_fast64_t;

#ifndef _INTMAX_T_DECLARED
typedef	__intmax_t		intmax_t;
#define	_INTMAX_T_DECLARED
#endif
# 62 "/usr/include/stdint.h" 3 4
#ifndef _UINTMAX_T_DECLARED
typedef	__uintmax_t		uintmax_t;
#define	_UINTMAX_T_DECLARED
#endif
# 66 "/usr/include/stdint.h" 3 4

/* GNU and Darwin define this and people seem to think it's portable */
#if defined(UINTPTR_MAX) && defined(UINT64_MAX) && (UINTPTR_MAX == UINT64_MAX)
#define	__WORDSIZE		64
#else
# 71 "/usr/include/stdint.h" 3 4
#define	__WORDSIZE		32
#endif
# 73 "/usr/include/stdint.h" 3 4

/* Limits of wchar_t. */
#define	WCHAR_MIN	__WCHAR_MIN
#define	WCHAR_MAX	__WCHAR_MAX

#endif /* !_SYS_STDINT_H_ */
# 79 "/usr/include/stdint.h" 3 4
# 146 "/usr/include/c++/v1/cstdint" 2 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 149 "/usr/include/c++/v1/cstdint" 3
#endif
# 150 "/usr/include/c++/v1/cstdint" 3

_LIBCPP_BEGIN_NAMESPACE_STD

using::int8_t;
using::int16_t;
using::int32_t;
using::int64_t;

using::uint8_t;
using::uint16_t;
using::uint32_t;
using::uint64_t;

using::int_least8_t;
using::int_least16_t;
using::int_least32_t;
using::int_least64_t;

using::uint_least8_t;
using::uint_least16_t;
using::uint_least32_t;
using::uint_least64_t;

using::int_fast8_t;
using::int_fast16_t;
using::int_fast32_t;
using::int_fast64_t;

using::uint_fast8_t;
using::uint_fast16_t;
using::uint_fast32_t;
using::uint_fast64_t;

using::intptr_t;
using::uintptr_t;

using::intmax_t;
using::uintmax_t;

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_CSTDINT
# 192 "/usr/include/c++/v1/cstdint" 3
# 597 "/usr/include/c++/v1/memory" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <new>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/new" 1 3
// -*- C++ -*-
//===----------------------------- new ------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_NEW
#define _LIBCPP_NEW

/*
    new synopsis

namespace std
{

class bad_alloc
    : public exception
{
public:
    bad_alloc() noexcept;
    bad_alloc(const bad_alloc&) noexcept;
    bad_alloc& operator=(const bad_alloc&) noexcept;
    virtual const char* what() const noexcept;
};

class bad_array_length : public bad_alloc // C++14
{
public:
    bad_array_length() noexcept;
};

class bad_array_new_length : public bad_alloc
{
public:
    bad_array_new_length() noexcept;
};

struct nothrow_t {};
extern const nothrow_t nothrow;
typedef void (*new_handler)();
new_handler set_new_handler(new_handler new_p) noexcept;
new_handler get_new_handler() noexcept;

}  // std

void* operator new(std::size_t size);                                   // replaceable
void* operator new(std::size_t size, const std::nothrow_t&) noexcept;   // replaceable
void  operator delete(void* ptr) noexcept;                              // replaceable
void  operator delete(void* ptr, const std::nothrow_t&) noexcept;       // replaceable

void* operator new[](std::size_t size);                                 // replaceable
void* operator new[](std::size_t size, const std::nothrow_t&) noexcept; // replaceable
void  operator delete[](void* ptr) noexcept;                            // replaceable
void  operator delete[](void* ptr, const std::nothrow_t&) noexcept;     // replaceable

void* operator new  (std::size_t size, void* ptr) noexcept;
void* operator new[](std::size_t size, void* ptr) noexcept;
void  operator delete  (void* ptr, void*) noexcept;
void  operator delete[](void* ptr, void*) noexcept;

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 68 "/usr/include/c++/v1/new" 3
#if 0 /* expanded by -frewrite-includes */
#include <exception>
#endif /* expanded by -frewrite-includes */
# 69 "/usr/include/c++/v1/new" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 70 "/usr/include/c++/v1/new" 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 73 "/usr/include/c++/v1/new" 3
#endif
# 74 "/usr/include/c++/v1/new" 3

namespace std  // purposefully not using versioning namespace
{

class _LIBCPP_EXCEPTION_ABI bad_alloc
    : public exception
{
public:
    bad_alloc() _NOEXCEPT;
    virtual ~bad_alloc() _NOEXCEPT;
    virtual const char* what() const _NOEXCEPT;
};

class _LIBCPP_EXCEPTION_ABI bad_array_new_length
    : public bad_alloc
{
public:
    bad_array_new_length() _NOEXCEPT;
    virtual ~bad_array_new_length() _NOEXCEPT;
    virtual const char* what() const _NOEXCEPT;
};

#if defined(_LIBCPP_BUILDING_NEW) || (_LIBCPP_STD_VER > 11)

class _LIBCPP_EXCEPTION_ABI bad_array_length
    : public bad_alloc
{
public:
    bad_array_length() _NOEXCEPT;
    virtual ~bad_array_length() _NOEXCEPT;
    virtual const char* what() const _NOEXCEPT;
};

#define _LIBCPP_BAD_ARRAY_LENGTH_DEFINED

#endif  // defined(_LIBCPP_BUILDING_NEW) || (_LIBCPP_STD_VER > 11)
# 110 "/usr/include/c++/v1/new" 3

_LIBCPP_FUNC_VIS void __throw_bad_alloc();  // not in C++ spec

struct _LIBCPP_TYPE_VIS nothrow_t {};
extern _LIBCPP_FUNC_VIS const nothrow_t nothrow;
typedef void (*new_handler)();
_LIBCPP_FUNC_VIS new_handler set_new_handler(new_handler) _NOEXCEPT;
_LIBCPP_FUNC_VIS new_handler get_new_handler() _NOEXCEPT;

}  // std

#if defined(_WIN32) && !defined(cxx_EXPORTS)
# define _LIBCPP_NEW_DELETE_VIS _LIBCPP_FUNC_VIS_ONLY
#else
# 124 "/usr/include/c++/v1/new" 3
# define _LIBCPP_NEW_DELETE_VIS _LIBCPP_FUNC_VIS
#endif
# 126 "/usr/include/c++/v1/new" 3

_LIBCPP_NEW_DELETE_VIS void* operator new(std::size_t __sz)
#if !__has_feature(cxx_noexcept)
    throw(std::bad_alloc)
#endif
# 131 "/usr/include/c++/v1/new" 3
;
_LIBCPP_NEW_DELETE_VIS void* operator new(std::size_t __sz, const std::nothrow_t&) _NOEXCEPT _NOALIAS;
_LIBCPP_NEW_DELETE_VIS void  operator delete(void* __p) _NOEXCEPT;
_LIBCPP_NEW_DELETE_VIS void  operator delete(void* __p, const std::nothrow_t&) _NOEXCEPT;

_LIBCPP_NEW_DELETE_VIS void* operator new[](std::size_t __sz)
#if !__has_feature(cxx_noexcept)
    throw(std::bad_alloc)
#endif
# 140 "/usr/include/c++/v1/new" 3
;
_LIBCPP_NEW_DELETE_VIS void* operator new[](std::size_t __sz, const std::nothrow_t&) _NOEXCEPT _NOALIAS;
_LIBCPP_NEW_DELETE_VIS void  operator delete[](void* __p) _NOEXCEPT;
_LIBCPP_NEW_DELETE_VIS void  operator delete[](void* __p, const std::nothrow_t&) _NOEXCEPT;

inline _LIBCPP_INLINE_VISIBILITY void* operator new  (std::size_t, void* __p) _NOEXCEPT {return __p;}
inline _LIBCPP_INLINE_VISIBILITY void* operator new[](std::size_t, void* __p) _NOEXCEPT {return __p;}
inline _LIBCPP_INLINE_VISIBILITY void  operator delete  (void*, void*) _NOEXCEPT {}
inline _LIBCPP_INLINE_VISIBILITY void  operator delete[](void*, void*) _NOEXCEPT {}

#endif  // _LIBCPP_NEW
# 151 "/usr/include/c++/v1/new" 3
# 598 "/usr/include/c++/v1/memory" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 599 "/usr/include/c++/v1/memory" 3
#if 0 /* expanded by -frewrite-includes */
#include <limits>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/limits" 1 3
// -*- C++ -*-
//===---------------------------- limits ----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_LIMITS
#define _LIBCPP_LIMITS

/*
    limits synopsis

namespace std
{

template<class T>
class numeric_limits
{
public:
    static constexpr bool is_specialized = false;
    static constexpr T min() noexcept;
    static constexpr T max() noexcept;
    static constexpr T lowest() noexcept;

    static constexpr int  digits = 0;
    static constexpr int  digits10 = 0;
    static constexpr int  max_digits10 = 0;
    static constexpr bool is_signed = false;
    static constexpr bool is_integer = false;
    static constexpr bool is_exact = false;
    static constexpr int  radix = 0;
    static constexpr T epsilon() noexcept;
    static constexpr T round_error() noexcept;

    static constexpr int  min_exponent = 0;
    static constexpr int  min_exponent10 = 0;
    static constexpr int  max_exponent = 0;
    static constexpr int  max_exponent10 = 0;

    static constexpr bool has_infinity = false;
    static constexpr bool has_quiet_NaN = false;
    static constexpr bool has_signaling_NaN = false;
    static constexpr float_denorm_style has_denorm = denorm_absent;
    static constexpr bool has_denorm_loss = false;
    static constexpr T infinity() noexcept;
    static constexpr T quiet_NaN() noexcept;
    static constexpr T signaling_NaN() noexcept;
    static constexpr T denorm_min() noexcept;

    static constexpr bool is_iec559 = false;
    static constexpr bool is_bounded = false;
    static constexpr bool is_modulo = false;

    static constexpr bool traps = false;
    static constexpr bool tinyness_before = false;
    static constexpr float_round_style round_style = round_toward_zero;
};

enum float_round_style
{
    round_indeterminate       = -1,
    round_toward_zero         =  0,
    round_to_nearest          =  1,
    round_toward_infinity     =  2,
    round_toward_neg_infinity =  3
};

enum float_denorm_style
{
    denorm_indeterminate = -1,
    denorm_absent = 0,
    denorm_present = 1
};

template<> class numeric_limits<cv bool>;

template<> class numeric_limits<cv char>;
template<> class numeric_limits<cv signed char>;
template<> class numeric_limits<cv unsigned char>;
template<> class numeric_limits<cv wchar_t>;
template<> class numeric_limits<cv char16_t>;
template<> class numeric_limits<cv char32_t>;

template<> class numeric_limits<cv short>;
template<> class numeric_limits<cv int>;
template<> class numeric_limits<cv long>;
template<> class numeric_limits<cv long long>;
template<> class numeric_limits<cv unsigned short>;
template<> class numeric_limits<cv unsigned int>;
template<> class numeric_limits<cv unsigned long>;
template<> class numeric_limits<cv unsigned long long>;

template<> class numeric_limits<cv float>;
template<> class numeric_limits<cv double>;
template<> class numeric_limits<cv long double>;

}  // std

*/

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 107 "/usr/include/c++/v1/limits" 3
#endif
# 108 "/usr/include/c++/v1/limits" 3

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 110 "/usr/include/c++/v1/limits" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 111 "/usr/include/c++/v1/limits" 3

#if 0 /* expanded by -frewrite-includes */
#include <__undef_min_max>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/__undef_min_max" 1 3
// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifdef min
#if defined(_MSC_VER) && ! defined(__clang__)
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 16 "/usr/include/c++/v1/__undef_min_max" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 18 "/usr/include/c++/v1/__undef_min_max" 3
#undef min
#endif
# 20 "/usr/include/c++/v1/__undef_min_max" 3

#ifdef max
#if defined(_MSC_VER) && ! defined(__clang__)
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 26 "/usr/include/c++/v1/__undef_min_max" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 28 "/usr/include/c++/v1/__undef_min_max" 3
#undef max
#endif
# 30 "/usr/include/c++/v1/__undef_min_max" 3
# 113 "/usr/include/c++/v1/limits" 2 3

#if defined(_LIBCPP_MSVCRT)
#if 0 /* expanded by -frewrite-includes */
#include "support/win32/limits_win32.h"
#endif /* expanded by -frewrite-includes */
# 116 "/usr/include/c++/v1/limits" 3
#endif // _LIBCPP_MSVCRT
# 117 "/usr/include/c++/v1/limits" 3

#if defined(__IBMCPP__)
#if 0 /* expanded by -frewrite-includes */
#include "support/ibm/limits.h"
#endif /* expanded by -frewrite-includes */
# 120 "/usr/include/c++/v1/limits" 3
#endif // __IBMCPP__
# 121 "/usr/include/c++/v1/limits" 3

_LIBCPP_BEGIN_NAMESPACE_STD

enum float_round_style
{
    round_indeterminate       = -1,
    round_toward_zero         =  0,
    round_to_nearest          =  1,
    round_toward_infinity     =  2,
    round_toward_neg_infinity =  3
};

enum float_denorm_style
{
    denorm_indeterminate = -1,
    denorm_absent = 0,
    denorm_present = 1
};

template <class _Tp, bool = is_arithmetic<_Tp>::value>
class __libcpp_numeric_limits
{
protected:
    typedef _Tp type;

    static _LIBCPP_CONSTEXPR const  bool is_specialized = false;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type min() _NOEXCEPT {return type();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type max() _NOEXCEPT {return type();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type lowest() _NOEXCEPT {return type();}

    static _LIBCPP_CONSTEXPR const int  digits = 0;
    static _LIBCPP_CONSTEXPR const int  digits10 = 0;
    static _LIBCPP_CONSTEXPR const int  max_digits10 = 0;
    static _LIBCPP_CONSTEXPR const bool is_signed = false;
    static _LIBCPP_CONSTEXPR const bool is_integer = false;
    static _LIBCPP_CONSTEXPR const bool is_exact = false;
    static _LIBCPP_CONSTEXPR const int  radix = 0;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type epsilon() _NOEXCEPT {return type();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type round_error() _NOEXCEPT {return type();}

    static _LIBCPP_CONSTEXPR const int  min_exponent = 0;
    static _LIBCPP_CONSTEXPR const int  min_exponent10 = 0;
    static _LIBCPP_CONSTEXPR const int  max_exponent = 0;
    static _LIBCPP_CONSTEXPR const int  max_exponent10 = 0;

    static _LIBCPP_CONSTEXPR const bool has_infinity = false;
    static _LIBCPP_CONSTEXPR const bool has_quiet_NaN = false;
    static _LIBCPP_CONSTEXPR const bool has_signaling_NaN = false;
    static _LIBCPP_CONSTEXPR const float_denorm_style has_denorm = denorm_absent;
    static _LIBCPP_CONSTEXPR const bool has_denorm_loss = false;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type infinity() _NOEXCEPT {return type();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type quiet_NaN() _NOEXCEPT {return type();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type signaling_NaN() _NOEXCEPT {return type();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type denorm_min() _NOEXCEPT {return type();}

    static _LIBCPP_CONSTEXPR const bool is_iec559 = false;
    static _LIBCPP_CONSTEXPR const bool is_bounded = false;
    static _LIBCPP_CONSTEXPR const bool is_modulo = false;

    static _LIBCPP_CONSTEXPR const bool traps = false;
    static _LIBCPP_CONSTEXPR const bool tinyness_before = false;
    static _LIBCPP_CONSTEXPR const float_round_style round_style = round_toward_zero;
};

template <class _Tp, int digits, bool is_signed>
struct __libcpp_compute_min
{
    static _LIBCPP_CONSTEXPR const _Tp value = _Tp(_Tp(1) << digits);
};

template <class _Tp, int digits>
struct __libcpp_compute_min<_Tp, digits, false>
{
    static _LIBCPP_CONSTEXPR const _Tp value = _Tp(0);
};

template <class _Tp>
class __libcpp_numeric_limits<_Tp, true>
{
protected:
    typedef _Tp type;

    static _LIBCPP_CONSTEXPR const bool is_specialized = true;

    static _LIBCPP_CONSTEXPR const bool is_signed = type(-1) < type(0);
    static _LIBCPP_CONSTEXPR const int  digits = static_cast<int>(sizeof(type) * __CHAR_BIT__ - is_signed);
    static _LIBCPP_CONSTEXPR const int  digits10 = digits * 3 / 10;
    static _LIBCPP_CONSTEXPR const int  max_digits10 = 0;
    static _LIBCPP_CONSTEXPR const type __min = __libcpp_compute_min<type, digits, is_signed>::value;
    static _LIBCPP_CONSTEXPR const type __max = is_signed ? type(type(~0) ^ __min) : type(~0);
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type min() _NOEXCEPT {return __min;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type max() _NOEXCEPT {return __max;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type lowest() _NOEXCEPT {return min();}

    static _LIBCPP_CONSTEXPR const bool is_integer = true;
    static _LIBCPP_CONSTEXPR const bool is_exact = true;
    static _LIBCPP_CONSTEXPR const int  radix = 2;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type epsilon() _NOEXCEPT {return type(0);}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type round_error() _NOEXCEPT {return type(0);}

    static _LIBCPP_CONSTEXPR const int  min_exponent = 0;
    static _LIBCPP_CONSTEXPR const int  min_exponent10 = 0;
    static _LIBCPP_CONSTEXPR const int  max_exponent = 0;
    static _LIBCPP_CONSTEXPR const int  max_exponent10 = 0;

    static _LIBCPP_CONSTEXPR const bool has_infinity = false;
    static _LIBCPP_CONSTEXPR const bool has_quiet_NaN = false;
    static _LIBCPP_CONSTEXPR const bool has_signaling_NaN = false;
    static _LIBCPP_CONSTEXPR const float_denorm_style has_denorm = denorm_absent;
    static _LIBCPP_CONSTEXPR const bool has_denorm_loss = false;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type infinity() _NOEXCEPT {return type(0);}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type quiet_NaN() _NOEXCEPT {return type(0);}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type signaling_NaN() _NOEXCEPT {return type(0);}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type denorm_min() _NOEXCEPT {return type(0);}

    static _LIBCPP_CONSTEXPR const bool is_iec559 = false;
    static _LIBCPP_CONSTEXPR const bool is_bounded = true;
    static _LIBCPP_CONSTEXPR const bool is_modulo = true;

#if __i386__ || __x86_64__
    static _LIBCPP_CONSTEXPR const bool traps = true;
#else
# 243 "/usr/include/c++/v1/limits" 3
    static _LIBCPP_CONSTEXPR const bool traps = false;
#endif
# 245 "/usr/include/c++/v1/limits" 3
    static _LIBCPP_CONSTEXPR const bool tinyness_before = false;
    static _LIBCPP_CONSTEXPR const float_round_style round_style = round_toward_zero;
};

template <>
class __libcpp_numeric_limits<bool, true>
{
protected:
    typedef bool type;

    static _LIBCPP_CONSTEXPR const bool is_specialized = true;

    static _LIBCPP_CONSTEXPR const bool is_signed = false;
    static _LIBCPP_CONSTEXPR const int  digits = 1;
    static _LIBCPP_CONSTEXPR const int  digits10 = 0;
    static _LIBCPP_CONSTEXPR const int  max_digits10 = 0;
    static _LIBCPP_CONSTEXPR const type __min = false;
    static _LIBCPP_CONSTEXPR const type __max = true;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type min() _NOEXCEPT {return __min;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type max() _NOEXCEPT {return __max;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type lowest() _NOEXCEPT {return min();}

    static _LIBCPP_CONSTEXPR const bool is_integer = true;
    static _LIBCPP_CONSTEXPR const bool is_exact = true;
    static _LIBCPP_CONSTEXPR const int  radix = 2;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type epsilon() _NOEXCEPT {return type(0);}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type round_error() _NOEXCEPT {return type(0);}

    static _LIBCPP_CONSTEXPR const int  min_exponent = 0;
    static _LIBCPP_CONSTEXPR const int  min_exponent10 = 0;
    static _LIBCPP_CONSTEXPR const int  max_exponent = 0;
    static _LIBCPP_CONSTEXPR const int  max_exponent10 = 0;

    static _LIBCPP_CONSTEXPR const bool has_infinity = false;
    static _LIBCPP_CONSTEXPR const bool has_quiet_NaN = false;
    static _LIBCPP_CONSTEXPR const bool has_signaling_NaN = false;
    static _LIBCPP_CONSTEXPR const float_denorm_style has_denorm = denorm_absent;
    static _LIBCPP_CONSTEXPR const bool has_denorm_loss = false;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type infinity() _NOEXCEPT {return type(0);}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type quiet_NaN() _NOEXCEPT {return type(0);}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type signaling_NaN() _NOEXCEPT {return type(0);}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type denorm_min() _NOEXCEPT {return type(0);}

    static _LIBCPP_CONSTEXPR const bool is_iec559 = false;
    static _LIBCPP_CONSTEXPR const bool is_bounded = true;
    static _LIBCPP_CONSTEXPR const bool is_modulo = false;

    static _LIBCPP_CONSTEXPR const bool traps = false;
    static _LIBCPP_CONSTEXPR const bool tinyness_before = false;
    static _LIBCPP_CONSTEXPR const float_round_style round_style = round_toward_zero;
};

template <>
class __libcpp_numeric_limits<float, true>
{
protected:
    typedef float type;

    static _LIBCPP_CONSTEXPR const bool is_specialized = true;

    static _LIBCPP_CONSTEXPR const bool is_signed = true;
    static _LIBCPP_CONSTEXPR const int  digits = __FLT_MANT_DIG__;
    static _LIBCPP_CONSTEXPR const int  digits10 = __FLT_DIG__;
    static _LIBCPP_CONSTEXPR const int  max_digits10 = 2+(digits * 30103)/100000;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type min() _NOEXCEPT {return __FLT_MIN__;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type max() _NOEXCEPT {return __FLT_MAX__;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type lowest() _NOEXCEPT {return -max();}

    static _LIBCPP_CONSTEXPR const bool is_integer = false;
    static _LIBCPP_CONSTEXPR const bool is_exact = false;
    static _LIBCPP_CONSTEXPR const int  radix = __FLT_RADIX__;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type epsilon() _NOEXCEPT {return __FLT_EPSILON__;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type round_error() _NOEXCEPT {return 0.5F;}

    static _LIBCPP_CONSTEXPR const int  min_exponent = __FLT_MIN_EXP__;
    static _LIBCPP_CONSTEXPR const int  min_exponent10 = __FLT_MIN_10_EXP__;
    static _LIBCPP_CONSTEXPR const int  max_exponent = __FLT_MAX_EXP__;
    static _LIBCPP_CONSTEXPR const int  max_exponent10 = __FLT_MAX_10_EXP__;

    static _LIBCPP_CONSTEXPR const bool has_infinity = true;
    static _LIBCPP_CONSTEXPR const bool has_quiet_NaN = true;
    static _LIBCPP_CONSTEXPR const bool has_signaling_NaN = true;
    static _LIBCPP_CONSTEXPR const float_denorm_style has_denorm = denorm_present;
    static _LIBCPP_CONSTEXPR const bool has_denorm_loss = false;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type infinity() _NOEXCEPT {return __builtin_huge_valf();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type quiet_NaN() _NOEXCEPT {return __builtin_nanf("");}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type signaling_NaN() _NOEXCEPT {return __builtin_nansf("");}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type denorm_min() _NOEXCEPT {return __FLT_DENORM_MIN__;}

    static _LIBCPP_CONSTEXPR const bool is_iec559 = true;
    static _LIBCPP_CONSTEXPR const bool is_bounded = true;
    static _LIBCPP_CONSTEXPR const bool is_modulo = false;

    static _LIBCPP_CONSTEXPR const bool traps = false;
    static _LIBCPP_CONSTEXPR const bool tinyness_before = false;
    static _LIBCPP_CONSTEXPR const float_round_style round_style = round_to_nearest;
};

template <>
class __libcpp_numeric_limits<double, true>
{
protected:
    typedef double type;

    static _LIBCPP_CONSTEXPR const bool is_specialized = true;

    static _LIBCPP_CONSTEXPR const bool is_signed = true;
    static _LIBCPP_CONSTEXPR const int  digits = __DBL_MANT_DIG__;
    static _LIBCPP_CONSTEXPR const int  digits10 = __DBL_DIG__;
    static _LIBCPP_CONSTEXPR const int  max_digits10 = 2+(digits * 30103)/100000;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type min() _NOEXCEPT {return __DBL_MIN__;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type max() _NOEXCEPT {return __DBL_MAX__;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type lowest() _NOEXCEPT {return -max();}

    static _LIBCPP_CONSTEXPR const bool is_integer = false;
    static _LIBCPP_CONSTEXPR const bool is_exact = false;
    static _LIBCPP_CONSTEXPR const int  radix = __FLT_RADIX__;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type epsilon() _NOEXCEPT {return __DBL_EPSILON__;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type round_error() _NOEXCEPT {return 0.5;}

    static _LIBCPP_CONSTEXPR const int  min_exponent = __DBL_MIN_EXP__;
    static _LIBCPP_CONSTEXPR const int  min_exponent10 = __DBL_MIN_10_EXP__;
    static _LIBCPP_CONSTEXPR const int  max_exponent = __DBL_MAX_EXP__;
    static _LIBCPP_CONSTEXPR const int  max_exponent10 = __DBL_MAX_10_EXP__;

    static _LIBCPP_CONSTEXPR const bool has_infinity = true;
    static _LIBCPP_CONSTEXPR const bool has_quiet_NaN = true;
    static _LIBCPP_CONSTEXPR const bool has_signaling_NaN = true;
    static _LIBCPP_CONSTEXPR const float_denorm_style has_denorm = denorm_present;
    static _LIBCPP_CONSTEXPR const bool has_denorm_loss = false;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type infinity() _NOEXCEPT {return __builtin_huge_val();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type quiet_NaN() _NOEXCEPT {return __builtin_nan("");}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type signaling_NaN() _NOEXCEPT {return __builtin_nans("");}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type denorm_min() _NOEXCEPT {return __DBL_DENORM_MIN__;}

    static _LIBCPP_CONSTEXPR const bool is_iec559 = true;
    static _LIBCPP_CONSTEXPR const bool is_bounded = true;
    static _LIBCPP_CONSTEXPR const bool is_modulo = false;

    static _LIBCPP_CONSTEXPR const bool traps = false;
    static _LIBCPP_CONSTEXPR const bool tinyness_before = false;
    static _LIBCPP_CONSTEXPR const float_round_style round_style = round_to_nearest;
};

template <>
class __libcpp_numeric_limits<long double, true>
{
protected:
    typedef long double type;

    static _LIBCPP_CONSTEXPR const bool is_specialized = true;

    static _LIBCPP_CONSTEXPR const bool is_signed = true;
    static _LIBCPP_CONSTEXPR const int  digits = __LDBL_MANT_DIG__;
    static _LIBCPP_CONSTEXPR const int  digits10 = __LDBL_DIG__;
    static _LIBCPP_CONSTEXPR const int  max_digits10 = 2+(digits * 30103)/100000;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type min() _NOEXCEPT {return __LDBL_MIN__;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type max() _NOEXCEPT {return __LDBL_MAX__;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type lowest() _NOEXCEPT {return -max();}

    static _LIBCPP_CONSTEXPR const bool is_integer = false;
    static _LIBCPP_CONSTEXPR const bool is_exact = false;
    static _LIBCPP_CONSTEXPR const int  radix = __FLT_RADIX__;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type epsilon() _NOEXCEPT {return __LDBL_EPSILON__;}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type round_error() _NOEXCEPT {return 0.5;}

    static _LIBCPP_CONSTEXPR const int  min_exponent = __LDBL_MIN_EXP__;
    static _LIBCPP_CONSTEXPR const int  min_exponent10 = __LDBL_MIN_10_EXP__;
    static _LIBCPP_CONSTEXPR const int  max_exponent = __LDBL_MAX_EXP__;
    static _LIBCPP_CONSTEXPR const int  max_exponent10 = __LDBL_MAX_10_EXP__;

    static _LIBCPP_CONSTEXPR const bool has_infinity = true;
    static _LIBCPP_CONSTEXPR const bool has_quiet_NaN = true;
    static _LIBCPP_CONSTEXPR const bool has_signaling_NaN = true;
    static _LIBCPP_CONSTEXPR const float_denorm_style has_denorm = denorm_present;
    static _LIBCPP_CONSTEXPR const bool has_denorm_loss = false;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type infinity() _NOEXCEPT {return __builtin_huge_vall();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type quiet_NaN() _NOEXCEPT {return __builtin_nanl("");}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type signaling_NaN() _NOEXCEPT {return __builtin_nansl("");}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type denorm_min() _NOEXCEPT {return __LDBL_DENORM_MIN__;}

#if (defined(__ppc__) || defined(__ppc64__))
    static _LIBCPP_CONSTEXPR const bool is_iec559 = false;
#else
# 429 "/usr/include/c++/v1/limits" 3
    static _LIBCPP_CONSTEXPR const bool is_iec559 = true;
#endif
# 431 "/usr/include/c++/v1/limits" 3
    static _LIBCPP_CONSTEXPR const bool is_bounded = true;
    static _LIBCPP_CONSTEXPR const bool is_modulo = false;

    static _LIBCPP_CONSTEXPR const bool traps = false;
    static _LIBCPP_CONSTEXPR const bool tinyness_before = false;
    static _LIBCPP_CONSTEXPR const float_round_style round_style = round_to_nearest;
};

template <class _Tp>
class _LIBCPP_TYPE_VIS_ONLY numeric_limits
    : private __libcpp_numeric_limits<typename remove_cv<_Tp>::type>
{
    typedef __libcpp_numeric_limits<typename remove_cv<_Tp>::type> __base;
    typedef typename __base::type type;
public:
    static _LIBCPP_CONSTEXPR const bool is_specialized = __base::is_specialized;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type min() _NOEXCEPT {return __base::min();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type max() _NOEXCEPT {return __base::max();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type lowest() _NOEXCEPT {return __base::lowest();}

    static _LIBCPP_CONSTEXPR const int  digits = __base::digits;
    static _LIBCPP_CONSTEXPR const int  digits10 = __base::digits10;
    static _LIBCPP_CONSTEXPR const int  max_digits10 = __base::max_digits10;
    static _LIBCPP_CONSTEXPR const bool is_signed = __base::is_signed;
    static _LIBCPP_CONSTEXPR const bool is_integer = __base::is_integer;
    static _LIBCPP_CONSTEXPR const bool is_exact = __base::is_exact;
    static _LIBCPP_CONSTEXPR const int  radix = __base::radix;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type epsilon() _NOEXCEPT {return __base::epsilon();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type round_error() _NOEXCEPT {return __base::round_error();}

    static _LIBCPP_CONSTEXPR const int  min_exponent = __base::min_exponent;
    static _LIBCPP_CONSTEXPR const int  min_exponent10 = __base::min_exponent10;
    static _LIBCPP_CONSTEXPR const int  max_exponent = __base::max_exponent;
    static _LIBCPP_CONSTEXPR const int  max_exponent10 = __base::max_exponent10;

    static _LIBCPP_CONSTEXPR const bool has_infinity = __base::has_infinity;
    static _LIBCPP_CONSTEXPR const bool has_quiet_NaN = __base::has_quiet_NaN;
    static _LIBCPP_CONSTEXPR const bool has_signaling_NaN = __base::has_signaling_NaN;
    static _LIBCPP_CONSTEXPR const float_denorm_style has_denorm = __base::has_denorm;
    static _LIBCPP_CONSTEXPR const bool has_denorm_loss = __base::has_denorm_loss;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type infinity() _NOEXCEPT {return __base::infinity();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type quiet_NaN() _NOEXCEPT {return __base::quiet_NaN();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type signaling_NaN() _NOEXCEPT {return __base::signaling_NaN();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type denorm_min() _NOEXCEPT {return __base::denorm_min();}

    static _LIBCPP_CONSTEXPR const bool is_iec559 = __base::is_iec559;
    static _LIBCPP_CONSTEXPR const bool is_bounded = __base::is_bounded;
    static _LIBCPP_CONSTEXPR const bool is_modulo = __base::is_modulo;

    static _LIBCPP_CONSTEXPR const bool traps = __base::traps;
    static _LIBCPP_CONSTEXPR const bool tinyness_before = __base::tinyness_before;
    static _LIBCPP_CONSTEXPR const float_round_style round_style = __base::round_style;
};

template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::is_specialized;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<_Tp>::digits;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<_Tp>::digits10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<_Tp>::max_digits10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::is_signed;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::is_integer;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::is_exact;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<_Tp>::radix;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<_Tp>::min_exponent;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<_Tp>::min_exponent10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<_Tp>::max_exponent;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<_Tp>::max_exponent10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::has_infinity;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::has_quiet_NaN;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::has_signaling_NaN;
template <class _Tp>
    _LIBCPP_CONSTEXPR const float_denorm_style numeric_limits<_Tp>::has_denorm;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::has_denorm_loss;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::is_iec559;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::is_bounded;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::is_modulo;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::traps;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<_Tp>::tinyness_before;
template <class _Tp>
    _LIBCPP_CONSTEXPR const float_round_style numeric_limits<_Tp>::round_style;

template <class _Tp>
class _LIBCPP_TYPE_VIS_ONLY numeric_limits<const _Tp>
    : private numeric_limits<_Tp>
{
    typedef numeric_limits<_Tp> __base;
    typedef _Tp type;
public:
    static _LIBCPP_CONSTEXPR const bool is_specialized = __base::is_specialized;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type min() _NOEXCEPT {return __base::min();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type max() _NOEXCEPT {return __base::max();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type lowest() _NOEXCEPT {return __base::lowest();}

    static _LIBCPP_CONSTEXPR const int  digits = __base::digits;
    static _LIBCPP_CONSTEXPR const int  digits10 = __base::digits10;
    static _LIBCPP_CONSTEXPR const int  max_digits10 = __base::max_digits10;
    static _LIBCPP_CONSTEXPR const bool is_signed = __base::is_signed;
    static _LIBCPP_CONSTEXPR const bool is_integer = __base::is_integer;
    static _LIBCPP_CONSTEXPR const bool is_exact = __base::is_exact;
    static _LIBCPP_CONSTEXPR const int  radix = __base::radix;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type epsilon() _NOEXCEPT {return __base::epsilon();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type round_error() _NOEXCEPT {return __base::round_error();}

    static _LIBCPP_CONSTEXPR const int  min_exponent = __base::min_exponent;
    static _LIBCPP_CONSTEXPR const int  min_exponent10 = __base::min_exponent10;
    static _LIBCPP_CONSTEXPR const int  max_exponent = __base::max_exponent;
    static _LIBCPP_CONSTEXPR const int  max_exponent10 = __base::max_exponent10;

    static _LIBCPP_CONSTEXPR const bool has_infinity = __base::has_infinity;
    static _LIBCPP_CONSTEXPR const bool has_quiet_NaN = __base::has_quiet_NaN;
    static _LIBCPP_CONSTEXPR const bool has_signaling_NaN = __base::has_signaling_NaN;
    static _LIBCPP_CONSTEXPR const float_denorm_style has_denorm = __base::has_denorm;
    static _LIBCPP_CONSTEXPR const bool has_denorm_loss = __base::has_denorm_loss;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type infinity() _NOEXCEPT {return __base::infinity();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type quiet_NaN() _NOEXCEPT {return __base::quiet_NaN();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type signaling_NaN() _NOEXCEPT {return __base::signaling_NaN();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type denorm_min() _NOEXCEPT {return __base::denorm_min();}

    static _LIBCPP_CONSTEXPR const bool is_iec559 = __base::is_iec559;
    static _LIBCPP_CONSTEXPR const bool is_bounded = __base::is_bounded;
    static _LIBCPP_CONSTEXPR const bool is_modulo = __base::is_modulo;

    static _LIBCPP_CONSTEXPR const bool traps = __base::traps;
    static _LIBCPP_CONSTEXPR const bool tinyness_before = __base::tinyness_before;
    static _LIBCPP_CONSTEXPR const float_round_style round_style = __base::round_style;
};

template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::is_specialized;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const _Tp>::digits;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const _Tp>::digits10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const _Tp>::max_digits10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::is_signed;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::is_integer;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::is_exact;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const _Tp>::radix;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const _Tp>::min_exponent;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const _Tp>::min_exponent10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const _Tp>::max_exponent;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const _Tp>::max_exponent10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::has_infinity;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::has_quiet_NaN;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::has_signaling_NaN;
template <class _Tp>
    _LIBCPP_CONSTEXPR const float_denorm_style numeric_limits<const _Tp>::has_denorm;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::has_denorm_loss;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::is_iec559;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::is_bounded;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::is_modulo;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::traps;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const _Tp>::tinyness_before;
template <class _Tp>
    _LIBCPP_CONSTEXPR const float_round_style numeric_limits<const _Tp>::round_style;

template <class _Tp>
class _LIBCPP_TYPE_VIS_ONLY numeric_limits<volatile _Tp>
    : private numeric_limits<_Tp>
{
    typedef numeric_limits<_Tp> __base;
    typedef _Tp type;
public:
    static _LIBCPP_CONSTEXPR const bool is_specialized = __base::is_specialized;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type min() _NOEXCEPT {return __base::min();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type max() _NOEXCEPT {return __base::max();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type lowest() _NOEXCEPT {return __base::lowest();}

    static _LIBCPP_CONSTEXPR const int  digits = __base::digits;
    static _LIBCPP_CONSTEXPR const int  digits10 = __base::digits10;
    static _LIBCPP_CONSTEXPR const int  max_digits10 = __base::max_digits10;
    static _LIBCPP_CONSTEXPR const bool is_signed = __base::is_signed;
    static _LIBCPP_CONSTEXPR const bool is_integer = __base::is_integer;
    static _LIBCPP_CONSTEXPR const bool is_exact = __base::is_exact;
    static _LIBCPP_CONSTEXPR const int  radix = __base::radix;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type epsilon() _NOEXCEPT {return __base::epsilon();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type round_error() _NOEXCEPT {return __base::round_error();}

    static _LIBCPP_CONSTEXPR const int  min_exponent = __base::min_exponent;
    static _LIBCPP_CONSTEXPR const int  min_exponent10 = __base::min_exponent10;
    static _LIBCPP_CONSTEXPR const int  max_exponent = __base::max_exponent;
    static _LIBCPP_CONSTEXPR const int  max_exponent10 = __base::max_exponent10;

    static _LIBCPP_CONSTEXPR const bool has_infinity = __base::has_infinity;
    static _LIBCPP_CONSTEXPR const bool has_quiet_NaN = __base::has_quiet_NaN;
    static _LIBCPP_CONSTEXPR const bool has_signaling_NaN = __base::has_signaling_NaN;
    static _LIBCPP_CONSTEXPR const float_denorm_style has_denorm = __base::has_denorm;
    static _LIBCPP_CONSTEXPR const bool has_denorm_loss = __base::has_denorm_loss;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type infinity() _NOEXCEPT {return __base::infinity();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type quiet_NaN() _NOEXCEPT {return __base::quiet_NaN();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type signaling_NaN() _NOEXCEPT {return __base::signaling_NaN();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type denorm_min() _NOEXCEPT {return __base::denorm_min();}

    static _LIBCPP_CONSTEXPR const bool is_iec559 = __base::is_iec559;
    static _LIBCPP_CONSTEXPR const bool is_bounded = __base::is_bounded;
    static _LIBCPP_CONSTEXPR const bool is_modulo = __base::is_modulo;

    static _LIBCPP_CONSTEXPR const bool traps = __base::traps;
    static _LIBCPP_CONSTEXPR const bool tinyness_before = __base::tinyness_before;
    static _LIBCPP_CONSTEXPR const float_round_style round_style = __base::round_style;
};

template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::is_specialized;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<volatile _Tp>::digits;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<volatile _Tp>::digits10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<volatile _Tp>::max_digits10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::is_signed;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::is_integer;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::is_exact;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<volatile _Tp>::radix;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<volatile _Tp>::min_exponent;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<volatile _Tp>::min_exponent10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<volatile _Tp>::max_exponent;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<volatile _Tp>::max_exponent10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::has_infinity;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::has_quiet_NaN;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::has_signaling_NaN;
template <class _Tp>
    _LIBCPP_CONSTEXPR const float_denorm_style numeric_limits<volatile _Tp>::has_denorm;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::has_denorm_loss;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::is_iec559;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::is_bounded;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::is_modulo;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::traps;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<volatile _Tp>::tinyness_before;
template <class _Tp>
    _LIBCPP_CONSTEXPR const float_round_style numeric_limits<volatile _Tp>::round_style;

template <class _Tp>
class _LIBCPP_TYPE_VIS_ONLY numeric_limits<const volatile _Tp>
    : private numeric_limits<_Tp>
{
    typedef numeric_limits<_Tp> __base;
    typedef _Tp type;
public:
    static _LIBCPP_CONSTEXPR const bool is_specialized = __base::is_specialized;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type min() _NOEXCEPT {return __base::min();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type max() _NOEXCEPT {return __base::max();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type lowest() _NOEXCEPT {return __base::lowest();}

    static _LIBCPP_CONSTEXPR const int  digits = __base::digits;
    static _LIBCPP_CONSTEXPR const int  digits10 = __base::digits10;
    static _LIBCPP_CONSTEXPR const int  max_digits10 = __base::max_digits10;
    static _LIBCPP_CONSTEXPR const bool is_signed = __base::is_signed;
    static _LIBCPP_CONSTEXPR const bool is_integer = __base::is_integer;
    static _LIBCPP_CONSTEXPR const bool is_exact = __base::is_exact;
    static _LIBCPP_CONSTEXPR const int  radix = __base::radix;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type epsilon() _NOEXCEPT {return __base::epsilon();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type round_error() _NOEXCEPT {return __base::round_error();}

    static _LIBCPP_CONSTEXPR const int  min_exponent = __base::min_exponent;
    static _LIBCPP_CONSTEXPR const int  min_exponent10 = __base::min_exponent10;
    static _LIBCPP_CONSTEXPR const int  max_exponent = __base::max_exponent;
    static _LIBCPP_CONSTEXPR const int  max_exponent10 = __base::max_exponent10;

    static _LIBCPP_CONSTEXPR const bool has_infinity = __base::has_infinity;
    static _LIBCPP_CONSTEXPR const bool has_quiet_NaN = __base::has_quiet_NaN;
    static _LIBCPP_CONSTEXPR const bool has_signaling_NaN = __base::has_signaling_NaN;
    static _LIBCPP_CONSTEXPR const float_denorm_style has_denorm = __base::has_denorm;
    static _LIBCPP_CONSTEXPR const bool has_denorm_loss = __base::has_denorm_loss;
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type infinity() _NOEXCEPT {return __base::infinity();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type quiet_NaN() _NOEXCEPT {return __base::quiet_NaN();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type signaling_NaN() _NOEXCEPT {return __base::signaling_NaN();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR type denorm_min() _NOEXCEPT {return __base::denorm_min();}

    static _LIBCPP_CONSTEXPR const bool is_iec559 = __base::is_iec559;
    static _LIBCPP_CONSTEXPR const bool is_bounded = __base::is_bounded;
    static _LIBCPP_CONSTEXPR const bool is_modulo = __base::is_modulo;

    static _LIBCPP_CONSTEXPR const bool traps = __base::traps;
    static _LIBCPP_CONSTEXPR const bool tinyness_before = __base::tinyness_before;
    static _LIBCPP_CONSTEXPR const float_round_style round_style = __base::round_style;
};

template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::is_specialized;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const volatile _Tp>::digits;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const volatile _Tp>::digits10;
template <class _Tp>
    const int numeric_limits<const volatile _Tp>::max_digits10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::is_signed;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::is_integer;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::is_exact;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const volatile _Tp>::radix;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const volatile _Tp>::min_exponent;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const volatile _Tp>::min_exponent10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const volatile _Tp>::max_exponent;
template <class _Tp>
    _LIBCPP_CONSTEXPR const int numeric_limits<const volatile _Tp>::max_exponent10;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::has_infinity;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::has_quiet_NaN;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::has_signaling_NaN;
template <class _Tp>
    _LIBCPP_CONSTEXPR const float_denorm_style numeric_limits<const volatile _Tp>::has_denorm;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::has_denorm_loss;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::is_iec559;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::is_bounded;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::is_modulo;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::traps;
template <class _Tp>
    _LIBCPP_CONSTEXPR const bool numeric_limits<const volatile _Tp>::tinyness_before;
template <class _Tp>
    _LIBCPP_CONSTEXPR const float_round_style numeric_limits<const volatile _Tp>::round_style;

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_LIMITS
# 814 "/usr/include/c++/v1/limits" 3
# 600 "/usr/include/c++/v1/memory" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/iterator" 1 3
// -*- C++ -*-
//===-------------------------- iterator ----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_ITERATOR
#define _LIBCPP_ITERATOR

/*
    iterator synopsis

namespace std
{

template<class Iterator>
struct iterator_traits
{
    typedef typename Iterator::difference_type difference_type;
    typedef typename Iterator::value_type value_type;
    typedef typename Iterator::pointer pointer;
    typedef typename Iterator::reference reference;
    typedef typename Iterator::iterator_category iterator_category;
};

template<class T>
struct iterator_traits<T*>
{
    typedef ptrdiff_t difference_type;
    typedef T value_type;
    typedef T* pointer;
    typedef T& reference;
    typedef random_access_iterator_tag iterator_category;
};

template<class T>
struct iterator_traits<const T*>
{
    typedef ptrdiff_t difference_type;
    typedef T value_type;
    typedef const T* pointer;
    typedef const T& reference;
    typedef random_access_iterator_tag iterator_category;
};

template<class Category, class T, class Distance = ptrdiff_t,
         class Pointer = T*, class Reference = T&>
struct iterator
{
    typedef T         value_type;
    typedef Distance  difference_type;
    typedef Pointer   pointer;
    typedef Reference reference;
    typedef Category  iterator_category;
};

struct input_iterator_tag  {};
struct output_iterator_tag {};
struct forward_iterator_tag       : public input_iterator_tag         {};
struct bidirectional_iterator_tag : public forward_iterator_tag       {};
struct random_access_iterator_tag : public bidirectional_iterator_tag {};

// extension: second argument not conforming to C++03
template <class InputIterator>
void advance(InputIterator& i,
             typename iterator_traits<InputIterator>::difference_type n);

template <class InputIterator>
typename iterator_traits<InputIterator>::difference_type
distance(InputIterator first, InputIterator last);

template <class Iterator>
class reverse_iterator
    : public iterator<typename iterator_traits<Iterator>::iterator_category,
                      typename iterator_traits<Iterator>::value_type,
                      typename iterator_traits<Iterator>::difference_type,
                      typename iterator_traits<Iterator>::pointer,
                      typename iterator_traits<Iterator>::reference>
{
protected:
    Iterator current;
public:
    typedef Iterator                                            iterator_type;
    typedef typename iterator_traits<Iterator>::difference_type difference_type;
    typedef typename iterator_traits<Iterator>::reference       reference;
    typedef typename iterator_traits<Iterator>::pointer         pointer;

    reverse_iterator();
    explicit reverse_iterator(Iterator x);
    template <class U> reverse_iterator(const reverse_iterator<U>& u);
    Iterator base() const;
    reference operator*() const;
    pointer   operator->() const;
    reverse_iterator& operator++();
    reverse_iterator  operator++(int);
    reverse_iterator& operator--();
    reverse_iterator  operator--(int);
    reverse_iterator  operator+ (difference_type n) const;
    reverse_iterator& operator+=(difference_type n);
    reverse_iterator  operator- (difference_type n) const;
    reverse_iterator& operator-=(difference_type n);
    reference         operator[](difference_type n) const;
};

template <class Iterator1, class Iterator2>
bool
operator==(const reverse_iterator<Iterator1>& x, const reverse_iterator<Iterator2>& y);

template <class Iterator1, class Iterator2>
bool
operator<(const reverse_iterator<Iterator1>& x, const reverse_iterator<Iterator2>& y);

template <class Iterator1, class Iterator2>
bool
operator!=(const reverse_iterator<Iterator1>& x, const reverse_iterator<Iterator2>& y);

template <class Iterator1, class Iterator2>
bool
operator>(const reverse_iterator<Iterator1>& x, const reverse_iterator<Iterator2>& y);

template <class Iterator1, class Iterator2>
bool
operator>=(const reverse_iterator<Iterator1>& x, const reverse_iterator<Iterator2>& y);

template <class Iterator1, class Iterator2>
bool
operator<=(const reverse_iterator<Iterator1>& x, const reverse_iterator<Iterator2>& y);

template <class Iterator1, class Iterator2>
typename reverse_iterator<Iterator1>::difference_type
operator-(const reverse_iterator<Iterator1>& x, const reverse_iterator<Iterator2>& y);

template <class Iterator>
reverse_iterator<Iterator>
operator+(typename reverse_iterator<Iterator>::difference_type n, const reverse_iterator<Iterator>& x);

template <class Container>
class back_insert_iterator
{
protected:
    Container* container;
public:
    typedef Container                   container_type;
    typedef void                        value_type;
    typedef void                        difference_type;
    typedef back_insert_iterator<Cont>& reference;
    typedef void                        pointer;

    explicit back_insert_iterator(Container& x);
    back_insert_iterator& operator=(const typename Container::value_type& value);
    back_insert_iterator& operator*();
    back_insert_iterator& operator++();
    back_insert_iterator  operator++(int);
};

template <class Container> back_insert_iterator<Container> back_inserter(Container& x);

template <class Container>
class front_insert_iterator
{
protected:
    Container* container;
public:
    typedef Container                    container_type;
    typedef void                         value_type;
    typedef void                         difference_type;
    typedef front_insert_iterator<Cont>& reference;
    typedef void                         pointer;

    explicit front_insert_iterator(Container& x);
    front_insert_iterator& operator=(const typename Container::value_type& value);
    front_insert_iterator& operator*();
    front_insert_iterator& operator++();
    front_insert_iterator  operator++(int);
};

template <class Container> front_insert_iterator<Container> front_inserter(Container& x);

template <class Container>
class insert_iterator
{
protected:
    Container* container;
    typename Container::iterator iter;
public:
    typedef Container              container_type;
    typedef void                   value_type;
    typedef void                   difference_type;
    typedef insert_iterator<Cont>& reference;
    typedef void                   pointer;

    insert_iterator(Container& x, typename Container::iterator i);
    insert_iterator& operator=(const typename Container::value_type& value);
    insert_iterator& operator*();
    insert_iterator& operator++();
    insert_iterator& operator++(int);
};

template <class Container, class Iterator>
insert_iterator<Container> inserter(Container& x, Iterator i);

template <class T, class charT = char, class traits = char_traits<charT>, class Distance = ptrdiff_t>
class istream_iterator
    : public iterator<input_iterator_tag, T, Distance, const T*, const T&>
{
public:
    typedef charT char_type;
    typedef traits traits_type;
    typedef basic_istream<charT,traits> istream_type;

    istream_iterator();
    istream_iterator(istream_type& s);
    istream_iterator(const istream_iterator& x);
    ~istream_iterator();

    const T& operator*() const;
    const T* operator->() const;
    istream_iterator& operator++();
    istream_iterator  operator++(int);
};

template <class T, class charT, class traits, class Distance>
bool operator==(const istream_iterator<T,charT,traits,Distance>& x,
                const istream_iterator<T,charT,traits,Distance>& y);
template <class T, class charT, class traits, class Distance>
bool operator!=(const istream_iterator<T,charT,traits,Distance>& x,
                const istream_iterator<T,charT,traits,Distance>& y);

template <class T, class charT = char, class traits = char_traits<charT> >
class ostream_iterator
    : public iterator<output_iterator_tag, void, void, void ,void>
{
public:
    typedef charT char_type;
    typedef traits traits_type;
    typedef basic_ostream<charT,traits> ostream_type;

    ostream_iterator(ostream_type& s);
    ostream_iterator(ostream_type& s, const charT* delimiter);
    ostream_iterator(const ostream_iterator& x);
    ~ostream_iterator();
    ostream_iterator& operator=(const T& value);

    ostream_iterator& operator*();
    ostream_iterator& operator++();
    ostream_iterator& operator++(int);
};

template<class charT, class traits = char_traits<charT> >
class istreambuf_iterator
    : public iterator<input_iterator_tag, charT,
                      typename traits::off_type, unspecified,
                      charT>
{
public:
    typedef charT                         char_type;
    typedef traits                        traits_type;
    typedef typename traits::int_type     int_type;
    typedef basic_streambuf<charT,traits> streambuf_type;
    typedef basic_istream<charT,traits>   istream_type;

    istreambuf_iterator() noexcept;
    istreambuf_iterator(istream_type& s) noexcept;
    istreambuf_iterator(streambuf_type* s) noexcept;
    istreambuf_iterator(a-private-type) noexcept;

    charT                operator*() const;
    pointer operator->() const;
    istreambuf_iterator& operator++();
    a-private-type       operator++(int);

    bool equal(const istreambuf_iterator& b) const;
};

template <class charT, class traits>
bool operator==(const istreambuf_iterator<charT,traits>& a,
                const istreambuf_iterator<charT,traits>& b);
template <class charT, class traits>
bool operator!=(const istreambuf_iterator<charT,traits>& a,
                const istreambuf_iterator<charT,traits>& b);

template <class charT, class traits = char_traits<charT> >
class ostreambuf_iterator
    : public iterator<output_iterator_tag, void, void, void, void>
{
public:
    typedef charT                         char_type;
    typedef traits                        traits_type;
    typedef basic_streambuf<charT,traits> streambuf_type;
    typedef basic_ostream<charT,traits>   ostream_type;

    ostreambuf_iterator(ostream_type& s) noexcept;
    ostreambuf_iterator(streambuf_type* s) noexcept;
    ostreambuf_iterator& operator=(charT c);
    ostreambuf_iterator& operator*();
    ostreambuf_iterator& operator++();
    ostreambuf_iterator& operator++(int);
    bool failed() const noexcept;
};

template <class C> auto begin(C& c) -> decltype(c.begin());
template <class C> auto begin(const C& c) -> decltype(c.begin());
template <class C> auto end(C& c) -> decltype(c.end());
template <class C> auto end(const C& c) -> decltype(c.end());
template <class T, size_t N> T* begin(T (&array)[N]);
template <class T, size_t N> T* end(T (&array)[N]);

template <class C> auto cbegin(const C& c) -> decltype(std::begin(c));        // C++14
template <class C> auto cend(const C& c) -> decltype(std::end(c));            // C++14
template <class C> auto rbegin(C& c) -> decltype(c.rbegin());                 // C++14
template <class C> auto rbegin(const C& c) -> decltype(c.rbegin());           // C++14
template <class C> auto rend(C& c) -> decltype(c.rend());                     // C++14
template <class C> auto rend(const C& c) -> decltype(c.rend());               // C++14
template <class E> reverse_iterator<const E*> rbegin(initializer_list<E> il); // C++14
template <class E> reverse_iterator<const E*> rend(initializer_list<E> il);   // C++14
template <class T, size_t N> reverse_iterator<T*> rbegin(T (&array)[N]);      // C++14
template <class T, size_t N> reverse_iterator<T*> rend(T (&array)[N]);        // C++14
template <class C> auto crbegin(const C& c) -> decltype(std::rbegin(c));      // C++14
template <class C> auto crend(const C& c) -> decltype(std::rend(c));          // C++14

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 330 "/usr/include/c++/v1/iterator" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 331 "/usr/include/c++/v1/iterator" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 332 "/usr/include/c++/v1/iterator" 3
#if 0 /* expanded by -frewrite-includes */
#include <iosfwd>
#endif /* expanded by -frewrite-includes */
# 333 "/usr/include/c++/v1/iterator" 3
#if 0 /* expanded by -frewrite-includes */
#include <initializer_list>
#endif /* expanded by -frewrite-includes */
# 334 "/usr/include/c++/v1/iterator" 3
#ifdef __APPLE__
#if 0 /* expanded by -frewrite-includes */
#include <Availability.h>
#endif /* expanded by -frewrite-includes */
# 336 "/usr/include/c++/v1/iterator" 3
#endif
# 337 "/usr/include/c++/v1/iterator" 3

#ifdef _LIBCPP_DEBUG
#if 0 /* expanded by -frewrite-includes */
#   include <__debug>
#endif /* expanded by -frewrite-includes */
# 340 "/usr/include/c++/v1/iterator" 3
#else
# 341 "/usr/include/c++/v1/iterator" 3
#   define _LIBCPP_ASSERT(x, m) ((void)0)
#endif
# 343 "/usr/include/c++/v1/iterator" 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 346 "/usr/include/c++/v1/iterator" 3
#endif
# 347 "/usr/include/c++/v1/iterator" 3

_LIBCPP_BEGIN_NAMESPACE_STD

struct _LIBCPP_TYPE_VIS_ONLY input_iterator_tag {};
struct _LIBCPP_TYPE_VIS_ONLY output_iterator_tag {};
struct _LIBCPP_TYPE_VIS_ONLY forward_iterator_tag       : public input_iterator_tag {};
struct _LIBCPP_TYPE_VIS_ONLY bidirectional_iterator_tag : public forward_iterator_tag {};
struct _LIBCPP_TYPE_VIS_ONLY random_access_iterator_tag : public bidirectional_iterator_tag {};

template <class _Tp>
struct __has_iterator_category
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Up> static __two __test(...);
    template <class _Up> static char __test(typename _Up::iterator_category* = 0);
public:
    static const bool value = sizeof(__test<_Tp>(0)) == 1;
};

template <class _Iter, bool> struct ____iterator_traits {};

template <class _Iter>
struct ____iterator_traits<_Iter, true>
{
    typedef typename _Iter::difference_type   difference_type;
    typedef typename _Iter::value_type        value_type;
    typedef typename _Iter::pointer           pointer;
    typedef typename _Iter::reference         reference;
    typedef typename _Iter::iterator_category iterator_category;
};

template <class _Iter, bool> struct __iterator_traits {};

template <class _Iter>
struct __iterator_traits<_Iter, true>
    :  ____iterator_traits
      <
        _Iter,
        is_convertible<typename _Iter::iterator_category, input_iterator_tag>::value ||
        is_convertible<typename _Iter::iterator_category, output_iterator_tag>::value
      >
{};

// iterator_traits<Iterator> will only have the nested types if Iterator::iterator_category
//    exists.  Else iterator_traits<Iterator> will be an empty class.  This is a
//    conforming extension which allows some programs to compile and behave as
//    the client expects instead of failing at compile time.

template <class _Iter>
struct _LIBCPP_TYPE_VIS_ONLY iterator_traits
    : __iterator_traits<_Iter, __has_iterator_category<_Iter>::value> {};

template<class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY iterator_traits<_Tp*>
{
    typedef ptrdiff_t difference_type;
    typedef typename remove_const<_Tp>::type value_type;
    typedef _Tp* pointer;
    typedef _Tp& reference;
    typedef random_access_iterator_tag iterator_category;
};

template <class _Tp, class _Up, bool = __has_iterator_category<iterator_traits<_Tp> >::value>
struct __has_iterator_category_convertible_to
    : public integral_constant<bool, is_convertible<typename iterator_traits<_Tp>::iterator_category, _Up>::value>
{};

template <class _Tp, class _Up>
struct __has_iterator_category_convertible_to<_Tp, _Up, false> : public false_type {};

template <class _Tp>
struct __is_input_iterator : public __has_iterator_category_convertible_to<_Tp, input_iterator_tag> {};

template <class _Tp>
struct __is_forward_iterator : public __has_iterator_category_convertible_to<_Tp, forward_iterator_tag> {};

template <class _Tp>
struct __is_bidirectional_iterator : public __has_iterator_category_convertible_to<_Tp, bidirectional_iterator_tag> {};

template <class _Tp>
struct __is_random_access_iterator : public __has_iterator_category_convertible_to<_Tp, random_access_iterator_tag> {};

template<class _Category, class _Tp, class _Distance = ptrdiff_t,
         class _Pointer = _Tp*, class _Reference = _Tp&>
struct _LIBCPP_TYPE_VIS_ONLY iterator
{
    typedef _Tp        value_type;
    typedef _Distance  difference_type;
    typedef _Pointer   pointer;
    typedef _Reference reference;
    typedef _Category  iterator_category;
};

template <class _InputIter>
inline _LIBCPP_INLINE_VISIBILITY
void __advance(_InputIter& __i,
             typename iterator_traits<_InputIter>::difference_type __n, input_iterator_tag)
{
    for (; __n > 0; --__n)
        ++__i;
}

template <class _BiDirIter>
inline _LIBCPP_INLINE_VISIBILITY
void __advance(_BiDirIter& __i,
             typename iterator_traits<_BiDirIter>::difference_type __n, bidirectional_iterator_tag)
{
    if (__n >= 0)
        for (; __n > 0; --__n)
            ++__i;
    else
        for (; __n < 0; ++__n)
            --__i;
}

template <class _RandIter>
inline _LIBCPP_INLINE_VISIBILITY
void __advance(_RandIter& __i,
             typename iterator_traits<_RandIter>::difference_type __n, random_access_iterator_tag)
{
   __i += __n;
}

template <class _InputIter>
inline _LIBCPP_INLINE_VISIBILITY
void advance(_InputIter& __i,
             typename iterator_traits<_InputIter>::difference_type __n)
{
    __advance(__i, __n, typename iterator_traits<_InputIter>::iterator_category());
}

template <class _InputIter>
inline _LIBCPP_INLINE_VISIBILITY
typename iterator_traits<_InputIter>::difference_type
__distance(_InputIter __first, _InputIter __last, input_iterator_tag)
{
    typename iterator_traits<_InputIter>::difference_type __r(0);
    for (; __first != __last; ++__first)
        ++__r;
    return __r;
}

template <class _RandIter>
inline _LIBCPP_INLINE_VISIBILITY
typename iterator_traits<_RandIter>::difference_type
__distance(_RandIter __first, _RandIter __last, random_access_iterator_tag)
{
    return __last - __first;
}

template <class _InputIter>
inline _LIBCPP_INLINE_VISIBILITY
typename iterator_traits<_InputIter>::difference_type
distance(_InputIter __first, _InputIter __last)
{
    return __distance(__first, __last, typename iterator_traits<_InputIter>::iterator_category());
}

template <class _ForwardIter>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIter
next(_ForwardIter __x,
     typename iterator_traits<_ForwardIter>::difference_type __n = 1,
     typename enable_if<__is_forward_iterator<_ForwardIter>::value>::type* = 0)
{
    _VSTD::advance(__x, __n);
    return __x;
}

template <class _BidiretionalIter>
inline _LIBCPP_INLINE_VISIBILITY
_BidiretionalIter
prev(_BidiretionalIter __x,
     typename iterator_traits<_BidiretionalIter>::difference_type __n = 1,
     typename enable_if<__is_bidirectional_iterator<_BidiretionalIter>::value>::type* = 0)
{
    _VSTD::advance(__x, -__n);
    return __x;
}

template <class _Iter>
class _LIBCPP_TYPE_VIS_ONLY reverse_iterator
    : public iterator<typename iterator_traits<_Iter>::iterator_category,
                      typename iterator_traits<_Iter>::value_type,
                      typename iterator_traits<_Iter>::difference_type,
                      typename iterator_traits<_Iter>::pointer,
                      typename iterator_traits<_Iter>::reference>
{
private:
    mutable _Iter __t;
protected:
    _Iter current;
public:
    typedef _Iter                                            iterator_type;
    typedef typename iterator_traits<_Iter>::difference_type difference_type;
    typedef typename iterator_traits<_Iter>::reference       reference;
    typedef typename iterator_traits<_Iter>::pointer         pointer;

    _LIBCPP_INLINE_VISIBILITY reverse_iterator() : current() {}
    _LIBCPP_INLINE_VISIBILITY explicit reverse_iterator(_Iter __x) : __t(__x), current(__x) {}
    template <class _Up> _LIBCPP_INLINE_VISIBILITY reverse_iterator(const reverse_iterator<_Up>& __u)
        : __t(__u.base()), current(__u.base()) {}
    _LIBCPP_INLINE_VISIBILITY _Iter base() const {return current;}
    _LIBCPP_INLINE_VISIBILITY reference operator*() const {__t = current; return *--__t;}
    _LIBCPP_INLINE_VISIBILITY pointer  operator->() const {return &(operator*());}
    _LIBCPP_INLINE_VISIBILITY reverse_iterator& operator++() {--current; return *this;}
    _LIBCPP_INLINE_VISIBILITY reverse_iterator  operator++(int)
        {reverse_iterator __tmp(*this); --current; return __tmp;}
    _LIBCPP_INLINE_VISIBILITY reverse_iterator& operator--() {++current; return *this;}
    _LIBCPP_INLINE_VISIBILITY reverse_iterator  operator--(int)
        {reverse_iterator __tmp(*this); ++current; return __tmp;}
    _LIBCPP_INLINE_VISIBILITY reverse_iterator  operator+ (difference_type __n) const
        {return reverse_iterator(current - __n);}
    _LIBCPP_INLINE_VISIBILITY reverse_iterator& operator+=(difference_type __n)
        {current -= __n; return *this;}
    _LIBCPP_INLINE_VISIBILITY reverse_iterator  operator- (difference_type __n) const
        {return reverse_iterator(current + __n);}
    _LIBCPP_INLINE_VISIBILITY reverse_iterator& operator-=(difference_type __n)
        {current += __n; return *this;}
    _LIBCPP_INLINE_VISIBILITY reference         operator[](difference_type __n) const
        {return current[-__n-1];}
};

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const reverse_iterator<_Iter1>& __x, const reverse_iterator<_Iter2>& __y)
{
    return __x.base() == __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<(const reverse_iterator<_Iter1>& __x, const reverse_iterator<_Iter2>& __y)
{
    return __x.base() > __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const reverse_iterator<_Iter1>& __x, const reverse_iterator<_Iter2>& __y)
{
    return __x.base() != __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>(const reverse_iterator<_Iter1>& __x, const reverse_iterator<_Iter2>& __y)
{
    return __x.base() < __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const reverse_iterator<_Iter1>& __x, const reverse_iterator<_Iter2>& __y)
{
    return __x.base() <= __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const reverse_iterator<_Iter1>& __x, const reverse_iterator<_Iter2>& __y)
{
    return __x.base() >= __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
typename reverse_iterator<_Iter1>::difference_type
operator-(const reverse_iterator<_Iter1>& __x, const reverse_iterator<_Iter2>& __y)
{
    return __y.base() - __x.base();
}

template <class _Iter>
inline _LIBCPP_INLINE_VISIBILITY
reverse_iterator<_Iter>
operator+(typename reverse_iterator<_Iter>::difference_type __n, const reverse_iterator<_Iter>& __x)
{
    return reverse_iterator<_Iter>(__x.base() - __n);
}

template <class _Container>
class _LIBCPP_TYPE_VIS_ONLY back_insert_iterator
    : public iterator<output_iterator_tag,
                      void,
                      void,
                      void,
                      back_insert_iterator<_Container>&>
{
protected:
    _Container* container;
public:
    typedef _Container container_type;

    _LIBCPP_INLINE_VISIBILITY explicit back_insert_iterator(_Container& __x) : container(&__x) {}
    _LIBCPP_INLINE_VISIBILITY back_insert_iterator& operator=(const typename _Container::value_type& __value_)
        {container->push_back(__value_); return *this;}
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    _LIBCPP_INLINE_VISIBILITY back_insert_iterator& operator=(typename _Container::value_type&& __value_)
        {container->push_back(_VSTD::move(__value_)); return *this;}
#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 655 "/usr/include/c++/v1/iterator" 3
    _LIBCPP_INLINE_VISIBILITY back_insert_iterator& operator*()     {return *this;}
    _LIBCPP_INLINE_VISIBILITY back_insert_iterator& operator++()    {return *this;}
    _LIBCPP_INLINE_VISIBILITY back_insert_iterator  operator++(int) {return *this;}
};

template <class _Container>
inline _LIBCPP_INLINE_VISIBILITY
back_insert_iterator<_Container>
back_inserter(_Container& __x)
{
    return back_insert_iterator<_Container>(__x);
}

template <class _Container>
class _LIBCPP_TYPE_VIS_ONLY front_insert_iterator
    : public iterator<output_iterator_tag,
                      void,
                      void,
                      void,
                      front_insert_iterator<_Container>&>
{
protected:
    _Container* container;
public:
    typedef _Container container_type;

    _LIBCPP_INLINE_VISIBILITY explicit front_insert_iterator(_Container& __x) : container(&__x) {}
    _LIBCPP_INLINE_VISIBILITY front_insert_iterator& operator=(const typename _Container::value_type& __value_)
        {container->push_front(__value_); return *this;}
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    _LIBCPP_INLINE_VISIBILITY front_insert_iterator& operator=(typename _Container::value_type&& __value_)
        {container->push_front(_VSTD::move(__value_)); return *this;}
#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 688 "/usr/include/c++/v1/iterator" 3
    _LIBCPP_INLINE_VISIBILITY front_insert_iterator& operator*()     {return *this;}
    _LIBCPP_INLINE_VISIBILITY front_insert_iterator& operator++()    {return *this;}
    _LIBCPP_INLINE_VISIBILITY front_insert_iterator  operator++(int) {return *this;}
};

template <class _Container>
inline _LIBCPP_INLINE_VISIBILITY
front_insert_iterator<_Container>
front_inserter(_Container& __x)
{
    return front_insert_iterator<_Container>(__x);
}

template <class _Container>
class _LIBCPP_TYPE_VIS_ONLY insert_iterator
    : public iterator<output_iterator_tag,
                      void,
                      void,
                      void,
                      insert_iterator<_Container>&>
{
protected:
    _Container* container;
    typename _Container::iterator iter;
public:
    typedef _Container container_type;

    _LIBCPP_INLINE_VISIBILITY insert_iterator(_Container& __x, typename _Container::iterator __i)
        : container(&__x), iter(__i) {}
    _LIBCPP_INLINE_VISIBILITY insert_iterator& operator=(const typename _Container::value_type& __value_)
        {iter = container->insert(iter, __value_); ++iter; return *this;}
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    _LIBCPP_INLINE_VISIBILITY insert_iterator& operator=(typename _Container::value_type&& __value_)
        {iter = container->insert(iter, _VSTD::move(__value_)); ++iter; return *this;}
#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 723 "/usr/include/c++/v1/iterator" 3
    _LIBCPP_INLINE_VISIBILITY insert_iterator& operator*()        {return *this;}
    _LIBCPP_INLINE_VISIBILITY insert_iterator& operator++()       {return *this;}
    _LIBCPP_INLINE_VISIBILITY insert_iterator& operator++(int)    {return *this;}
};

template <class _Container>
inline _LIBCPP_INLINE_VISIBILITY
insert_iterator<_Container>
inserter(_Container& __x, typename _Container::iterator __i)
{
    return insert_iterator<_Container>(__x, __i);
}

template <class _Tp, class _CharT = char,
          class _Traits = char_traits<_CharT>, class _Distance = ptrdiff_t>
class _LIBCPP_TYPE_VIS_ONLY istream_iterator
    : public iterator<input_iterator_tag, _Tp, _Distance, const _Tp*, const _Tp&>
{
public:
    typedef _CharT char_type;
    typedef _Traits traits_type;
    typedef basic_istream<_CharT,_Traits> istream_type;
private:
    istream_type* __in_stream_;
    _Tp __value_;
public:
    _LIBCPP_INLINE_VISIBILITY istream_iterator() : __in_stream_(0) {}
    _LIBCPP_INLINE_VISIBILITY istream_iterator(istream_type& __s) : __in_stream_(&__s)
        {
            if (!(*__in_stream_ >> __value_))
                __in_stream_ = 0;
        }

    _LIBCPP_INLINE_VISIBILITY const _Tp& operator*() const {return __value_;}
    _LIBCPP_INLINE_VISIBILITY const _Tp* operator->() const {return &(operator*());}
    _LIBCPP_INLINE_VISIBILITY istream_iterator& operator++()
        {
            if (!(*__in_stream_ >> __value_))
                __in_stream_ = 0;
            return *this;
        }
    _LIBCPP_INLINE_VISIBILITY istream_iterator  operator++(int)
        {istream_iterator __t(*this); ++(*this); return __t;}

    friend _LIBCPP_INLINE_VISIBILITY
    bool operator==(const istream_iterator& __x, const istream_iterator& __y)
        {return __x.__in_stream_ == __y.__in_stream_;}

    friend _LIBCPP_INLINE_VISIBILITY
    bool operator!=(const istream_iterator& __x, const istream_iterator& __y)
        {return !(__x == __y);}
};

template <class _Tp, class _CharT = char, class _Traits = char_traits<_CharT> >
class _LIBCPP_TYPE_VIS_ONLY ostream_iterator
    : public iterator<output_iterator_tag, void, void, void, void>
{
public:
    typedef _CharT char_type;
    typedef _Traits traits_type;
    typedef basic_ostream<_CharT,_Traits> ostream_type;
private:
    ostream_type* __out_stream_;
    const char_type* __delim_;
public:
    _LIBCPP_INLINE_VISIBILITY ostream_iterator(ostream_type& __s)
        : __out_stream_(&__s), __delim_(0) {}
    _LIBCPP_INLINE_VISIBILITY ostream_iterator(ostream_type& __s, const _CharT* __delimiter)
        : __out_stream_(&__s), __delim_(__delimiter) {}
    _LIBCPP_INLINE_VISIBILITY ostream_iterator& operator=(const _Tp& __value_)
        {
            *__out_stream_ << __value_;
            if (__delim_)
                *__out_stream_ << __delim_;
            return *this;
        }

    _LIBCPP_INLINE_VISIBILITY ostream_iterator& operator*()     {return *this;}
    _LIBCPP_INLINE_VISIBILITY ostream_iterator& operator++()    {return *this;}
    _LIBCPP_INLINE_VISIBILITY ostream_iterator& operator++(int) {return *this;}
};

template<class _CharT, class _Traits>
class _LIBCPP_TYPE_VIS_ONLY istreambuf_iterator
    : public iterator<input_iterator_tag, _CharT,
                      typename _Traits::off_type, _CharT*,
                      _CharT>
{
public:
    typedef _CharT                          char_type;
    typedef _Traits                         traits_type;
    typedef typename _Traits::int_type      int_type;
    typedef basic_streambuf<_CharT,_Traits> streambuf_type;
    typedef basic_istream<_CharT,_Traits>   istream_type;
private:
    mutable streambuf_type* __sbuf_;

    class __proxy
    {
        char_type __keep_;
        streambuf_type* __sbuf_;
        _LIBCPP_INLINE_VISIBILITY __proxy(char_type __c, streambuf_type* __s)
            : __keep_(__c), __sbuf_(__s) {}
        friend class istreambuf_iterator;
    public:
        _LIBCPP_INLINE_VISIBILITY char_type operator*() const {return __keep_;}
    };

    _LIBCPP_INLINE_VISIBILITY
    bool __test_for_eof() const
    {
        if (__sbuf_ && traits_type::eq_int_type(__sbuf_->sgetc(), traits_type::eof()))
            __sbuf_ = 0;
        return __sbuf_ == 0;
    }
public:
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR istreambuf_iterator() _NOEXCEPT : __sbuf_(0) {}
    _LIBCPP_INLINE_VISIBILITY istreambuf_iterator(istream_type& __s) _NOEXCEPT
        : __sbuf_(__s.rdbuf()) {}
    _LIBCPP_INLINE_VISIBILITY istreambuf_iterator(streambuf_type* __s) _NOEXCEPT
        : __sbuf_(__s) {}
    _LIBCPP_INLINE_VISIBILITY istreambuf_iterator(const __proxy& __p) _NOEXCEPT
        : __sbuf_(__p.__sbuf_) {}

    _LIBCPP_INLINE_VISIBILITY char_type  operator*() const
        {return static_cast<char_type>(__sbuf_->sgetc());}
    _LIBCPP_INLINE_VISIBILITY char_type* operator->() const {return nullptr;}
    _LIBCPP_INLINE_VISIBILITY istreambuf_iterator& operator++()
        {
            __sbuf_->sbumpc();
            return *this;
        }
    _LIBCPP_INLINE_VISIBILITY __proxy              operator++(int)
        {
            return __proxy(__sbuf_->sbumpc(), __sbuf_);
        }

    _LIBCPP_INLINE_VISIBILITY bool equal(const istreambuf_iterator& __b) const
        {return __test_for_eof() == __b.__test_for_eof();}
};

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
bool operator==(const istreambuf_iterator<_CharT,_Traits>& __a,
                const istreambuf_iterator<_CharT,_Traits>& __b)
                {return __a.equal(__b);}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
bool operator!=(const istreambuf_iterator<_CharT,_Traits>& __a,
                const istreambuf_iterator<_CharT,_Traits>& __b)
                {return !__a.equal(__b);}

template <class _CharT, class _Traits>
class _LIBCPP_TYPE_VIS_ONLY ostreambuf_iterator
    : public iterator<output_iterator_tag, void, void, void, void>
{
public:
    typedef _CharT                          char_type;
    typedef _Traits                         traits_type;
    typedef basic_streambuf<_CharT,_Traits> streambuf_type;
    typedef basic_ostream<_CharT,_Traits>   ostream_type;
private:
    streambuf_type* __sbuf_;
public:
    _LIBCPP_INLINE_VISIBILITY ostreambuf_iterator(ostream_type& __s) _NOEXCEPT
        : __sbuf_(__s.rdbuf()) {}
    _LIBCPP_INLINE_VISIBILITY ostreambuf_iterator(streambuf_type* __s) _NOEXCEPT
        : __sbuf_(__s) {}
    _LIBCPP_INLINE_VISIBILITY ostreambuf_iterator& operator=(_CharT __c)
        {
            if (__sbuf_ && traits_type::eq_int_type(__sbuf_->sputc(__c), traits_type::eof()))
                __sbuf_ = 0;
            return *this;
        }
    _LIBCPP_INLINE_VISIBILITY ostreambuf_iterator& operator*()     {return *this;}
    _LIBCPP_INLINE_VISIBILITY ostreambuf_iterator& operator++()    {return *this;}
    _LIBCPP_INLINE_VISIBILITY ostreambuf_iterator& operator++(int) {return *this;}
    _LIBCPP_INLINE_VISIBILITY bool failed() const _NOEXCEPT {return __sbuf_ == 0;}

#if !defined(__APPLE__) || \
    (defined(__MAC_OS_X_VERSION_MIN_REQUIRED) && __MAC_OS_X_VERSION_MIN_REQUIRED > __MAC_10_8) || \
    (defined(__IPHONE_OS_VERSION_MIN_REQUIRED) && __IPHONE_OS_VERSION_MIN_REQUIRED > __IPHONE_6_0)

    template <class _Ch, class _Tr>
    friend
    _LIBCPP_HIDDEN
    ostreambuf_iterator<_Ch, _Tr>
    __pad_and_output(ostreambuf_iterator<_Ch, _Tr> __s,
                     const _Ch* __ob, const _Ch* __op, const _Ch* __oe,
                     ios_base& __iob, _Ch __fl);
#endif
# 915 "/usr/include/c++/v1/iterator" 3
};

template <class _Iter>
class _LIBCPP_TYPE_VIS_ONLY move_iterator
{
private:
    _Iter __i;
public:
    typedef _Iter                                            iterator_type;
    typedef typename iterator_traits<iterator_type>::iterator_category iterator_category;
    typedef typename iterator_traits<iterator_type>::value_type value_type;
    typedef typename iterator_traits<iterator_type>::difference_type difference_type;
    typedef typename iterator_traits<iterator_type>::pointer pointer;
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    typedef value_type&& reference;
#else
# 931 "/usr/include/c++/v1/iterator" 3
    typedef typename iterator_traits<iterator_type>::reference reference;
#endif
# 933 "/usr/include/c++/v1/iterator" 3

    _LIBCPP_INLINE_VISIBILITY move_iterator() : __i() {}
    _LIBCPP_INLINE_VISIBILITY explicit move_iterator(_Iter __x) : __i(__x) {}
    template <class _Up> _LIBCPP_INLINE_VISIBILITY move_iterator(const move_iterator<_Up>& __u)
        : __i(__u.base()) {}
    _LIBCPP_INLINE_VISIBILITY _Iter base() const {return __i;}
    _LIBCPP_INLINE_VISIBILITY reference operator*() const {
      return static_cast<reference>(*__i);
    }
    _LIBCPP_INLINE_VISIBILITY pointer  operator->() const {
      typename iterator_traits<iterator_type>::reference __ref = *__i;
      return &__ref;
    }
    _LIBCPP_INLINE_VISIBILITY move_iterator& operator++() {++__i; return *this;}
    _LIBCPP_INLINE_VISIBILITY move_iterator  operator++(int)
        {move_iterator __tmp(*this); ++__i; return __tmp;}
    _LIBCPP_INLINE_VISIBILITY move_iterator& operator--() {--__i; return *this;}
    _LIBCPP_INLINE_VISIBILITY move_iterator  operator--(int)
        {move_iterator __tmp(*this); --__i; return __tmp;}
    _LIBCPP_INLINE_VISIBILITY move_iterator  operator+ (difference_type __n) const
        {return move_iterator(__i + __n);}
    _LIBCPP_INLINE_VISIBILITY move_iterator& operator+=(difference_type __n)
        {__i += __n; return *this;}
    _LIBCPP_INLINE_VISIBILITY move_iterator  operator- (difference_type __n) const
        {return move_iterator(__i - __n);}
    _LIBCPP_INLINE_VISIBILITY move_iterator& operator-=(difference_type __n)
        {__i -= __n; return *this;}
    _LIBCPP_INLINE_VISIBILITY reference         operator[](difference_type __n) const
    {
      return static_cast<reference>(__i[__n]);
    }
};

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const move_iterator<_Iter1>& __x, const move_iterator<_Iter2>& __y)
{
    return __x.base() == __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<(const move_iterator<_Iter1>& __x, const move_iterator<_Iter2>& __y)
{
    return __x.base() < __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const move_iterator<_Iter1>& __x, const move_iterator<_Iter2>& __y)
{
    return __x.base() != __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>(const move_iterator<_Iter1>& __x, const move_iterator<_Iter2>& __y)
{
    return __x.base() > __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const move_iterator<_Iter1>& __x, const move_iterator<_Iter2>& __y)
{
    return __x.base() >= __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const move_iterator<_Iter1>& __x, const move_iterator<_Iter2>& __y)
{
    return __x.base() <= __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
typename move_iterator<_Iter1>::difference_type
operator-(const move_iterator<_Iter1>& __x, const move_iterator<_Iter2>& __y)
{
    return __x.base() - __y.base();
}

template <class _Iter>
inline _LIBCPP_INLINE_VISIBILITY
move_iterator<_Iter>
operator+(typename move_iterator<_Iter>::difference_type __n, const move_iterator<_Iter>& __x)
{
    return move_iterator<_Iter>(__x.base() + __n);
}

template <class _Iter>
inline _LIBCPP_INLINE_VISIBILITY
move_iterator<_Iter>
make_move_iterator(_Iter __i)
{
    return move_iterator<_Iter>(__i);
}

// __wrap_iter

template <class _Iter> class __wrap_iter;

template <class _Iter1, class _Iter2>
_LIBCPP_INLINE_VISIBILITY
bool
operator==(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

template <class _Iter1, class _Iter2>
_LIBCPP_INLINE_VISIBILITY
bool
operator<(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

template <class _Iter1, class _Iter2>
_LIBCPP_INLINE_VISIBILITY
bool
operator!=(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

template <class _Iter1, class _Iter2>
_LIBCPP_INLINE_VISIBILITY
bool
operator>(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

template <class _Iter1, class _Iter2>
_LIBCPP_INLINE_VISIBILITY
bool
operator>=(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

template <class _Iter1, class _Iter2>
_LIBCPP_INLINE_VISIBILITY
bool
operator<=(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

template <class _Iter1, class _Iter2>
_LIBCPP_INLINE_VISIBILITY
typename __wrap_iter<_Iter1>::difference_type
operator-(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

template <class _Iter>
_LIBCPP_INLINE_VISIBILITY
__wrap_iter<_Iter>
operator+(typename __wrap_iter<_Iter>::difference_type, __wrap_iter<_Iter>) _NOEXCEPT;

template <class _Ip, class _Op> _Op _LIBCPP_INLINE_VISIBILITY copy(_Ip, _Ip, _Op);
template <class _B1, class _B2> _B2 _LIBCPP_INLINE_VISIBILITY copy_backward(_B1, _B1, _B2);
template <class _Ip, class _Op> _Op _LIBCPP_INLINE_VISIBILITY move(_Ip, _Ip, _Op);
template <class _B1, class _B2> _B2 _LIBCPP_INLINE_VISIBILITY move_backward(_B1, _B1, _B2);

template <class _Tp>
_LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_trivially_copy_assignable<_Tp>::value,
    _Tp*
>::type
__unwrap_iter(__wrap_iter<_Tp*>);

template <class _Iter>
class __wrap_iter
{
public:
    typedef _Iter                                                      iterator_type;
    typedef typename iterator_traits<iterator_type>::iterator_category iterator_category;
    typedef typename iterator_traits<iterator_type>::value_type        value_type;
    typedef typename iterator_traits<iterator_type>::difference_type   difference_type;
    typedef typename iterator_traits<iterator_type>::pointer           pointer;
    typedef typename iterator_traits<iterator_type>::reference         reference;
private:
    iterator_type __i;
public:
    _LIBCPP_INLINE_VISIBILITY __wrap_iter() _NOEXCEPT
#if _LIBCPP_STD_VER > 11
                : __i{}
#endif
# 1113 "/usr/include/c++/v1/iterator" 3
    {
#if _LIBCPP_DEBUG_LEVEL >= 2
        __get_db()->__insert_i(this);
#endif
# 1117 "/usr/include/c++/v1/iterator" 3
    }
    template <class _Up> _LIBCPP_INLINE_VISIBILITY __wrap_iter(const __wrap_iter<_Up>& __u,
        typename enable_if<is_convertible<_Up, iterator_type>::value>::type* = 0) _NOEXCEPT
        : __i(__u.base())
    {
#if _LIBCPP_DEBUG_LEVEL >= 2
        __get_db()->__iterator_copy(this, &__u);
#endif
# 1125 "/usr/include/c++/v1/iterator" 3
    }
#if _LIBCPP_DEBUG_LEVEL >= 2
    _LIBCPP_INLINE_VISIBILITY
    __wrap_iter(const __wrap_iter& __x)
        : __i(__x.base())
    {
        __get_db()->__iterator_copy(this, &__x);
    }
    _LIBCPP_INLINE_VISIBILITY
    __wrap_iter& operator=(const __wrap_iter& __x)
    {
        if (this != &__x)
        {
            __get_db()->__iterator_copy(this, &__x);
            __i = __x.__i;
        }
        return *this;
    }
    _LIBCPP_INLINE_VISIBILITY
    ~__wrap_iter()
    {
        __get_db()->__erase_i(this);
    }
#endif
# 1149 "/usr/include/c++/v1/iterator" 3
    _LIBCPP_INLINE_VISIBILITY reference operator*() const _NOEXCEPT
    {
#if _LIBCPP_DEBUG_LEVEL >= 2
        _LIBCPP_ASSERT(__get_const_db()->__dereferenceable(this),
                       "Attempted to dereference a non-dereferenceable iterator");
#endif
# 1155 "/usr/include/c++/v1/iterator" 3
        return *__i;
    }
    _LIBCPP_INLINE_VISIBILITY pointer  operator->() const _NOEXCEPT
    {
#if _LIBCPP_DEBUG_LEVEL >= 2
        _LIBCPP_ASSERT(__get_const_db()->__dereferenceable(this),
                       "Attempted to dereference a non-dereferenceable iterator");
#endif
# 1163 "/usr/include/c++/v1/iterator" 3
        return (pointer)&reinterpret_cast<const volatile char&>(*__i);
    }
    _LIBCPP_INLINE_VISIBILITY __wrap_iter& operator++() _NOEXCEPT
    {
#if _LIBCPP_DEBUG_LEVEL >= 2
        _LIBCPP_ASSERT(__get_const_db()->__dereferenceable(this),
                       "Attempted to increment non-incrementable iterator");
#endif
# 1171 "/usr/include/c++/v1/iterator" 3
        ++__i;
        return *this;
    }
    _LIBCPP_INLINE_VISIBILITY __wrap_iter  operator++(int) _NOEXCEPT
        {__wrap_iter __tmp(*this); ++(*this); return __tmp;}
    _LIBCPP_INLINE_VISIBILITY __wrap_iter& operator--() _NOEXCEPT
    {
#if _LIBCPP_DEBUG_LEVEL >= 2
        _LIBCPP_ASSERT(__get_const_db()->__decrementable(this),
                       "Attempted to decrement non-decrementable iterator");
#endif
# 1182 "/usr/include/c++/v1/iterator" 3
        --__i;
        return *this;
    }
    _LIBCPP_INLINE_VISIBILITY __wrap_iter  operator--(int) _NOEXCEPT
        {__wrap_iter __tmp(*this); --(*this); return __tmp;}
    _LIBCPP_INLINE_VISIBILITY __wrap_iter  operator+ (difference_type __n) const _NOEXCEPT
        {__wrap_iter __w(*this); __w += __n; return __w;}
    _LIBCPP_INLINE_VISIBILITY __wrap_iter& operator+=(difference_type __n) _NOEXCEPT
    {
#if _LIBCPP_DEBUG_LEVEL >= 2
        _LIBCPP_ASSERT(__get_const_db()->__addable(this, __n),
                   "Attempted to add/subtract iterator outside of valid range");
#endif
# 1195 "/usr/include/c++/v1/iterator" 3
        __i += __n;
        return *this;
    }
    _LIBCPP_INLINE_VISIBILITY __wrap_iter  operator- (difference_type __n) const _NOEXCEPT
        {return *this + (-__n);}
    _LIBCPP_INLINE_VISIBILITY __wrap_iter& operator-=(difference_type __n) _NOEXCEPT
        {*this += -__n; return *this;}
    _LIBCPP_INLINE_VISIBILITY reference        operator[](difference_type __n) const _NOEXCEPT
    {
#if _LIBCPP_DEBUG_LEVEL >= 2
        _LIBCPP_ASSERT(__get_const_db()->__subscriptable(this, __n),
                   "Attempted to subscript iterator outside of valid range");
#endif
# 1208 "/usr/include/c++/v1/iterator" 3
        return __i[__n];
    }

    _LIBCPP_INLINE_VISIBILITY iterator_type base() const _NOEXCEPT {return __i;}

private:
#if _LIBCPP_DEBUG_LEVEL >= 2
    _LIBCPP_INLINE_VISIBILITY __wrap_iter(const void* __p, iterator_type __x) : __i(__x)
    {
        __get_db()->__insert_ic(this, __p);
    }
#else
# 1220 "/usr/include/c++/v1/iterator" 3
    _LIBCPP_INLINE_VISIBILITY __wrap_iter(iterator_type __x) _NOEXCEPT : __i(__x) {}
#endif
# 1222 "/usr/include/c++/v1/iterator" 3

    template <class _Up> friend class __wrap_iter;
    template <class _CharT, class _Traits, class _Alloc> friend class basic_string;
    template <class _Tp, class _Alloc> friend class vector;

    template <class _Iter1, class _Iter2>
    friend
    bool
    operator==(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

    template <class _Iter1, class _Iter2>
    friend
    bool
    operator<(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

    template <class _Iter1, class _Iter2>
    friend
    bool
    operator!=(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

    template <class _Iter1, class _Iter2>
    friend
    bool
    operator>(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

    template <class _Iter1, class _Iter2>
    friend
    bool
    operator>=(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

    template <class _Iter1, class _Iter2>
    friend
    bool
    operator<=(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

    template <class _Iter1, class _Iter2>
    friend
    typename __wrap_iter<_Iter1>::difference_type
    operator-(const __wrap_iter<_Iter1>&, const __wrap_iter<_Iter2>&) _NOEXCEPT;

    template <class _Iter1>
    friend
    __wrap_iter<_Iter1>
    operator+(typename __wrap_iter<_Iter1>::difference_type, __wrap_iter<_Iter1>) _NOEXCEPT;

    template <class _Ip, class _Op> friend _Op copy(_Ip, _Ip, _Op);
    template <class _B1, class _B2> friend _B2 copy_backward(_B1, _B1, _B2);
    template <class _Ip, class _Op> friend _Op move(_Ip, _Ip, _Op);
    template <class _B1, class _B2> friend _B2 move_backward(_B1, _B1, _B2);

    template <class _Tp>
    friend
    typename enable_if
    <
        is_trivially_copy_assignable<_Tp>::value,
        _Tp*
    >::type
    __unwrap_iter(__wrap_iter<_Tp*>);
};

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter2>& __y) _NOEXCEPT
{
    return __x.base() == __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter2>& __y) _NOEXCEPT
{
#if _LIBCPP_DEBUG_LEVEL >= 2
    _LIBCPP_ASSERT(__get_const_db()->__less_than_comparable(&__x, &__y),
                   "Attempted to compare incomparable iterators");
#endif
# 1299 "/usr/include/c++/v1/iterator" 3
    return __x.base() < __y.base();
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter2>& __y) _NOEXCEPT
{
    return !(__x == __y);
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter2>& __y) _NOEXCEPT
{
    return __y < __x;
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter2>& __y) _NOEXCEPT
{
    return !(__x < __y);
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter2>& __y) _NOEXCEPT
{
    return !(__y < __x);
}

template <class _Iter1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter1>& __y) _NOEXCEPT
{
    return !(__x == __y);
}

template <class _Iter1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter1>& __y) _NOEXCEPT
{
    return __y < __x;
}

template <class _Iter1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter1>& __y) _NOEXCEPT
{
    return !(__x < __y);
}

template <class _Iter1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter1>& __y) _NOEXCEPT
{
    return !(__y < __x);
}

template <class _Iter1, class _Iter2>
inline _LIBCPP_INLINE_VISIBILITY
typename __wrap_iter<_Iter1>::difference_type
operator-(const __wrap_iter<_Iter1>& __x, const __wrap_iter<_Iter2>& __y) _NOEXCEPT
{
#if _LIBCPP_DEBUG_LEVEL >= 2
    _LIBCPP_ASSERT(__get_const_db()->__less_than_comparable(&__x, &__y),
                   "Attempted to subtract incompatible iterators");
#endif
# 1375 "/usr/include/c++/v1/iterator" 3
    return __x.base() - __y.base();
}

template <class _Iter>
inline _LIBCPP_INLINE_VISIBILITY
__wrap_iter<_Iter>
operator+(typename __wrap_iter<_Iter>::difference_type __n,
          __wrap_iter<_Iter> __x) _NOEXCEPT
{
    __x += __n;
    return __x;
}

template <class _Tp, size_t _Np>
inline _LIBCPP_INLINE_VISIBILITY
_Tp*
begin(_Tp (&__array)[_Np])
{
    return __array;
}

template <class _Tp, size_t _Np>
inline _LIBCPP_INLINE_VISIBILITY
_Tp*
end(_Tp (&__array)[_Np])
{
    return __array + _Np;
}

#if !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES) && !defined(_LIBCPP_HAS_NO_TRAILING_RETURN)

template <class _Cp>
inline _LIBCPP_INLINE_VISIBILITY
auto
begin(_Cp& __c) -> decltype(__c.begin())
{
    return __c.begin();
}

template <class _Cp>
inline _LIBCPP_INLINE_VISIBILITY
auto
begin(const _Cp& __c) -> decltype(__c.begin())
{
    return __c.begin();
}

template <class _Cp>
inline _LIBCPP_INLINE_VISIBILITY
auto
end(_Cp& __c) -> decltype(__c.end())
{
    return __c.end();
}

template <class _Cp>
inline _LIBCPP_INLINE_VISIBILITY
auto
end(const _Cp& __c) -> decltype(__c.end())
{
    return __c.end();
}

#if _LIBCPP_STD_VER > 11

template <class _Tp, size_t _Np>
inline _LIBCPP_INLINE_VISIBILITY
reverse_iterator<_Tp*> rbegin(_Tp (&__array)[_Np])
{
    return reverse_iterator<_Tp*>(__array + _Np);
}

template <class _Tp, size_t _Np>
inline _LIBCPP_INLINE_VISIBILITY
reverse_iterator<_Tp*> rend(_Tp (&__array)[_Np])
{
    return reverse_iterator<_Tp*>(__array);
}

template <class _Ep>
inline _LIBCPP_INLINE_VISIBILITY
reverse_iterator<const _Ep*> rbegin(initializer_list<_Ep> __il)
{
    return reverse_iterator<const _Ep*>(__il.end());
}

template <class _Ep>
inline _LIBCPP_INLINE_VISIBILITY
reverse_iterator<const _Ep*> rend(initializer_list<_Ep> __il)
{
    return reverse_iterator<const _Ep*>(__il.begin());
}

template <class _Cp>
inline _LIBCPP_INLINE_VISIBILITY
auto cbegin(const _Cp& __c) -> decltype(begin(__c))
{
    return _VSTD::begin(__c);
}

template <class _Cp>
inline _LIBCPP_INLINE_VISIBILITY
auto cend(const _Cp& __c) -> decltype(end(__c))
{
    return _VSTD::end(__c);
}

template <class _Cp>
inline _LIBCPP_INLINE_VISIBILITY
auto rbegin(_Cp& __c) -> decltype(__c.rbegin())
{
    return __c.rbegin();
}

template <class _Cp>
inline _LIBCPP_INLINE_VISIBILITY
auto rbegin(const _Cp& __c) -> decltype(__c.rbegin())
{
    return __c.rbegin();
}

template <class _Cp>
inline _LIBCPP_INLINE_VISIBILITY
auto rend(_Cp& __c) -> decltype(__c.rend())
{
    return __c.rend();
}

template <class _Cp>
inline _LIBCPP_INLINE_VISIBILITY
auto rend(const _Cp& __c) -> decltype(__c.rend())
{
    return __c.rend();
}

template <class _Cp>
inline _LIBCPP_INLINE_VISIBILITY
auto crbegin(const _Cp& __c) -> decltype(rbegin(__c))
{
    return rbegin(__c);
}

template <class _Cp>
inline _LIBCPP_INLINE_VISIBILITY
auto crend(const _Cp& __c) -> decltype(rend(__c))
{
    return rend(__c);
}

#endif
# 1525 "/usr/include/c++/v1/iterator" 3


#else  // !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES) && !defined(_LIBCPP_HAS_NO_TRAILING_RETURN)
# 1528 "/usr/include/c++/v1/iterator" 3

template <class _Cp>
inline _LIBCPP_INLINE_VISIBILITY
typename _Cp::iterator
begin(_Cp& __c)
{
    return __c.begin();
}

template <class _Cp>
inline _LIBCPP_INLINE_VISIBILITY
typename _Cp::const_iterator
begin(const _Cp& __c)
{
    return __c.begin();
}

template <class _Cp>
inline _LIBCPP_INLINE_VISIBILITY
typename _Cp::iterator
end(_Cp& __c)
{
    return __c.end();
}

template <class _Cp>
inline _LIBCPP_INLINE_VISIBILITY
typename _Cp::const_iterator
end(const _Cp& __c)
{
    return __c.end();
}

#endif  // !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES) && !defined(_LIBCPP_HAS_NO_TRAILING_RETURN)
# 1562 "/usr/include/c++/v1/iterator" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_ITERATOR
# 1566 "/usr/include/c++/v1/iterator" 3
# 601 "/usr/include/c++/v1/memory" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <__functional_base>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/__functional_base" 1 3
// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_FUNCTIONAL_BASE
#define _LIBCPP_FUNCTIONAL_BASE

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 15 "/usr/include/c++/v1/__functional_base" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 16 "/usr/include/c++/v1/__functional_base" 3
#if 0 /* expanded by -frewrite-includes */
#include <typeinfo>
#endif /* expanded by -frewrite-includes */
# 17 "/usr/include/c++/v1/__functional_base" 3
#if 0 /* expanded by -frewrite-includes */
#include <exception>
#endif /* expanded by -frewrite-includes */
# 18 "/usr/include/c++/v1/__functional_base" 3
#if 0 /* expanded by -frewrite-includes */
#include <new>
#endif /* expanded by -frewrite-includes */
# 19 "/usr/include/c++/v1/__functional_base" 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 22 "/usr/include/c++/v1/__functional_base" 3
#endif
# 23 "/usr/include/c++/v1/__functional_base" 3

_LIBCPP_BEGIN_NAMESPACE_STD

template <class _Arg, class _Result>
struct _LIBCPP_TYPE_VIS_ONLY unary_function
{
    typedef _Arg    argument_type;
    typedef _Result result_type;
};

template <class _Arg1, class _Arg2, class _Result>
struct _LIBCPP_TYPE_VIS_ONLY binary_function
{
    typedef _Arg1   first_argument_type;
    typedef _Arg2   second_argument_type;
    typedef _Result result_type;
};

template <class _Tp> struct _LIBCPP_TYPE_VIS_ONLY hash;

template <class _Tp>
struct __has_result_type
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Up> static __two __test(...);
    template <class _Up> static char __test(typename _Up::result_type* = 0);
public:
    static const bool value = sizeof(__test<_Tp>(0)) == 1;
};

#if _LIBCPP_STD_VER > 11
template <class _Tp = void>
#else
# 57 "/usr/include/c++/v1/__functional_base" 3
template <class _Tp>
#endif
# 59 "/usr/include/c++/v1/__functional_base" 3
struct _LIBCPP_TYPE_VIS_ONLY less : binary_function<_Tp, _Tp, bool>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY 
    bool operator()(const _Tp& __x, const _Tp& __y) const
        {return __x < __y;}
};

#if _LIBCPP_STD_VER > 11
template <>
struct _LIBCPP_TYPE_VIS_ONLY less<void>
{
    template <class _T1, class _T2> 
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
        { return _VSTD::forward<_T1>(__t) < _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 77 "/usr/include/c++/v1/__functional_base" 3

// addressof

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_Tp*
addressof(_Tp& __x) _NOEXCEPT
{
    return (_Tp*)&reinterpret_cast<const volatile char&>(__x);
}

#if defined(_LIBCPP_HAS_OBJC_ARC) && !defined(_LIBCPP_PREDEFINED_OBJC_ARC_ADDRESSOF)
// Objective-C++ Automatic Reference Counting uses qualified pointers
// that require special addressof() signatures. When
// _LIBCPP_PREDEFINED_OBJC_ARC_ADDRESSOF is defined, the compiler
// itself is providing these definitions. Otherwise, we provide them.
template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
__strong _Tp*
addressof(__strong _Tp& __x) _NOEXCEPT
{
  return &__x;
}

#ifdef _LIBCPP_HAS_OBJC_ARC_WEAK
template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
__weak _Tp*
addressof(__weak _Tp& __x) _NOEXCEPT
{
  return &__x;
}
#endif
# 110 "/usr/include/c++/v1/__functional_base" 3

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
__autoreleasing _Tp*
addressof(__autoreleasing _Tp& __x) _NOEXCEPT
{
  return &__x;
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
__unsafe_unretained _Tp*
addressof(__unsafe_unretained _Tp& __x) _NOEXCEPT
{
  return &__x;
}
#endif
# 127 "/usr/include/c++/v1/__functional_base" 3

#ifdef _LIBCPP_HAS_NO_VARIADICS

#if 0 /* expanded by -frewrite-includes */
#include <__functional_base_03>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/__functional_base_03" 1 3
// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_FUNCTIONAL_BASE_03
#define _LIBCPP_FUNCTIONAL_BASE_03

// manual variadic expansion for <functional>

// __weak_result_type

template <class _Tp>
struct __derives_from_unary_function
{
private:
    struct __two {char __lx; char __lxx;};
    static __two __test(...);
    template <class _Ap, class _Rp>
        static unary_function<_Ap, _Rp>
        __test(const volatile unary_function<_Ap, _Rp>*);
public:
    static const bool value = !is_same<decltype(__test((_Tp*)0)), __two>::value;
    typedef decltype(__test((_Tp*)0)) type;
};

template <class _Tp>
struct __derives_from_binary_function
{
private:
    struct __two {char __lx; char __lxx;};
    static __two __test(...);
    template <class _A1, class _A2, class _Rp>
        static binary_function<_A1, _A2, _Rp>
        __test(const volatile binary_function<_A1, _A2, _Rp>*);
public:
    static const bool value = !is_same<decltype(__test((_Tp*)0)), __two>::value;
    typedef decltype(__test((_Tp*)0)) type;
};

template <class _Tp, bool = __derives_from_unary_function<_Tp>::value>
struct __maybe_derive_from_unary_function  // bool is true
    : public __derives_from_unary_function<_Tp>::type
{
};

template <class _Tp>
struct __maybe_derive_from_unary_function<_Tp, false>
{
};

template <class _Tp, bool = __derives_from_binary_function<_Tp>::value>
struct __maybe_derive_from_binary_function  // bool is true
    : public __derives_from_binary_function<_Tp>::type
{
};

template <class _Tp>
struct __maybe_derive_from_binary_function<_Tp, false>
{
};

template <class _Tp, bool = __has_result_type<_Tp>::value>
struct __weak_result_type_imp // bool is true
    : public __maybe_derive_from_unary_function<_Tp>,
      public __maybe_derive_from_binary_function<_Tp>
{
    typedef typename _Tp::result_type result_type;
};

template <class _Tp>
struct __weak_result_type_imp<_Tp, false>
    : public __maybe_derive_from_unary_function<_Tp>,
      public __maybe_derive_from_binary_function<_Tp>
{
};

template <class _Tp>
struct __weak_result_type
    : public __weak_result_type_imp<typename remove_reference<_Tp>::type>
{
};

// 0 argument case

template <class _Rp>
struct __weak_result_type<_Rp ()>
{
    typedef _Rp result_type;
};

template <class _Rp>
struct __weak_result_type<_Rp (&)()>
{
    typedef _Rp result_type;
};

template <class _Rp>
struct __weak_result_type<_Rp (*)()>
{
    typedef _Rp result_type;
};

// 1 argument case

template <class _Rp, class _A1>
struct __weak_result_type<_Rp (_A1)>
    : public unary_function<_A1, _Rp>
{
};

template <class _Rp, class _A1>
struct __weak_result_type<_Rp (&)(_A1)>
    : public unary_function<_A1, _Rp>
{
};

template <class _Rp, class _A1>
struct __weak_result_type<_Rp (*)(_A1)>
    : public unary_function<_A1, _Rp>
{
};

template <class _Rp, class _Cp>
struct __weak_result_type<_Rp (_Cp::*)()>
    : public unary_function<_Cp*, _Rp>
{
};

template <class _Rp, class _Cp>
struct __weak_result_type<_Rp (_Cp::*)() const>
    : public unary_function<const _Cp*, _Rp>
{
};

template <class _Rp, class _Cp>
struct __weak_result_type<_Rp (_Cp::*)() volatile>
    : public unary_function<volatile _Cp*, _Rp>
{
};

template <class _Rp, class _Cp>
struct __weak_result_type<_Rp (_Cp::*)() const volatile>
    : public unary_function<const volatile _Cp*, _Rp>
{
};

// 2 argument case

template <class _Rp, class _A1, class _A2>
struct __weak_result_type<_Rp (_A1, _A2)>
    : public binary_function<_A1, _A2, _Rp>
{
};

template <class _Rp, class _A1, class _A2>
struct __weak_result_type<_Rp (*)(_A1, _A2)>
    : public binary_function<_A1, _A2, _Rp>
{
};

template <class _Rp, class _A1, class _A2>
struct __weak_result_type<_Rp (&)(_A1, _A2)>
    : public binary_function<_A1, _A2, _Rp>
{
};

template <class _Rp, class _Cp, class _A1>
struct __weak_result_type<_Rp (_Cp::*)(_A1)>
    : public binary_function<_Cp*, _A1, _Rp>
{
};

template <class _Rp, class _Cp, class _A1>
struct __weak_result_type<_Rp (_Cp::*)(_A1) const>
    : public binary_function<const _Cp*, _A1, _Rp>
{
};

template <class _Rp, class _Cp, class _A1>
struct __weak_result_type<_Rp (_Cp::*)(_A1) volatile>
    : public binary_function<volatile _Cp*, _A1, _Rp>
{
};

template <class _Rp, class _Cp, class _A1>
struct __weak_result_type<_Rp (_Cp::*)(_A1) const volatile>
    : public binary_function<const volatile _Cp*, _A1, _Rp>
{
};

// 3 or more arguments

template <class _Rp, class _A1, class _A2, class _A3>
struct __weak_result_type<_Rp (_A1, _A2, _A3)>
{
    typedef _Rp result_type;
};

template <class _Rp, class _A1, class _A2, class _A3>
struct __weak_result_type<_Rp (&)(_A1, _A2, _A3)>
{
    typedef _Rp result_type;
};

template <class _Rp, class _A1, class _A2, class _A3>
struct __weak_result_type<_Rp (*)(_A1, _A2, _A3)>
{
    typedef _Rp result_type;
};

template <class _Rp, class _Cp, class _A1, class _A2>
struct __weak_result_type<_Rp (_Cp::*)(_A1, _A2)>
{
    typedef _Rp result_type;
};

template <class _Rp, class _Cp, class _A1, class _A2>
struct __weak_result_type<_Rp (_Cp::*)(_A1, _A2) const>
{
    typedef _Rp result_type;
};

template <class _Rp, class _Cp, class _A1, class _A2>
struct __weak_result_type<_Rp (_Cp::*)(_A1, _A2) volatile>
{
    typedef _Rp result_type;
};

// __invoke

// __ref_return0
//
// template <class _Tp, bool _HasResultType>
// struct ________ref_return0  // _HasResultType is true
// {
//     typedef typename _Tp::result_type type;
// };
//
// template <class _Tp>
// struct ________ref_return0<_Tp, false>
// {
//     typedef void type;
// };
//
// template <class _Tp, bool _IsClass>
// struct ____ref_return0  // _IsClass is true
//     : public ________ref_return0<_Tp, __has_result_type<typename remove_cv<_Tp>::type>::value>
// {
// };
//
// template <class _Tp, bool _HasResultType>
// struct ______ref_return0  // _HasResultType is true
// {
//     typedef typename __callable_type<_Tp>::result_type type;
// };
//
// template <class _Tp>
// struct ______ref_return0<_Tp, false>  // pointer to member data
// {
//     typedef void type;
// };
//
// template <class _Tp>
// struct ____ref_return0<_Tp, false>
//     : public ______ref_return0<typename remove_cv<_Tp>::type,
//                  __has_result_type<__callable_type<typename remove_cv<_Tp>::type> >::value>
// {
// };
//
// template <class _Tp>
// struct __ref_return0
//     : public ____ref_return0<typename remove_reference<_Tp>::type,
//                    is_class<typename remove_reference<_Tp>::type>::value>
// {
// };
//
// __ref_return1
//
// template <class _Tp, bool _IsClass, class _A0>
// struct ____ref_return1  // _IsClass is true
// {
//     typedef typename result_of<_Tp(_A0)>::type type;
// };
//
// template <class _Tp, bool _HasResultType, class _A0>
// struct ______ref_return1  // _HasResultType is true
// {
//     typedef typename __callable_type<_Tp>::result_type type;
// };
//
// template <class _Tp, class _A0, bool>
// struct __ref_return1_member_data1;
//
// template <class _Rp, class _Cp, class _A0>
// struct __ref_return1_member_data1<_Rp _Cp::*, _A0, true>
// {
//     typedef typename __apply_cv<_A0, _Rp>::type& type;
// };
//
// template <class _Rp, class _Cp, class _A0>
// struct __ref_return1_member_data1<_Rp _Cp::*, _A0, false>
// {
//     static _A0 __a;
//     typedef typename __apply_cv<decltype(*__a), _Rp>::type& type;
// };
//
// template <class _Tp, class _A0>
// struct __ref_return1_member_data;
//
// template <class _Rp, class _Cp, class _A0>
// struct __ref_return1_member_data<_Rp _Cp::*, _A0>
//     : public __ref_return1_member_data1<_Rp _Cp::*, _A0,
//                 is_same<typename remove_cv<_Cp>::type,
//                         typename remove_cv<typename remove_reference<_A0>::type>::type>::value>
// {
// };
//
// template <class _Tp, class _A0>
// struct ______ref_return1<_Tp, false, _A0>  // pointer to member data
//     : public __ref_return1_member_data<typename remove_cv<_Tp>::type, _A0>
// {
// };
//
// template <class _Tp, class _A0>
// struct ____ref_return1<_Tp, false, _A0>
//     : public ______ref_return1<typename remove_cv<_Tp>::type,
//                  __has_result_type<__callable_type<typename remove_cv<_Tp>::type> >::value, _A0>
// {
// };
//
// template <class _Tp, class _A0>
// struct __ref_return1
//     : public ____ref_return1<typename remove_reference<_Tp>::type,
//                    is_class<typename remove_reference<_Tp>::type>::value, _A0>
// {
// };
//
// __ref_return2
//
// template <class _Tp, bool _IsClass, class _A0, class _A1>
// struct ____ref_return2  // _IsClass is true
// {
//     typedef typename result_of<_Tp(_A0, _A1)>::type type;
// };
//
// template <class _Tp, bool _HasResultType, class _A0, class _A1>
// struct ______ref_return2  // _HasResultType is true
// {
//     typedef typename __callable_type<_Tp>::result_type type;
// };
//
// template <class _Tp>
// struct ______ref_return2<_Tp, false, class _A0, class _A1>  // pointer to member data
// {
//     static_assert(sizeof(_Tp) == 0, "An attempt has been made to `call` a pointer"
//                          " to member data with too many arguments.");
// };
//
// template <class _Tp, class _A0, class _A1>
// struct ____ref_return2<_Tp, false, _A0, _A1>
//     : public ______ref_return2<typename remove_cv<_Tp>::type,
//                  __has_result_type<__callable_type<typename remove_cv<_Tp>::type> >::value, _A0, _A1>
// {
// };
//
// template <class _Tp, class _A0, class _A1>
// struct __ref_return2
//     : public ____ref_return2<typename remove_reference<_Tp>::type,
//                    is_class<typename remove_reference<_Tp>::type>::value, _A0, _A1>
// {
// };
//
// __ref_return3
//
// template <class _Tp, bool _IsClass, class _A0, class _A1, class _A2>
// struct ____ref_return3  // _IsClass is true
// {
//     typedef typename result_of<_Tp(_A0, _A1, _A2)>::type type;
// };
//
// template <class _Tp, bool _HasResultType, class _A0, class _A1, class _A2>
// struct ______ref_return3  // _HasResultType is true
// {
//     typedef typename __callable_type<_Tp>::result_type type;
// };
//
// template <class _Tp>
// struct ______ref_return3<_Tp, false, class _A0, class _A1, class _A2>  // pointer to member data
// {
//     static_assert(sizeof(_Tp) == 0, "An attempt has been made to `call` a pointer"
//                          " to member data with too many arguments.");
// };
//
// template <class _Tp, class _A0, class _A1, class _A2>
// struct ____ref_return3<_Tp, false, _A0, _A1, _A2>
//     : public ______ref_return3<typename remove_cv<_Tp>::type,
//                  __has_result_type<__callable_type<typename remove_cv<_Tp>::type> >::value, _A0, _A1, _A2>
// {
// };
//
// template <class _Tp, class _A0, class _A1, class _A2>
// struct __ref_return3
//     : public ____ref_return3<typename remove_reference<_Tp>::type,
//                    is_class<typename remove_reference<_Tp>::type>::value, _A0, _A1, _A2>
// {
// };

// first bullet

template <class _Rp, class _Tp, class _T1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(), _T1& __t1)
{
    return (__t1.*__f)();
}

template <class _Rp, class _Tp, class _T1, class _A0>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0), _T1& __t1, _A0& __a0)
{
    return (__t1.*__f)(__a0);
}

template <class _Rp, class _Tp, class _T1, class _A0, class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0, _A1), _T1& __t1, _A0& __a0, _A1& __a1)
{
    return (__t1.*__f)(__a0, __a1);
}

template <class _Rp, class _Tp, class _T1, class _A0, class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0, _A1, _A2), _T1& __t1, _A0& __a0, _A1& __a1, _A2& __a2)
{
    return (__t1.*__f)(__a0, __a1, __a2);
}

template <class _Rp, class _Tp, class _T1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)() const, _T1& __t1)
{
    return (__t1.*__f)();
}

template <class _Rp, class _Tp, class _T1, class _A0>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0) const, _T1& __t1, _A0& __a0)
{
    return (__t1.*__f)(__a0);
}

template <class _Rp, class _Tp, class _T1, class _A0, class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0, _A1) const, _T1& __t1, _A0& __a0, _A1& __a1)
{
    return (__t1.*__f)(__a0, __a1);
}

template <class _Rp, class _Tp, class _T1, class _A0, class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0, _A1, _A2) const, _T1& __t1, _A0& __a0, _A1& __a1, _A2& __a2)
{
    return (__t1.*__f)(__a0, __a1, __a2);
}

template <class _Rp, class _Tp, class _T1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)() volatile, _T1& __t1)
{
    return (__t1.*__f)();
}

template <class _Rp, class _Tp, class _T1, class _A0>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0) volatile, _T1& __t1, _A0& __a0)
{
    return (__t1.*__f)(__a0);
}

template <class _Rp, class _Tp, class _T1, class _A0, class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0, _A1) volatile, _T1& __t1, _A0& __a0, _A1& __a1)
{
    return (__t1.*__f)(__a0, __a1);
}

template <class _Rp, class _Tp, class _T1, class _A0, class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0, _A1, _A2) volatile, _T1& __t1, _A0& __a0, _A1& __a1, _A2& __a2)
{
    return (__t1.*__f)(__a0, __a1, __a2);
}

template <class _Rp, class _Tp, class _T1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)() const volatile, _T1& __t1)
{
    return (__t1.*__f)();
}

template <class _Rp, class _Tp, class _T1, class _A0>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0) const volatile, _T1& __t1, _A0& __a0)
{
    return (__t1.*__f)(__a0);
}

template <class _Rp, class _Tp, class _T1, class _A0, class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0, _A1) const volatile, _T1& __t1, _A0& __a0, _A1& __a1)
{
    return (__t1.*__f)(__a0, __a1);
}

template <class _Rp, class _Tp, class _T1, class _A0, class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0, _A1, _A2) const volatile, _T1& __t1, _A0& __a0, _A1& __a1, _A2& __a2)
{
    return (__t1.*__f)(__a0, __a1, __a2);
}

// second bullet

template <class _Rp, class _Tp, class _T1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(), _T1 __t1)
{
    return ((*__t1).*__f)();
}

template <class _Rp, class _Tp, class _T1, class _A0>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0), _T1 __t1, _A0& __a0)
{
    return ((*__t1).*__f)(__a0);
}

template <class _Rp, class _Tp, class _T1, class _A0, class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0, _A1), _T1 __t1, _A0& __a0, _A1& __a1)
{
    return ((*__t1).*__f)(__a0, __a1);
}

template <class _Rp, class _Tp, class _T1, class _A0, class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0, _A1, _A2), _T1 __t1, _A0& __a0, _A1& __a1, _A2& __a2)
{
    return ((*__t1).*__f)(__a0, __a1, __a2);
}

template <class _Rp, class _Tp, class _T1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)() const, _T1 __t1)
{
    return ((*__t1).*__f)();
}

template <class _Rp, class _Tp, class _T1, class _A0>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0) const, _T1 __t1, _A0& __a0)
{
    return ((*__t1).*__f)(__a0);
}

template <class _Rp, class _Tp, class _T1, class _A0, class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0, _A1) const, _T1 __t1, _A0& __a0, _A1& __a1)
{
    return ((*__t1).*__f)(__a0, __a1);
}

template <class _Rp, class _Tp, class _T1, class _A0, class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0, _A1, _A2) const, _T1 __t1, _A0& __a0, _A1& __a1, _A2& __a2)
{
    return ((*__t1).*__f)(__a0, __a1, __a2);
}

template <class _Rp, class _Tp, class _T1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)() volatile, _T1 __t1)
{
    return ((*__t1).*__f)();
}

template <class _Rp, class _Tp, class _T1, class _A0>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0) volatile, _T1 __t1, _A0& __a0)
{
    return ((*__t1).*__f)(__a0);
}

template <class _Rp, class _Tp, class _T1, class _A0, class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0, _A1) volatile, _T1 __t1, _A0& __a0, _A1& __a1)
{
    return ((*__t1).*__f)(__a0, __a1);
}

template <class _Rp, class _Tp, class _T1, class _A0, class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0, _A1, _A2) volatile, _T1 __t1, _A0& __a0, _A1& __a1, _A2& __a2)
{
    return ((*__t1).*__f)(__a0, __a1, __a2);
}

template <class _Rp, class _Tp, class _T1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)() const volatile, _T1 __t1)
{
    return ((*__t1).*__f)();
}

template <class _Rp, class _Tp, class _T1, class _A0>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0) const volatile, _T1 __t1, _A0& __a0)
{
    return ((*__t1).*__f)(__a0);
}

template <class _Rp, class _Tp, class _T1, class _A0, class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0, _A1) const volatile, _T1 __t1, _A0& __a0, _A1& __a1)
{
    return ((*__t1).*__f)(__a0, __a1);
}

template <class _Rp, class _Tp, class _T1, class _A0, class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    _Rp
>::type
__invoke(_Rp (_Tp::*__f)(_A0, _A1, _A2) const volatile, _T1 __t1, _A0& __a0, _A1& __a1, _A2& __a2)
{
    return ((*__t1).*__f)(__a0, __a1, __a2);
}

// third bullet

template <class _Rp, class _Tp, class _T1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
    typename __apply_cv<_T1, _Rp>::type&
>::type
__invoke(_Rp _Tp::* __f, _T1& __t1)
{
    return __t1.*__f;
}

template <class _Rp, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void
__invoke(_Rp _Tp::*)
{
}

// template <class _Dp, class _Rp, class _Tp, class _T1>
// inline _LIBCPP_INLINE_VISIBILITY
// typename enable_if
// <
//     is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
//     typename __ref_return1<_Rp _Tp::*, _T1>::type
// >::type
// __invoke(_Rp _Tp::* __f, _T1& __t1)
// {
//     return __t1.*__f;
// }

// forth bullet

template <class _T1, class _Rp, bool>
struct __4th_helper
{
};

template <class _T1, class _Rp>
struct __4th_helper<_T1, _Rp, true>
{
    typedef typename __apply_cv<decltype(*_VSTD::declval<_T1>()), _Rp>::type type;
};

template <class _Rp, class _Tp, class _T1>
inline _LIBCPP_INLINE_VISIBILITY
typename __4th_helper<_T1, _Rp,
                      !is_base_of<_Tp,
                                  typename remove_reference<_T1>::type
                                 >::value
                     >::type&
__invoke(_Rp _Tp::* __f, _T1& __t1)
{
    return (*__t1).*__f;
}

// template <class _Dp, class _Rp, class _Tp, class _T1>
// inline _LIBCPP_INLINE_VISIBILITY
// typename enable_if
// <
//     !is_base_of<_Tp, typename remove_reference<_T1>::type>::value,
//     typename __ref_return1<_Rp _Tp::*, _T1>::type
// >::type
// __invoke(_Rp _Tp::* __f, _T1 __t1)
// {
//     return (*__t1).*__f;
// }

// fifth bullet

template <class _Fp>
inline _LIBCPP_INLINE_VISIBILITY
decltype(declval<_Fp>()())
__invoke(_Fp __f)
{
    return __f();
}

template <class _Fp, class _A0>
inline _LIBCPP_INLINE_VISIBILITY
decltype(declval<_Fp>()(declval<_A0&>()))
__invoke(_Fp __f, _A0& __a0)
{
    return __f(__a0);
}

template <class _Fp, class _A0, class _A1>
inline _LIBCPP_INLINE_VISIBILITY
decltype(declval<_Fp>()(declval<_A0&>(), declval<_A1&>()))
__invoke(_Fp __f, _A0& __a0, _A1& __a1)
{
    return __f(__a0, __a1);
}

template <class _Fp, class _A0, class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
decltype(declval<_Fp>()(declval<_A0&>(), declval<_A1&>(), declval<_A2&>()))
__invoke(_Fp __f, _A0& __a0, _A1& __a1, _A2& __a2)
{
    return __f(__a0, __a1, __a2);
}

// template <class _Rp, class _Fp>
// inline _LIBCPP_INLINE_VISIBILITY
// _Rp
// __invoke(_Fp& __f)
// {
//     return __f();
// }
//
// template <class _Rp, class _Fp, class _A0>
// inline _LIBCPP_INLINE_VISIBILITY
// typename enable_if
// <
//     !is_member_pointer<_Fp>::value,
//     _Rp
// >::type
// __invoke(_Fp& __f, _A0& __a0)
// {
//     return __f(__a0);
// }
//
// template <class _Rp, class _Fp, class _A0, class _A1>
// inline _LIBCPP_INLINE_VISIBILITY
// _Rp
// __invoke(_Fp& __f, _A0& __a0, _A1& __a1)
// {
//     return __f(__a0, __a1);
// }
//
// template <class _Rp, class _Fp, class _A0, class _A1, class _A2>
// inline _LIBCPP_INLINE_VISIBILITY
// _Rp
// __invoke(_Fp& __f, _A0& __a0, _A1& __a1, _A2& __a2)
// {
//     return __f(__a0, __a1, __a2);
// }

template <class _Tp>
struct __has_type
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Up> static __two __test(...);
    template <class _Up> static char __test(typename _Up::type* = 0);
public:
    static const bool value = sizeof(__test<_Tp>(0)) == 1;
};

template <class _Fp, bool = __has_result_type<__weak_result_type<_Fp> >::value>
struct __invoke_return
{
    typedef typename __weak_result_type<_Fp>::result_type type;
};

template <class _Fp>
struct __invoke_return<_Fp, false>
{
    typedef decltype(__invoke(_VSTD::declval<_Fp>())) type;
};

template <class _Tp, class _A0>
struct __invoke_return0
{
    typedef decltype(__invoke(_VSTD::declval<_Tp>(), _VSTD::declval<_A0>())) type;
};

template <class _Rp, class _Tp, class _A0>
struct __invoke_return0<_Rp _Tp::*, _A0>
{
    typedef typename __apply_cv<_A0, _Rp>::type& type;
};

template <class _Rp, class _Tp, class _A0>
struct __invoke_return0<_Rp _Tp::*, _A0*>
{
    typedef typename __apply_cv<_A0, _Rp>::type& type;
};

template <class _Tp, class _A0, class _A1>
struct __invoke_return1
{
    typedef decltype(__invoke(_VSTD::declval<_Tp>(), _VSTD::declval<_A0>(),
                                                    _VSTD::declval<_A1>())) type;
};

template <class _Tp, class _A0, class _A1, class _A2>
struct __invoke_return2
{
    typedef decltype(__invoke(_VSTD::declval<_Tp>(), _VSTD::declval<_A0>(),
                                                    _VSTD::declval<_A1>(),
                                                    _VSTD::declval<_A2>())) type;
};

template <class _Tp>
class _LIBCPP_TYPE_VIS_ONLY reference_wrapper
    : public __weak_result_type<_Tp>
{
public:
    // types
    typedef _Tp type;
private:
    type* __f_;

public:
    // construct/copy/destroy
    _LIBCPP_INLINE_VISIBILITY reference_wrapper(type& __f) : __f_(&__f) {}

    // access
    _LIBCPP_INLINE_VISIBILITY operator type&    () const {return *__f_;}
    _LIBCPP_INLINE_VISIBILITY          type& get() const {return *__f_;}

    // invoke

    _LIBCPP_INLINE_VISIBILITY
    typename __invoke_return<type&>::type
       operator() () const
       {
           return __invoke(get());
       }

    template <class _A0>
       _LIBCPP_INLINE_VISIBILITY
       typename __invoke_return0<type&, _A0>::type
          operator() (_A0& __a0) const
          {
              return __invoke(get(), __a0);
          }

    template <class _A0, class _A1>
       _LIBCPP_INLINE_VISIBILITY
       typename __invoke_return1<type&, _A0, _A1>::type
          operator() (_A0& __a0, _A1& __a1) const
          {
              return __invoke(get(), __a0, __a1);
          }

    template <class _A0, class _A1, class _A2>
       _LIBCPP_INLINE_VISIBILITY
       typename __invoke_return2<type&, _A0, _A1, _A2>::type
          operator() (_A0& __a0, _A1& __a1, _A2& __a2) const
          {
              return __invoke(get(), __a0, __a1, __a2);
          }
};

template <class _Tp> struct ____is_reference_wrapper : public false_type {};
template <class _Tp> struct ____is_reference_wrapper<reference_wrapper<_Tp> > : public true_type {};
template <class _Tp> struct __is_reference_wrapper
    : public ____is_reference_wrapper<typename remove_cv<_Tp>::type> {};

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
reference_wrapper<_Tp>
ref(_Tp& __t)
{
    return reference_wrapper<_Tp>(__t);
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
reference_wrapper<_Tp>
ref(reference_wrapper<_Tp> __t)
{
    return ref(__t.get());
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
reference_wrapper<const _Tp>
cref(const _Tp& __t)
{
    return reference_wrapper<const _Tp>(__t);
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
reference_wrapper<const _Tp>
cref(reference_wrapper<_Tp> __t)
{
    return cref(__t.get());
}

#endif  // _LIBCPP_FUNCTIONAL_BASE_03
# 1088 "/usr/include/c++/v1/__functional_base_03" 3
# 131 "/usr/include/c++/v1/__functional_base" 2 3

#else  // _LIBCPP_HAS_NO_VARIADICS
# 133 "/usr/include/c++/v1/__functional_base" 3

// __weak_result_type

template <class _Tp>
struct __derives_from_unary_function
{
private:
    struct __two {char __lx; char __lxx;};
    static __two __test(...);
    template <class _Ap, class _Rp>
        static unary_function<_Ap, _Rp>
        __test(const volatile unary_function<_Ap, _Rp>*);
public:
    static const bool value = !is_same<decltype(__test((_Tp*)0)), __two>::value;
    typedef decltype(__test((_Tp*)0)) type;
};

template <class _Tp>
struct __derives_from_binary_function
{
private:
    struct __two {char __lx; char __lxx;};
    static __two __test(...);
    template <class _A1, class _A2, class _Rp>
        static binary_function<_A1, _A2, _Rp>
        __test(const volatile binary_function<_A1, _A2, _Rp>*);
public:
    static const bool value = !is_same<decltype(__test((_Tp*)0)), __two>::value;
    typedef decltype(__test((_Tp*)0)) type;
};

template <class _Tp, bool = __derives_from_unary_function<_Tp>::value>
struct __maybe_derive_from_unary_function  // bool is true
    : public __derives_from_unary_function<_Tp>::type
{
};

template <class _Tp>
struct __maybe_derive_from_unary_function<_Tp, false>
{
};

template <class _Tp, bool = __derives_from_binary_function<_Tp>::value>
struct __maybe_derive_from_binary_function  // bool is true
    : public __derives_from_binary_function<_Tp>::type
{
};

template <class _Tp>
struct __maybe_derive_from_binary_function<_Tp, false>
{
};

template <class _Tp, bool = __has_result_type<_Tp>::value>
struct __weak_result_type_imp // bool is true
    : public __maybe_derive_from_unary_function<_Tp>,
      public __maybe_derive_from_binary_function<_Tp>
{
    typedef typename _Tp::result_type result_type;
};

template <class _Tp>
struct __weak_result_type_imp<_Tp, false>
    : public __maybe_derive_from_unary_function<_Tp>,
      public __maybe_derive_from_binary_function<_Tp>
{
};

template <class _Tp>
struct __weak_result_type
    : public __weak_result_type_imp<_Tp>
{
};

// 0 argument case

template <class _Rp>
struct __weak_result_type<_Rp ()>
{
    typedef _Rp result_type;
};

template <class _Rp>
struct __weak_result_type<_Rp (&)()>
{
    typedef _Rp result_type;
};

template <class _Rp>
struct __weak_result_type<_Rp (*)()>
{
    typedef _Rp result_type;
};

// 1 argument case

template <class _Rp, class _A1>
struct __weak_result_type<_Rp (_A1)>
    : public unary_function<_A1, _Rp>
{
};

template <class _Rp, class _A1>
struct __weak_result_type<_Rp (&)(_A1)>
    : public unary_function<_A1, _Rp>
{
};

template <class _Rp, class _A1>
struct __weak_result_type<_Rp (*)(_A1)>
    : public unary_function<_A1, _Rp>
{
};

template <class _Rp, class _Cp>
struct __weak_result_type<_Rp (_Cp::*)()>
    : public unary_function<_Cp*, _Rp>
{
};

template <class _Rp, class _Cp>
struct __weak_result_type<_Rp (_Cp::*)() const>
    : public unary_function<const _Cp*, _Rp>
{
};

template <class _Rp, class _Cp>
struct __weak_result_type<_Rp (_Cp::*)() volatile>
    : public unary_function<volatile _Cp*, _Rp>
{
};

template <class _Rp, class _Cp>
struct __weak_result_type<_Rp (_Cp::*)() const volatile>
    : public unary_function<const volatile _Cp*, _Rp>
{
};

// 2 argument case

template <class _Rp, class _A1, class _A2>
struct __weak_result_type<_Rp (_A1, _A2)>
    : public binary_function<_A1, _A2, _Rp>
{
};

template <class _Rp, class _A1, class _A2>
struct __weak_result_type<_Rp (*)(_A1, _A2)>
    : public binary_function<_A1, _A2, _Rp>
{
};

template <class _Rp, class _A1, class _A2>
struct __weak_result_type<_Rp (&)(_A1, _A2)>
    : public binary_function<_A1, _A2, _Rp>
{
};

template <class _Rp, class _Cp, class _A1>
struct __weak_result_type<_Rp (_Cp::*)(_A1)>
    : public binary_function<_Cp*, _A1, _Rp>
{
};

template <class _Rp, class _Cp, class _A1>
struct __weak_result_type<_Rp (_Cp::*)(_A1) const>
    : public binary_function<const _Cp*, _A1, _Rp>
{
};

template <class _Rp, class _Cp, class _A1>
struct __weak_result_type<_Rp (_Cp::*)(_A1) volatile>
    : public binary_function<volatile _Cp*, _A1, _Rp>
{
};

template <class _Rp, class _Cp, class _A1>
struct __weak_result_type<_Rp (_Cp::*)(_A1) const volatile>
    : public binary_function<const volatile _Cp*, _A1, _Rp>
{
};

// 3 or more arguments

template <class _Rp, class _A1, class _A2, class _A3, class ..._A4>
struct __weak_result_type<_Rp (_A1, _A2, _A3, _A4...)>
{
    typedef _Rp result_type;
};

template <class _Rp, class _A1, class _A2, class _A3, class ..._A4>
struct __weak_result_type<_Rp (&)(_A1, _A2, _A3, _A4...)>
{
    typedef _Rp result_type;
};

template <class _Rp, class _A1, class _A2, class _A3, class ..._A4>
struct __weak_result_type<_Rp (*)(_A1, _A2, _A3, _A4...)>
{
    typedef _Rp result_type;
};

template <class _Rp, class _Cp, class _A1, class _A2, class ..._A3>
struct __weak_result_type<_Rp (_Cp::*)(_A1, _A2, _A3...)>
{
    typedef _Rp result_type;
};

template <class _Rp, class _Cp, class _A1, class _A2, class ..._A3>
struct __weak_result_type<_Rp (_Cp::*)(_A1, _A2, _A3...) const>
{
    typedef _Rp result_type;
};

template <class _Rp, class _Cp, class _A1, class _A2, class ..._A3>
struct __weak_result_type<_Rp (_Cp::*)(_A1, _A2, _A3...) volatile>
{
    typedef _Rp result_type;
};

template <class _Rp, class _Cp, class _A1, class _A2, class ..._A3>
struct __weak_result_type<_Rp (_Cp::*)(_A1, _A2, _A3...) const volatile>
{
    typedef _Rp result_type;
};

// __invoke

// bullets 1 and 2

template <class _Fp, class _A0, class ..._Args,
            class>
inline _LIBCPP_INLINE_VISIBILITY
auto
__invoke(_Fp&& __f, _A0&& __a0, _Args&& ...__args)
    -> decltype((_VSTD::forward<_A0>(__a0).*__f)(_VSTD::forward<_Args>(__args)...))
{
    return (_VSTD::forward<_A0>(__a0).*__f)(_VSTD::forward<_Args>(__args)...);
}

template <class _Fp, class _A0, class ..._Args,
            class>
inline _LIBCPP_INLINE_VISIBILITY
auto
__invoke(_Fp&& __f, _A0&& __a0, _Args&& ...__args)
    -> decltype(((*_VSTD::forward<_A0>(__a0)).*__f)(_VSTD::forward<_Args>(__args)...))
{
    return ((*_VSTD::forward<_A0>(__a0)).*__f)(_VSTD::forward<_Args>(__args)...);
}

// bullets 3 and 4

template <class _Fp, class _A0,
            class>
inline _LIBCPP_INLINE_VISIBILITY
auto
__invoke(_Fp&& __f, _A0&& __a0)
    -> decltype(_VSTD::forward<_A0>(__a0).*__f)
{
    return _VSTD::forward<_A0>(__a0).*__f;
}

template <class _Fp, class _A0,
            class>
inline _LIBCPP_INLINE_VISIBILITY
auto
__invoke(_Fp&& __f, _A0&& __a0)
    -> decltype((*_VSTD::forward<_A0>(__a0)).*__f)
{
    return (*_VSTD::forward<_A0>(__a0)).*__f;
}

// bullet 5

template <class _Fp, class ..._Args>
inline _LIBCPP_INLINE_VISIBILITY
auto
__invoke(_Fp&& __f, _Args&& ...__args)
    -> decltype(_VSTD::forward<_Fp>(__f)(_VSTD::forward<_Args>(__args)...))
{
    return _VSTD::forward<_Fp>(__f)(_VSTD::forward<_Args>(__args)...);
}

template <class _Tp, class ..._Args>
struct __invoke_return
{
    typedef decltype(__invoke(_VSTD::declval<_Tp>(), _VSTD::declval<_Args>()...)) type;
};

template <class _Tp>
class _LIBCPP_TYPE_VIS_ONLY reference_wrapper
    : public __weak_result_type<_Tp>
{
public:
    // types
    typedef _Tp type;
private:
    type* __f_;

public:
    // construct/copy/destroy
    _LIBCPP_INLINE_VISIBILITY reference_wrapper(type& __f) _NOEXCEPT
        : __f_(_VSTD::addressof(__f)) {}
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    private: reference_wrapper(type&&); public: // = delete; // do not bind to temps
#endif
# 439 "/usr/include/c++/v1/__functional_base" 3

    // access
    _LIBCPP_INLINE_VISIBILITY operator type&    () const _NOEXCEPT {return *__f_;}
    _LIBCPP_INLINE_VISIBILITY          type& get() const _NOEXCEPT {return *__f_;}

    // invoke
    template <class... _ArgTypes>
       _LIBCPP_INLINE_VISIBILITY
       typename __invoke_of<type&, _ArgTypes...>::type
          operator() (_ArgTypes&&... __args) const
          {
              return __invoke(get(), _VSTD::forward<_ArgTypes>(__args)...);
          }
};

template <class _Tp> struct ____is_reference_wrapper : public false_type {};
template <class _Tp> struct ____is_reference_wrapper<reference_wrapper<_Tp> > : public true_type {};
template <class _Tp> struct __is_reference_wrapper
    : public ____is_reference_wrapper<typename remove_cv<_Tp>::type> {};

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
reference_wrapper<_Tp>
ref(_Tp& __t) _NOEXCEPT
{
    return reference_wrapper<_Tp>(__t);
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
reference_wrapper<_Tp>
ref(reference_wrapper<_Tp> __t) _NOEXCEPT
{
    return ref(__t.get());
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
reference_wrapper<const _Tp>
cref(const _Tp& __t) _NOEXCEPT
{
    return reference_wrapper<const _Tp>(__t);
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
reference_wrapper<const _Tp>
cref(reference_wrapper<_Tp> __t) _NOEXCEPT
{
    return cref(__t.get());
}

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
#ifndef _LIBCPP_HAS_NO_DELETED_FUNCTIONS

template <class _Tp> void ref(const _Tp&&) = delete;
template <class _Tp> void cref(const _Tp&&) = delete;

#else  // _LIBCPP_HAS_NO_DELETED_FUNCTIONS
# 498 "/usr/include/c++/v1/__functional_base" 3

template <class _Tp> void ref(const _Tp&&);// = delete;
template <class _Tp> void cref(const _Tp&&);// = delete;

#endif  // _LIBCPP_HAS_NO_DELETED_FUNCTIONS
# 503 "/usr/include/c++/v1/__functional_base" 3

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 505 "/usr/include/c++/v1/__functional_base" 3

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 507 "/usr/include/c++/v1/__functional_base" 3

#if _LIBCPP_STD_VER > 11
template <class _Tp1, class _Tp2 = void>
struct __is_transparent
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Up> static __two __test(...);
    template <class _Up> static char __test(typename _Up::is_transparent* = 0);
public:
    static const bool value = sizeof(__test<_Tp1>(0)) == 1;
};
#endif
# 520 "/usr/include/c++/v1/__functional_base" 3

// allocator_arg_t

struct _LIBCPP_TYPE_VIS_ONLY allocator_arg_t { };

#if defined(_LIBCPP_HAS_NO_CONSTEXPR) || defined(_LIBCPP_BUILDING_MEMORY)
extern const allocator_arg_t allocator_arg;
#else
# 528 "/usr/include/c++/v1/__functional_base" 3
constexpr allocator_arg_t allocator_arg = allocator_arg_t();
#endif
# 530 "/usr/include/c++/v1/__functional_base" 3

// uses_allocator

template <class _Tp>
struct __has_allocator_type
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Up> static __two __test(...);
    template <class _Up> static char __test(typename _Up::allocator_type* = 0);
public:
    static const bool value = sizeof(__test<_Tp>(0)) == 1;
};

template <class _Tp, class _Alloc, bool = __has_allocator_type<_Tp>::value>
struct __uses_allocator
    : public integral_constant<bool,
        is_convertible<_Alloc, typename _Tp::allocator_type>::value>
{
};

template <class _Tp, class _Alloc>
struct __uses_allocator<_Tp, _Alloc, false>
    : public false_type
{
};

template <class _Tp, class _Alloc>
struct _LIBCPP_TYPE_VIS_ONLY uses_allocator
    : public __uses_allocator<_Tp, _Alloc>
{
};

#ifndef _LIBCPP_HAS_NO_VARIADICS

// allocator construction

template <class _Tp, class _Alloc, class ..._Args>
struct __uses_alloc_ctor_imp
{
    static const bool __ua = uses_allocator<_Tp, _Alloc>::value;
    static const bool __ic =
        is_constructible<_Tp, allocator_arg_t, _Alloc, _Args...>::value;
    static const int value = __ua ? 2 - __ic : 0;
};

template <class _Tp, class _Alloc, class ..._Args>
struct __uses_alloc_ctor
    : integral_constant<int, __uses_alloc_ctor_imp<_Tp, _Alloc, _Args...>::value>
    {};

template <class _Tp, class _Allocator, class... _Args>
inline _LIBCPP_INLINE_VISIBILITY
void __user_alloc_construct_impl (integral_constant<int, 0>, _Tp *__storage, const _Allocator &, _Args &&... __args )
{
    new (__storage) _Tp (_VSTD::forward<_Args>(__args)...);
}

template <class _Tp, class _Allocator, class... _Args>
inline _LIBCPP_INLINE_VISIBILITY
void __user_alloc_construct_impl (integral_constant<int, 1>, _Tp *__storage, const _Allocator &__a, _Args &&... __args )
{
    new (__storage) _Tp (allocator_arg, __a, _VSTD::forward<_Args>(__args)...);
}

template <class _Tp, class _Allocator, class... _Args>
inline _LIBCPP_INLINE_VISIBILITY
void __user_alloc_construct_impl (integral_constant<int, 2>, _Tp *__storage, const _Allocator &__a, _Args &&... __args )
{
    new (__storage) _Tp (_VSTD::forward<_Args>(__args)..., __a);
}

template <class _Tp, class _Allocator, class... _Args>
inline _LIBCPP_INLINE_VISIBILITY
void __user_alloc_construct (_Tp *__storage, const _Allocator &__a, _Args &&... __args)
{ 
    __user_alloc_construct_impl( 
             __uses_alloc_ctor<_Tp, _Allocator>(), 
             __storage, __a, _VSTD::forward<_Args>(__args)...
        );
}
#endif  // _LIBCPP_HAS_NO_VARIADICS
# 612 "/usr/include/c++/v1/__functional_base" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_FUNCTIONAL_BASE
# 616 "/usr/include/c++/v1/__functional_base" 3
# 602 "/usr/include/c++/v1/memory" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <iosfwd>
#endif /* expanded by -frewrite-includes */
# 603 "/usr/include/c++/v1/memory" 3
#if 0 /* expanded by -frewrite-includes */
#include <tuple>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/tuple" 1 3
// -*- C++ -*-
//===--------------------------- tuple ------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is distributed under the University of Illinois Open Source
// License. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_TUPLE
#define _LIBCPP_TUPLE

/*
    tuple synopsis

namespace std
{

template <class... T>
class tuple {
public:
    constexpr tuple();
    explicit tuple(const T&...);  // constexpr in C++14
    template <class... U>
        explicit tuple(U&&...);  // constexpr in C++14
    tuple(const tuple&) = default;
    tuple(tuple&&) = default;
    template <class... U>
        tuple(const tuple<U...>&);  // constexpr in C++14
    template <class... U>
        tuple(tuple<U...>&&);  // constexpr in C++14
    template <class U1, class U2>
        tuple(const pair<U1, U2>&); // iff sizeof...(T) == 2 // constexpr in C++14
    template <class U1, class U2>
        tuple(pair<U1, U2>&&); // iff sizeof...(T) == 2  // constexpr in C++14

    // allocator-extended constructors
    template <class Alloc>
        tuple(allocator_arg_t, const Alloc& a);
    template <class Alloc>
        tuple(allocator_arg_t, const Alloc& a, const T&...);
    template <class Alloc, class... U>
        tuple(allocator_arg_t, const Alloc& a, U&&...);
    template <class Alloc>
        tuple(allocator_arg_t, const Alloc& a, const tuple&);
    template <class Alloc>
        tuple(allocator_arg_t, const Alloc& a, tuple&&);
    template <class Alloc, class... U>
        tuple(allocator_arg_t, const Alloc& a, const tuple<U...>&);
    template <class Alloc, class... U>
        tuple(allocator_arg_t, const Alloc& a, tuple<U...>&&);
    template <class Alloc, class U1, class U2>
        tuple(allocator_arg_t, const Alloc& a, const pair<U1, U2>&);
    template <class Alloc, class U1, class U2>
        tuple(allocator_arg_t, const Alloc& a, pair<U1, U2>&&);

    tuple& operator=(const tuple&);
    tuple&
        operator=(tuple&&) noexcept(AND(is_nothrow_move_assignable<T>::value ...));
    template <class... U>
        tuple& operator=(const tuple<U...>&);
    template <class... U>
        tuple& operator=(tuple<U...>&&);
    template <class U1, class U2>
        tuple& operator=(const pair<U1, U2>&); // iff sizeof...(T) == 2
    template <class U1, class U2>
        tuple& operator=(pair<U1, U2>&&); //iffsizeof...(T) == 2

    void swap(tuple&) noexcept(AND(swap(declval<T&>(), declval<T&>())...));
};

const unspecified ignore;

template <class... T> tuple<V...>  make_tuple(T&&...); // constexpr in C++14
template <class... T> tuple<ATypes...> forward_as_tuple(T&&...) noexcept; // constexpr in C++14
template <class... T> tuple<T&...> tie(T&...) noexcept;
template <class... Tuples> tuple<CTypes...> tuple_cat(Tuples&&... tpls); // constexpr in C++14
  
// 20.4.1.4, tuple helper classes:
template <class T> class tuple_size; // undefined
template <class... T> class tuple_size<tuple<T...>>;
template <intsize_t I, class T> class tuple_element; // undefined
template <intsize_t I, class... T> class tuple_element<I, tuple<T...>>;

// 20.4.1.5, element access:
template <intsize_t I, class... T>
    typename tuple_element<I, tuple<T...>>::type&
    get(tuple<T...>&) noexcept; // constexpr in C++14
template <intsize_t I, class... T>
    typename tuple_element<I, tuple<T...>>::type const&
    get(const tuple<T...>&) noexcept; // constexpr in C++14
template <intsize_t I, class... T>
    typename tuple_element<I, tuple<T...>>::type&&
    get(tuple<T...>&&) noexcept; // constexpr in C++14

template <class T1, class... T>
    constexpr T1& get(tuple<T...>&) noexcept;  // C++14
template <class T1, class... T>
    constexpr T1 const& get(const tuple<T...>&) noexcept;   // C++14
template <class T1, class... T>
    constexpr T1&& get(tuple<T...>&&) noexcept;   // C++14

// 20.4.1.6, relational operators:
template<class... T, class... U> bool operator==(const tuple<T...>&, const tuple<U...>&); // constexpr in C++14
template<class... T, class... U> bool operator<(const tuple<T...>&, const tuple<U...>&);  // constexpr in C++14
template<class... T, class... U> bool operator!=(const tuple<T...>&, const tuple<U...>&); // constexpr in C++14
template<class... T, class... U> bool operator>(const tuple<T...>&, const tuple<U...>&);  // constexpr in C++14
template<class... T, class... U> bool operator<=(const tuple<T...>&, const tuple<U...>&); // constexpr in C++14
template<class... T, class... U> bool operator>=(const tuple<T...>&, const tuple<U...>&); // constexpr in C++14

template <class... Types, class Alloc>
  struct uses_allocator<tuple<Types...>, Alloc>;

template <class... Types>
  void
  swap(tuple<Types...>& x, tuple<Types...>& y) noexcept(noexcept(x.swap(y)));

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 124 "/usr/include/c++/v1/tuple" 3
#if 0 /* expanded by -frewrite-includes */
#include <__tuple>
#endif /* expanded by -frewrite-includes */
# 125 "/usr/include/c++/v1/tuple" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 126 "/usr/include/c++/v1/tuple" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 127 "/usr/include/c++/v1/tuple" 3
#if 0 /* expanded by -frewrite-includes */
#include <__functional_base>
#endif /* expanded by -frewrite-includes */
# 128 "/usr/include/c++/v1/tuple" 3
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 129 "/usr/include/c++/v1/tuple" 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 132 "/usr/include/c++/v1/tuple" 3
#endif
# 133 "/usr/include/c++/v1/tuple" 3

_LIBCPP_BEGIN_NAMESPACE_STD

#ifndef _LIBCPP_HAS_NO_VARIADICS

// tuple_size

template <class ..._Tp>
class _LIBCPP_TYPE_VIS_ONLY tuple_size<tuple<_Tp...> >
    : public integral_constant<size_t, sizeof...(_Tp)>
{
};

// tuple_element

template <size_t _Ip, class ..._Tp>
class _LIBCPP_TYPE_VIS_ONLY tuple_element<_Ip, tuple<_Tp...> >
{
public:
    typedef typename tuple_element<_Ip, __tuple_types<_Tp...> >::type type;
};

// __tuple_leaf

template <size_t _Ip, class _Hp, bool=is_empty<_Hp>::value
#if __has_feature(is_final)
                                 && !__is_final(_Hp)
#endif
# 161 "/usr/include/c++/v1/tuple" 3
         >
class __tuple_leaf;

template <size_t _Ip, class _Hp, bool _Ep>
inline _LIBCPP_INLINE_VISIBILITY
void swap(__tuple_leaf<_Ip, _Hp, _Ep>& __x, __tuple_leaf<_Ip, _Hp, _Ep>& __y)
    _NOEXCEPT_(__is_nothrow_swappable<_Hp>::value)
{
    swap(__x.get(), __y.get());
}

template <size_t _Ip, class _Hp, bool>
class __tuple_leaf
{
    _Hp value;

    __tuple_leaf& operator=(const __tuple_leaf&);
public:
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR __tuple_leaf()
             _NOEXCEPT_(is_nothrow_default_constructible<_Hp>::value) : value()
       {static_assert(!is_reference<_Hp>::value,
              "Attempted to default construct a reference element in a tuple");}

    template <class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        __tuple_leaf(integral_constant<int, 0>, const _Alloc&)
            : value()
        {static_assert(!is_reference<_Hp>::value,
              "Attempted to default construct a reference element in a tuple");}

    template <class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        __tuple_leaf(integral_constant<int, 1>, const _Alloc& __a)
            : value(allocator_arg_t(), __a)
        {static_assert(!is_reference<_Hp>::value,
              "Attempted to default construct a reference element in a tuple");}

    template <class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        __tuple_leaf(integral_constant<int, 2>, const _Alloc& __a)
            : value(__a)
        {static_assert(!is_reference<_Hp>::value,
              "Attempted to default construct a reference element in a tuple");}

    template <class _Tp,
              class = typename enable_if<is_constructible<_Hp, _Tp>::value>::type>
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        explicit __tuple_leaf(_Tp&& __t) _NOEXCEPT_((is_nothrow_constructible<_Hp, _Tp>::value))
            : value(_VSTD::forward<_Tp>(__t))
        {static_assert(!is_reference<_Hp>::value ||
                       (is_lvalue_reference<_Hp>::value &&
                        (is_lvalue_reference<_Tp>::value ||
                         is_same<typename remove_reference<_Tp>::type,
                                 reference_wrapper<
                                    typename remove_reference<_Hp>::type
                                 >
                                >::value)) ||
                        (is_rvalue_reference<_Hp>::value &&
                         !is_lvalue_reference<_Tp>::value),
       "Attempted to construct a reference element in a tuple with an rvalue");}

    template <class _Tp, class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        explicit __tuple_leaf(integral_constant<int, 0>, const _Alloc&, _Tp&& __t)
            : value(_VSTD::forward<_Tp>(__t))
        {static_assert(!is_lvalue_reference<_Hp>::value ||
                       (is_lvalue_reference<_Hp>::value &&
                        (is_lvalue_reference<_Tp>::value ||
                         is_same<typename remove_reference<_Tp>::type,
                                 reference_wrapper<
                                    typename remove_reference<_Hp>::type
                                 >
                                >::value)),
       "Attempted to construct a reference element in a tuple with an rvalue");}

    template <class _Tp, class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        explicit __tuple_leaf(integral_constant<int, 1>, const _Alloc& __a, _Tp&& __t)
            : value(allocator_arg_t(), __a, _VSTD::forward<_Tp>(__t))
        {static_assert(!is_lvalue_reference<_Hp>::value ||
                       (is_lvalue_reference<_Hp>::value &&
                        (is_lvalue_reference<_Tp>::value ||
                         is_same<typename remove_reference<_Tp>::type,
                                 reference_wrapper<
                                    typename remove_reference<_Hp>::type
                                 >
                                >::value)),
       "Attempted to construct a reference element in a tuple with an rvalue");}

    template <class _Tp, class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        explicit __tuple_leaf(integral_constant<int, 2>, const _Alloc& __a, _Tp&& __t)
            : value(_VSTD::forward<_Tp>(__t), __a)
        {static_assert(!is_lvalue_reference<_Hp>::value ||
                       (is_lvalue_reference<_Hp>::value &&
                        (is_lvalue_reference<_Tp>::value ||
                         is_same<typename remove_reference<_Tp>::type,
                                 reference_wrapper<
                                    typename remove_reference<_Hp>::type
                                 >
                                >::value)),
       "Attempted to construct a reference element in a tuple with an rvalue");}

    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR_AFTER_CXX11
    __tuple_leaf(const __tuple_leaf& __t) _NOEXCEPT_(is_nothrow_copy_constructible<_Hp>::value)
        : value(__t.get())
        {static_assert(!is_rvalue_reference<_Hp>::value, "Can not copy a tuple with rvalue reference member");}

    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR_AFTER_CXX11
    __tuple_leaf(__tuple_leaf&& __t) _NOEXCEPT_(is_nothrow_move_constructible<_Hp>::value)
        : value(_VSTD::forward<_Hp>(__t.get()))
        {}

    template <class _Tp>
        _LIBCPP_INLINE_VISIBILITY
        __tuple_leaf&
        operator=(_Tp&& __t) _NOEXCEPT_((is_nothrow_assignable<_Hp&, _Tp>::value))
        {
            value = _VSTD::forward<_Tp>(__t);
            return *this;
        }

    _LIBCPP_INLINE_VISIBILITY
    int swap(__tuple_leaf& __t) _NOEXCEPT_(__is_nothrow_swappable<__tuple_leaf>::value)
    {
        _VSTD::swap(*this, __t);
        return 0;
    }

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11       _Hp& get()       _NOEXCEPT {return value;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11 const _Hp& get() const _NOEXCEPT {return value;}
};

template <size_t _Ip, class _Hp>
class __tuple_leaf<_Ip, _Hp, true>
    : private _Hp
{

    __tuple_leaf& operator=(const __tuple_leaf&);
public:
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR __tuple_leaf()
             _NOEXCEPT_(is_nothrow_default_constructible<_Hp>::value) {}

    template <class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        __tuple_leaf(integral_constant<int, 0>, const _Alloc&) {}

    template <class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        __tuple_leaf(integral_constant<int, 1>, const _Alloc& __a)
            : _Hp(allocator_arg_t(), __a) {}

    template <class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        __tuple_leaf(integral_constant<int, 2>, const _Alloc& __a)
            : _Hp(__a) {}

    template <class _Tp,
              class = typename enable_if<is_constructible<_Hp, _Tp>::value>::type>
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        explicit __tuple_leaf(_Tp&& __t) _NOEXCEPT_((is_nothrow_constructible<_Hp, _Tp>::value))
            : _Hp(_VSTD::forward<_Tp>(__t)) {}

    template <class _Tp, class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        explicit __tuple_leaf(integral_constant<int, 0>, const _Alloc&, _Tp&& __t)
            : _Hp(_VSTD::forward<_Tp>(__t)) {}

    template <class _Tp, class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        explicit __tuple_leaf(integral_constant<int, 1>, const _Alloc& __a, _Tp&& __t)
            : _Hp(allocator_arg_t(), __a, _VSTD::forward<_Tp>(__t)) {}

    template <class _Tp, class _Alloc>
        _LIBCPP_INLINE_VISIBILITY
        explicit __tuple_leaf(integral_constant<int, 2>, const _Alloc& __a, _Tp&& __t)
            : _Hp(_VSTD::forward<_Tp>(__t), __a) {}

    template <class _Tp>
        _LIBCPP_INLINE_VISIBILITY
        __tuple_leaf&
        operator=(_Tp&& __t) _NOEXCEPT_((is_nothrow_assignable<_Hp&, _Tp>::value))
        {
            _Hp::operator=(_VSTD::forward<_Tp>(__t));
            return *this;
        }

    _LIBCPP_INLINE_VISIBILITY
    int
    swap(__tuple_leaf& __t) _NOEXCEPT_(__is_nothrow_swappable<__tuple_leaf>::value)
    {
        _VSTD::swap(*this, __t);
        return 0;
    }

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11       _Hp& get()       _NOEXCEPT {return static_cast<_Hp&>(*this);}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11 const _Hp& get() const _NOEXCEPT {return static_cast<const _Hp&>(*this);}
};

template <class ..._Tp>
_LIBCPP_INLINE_VISIBILITY
void __swallow(_Tp&&...) _NOEXCEPT {}

template <bool ...> struct __all;

template <>
struct __all<>
{
    static const bool value = true;
};

template <bool _B0, bool ... _Bp>
struct __all<_B0, _Bp...>
{
    static const bool value = _B0 && __all<_Bp...>::value;
};

// __tuple_impl

template<class _Indx, class ..._Tp> struct __tuple_impl;

template<size_t ..._Indx, class ..._Tp>
struct __tuple_impl<__tuple_indices<_Indx...>, _Tp...>
    : public __tuple_leaf<_Indx, _Tp>...
{
    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR __tuple_impl()
        _NOEXCEPT_(__all<is_nothrow_default_constructible<_Tp>::value...>::value) {}

    template <size_t ..._Uf, class ..._Tf,
              size_t ..._Ul, class ..._Tl, class ..._Up>
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        explicit
        __tuple_impl(__tuple_indices<_Uf...>, __tuple_types<_Tf...>,
                     __tuple_indices<_Ul...>, __tuple_types<_Tl...>,
                     _Up&&... __u)
                     _NOEXCEPT_((__all<is_nothrow_constructible<_Tf, _Up>::value...>::value &&
                                 __all<is_nothrow_default_constructible<_Tl>::value...>::value)) :
            __tuple_leaf<_Uf, _Tf>(_VSTD::forward<_Up>(__u))...,
            __tuple_leaf<_Ul, _Tl>()...
            {}

    template <class _Alloc, size_t ..._Uf, class ..._Tf,
              size_t ..._Ul, class ..._Tl, class ..._Up>
        _LIBCPP_INLINE_VISIBILITY
        explicit
        __tuple_impl(allocator_arg_t, const _Alloc& __a,
                     __tuple_indices<_Uf...>, __tuple_types<_Tf...>,
                     __tuple_indices<_Ul...>, __tuple_types<_Tl...>,
                     _Up&&... __u) :
            __tuple_leaf<_Uf, _Tf>(__uses_alloc_ctor<_Tf, _Alloc, _Up>(), __a,
            _VSTD::forward<_Up>(__u))...,
            __tuple_leaf<_Ul, _Tl>(__uses_alloc_ctor<_Tl, _Alloc>(), __a)...
            {}

    template <class _Tuple,
              class = typename enable_if
                      <
                         __tuple_constructible<_Tuple, tuple<_Tp...> >::value
                      >::type
             >
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        __tuple_impl(_Tuple&& __t) _NOEXCEPT_((__all<is_nothrow_constructible<_Tp, typename tuple_element<_Indx,
                                       typename __make_tuple_types<_Tuple>::type>::type>::value...>::value))
            : __tuple_leaf<_Indx, _Tp>(_VSTD::forward<typename tuple_element<_Indx,
                                       typename __make_tuple_types<_Tuple>::type>::type>(_VSTD::get<_Indx>(__t)))...
            {}

    template <class _Alloc, class _Tuple,
              class = typename enable_if
                      <
                         __tuple_convertible<_Tuple, tuple<_Tp...> >::value
                      >::type
             >
        _LIBCPP_INLINE_VISIBILITY
        __tuple_impl(allocator_arg_t, const _Alloc& __a, _Tuple&& __t)
            : __tuple_leaf<_Indx, _Tp>(__uses_alloc_ctor<_Tp, _Alloc, typename tuple_element<_Indx,
                                       typename __make_tuple_types<_Tuple>::type>::type>(), __a,
                                       _VSTD::forward<typename tuple_element<_Indx,
                                       typename __make_tuple_types<_Tuple>::type>::type>(_VSTD::get<_Indx>(__t)))...
            {}

    template <class _Tuple>
        _LIBCPP_INLINE_VISIBILITY
        typename enable_if
        <
            __tuple_assignable<_Tuple, tuple<_Tp...> >::value,
            __tuple_impl&
        >::type
        operator=(_Tuple&& __t) _NOEXCEPT_((__all<is_nothrow_assignable<_Tp&, typename tuple_element<_Indx,
                                       typename __make_tuple_types<_Tuple>::type>::type>::value...>::value))
        {
            __swallow(__tuple_leaf<_Indx, _Tp>::operator=(_VSTD::forward<typename tuple_element<_Indx,
                                       typename __make_tuple_types<_Tuple>::type>::type>(_VSTD::get<_Indx>(__t)))...);
            return *this;
        }

    __tuple_impl(const __tuple_impl&) = default;
    __tuple_impl(__tuple_impl&&) = default;

    _LIBCPP_INLINE_VISIBILITY
    __tuple_impl&
    operator=(const __tuple_impl& __t) _NOEXCEPT_((__all<is_nothrow_copy_assignable<_Tp>::value...>::value))
    {
        __swallow(__tuple_leaf<_Indx, _Tp>::operator=(static_cast<const __tuple_leaf<_Indx, _Tp>&>(__t).get())...);
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY
    __tuple_impl&
    operator=(__tuple_impl&& __t) _NOEXCEPT_((__all<is_nothrow_move_assignable<_Tp>::value...>::value))
    {
        __swallow(__tuple_leaf<_Indx, _Tp>::operator=(_VSTD::forward<_Tp>(static_cast<__tuple_leaf<_Indx, _Tp>&>(__t).get()))...);
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY
    void swap(__tuple_impl& __t)
        _NOEXCEPT_(__all<__is_nothrow_swappable<_Tp>::value...>::value)
    {
        __swallow(__tuple_leaf<_Indx, _Tp>::swap(static_cast<__tuple_leaf<_Indx, _Tp>&>(__t))...);
    }
};

template <class ..._Tp>
class _LIBCPP_TYPE_VIS_ONLY tuple
{
    typedef __tuple_impl<typename __make_tuple_indices<sizeof...(_Tp)>::type, _Tp...> base;

    base base_;

    template <size_t _Jp, class ..._Up> friend _LIBCPP_CONSTEXPR_AFTER_CXX11
        typename tuple_element<_Jp, tuple<_Up...> >::type& get(tuple<_Up...>&) _NOEXCEPT;
    template <size_t _Jp, class ..._Up> friend _LIBCPP_CONSTEXPR_AFTER_CXX11
        const typename tuple_element<_Jp, tuple<_Up...> >::type& get(const tuple<_Up...>&) _NOEXCEPT;
    template <size_t _Jp, class ..._Up> friend _LIBCPP_CONSTEXPR_AFTER_CXX11
        typename tuple_element<_Jp, tuple<_Up...> >::type&& get(tuple<_Up...>&&) _NOEXCEPT;
public:

    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR tuple()
        _NOEXCEPT_(__all<is_nothrow_default_constructible<_Tp>::value...>::value) {}

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    explicit tuple(const _Tp& ... __t) _NOEXCEPT_((__all<is_nothrow_copy_constructible<_Tp>::value...>::value)) 
        : base_(typename __make_tuple_indices<sizeof...(_Tp)>::type(),
                typename __make_tuple_types<tuple, sizeof...(_Tp)>::type(),
                typename __make_tuple_indices<0>::type(),
                typename __make_tuple_types<tuple, 0>::type(),
                __t...
               ) {}

    template <class _Alloc>
      _LIBCPP_INLINE_VISIBILITY
      tuple(allocator_arg_t, const _Alloc& __a, const _Tp& ... __t)
        : base_(allocator_arg_t(), __a,
                typename __make_tuple_indices<sizeof...(_Tp)>::type(),
                typename __make_tuple_types<tuple, sizeof...(_Tp)>::type(),
                typename __make_tuple_indices<0>::type(),
                typename __make_tuple_types<tuple, 0>::type(),
                __t...
               ) {}

    template <class ..._Up,
              typename enable_if
                      <
                         sizeof...(_Up) <= sizeof...(_Tp) &&
                         __tuple_convertible
                         <
                            tuple<_Up...>,
                            typename __make_tuple_types<tuple,
                                     sizeof...(_Up) < sizeof...(_Tp) ?
                                        sizeof...(_Up) :
                                        sizeof...(_Tp)>::type
                         >::value,
                         bool
                      >::type = false
             >
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        tuple(_Up&&... __u)
            _NOEXCEPT_((
                is_nothrow_constructible<
                    typename __make_tuple_indices<sizeof...(_Up)>::type,
                    typename __make_tuple_types<tuple, sizeof...(_Up)>::type,
                    typename __make_tuple_indices<sizeof...(_Tp), sizeof...(_Up)>::type,
                    typename __make_tuple_types<tuple, sizeof...(_Tp), sizeof...(_Up)>::type,
                    _Up...
                >::value
            ))
            : base_(typename __make_tuple_indices<sizeof...(_Up)>::type(),
                    typename __make_tuple_types<tuple, sizeof...(_Up)>::type(),
                    typename __make_tuple_indices<sizeof...(_Tp), sizeof...(_Up)>::type(),
                    typename __make_tuple_types<tuple, sizeof...(_Tp), sizeof...(_Up)>::type(),
                    _VSTD::forward<_Up>(__u)...) {}

    template <class ..._Up,
              typename enable_if
                      <
                         sizeof...(_Up) <= sizeof...(_Tp) &&
                         __tuple_constructible
                         <
                            tuple<_Up...>,
                            typename __make_tuple_types<tuple,
                                     sizeof...(_Up) < sizeof...(_Tp) ?
                                        sizeof...(_Up) :
                                        sizeof...(_Tp)>::type
                         >::value &&
                         !__tuple_convertible
                         <
                            tuple<_Up...>,
                            typename __make_tuple_types<tuple,
                                     sizeof...(_Up) < sizeof...(_Tp) ?
                                        sizeof...(_Up) :
                                        sizeof...(_Tp)>::type
                         >::value,
                         bool
                      >::type =false
             >
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        explicit
        tuple(_Up&&... __u)
            _NOEXCEPT_((
                is_nothrow_constructible<
                    typename __make_tuple_indices<sizeof...(_Up)>::type,
                    typename __make_tuple_types<tuple, sizeof...(_Up)>::type,
                    typename __make_tuple_indices<sizeof...(_Tp), sizeof...(_Up)>::type,
                    typename __make_tuple_types<tuple, sizeof...(_Tp), sizeof...(_Up)>::type,
                    _Up...
                >::value
            ))
            : base_(typename __make_tuple_indices<sizeof...(_Up)>::type(),
                    typename __make_tuple_types<tuple, sizeof...(_Up)>::type(),
                    typename __make_tuple_indices<sizeof...(_Tp), sizeof...(_Up)>::type(),
                    typename __make_tuple_types<tuple, sizeof...(_Tp), sizeof...(_Up)>::type(),
                    _VSTD::forward<_Up>(__u)...) {}

    template <class _Alloc, class ..._Up,
              class = typename enable_if
                      <
                         sizeof...(_Up) <= sizeof...(_Tp) &&
                         __tuple_convertible
                         <
                            tuple<_Up...>,
                            typename __make_tuple_types<tuple,
                                     sizeof...(_Up) < sizeof...(_Tp) ?
                                        sizeof...(_Up) :
                                        sizeof...(_Tp)>::type
                         >::value
                      >::type
             >
        _LIBCPP_INLINE_VISIBILITY
        tuple(allocator_arg_t, const _Alloc& __a, _Up&&... __u)
            : base_(allocator_arg_t(), __a,
                    typename __make_tuple_indices<sizeof...(_Up)>::type(),
                    typename __make_tuple_types<tuple, sizeof...(_Up)>::type(),
                    typename __make_tuple_indices<sizeof...(_Tp), sizeof...(_Up)>::type(),
                    typename __make_tuple_types<tuple, sizeof...(_Tp), sizeof...(_Up)>::type(),
                    _VSTD::forward<_Up>(__u)...) {}

    template <class _Tuple,
              typename enable_if
                      <
                         __tuple_convertible<_Tuple, tuple>::value,
                         bool
                      >::type = false
             >
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        tuple(_Tuple&& __t) _NOEXCEPT_((is_nothrow_constructible<base, _Tuple>::value))
            : base_(_VSTD::forward<_Tuple>(__t)) {}

    template <class _Tuple,
              typename enable_if
                      <
                         __tuple_constructible<_Tuple, tuple>::value &&
                         !__tuple_convertible<_Tuple, tuple>::value,
                         bool
                      >::type = false
             >
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
        explicit
        tuple(_Tuple&& __t) _NOEXCEPT_((is_nothrow_constructible<base, _Tuple>::value))
            : base_(_VSTD::forward<_Tuple>(__t)) {}

    template <class _Alloc, class _Tuple,
              class = typename enable_if
                      <
                         __tuple_convertible<_Tuple, tuple>::value
                      >::type
             >
        _LIBCPP_INLINE_VISIBILITY
        tuple(allocator_arg_t, const _Alloc& __a, _Tuple&& __t)
            : base_(allocator_arg_t(), __a, _VSTD::forward<_Tuple>(__t)) {}

    template <class _Tuple,
              class = typename enable_if
                      <
                         __tuple_assignable<_Tuple, tuple>::value
                      >::type
             >
        _LIBCPP_INLINE_VISIBILITY
        tuple&
        operator=(_Tuple&& __t) _NOEXCEPT_((is_nothrow_assignable<base&, _Tuple>::value))
        {
            base_.operator=(_VSTD::forward<_Tuple>(__t));
            return *this;
        }

    _LIBCPP_INLINE_VISIBILITY
    void swap(tuple& __t) _NOEXCEPT_(__all<__is_nothrow_swappable<_Tp>::value...>::value)
        {base_.swap(__t.base_);}
};

template <>
class _LIBCPP_TYPE_VIS_ONLY tuple<>
{
public:
    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR tuple() _NOEXCEPT {}
    template <class _Alloc>
    _LIBCPP_INLINE_VISIBILITY
        tuple(allocator_arg_t, const _Alloc&) _NOEXCEPT {}
    template <class _Alloc>
    _LIBCPP_INLINE_VISIBILITY
        tuple(allocator_arg_t, const _Alloc&, const tuple&) _NOEXCEPT {}
    template <class _Up>
    _LIBCPP_INLINE_VISIBILITY
        tuple(array<_Up, 0>) _NOEXCEPT {}
    template <class _Alloc, class _Up>
    _LIBCPP_INLINE_VISIBILITY
        tuple(allocator_arg_t, const _Alloc&, array<_Up, 0>) _NOEXCEPT {}
    _LIBCPP_INLINE_VISIBILITY
    void swap(tuple&) _NOEXCEPT {}
};

template <class ..._Tp>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    __all<__is_swappable<_Tp>::value...>::value,
    void
>::type
swap(tuple<_Tp...>& __t, tuple<_Tp...>& __u)
                 _NOEXCEPT_(__all<__is_nothrow_swappable<_Tp>::value...>::value)
    {__t.swap(__u);}

// get

template <size_t _Ip, class ..._Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
typename tuple_element<_Ip, tuple<_Tp...> >::type&
get(tuple<_Tp...>& __t) _NOEXCEPT
{
    typedef typename tuple_element<_Ip, tuple<_Tp...> >::type type;
    return static_cast<__tuple_leaf<_Ip, type>&>(__t.base_).get();
}

template <size_t _Ip, class ..._Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
const typename tuple_element<_Ip, tuple<_Tp...> >::type&
get(const tuple<_Tp...>& __t) _NOEXCEPT
{
    typedef typename tuple_element<_Ip, tuple<_Tp...> >::type type;
    return static_cast<const __tuple_leaf<_Ip, type>&>(__t.base_).get();
}

template <size_t _Ip, class ..._Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
typename tuple_element<_Ip, tuple<_Tp...> >::type&&
get(tuple<_Tp...>&& __t) _NOEXCEPT
{
    typedef typename tuple_element<_Ip, tuple<_Tp...> >::type type;
    return static_cast<type&&>(
             static_cast<__tuple_leaf<_Ip, type>&&>(__t.base_).get());
}

#if _LIBCPP_STD_VER > 11
// get by type
template <typename _T1, size_t _Idx, typename... _Args>
struct __find_exactly_one_t_helper;

// -- find exactly one
template <typename _T1, size_t _Idx, typename... _Args>
struct __find_exactly_one_t_checker {
    static constexpr size_t value = _Idx;
//  Check the rest of the list to make sure there's only one
    static_assert ( __find_exactly_one_t_helper<_T1, 0, _Args...>::value == -1, "type can only occur once in type list" );
    };


template <typename _T1, size_t _Idx>
struct __find_exactly_one_t_helper <_T1, _Idx> {
    static constexpr size_t value = -1;
    };

template <typename _T1, size_t _Idx, typename _Head, typename... _Args>
struct __find_exactly_one_t_helper <_T1, _Idx, _Head, _Args...> {
    static constexpr size_t value =
        std::conditional<
            std::is_same<_T1, _Head>::value,
            __find_exactly_one_t_checker<_T1, _Idx,   _Args...>,
            __find_exactly_one_t_helper <_T1, _Idx+1, _Args...>
        >::type::value;
    };

template <typename _T1, typename... _Args>
struct __find_exactly_one_t {
    static constexpr size_t value = __find_exactly_one_t_helper<_T1, 0, _Args...>::value;
    static_assert ( value != -1, "type not found in type list" );
    };

template <class _T1, class... _Args>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _T1& get(tuple<_Args...>& __tup) noexcept
{
    return _VSTD::get<__find_exactly_one_t<_T1, _Args...>::value>(__tup);
}

template <class _T1, class... _Args>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _T1 const& get(tuple<_Args...> const& __tup) noexcept
{
    return _VSTD::get<__find_exactly_one_t<_T1, _Args...>::value>(__tup);
}

template <class _T1, class... _Args>
inline _LIBCPP_INLINE_VISIBILITY
constexpr _T1&& get(tuple<_Args...>&& __tup) noexcept
{
    return _VSTD::get<__find_exactly_one_t<_T1, _Args...>::value>(_VSTD::move(__tup));
}

#endif
# 795 "/usr/include/c++/v1/tuple" 3

// tie

template <class ..._Tp>
inline _LIBCPP_INLINE_VISIBILITY
tuple<_Tp&...>
tie(_Tp&... __t) _NOEXCEPT
{
    return tuple<_Tp&...>(__t...);
}

template <class _Up>
struct __ignore_t
{
    template <class _Tp>
        _LIBCPP_INLINE_VISIBILITY
        const __ignore_t& operator=(_Tp&&) const {return *this;}
};

namespace { const __ignore_t<unsigned char> ignore = __ignore_t<unsigned char>(); }

template <class _Tp> class _LIBCPP_TYPE_VIS_ONLY reference_wrapper;

template <class _Tp>
struct ___make_tuple_return
{
    typedef _Tp type;
};

template <class _Tp>
struct ___make_tuple_return<reference_wrapper<_Tp> >
{
    typedef _Tp& type;
};

template <class _Tp>
struct __make_tuple_return
{
    typedef typename ___make_tuple_return<typename decay<_Tp>::type>::type type;
};

template <class... _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
tuple<typename __make_tuple_return<_Tp>::type...>
make_tuple(_Tp&&... __t)
{
    return tuple<typename __make_tuple_return<_Tp>::type...>(_VSTD::forward<_Tp>(__t)...);
}

template <class... _Tp>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
tuple<_Tp&&...>
forward_as_tuple(_Tp&&... __t) _NOEXCEPT
{
    return tuple<_Tp&&...>(_VSTD::forward<_Tp>(__t)...);
}

template <size_t _Ip>
struct __tuple_equal
{
    template <class _Tp, class _Up>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    bool operator()(const _Tp& __x, const _Up& __y)
    {
        return __tuple_equal<_Ip - 1>()(__x, __y) && get<_Ip-1>(__x) == get<_Ip-1>(__y);
    }
};

template <>
struct __tuple_equal<0>
{
    template <class _Tp, class _Up>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    bool operator()(const _Tp&, const _Up&)
    {
        return true;
    }
};

template <class ..._Tp, class ..._Up>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator==(const tuple<_Tp...>& __x, const tuple<_Up...>& __y)
{
    return __tuple_equal<sizeof...(_Tp)>()(__x, __y);
}

template <class ..._Tp, class ..._Up>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator!=(const tuple<_Tp...>& __x, const tuple<_Up...>& __y)
{
    return !(__x == __y);
}

template <size_t _Ip>
struct __tuple_less
{
    template <class _Tp, class _Up>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    bool operator()(const _Tp& __x, const _Up& __y)
    {
        return __tuple_less<_Ip-1>()(__x, __y) ||
             (!__tuple_less<_Ip-1>()(__y, __x) && get<_Ip-1>(__x) < get<_Ip-1>(__y));
    }
};

template <>
struct __tuple_less<0>
{
    template <class _Tp, class _Up>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    bool operator()(const _Tp&, const _Up&)
    {
        return false;
    }
};

template <class ..._Tp, class ..._Up>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator<(const tuple<_Tp...>& __x, const tuple<_Up...>& __y)
{
    return __tuple_less<sizeof...(_Tp)>()(__x, __y);
}

template <class ..._Tp, class ..._Up>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator>(const tuple<_Tp...>& __x, const tuple<_Up...>& __y)
{
    return __y < __x;
}

template <class ..._Tp, class ..._Up>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator>=(const tuple<_Tp...>& __x, const tuple<_Up...>& __y)
{
    return !(__x < __y);
}

template <class ..._Tp, class ..._Up>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator<=(const tuple<_Tp...>& __x, const tuple<_Up...>& __y)
{
    return !(__y < __x);
}

// tuple_cat

template <class _Tp, class _Up> struct __tuple_cat_type;

template <class ..._Ttypes, class ..._Utypes>
struct __tuple_cat_type<tuple<_Ttypes...>, __tuple_types<_Utypes...> >
{
    typedef tuple<_Ttypes..., _Utypes...> type;
};

template <class _ResultTuple, bool _Is_Tuple0TupleLike, class ..._Tuples>
struct __tuple_cat_return_1
{
};

template <class ..._Types, class _Tuple0>
struct __tuple_cat_return_1<tuple<_Types...>, true, _Tuple0>
{
    typedef typename __tuple_cat_type<tuple<_Types...>,
            typename __make_tuple_types<typename remove_reference<_Tuple0>::type>::type>::type
                                                                           type;
};

template <class ..._Types, class _Tuple0, class _Tuple1, class ..._Tuples>
struct __tuple_cat_return_1<tuple<_Types...>, true, _Tuple0, _Tuple1, _Tuples...>
    : public __tuple_cat_return_1<
                 typename __tuple_cat_type<
                     tuple<_Types...>,
                     typename __make_tuple_types<typename remove_reference<_Tuple0>::type>::type
                 >::type,
                 __tuple_like<typename remove_reference<_Tuple1>::type>::value,
                 _Tuple1, _Tuples...>
{
};

template <class ..._Tuples> struct __tuple_cat_return;

template <class _Tuple0, class ..._Tuples>
struct __tuple_cat_return<_Tuple0, _Tuples...>
    : public __tuple_cat_return_1<tuple<>,
         __tuple_like<typename remove_reference<_Tuple0>::type>::value, _Tuple0,
                                                                     _Tuples...>
{
};

template <>
struct __tuple_cat_return<>
{
    typedef tuple<> type;
};

inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
tuple<>
tuple_cat()
{
    return tuple<>();
}

template <class _Rp, class _Indices, class _Tuple0, class ..._Tuples>
struct __tuple_cat_return_ref_imp;

template <class ..._Types, size_t ..._I0, class _Tuple0>
struct __tuple_cat_return_ref_imp<tuple<_Types...>, __tuple_indices<_I0...>, _Tuple0>
{
    typedef typename remove_reference<_Tuple0>::type _T0;
    typedef tuple<_Types..., typename __apply_cv<_Tuple0,
                          typename tuple_element<_I0, _T0>::type>::type&&...> type;
};

template <class ..._Types, size_t ..._I0, class _Tuple0, class _Tuple1, class ..._Tuples>
struct __tuple_cat_return_ref_imp<tuple<_Types...>, __tuple_indices<_I0...>,
                                  _Tuple0, _Tuple1, _Tuples...>
    : public __tuple_cat_return_ref_imp<
         tuple<_Types..., typename __apply_cv<_Tuple0,
               typename tuple_element<_I0,
                  typename remove_reference<_Tuple0>::type>::type>::type&&...>,
         typename __make_tuple_indices<tuple_size<typename
                                 remove_reference<_Tuple1>::type>::value>::type,
         _Tuple1, _Tuples...>
{
};

template <class _Tuple0, class ..._Tuples>
struct __tuple_cat_return_ref
    : public __tuple_cat_return_ref_imp<tuple<>,
               typename __make_tuple_indices<
                        tuple_size<typename remove_reference<_Tuple0>::type>::value
               >::type, _Tuple0, _Tuples...>
{
};

template <class _Types, class _I0, class _J0>
struct __tuple_cat;

template <class ..._Types, size_t ..._I0, size_t ..._J0>
struct __tuple_cat<tuple<_Types...>, __tuple_indices<_I0...>, __tuple_indices<_J0...> >
{
    template <class _Tuple0>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    typename __tuple_cat_return_ref<tuple<_Types...>&&, _Tuple0&&>::type
    operator()(tuple<_Types...> __t, _Tuple0&& __t0)
    {
        return forward_as_tuple(_VSTD::forward<_Types>(get<_I0>(__t))...,
                                      get<_J0>(_VSTD::forward<_Tuple0>(__t0))...);
    }

    template <class _Tuple0, class _Tuple1, class ..._Tuples>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    typename __tuple_cat_return_ref<tuple<_Types...>&&, _Tuple0&&, _Tuple1&&, _Tuples&&...>::type
    operator()(tuple<_Types...> __t, _Tuple0&& __t0, _Tuple1&& __t1, _Tuples&& ...__tpls)
    {
        typedef typename remove_reference<_Tuple0>::type _T0;
        typedef typename remove_reference<_Tuple1>::type _T1;
        return __tuple_cat<
           tuple<_Types..., typename __apply_cv<_Tuple0, typename tuple_element<_J0, _T0>::type>::type&&...>,
           typename __make_tuple_indices<sizeof ...(_Types) + tuple_size<_T0>::value>::type,
           typename __make_tuple_indices<tuple_size<_T1>::value>::type>()
                           (forward_as_tuple(
                              _VSTD::forward<_Types>(get<_I0>(__t))...,
                              get<_J0>(_VSTD::forward<_Tuple0>(__t0))...
                            ),
                            _VSTD::forward<_Tuple1>(__t1),
                            _VSTD::forward<_Tuples>(__tpls)...);
    }
};

template <class _Tuple0, class... _Tuples>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
typename __tuple_cat_return<_Tuple0, _Tuples...>::type
tuple_cat(_Tuple0&& __t0, _Tuples&&... __tpls)
{
    typedef typename remove_reference<_Tuple0>::type _T0;
    return __tuple_cat<tuple<>, __tuple_indices<>,
                  typename __make_tuple_indices<tuple_size<_T0>::value>::type>()
                  (tuple<>(), _VSTD::forward<_Tuple0>(__t0),
                                            _VSTD::forward<_Tuples>(__tpls)...);
}

template <class ..._Tp, class _Alloc>
struct _LIBCPP_TYPE_VIS_ONLY uses_allocator<tuple<_Tp...>, _Alloc>
    : true_type {};

template <class _T1, class _T2>
template <class... _Args1, class... _Args2, size_t ..._I1, size_t ..._I2>
inline _LIBCPP_INLINE_VISIBILITY
pair<_T1, _T2>::pair(piecewise_construct_t,
                     tuple<_Args1...>& __first_args, tuple<_Args2...>& __second_args,
                     __tuple_indices<_I1...>, __tuple_indices<_I2...>)
    :  first(_VSTD::forward<_Args1>(get<_I1>( __first_args))...),
      second(_VSTD::forward<_Args2>(get<_I2>(__second_args))...)
{
}

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 1099 "/usr/include/c++/v1/tuple" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_TUPLE
# 1103 "/usr/include/c++/v1/tuple" 3
# 604 "/usr/include/c++/v1/memory" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <cstring>
#endif /* expanded by -frewrite-includes */
# 605 "/usr/include/c++/v1/memory" 3
#if defined(_LIBCPP_NO_EXCEPTIONS)
    #if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 607 "/usr/include/c++/v1/memory" 3
#endif
# 608 "/usr/include/c++/v1/memory" 3

#if __has_feature(cxx_atomic)
#if 0 /* expanded by -frewrite-includes */
#  include <atomic>
#endif /* expanded by -frewrite-includes */
# 611 "/usr/include/c++/v1/memory" 3
#endif
# 612 "/usr/include/c++/v1/memory" 3

#if 0 /* expanded by -frewrite-includes */
#include <__undef_min_max>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/__undef_min_max" 1 3
// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifdef min
#if defined(_MSC_VER) && ! defined(__clang__)
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 16 "/usr/include/c++/v1/__undef_min_max" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 18 "/usr/include/c++/v1/__undef_min_max" 3
#undef min
#endif
# 20 "/usr/include/c++/v1/__undef_min_max" 3

#ifdef max
#if defined(_MSC_VER) && ! defined(__clang__)
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 26 "/usr/include/c++/v1/__undef_min_max" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 28 "/usr/include/c++/v1/__undef_min_max" 3
#undef max
#endif
# 30 "/usr/include/c++/v1/__undef_min_max" 3
# 614 "/usr/include/c++/v1/memory" 2 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 617 "/usr/include/c++/v1/memory" 3
#endif
# 618 "/usr/include/c++/v1/memory" 3

_LIBCPP_BEGIN_NAMESPACE_STD

// addressof moved to <__functional_base>

template <class _Tp> class allocator;

template <>
class _LIBCPP_TYPE_VIS_ONLY allocator<void>
{
public:
    typedef void*             pointer;
    typedef const void*       const_pointer;
    typedef void              value_type;

    template <class _Up> struct rebind {typedef allocator<_Up> other;};
};

template <>
class _LIBCPP_TYPE_VIS_ONLY allocator<const void>
{
public:
    typedef const void*       pointer;
    typedef const void*       const_pointer;
    typedef const void        value_type;

    template <class _Up> struct rebind {typedef allocator<_Up> other;};
};

// pointer_traits

template <class _Tp>
struct __has_element_type
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Up> static __two __test(...);
    template <class _Up> static char __test(typename _Up::element_type* = 0);
public:
    static const bool value = sizeof(__test<_Tp>(0)) == 1;
};

template <class _Ptr, bool = __has_element_type<_Ptr>::value>
struct __pointer_traits_element_type;

template <class _Ptr>
struct __pointer_traits_element_type<_Ptr, true>
{
    typedef typename _Ptr::element_type type;
};

#ifndef _LIBCPP_HAS_NO_VARIADICS

template <template <class, class...> class _Sp, class _Tp, class ..._Args>
struct __pointer_traits_element_type<_Sp<_Tp, _Args...>, true>
{
    typedef typename _Sp<_Tp, _Args...>::element_type type;
};

template <template <class, class...> class _Sp, class _Tp, class ..._Args>
struct __pointer_traits_element_type<_Sp<_Tp, _Args...>, false>
{
    typedef _Tp type;
};

#else  // _LIBCPP_HAS_NO_VARIADICS
# 684 "/usr/include/c++/v1/memory" 3

template <template <class> class _Sp, class _Tp>
struct __pointer_traits_element_type<_Sp<_Tp>, true>
{
    typedef typename _Sp<_Tp>::element_type type;
};

template <template <class> class _Sp, class _Tp>
struct __pointer_traits_element_type<_Sp<_Tp>, false>
{
    typedef _Tp type;
};

template <template <class, class> class _Sp, class _Tp, class _A0>
struct __pointer_traits_element_type<_Sp<_Tp, _A0>, true>
{
    typedef typename _Sp<_Tp, _A0>::element_type type;
};

template <template <class, class> class _Sp, class _Tp, class _A0>
struct __pointer_traits_element_type<_Sp<_Tp, _A0>, false>
{
    typedef _Tp type;
};

template <template <class, class, class> class _Sp, class _Tp, class _A0, class _A1>
struct __pointer_traits_element_type<_Sp<_Tp, _A0, _A1>, true>
{
    typedef typename _Sp<_Tp, _A0, _A1>::element_type type;
};

template <template <class, class, class> class _Sp, class _Tp, class _A0, class _A1>
struct __pointer_traits_element_type<_Sp<_Tp, _A0, _A1>, false>
{
    typedef _Tp type;
};

template <template <class, class, class, class> class _Sp, class _Tp, class _A0,
                                                           class _A1, class _A2>
struct __pointer_traits_element_type<_Sp<_Tp, _A0, _A1, _A2>, true>
{
    typedef typename _Sp<_Tp, _A0, _A1, _A2>::element_type type;
};

template <template <class, class, class, class> class _Sp, class _Tp, class _A0,
                                                           class _A1, class _A2>
struct __pointer_traits_element_type<_Sp<_Tp, _A0, _A1, _A2>, false>
{
    typedef _Tp type;
};

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 736 "/usr/include/c++/v1/memory" 3

template <class _Tp>
struct __has_difference_type
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Up> static __two __test(...);
    template <class _Up> static char __test(typename _Up::difference_type* = 0);
public:
    static const bool value = sizeof(__test<_Tp>(0)) == 1;
};

template <class _Ptr, bool = __has_difference_type<_Ptr>::value>
struct __pointer_traits_difference_type
{
    typedef ptrdiff_t type;
};

template <class _Ptr>
struct __pointer_traits_difference_type<_Ptr, true>
{
    typedef typename _Ptr::difference_type type;
};

template <class _Tp, class _Up>
struct __has_rebind
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Xp> static __two __test(...);
    template <class _Xp> static char __test(typename _Xp::template rebind<_Up>* = 0);
public:
    static const bool value = sizeof(__test<_Tp>(0)) == 1;
};

template <class _Tp, class _Up, bool = __has_rebind<_Tp, _Up>::value>
struct __pointer_traits_rebind
{
#ifndef _LIBCPP_HAS_NO_TEMPLATE_ALIASES
    typedef typename _Tp::template rebind<_Up> type;
#else
# 777 "/usr/include/c++/v1/memory" 3
    typedef typename _Tp::template rebind<_Up>::other type;
#endif
# 779 "/usr/include/c++/v1/memory" 3
};

#ifndef _LIBCPP_HAS_NO_VARIADICS

template <template <class, class...> class _Sp, class _Tp, class ..._Args, class _Up>
struct __pointer_traits_rebind<_Sp<_Tp, _Args...>, _Up, true>
{
#ifndef _LIBCPP_HAS_NO_TEMPLATE_ALIASES
    typedef typename _Sp<_Tp, _Args...>::template rebind<_Up> type;
#else
# 789 "/usr/include/c++/v1/memory" 3
    typedef typename _Sp<_Tp, _Args...>::template rebind<_Up>::other type;
#endif
# 791 "/usr/include/c++/v1/memory" 3
};

template <template <class, class...> class _Sp, class _Tp, class ..._Args, class _Up>
struct __pointer_traits_rebind<_Sp<_Tp, _Args...>, _Up, false>
{
    typedef _Sp<_Up, _Args...> type;
};

#else  // _LIBCPP_HAS_NO_VARIADICS
# 800 "/usr/include/c++/v1/memory" 3

template <template <class> class _Sp, class _Tp, class _Up>
struct __pointer_traits_rebind<_Sp<_Tp>, _Up, true>
{
#ifndef _LIBCPP_HAS_NO_TEMPLATE_ALIASES
    typedef typename _Sp<_Tp>::template rebind<_Up> type;
#else
# 807 "/usr/include/c++/v1/memory" 3
    typedef typename _Sp<_Tp>::template rebind<_Up>::other type;
#endif
# 809 "/usr/include/c++/v1/memory" 3
};

template <template <class> class _Sp, class _Tp, class _Up>
struct __pointer_traits_rebind<_Sp<_Tp>, _Up, false>
{
    typedef _Sp<_Up> type;
};

template <template <class, class> class _Sp, class _Tp, class _A0, class _Up>
struct __pointer_traits_rebind<_Sp<_Tp, _A0>, _Up, true>
{
#ifndef _LIBCPP_HAS_NO_TEMPLATE_ALIASES
    typedef typename _Sp<_Tp, _A0>::template rebind<_Up> type;
#else
# 823 "/usr/include/c++/v1/memory" 3
    typedef typename _Sp<_Tp, _A0>::template rebind<_Up>::other type;
#endif
# 825 "/usr/include/c++/v1/memory" 3
};

template <template <class, class> class _Sp, class _Tp, class _A0, class _Up>
struct __pointer_traits_rebind<_Sp<_Tp, _A0>, _Up, false>
{
    typedef _Sp<_Up, _A0> type;
};

template <template <class, class, class> class _Sp, class _Tp, class _A0,
                                         class _A1, class _Up>
struct __pointer_traits_rebind<_Sp<_Tp, _A0, _A1>, _Up, true>
{
#ifndef _LIBCPP_HAS_NO_TEMPLATE_ALIASES
    typedef typename _Sp<_Tp, _A0, _A1>::template rebind<_Up> type;
#else
# 840 "/usr/include/c++/v1/memory" 3
    typedef typename _Sp<_Tp, _A0, _A1>::template rebind<_Up>::other type;
#endif
# 842 "/usr/include/c++/v1/memory" 3
};

template <template <class, class, class> class _Sp, class _Tp, class _A0,
                                         class _A1, class _Up>
struct __pointer_traits_rebind<_Sp<_Tp, _A0, _A1>, _Up, false>
{
    typedef _Sp<_Up, _A0, _A1> type;
};

template <template <class, class, class, class> class _Sp, class _Tp, class _A0,
                                                class _A1, class _A2, class _Up>
struct __pointer_traits_rebind<_Sp<_Tp, _A0, _A1, _A2>, _Up, true>
{
#ifndef _LIBCPP_HAS_NO_TEMPLATE_ALIASES
    typedef typename _Sp<_Tp, _A0, _A1, _A2>::template rebind<_Up> type;
#else
# 858 "/usr/include/c++/v1/memory" 3
    typedef typename _Sp<_Tp, _A0, _A1, _A2>::template rebind<_Up>::other type;
#endif
# 860 "/usr/include/c++/v1/memory" 3
};

template <template <class, class, class, class> class _Sp, class _Tp, class _A0,
                                                class _A1, class _A2, class _Up>
struct __pointer_traits_rebind<_Sp<_Tp, _A0, _A1, _A2>, _Up, false>
{
    typedef _Sp<_Up, _A0, _A1, _A2> type;
};

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 870 "/usr/include/c++/v1/memory" 3

template <class _Ptr>
struct _LIBCPP_TYPE_VIS_ONLY pointer_traits
{
    typedef _Ptr                                                     pointer;
    typedef typename __pointer_traits_element_type<pointer>::type    element_type;
    typedef typename __pointer_traits_difference_type<pointer>::type difference_type;

#ifndef _LIBCPP_HAS_NO_TEMPLATE_ALIASES
    template <class _Up> using rebind = typename __pointer_traits_rebind<pointer, _Up>::type;
#else
# 881 "/usr/include/c++/v1/memory" 3
    template <class _Up> struct rebind
        {typedef typename __pointer_traits_rebind<pointer, _Up>::type other;};
#endif  // _LIBCPP_HAS_NO_TEMPLATE_ALIASES
# 884 "/usr/include/c++/v1/memory" 3

private:
    struct __nat {};
public:
    _LIBCPP_INLINE_VISIBILITY
    static pointer pointer_to(typename conditional<is_void<element_type>::value,
                                           __nat, element_type>::type& __r)
        {return pointer::pointer_to(__r);}
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY pointer_traits<_Tp*>
{
    typedef _Tp*      pointer;
    typedef _Tp       element_type;
    typedef ptrdiff_t difference_type;

#ifndef _LIBCPP_HAS_NO_TEMPLATE_ALIASES
    template <class _Up> using rebind = _Up*;
#else
# 904 "/usr/include/c++/v1/memory" 3
    template <class _Up> struct rebind {typedef _Up* other;};
#endif
# 906 "/usr/include/c++/v1/memory" 3

private:
    struct __nat {};
public:
    _LIBCPP_INLINE_VISIBILITY
    static pointer pointer_to(typename conditional<is_void<element_type>::value,
                                      __nat, element_type>::type& __r) _NOEXCEPT
        {return _VSTD::addressof(__r);}
};

// allocator_traits

namespace __has_pointer_type_imp
{
    template <class _Up> static __two __test(...);
    template <class _Up> static char __test(typename _Up::pointer* = 0);
}

template <class _Tp>
struct __has_pointer_type
    : public integral_constant<bool, sizeof(__has_pointer_type_imp::__test<_Tp>(0)) == 1>
{
};

namespace __pointer_type_imp
{

template <class _Tp, class _Dp, bool = __has_pointer_type<_Dp>::value>
struct __pointer_type
{
    typedef typename _Dp::pointer type;
};

template <class _Tp, class _Dp>
struct __pointer_type<_Tp, _Dp, false>
{
    typedef _Tp* type;
};

}  // __pointer_type_imp

template <class _Tp, class _Dp>
struct __pointer_type
{
    typedef typename __pointer_type_imp::__pointer_type<_Tp, typename remove_reference<_Dp>::type>::type type;
};

template <class _Tp>
struct __has_const_pointer
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Up> static __two __test(...);
    template <class _Up> static char __test(typename _Up::const_pointer* = 0);
public:
    static const bool value = sizeof(__test<_Tp>(0)) == 1;
};

template <class _Tp, class _Ptr, class _Alloc, bool = __has_const_pointer<_Alloc>::value>
struct __const_pointer
{
    typedef typename _Alloc::const_pointer type;
};

template <class _Tp, class _Ptr, class _Alloc>
struct __const_pointer<_Tp, _Ptr, _Alloc, false>
{
#ifndef _LIBCPP_HAS_NO_TEMPLATE_ALIASES
    typedef typename pointer_traits<_Ptr>::template rebind<const _Tp> type;
#else
# 976 "/usr/include/c++/v1/memory" 3
    typedef typename pointer_traits<_Ptr>::template rebind<const _Tp>::other type;
#endif
# 978 "/usr/include/c++/v1/memory" 3
};

template <class _Tp>
struct __has_void_pointer
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Up> static __two __test(...);
    template <class _Up> static char __test(typename _Up::void_pointer* = 0);
public:
    static const bool value = sizeof(__test<_Tp>(0)) == 1;
};

template <class _Ptr, class _Alloc, bool = __has_void_pointer<_Alloc>::value>
struct __void_pointer
{
    typedef typename _Alloc::void_pointer type;
};

template <class _Ptr, class _Alloc>
struct __void_pointer<_Ptr, _Alloc, false>
{
#ifndef _LIBCPP_HAS_NO_TEMPLATE_ALIASES
    typedef typename pointer_traits<_Ptr>::template rebind<void> type;
#else
# 1003 "/usr/include/c++/v1/memory" 3
    typedef typename pointer_traits<_Ptr>::template rebind<void>::other type;
#endif
# 1005 "/usr/include/c++/v1/memory" 3
};

template <class _Tp>
struct __has_const_void_pointer
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Up> static __two __test(...);
    template <class _Up> static char __test(typename _Up::const_void_pointer* = 0);
public:
    static const bool value = sizeof(__test<_Tp>(0)) == 1;
};

template <class _Ptr, class _Alloc, bool = __has_const_void_pointer<_Alloc>::value>
struct __const_void_pointer
{
    typedef typename _Alloc::const_void_pointer type;
};

template <class _Ptr, class _Alloc>
struct __const_void_pointer<_Ptr, _Alloc, false>
{
#ifndef _LIBCPP_HAS_NO_TEMPLATE_ALIASES
    typedef typename pointer_traits<_Ptr>::template rebind<const void> type;
#else
# 1030 "/usr/include/c++/v1/memory" 3
    typedef typename pointer_traits<_Ptr>::template rebind<const void>::other type;
#endif
# 1032 "/usr/include/c++/v1/memory" 3
};

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_Tp*
__to_raw_pointer(_Tp* __p) _NOEXCEPT
{
    return __p;
}

template <class _Pointer>
inline _LIBCPP_INLINE_VISIBILITY
typename pointer_traits<_Pointer>::element_type*
__to_raw_pointer(_Pointer __p) _NOEXCEPT
{
    return _VSTD::__to_raw_pointer(__p.operator->());
}

template <class _Tp>
struct __has_size_type
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Up> static __two __test(...);
    template <class _Up> static char __test(typename _Up::size_type* = 0);
public:
    static const bool value = sizeof(__test<_Tp>(0)) == 1;
};

template <class _Alloc, class _DiffType, bool = __has_size_type<_Alloc>::value>
struct __size_type
{
    typedef typename make_unsigned<_DiffType>::type type;
};

template <class _Alloc, class _DiffType>
struct __size_type<_Alloc, _DiffType, true>
{
    typedef typename _Alloc::size_type type;
};

template <class _Tp>
struct __has_propagate_on_container_copy_assignment
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Up> static __two __test(...);
    template <class _Up> static char __test(typename _Up::propagate_on_container_copy_assignment* = 0);
public:
    static const bool value = sizeof(__test<_Tp>(0)) == 1;
};

template <class _Alloc, bool = __has_propagate_on_container_copy_assignment<_Alloc>::value>
struct __propagate_on_container_copy_assignment
{
    typedef false_type type;
};

template <class _Alloc>
struct __propagate_on_container_copy_assignment<_Alloc, true>
{
    typedef typename _Alloc::propagate_on_container_copy_assignment type;
};

template <class _Tp>
struct __has_propagate_on_container_move_assignment
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Up> static __two __test(...);
    template <class _Up> static char __test(typename _Up::propagate_on_container_move_assignment* = 0);
public:
    static const bool value = sizeof(__test<_Tp>(0)) == 1;
};

template <class _Alloc, bool = __has_propagate_on_container_move_assignment<_Alloc>::value>
struct __propagate_on_container_move_assignment
{
    typedef false_type type;
};

template <class _Alloc>
struct __propagate_on_container_move_assignment<_Alloc, true>
{
    typedef typename _Alloc::propagate_on_container_move_assignment type;
};

template <class _Tp>
struct __has_propagate_on_container_swap
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Up> static __two __test(...);
    template <class _Up> static char __test(typename _Up::propagate_on_container_swap* = 0);
public:
    static const bool value = sizeof(__test<_Tp>(0)) == 1;
};

template <class _Alloc, bool = __has_propagate_on_container_swap<_Alloc>::value>
struct __propagate_on_container_swap
{
    typedef false_type type;
};

template <class _Alloc>
struct __propagate_on_container_swap<_Alloc, true>
{
    typedef typename _Alloc::propagate_on_container_swap type;
};

template <class _Tp, class _Up, bool = __has_rebind<_Tp, _Up>::value>
struct __has_rebind_other
{
private:
    struct __two {char __lx; char __lxx;};
    template <class _Xp> static __two __test(...);
    template <class _Xp> static char __test(typename _Xp::template rebind<_Up>::other* = 0);
public:
    static const bool value = sizeof(__test<_Tp>(0)) == 1;
};

template <class _Tp, class _Up>
struct __has_rebind_other<_Tp, _Up, false>
{
    static const bool value = false;
};

template <class _Tp, class _Up, bool = __has_rebind_other<_Tp, _Up>::value>
struct __allocator_traits_rebind
{
    typedef typename _Tp::template rebind<_Up>::other type;
};

#ifndef _LIBCPP_HAS_NO_VARIADICS

template <template <class, class...> class _Alloc, class _Tp, class ..._Args, class _Up>
struct __allocator_traits_rebind<_Alloc<_Tp, _Args...>, _Up, true>
{
    typedef typename _Alloc<_Tp, _Args...>::template rebind<_Up>::other type;
};

template <template <class, class...> class _Alloc, class _Tp, class ..._Args, class _Up>
struct __allocator_traits_rebind<_Alloc<_Tp, _Args...>, _Up, false>
{
    typedef _Alloc<_Up, _Args...> type;
};

#else  // _LIBCPP_HAS_NO_VARIADICS
# 1180 "/usr/include/c++/v1/memory" 3

template <template <class> class _Alloc, class _Tp, class _Up>
struct __allocator_traits_rebind<_Alloc<_Tp>, _Up, true>
{
    typedef typename _Alloc<_Tp>::template rebind<_Up>::other type;
};

template <template <class> class _Alloc, class _Tp, class _Up>
struct __allocator_traits_rebind<_Alloc<_Tp>, _Up, false>
{
    typedef _Alloc<_Up> type;
};

template <template <class, class> class _Alloc, class _Tp, class _A0, class _Up>
struct __allocator_traits_rebind<_Alloc<_Tp, _A0>, _Up, true>
{
    typedef typename _Alloc<_Tp, _A0>::template rebind<_Up>::other type;
};

template <template <class, class> class _Alloc, class _Tp, class _A0, class _Up>
struct __allocator_traits_rebind<_Alloc<_Tp, _A0>, _Up, false>
{
    typedef _Alloc<_Up, _A0> type;
};

template <template <class, class, class> class _Alloc, class _Tp, class _A0,
                                         class _A1, class _Up>
struct __allocator_traits_rebind<_Alloc<_Tp, _A0, _A1>, _Up, true>
{
    typedef typename _Alloc<_Tp, _A0, _A1>::template rebind<_Up>::other type;
};

template <template <class, class, class> class _Alloc, class _Tp, class _A0,
                                         class _A1, class _Up>
struct __allocator_traits_rebind<_Alloc<_Tp, _A0, _A1>, _Up, false>
{
    typedef _Alloc<_Up, _A0, _A1> type;
};

template <template <class, class, class, class> class _Alloc, class _Tp, class _A0,
                                                class _A1, class _A2, class _Up>
struct __allocator_traits_rebind<_Alloc<_Tp, _A0, _A1, _A2>, _Up, true>
{
    typedef typename _Alloc<_Tp, _A0, _A1, _A2>::template rebind<_Up>::other type;
};

template <template <class, class, class, class> class _Alloc, class _Tp, class _A0,
                                                class _A1, class _A2, class _Up>
struct __allocator_traits_rebind<_Alloc<_Tp, _A0, _A1, _A2>, _Up, false>
{
    typedef _Alloc<_Up, _A0, _A1, _A2> type;
};

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 1234 "/usr/include/c++/v1/memory" 3

#ifndef _LIBCPP_HAS_NO_ADVANCED_SFINAE

template <class _Alloc, class _SizeType, class _ConstVoidPtr>
auto
__has_allocate_hint_test(_Alloc&& __a, _SizeType&& __sz, _ConstVoidPtr&& __p)
    -> decltype(__a.allocate(__sz, __p), true_type());

template <class _Alloc, class _SizeType, class _ConstVoidPtr>
auto
__has_allocate_hint_test(const _Alloc& __a, _SizeType&& __sz, _ConstVoidPtr&& __p)
    -> false_type;

template <class _Alloc, class _SizeType, class _ConstVoidPtr>
struct __has_allocate_hint
    : integral_constant<bool,
        is_same<
            decltype(__has_allocate_hint_test(declval<_Alloc>(),
                                          declval<_SizeType>(),
                                          declval<_ConstVoidPtr>())),
            true_type>::value>
{
};

#else  // _LIBCPP_HAS_NO_ADVANCED_SFINAE
# 1259 "/usr/include/c++/v1/memory" 3

template <class _Alloc, class _SizeType, class _ConstVoidPtr>
struct __has_allocate_hint
    : true_type
{
};

#endif  // _LIBCPP_HAS_NO_ADVANCED_SFINAE
# 1267 "/usr/include/c++/v1/memory" 3

#if !defined(_LIBCPP_HAS_NO_ADVANCED_SFINAE) && !defined(_LIBCPP_HAS_NO_VARIADICS)

template <class _Alloc, class _Tp, class ..._Args>
decltype(_VSTD::declval<_Alloc>().construct(_VSTD::declval<_Tp*>(),
                                           _VSTD::declval<_Args>()...),
                                           true_type())
__has_construct_test(_Alloc&& __a, _Tp* __p, _Args&& ...__args);

template <class _Alloc, class _Pointer, class ..._Args>
false_type
__has_construct_test(const _Alloc& __a, _Pointer&& __p, _Args&& ...__args);

template <class _Alloc, class _Pointer, class ..._Args>
struct __has_construct
    : integral_constant<bool,
        is_same<
            decltype(__has_construct_test(declval<_Alloc>(),
                                          declval<_Pointer>(),
                                          declval<_Args>()...)),
            true_type>::value>
{
};

template <class _Alloc, class _Pointer>
auto
__has_destroy_test(_Alloc&& __a, _Pointer&& __p)
    -> decltype(__a.destroy(__p), true_type());

template <class _Alloc, class _Pointer>
auto
__has_destroy_test(const _Alloc& __a, _Pointer&& __p)
    -> false_type;

template <class _Alloc, class _Pointer>
struct __has_destroy
    : integral_constant<bool,
        is_same<
            decltype(__has_destroy_test(declval<_Alloc>(),
                                        declval<_Pointer>())),
            true_type>::value>
{
};

template <class _Alloc>
auto
__has_max_size_test(_Alloc&& __a)
    -> decltype(__a.max_size(), true_type());

template <class _Alloc>
auto
__has_max_size_test(const volatile _Alloc& __a)
    -> false_type;

template <class _Alloc>
struct __has_max_size
    : integral_constant<bool,
        is_same<
            decltype(__has_max_size_test(declval<_Alloc&>())),
            true_type>::value>
{
};

template <class _Alloc>
auto
__has_select_on_container_copy_construction_test(_Alloc&& __a)
    -> decltype(__a.select_on_container_copy_construction(), true_type());

template <class _Alloc>
auto
__has_select_on_container_copy_construction_test(const volatile _Alloc& __a)
    -> false_type;

template <class _Alloc>
struct __has_select_on_container_copy_construction
    : integral_constant<bool,
        is_same<
            decltype(__has_select_on_container_copy_construction_test(declval<_Alloc&>())),
            true_type>::value>
{
};

#else  // _LIBCPP_HAS_NO_ADVANCED_SFINAE
# 1350 "/usr/include/c++/v1/memory" 3

#ifndef _LIBCPP_HAS_NO_VARIADICS

template <class _Alloc, class _Pointer, class ..._Args>
struct __has_construct
    : false_type
{
};

#else  // _LIBCPP_HAS_NO_VARIADICS
# 1360 "/usr/include/c++/v1/memory" 3

template <class _Alloc, class _Pointer, class _Args>
struct __has_construct
    : false_type
{
};

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 1368 "/usr/include/c++/v1/memory" 3

template <class _Alloc, class _Pointer>
struct __has_destroy
    : false_type
{
};

template <class _Alloc>
struct __has_max_size
    : true_type
{
};

template <class _Alloc>
struct __has_select_on_container_copy_construction
    : false_type
{
};

#endif  // _LIBCPP_HAS_NO_ADVANCED_SFINAE
# 1388 "/usr/include/c++/v1/memory" 3

template <class _Alloc, class _Ptr, bool = __has_difference_type<_Alloc>::value>
struct __alloc_traits_difference_type
{
    typedef typename pointer_traits<_Ptr>::difference_type type;
};

template <class _Alloc, class _Ptr>
struct __alloc_traits_difference_type<_Alloc, _Ptr, true>
{
    typedef typename _Alloc::difference_type type;
};

template <class _Alloc>
struct _LIBCPP_TYPE_VIS_ONLY allocator_traits
{
    typedef _Alloc                              allocator_type;
    typedef typename allocator_type::value_type value_type;

    typedef typename __pointer_type<value_type, allocator_type>::type pointer;
    typedef typename __const_pointer<value_type, pointer, allocator_type>::type const_pointer;
    typedef typename __void_pointer<pointer, allocator_type>::type void_pointer;
    typedef typename __const_void_pointer<pointer, allocator_type>::type const_void_pointer;

    typedef typename __alloc_traits_difference_type<allocator_type, pointer>::type difference_type;
    typedef typename __size_type<allocator_type, difference_type>::type size_type;

    typedef typename __propagate_on_container_copy_assignment<allocator_type>::type
                     propagate_on_container_copy_assignment;
    typedef typename __propagate_on_container_move_assignment<allocator_type>::type
                     propagate_on_container_move_assignment;
    typedef typename __propagate_on_container_swap<allocator_type>::type
                     propagate_on_container_swap;

#ifndef _LIBCPP_HAS_NO_TEMPLATE_ALIASES
    template <class _Tp> using rebind_alloc =
                  typename __allocator_traits_rebind<allocator_type, _Tp>::type;
    template <class _Tp> using rebind_traits = allocator_traits<rebind_alloc<_Tp>>;
#else  // _LIBCPP_HAS_NO_TEMPLATE_ALIASES
# 1427 "/usr/include/c++/v1/memory" 3
    template <class _Tp> struct rebind_alloc
        {typedef typename __allocator_traits_rebind<allocator_type, _Tp>::type other;};
    template <class _Tp> struct rebind_traits
        {typedef allocator_traits<typename rebind_alloc<_Tp>::other> other;};
#endif  // _LIBCPP_HAS_NO_TEMPLATE_ALIASES
# 1432 "/usr/include/c++/v1/memory" 3

    _LIBCPP_INLINE_VISIBILITY
    static pointer allocate(allocator_type& __a, size_type __n)
        {return __a.allocate(__n);}
    _LIBCPP_INLINE_VISIBILITY
    static pointer allocate(allocator_type& __a, size_type __n, const_void_pointer __hint)
        {return allocate(__a, __n, __hint,
            __has_allocate_hint<allocator_type, size_type, const_void_pointer>());}

    _LIBCPP_INLINE_VISIBILITY
    static void deallocate(allocator_type& __a, pointer __p, size_type __n) _NOEXCEPT
        {__a.deallocate(__p, __n);}

#ifndef _LIBCPP_HAS_NO_VARIADICS
    template <class _Tp, class... _Args>
        _LIBCPP_INLINE_VISIBILITY
        static void construct(allocator_type& __a, _Tp* __p, _Args&&... __args)
            {__construct(__has_construct<allocator_type, pointer, _Args...>(),
                         __a, __p, _VSTD::forward<_Args>(__args)...);}
#else  // _LIBCPP_HAS_NO_VARIADICS
# 1452 "/usr/include/c++/v1/memory" 3
    template <class _Tp>
        _LIBCPP_INLINE_VISIBILITY
        static void construct(allocator_type& __a, _Tp* __p)
            {
                ::new ((void*)__p) _Tp();
            }
    template <class _Tp, class _A0>
        _LIBCPP_INLINE_VISIBILITY
        static void construct(allocator_type& __a, _Tp* __p, const _A0& __a0)
            {
                ::new ((void*)__p) _Tp(__a0);
            }
    template <class _Tp, class _A0, class _A1>
        _LIBCPP_INLINE_VISIBILITY
        static void construct(allocator_type& __a, _Tp* __p, const _A0& __a0,
                              const _A1& __a1)
            {
                ::new ((void*)__p) _Tp(__a0, __a1);
            }
    template <class _Tp, class _A0, class _A1, class _A2>
        _LIBCPP_INLINE_VISIBILITY
        static void construct(allocator_type& __a, _Tp* __p, const _A0& __a0,
                              const _A1& __a1, const _A2& __a2)
            {
                ::new ((void*)__p) _Tp(__a0, __a1, __a2);
            }
#endif  // _LIBCPP_HAS_NO_VARIADICS
# 1479 "/usr/include/c++/v1/memory" 3

    template <class _Tp>
        _LIBCPP_INLINE_VISIBILITY
        static void destroy(allocator_type& __a, _Tp* __p)
            {__destroy(__has_destroy<allocator_type, _Tp*>(), __a, __p);}

    _LIBCPP_INLINE_VISIBILITY
    static size_type max_size(const allocator_type& __a) _NOEXCEPT
        {return __max_size(__has_max_size<const allocator_type>(), __a);}

    _LIBCPP_INLINE_VISIBILITY
    static allocator_type
        select_on_container_copy_construction(const allocator_type& __a)
            {return select_on_container_copy_construction(
                __has_select_on_container_copy_construction<const allocator_type>(),
                __a);}

    template <class _Ptr>
        _LIBCPP_INLINE_VISIBILITY
        static
        void
        __construct_forward(allocator_type& __a, _Ptr __begin1, _Ptr __end1, _Ptr& __begin2)
        {
            for (; __begin1 != __end1; ++__begin1, ++__begin2)
                construct(__a, _VSTD::__to_raw_pointer(__begin2), _VSTD::move_if_noexcept(*__begin1));
        }

    template <class _Tp>
        _LIBCPP_INLINE_VISIBILITY
        static
        typename enable_if
        <
            (is_same<allocator_type, allocator<_Tp> >::value
                || !__has_construct<allocator_type, _Tp*, _Tp>::value) &&
             is_trivially_move_constructible<_Tp>::value,
            void
        >::type
        __construct_forward(allocator_type& __a, _Tp* __begin1, _Tp* __end1, _Tp*& __begin2)
        {
            ptrdiff_t _Np = __end1 - __begin1;
            _VSTD::memcpy(__begin2, __begin1, _Np * sizeof(_Tp));
            __begin2 += _Np;
        }

    template <class _Ptr>
        _LIBCPP_INLINE_VISIBILITY
        static
        void
        __construct_backward(allocator_type& __a, _Ptr __begin1, _Ptr __end1, _Ptr& __end2)
        {
            while (__end1 != __begin1)
            {
                construct(__a, _VSTD::__to_raw_pointer(__end2-1), _VSTD::move_if_noexcept(*--__end1));
                --__end2;
            }
        }

    template <class _Tp>
        _LIBCPP_INLINE_VISIBILITY
        static
        typename enable_if
        <
            (is_same<allocator_type, allocator<_Tp> >::value
                || !__has_construct<allocator_type, _Tp*, _Tp>::value) &&
             is_trivially_move_constructible<_Tp>::value,
            void
        >::type
        __construct_backward(allocator_type& __a, _Tp* __begin1, _Tp* __end1, _Tp*& __end2)
        {
            ptrdiff_t _Np = __end1 - __begin1;
            __end2 -= _Np;
            _VSTD::memcpy(__end2, __begin1, _Np * sizeof(_Tp));
        }

private:

    _LIBCPP_INLINE_VISIBILITY
    static pointer allocate(allocator_type& __a, size_type __n,
        const_void_pointer __hint, true_type)
        {return __a.allocate(__n, __hint);}
    _LIBCPP_INLINE_VISIBILITY
    static pointer allocate(allocator_type& __a, size_type __n,
        const_void_pointer, false_type)
        {return __a.allocate(__n);}

#ifndef _LIBCPP_HAS_NO_VARIADICS
    template <class _Tp, class... _Args>
        _LIBCPP_INLINE_VISIBILITY
        static void __construct(true_type, allocator_type& __a, _Tp* __p, _Args&&... __args)
            {__a.construct(__p, _VSTD::forward<_Args>(__args)...);}
    template <class _Tp, class... _Args>
        _LIBCPP_INLINE_VISIBILITY
        static void __construct(false_type, allocator_type&, _Tp* __p, _Args&&... __args)
            {
                ::new ((void*)__p) _Tp(_VSTD::forward<_Args>(__args)...);
            }
#endif  // _LIBCPP_HAS_NO_VARIADICS
# 1576 "/usr/include/c++/v1/memory" 3

    template <class _Tp>
        _LIBCPP_INLINE_VISIBILITY
        static void __destroy(true_type, allocator_type& __a, _Tp* __p)
            {__a.destroy(__p);}
    template <class _Tp>
        _LIBCPP_INLINE_VISIBILITY
        static void __destroy(false_type, allocator_type&, _Tp* __p)
            {
                __p->~_Tp();
            }

    _LIBCPP_INLINE_VISIBILITY
    static size_type __max_size(true_type, const allocator_type& __a)
            {return __a.max_size();}
    _LIBCPP_INLINE_VISIBILITY
    static size_type __max_size(false_type, const allocator_type&)
            {return numeric_limits<size_type>::max();}

    _LIBCPP_INLINE_VISIBILITY
    static allocator_type
        select_on_container_copy_construction(true_type, const allocator_type& __a)
            {return __a.select_on_container_copy_construction();}
    _LIBCPP_INLINE_VISIBILITY
    static allocator_type
        select_on_container_copy_construction(false_type, const allocator_type& __a)
            {return __a;}
};

// allocator

template <class _Tp>
class _LIBCPP_TYPE_VIS_ONLY allocator
{
public:
    typedef size_t            size_type;
    typedef ptrdiff_t         difference_type;
    typedef _Tp*              pointer;
    typedef const _Tp*        const_pointer;
    typedef _Tp&              reference;
    typedef const _Tp&        const_reference;
    typedef _Tp               value_type;

    typedef true_type propagate_on_container_move_assignment;

    template <class _Up> struct rebind {typedef allocator<_Up> other;};

    _LIBCPP_INLINE_VISIBILITY allocator() _NOEXCEPT {}
    template <class _Up> _LIBCPP_INLINE_VISIBILITY allocator(const allocator<_Up>&) _NOEXCEPT {}
    _LIBCPP_INLINE_VISIBILITY pointer address(reference __x) const _NOEXCEPT
        {return _VSTD::addressof(__x);}
    _LIBCPP_INLINE_VISIBILITY const_pointer address(const_reference __x) const _NOEXCEPT
        {return _VSTD::addressof(__x);}
    _LIBCPP_INLINE_VISIBILITY pointer allocate(size_type __n, allocator<void>::const_pointer = 0)
        {return static_cast<pointer>(::operator new(__n * sizeof(_Tp)));}
    _LIBCPP_INLINE_VISIBILITY void deallocate(pointer __p, size_type) _NOEXCEPT
        {::operator delete((void*)__p);}
    _LIBCPP_INLINE_VISIBILITY size_type max_size() const _NOEXCEPT
        {return size_type(~0) / sizeof(_Tp);}
#if !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES) && !defined(_LIBCPP_HAS_NO_VARIADICS)
    template <class _Up, class... _Args>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(_Up* __p, _Args&&... __args)
        {
            ::new((void*)__p) _Up(_VSTD::forward<_Args>(__args)...);
        }
#else  // !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES) && !defined(_LIBCPP_HAS_NO_VARIADICS)
# 1644 "/usr/include/c++/v1/memory" 3
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p)
        {
            ::new((void*)__p) _Tp();
        }
# if defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES)

    template <class _A0>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, _A0& __a0)
        {
            ::new((void*)__p) _Tp(__a0);
        }
    template <class _A0>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, const _A0& __a0)
        {
            ::new((void*)__p) _Tp(__a0);
        }
# endif  // defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES)
# 1667 "/usr/include/c++/v1/memory" 3
    template <class _A0, class _A1>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, _A0& __a0, _A1& __a1)
        {
            ::new((void*)__p) _Tp(__a0, __a1);
        }
    template <class _A0, class _A1>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, const _A0& __a0, _A1& __a1)
        {
            ::new((void*)__p) _Tp(__a0, __a1);
        }
    template <class _A0, class _A1>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, _A0& __a0, const _A1& __a1)
        {
            ::new((void*)__p) _Tp(__a0, __a1);
        }
    template <class _A0, class _A1>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, const _A0& __a0, const _A1& __a1)
        {
            ::new((void*)__p) _Tp(__a0, __a1);
        }
#endif  // !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES) && !defined(_LIBCPP_HAS_NO_VARIADICS)
# 1696 "/usr/include/c++/v1/memory" 3
    _LIBCPP_INLINE_VISIBILITY void destroy(pointer __p) {__p->~_Tp();}
};

template <class _Tp>
class _LIBCPP_TYPE_VIS_ONLY allocator<const _Tp>
{
public:
    typedef size_t            size_type;
    typedef ptrdiff_t         difference_type;
    typedef const _Tp*        pointer;
    typedef const _Tp*        const_pointer;
    typedef const _Tp&        reference;
    typedef const _Tp&        const_reference;
    typedef const _Tp         value_type;

    typedef true_type propagate_on_container_move_assignment;

    template <class _Up> struct rebind {typedef allocator<_Up> other;};

    _LIBCPP_INLINE_VISIBILITY allocator() _NOEXCEPT {}
    template <class _Up> _LIBCPP_INLINE_VISIBILITY allocator(const allocator<_Up>&) _NOEXCEPT {}
    _LIBCPP_INLINE_VISIBILITY const_pointer address(const_reference __x) const _NOEXCEPT
        {return _VSTD::addressof(__x);}
    _LIBCPP_INLINE_VISIBILITY pointer allocate(size_type __n, allocator<void>::const_pointer = 0)
        {return static_cast<pointer>(::operator new(__n * sizeof(_Tp)));}
    _LIBCPP_INLINE_VISIBILITY void deallocate(pointer __p, size_type) _NOEXCEPT
        {::operator delete((void*)__p);}
    _LIBCPP_INLINE_VISIBILITY size_type max_size() const _NOEXCEPT
        {return size_type(~0) / sizeof(_Tp);}
#if !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES) && !defined(_LIBCPP_HAS_NO_VARIADICS)
    template <class _Up, class... _Args>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(_Up* __p, _Args&&... __args)
        {
            ::new((void*)__p) _Up(_VSTD::forward<_Args>(__args)...);
        }
#else  // !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES) && !defined(_LIBCPP_HAS_NO_VARIADICS)
# 1734 "/usr/include/c++/v1/memory" 3
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p)
        {
            ::new((void*)__p) _Tp();
        }
# if defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES)

    template <class _A0>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, _A0& __a0)
        {
            ::new((void*)__p) _Tp(__a0);
        }
    template <class _A0>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, const _A0& __a0)
        {
            ::new((void*)__p) _Tp(__a0);
        }
# endif  // defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES)
# 1757 "/usr/include/c++/v1/memory" 3
    template <class _A0, class _A1>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, _A0& __a0, _A1& __a1)
        {
            ::new((void*)__p) _Tp(__a0, __a1);
        }
    template <class _A0, class _A1>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, const _A0& __a0, _A1& __a1)
        {
            ::new((void*)__p) _Tp(__a0, __a1);
        }
    template <class _A0, class _A1>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, _A0& __a0, const _A1& __a1)
        {
            ::new((void*)__p) _Tp(__a0, __a1);
        }
    template <class _A0, class _A1>
        _LIBCPP_INLINE_VISIBILITY
        void
        construct(pointer __p, const _A0& __a0, const _A1& __a1)
        {
            ::new((void*)__p) _Tp(__a0, __a1);
        }
#endif  // !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES) && !defined(_LIBCPP_HAS_NO_VARIADICS)
# 1786 "/usr/include/c++/v1/memory" 3
    _LIBCPP_INLINE_VISIBILITY void destroy(pointer __p) {__p->~_Tp();}
};

template <class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
bool operator==(const allocator<_Tp>&, const allocator<_Up>&) _NOEXCEPT {return true;}

template <class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
bool operator!=(const allocator<_Tp>&, const allocator<_Up>&) _NOEXCEPT {return false;}

template <class _OutputIterator, class _Tp>
class _LIBCPP_TYPE_VIS_ONLY raw_storage_iterator
    : public iterator<output_iterator_tag,
                      _Tp,                                         // purposefully not C++03
                      ptrdiff_t,                                   // purposefully not C++03
                      _Tp*,                                        // purposefully not C++03
                      raw_storage_iterator<_OutputIterator, _Tp>&> // purposefully not C++03
{
private:
    _OutputIterator __x_;
public:
    _LIBCPP_INLINE_VISIBILITY explicit raw_storage_iterator(_OutputIterator __x) : __x_(__x) {}
    _LIBCPP_INLINE_VISIBILITY raw_storage_iterator& operator*() {return *this;}
    _LIBCPP_INLINE_VISIBILITY raw_storage_iterator& operator=(const _Tp& __element)
        {::new(&*__x_) _Tp(__element); return *this;}
    _LIBCPP_INLINE_VISIBILITY raw_storage_iterator& operator++() {++__x_; return *this;}
    _LIBCPP_INLINE_VISIBILITY raw_storage_iterator  operator++(int)
        {raw_storage_iterator __t(*this); ++__x_; return __t;}
};

template <class _Tp>
pair<_Tp*, ptrdiff_t>
get_temporary_buffer(ptrdiff_t __n) _NOEXCEPT
{
    pair<_Tp*, ptrdiff_t> __r(0, 0);
    const ptrdiff_t __m = (~ptrdiff_t(0) ^
                           ptrdiff_t(ptrdiff_t(1) << (sizeof(ptrdiff_t) * __CHAR_BIT__ - 1)))
                           / sizeof(_Tp);
    if (__n > __m)
        __n = __m;
    while (__n > 0)
    {
        __r.first = static_cast<_Tp*>(::operator new(__n * sizeof(_Tp), nothrow));
        if (__r.first)
        {
            __r.second = __n;
            break;
        }
        __n /= 2;
    }
    return __r;
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void return_temporary_buffer(_Tp* __p) _NOEXCEPT {::operator delete(__p);}

template <class _Tp>
struct auto_ptr_ref
{
    _Tp* __ptr_;
};

template<class _Tp>
class _LIBCPP_TYPE_VIS_ONLY auto_ptr
{
private:
    _Tp* __ptr_;
public:
    typedef _Tp element_type;

    _LIBCPP_INLINE_VISIBILITY explicit auto_ptr(_Tp* __p = 0) throw() : __ptr_(__p) {}
    _LIBCPP_INLINE_VISIBILITY auto_ptr(auto_ptr& __p) throw() : __ptr_(__p.release()) {}
    template<class _Up> _LIBCPP_INLINE_VISIBILITY auto_ptr(auto_ptr<_Up>& __p) throw()
        : __ptr_(__p.release()) {}
    _LIBCPP_INLINE_VISIBILITY auto_ptr& operator=(auto_ptr& __p) throw()
        {reset(__p.release()); return *this;}
    template<class _Up> _LIBCPP_INLINE_VISIBILITY auto_ptr& operator=(auto_ptr<_Up>& __p) throw()
        {reset(__p.release()); return *this;}
    _LIBCPP_INLINE_VISIBILITY auto_ptr& operator=(auto_ptr_ref<_Tp> __p) throw()
        {reset(__p.__ptr_); return *this;}
    _LIBCPP_INLINE_VISIBILITY ~auto_ptr() throw() {delete __ptr_;}

    _LIBCPP_INLINE_VISIBILITY _Tp& operator*() const throw()
        {return *__ptr_;}
    _LIBCPP_INLINE_VISIBILITY _Tp* operator->() const throw() {return __ptr_;}
    _LIBCPP_INLINE_VISIBILITY _Tp* get() const throw() {return __ptr_;}
    _LIBCPP_INLINE_VISIBILITY _Tp* release() throw()
    {
        _Tp* __t = __ptr_;
        __ptr_ = 0;
        return __t;
    }
    _LIBCPP_INLINE_VISIBILITY void reset(_Tp* __p = 0) throw()
    {
        if (__ptr_ != __p)
            delete __ptr_;
        __ptr_ = __p;
    }

    _LIBCPP_INLINE_VISIBILITY auto_ptr(auto_ptr_ref<_Tp> __p) throw() : __ptr_(__p.__ptr_) {}
    template<class _Up> _LIBCPP_INLINE_VISIBILITY operator auto_ptr_ref<_Up>() throw()
        {auto_ptr_ref<_Up> __t; __t.__ptr_ = release(); return __t;}
    template<class _Up> _LIBCPP_INLINE_VISIBILITY operator auto_ptr<_Up>() throw()
        {return auto_ptr<_Up>(release());}
};

template <>
class _LIBCPP_TYPE_VIS_ONLY auto_ptr<void>
{
public:
    typedef void element_type;
};

template <class _T1, class _T2, bool = is_same<typename remove_cv<_T1>::type,
                                                     typename remove_cv<_T2>::type>::value,
                                bool = is_empty<_T1>::value
#if __has_feature(is_final)
                                       && !__is_final(_T1)
#endif
# 1907 "/usr/include/c++/v1/memory" 3
                                ,
                                bool = is_empty<_T2>::value
#if __has_feature(is_final)
                                       && !__is_final(_T2)
#endif
# 1912 "/usr/include/c++/v1/memory" 3
         >
struct __libcpp_compressed_pair_switch;

template <class _T1, class _T2, bool IsSame>
struct __libcpp_compressed_pair_switch<_T1, _T2, IsSame, false, false> {enum {value = 0};};

template <class _T1, class _T2, bool IsSame>
struct __libcpp_compressed_pair_switch<_T1, _T2, IsSame, true, false>  {enum {value = 1};};

template <class _T1, class _T2, bool IsSame>
struct __libcpp_compressed_pair_switch<_T1, _T2, IsSame, false, true>  {enum {value = 2};};

template <class _T1, class _T2>
struct __libcpp_compressed_pair_switch<_T1, _T2, false, true, true>    {enum {value = 3};};

template <class _T1, class _T2>
struct __libcpp_compressed_pair_switch<_T1, _T2, true, true, true>     {enum {value = 1};};

template <class _T1, class _T2, unsigned = __libcpp_compressed_pair_switch<_T1, _T2>::value>
class __libcpp_compressed_pair_imp;

template <class _T1, class _T2>
class __libcpp_compressed_pair_imp<_T1, _T2, 0>
{
private:
    _T1 __first_;
    _T2 __second_;
public:
    typedef _T1 _T1_param;
    typedef _T2 _T2_param;

    typedef typename remove_reference<_T1>::type& _T1_reference;
    typedef typename remove_reference<_T2>::type& _T2_reference;

    typedef const typename remove_reference<_T1>::type& _T1_const_reference;
    typedef const typename remove_reference<_T2>::type& _T2_const_reference;

    _LIBCPP_INLINE_VISIBILITY __libcpp_compressed_pair_imp() {}
    _LIBCPP_INLINE_VISIBILITY explicit __libcpp_compressed_pair_imp(_T1_param __t1)
        : __first_(_VSTD::forward<_T1_param>(__t1)) {}
    _LIBCPP_INLINE_VISIBILITY explicit __libcpp_compressed_pair_imp(_T2_param __t2)
        : __second_(_VSTD::forward<_T2_param>(__t2)) {}
    _LIBCPP_INLINE_VISIBILITY __libcpp_compressed_pair_imp(_T1_param __t1, _T2_param __t2)
        : __first_(_VSTD::forward<_T1_param>(__t1)), __second_(_VSTD::forward<_T2_param>(__t2)) {}

#if defined(_LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS) && !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES)

    _LIBCPP_INLINE_VISIBILITY
    __libcpp_compressed_pair_imp(const __libcpp_compressed_pair_imp& __p)
        _NOEXCEPT_(is_nothrow_copy_constructible<_T1>::value &&
                   is_nothrow_copy_constructible<_T2>::value)
        : __first_(__p.first()),
          __second_(__p.second()) {}

    _LIBCPP_INLINE_VISIBILITY
    __libcpp_compressed_pair_imp& operator=(const __libcpp_compressed_pair_imp& __p)
        _NOEXCEPT_(is_nothrow_copy_assignable<_T1>::value &&
                   is_nothrow_copy_assignable<_T2>::value)
        {
            __first_ = __p.first();
            __second_ = __p.second();
            return *this;
        }

    _LIBCPP_INLINE_VISIBILITY
    __libcpp_compressed_pair_imp(__libcpp_compressed_pair_imp&& __p)
        _NOEXCEPT_(is_nothrow_move_constructible<_T1>::value &&
                   is_nothrow_move_constructible<_T2>::value)
        : __first_(_VSTD::forward<_T1>(__p.first())),
          __second_(_VSTD::forward<_T2>(__p.second())) {}

    _LIBCPP_INLINE_VISIBILITY
    __libcpp_compressed_pair_imp& operator=(__libcpp_compressed_pair_imp&& __p)
        _NOEXCEPT_(is_nothrow_move_assignable<_T1>::value &&
                   is_nothrow_move_assignable<_T2>::value)
        {
            __first_ = _VSTD::forward<_T1>(__p.first());
            __second_ = _VSTD::forward<_T2>(__p.second());
            return *this;
        }

#endif  // defined(_LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS) && !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES)
# 1994 "/usr/include/c++/v1/memory" 3

#ifndef _LIBCPP_HAS_NO_VARIADICS

    template <class... _Args1, class... _Args2, size_t... _I1, size_t... _I2>
        _LIBCPP_INLINE_VISIBILITY
        __libcpp_compressed_pair_imp(piecewise_construct_t __pc,
                                     tuple<_Args1...> __first_args,
                                     tuple<_Args2...> __second_args,
                                     __tuple_indices<_I1...>,
                                     __tuple_indices<_I2...>)
            : __first_(_VSTD::forward<_Args1>(get<_I1>(__first_args))...),
              __second_(_VSTD::forward<_Args2>(get<_I2>(__second_args))...)
            {}

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 2009 "/usr/include/c++/v1/memory" 3

    _LIBCPP_INLINE_VISIBILITY _T1_reference       first() _NOEXCEPT       {return __first_;}
    _LIBCPP_INLINE_VISIBILITY _T1_const_reference first() const _NOEXCEPT {return __first_;}

    _LIBCPP_INLINE_VISIBILITY _T2_reference       second() _NOEXCEPT       {return __second_;}
    _LIBCPP_INLINE_VISIBILITY _T2_const_reference second() const _NOEXCEPT {return __second_;}

    _LIBCPP_INLINE_VISIBILITY void swap(__libcpp_compressed_pair_imp& __x)
        _NOEXCEPT_(__is_nothrow_swappable<_T1>::value &&
                   __is_nothrow_swappable<_T1>::value)
    {
        using _VSTD::swap;
        swap(__first_, __x.__first_);
        swap(__second_, __x.__second_);
    }
};

template <class _T1, class _T2>
class __libcpp_compressed_pair_imp<_T1, _T2, 1>
    : private _T1
{
private:
    _T2 __second_;
public:
    typedef _T1 _T1_param;
    typedef _T2 _T2_param;

    typedef _T1&                                        _T1_reference;
    typedef typename remove_reference<_T2>::type& _T2_reference;

    typedef const _T1&                                        _T1_const_reference;
    typedef const typename remove_reference<_T2>::type& _T2_const_reference;

    _LIBCPP_INLINE_VISIBILITY __libcpp_compressed_pair_imp() {}
    _LIBCPP_INLINE_VISIBILITY explicit __libcpp_compressed_pair_imp(_T1_param __t1)
        : _T1(_VSTD::forward<_T1_param>(__t1)) {}
    _LIBCPP_INLINE_VISIBILITY explicit __libcpp_compressed_pair_imp(_T2_param __t2)
        : __second_(_VSTD::forward<_T2_param>(__t2)) {}
    _LIBCPP_INLINE_VISIBILITY __libcpp_compressed_pair_imp(_T1_param __t1, _T2_param __t2)
        : _T1(_VSTD::forward<_T1_param>(__t1)), __second_(_VSTD::forward<_T2_param>(__t2)) {}

#if defined(_LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS) && !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES)

    _LIBCPP_INLINE_VISIBILITY
    __libcpp_compressed_pair_imp(const __libcpp_compressed_pair_imp& __p)
        _NOEXCEPT_(is_nothrow_copy_constructible<_T1>::value &&
                   is_nothrow_copy_constructible<_T2>::value)
        : _T1(__p.first()), __second_(__p.second()) {}

    _LIBCPP_INLINE_VISIBILITY
    __libcpp_compressed_pair_imp& operator=(const __libcpp_compressed_pair_imp& __p)
        _NOEXCEPT_(is_nothrow_copy_assignable<_T1>::value &&
                   is_nothrow_copy_assignable<_T2>::value)
        {
            _T1::operator=(__p.first());
            __second_ = __p.second();
            return *this;
        }

    _LIBCPP_INLINE_VISIBILITY
    __libcpp_compressed_pair_imp(__libcpp_compressed_pair_imp&& __p)
        _NOEXCEPT_(is_nothrow_move_constructible<_T1>::value &&
                   is_nothrow_move_constructible<_T2>::value)
        : _T1(_VSTD::move(__p.first())), __second_(_VSTD::forward<_T2>(__p.second())) {}

    _LIBCPP_INLINE_VISIBILITY
    __libcpp_compressed_pair_imp& operator=(__libcpp_compressed_pair_imp&& __p)
        _NOEXCEPT_(is_nothrow_move_assignable<_T1>::value &&
                   is_nothrow_move_assignable<_T2>::value)
        {
            _T1::operator=(_VSTD::move(__p.first()));
            __second_ = _VSTD::forward<_T2>(__p.second());
            return *this;
        }

#endif  // defined(_LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS) && !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES)
# 2085 "/usr/include/c++/v1/memory" 3

#ifndef _LIBCPP_HAS_NO_VARIADICS

    template <class... _Args1, class... _Args2, size_t... _I1, size_t... _I2>
        _LIBCPP_INLINE_VISIBILITY
        __libcpp_compressed_pair_imp(piecewise_construct_t __pc,
                                     tuple<_Args1...> __first_args,
                                     tuple<_Args2...> __second_args,
                                     __tuple_indices<_I1...>,
                                     __tuple_indices<_I2...>)
            : _T1(_VSTD::forward<_Args1>(get<_I1>(__first_args))...),
              __second_(_VSTD::forward<_Args2>(get<_I2>(__second_args))...)
            {}

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 2100 "/usr/include/c++/v1/memory" 3

    _LIBCPP_INLINE_VISIBILITY _T1_reference       first() _NOEXCEPT       {return *this;}
    _LIBCPP_INLINE_VISIBILITY _T1_const_reference first() const _NOEXCEPT {return *this;}

    _LIBCPP_INLINE_VISIBILITY _T2_reference       second() _NOEXCEPT       {return __second_;}
    _LIBCPP_INLINE_VISIBILITY _T2_const_reference second() const _NOEXCEPT {return __second_;}

    _LIBCPP_INLINE_VISIBILITY void swap(__libcpp_compressed_pair_imp& __x)
        _NOEXCEPT_(__is_nothrow_swappable<_T1>::value &&
                   __is_nothrow_swappable<_T1>::value)
    {
        using _VSTD::swap;
        swap(__second_, __x.__second_);
    }
};

template <class _T1, class _T2>
class __libcpp_compressed_pair_imp<_T1, _T2, 2>
    : private _T2
{
private:
    _T1 __first_;
public:
    typedef _T1 _T1_param;
    typedef _T2 _T2_param;

    typedef typename remove_reference<_T1>::type& _T1_reference;
    typedef _T2&                                        _T2_reference;

    typedef const typename remove_reference<_T1>::type& _T1_const_reference;
    typedef const _T2&                                        _T2_const_reference;

    _LIBCPP_INLINE_VISIBILITY __libcpp_compressed_pair_imp() {}
    _LIBCPP_INLINE_VISIBILITY explicit __libcpp_compressed_pair_imp(_T1_param __t1)
        : __first_(_VSTD::forward<_T1_param>(__t1)) {}
    _LIBCPP_INLINE_VISIBILITY explicit __libcpp_compressed_pair_imp(_T2_param __t2)
        : _T2(_VSTD::forward<_T2_param>(__t2)) {}
    _LIBCPP_INLINE_VISIBILITY __libcpp_compressed_pair_imp(_T1_param __t1, _T2_param __t2)
        _NOEXCEPT_(is_nothrow_move_constructible<_T1>::value &&
                   is_nothrow_move_constructible<_T2>::value)
        : _T2(_VSTD::forward<_T2_param>(__t2)), __first_(_VSTD::forward<_T1_param>(__t1)) {}

#if defined(_LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS) && !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES)

    _LIBCPP_INLINE_VISIBILITY
    __libcpp_compressed_pair_imp(const __libcpp_compressed_pair_imp& __p)
        _NOEXCEPT_(is_nothrow_copy_constructible<_T1>::value &&
                   is_nothrow_copy_constructible<_T2>::value)
        : _T2(__p.second()), __first_(__p.first()) {}

    _LIBCPP_INLINE_VISIBILITY
    __libcpp_compressed_pair_imp& operator=(const __libcpp_compressed_pair_imp& __p)
        _NOEXCEPT_(is_nothrow_copy_assignable<_T1>::value &&
                   is_nothrow_copy_assignable<_T2>::value)
        {
            _T2::operator=(__p.second());
            __first_ = __p.first();
            return *this;
        }

    _LIBCPP_INLINE_VISIBILITY
    __libcpp_compressed_pair_imp(__libcpp_compressed_pair_imp&& __p)
        _NOEXCEPT_(is_nothrow_move_constructible<_T1>::value &&
                   is_nothrow_move_constructible<_T2>::value)
        : _T2(_VSTD::forward<_T2>(__p.second())), __first_(_VSTD::move(__p.first())) {}

    _LIBCPP_INLINE_VISIBILITY
    __libcpp_compressed_pair_imp& operator=(__libcpp_compressed_pair_imp&& __p)
        _NOEXCEPT_(is_nothrow_move_assignable<_T1>::value &&
                   is_nothrow_move_assignable<_T2>::value)
        {
            _T2::operator=(_VSTD::forward<_T2>(__p.second()));
            __first_ = _VSTD::move(__p.first());
            return *this;
        }

#endif  // defined(_LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS) && !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES)
# 2177 "/usr/include/c++/v1/memory" 3

#ifndef _LIBCPP_HAS_NO_VARIADICS

    template <class... _Args1, class... _Args2, size_t... _I1, size_t... _I2>
        _LIBCPP_INLINE_VISIBILITY
        __libcpp_compressed_pair_imp(piecewise_construct_t __pc,
                                     tuple<_Args1...> __first_args,
                                     tuple<_Args2...> __second_args,
                                     __tuple_indices<_I1...>,
                                     __tuple_indices<_I2...>)
            : _T2(_VSTD::forward<_Args2>(get<_I2>(__second_args))...),
              __first_(_VSTD::forward<_Args1>(get<_I1>(__first_args))...)
              
            {}

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 2193 "/usr/include/c++/v1/memory" 3

    _LIBCPP_INLINE_VISIBILITY _T1_reference       first() _NOEXCEPT       {return __first_;}
    _LIBCPP_INLINE_VISIBILITY _T1_const_reference first() const _NOEXCEPT {return __first_;}

    _LIBCPP_INLINE_VISIBILITY _T2_reference       second() _NOEXCEPT       {return *this;}
    _LIBCPP_INLINE_VISIBILITY _T2_const_reference second() const _NOEXCEPT {return *this;}

    _LIBCPP_INLINE_VISIBILITY void swap(__libcpp_compressed_pair_imp& __x)
        _NOEXCEPT_(__is_nothrow_swappable<_T1>::value &&
                   __is_nothrow_swappable<_T1>::value)
    {
        using _VSTD::swap;
        swap(__first_, __x.__first_);
    }
};

template <class _T1, class _T2>
class __libcpp_compressed_pair_imp<_T1, _T2, 3>
    : private _T1,
      private _T2
{
public:
    typedef _T1 _T1_param;
    typedef _T2 _T2_param;

    typedef _T1& _T1_reference;
    typedef _T2& _T2_reference;

    typedef const _T1& _T1_const_reference;
    typedef const _T2& _T2_const_reference;

    _LIBCPP_INLINE_VISIBILITY __libcpp_compressed_pair_imp() {}
    _LIBCPP_INLINE_VISIBILITY explicit __libcpp_compressed_pair_imp(_T1_param __t1)
        : _T1(_VSTD::forward<_T1_param>(__t1)) {}
    _LIBCPP_INLINE_VISIBILITY explicit __libcpp_compressed_pair_imp(_T2_param __t2)
        : _T2(_VSTD::forward<_T2_param>(__t2)) {}
    _LIBCPP_INLINE_VISIBILITY __libcpp_compressed_pair_imp(_T1_param __t1, _T2_param __t2)
        : _T1(_VSTD::forward<_T1_param>(__t1)), _T2(_VSTD::forward<_T2_param>(__t2)) {}

#if defined(_LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS) && !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES)

    _LIBCPP_INLINE_VISIBILITY
    __libcpp_compressed_pair_imp(const __libcpp_compressed_pair_imp& __p)
        _NOEXCEPT_(is_nothrow_copy_constructible<_T1>::value &&
                   is_nothrow_copy_constructible<_T2>::value)
        : _T1(__p.first()), _T2(__p.second()) {}

    _LIBCPP_INLINE_VISIBILITY
    __libcpp_compressed_pair_imp& operator=(const __libcpp_compressed_pair_imp& __p)
        _NOEXCEPT_(is_nothrow_copy_assignable<_T1>::value &&
                   is_nothrow_copy_assignable<_T2>::value)
        {
            _T1::operator=(__p.first());
            _T2::operator=(__p.second());
            return *this;
        }

    _LIBCPP_INLINE_VISIBILITY
    __libcpp_compressed_pair_imp(__libcpp_compressed_pair_imp&& __p)
        _NOEXCEPT_(is_nothrow_move_constructible<_T1>::value &&
                   is_nothrow_move_constructible<_T2>::value)
        : _T1(_VSTD::move(__p.first())), _T2(_VSTD::move(__p.second())) {}

    _LIBCPP_INLINE_VISIBILITY
    __libcpp_compressed_pair_imp& operator=(__libcpp_compressed_pair_imp&& __p)
        _NOEXCEPT_(is_nothrow_move_assignable<_T1>::value &&
                   is_nothrow_move_assignable<_T2>::value)
        {
            _T1::operator=(_VSTD::move(__p.first()));
            _T2::operator=(_VSTD::move(__p.second()));
            return *this;
        }

#endif  // defined(_LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS) && !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES)
# 2267 "/usr/include/c++/v1/memory" 3

#ifndef _LIBCPP_HAS_NO_VARIADICS

    template <class... _Args1, class... _Args2, size_t... _I1, size_t... _I2>
        _LIBCPP_INLINE_VISIBILITY
        __libcpp_compressed_pair_imp(piecewise_construct_t __pc,
                                     tuple<_Args1...> __first_args,
                                     tuple<_Args2...> __second_args,
                                     __tuple_indices<_I1...>,
                                     __tuple_indices<_I2...>)
            : _T1(_VSTD::forward<_Args1>(get<_I1>(__first_args))...),
              _T2(_VSTD::forward<_Args2>(get<_I2>(__second_args))...)
            {}

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 2282 "/usr/include/c++/v1/memory" 3

    _LIBCPP_INLINE_VISIBILITY _T1_reference       first() _NOEXCEPT       {return *this;}
    _LIBCPP_INLINE_VISIBILITY _T1_const_reference first() const _NOEXCEPT {return *this;}

    _LIBCPP_INLINE_VISIBILITY _T2_reference       second() _NOEXCEPT       {return *this;}
    _LIBCPP_INLINE_VISIBILITY _T2_const_reference second() const _NOEXCEPT {return *this;}

    _LIBCPP_INLINE_VISIBILITY void swap(__libcpp_compressed_pair_imp&)
        _NOEXCEPT_(__is_nothrow_swappable<_T1>::value &&
                   __is_nothrow_swappable<_T1>::value)
    {
    }
};

template <class _T1, class _T2>
class __compressed_pair
    : private __libcpp_compressed_pair_imp<_T1, _T2>
{
    typedef __libcpp_compressed_pair_imp<_T1, _T2> base;
public:
    typedef typename base::_T1_param _T1_param;
    typedef typename base::_T2_param _T2_param;

    typedef typename base::_T1_reference _T1_reference;
    typedef typename base::_T2_reference _T2_reference;

    typedef typename base::_T1_const_reference _T1_const_reference;
    typedef typename base::_T2_const_reference _T2_const_reference;

    _LIBCPP_INLINE_VISIBILITY __compressed_pair() {}
    _LIBCPP_INLINE_VISIBILITY explicit __compressed_pair(_T1_param __t1)
        : base(_VSTD::forward<_T1_param>(__t1)) {}
    _LIBCPP_INLINE_VISIBILITY explicit __compressed_pair(_T2_param __t2)
        : base(_VSTD::forward<_T2_param>(__t2)) {}
    _LIBCPP_INLINE_VISIBILITY __compressed_pair(_T1_param __t1, _T2_param __t2)
        : base(_VSTD::forward<_T1_param>(__t1), _VSTD::forward<_T2_param>(__t2)) {}

#if defined(_LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS) && !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES)

    _LIBCPP_INLINE_VISIBILITY
    __compressed_pair(const __compressed_pair& __p)
        _NOEXCEPT_(is_nothrow_copy_constructible<_T1>::value &&
                   is_nothrow_copy_constructible<_T2>::value)
        : base(__p) {}

    _LIBCPP_INLINE_VISIBILITY
    __compressed_pair& operator=(const __compressed_pair& __p)
        _NOEXCEPT_(is_nothrow_copy_assignable<_T1>::value &&
                   is_nothrow_copy_assignable<_T2>::value)
        {
            base::operator=(__p);
            return *this;
        }

    _LIBCPP_INLINE_VISIBILITY
    __compressed_pair(__compressed_pair&& __p)
        _NOEXCEPT_(is_nothrow_move_constructible<_T1>::value &&
                   is_nothrow_move_constructible<_T2>::value)
        : base(_VSTD::move(__p)) {}

    _LIBCPP_INLINE_VISIBILITY
    __compressed_pair& operator=(__compressed_pair&& __p)
        _NOEXCEPT_(is_nothrow_move_assignable<_T1>::value &&
                   is_nothrow_move_assignable<_T2>::value)
        {
            base::operator=(_VSTD::move(__p));
            return *this;
        }

#endif  // defined(_LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS) && !defined(_LIBCPP_HAS_NO_RVALUE_REFERENCES)
# 2352 "/usr/include/c++/v1/memory" 3

#ifndef _LIBCPP_HAS_NO_VARIADICS

    template <class... _Args1, class... _Args2>
        _LIBCPP_INLINE_VISIBILITY
        __compressed_pair(piecewise_construct_t __pc, tuple<_Args1...> __first_args,
                                                      tuple<_Args2...> __second_args)
            : base(__pc, _VSTD::move(__first_args), _VSTD::move(__second_args),
                   typename __make_tuple_indices<sizeof...(_Args1)>::type(),
                   typename __make_tuple_indices<sizeof...(_Args2) >::type())
            {}

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 2365 "/usr/include/c++/v1/memory" 3

    _LIBCPP_INLINE_VISIBILITY _T1_reference       first() _NOEXCEPT       {return base::first();}
    _LIBCPP_INLINE_VISIBILITY _T1_const_reference first() const _NOEXCEPT {return base::first();}

    _LIBCPP_INLINE_VISIBILITY _T2_reference       second() _NOEXCEPT       {return base::second();}
    _LIBCPP_INLINE_VISIBILITY _T2_const_reference second() const _NOEXCEPT {return base::second();}

    _LIBCPP_INLINE_VISIBILITY void swap(__compressed_pair& __x)
        _NOEXCEPT_(__is_nothrow_swappable<_T1>::value &&
                   __is_nothrow_swappable<_T1>::value)
        {base::swap(__x);}
};

template <class _T1, class _T2>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(__compressed_pair<_T1, _T2>& __x, __compressed_pair<_T1, _T2>& __y)
        _NOEXCEPT_(__is_nothrow_swappable<_T1>::value &&
                   __is_nothrow_swappable<_T1>::value)
    {__x.swap(__y);}

// __same_or_less_cv_qualified

template <class _Ptr1, class _Ptr2,
          bool = is_same<typename remove_cv<typename pointer_traits<_Ptr1>::element_type>::type,
                         typename remove_cv<typename pointer_traits<_Ptr2>::element_type>::type
                        >::value
         >
struct __same_or_less_cv_qualified_imp
    : is_convertible<_Ptr1, _Ptr2> {};

template <class _Ptr1, class _Ptr2>
struct __same_or_less_cv_qualified_imp<_Ptr1, _Ptr2, false>
    : false_type {};

template <class _Ptr1, class _Ptr2, bool = is_scalar<_Ptr1>::value &&
                                         !is_pointer<_Ptr1>::value>
struct __same_or_less_cv_qualified
    : __same_or_less_cv_qualified_imp<_Ptr1, _Ptr2> {};

template <class _Ptr1, class _Ptr2>
struct __same_or_less_cv_qualified<_Ptr1, _Ptr2, true>
    : false_type {};

// default_delete

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY default_delete
{
#ifndef _LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR default_delete() _NOEXCEPT = default;
#else
# 2417 "/usr/include/c++/v1/memory" 3
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR default_delete() _NOEXCEPT {}
#endif
# 2419 "/usr/include/c++/v1/memory" 3
    template <class _Up>
        _LIBCPP_INLINE_VISIBILITY default_delete(const default_delete<_Up>&,
             typename enable_if<is_convertible<_Up*, _Tp*>::value>::type* = 0) _NOEXCEPT {}
    _LIBCPP_INLINE_VISIBILITY void operator() (_Tp* __ptr) const _NOEXCEPT
        {
            static_assert(sizeof(_Tp) > 0, "default_delete can not delete incomplete type");
            static_assert(!is_void<_Tp>::value, "default_delete can not delete incomplete type");
            delete __ptr;
        }
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY default_delete<_Tp[]>
{
public:
#ifndef _LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR default_delete() _NOEXCEPT = default;
#else
# 2437 "/usr/include/c++/v1/memory" 3
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR default_delete() _NOEXCEPT {}
#endif
# 2439 "/usr/include/c++/v1/memory" 3
    template <class _Up>
        _LIBCPP_INLINE_VISIBILITY default_delete(const default_delete<_Up[]>&,
             typename enable_if<__same_or_less_cv_qualified<_Up*, _Tp*>::value>::type* = 0) _NOEXCEPT {}
    template <class _Up>
        _LIBCPP_INLINE_VISIBILITY
        void operator() (_Up* __ptr,
                         typename enable_if<__same_or_less_cv_qualified<_Up*, _Tp*>::value>::type* = 0) const _NOEXCEPT
        {
            static_assert(sizeof(_Tp) > 0, "default_delete can not delete incomplete type");
            static_assert(!is_void<_Tp>::value, "default_delete can not delete incomplete type");
            delete [] __ptr;
        }
};

template <class _Tp, class _Dp = default_delete<_Tp> >
class _LIBCPP_TYPE_VIS_ONLY unique_ptr
{
public:
    typedef _Tp element_type;
    typedef _Dp deleter_type;
    typedef typename __pointer_type<_Tp, deleter_type>::type pointer;
private:
    __compressed_pair<pointer, deleter_type> __ptr_;

#ifdef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    unique_ptr(unique_ptr&);
    template <class _Up, class _Ep>
        unique_ptr(unique_ptr<_Up, _Ep>&);
    unique_ptr& operator=(unique_ptr&);
    template <class _Up, class _Ep>
        unique_ptr& operator=(unique_ptr<_Up, _Ep>&);
#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 2471 "/usr/include/c++/v1/memory" 3

    struct __nat {int __for_bool_;};

    typedef       typename remove_reference<deleter_type>::type& _Dp_reference;
    typedef const typename remove_reference<deleter_type>::type& _Dp_const_reference;
public:
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR unique_ptr() _NOEXCEPT
        : __ptr_(pointer())
        {
            static_assert(!is_pointer<deleter_type>::value,
                "unique_ptr constructed with null function pointer deleter");
        }
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR unique_ptr(nullptr_t) _NOEXCEPT
        : __ptr_(pointer())
        {
            static_assert(!is_pointer<deleter_type>::value,
                "unique_ptr constructed with null function pointer deleter");
        }
    _LIBCPP_INLINE_VISIBILITY explicit unique_ptr(pointer __p) _NOEXCEPT
        : __ptr_(_VSTD::move(__p))
        {
            static_assert(!is_pointer<deleter_type>::value,
                "unique_ptr constructed with null function pointer deleter");
        }

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    _LIBCPP_INLINE_VISIBILITY unique_ptr(pointer __p, typename conditional<
                                        is_reference<deleter_type>::value,
                                        deleter_type,
                                        typename add_lvalue_reference<const deleter_type>::type>::type __d)
             _NOEXCEPT
        : __ptr_(__p, __d) {}

    _LIBCPP_INLINE_VISIBILITY unique_ptr(pointer __p, typename remove_reference<deleter_type>::type&& __d)
             _NOEXCEPT
        : __ptr_(__p, _VSTD::move(__d))
        {
            static_assert(!is_reference<deleter_type>::value, "rvalue deleter bound to reference");
        }
    _LIBCPP_INLINE_VISIBILITY unique_ptr(unique_ptr&& __u) _NOEXCEPT
        : __ptr_(__u.release(), _VSTD::forward<deleter_type>(__u.get_deleter())) {}
    template <class _Up, class _Ep>
        _LIBCPP_INLINE_VISIBILITY
        unique_ptr(unique_ptr<_Up, _Ep>&& __u,
                   typename enable_if
                      <
                        !is_array<_Up>::value &&
                         is_convertible<typename unique_ptr<_Up, _Ep>::pointer, pointer>::value &&
                         is_convertible<_Ep, deleter_type>::value &&
                         (
                            !is_reference<deleter_type>::value ||
                            is_same<deleter_type, _Ep>::value
                         ),
                         __nat
                      >::type = __nat()) _NOEXCEPT
            : __ptr_(__u.release(), _VSTD::forward<_Ep>(__u.get_deleter())) {}

    template <class _Up>
        _LIBCPP_INLINE_VISIBILITY unique_ptr(auto_ptr<_Up>&& __p,
                typename enable_if<
                                      is_convertible<_Up*, _Tp*>::value &&
                                      is_same<_Dp, default_delete<_Tp> >::value,
                                      __nat
                                  >::type = __nat()) _NOEXCEPT
            : __ptr_(__p.release())
            {
            }

        _LIBCPP_INLINE_VISIBILITY unique_ptr& operator=(unique_ptr&& __u) _NOEXCEPT
            {
                reset(__u.release());
                __ptr_.second() = _VSTD::forward<deleter_type>(__u.get_deleter());
                return *this;
            }

        template <class _Up, class _Ep>
            _LIBCPP_INLINE_VISIBILITY
            typename enable_if
            <
                !is_array<_Up>::value &&
                is_convertible<typename unique_ptr<_Up, _Ep>::pointer, pointer>::value &&
                is_assignable<deleter_type&, _Ep&&>::value,
                unique_ptr&
            >::type
            operator=(unique_ptr<_Up, _Ep>&& __u) _NOEXCEPT
            {
                reset(__u.release());
                __ptr_.second() = _VSTD::forward<_Ep>(__u.get_deleter());
                return *this;
            }
#else  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 2562 "/usr/include/c++/v1/memory" 3

    _LIBCPP_INLINE_VISIBILITY operator __rv<unique_ptr>()
    {
        return __rv<unique_ptr>(*this);
    }

    _LIBCPP_INLINE_VISIBILITY unique_ptr(__rv<unique_ptr> __u)
        : __ptr_(__u->release(), _VSTD::forward<deleter_type>(__u->get_deleter())) {}

    template <class _Up, class _Ep>
    _LIBCPP_INLINE_VISIBILITY unique_ptr& operator=(unique_ptr<_Up, _Ep> __u)
    {
        reset(__u.release());
        __ptr_.second() = _VSTD::forward<deleter_type>(__u.get_deleter());
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY unique_ptr(pointer __p, deleter_type __d)
        : __ptr_(_VSTD::move(__p), _VSTD::move(__d)) {}

    template <class _Up>
        _LIBCPP_INLINE_VISIBILITY
                typename enable_if<
                                      is_convertible<_Up*, _Tp*>::value &&
                                      is_same<_Dp, default_delete<_Tp> >::value,
                                      unique_ptr&
                                  >::type
        operator=(auto_ptr<_Up> __p)
            {reset(__p.release()); return *this;}

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 2593 "/usr/include/c++/v1/memory" 3
    _LIBCPP_INLINE_VISIBILITY ~unique_ptr() {reset();}

    _LIBCPP_INLINE_VISIBILITY unique_ptr& operator=(nullptr_t) _NOEXCEPT
    {
        reset();
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY typename add_lvalue_reference<_Tp>::type operator*() const
        {return *__ptr_.first();}
    _LIBCPP_INLINE_VISIBILITY pointer operator->() const _NOEXCEPT {return __ptr_.first();}
    _LIBCPP_INLINE_VISIBILITY pointer get() const _NOEXCEPT {return __ptr_.first();}
    _LIBCPP_INLINE_VISIBILITY       _Dp_reference get_deleter() _NOEXCEPT
        {return __ptr_.second();}
    _LIBCPP_INLINE_VISIBILITY _Dp_const_reference get_deleter() const _NOEXCEPT
        {return __ptr_.second();}
    _LIBCPP_INLINE_VISIBILITY
        _LIBCPP_EXPLICIT operator bool() const _NOEXCEPT
        {return __ptr_.first() != nullptr;}

    _LIBCPP_INLINE_VISIBILITY pointer release() _NOEXCEPT
    {
        pointer __t = __ptr_.first();
        __ptr_.first() = pointer();
        return __t;
    }

    _LIBCPP_INLINE_VISIBILITY void reset(pointer __p = pointer()) _NOEXCEPT
    {
        pointer __tmp = __ptr_.first();
        __ptr_.first() = __p;
        if (__tmp)
            __ptr_.second()(__tmp);
    }

    _LIBCPP_INLINE_VISIBILITY void swap(unique_ptr& __u) _NOEXCEPT
        {__ptr_.swap(__u.__ptr_);}
};

template <class _Tp, class _Dp>
class _LIBCPP_TYPE_VIS_ONLY unique_ptr<_Tp[], _Dp>
{
public:
    typedef _Tp element_type;
    typedef _Dp deleter_type;
    typedef typename __pointer_type<_Tp, deleter_type>::type pointer;
private:
    __compressed_pair<pointer, deleter_type> __ptr_;

#ifdef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    unique_ptr(unique_ptr&);
    template <class _Up>
        unique_ptr(unique_ptr<_Up>&);
    unique_ptr& operator=(unique_ptr&);
    template <class _Up>
        unique_ptr& operator=(unique_ptr<_Up>&);
#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 2650 "/usr/include/c++/v1/memory" 3

    struct __nat {int __for_bool_;};

    typedef       typename remove_reference<deleter_type>::type& _Dp_reference;
    typedef const typename remove_reference<deleter_type>::type& _Dp_const_reference;
public:
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR unique_ptr() _NOEXCEPT
        : __ptr_(pointer())
        {
            static_assert(!is_pointer<deleter_type>::value,
                "unique_ptr constructed with null function pointer deleter");
        }
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR unique_ptr(nullptr_t) _NOEXCEPT
        : __ptr_(pointer())
        {
            static_assert(!is_pointer<deleter_type>::value,
                "unique_ptr constructed with null function pointer deleter");
        }
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    template <class _Pp,
              class = typename enable_if<__same_or_less_cv_qualified<_Pp, pointer>::value>::type
             >
    _LIBCPP_INLINE_VISIBILITY explicit unique_ptr(_Pp __p) _NOEXCEPT
        : __ptr_(__p)
        {
            static_assert(!is_pointer<deleter_type>::value,
                "unique_ptr constructed with null function pointer deleter");
        }

    template <class _Pp,
              class = typename enable_if<__same_or_less_cv_qualified<_Pp, pointer>::value>::type
             >
    _LIBCPP_INLINE_VISIBILITY unique_ptr(_Pp __p, typename conditional<
                                       is_reference<deleter_type>::value,
                                       deleter_type,
                                       typename add_lvalue_reference<const deleter_type>::type>::type __d)
             _NOEXCEPT
        : __ptr_(__p, __d) {}

    _LIBCPP_INLINE_VISIBILITY unique_ptr(nullptr_t, typename conditional<
                                       is_reference<deleter_type>::value,
                                       deleter_type,
                                       typename add_lvalue_reference<const deleter_type>::type>::type __d)
             _NOEXCEPT
        : __ptr_(pointer(), __d) {}

    template <class _Pp,
              class = typename enable_if<__same_or_less_cv_qualified<_Pp, pointer>::value>::type
             >
    _LIBCPP_INLINE_VISIBILITY unique_ptr(_Pp __p, typename remove_reference<deleter_type>::type&& __d)
             _NOEXCEPT
        : __ptr_(__p, _VSTD::move(__d))
        {
            static_assert(!is_reference<deleter_type>::value, "rvalue deleter bound to reference");
        }

    _LIBCPP_INLINE_VISIBILITY unique_ptr(nullptr_t, typename remove_reference<deleter_type>::type&& __d)
             _NOEXCEPT
        : __ptr_(pointer(), _VSTD::move(__d))
        {
            static_assert(!is_reference<deleter_type>::value, "rvalue deleter bound to reference");
        }

    _LIBCPP_INLINE_VISIBILITY unique_ptr(unique_ptr&& __u) _NOEXCEPT
        : __ptr_(__u.release(), _VSTD::forward<deleter_type>(__u.get_deleter())) {}

    _LIBCPP_INLINE_VISIBILITY unique_ptr& operator=(unique_ptr&& __u) _NOEXCEPT
        {
            reset(__u.release());
            __ptr_.second() = _VSTD::forward<deleter_type>(__u.get_deleter());
            return *this;
        }

    template <class _Up, class _Ep>
        _LIBCPP_INLINE_VISIBILITY
        unique_ptr(unique_ptr<_Up, _Ep>&& __u,
                   typename enable_if
                            <
                                is_array<_Up>::value &&
                                __same_or_less_cv_qualified<typename unique_ptr<_Up, _Ep>::pointer, pointer>::value
                                && is_convertible<_Ep, deleter_type>::value &&
                                (
                                    !is_reference<deleter_type>::value ||
                                    is_same<deleter_type, _Ep>::value
                                ),
                                __nat
                            >::type = __nat()
                  ) _NOEXCEPT
        : __ptr_(__u.release(), _VSTD::forward<deleter_type>(__u.get_deleter())) {}


        template <class _Up, class _Ep>
            _LIBCPP_INLINE_VISIBILITY
            typename enable_if
            <
                is_array<_Up>::value &&
                __same_or_less_cv_qualified<typename unique_ptr<_Up, _Ep>::pointer, pointer>::value &&
                is_assignable<deleter_type&, _Ep&&>::value,
                unique_ptr&
            >::type
            operator=(unique_ptr<_Up, _Ep>&& __u) _NOEXCEPT
            {
                reset(__u.release());
                __ptr_.second() = _VSTD::forward<_Ep>(__u.get_deleter());
                return *this;
            }
#else  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 2757 "/usr/include/c++/v1/memory" 3

    _LIBCPP_INLINE_VISIBILITY explicit unique_ptr(pointer __p)
        : __ptr_(__p)
        {
            static_assert(!is_pointer<deleter_type>::value,
                "unique_ptr constructed with null function pointer deleter");
        }

    _LIBCPP_INLINE_VISIBILITY unique_ptr(pointer __p, deleter_type __d)
        : __ptr_(__p, _VSTD::forward<deleter_type>(__d)) {}

    _LIBCPP_INLINE_VISIBILITY unique_ptr(nullptr_t, deleter_type __d)
        : __ptr_(pointer(), _VSTD::forward<deleter_type>(__d)) {}

    _LIBCPP_INLINE_VISIBILITY operator __rv<unique_ptr>()
    {
        return __rv<unique_ptr>(*this);
    }

    _LIBCPP_INLINE_VISIBILITY unique_ptr(__rv<unique_ptr> __u)
        : __ptr_(__u->release(), _VSTD::forward<deleter_type>(__u->get_deleter())) {}

    _LIBCPP_INLINE_VISIBILITY unique_ptr& operator=(__rv<unique_ptr> __u)
    {
        reset(__u->release());
        __ptr_.second() = _VSTD::forward<deleter_type>(__u->get_deleter());
        return *this;
    }

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 2787 "/usr/include/c++/v1/memory" 3
    _LIBCPP_INLINE_VISIBILITY ~unique_ptr() {reset();}

    _LIBCPP_INLINE_VISIBILITY unique_ptr& operator=(nullptr_t) _NOEXCEPT
    {
        reset();
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY typename add_lvalue_reference<_Tp>::type operator[](size_t __i) const
        {return __ptr_.first()[__i];}
    _LIBCPP_INLINE_VISIBILITY pointer get() const _NOEXCEPT {return __ptr_.first();}
    _LIBCPP_INLINE_VISIBILITY       _Dp_reference get_deleter() _NOEXCEPT
        {return __ptr_.second();}
    _LIBCPP_INLINE_VISIBILITY _Dp_const_reference get_deleter() const _NOEXCEPT
        {return __ptr_.second();}
    _LIBCPP_INLINE_VISIBILITY
        _LIBCPP_EXPLICIT operator bool() const _NOEXCEPT
        {return __ptr_.first() != nullptr;}

    _LIBCPP_INLINE_VISIBILITY pointer release() _NOEXCEPT
    {
        pointer __t = __ptr_.first();
        __ptr_.first() = pointer();
        return __t;
    }

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    template <class _Pp,
              class = typename enable_if<__same_or_less_cv_qualified<_Pp, pointer>::value>::type
             >
    _LIBCPP_INLINE_VISIBILITY void reset(_Pp __p) _NOEXCEPT
    {
        pointer __tmp = __ptr_.first();
        __ptr_.first() = __p;
        if (__tmp)
            __ptr_.second()(__tmp);
    }
    _LIBCPP_INLINE_VISIBILITY void reset(nullptr_t) _NOEXCEPT
    {
        pointer __tmp = __ptr_.first();
        __ptr_.first() = nullptr;
        if (__tmp)
            __ptr_.second()(__tmp);
    }
    _LIBCPP_INLINE_VISIBILITY void reset() _NOEXCEPT
    {
        pointer __tmp = __ptr_.first();
        __ptr_.first() = nullptr;
        if (__tmp)
            __ptr_.second()(__tmp);
    }
#else  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 2839 "/usr/include/c++/v1/memory" 3
    _LIBCPP_INLINE_VISIBILITY void reset(pointer __p = pointer())
    {
        pointer __tmp = __ptr_.first();
        __ptr_.first() = __p;
        if (__tmp)
            __ptr_.second()(__tmp);
    }
#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 2847 "/usr/include/c++/v1/memory" 3

    _LIBCPP_INLINE_VISIBILITY void swap(unique_ptr& __u) {__ptr_.swap(__u.__ptr_);}
private:

#ifdef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    template <class _Up>
        explicit unique_ptr(_Up);
    template <class _Up>
        unique_ptr(_Up __u,
                   typename conditional<
                                       is_reference<deleter_type>::value,
                                       deleter_type,
                                       typename add_lvalue_reference<const deleter_type>::type>::type,
                   typename enable_if
                      <
                         is_convertible<_Up, pointer>::value,
                         __nat
                      >::type = __nat());
#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 2866 "/usr/include/c++/v1/memory" 3
};

template <class _Tp, class _Dp>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(unique_ptr<_Tp, _Dp>& __x, unique_ptr<_Tp, _Dp>& __y) _NOEXCEPT {__x.swap(__y);}

template <class _T1, class _D1, class _T2, class _D2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const unique_ptr<_T1, _D1>& __x, const unique_ptr<_T2, _D2>& __y) {return __x.get() == __y.get();}

template <class _T1, class _D1, class _T2, class _D2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const unique_ptr<_T1, _D1>& __x, const unique_ptr<_T2, _D2>& __y) {return !(__x == __y);}

template <class _T1, class _D1, class _T2, class _D2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator< (const unique_ptr<_T1, _D1>& __x, const unique_ptr<_T2, _D2>& __y)
{
    typedef typename unique_ptr<_T1, _D1>::pointer _P1;
    typedef typename unique_ptr<_T2, _D2>::pointer _P2;
    typedef typename common_type<_P1, _P2>::type _V;
    return less<_V>()(__x.get(), __y.get());
}

template <class _T1, class _D1, class _T2, class _D2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator> (const unique_ptr<_T1, _D1>& __x, const unique_ptr<_T2, _D2>& __y) {return __y < __x;}

template <class _T1, class _D1, class _T2, class _D2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const unique_ptr<_T1, _D1>& __x, const unique_ptr<_T2, _D2>& __y) {return !(__y < __x);}

template <class _T1, class _D1, class _T2, class _D2>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const unique_ptr<_T1, _D1>& __x, const unique_ptr<_T2, _D2>& __y) {return !(__x < __y);}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const unique_ptr<_T1, _D1>& __x, nullptr_t) _NOEXCEPT
{
    return !__x;
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(nullptr_t, const unique_ptr<_T1, _D1>& __x) _NOEXCEPT
{
    return !__x;
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const unique_ptr<_T1, _D1>& __x, nullptr_t) _NOEXCEPT
{
    return static_cast<bool>(__x);
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(nullptr_t, const unique_ptr<_T1, _D1>& __x) _NOEXCEPT
{
    return static_cast<bool>(__x);
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<(const unique_ptr<_T1, _D1>& __x, nullptr_t)
{
    typedef typename unique_ptr<_T1, _D1>::pointer _P1;
    return less<_P1>()(__x.get(), nullptr);
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<(nullptr_t, const unique_ptr<_T1, _D1>& __x)
{
    typedef typename unique_ptr<_T1, _D1>::pointer _P1;
    return less<_P1>()(nullptr, __x.get());
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>(const unique_ptr<_T1, _D1>& __x, nullptr_t)
{
    return nullptr < __x;
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>(nullptr_t, const unique_ptr<_T1, _D1>& __x)
{
    return __x < nullptr;
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const unique_ptr<_T1, _D1>& __x, nullptr_t)
{
    return !(nullptr < __x);
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(nullptr_t, const unique_ptr<_T1, _D1>& __x)
{
    return !(__x < nullptr);
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const unique_ptr<_T1, _D1>& __x, nullptr_t)
{
    return !(__x < nullptr);
}

template <class _T1, class _D1>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(nullptr_t, const unique_ptr<_T1, _D1>& __x)
{
    return !(nullptr < __x);
}

#ifdef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template <class _Tp, class _Dp>
inline _LIBCPP_INLINE_VISIBILITY
unique_ptr<_Tp, _Dp>
move(unique_ptr<_Tp, _Dp>& __t)
{
    return unique_ptr<_Tp, _Dp>(__rv<unique_ptr<_Tp, _Dp> >(__t));
}

#endif
# 3018 "/usr/include/c++/v1/memory" 3

#if _LIBCPP_STD_VER > 11

template<class _Tp>
struct __unique_if
{
    typedef unique_ptr<_Tp> __unique_single;
};

template<class _Tp>
struct __unique_if<_Tp[]>
{
    typedef unique_ptr<_Tp[]> __unique_array_unknown_bound;
};

template<class _Tp, size_t _Np>
struct __unique_if<_Tp[_Np]>
{
    typedef void __unique_array_known_bound;
};

template<class _Tp, class... _Args>
inline _LIBCPP_INLINE_VISIBILITY
typename __unique_if<_Tp>::__unique_single
make_unique(_Args&&... __args)
{
    return unique_ptr<_Tp>(new _Tp(_VSTD::forward<_Args>(__args)...));
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
typename __unique_if<_Tp>::__unique_array_unknown_bound
make_unique(size_t __n)
{
    typedef typename remove_extent<_Tp>::type _Up;
    return unique_ptr<_Tp>(new _Up[__n]());
}

template<class _Tp, class... _Args>
    typename __unique_if<_Tp>::__unique_array_known_bound
    make_unique(_Args&&...) = delete;

#endif  // _LIBCPP_STD_VER > 11
# 3061 "/usr/include/c++/v1/memory" 3

template <class _Tp> struct hash;

template <class _Size>
inline _LIBCPP_INLINE_VISIBILITY
_Size
__loadword(const void* __p)
{
    _Size __r;
    std::memcpy(&__r, __p, sizeof(__r));
    return __r;
}

// We use murmur2 when size_t is 32 bits, and cityhash64 when size_t
// is 64 bits.  This is because cityhash64 uses 64bit x 64bit
// multiplication, which can be very slow on 32-bit systems.
template <class _Size, size_t = sizeof(_Size)*__CHAR_BIT__>
struct __murmur2_or_cityhash;

template <class _Size>
struct __murmur2_or_cityhash<_Size, 32>
{
    _Size operator()(const void* __key, _Size __len);
};

// murmur2
template <class _Size>
_Size
__murmur2_or_cityhash<_Size, 32>::operator()(const void* __key, _Size __len)
{
    const _Size __m = 0x5bd1e995;
    const _Size __r = 24;
    _Size __h = __len;
    const unsigned char* __data = static_cast<const unsigned char*>(__key);
    for (; __len >= 4; __data += 4, __len -= 4)
    {
        _Size __k = __loadword<_Size>(__data);
        __k *= __m;
        __k ^= __k >> __r;
        __k *= __m;
        __h *= __m;
        __h ^= __k;
    }
    switch (__len)
    {
    case 3:
        __h ^= __data[2] << 16;
    case 2:
        __h ^= __data[1] << 8;
    case 1:
        __h ^= __data[0];
        __h *= __m;
    }
    __h ^= __h >> 13;
    __h *= __m;
    __h ^= __h >> 15;
    return __h;
}

template <class _Size>
struct __murmur2_or_cityhash<_Size, 64>
{
    _Size operator()(const void* __key, _Size __len);

 private:
  // Some primes between 2^63 and 2^64.
  static const _Size __k0 = 0xc3a5c85c97cb3127ULL;
  static const _Size __k1 = 0xb492b66fbe98f273ULL;
  static const _Size __k2 = 0x9ae16a3b2f90404fULL;
  static const _Size __k3 = 0xc949d7c7509e6557ULL;

  static _Size __rotate(_Size __val, int __shift) {
    return __shift == 0 ? __val : ((__val >> __shift) | (__val << (64 - __shift)));
  }

  static _Size __rotate_by_at_least_1(_Size __val, int __shift) {
    return (__val >> __shift) | (__val << (64 - __shift));
  }

  static _Size __shift_mix(_Size __val) {
    return __val ^ (__val >> 47);
  }

  static _Size __hash_len_16(_Size __u, _Size __v) {
    const _Size __mul = 0x9ddfea08eb382d69ULL;
    _Size __a = (__u ^ __v) * __mul;
    __a ^= (__a >> 47);
    _Size __b = (__v ^ __a) * __mul;
    __b ^= (__b >> 47);
    __b *= __mul;
    return __b;
  }

  static _Size __hash_len_0_to_16(const char* __s, _Size __len) {
    if (__len > 8) {
      const _Size __a = __loadword<_Size>(__s);
      const _Size __b = __loadword<_Size>(__s + __len - 8);
      return __hash_len_16(__a, __rotate_by_at_least_1(__b + __len, __len)) ^ __b;
    }
    if (__len >= 4) {
      const uint32_t __a = __loadword<uint32_t>(__s);
      const uint32_t __b = __loadword<uint32_t>(__s + __len - 4);
      return __hash_len_16(__len + (__a << 3), __b);
    }
    if (__len > 0) {
      const unsigned char __a = __s[0];
      const unsigned char __b = __s[__len >> 1];
      const unsigned char __c = __s[__len - 1];
      const uint32_t __y = static_cast<uint32_t>(__a) +
                           (static_cast<uint32_t>(__b) << 8);
      const uint32_t __z = __len + (static_cast<uint32_t>(__c) << 2);
      return __shift_mix(__y * __k2 ^ __z * __k3) * __k2;
    }
    return __k2;
  }

  static _Size __hash_len_17_to_32(const char *__s, _Size __len) {
    const _Size __a = __loadword<_Size>(__s) * __k1;
    const _Size __b = __loadword<_Size>(__s + 8);
    const _Size __c = __loadword<_Size>(__s + __len - 8) * __k2;
    const _Size __d = __loadword<_Size>(__s + __len - 16) * __k0;
    return __hash_len_16(__rotate(__a - __b, 43) + __rotate(__c, 30) + __d,
                         __a + __rotate(__b ^ __k3, 20) - __c + __len);
  }

  // Return a 16-byte hash for 48 bytes.  Quick and dirty.
  // Callers do best to use "random-looking" values for a and b.
  static pair<_Size, _Size> __weak_hash_len_32_with_seeds(
      _Size __w, _Size __x, _Size __y, _Size __z, _Size __a, _Size __b) {
    __a += __w;
    __b = __rotate(__b + __a + __z, 21);
    const _Size __c = __a;
    __a += __x;
    __a += __y;
    __b += __rotate(__a, 44);
    return pair<_Size, _Size>(__a + __z, __b + __c);
  }

  // Return a 16-byte hash for s[0] ... s[31], a, and b.  Quick and dirty.
  static pair<_Size, _Size> __weak_hash_len_32_with_seeds(
      const char* __s, _Size __a, _Size __b) {
    return __weak_hash_len_32_with_seeds(__loadword<_Size>(__s),
                                         __loadword<_Size>(__s + 8),
                                         __loadword<_Size>(__s + 16),
                                         __loadword<_Size>(__s + 24),
                                         __a,
                                         __b);
  }

  // Return an 8-byte hash for 33 to 64 bytes.
  static _Size __hash_len_33_to_64(const char *__s, size_t __len) {
    _Size __z = __loadword<_Size>(__s + 24);
    _Size __a = __loadword<_Size>(__s) +
                (__len + __loadword<_Size>(__s + __len - 16)) * __k0;
    _Size __b = __rotate(__a + __z, 52);
    _Size __c = __rotate(__a, 37);
    __a += __loadword<_Size>(__s + 8);
    __c += __rotate(__a, 7);
    __a += __loadword<_Size>(__s + 16);
    _Size __vf = __a + __z;
    _Size __vs = __b + __rotate(__a, 31) + __c;
    __a = __loadword<_Size>(__s + 16) + __loadword<_Size>(__s + __len - 32);
    __z += __loadword<_Size>(__s + __len - 8);
    __b = __rotate(__a + __z, 52);
    __c = __rotate(__a, 37);
    __a += __loadword<_Size>(__s + __len - 24);
    __c += __rotate(__a, 7);
    __a += __loadword<_Size>(__s + __len - 16);
    _Size __wf = __a + __z;
    _Size __ws = __b + __rotate(__a, 31) + __c;
    _Size __r = __shift_mix((__vf + __ws) * __k2 + (__wf + __vs) * __k0);
    return __shift_mix(__r * __k0 + __vs) * __k2;
  }
};

// cityhash64
template <class _Size>
_Size
__murmur2_or_cityhash<_Size, 64>::operator()(const void* __key, _Size __len)
{
  const char* __s = static_cast<const char*>(__key);
  if (__len <= 32) {
    if (__len <= 16) {
      return __hash_len_0_to_16(__s, __len);
    } else {
      return __hash_len_17_to_32(__s, __len);
    }
  } else if (__len <= 64) {
    return __hash_len_33_to_64(__s, __len);
  }

  // For strings over 64 bytes we hash the end first, and then as we
  // loop we keep 56 bytes of state: v, w, x, y, and z.
  _Size __x = __loadword<_Size>(__s + __len - 40);
  _Size __y = __loadword<_Size>(__s + __len - 16) +
              __loadword<_Size>(__s + __len - 56);
  _Size __z = __hash_len_16(__loadword<_Size>(__s + __len - 48) + __len,
                          __loadword<_Size>(__s + __len - 24));
  pair<_Size, _Size> __v = __weak_hash_len_32_with_seeds(__s + __len - 64, __len, __z);
  pair<_Size, _Size> __w = __weak_hash_len_32_with_seeds(__s + __len - 32, __y + __k1, __x);
  __x = __x * __k1 + __loadword<_Size>(__s);

  // Decrease len to the nearest multiple of 64, and operate on 64-byte chunks.
  __len = (__len - 1) & ~static_cast<_Size>(63);
  do {
    __x = __rotate(__x + __y + __v.first + __loadword<_Size>(__s + 8), 37) * __k1;
    __y = __rotate(__y + __v.second + __loadword<_Size>(__s + 48), 42) * __k1;
    __x ^= __w.second;
    __y += __v.first + __loadword<_Size>(__s + 40);
    __z = __rotate(__z + __w.first, 33) * __k1;
    __v = __weak_hash_len_32_with_seeds(__s, __v.second * __k1, __x + __w.first);
    __w = __weak_hash_len_32_with_seeds(__s + 32, __z + __w.second,
                                        __y + __loadword<_Size>(__s + 16));
    std::swap(__z, __x);
    __s += 64;
    __len -= 64;
  } while (__len != 0);
  return __hash_len_16(
      __hash_len_16(__v.first, __w.first) + __shift_mix(__y) * __k1 + __z,
      __hash_len_16(__v.second, __w.second) + __x);
}

template <class _Tp, size_t = sizeof(_Tp) / sizeof(size_t)>
struct __scalar_hash;

template <class _Tp>
struct __scalar_hash<_Tp, 0>
    : public unary_function<_Tp, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(_Tp __v) const _NOEXCEPT
    {
        union
        {
            _Tp    __t;
            size_t __a;
        } __u;
        __u.__a = 0;
        __u.__t = __v;
        return __u.__a;
    }
};

template <class _Tp>
struct __scalar_hash<_Tp, 1>
    : public unary_function<_Tp, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(_Tp __v) const _NOEXCEPT
    {
        union
        {
            _Tp    __t;
            size_t __a;
        } __u;
        __u.__t = __v;
        return __u.__a;
    }
};

template <class _Tp>
struct __scalar_hash<_Tp, 2>
    : public unary_function<_Tp, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(_Tp __v) const _NOEXCEPT
    {
        union
        {
            _Tp __t;
            struct
            {
                size_t __a;
                size_t __b;
            };
        } __u;
        __u.__t = __v;
        return __murmur2_or_cityhash<size_t>()(&__u, sizeof(__u));
    }
};

template <class _Tp>
struct __scalar_hash<_Tp, 3>
    : public unary_function<_Tp, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(_Tp __v) const _NOEXCEPT
    {
        union
        {
            _Tp __t;
            struct
            {
                size_t __a;
                size_t __b;
                size_t __c;
            };
        } __u;
        __u.__t = __v;
        return __murmur2_or_cityhash<size_t>()(&__u, sizeof(__u));
    }
};

template <class _Tp>
struct __scalar_hash<_Tp, 4>
    : public unary_function<_Tp, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(_Tp __v) const _NOEXCEPT
    {
        union
        {
            _Tp __t;
            struct
            {
                size_t __a;
                size_t __b;
                size_t __c;
                size_t __d;
            };
        } __u;
        __u.__t = __v;
        return __murmur2_or_cityhash<size_t>()(&__u, sizeof(__u));
    }
};

template<class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY hash<_Tp*>
    : public unary_function<_Tp*, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(_Tp* __v) const _NOEXCEPT
    {
        union
        {
            _Tp* __t;
            size_t __a;
        } __u;
        __u.__t = __v;
        return __murmur2_or_cityhash<size_t>()(&__u, sizeof(__u));
    }
};

template <class _Tp, class _Dp>
struct _LIBCPP_TYPE_VIS_ONLY hash<unique_ptr<_Tp, _Dp> >
{
    typedef unique_ptr<_Tp, _Dp> argument_type;
    typedef size_t               result_type;
    _LIBCPP_INLINE_VISIBILITY
    result_type operator()(const argument_type& __ptr) const _NOEXCEPT
    {
        typedef typename argument_type::pointer pointer;
        return hash<pointer>()(__ptr.get());
    }
};

struct __destruct_n
{
private:
    size_t size;

    template <class _Tp>
    _LIBCPP_INLINE_VISIBILITY void __process(_Tp* __p, false_type) _NOEXCEPT
        {for (size_t __i = 0; __i < size; ++__i, ++__p) __p->~_Tp();}

    template <class _Tp>
    _LIBCPP_INLINE_VISIBILITY void __process(_Tp*, true_type) _NOEXCEPT
        {}

    _LIBCPP_INLINE_VISIBILITY void __incr(false_type) _NOEXCEPT
        {++size;}
    _LIBCPP_INLINE_VISIBILITY void __incr(true_type) _NOEXCEPT
        {}

    _LIBCPP_INLINE_VISIBILITY void __set(size_t __s, false_type) _NOEXCEPT
        {size = __s;}
    _LIBCPP_INLINE_VISIBILITY void __set(size_t, true_type) _NOEXCEPT
        {}
public:
    _LIBCPP_INLINE_VISIBILITY explicit __destruct_n(size_t __s) _NOEXCEPT
        : size(__s) {}

    template <class _Tp>
    _LIBCPP_INLINE_VISIBILITY void __incr(_Tp*) _NOEXCEPT
        {__incr(integral_constant<bool, is_trivially_destructible<_Tp>::value>());}

    template <class _Tp>
    _LIBCPP_INLINE_VISIBILITY void __set(size_t __s, _Tp*) _NOEXCEPT
        {__set(__s, integral_constant<bool, is_trivially_destructible<_Tp>::value>());}

    template <class _Tp>
    _LIBCPP_INLINE_VISIBILITY void operator()(_Tp* __p) _NOEXCEPT
        {__process(__p, integral_constant<bool, is_trivially_destructible<_Tp>::value>());}
};

template <class _Alloc>
class __allocator_destructor
{
    typedef allocator_traits<_Alloc> __alloc_traits;
public:
    typedef typename __alloc_traits::pointer pointer;
    typedef typename __alloc_traits::size_type size_type;
private:
    _Alloc& __alloc_;
    size_type __s_;
public:
    _LIBCPP_INLINE_VISIBILITY __allocator_destructor(_Alloc& __a, size_type __s)
             _NOEXCEPT
        : __alloc_(__a), __s_(__s) {}
    _LIBCPP_INLINE_VISIBILITY
    void operator()(pointer __p) _NOEXCEPT
        {__alloc_traits::deallocate(__alloc_, __p, __s_);}
};

template <class _InputIterator, class _ForwardIterator>
_ForwardIterator
uninitialized_copy(_InputIterator __f, _InputIterator __l, _ForwardIterator __r)
{
    typedef typename iterator_traits<_ForwardIterator>::value_type value_type;
#ifndef _LIBCPP_NO_EXCEPTIONS
    _ForwardIterator __s = __r;
    try
    {
#endif
# 3485 "/usr/include/c++/v1/memory" 3
        for (; __f != __l; ++__f, ++__r)
            ::new(&*__r) value_type(*__f);
#ifndef _LIBCPP_NO_EXCEPTIONS
    }
    catch (...)
    {
        for (; __s != __r; ++__s)
            __s->~value_type();
        throw;
    }
#endif
# 3496 "/usr/include/c++/v1/memory" 3
    return __r;
}

template <class _InputIterator, class _Size, class _ForwardIterator>
_ForwardIterator
uninitialized_copy_n(_InputIterator __f, _Size __n, _ForwardIterator __r)
{
    typedef typename iterator_traits<_ForwardIterator>::value_type value_type;
#ifndef _LIBCPP_NO_EXCEPTIONS
    _ForwardIterator __s = __r;
    try
    {
#endif
# 3509 "/usr/include/c++/v1/memory" 3
        for (; __n > 0; ++__f, ++__r, --__n)
            ::new(&*__r) value_type(*__f);
#ifndef _LIBCPP_NO_EXCEPTIONS
    }
    catch (...)
    {
        for (; __s != __r; ++__s)
            __s->~value_type();
        throw;
    }
#endif
# 3520 "/usr/include/c++/v1/memory" 3
    return __r;
}

template <class _ForwardIterator, class _Tp>
void
uninitialized_fill(_ForwardIterator __f, _ForwardIterator __l, const _Tp& __x)
{
    typedef typename iterator_traits<_ForwardIterator>::value_type value_type;
#ifndef _LIBCPP_NO_EXCEPTIONS
    _ForwardIterator __s = __f;
    try
    {
#endif
# 3533 "/usr/include/c++/v1/memory" 3
        for (; __f != __l; ++__f)
            ::new(&*__f) value_type(__x);
#ifndef _LIBCPP_NO_EXCEPTIONS
    }
    catch (...)
    {
        for (; __s != __f; ++__s)
            __s->~value_type();
        throw;
    }
#endif
# 3544 "/usr/include/c++/v1/memory" 3
}

template <class _ForwardIterator, class _Size, class _Tp>
_ForwardIterator
uninitialized_fill_n(_ForwardIterator __f, _Size __n, const _Tp& __x)
{
    typedef typename iterator_traits<_ForwardIterator>::value_type value_type;
#ifndef _LIBCPP_NO_EXCEPTIONS
    _ForwardIterator __s = __f;
    try
    {
#endif
# 3556 "/usr/include/c++/v1/memory" 3
        for (; __n > 0; ++__f, --__n)
            ::new(&*__f) value_type(__x);
#ifndef _LIBCPP_NO_EXCEPTIONS
    }
    catch (...)
    {
        for (; __s != __f; ++__s)
            __s->~value_type();
        throw;
    }
#endif
# 3567 "/usr/include/c++/v1/memory" 3
    return __f;
}

class _LIBCPP_EXCEPTION_ABI bad_weak_ptr
    : public std::exception
{
public:
    virtual ~bad_weak_ptr() _NOEXCEPT;
    virtual const char* what() const  _NOEXCEPT;
};

template<class _Tp> class _LIBCPP_TYPE_VIS_ONLY weak_ptr;

class _LIBCPP_TYPE_VIS __shared_count
{
    __shared_count(const __shared_count&);
    __shared_count& operator=(const __shared_count&);

protected:
    long __shared_owners_;
    virtual ~__shared_count();
private:
    virtual void __on_zero_shared() _NOEXCEPT = 0;

public:
    _LIBCPP_INLINE_VISIBILITY
    explicit __shared_count(long __refs = 0) _NOEXCEPT
        : __shared_owners_(__refs) {}

    void __add_shared() _NOEXCEPT;
    bool __release_shared() _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    long use_count() const _NOEXCEPT {return __shared_owners_ + 1;}
};

class _LIBCPP_TYPE_VIS __shared_weak_count
    : private __shared_count
{
    long __shared_weak_owners_;

public:
    _LIBCPP_INLINE_VISIBILITY
    explicit __shared_weak_count(long __refs = 0) _NOEXCEPT
        : __shared_count(__refs),
          __shared_weak_owners_(__refs) {}
protected:
    virtual ~__shared_weak_count();

public:
    void __add_shared() _NOEXCEPT;
    void __add_weak() _NOEXCEPT;
    void __release_shared() _NOEXCEPT;
    void __release_weak() _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    long use_count() const _NOEXCEPT {return __shared_count::use_count();}
    __shared_weak_count* lock() _NOEXCEPT;

    // Define the function out only if we build static libc++ without RTTI.
    // Otherwise we may break clients who need to compile their projects with
    // -fno-rtti and yet link against a libc++.dylib compiled
    // without -fno-rtti.
#if !defined(_LIBCPP_NO_RTTI) || !defined(_LIBCPP_BUILD_STATIC)
    virtual const void* __get_deleter(const type_info&) const _NOEXCEPT;
#endif
# 3631 "/usr/include/c++/v1/memory" 3
private:
    virtual void __on_zero_shared_weak() _NOEXCEPT = 0;
};

template <class _Tp, class _Dp, class _Alloc>
class __shared_ptr_pointer
    : public __shared_weak_count
{
    __compressed_pair<__compressed_pair<_Tp, _Dp>, _Alloc> __data_;
public:
    _LIBCPP_INLINE_VISIBILITY
    __shared_ptr_pointer(_Tp __p, _Dp __d, _Alloc __a)
        :  __data_(__compressed_pair<_Tp, _Dp>(__p, _VSTD::move(__d)), _VSTD::move(__a)) {}

#ifndef _LIBCPP_NO_RTTI
    virtual const void* __get_deleter(const type_info&) const _NOEXCEPT;
#endif
# 3648 "/usr/include/c++/v1/memory" 3

private:
    virtual void __on_zero_shared() _NOEXCEPT;
    virtual void __on_zero_shared_weak() _NOEXCEPT;
};

#ifndef _LIBCPP_NO_RTTI

template <class _Tp, class _Dp, class _Alloc>
const void*
__shared_ptr_pointer<_Tp, _Dp, _Alloc>::__get_deleter(const type_info& __t) const _NOEXCEPT
{
    return __t == typeid(_Dp) ? &__data_.first().second() : 0;
}

#endif  // _LIBCPP_NO_RTTI
# 3664 "/usr/include/c++/v1/memory" 3

template <class _Tp, class _Dp, class _Alloc>
void
__shared_ptr_pointer<_Tp, _Dp, _Alloc>::__on_zero_shared() _NOEXCEPT
{
    __data_.first().second()(__data_.first().first());
    __data_.first().second().~_Dp();
}

template <class _Tp, class _Dp, class _Alloc>
void
__shared_ptr_pointer<_Tp, _Dp, _Alloc>::__on_zero_shared_weak() _NOEXCEPT
{
    typename _Alloc::template rebind<__shared_ptr_pointer>::other __a(__data_.second());
    __data_.second().~_Alloc();
    __a.deallocate(this, 1);
}

template <class _Tp, class _Alloc>
class __shared_ptr_emplace
    : public __shared_weak_count
{
    __compressed_pair<_Alloc, _Tp> __data_;
public:
#ifndef _LIBCPP_HAS_NO_VARIADICS

    _LIBCPP_INLINE_VISIBILITY
    __shared_ptr_emplace(_Alloc __a)
        :  __data_(_VSTD::move(__a)) {}

    template <class ..._Args>
        _LIBCPP_INLINE_VISIBILITY
        __shared_ptr_emplace(_Alloc __a, _Args&& ...__args)
            :  __data_(piecewise_construct, _VSTD::forward_as_tuple(__a),
                   _VSTD::forward_as_tuple(_VSTD::forward<_Args>(__args)...)) {}

#else  // _LIBCPP_HAS_NO_VARIADICS
# 3701 "/usr/include/c++/v1/memory" 3

    _LIBCPP_INLINE_VISIBILITY
    __shared_ptr_emplace(_Alloc __a)
        :  __data_(__a) {}

    template <class _A0>
        _LIBCPP_INLINE_VISIBILITY
        __shared_ptr_emplace(_Alloc __a, _A0& __a0)
            :  __data_(__a, _Tp(__a0)) {}

    template <class _A0, class _A1>
        _LIBCPP_INLINE_VISIBILITY
        __shared_ptr_emplace(_Alloc __a, _A0& __a0, _A1& __a1)
            :  __data_(__a, _Tp(__a0, __a1)) {}

    template <class _A0, class _A1, class _A2>
        _LIBCPP_INLINE_VISIBILITY
        __shared_ptr_emplace(_Alloc __a, _A0& __a0, _A1& __a1, _A2& __a2)
            :  __data_(__a, _Tp(__a0, __a1, __a2)) {}

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 3722 "/usr/include/c++/v1/memory" 3

private:
    virtual void __on_zero_shared() _NOEXCEPT;
    virtual void __on_zero_shared_weak() _NOEXCEPT;
public:
    _LIBCPP_INLINE_VISIBILITY
    _Tp* get() _NOEXCEPT {return &__data_.second();}
};

template <class _Tp, class _Alloc>
void
__shared_ptr_emplace<_Tp, _Alloc>::__on_zero_shared() _NOEXCEPT
{
    __data_.second().~_Tp();
}

template <class _Tp, class _Alloc>
void
__shared_ptr_emplace<_Tp, _Alloc>::__on_zero_shared_weak() _NOEXCEPT
{
    typename _Alloc::template rebind<__shared_ptr_emplace>::other __a(__data_.first());
    __data_.first().~_Alloc();
    __a.deallocate(this, 1);
}

template<class _Tp> class _LIBCPP_TYPE_VIS_ONLY enable_shared_from_this;

template<class _Tp>
class _LIBCPP_TYPE_VIS_ONLY shared_ptr
{
public:
    typedef _Tp element_type;
private:
    element_type*      __ptr_;
    __shared_weak_count* __cntrl_;

    struct __nat {int __for_bool_;};
public:
    _LIBCPP_CONSTEXPR shared_ptr() _NOEXCEPT;
    _LIBCPP_CONSTEXPR shared_ptr(nullptr_t) _NOEXCEPT;
    template<class _Yp,
             class = typename enable_if
                     <
                        is_convertible<_Yp*, element_type*>::value
                     >::type
            >
        explicit shared_ptr(_Yp* __p);
    template<class _Yp, class _Dp,
             class = typename enable_if
                     <
                        is_convertible<_Yp*, element_type*>::value
                     >::type
            >
        shared_ptr(_Yp* __p, _Dp __d);
    template<class _Yp, class _Dp, class _Alloc,
             class = typename enable_if
                     <
                        is_convertible<_Yp*, element_type*>::value
                     >::type
            >
        shared_ptr(_Yp* __p, _Dp __d, _Alloc __a);
    template <class _Dp> shared_ptr(nullptr_t __p, _Dp __d);
    template <class _Dp, class _Alloc> shared_ptr(nullptr_t __p, _Dp __d, _Alloc __a);
    template<class _Yp> shared_ptr(const shared_ptr<_Yp>& __r, element_type* __p) _NOEXCEPT;
    shared_ptr(const shared_ptr& __r) _NOEXCEPT;
    template<class _Yp>
        shared_ptr(const shared_ptr<_Yp>& __r,
                   typename enable_if<is_convertible<_Yp*, _Tp*>::value, __nat>::type = __nat())
                       _NOEXCEPT;
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    shared_ptr(shared_ptr&& __r) _NOEXCEPT;
    template<class _Yp> shared_ptr(shared_ptr<_Yp>&& __r,
                   typename enable_if<is_convertible<_Yp*, _Tp*>::value, __nat>::type = __nat())
                       _NOEXCEPT;
#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 3797 "/usr/include/c++/v1/memory" 3
    template<class _Yp> explicit shared_ptr(const weak_ptr<_Yp>& __r,
                   typename enable_if<is_convertible<_Yp*, _Tp*>::value, __nat>::type= __nat());
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    template<class _Yp,
             class = typename enable_if
                     <
                        is_convertible<_Yp*, element_type*>::value
                     >::type
            >
        shared_ptr(auto_ptr<_Yp>&& __r);
#else
# 3808 "/usr/include/c++/v1/memory" 3
    template<class _Yp,
             class = typename enable_if
                     <
                        is_convertible<_Yp*, element_type*>::value
                     >::type
            >
        shared_ptr(auto_ptr<_Yp> __r);
#endif
# 3816 "/usr/include/c++/v1/memory" 3
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    template <class _Yp, class _Dp,
                 class = typename enable_if
                 <
                    !is_array<_Yp>::value &&
                    is_convertible<typename unique_ptr<_Yp, _Dp>::pointer, element_type*>::value
                 >::type
             >
       shared_ptr(unique_ptr<_Yp, _Dp>&&,
       typename enable_if<!is_lvalue_reference<_Dp>::value, __nat>::type = __nat());
    template <class _Yp, class _Dp,
                 class = typename enable_if
                 <
                    !is_array<_Yp>::value &&
                    is_convertible<typename unique_ptr<_Yp, _Dp>::pointer, element_type*>::value
                 >::type
             >
       shared_ptr(unique_ptr<_Yp, _Dp>&&,
       typename enable_if<is_lvalue_reference<_Dp>::value, __nat>::type = __nat());
#else  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 3836 "/usr/include/c++/v1/memory" 3
    template <class _Yp, class _Dp,
                 class = typename enable_if
                 <
                    !is_array<_Yp>::value &&
                    is_convertible<typename unique_ptr<_Yp, _Dp>::pointer, element_type*>::value
                 >::type
             > shared_ptr(unique_ptr<_Yp, _Dp>,
       typename enable_if<!is_lvalue_reference<_Dp>::value, __nat>::type = __nat());
    template <class _Yp, class _Dp,
                 class = typename enable_if
                 <
                    !is_array<_Yp>::value &&
                    is_convertible<typename unique_ptr<_Yp, _Dp>::pointer, element_type*>::value
                 >::type
             >
       shared_ptr(unique_ptr<_Yp, _Dp>,
       typename enable_if<is_lvalue_reference<_Dp>::value, __nat>::type = __nat());
#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 3854 "/usr/include/c++/v1/memory" 3

    ~shared_ptr();

    shared_ptr& operator=(const shared_ptr& __r) _NOEXCEPT;
    template<class _Yp>
        typename enable_if
        <
            is_convertible<_Yp*, element_type*>::value,
            shared_ptr&
        >::type
        operator=(const shared_ptr<_Yp>& __r) _NOEXCEPT;
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    shared_ptr& operator=(shared_ptr&& __r) _NOEXCEPT;
    template<class _Yp>
        typename enable_if
        <
            is_convertible<_Yp*, element_type*>::value,
            shared_ptr<_Tp>&
        >::type
        operator=(shared_ptr<_Yp>&& __r);
    template<class _Yp>
        typename enable_if
        <
            !is_array<_Yp>::value &&
            is_convertible<_Yp*, element_type*>::value,
            shared_ptr
        >::type&
        operator=(auto_ptr<_Yp>&& __r);
#else  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 3883 "/usr/include/c++/v1/memory" 3
    template<class _Yp>
        typename enable_if
        <
            !is_array<_Yp>::value &&
            is_convertible<_Yp*, element_type*>::value,
            shared_ptr&
        >::type
        operator=(auto_ptr<_Yp> __r);
#endif
# 3892 "/usr/include/c++/v1/memory" 3
    template <class _Yp, class _Dp>
        typename enable_if
        <
            !is_array<_Yp>::value &&
            is_convertible<typename unique_ptr<_Yp, _Dp>::pointer, element_type*>::value,
            shared_ptr&
        >::type
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
        operator=(unique_ptr<_Yp, _Dp>&& __r);
#else  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 3902 "/usr/include/c++/v1/memory" 3
        operator=(unique_ptr<_Yp, _Dp> __r);
#endif
# 3904 "/usr/include/c++/v1/memory" 3

    void swap(shared_ptr& __r) _NOEXCEPT;
    void reset() _NOEXCEPT;
    template<class _Yp>
        typename enable_if
        <
            is_convertible<_Yp*, element_type*>::value,
            void
        >::type
        reset(_Yp* __p);
    template<class _Yp, class _Dp>
        typename enable_if
        <
            is_convertible<_Yp*, element_type*>::value,
            void
        >::type
        reset(_Yp* __p, _Dp __d);
    template<class _Yp, class _Dp, class _Alloc>
        typename enable_if
        <
            is_convertible<_Yp*, element_type*>::value,
            void
        >::type
        reset(_Yp* __p, _Dp __d, _Alloc __a);

    _LIBCPP_INLINE_VISIBILITY
    element_type* get() const _NOEXCEPT {return __ptr_;}
    _LIBCPP_INLINE_VISIBILITY
    typename add_lvalue_reference<element_type>::type operator*() const _NOEXCEPT
        {return *__ptr_;}
    _LIBCPP_INLINE_VISIBILITY
    element_type* operator->() const _NOEXCEPT {return __ptr_;}
    _LIBCPP_INLINE_VISIBILITY
    long use_count() const _NOEXCEPT {return __cntrl_ ? __cntrl_->use_count() : 0;}
    _LIBCPP_INLINE_VISIBILITY
    bool unique() const _NOEXCEPT {return use_count() == 1;}
    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_EXPLICIT operator bool() const _NOEXCEPT {return get() != 0;}
    template <class _Up>
        _LIBCPP_INLINE_VISIBILITY
        bool owner_before(shared_ptr<_Up> const& __p) const
        {return __cntrl_ < __p.__cntrl_;}
    template <class _Up>
        _LIBCPP_INLINE_VISIBILITY
        bool owner_before(weak_ptr<_Up> const& __p) const
        {return __cntrl_ < __p.__cntrl_;}
    _LIBCPP_INLINE_VISIBILITY
    bool
    __owner_equivalent(const shared_ptr& __p) const
        {return __cntrl_ == __p.__cntrl_;}

#ifndef _LIBCPP_NO_RTTI
    template <class _Dp>
        _LIBCPP_INLINE_VISIBILITY
        _Dp* __get_deleter() const _NOEXCEPT
            {return (_Dp*)(__cntrl_ ? __cntrl_->__get_deleter(typeid(_Dp)) : 0);}
#endif  // _LIBCPP_NO_RTTI
# 3961 "/usr/include/c++/v1/memory" 3

#ifndef _LIBCPP_HAS_NO_VARIADICS

    template<class ..._Args>
        static
        shared_ptr<_Tp>
        make_shared(_Args&& ...__args);

    template<class _Alloc, class ..._Args>
        static
        shared_ptr<_Tp>
        allocate_shared(const _Alloc& __a, _Args&& ...__args);

#else  // _LIBCPP_HAS_NO_VARIADICS
# 3975 "/usr/include/c++/v1/memory" 3

    static shared_ptr<_Tp> make_shared();

    template<class _A0>
        static shared_ptr<_Tp> make_shared(_A0&);

    template<class _A0, class _A1>
        static shared_ptr<_Tp> make_shared(_A0&, _A1&);

    template<class _A0, class _A1, class _A2>
        static shared_ptr<_Tp> make_shared(_A0&, _A1&, _A2&);

    template<class _Alloc>
        static shared_ptr<_Tp>
        allocate_shared(const _Alloc& __a);

    template<class _Alloc, class _A0>
        static shared_ptr<_Tp>
        allocate_shared(const _Alloc& __a, _A0& __a0);

    template<class _Alloc, class _A0, class _A1>
        static shared_ptr<_Tp>
        allocate_shared(const _Alloc& __a, _A0& __a0, _A1& __a1);

    template<class _Alloc, class _A0, class _A1, class _A2>
        static shared_ptr<_Tp>
        allocate_shared(const _Alloc& __a, _A0& __a0, _A1& __a1, _A2& __a2);

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 4004 "/usr/include/c++/v1/memory" 3

private:

    template <class _Yp>
        _LIBCPP_INLINE_VISIBILITY
        void
        __enable_weak_this(const enable_shared_from_this<_Yp>* __e) _NOEXCEPT
        {
            if (__e)
                __e->__weak_this_ = *this;
        }

    _LIBCPP_INLINE_VISIBILITY
    void __enable_weak_this(const void*) _NOEXCEPT {}

    template <class _Up> friend class _LIBCPP_TYPE_VIS_ONLY shared_ptr;
    template <class _Up> friend class _LIBCPP_TYPE_VIS_ONLY weak_ptr;
};

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
shared_ptr<_Tp>::shared_ptr() _NOEXCEPT
    : __ptr_(0),
      __cntrl_(0)
{
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
shared_ptr<_Tp>::shared_ptr(nullptr_t) _NOEXCEPT
    : __ptr_(0),
      __cntrl_(0)
{
}

template<class _Tp>
template<class _Yp, class>
shared_ptr<_Tp>::shared_ptr(_Yp* __p)
    : __ptr_(__p)
{
    unique_ptr<_Yp> __hold(__p);
    typedef __shared_ptr_pointer<_Yp*, default_delete<_Yp>, allocator<_Yp> > _CntrlBlk;
    __cntrl_ = new _CntrlBlk(__p, default_delete<_Yp>(), allocator<_Yp>());
    __hold.release();
    __enable_weak_this(__p);
}

template<class _Tp>
template<class _Yp, class _Dp, class>
shared_ptr<_Tp>::shared_ptr(_Yp* __p, _Dp __d)
    : __ptr_(__p)
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    try
    {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 4062 "/usr/include/c++/v1/memory" 3
        typedef __shared_ptr_pointer<_Yp*, _Dp, allocator<_Yp> > _CntrlBlk;
        __cntrl_ = new _CntrlBlk(__p, __d, allocator<_Yp>());
        __enable_weak_this(__p);
#ifndef _LIBCPP_NO_EXCEPTIONS
    }
    catch (...)
    {
        __d(__p);
        throw;
    }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 4073 "/usr/include/c++/v1/memory" 3
}

template<class _Tp>
template<class _Dp>
shared_ptr<_Tp>::shared_ptr(nullptr_t __p, _Dp __d)
    : __ptr_(0)
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    try
    {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 4084 "/usr/include/c++/v1/memory" 3
        typedef __shared_ptr_pointer<nullptr_t, _Dp, allocator<_Tp> > _CntrlBlk;
        __cntrl_ = new _CntrlBlk(__p, __d, allocator<_Tp>());
#ifndef _LIBCPP_NO_EXCEPTIONS
    }
    catch (...)
    {
        __d(__p);
        throw;
    }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 4094 "/usr/include/c++/v1/memory" 3
}

template<class _Tp>
template<class _Yp, class _Dp, class _Alloc, class>
shared_ptr<_Tp>::shared_ptr(_Yp* __p, _Dp __d, _Alloc __a)
    : __ptr_(__p)
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    try
    {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 4105 "/usr/include/c++/v1/memory" 3
        typedef __shared_ptr_pointer<_Yp*, _Dp, _Alloc> _CntrlBlk;
        typedef typename _Alloc::template rebind<_CntrlBlk>::other _A2;
        typedef __allocator_destructor<_A2> _D2;
        _A2 __a2(__a);
        unique_ptr<_CntrlBlk, _D2> __hold2(__a2.allocate(1), _D2(__a2, 1));
        ::new(__hold2.get()) _CntrlBlk(__p, __d, __a);
        __cntrl_ = __hold2.release();
        __enable_weak_this(__p);
#ifndef _LIBCPP_NO_EXCEPTIONS
    }
    catch (...)
    {
        __d(__p);
        throw;
    }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 4121 "/usr/include/c++/v1/memory" 3
}

template<class _Tp>
template<class _Dp, class _Alloc>
shared_ptr<_Tp>::shared_ptr(nullptr_t __p, _Dp __d, _Alloc __a)
    : __ptr_(0)
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    try
    {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 4132 "/usr/include/c++/v1/memory" 3
        typedef __shared_ptr_pointer<nullptr_t, _Dp, _Alloc> _CntrlBlk;
        typedef typename _Alloc::template rebind<_CntrlBlk>::other _A2;
        typedef __allocator_destructor<_A2> _D2;
        _A2 __a2(__a);
        unique_ptr<_CntrlBlk, _D2> __hold2(__a2.allocate(1), _D2(__a2, 1));
        ::new(__hold2.get()) _CntrlBlk(__p, __d, __a);
        __cntrl_ = __hold2.release();
#ifndef _LIBCPP_NO_EXCEPTIONS
    }
    catch (...)
    {
        __d(__p);
        throw;
    }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 4147 "/usr/include/c++/v1/memory" 3
}

template<class _Tp>
template<class _Yp>
inline _LIBCPP_INLINE_VISIBILITY
shared_ptr<_Tp>::shared_ptr(const shared_ptr<_Yp>& __r, element_type *__p) _NOEXCEPT
    : __ptr_(__p),
      __cntrl_(__r.__cntrl_)
{
    if (__cntrl_)
        __cntrl_->__add_shared();
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
shared_ptr<_Tp>::shared_ptr(const shared_ptr& __r) _NOEXCEPT
    : __ptr_(__r.__ptr_),
      __cntrl_(__r.__cntrl_)
{
    if (__cntrl_)
        __cntrl_->__add_shared();
}

template<class _Tp>
template<class _Yp>
inline _LIBCPP_INLINE_VISIBILITY
shared_ptr<_Tp>::shared_ptr(const shared_ptr<_Yp>& __r,
                            typename enable_if<is_convertible<_Yp*, _Tp*>::value, __nat>::type)
         _NOEXCEPT
    : __ptr_(__r.__ptr_),
      __cntrl_(__r.__cntrl_)
{
    if (__cntrl_)
        __cntrl_->__add_shared();
}

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
shared_ptr<_Tp>::shared_ptr(shared_ptr&& __r) _NOEXCEPT
    : __ptr_(__r.__ptr_),
      __cntrl_(__r.__cntrl_)
{
    __r.__ptr_ = 0;
    __r.__cntrl_ = 0;
}

template<class _Tp>
template<class _Yp>
inline _LIBCPP_INLINE_VISIBILITY
shared_ptr<_Tp>::shared_ptr(shared_ptr<_Yp>&& __r,
                            typename enable_if<is_convertible<_Yp*, _Tp*>::value, __nat>::type)
         _NOEXCEPT
    : __ptr_(__r.__ptr_),
      __cntrl_(__r.__cntrl_)
{
    __r.__ptr_ = 0;
    __r.__cntrl_ = 0;
}

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 4209 "/usr/include/c++/v1/memory" 3

template<class _Tp>
template<class _Yp, class>
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
shared_ptr<_Tp>::shared_ptr(auto_ptr<_Yp>&& __r)
#else
# 4215 "/usr/include/c++/v1/memory" 3
shared_ptr<_Tp>::shared_ptr(auto_ptr<_Yp> __r)
#endif
# 4217 "/usr/include/c++/v1/memory" 3
    : __ptr_(__r.get())
{
    typedef __shared_ptr_pointer<_Yp*, default_delete<_Yp>, allocator<_Yp> > _CntrlBlk;
    __cntrl_ = new _CntrlBlk(__r.get(), default_delete<_Yp>(), allocator<_Yp>());
    __enable_weak_this(__r.get());
    __r.release();
}

template<class _Tp>
template <class _Yp, class _Dp, class>
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
shared_ptr<_Tp>::shared_ptr(unique_ptr<_Yp, _Dp>&& __r,
#else
# 4230 "/usr/include/c++/v1/memory" 3
shared_ptr<_Tp>::shared_ptr(unique_ptr<_Yp, _Dp> __r,
#endif
# 4232 "/usr/include/c++/v1/memory" 3
           typename enable_if<!is_lvalue_reference<_Dp>::value, __nat>::type)
    : __ptr_(__r.get())
{
    typedef __shared_ptr_pointer<_Yp*, _Dp, allocator<_Yp> > _CntrlBlk;
    __cntrl_ = new _CntrlBlk(__r.get(), __r.get_deleter(), allocator<_Yp>());
    __enable_weak_this(__r.get());
    __r.release();
}

template<class _Tp>
template <class _Yp, class _Dp, class>
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
shared_ptr<_Tp>::shared_ptr(unique_ptr<_Yp, _Dp>&& __r,
#else
# 4246 "/usr/include/c++/v1/memory" 3
shared_ptr<_Tp>::shared_ptr(unique_ptr<_Yp, _Dp> __r,
#endif
# 4248 "/usr/include/c++/v1/memory" 3
           typename enable_if<is_lvalue_reference<_Dp>::value, __nat>::type)
    : __ptr_(__r.get())
{
    typedef __shared_ptr_pointer<_Yp*,
                                 reference_wrapper<typename remove_reference<_Dp>::type>,
                                 allocator<_Yp> > _CntrlBlk;
    __cntrl_ = new _CntrlBlk(__r.get(), ref(__r.get_deleter()), allocator<_Yp>());
    __enable_weak_this(__r.get());
    __r.release();
}

#ifndef _LIBCPP_HAS_NO_VARIADICS

template<class _Tp>
template<class ..._Args>
shared_ptr<_Tp>
shared_ptr<_Tp>::make_shared(_Args&& ...__args)
{
    typedef __shared_ptr_emplace<_Tp, allocator<_Tp> > _CntrlBlk;
    typedef allocator<_CntrlBlk> _A2;
    typedef __allocator_destructor<_A2> _D2;
    _A2 __a2;
    unique_ptr<_CntrlBlk, _D2> __hold2(__a2.allocate(1), _D2(__a2, 1));
    ::new(__hold2.get()) _CntrlBlk(__a2, _VSTD::forward<_Args>(__args)...);
    shared_ptr<_Tp> __r;
    __r.__ptr_ = __hold2.get()->get();
    __r.__cntrl_ = __hold2.release();
    __r.__enable_weak_this(__r.__ptr_);
    return __r;
}

template<class _Tp>
template<class _Alloc, class ..._Args>
shared_ptr<_Tp>
shared_ptr<_Tp>::allocate_shared(const _Alloc& __a, _Args&& ...__args)
{
    typedef __shared_ptr_emplace<_Tp, _Alloc> _CntrlBlk;
    typedef typename _Alloc::template rebind<_CntrlBlk>::other _A2;
    typedef __allocator_destructor<_A2> _D2;
    _A2 __a2(__a);
    unique_ptr<_CntrlBlk, _D2> __hold2(__a2.allocate(1), _D2(__a2, 1));
    ::new(__hold2.get()) _CntrlBlk(__a, _VSTD::forward<_Args>(__args)...);
    shared_ptr<_Tp> __r;
    __r.__ptr_ = __hold2.get()->get();
    __r.__cntrl_ = __hold2.release();
    __r.__enable_weak_this(__r.__ptr_);
    return __r;
}

#else  // _LIBCPP_HAS_NO_VARIADICS
# 4298 "/usr/include/c++/v1/memory" 3

template<class _Tp>
shared_ptr<_Tp>
shared_ptr<_Tp>::make_shared()
{
    typedef __shared_ptr_emplace<_Tp, allocator<_Tp> > _CntrlBlk;
    typedef allocator<_CntrlBlk> _Alloc2;
    typedef __allocator_destructor<_Alloc2> _D2;
    _Alloc2 __alloc2;
    unique_ptr<_CntrlBlk, _D2> __hold2(__alloc2.allocate(1), _D2(__alloc2, 1));
    ::new(__hold2.get()) _CntrlBlk(__alloc2);
    shared_ptr<_Tp> __r;
    __r.__ptr_ = __hold2.get()->get();
    __r.__cntrl_ = __hold2.release();
    __r.__enable_weak_this(__r.__ptr_);
    return __r;
}

template<class _Tp>
template<class _A0>
shared_ptr<_Tp>
shared_ptr<_Tp>::make_shared(_A0& __a0)
{
    typedef __shared_ptr_emplace<_Tp, allocator<_Tp> > _CntrlBlk;
    typedef allocator<_CntrlBlk> _Alloc2;
    typedef __allocator_destructor<_Alloc2> _D2;
    _Alloc2 __alloc2;
    unique_ptr<_CntrlBlk, _D2> __hold2(__alloc2.allocate(1), _D2(__alloc2, 1));
    ::new(__hold2.get()) _CntrlBlk(__alloc2, __a0);
    shared_ptr<_Tp> __r;
    __r.__ptr_ = __hold2.get()->get();
    __r.__cntrl_ = __hold2.release();
    __r.__enable_weak_this(__r.__ptr_);
    return __r;
}

template<class _Tp>
template<class _A0, class _A1>
shared_ptr<_Tp>
shared_ptr<_Tp>::make_shared(_A0& __a0, _A1& __a1)
{
    typedef __shared_ptr_emplace<_Tp, allocator<_Tp> > _CntrlBlk;
    typedef allocator<_CntrlBlk> _Alloc2;
    typedef __allocator_destructor<_Alloc2> _D2;
    _Alloc2 __alloc2;
    unique_ptr<_CntrlBlk, _D2> __hold2(__alloc2.allocate(1), _D2(__alloc2, 1));
    ::new(__hold2.get()) _CntrlBlk(__alloc2, __a0, __a1);
    shared_ptr<_Tp> __r;
    __r.__ptr_ = __hold2.get()->get();
    __r.__cntrl_ = __hold2.release();
    __r.__enable_weak_this(__r.__ptr_);
    return __r;
}

template<class _Tp>
template<class _A0, class _A1, class _A2>
shared_ptr<_Tp>
shared_ptr<_Tp>::make_shared(_A0& __a0, _A1& __a1, _A2& __a2)
{
    typedef __shared_ptr_emplace<_Tp, allocator<_Tp> > _CntrlBlk;
    typedef allocator<_CntrlBlk> _Alloc2;
    typedef __allocator_destructor<_Alloc2> _D2;
    _Alloc2 __alloc2;
    unique_ptr<_CntrlBlk, _D2> __hold2(__alloc2.allocate(1), _D2(__alloc2, 1));
    ::new(__hold2.get()) _CntrlBlk(__alloc2, __a0, __a1, __a2);
    shared_ptr<_Tp> __r;
    __r.__ptr_ = __hold2.get()->get();
    __r.__cntrl_ = __hold2.release();
    __r.__enable_weak_this(__r.__ptr_);
    return __r;
}

template<class _Tp>
template<class _Alloc>
shared_ptr<_Tp>
shared_ptr<_Tp>::allocate_shared(const _Alloc& __a)
{
    typedef __shared_ptr_emplace<_Tp, _Alloc> _CntrlBlk;
    typedef typename _Alloc::template rebind<_CntrlBlk>::other _Alloc2;
    typedef __allocator_destructor<_Alloc2> _D2;
    _Alloc2 __alloc2(__a);
    unique_ptr<_CntrlBlk, _D2> __hold2(__alloc2.allocate(1), _D2(__alloc2, 1));
    ::new(__hold2.get()) _CntrlBlk(__a);
    shared_ptr<_Tp> __r;
    __r.__ptr_ = __hold2.get()->get();
    __r.__cntrl_ = __hold2.release();
    __r.__enable_weak_this(__r.__ptr_);
    return __r;
}

template<class _Tp>
template<class _Alloc, class _A0>
shared_ptr<_Tp>
shared_ptr<_Tp>::allocate_shared(const _Alloc& __a, _A0& __a0)
{
    typedef __shared_ptr_emplace<_Tp, _Alloc> _CntrlBlk;
    typedef typename _Alloc::template rebind<_CntrlBlk>::other _Alloc2;
    typedef __allocator_destructor<_Alloc2> _D2;
    _Alloc2 __alloc2(__a);
    unique_ptr<_CntrlBlk, _D2> __hold2(__alloc2.allocate(1), _D2(__alloc2, 1));
    ::new(__hold2.get()) _CntrlBlk(__a, __a0);
    shared_ptr<_Tp> __r;
    __r.__ptr_ = __hold2.get()->get();
    __r.__cntrl_ = __hold2.release();
    __r.__enable_weak_this(__r.__ptr_);
    return __r;
}

template<class _Tp>
template<class _Alloc, class _A0, class _A1>
shared_ptr<_Tp>
shared_ptr<_Tp>::allocate_shared(const _Alloc& __a, _A0& __a0, _A1& __a1)
{
    typedef __shared_ptr_emplace<_Tp, _Alloc> _CntrlBlk;
    typedef typename _Alloc::template rebind<_CntrlBlk>::other _Alloc2;
    typedef __allocator_destructor<_Alloc2> _D2;
    _Alloc2 __alloc2(__a);
    unique_ptr<_CntrlBlk, _D2> __hold2(__alloc2.allocate(1), _D2(__alloc2, 1));
    ::new(__hold2.get()) _CntrlBlk(__a, __a0, __a1);
    shared_ptr<_Tp> __r;
    __r.__ptr_ = __hold2.get()->get();
    __r.__cntrl_ = __hold2.release();
    __r.__enable_weak_this(__r.__ptr_);
    return __r;
}

template<class _Tp>
template<class _Alloc, class _A0, class _A1, class _A2>
shared_ptr<_Tp>
shared_ptr<_Tp>::allocate_shared(const _Alloc& __a, _A0& __a0, _A1& __a1, _A2& __a2)
{
    typedef __shared_ptr_emplace<_Tp, _Alloc> _CntrlBlk;
    typedef typename _Alloc::template rebind<_CntrlBlk>::other _Alloc2;
    typedef __allocator_destructor<_Alloc2> _D2;
    _Alloc2 __alloc2(__a);
    unique_ptr<_CntrlBlk, _D2> __hold2(__alloc2.allocate(1), _D2(__alloc2, 1));
    ::new(__hold2.get()) _CntrlBlk(__a, __a0, __a1, __a2);
    shared_ptr<_Tp> __r;
    __r.__ptr_ = __hold2.get()->get();
    __r.__cntrl_ = __hold2.release();
    __r.__enable_weak_this(__r.__ptr_);
    return __r;
}

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 4443 "/usr/include/c++/v1/memory" 3

template<class _Tp>
shared_ptr<_Tp>::~shared_ptr()
{
    if (__cntrl_)
        __cntrl_->__release_shared();
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
shared_ptr<_Tp>&
shared_ptr<_Tp>::operator=(const shared_ptr& __r) _NOEXCEPT
{
    shared_ptr(__r).swap(*this);
    return *this;
}

template<class _Tp>
template<class _Yp>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_convertible<_Yp*, _Tp*>::value,
    shared_ptr<_Tp>&
>::type
shared_ptr<_Tp>::operator=(const shared_ptr<_Yp>& __r) _NOEXCEPT
{
    shared_ptr(__r).swap(*this);
    return *this;
}

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
shared_ptr<_Tp>&
shared_ptr<_Tp>::operator=(shared_ptr&& __r) _NOEXCEPT
{
    shared_ptr(_VSTD::move(__r)).swap(*this);
    return *this;
}

template<class _Tp>
template<class _Yp>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_convertible<_Yp*, _Tp*>::value,
    shared_ptr<_Tp>&
>::type
shared_ptr<_Tp>::operator=(shared_ptr<_Yp>&& __r)
{
    shared_ptr(_VSTD::move(__r)).swap(*this);
    return *this;
}

template<class _Tp>
template<class _Yp>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_array<_Yp>::value &&
    is_convertible<_Yp*, _Tp*>::value,
    shared_ptr<_Tp>
>::type&
shared_ptr<_Tp>::operator=(auto_ptr<_Yp>&& __r)
{
    shared_ptr(_VSTD::move(__r)).swap(*this);
    return *this;
}

template<class _Tp>
template <class _Yp, class _Dp>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_array<_Yp>::value &&
    is_convertible<typename unique_ptr<_Yp, _Dp>::pointer, _Tp*>::value,
    shared_ptr<_Tp>&
>::type
shared_ptr<_Tp>::operator=(unique_ptr<_Yp, _Dp>&& __r)
{
    shared_ptr(_VSTD::move(__r)).swap(*this);
    return *this;
}

#else  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 4530 "/usr/include/c++/v1/memory" 3

template<class _Tp>
template<class _Yp>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_array<_Yp>::value &&
    is_convertible<_Yp*, _Tp*>::value,
    shared_ptr<_Tp>&
>::type
shared_ptr<_Tp>::operator=(auto_ptr<_Yp> __r)
{
    shared_ptr(__r).swap(*this);
    return *this;
}

template<class _Tp>
template <class _Yp, class _Dp>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_array<_Yp>::value &&
    is_convertible<typename unique_ptr<_Yp, _Dp>::pointer, _Tp*>::value,
    shared_ptr<_Tp>&
>::type
shared_ptr<_Tp>::operator=(unique_ptr<_Yp, _Dp> __r)
{
    shared_ptr(_VSTD::move(__r)).swap(*this);
    return *this;
}

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 4562 "/usr/include/c++/v1/memory" 3

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void
shared_ptr<_Tp>::swap(shared_ptr& __r) _NOEXCEPT
{
    _VSTD::swap(__ptr_, __r.__ptr_);
    _VSTD::swap(__cntrl_, __r.__cntrl_);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void
shared_ptr<_Tp>::reset() _NOEXCEPT
{
    shared_ptr().swap(*this);
}

template<class _Tp>
template<class _Yp>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_convertible<_Yp*, _Tp*>::value,
    void
>::type
shared_ptr<_Tp>::reset(_Yp* __p)
{
    shared_ptr(__p).swap(*this);
}

template<class _Tp>
template<class _Yp, class _Dp>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_convertible<_Yp*, _Tp*>::value,
    void
>::type
shared_ptr<_Tp>::reset(_Yp* __p, _Dp __d)
{
    shared_ptr(__p, __d).swap(*this);
}

template<class _Tp>
template<class _Yp, class _Dp, class _Alloc>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_convertible<_Yp*, _Tp*>::value,
    void
>::type
shared_ptr<_Tp>::reset(_Yp* __p, _Dp __d, _Alloc __a)
{
    shared_ptr(__p, __d, __a).swap(*this);
}

#ifndef _LIBCPP_HAS_NO_VARIADICS

template<class _Tp, class ..._Args>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_array<_Tp>::value,
    shared_ptr<_Tp>
>::type
make_shared(_Args&& ...__args)
{
    return shared_ptr<_Tp>::make_shared(_VSTD::forward<_Args>(__args)...);
}

template<class _Tp, class _Alloc, class ..._Args>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_array<_Tp>::value,
    shared_ptr<_Tp>
>::type
allocate_shared(const _Alloc& __a, _Args&& ...__args)
{
    return shared_ptr<_Tp>::allocate_shared(__a, _VSTD::forward<_Args>(__args)...);
}

#else  // _LIBCPP_HAS_NO_VARIADICS
# 4646 "/usr/include/c++/v1/memory" 3

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
shared_ptr<_Tp>
make_shared()
{
    return shared_ptr<_Tp>::make_shared();
}

template<class _Tp, class _A0>
inline _LIBCPP_INLINE_VISIBILITY
shared_ptr<_Tp>
make_shared(_A0& __a0)
{
    return shared_ptr<_Tp>::make_shared(__a0);
}

template<class _Tp, class _A0, class _A1>
inline _LIBCPP_INLINE_VISIBILITY
shared_ptr<_Tp>
make_shared(_A0& __a0, _A1& __a1)
{
    return shared_ptr<_Tp>::make_shared(__a0, __a1);
}

template<class _Tp, class _A0, class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
shared_ptr<_Tp>
make_shared(_A0& __a0, _A1& __a1, _A2& __a2)
{
    return shared_ptr<_Tp>::make_shared(__a0, __a1, __a2);
}

template<class _Tp, class _Alloc>
inline _LIBCPP_INLINE_VISIBILITY
shared_ptr<_Tp>
allocate_shared(const _Alloc& __a)
{
    return shared_ptr<_Tp>::allocate_shared(__a);
}

template<class _Tp, class _Alloc, class _A0>
inline _LIBCPP_INLINE_VISIBILITY
shared_ptr<_Tp>
allocate_shared(const _Alloc& __a, _A0& __a0)
{
    return shared_ptr<_Tp>::allocate_shared(__a, __a0);
}

template<class _Tp, class _Alloc, class _A0, class _A1>
inline _LIBCPP_INLINE_VISIBILITY
shared_ptr<_Tp>
allocate_shared(const _Alloc& __a, _A0& __a0, _A1& __a1)
{
    return shared_ptr<_Tp>::allocate_shared(__a, __a0, __a1);
}

template<class _Tp, class _Alloc, class _A0, class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
shared_ptr<_Tp>
allocate_shared(const _Alloc& __a, _A0& __a0, _A1& __a1, _A2& __a2)
{
    return shared_ptr<_Tp>::allocate_shared(__a, __a0, __a1, __a2);
}

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 4712 "/usr/include/c++/v1/memory" 3

template<class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const shared_ptr<_Tp>& __x, const shared_ptr<_Up>& __y) _NOEXCEPT
{
    return __x.get() == __y.get();
}

template<class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const shared_ptr<_Tp>& __x, const shared_ptr<_Up>& __y) _NOEXCEPT
{
    return !(__x == __y);
}

template<class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<(const shared_ptr<_Tp>& __x, const shared_ptr<_Up>& __y) _NOEXCEPT
{
    typedef typename common_type<_Tp*, _Up*>::type _V;
    return less<_V>()(__x.get(), __y.get());
}

template<class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>(const shared_ptr<_Tp>& __x, const shared_ptr<_Up>& __y) _NOEXCEPT
{
    return __y < __x;
}

template<class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const shared_ptr<_Tp>& __x, const shared_ptr<_Up>& __y) _NOEXCEPT
{
    return !(__y < __x);
}

template<class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const shared_ptr<_Tp>& __x, const shared_ptr<_Up>& __y) _NOEXCEPT
{
    return !(__x < __y);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const shared_ptr<_Tp>& __x, nullptr_t) _NOEXCEPT
{
    return !__x;
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(nullptr_t, const shared_ptr<_Tp>& __x) _NOEXCEPT
{
    return !__x;
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const shared_ptr<_Tp>& __x, nullptr_t) _NOEXCEPT
{
    return static_cast<bool>(__x);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(nullptr_t, const shared_ptr<_Tp>& __x) _NOEXCEPT
{
    return static_cast<bool>(__x);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<(const shared_ptr<_Tp>& __x, nullptr_t) _NOEXCEPT
{
    return less<_Tp*>()(__x.get(), nullptr);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<(nullptr_t, const shared_ptr<_Tp>& __x) _NOEXCEPT
{
    return less<_Tp*>()(nullptr, __x.get());
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>(const shared_ptr<_Tp>& __x, nullptr_t) _NOEXCEPT
{
    return nullptr < __x;
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>(nullptr_t, const shared_ptr<_Tp>& __x) _NOEXCEPT
{
    return __x < nullptr;
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const shared_ptr<_Tp>& __x, nullptr_t) _NOEXCEPT
{
    return !(nullptr < __x);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(nullptr_t, const shared_ptr<_Tp>& __x) _NOEXCEPT
{
    return !(__x < nullptr);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const shared_ptr<_Tp>& __x, nullptr_t) _NOEXCEPT
{
    return !(__x < nullptr);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(nullptr_t, const shared_ptr<_Tp>& __x) _NOEXCEPT
{
    return !(nullptr < __x);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(shared_ptr<_Tp>& __x, shared_ptr<_Tp>& __y) _NOEXCEPT
{
    __x.swap(__y);
}

template<class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_array<_Tp>::value && !is_array<_Up>::value,
    shared_ptr<_Tp>
>::type
static_pointer_cast(const shared_ptr<_Up>& __r) _NOEXCEPT
{
    return shared_ptr<_Tp>(__r, static_cast<_Tp*>(__r.get()));
}

template<class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_array<_Tp>::value && !is_array<_Up>::value,
    shared_ptr<_Tp>
>::type
dynamic_pointer_cast(const shared_ptr<_Up>& __r) _NOEXCEPT
{
    _Tp* __p = dynamic_cast<_Tp*>(__r.get());
    return __p ? shared_ptr<_Tp>(__r, __p) : shared_ptr<_Tp>();
}

template<class _Tp, class _Up>
typename enable_if
<
    is_array<_Tp>::value == is_array<_Up>::value,
    shared_ptr<_Tp>
>::type
const_pointer_cast(const shared_ptr<_Up>& __r) _NOEXCEPT
{
    typedef typename remove_extent<_Tp>::type _RTp;
    return shared_ptr<_Tp>(__r, const_cast<_RTp*>(__r.get()));
}

#ifndef _LIBCPP_NO_RTTI

template<class _Dp, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_Dp*
get_deleter(const shared_ptr<_Tp>& __p) _NOEXCEPT
{
    return __p.template __get_deleter<_Dp>();
}

#endif  // _LIBCPP_NO_RTTI
# 4914 "/usr/include/c++/v1/memory" 3

template<class _Tp>
class _LIBCPP_TYPE_VIS_ONLY weak_ptr
{
public:
    typedef _Tp element_type;
private:
    element_type*        __ptr_;
    __shared_weak_count* __cntrl_;

public:
    _LIBCPP_CONSTEXPR weak_ptr() _NOEXCEPT;
    template<class _Yp> weak_ptr(shared_ptr<_Yp> const& __r,
                   typename enable_if<is_convertible<_Yp*, _Tp*>::value, __nat*>::type = 0)
                        _NOEXCEPT;
    weak_ptr(weak_ptr const& __r) _NOEXCEPT;
    template<class _Yp> weak_ptr(weak_ptr<_Yp> const& __r,
                   typename enable_if<is_convertible<_Yp*, _Tp*>::value, __nat*>::type = 0)
                         _NOEXCEPT;

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    weak_ptr(weak_ptr&& __r) _NOEXCEPT;
    template<class _Yp> weak_ptr(weak_ptr<_Yp>&& __r,
                   typename enable_if<is_convertible<_Yp*, _Tp*>::value, __nat*>::type = 0)
                         _NOEXCEPT;
#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 4940 "/usr/include/c++/v1/memory" 3
    ~weak_ptr();

    weak_ptr& operator=(weak_ptr const& __r) _NOEXCEPT;
    template<class _Yp>
        typename enable_if
        <
            is_convertible<_Yp*, element_type*>::value,
            weak_ptr&
        >::type
        operator=(weak_ptr<_Yp> const& __r) _NOEXCEPT;

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

    weak_ptr& operator=(weak_ptr&& __r) _NOEXCEPT;
    template<class _Yp>
        typename enable_if
        <
            is_convertible<_Yp*, element_type*>::value,
            weak_ptr&
        >::type
        operator=(weak_ptr<_Yp>&& __r) _NOEXCEPT;

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 4963 "/usr/include/c++/v1/memory" 3

    template<class _Yp>
        typename enable_if
        <
            is_convertible<_Yp*, element_type*>::value,
            weak_ptr&
        >::type
        operator=(shared_ptr<_Yp> const& __r) _NOEXCEPT;

    void swap(weak_ptr& __r) _NOEXCEPT;
    void reset() _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    long use_count() const _NOEXCEPT
        {return __cntrl_ ? __cntrl_->use_count() : 0;}
    _LIBCPP_INLINE_VISIBILITY
    bool expired() const _NOEXCEPT
        {return __cntrl_ == 0 || __cntrl_->use_count() == 0;}
    shared_ptr<_Tp> lock() const _NOEXCEPT;
    template<class _Up>
        _LIBCPP_INLINE_VISIBILITY
        bool owner_before(const shared_ptr<_Up>& __r) const
        {return __cntrl_ < __r.__cntrl_;}
    template<class _Up>
        _LIBCPP_INLINE_VISIBILITY
        bool owner_before(const weak_ptr<_Up>& __r) const
        {return __cntrl_ < __r.__cntrl_;}

    template <class _Up> friend class _LIBCPP_TYPE_VIS_ONLY weak_ptr;
    template <class _Up> friend class _LIBCPP_TYPE_VIS_ONLY shared_ptr;
};

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
weak_ptr<_Tp>::weak_ptr() _NOEXCEPT
    : __ptr_(0),
      __cntrl_(0)
{
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
weak_ptr<_Tp>::weak_ptr(weak_ptr const& __r) _NOEXCEPT
    : __ptr_(__r.__ptr_),
      __cntrl_(__r.__cntrl_)
{
    if (__cntrl_)
        __cntrl_->__add_weak();
}

template<class _Tp>
template<class _Yp>
inline _LIBCPP_INLINE_VISIBILITY
weak_ptr<_Tp>::weak_ptr(shared_ptr<_Yp> const& __r,
                        typename enable_if<is_convertible<_Yp*, _Tp*>::value, __nat*>::type)
                         _NOEXCEPT
    : __ptr_(__r.__ptr_),
      __cntrl_(__r.__cntrl_)
{
    if (__cntrl_)
        __cntrl_->__add_weak();
}

template<class _Tp>
template<class _Yp>
inline _LIBCPP_INLINE_VISIBILITY
weak_ptr<_Tp>::weak_ptr(weak_ptr<_Yp> const& __r,
                        typename enable_if<is_convertible<_Yp*, _Tp*>::value, __nat*>::type)
         _NOEXCEPT
    : __ptr_(__r.__ptr_),
      __cntrl_(__r.__cntrl_)
{
    if (__cntrl_)
        __cntrl_->__add_weak();
}

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
weak_ptr<_Tp>::weak_ptr(weak_ptr&& __r) _NOEXCEPT
    : __ptr_(__r.__ptr_),
      __cntrl_(__r.__cntrl_)
{
    __r.__ptr_ = 0;
    __r.__cntrl_ = 0;
}

template<class _Tp>
template<class _Yp>
inline _LIBCPP_INLINE_VISIBILITY
weak_ptr<_Tp>::weak_ptr(weak_ptr<_Yp>&& __r,
                        typename enable_if<is_convertible<_Yp*, _Tp*>::value, __nat*>::type)
         _NOEXCEPT
    : __ptr_(__r.__ptr_),
      __cntrl_(__r.__cntrl_)
{
    __r.__ptr_ = 0;
    __r.__cntrl_ = 0;
}

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 5066 "/usr/include/c++/v1/memory" 3

template<class _Tp>
weak_ptr<_Tp>::~weak_ptr()
{
    if (__cntrl_)
        __cntrl_->__release_weak();
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
weak_ptr<_Tp>&
weak_ptr<_Tp>::operator=(weak_ptr const& __r) _NOEXCEPT
{
    weak_ptr(__r).swap(*this);
    return *this;
}

template<class _Tp>
template<class _Yp>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_convertible<_Yp*, _Tp*>::value,
    weak_ptr<_Tp>&
>::type
weak_ptr<_Tp>::operator=(weak_ptr<_Yp> const& __r) _NOEXCEPT
{
    weak_ptr(__r).swap(*this);
    return *this;
}

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
weak_ptr<_Tp>&
weak_ptr<_Tp>::operator=(weak_ptr&& __r) _NOEXCEPT
{
    weak_ptr(_VSTD::move(__r)).swap(*this);
    return *this;
}

template<class _Tp>
template<class _Yp>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_convertible<_Yp*, _Tp*>::value,
    weak_ptr<_Tp>&
>::type
weak_ptr<_Tp>::operator=(weak_ptr<_Yp>&& __r) _NOEXCEPT
{
    weak_ptr(_VSTD::move(__r)).swap(*this);
    return *this;
}

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 5123 "/usr/include/c++/v1/memory" 3

template<class _Tp>
template<class _Yp>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_convertible<_Yp*, _Tp*>::value,
    weak_ptr<_Tp>&
>::type
weak_ptr<_Tp>::operator=(shared_ptr<_Yp> const& __r) _NOEXCEPT
{
    weak_ptr(__r).swap(*this);
    return *this;
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void
weak_ptr<_Tp>::swap(weak_ptr& __r) _NOEXCEPT
{
    _VSTD::swap(__ptr_, __r.__ptr_);
    _VSTD::swap(__cntrl_, __r.__cntrl_);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(weak_ptr<_Tp>& __x, weak_ptr<_Tp>& __y) _NOEXCEPT
{
    __x.swap(__y);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void
weak_ptr<_Tp>::reset() _NOEXCEPT
{
    weak_ptr().swap(*this);
}

template<class _Tp>
template<class _Yp>
shared_ptr<_Tp>::shared_ptr(const weak_ptr<_Yp>& __r,
                            typename enable_if<is_convertible<_Yp*, _Tp*>::value, __nat>::type)
    : __ptr_(__r.__ptr_),
      __cntrl_(__r.__cntrl_ ? __r.__cntrl_->lock() : __r.__cntrl_)
{
    if (__cntrl_ == 0)
#ifndef _LIBCPP_NO_EXCEPTIONS
        throw bad_weak_ptr();
#else
# 5174 "/usr/include/c++/v1/memory" 3
        assert(!"bad_weak_ptr");
#endif
# 5176 "/usr/include/c++/v1/memory" 3
}

template<class _Tp>
shared_ptr<_Tp>
weak_ptr<_Tp>::lock() const _NOEXCEPT
{
    shared_ptr<_Tp> __r;
    __r.__cntrl_ = __cntrl_ ? __cntrl_->lock() : __cntrl_;
    if (__r.__cntrl_)
        __r.__ptr_ = __ptr_;
    return __r;
}

template <class _Tp> struct owner_less;

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY owner_less<shared_ptr<_Tp> >
    : binary_function<shared_ptr<_Tp>, shared_ptr<_Tp>, bool>
{
    typedef bool result_type;
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(shared_ptr<_Tp> const& __x, shared_ptr<_Tp> const& __y) const
        {return __x.owner_before(__y);}
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(shared_ptr<_Tp> const& __x,   weak_ptr<_Tp> const& __y) const
        {return __x.owner_before(__y);}
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(  weak_ptr<_Tp> const& __x, shared_ptr<_Tp> const& __y) const
        {return __x.owner_before(__y);}
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY owner_less<weak_ptr<_Tp> >
    : binary_function<weak_ptr<_Tp>, weak_ptr<_Tp>, bool>
{
    typedef bool result_type;
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(  weak_ptr<_Tp> const& __x,   weak_ptr<_Tp> const& __y) const
        {return __x.owner_before(__y);}
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(shared_ptr<_Tp> const& __x,   weak_ptr<_Tp> const& __y) const
        {return __x.owner_before(__y);}
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(  weak_ptr<_Tp> const& __x, shared_ptr<_Tp> const& __y) const
        {return __x.owner_before(__y);}
};

template<class _Tp>
class _LIBCPP_TYPE_VIS_ONLY enable_shared_from_this
{
    mutable weak_ptr<_Tp> __weak_this_;
protected:
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    enable_shared_from_this() _NOEXCEPT {}
    _LIBCPP_INLINE_VISIBILITY
    enable_shared_from_this(enable_shared_from_this const&) _NOEXCEPT {}
    _LIBCPP_INLINE_VISIBILITY
    enable_shared_from_this& operator=(enable_shared_from_this const&) _NOEXCEPT
        {return *this;}
    _LIBCPP_INLINE_VISIBILITY
    ~enable_shared_from_this() {}
public:
    _LIBCPP_INLINE_VISIBILITY
    shared_ptr<_Tp> shared_from_this()
        {return shared_ptr<_Tp>(__weak_this_);}
    _LIBCPP_INLINE_VISIBILITY
    shared_ptr<_Tp const> shared_from_this() const
        {return shared_ptr<const _Tp>(__weak_this_);}

    template <class _Up> friend class shared_ptr;
};

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY hash<shared_ptr<_Tp> >
{
    typedef shared_ptr<_Tp>      argument_type;
    typedef size_t               result_type;
    _LIBCPP_INLINE_VISIBILITY
    result_type operator()(const argument_type& __ptr) const _NOEXCEPT
    {
        return hash<_Tp*>()(__ptr.get());
    }
};

template<class _CharT, class _Traits, class _Yp>
inline _LIBCPP_INLINE_VISIBILITY
basic_ostream<_CharT, _Traits>&
operator<<(basic_ostream<_CharT, _Traits>& __os, shared_ptr<_Yp> const& __p);

#if __has_feature(cxx_atomic)

class _LIBCPP_TYPE_VIS __sp_mut
{
    void* __lx;
public:
    void lock() _NOEXCEPT;
    void unlock() _NOEXCEPT;

private:
    _LIBCPP_CONSTEXPR __sp_mut(void*) _NOEXCEPT;
    __sp_mut(const __sp_mut&);
    __sp_mut& operator=(const __sp_mut&);

    friend _LIBCPP_FUNC_VIS __sp_mut& __get_sp_mut(const void*);
};

_LIBCPP_FUNC_VIS __sp_mut& __get_sp_mut(const void*);

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
atomic_is_lock_free(const shared_ptr<_Tp>*)
{
    return false;
}

template <class _Tp>
shared_ptr<_Tp>
atomic_load(const shared_ptr<_Tp>* __p)
{
    __sp_mut& __m = __get_sp_mut(__p);
    __m.lock();
    shared_ptr<_Tp> __q = *__p;
    __m.unlock();
    return __q;
}
  
template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
shared_ptr<_Tp>
atomic_load_explicit(const shared_ptr<_Tp>* __p, memory_order)
{
    return atomic_load(__p);
}

template <class _Tp>
void
atomic_store(shared_ptr<_Tp>* __p, shared_ptr<_Tp> __r)
{
    __sp_mut& __m = __get_sp_mut(__p);
    __m.lock();
    __p->swap(__r);
    __m.unlock();
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void
atomic_store_explicit(shared_ptr<_Tp>* __p, shared_ptr<_Tp> __r, memory_order)
{
    atomic_store(__p, __r);
}

template <class _Tp>
shared_ptr<_Tp>
atomic_exchange(shared_ptr<_Tp>* __p, shared_ptr<_Tp> __r)
{
    __sp_mut& __m = __get_sp_mut(__p);
    __m.lock();
    __p->swap(__r);
    __m.unlock();
    return __r;
}
  
template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
shared_ptr<_Tp>
atomic_exchange_explicit(shared_ptr<_Tp>* __p, shared_ptr<_Tp> __r, memory_order)
{
    return atomic_exchange(__p, __r);
}

template <class _Tp>
bool
atomic_compare_exchange_strong(shared_ptr<_Tp>* __p, shared_ptr<_Tp>* __v, shared_ptr<_Tp> __w)
{
    __sp_mut& __m = __get_sp_mut(__p);
    __m.lock();
    if (__p->__owner_equivalent(*__v))
    {
        *__p = __w;
        __m.unlock();
        return true;
    }
    *__v = *__p;
    __m.unlock();
    return false;
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
atomic_compare_exchange_weak(shared_ptr<_Tp>* __p, shared_ptr<_Tp>* __v, shared_ptr<_Tp> __w)
{
    return atomic_compare_exchange_strong(__p, __v, __w);
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
atomic_compare_exchange_strong_explicit(shared_ptr<_Tp>* __p, shared_ptr<_Tp>* __v,
                                        shared_ptr<_Tp> __w, memory_order, memory_order)
{
    return atomic_compare_exchange_strong(__p, __v, __w);
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
atomic_compare_exchange_weak_explicit(shared_ptr<_Tp>* __p, shared_ptr<_Tp>* __v,
                                      shared_ptr<_Tp> __w, memory_order, memory_order)
{
    return atomic_compare_exchange_weak(__p, __v, __w);
}

#endif  // __has_feature(cxx_atomic)
# 5392 "/usr/include/c++/v1/memory" 3

//enum class
struct _LIBCPP_TYPE_VIS pointer_safety
{
    enum __lx
    {
        relaxed,
        preferred,
        strict
    };

    __lx __v_;

    _LIBCPP_INLINE_VISIBILITY
    pointer_safety(__lx __v) : __v_(__v) {}
    _LIBCPP_INLINE_VISIBILITY
    operator int() const {return __v_;}
};

_LIBCPP_FUNC_VIS void declare_reachable(void* __p);
_LIBCPP_FUNC_VIS void declare_no_pointers(char* __p, size_t __n);
_LIBCPP_FUNC_VIS void undeclare_no_pointers(char* __p, size_t __n);
_LIBCPP_FUNC_VIS pointer_safety get_pointer_safety() _NOEXCEPT;
_LIBCPP_FUNC_VIS void* __undeclare_reachable(void* __p);

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_Tp*
undeclare_reachable(_Tp* __p)
{
    return static_cast<_Tp*>(__undeclare_reachable(__p));
}

_LIBCPP_FUNC_VIS void* align(size_t __align, size_t __sz, void*& __ptr, size_t& __space);

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_MEMORY
# 5430 "/usr/include/c++/v1/memory" 3
# 628 "/usr/include/c++/v1/algorithm" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 629 "/usr/include/c++/v1/algorithm" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 630 "/usr/include/c++/v1/algorithm" 3

#if defined(__IBMCPP__)
#if 0 /* expanded by -frewrite-includes */
#include "support/ibm/support.h"
#endif /* expanded by -frewrite-includes */
# 633 "/usr/include/c++/v1/algorithm" 3
#endif
# 634 "/usr/include/c++/v1/algorithm" 3
#if defined(_LIBCPP_MSVCRT) || defined(__MINGW32__)
#if 0 /* expanded by -frewrite-includes */
#include "support/win32/support.h"
#endif /* expanded by -frewrite-includes */
# 636 "/usr/include/c++/v1/algorithm" 3
#endif
# 637 "/usr/include/c++/v1/algorithm" 3

#if 0 /* expanded by -frewrite-includes */
#include <__undef_min_max>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/__undef_min_max" 1 3
// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifdef min
#if defined(_MSC_VER) && ! defined(__clang__)
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 16 "/usr/include/c++/v1/__undef_min_max" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 18 "/usr/include/c++/v1/__undef_min_max" 3
#undef min
#endif
# 20 "/usr/include/c++/v1/__undef_min_max" 3

#ifdef max
#if defined(_MSC_VER) && ! defined(__clang__)
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 26 "/usr/include/c++/v1/__undef_min_max" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 28 "/usr/include/c++/v1/__undef_min_max" 3
#undef max
#endif
# 30 "/usr/include/c++/v1/__undef_min_max" 3
# 639 "/usr/include/c++/v1/algorithm" 2 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 642 "/usr/include/c++/v1/algorithm" 3
#endif
# 643 "/usr/include/c++/v1/algorithm" 3

_LIBCPP_BEGIN_NAMESPACE_STD

template <class _T1, class _T2 = _T1>
struct __equal_to
{
    _LIBCPP_INLINE_VISIBILITY bool operator()(const _T1& __x, const _T1& __y) const {return __x == __y;}
    _LIBCPP_INLINE_VISIBILITY bool operator()(const _T1& __x, const _T2& __y) const {return __x == __y;}
    _LIBCPP_INLINE_VISIBILITY bool operator()(const _T2& __x, const _T1& __y) const {return __x == __y;}
    _LIBCPP_INLINE_VISIBILITY bool operator()(const _T2& __x, const _T2& __y) const {return __x == __y;}
};

template <class _T1>
struct __equal_to<_T1, _T1>
{
    _LIBCPP_INLINE_VISIBILITY bool operator()(const _T1& __x, const _T1& __y) const {return __x == __y;}
};

template <class _T1>
struct __equal_to<const _T1, _T1>
{
    _LIBCPP_INLINE_VISIBILITY bool operator()(const _T1& __x, const _T1& __y) const {return __x == __y;}
};

template <class _T1>
struct __equal_to<_T1, const _T1>
{
    _LIBCPP_INLINE_VISIBILITY bool operator()(const _T1& __x, const _T1& __y) const {return __x == __y;}
};

template <class _T1, class _T2 = _T1>
struct __less
{
    _LIBCPP_INLINE_VISIBILITY bool operator()(const _T1& __x, const _T1& __y) const {return __x < __y;}
    _LIBCPP_INLINE_VISIBILITY bool operator()(const _T1& __x, const _T2& __y) const {return __x < __y;}
    _LIBCPP_INLINE_VISIBILITY bool operator()(const _T2& __x, const _T1& __y) const {return __x < __y;}
    _LIBCPP_INLINE_VISIBILITY bool operator()(const _T2& __x, const _T2& __y) const {return __x < __y;}
};

template <class _T1>
struct __less<_T1, _T1>
{
    _LIBCPP_INLINE_VISIBILITY bool operator()(const _T1& __x, const _T1& __y) const {return __x < __y;}
};

template <class _T1>
struct __less<const _T1, _T1>
{
    _LIBCPP_INLINE_VISIBILITY bool operator()(const _T1& __x, const _T1& __y) const {return __x < __y;}
};

template <class _T1>
struct __less<_T1, const _T1>
{
    _LIBCPP_INLINE_VISIBILITY bool operator()(const _T1& __x, const _T1& __y) const {return __x < __y;}
};

template <class _Predicate>
class __negate
{
private:
    _Predicate __p_;
public:
    _LIBCPP_INLINE_VISIBILITY __negate() {}

    _LIBCPP_INLINE_VISIBILITY
    explicit __negate(_Predicate __p) : __p_(__p) {}

    template <class _T1>
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _T1& __x) {return !__p_(__x);}

    template <class _T1, class _T2>
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _T1& __x, const _T2& __y) {return !__p_(__x, __y);}
};

#ifdef _LIBCPP_DEBUG

template <class _Compare>
struct __debug_less
{
    _Compare __comp_;
    __debug_less(_Compare& __c) : __comp_(__c) {}
    template <class _Tp, class _Up>
    bool operator()(const _Tp& __x, const _Up& __y)
    {
        bool __r = __comp_(__x, __y);
        if (__r)
            _LIBCPP_ASSERT(!__comp_(__y, __x), "Comparator does not induce a strict weak ordering");
        return __r;
    }
};

#endif  // _LIBCPP_DEBUG
# 738 "/usr/include/c++/v1/algorithm" 3

// Precondition:  __x != 0
inline _LIBCPP_INLINE_VISIBILITY
unsigned
__ctz(unsigned __x)
{
    return static_cast<unsigned>(__builtin_ctz(__x));
}

inline _LIBCPP_INLINE_VISIBILITY
unsigned long
__ctz(unsigned long __x)
{
    return static_cast<unsigned long>(__builtin_ctzl(__x));
}

inline _LIBCPP_INLINE_VISIBILITY
unsigned long long
__ctz(unsigned long long __x)
{
    return static_cast<unsigned long long>(__builtin_ctzll(__x));
}

// Precondition:  __x != 0
inline _LIBCPP_INLINE_VISIBILITY
unsigned
__clz(unsigned __x)
{
    return static_cast<unsigned>(__builtin_clz(__x));
}

inline _LIBCPP_INLINE_VISIBILITY
unsigned long
__clz(unsigned long __x)
{
    return static_cast<unsigned long>(__builtin_clzl (__x));
}

inline _LIBCPP_INLINE_VISIBILITY
unsigned long long
__clz(unsigned long long __x)
{
    return static_cast<unsigned long long>(__builtin_clzll(__x));
}

inline _LIBCPP_INLINE_VISIBILITY int __pop_count(unsigned           __x) {return __builtin_popcount  (__x);}
inline _LIBCPP_INLINE_VISIBILITY int __pop_count(unsigned      long __x) {return __builtin_popcountl (__x);}
inline _LIBCPP_INLINE_VISIBILITY int __pop_count(unsigned long long __x) {return __builtin_popcountll(__x);}

// all_of

template <class _InputIterator, class _Predicate>
inline _LIBCPP_INLINE_VISIBILITY
bool
all_of(_InputIterator __first, _InputIterator __last, _Predicate __pred)
{
    for (; __first != __last; ++__first)
        if (!__pred(*__first))
            return false;
    return true;
}

// any_of

template <class _InputIterator, class _Predicate>
inline _LIBCPP_INLINE_VISIBILITY
bool
any_of(_InputIterator __first, _InputIterator __last, _Predicate __pred)
{
    for (; __first != __last; ++__first)
        if (__pred(*__first))
            return true;
    return false;
}

// none_of

template <class _InputIterator, class _Predicate>
inline _LIBCPP_INLINE_VISIBILITY
bool
none_of(_InputIterator __first, _InputIterator __last, _Predicate __pred)
{
    for (; __first != __last; ++__first)
        if (__pred(*__first))
            return false;
    return true;
}

// for_each

template <class _InputIterator, class _Function>
inline _LIBCPP_INLINE_VISIBILITY
_Function
for_each(_InputIterator __first, _InputIterator __last, _Function __f)
{
    for (; __first != __last; ++__first)
        __f(*__first);
    return _VSTD::move(__f);  // explicitly moved for (emulated) C++03
}

// find

template <class _InputIterator, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_InputIterator
find(_InputIterator __first, _InputIterator __last, const _Tp& __value_)
{
    for (; __first != __last; ++__first)
        if (*__first == __value_)
            break;
    return __first;
}

// find_if

template <class _InputIterator, class _Predicate>
inline _LIBCPP_INLINE_VISIBILITY
_InputIterator
find_if(_InputIterator __first, _InputIterator __last, _Predicate __pred)
{
    for (; __first != __last; ++__first)
        if (__pred(*__first))
            break;
    return __first;
}

// find_if_not

template<class _InputIterator, class _Predicate>
inline _LIBCPP_INLINE_VISIBILITY
_InputIterator
find_if_not(_InputIterator __first, _InputIterator __last, _Predicate __pred)
{
    for (; __first != __last; ++__first)
        if (!__pred(*__first))
            break;
    return __first;
}

// find_end

template <class _BinaryPredicate, class _ForwardIterator1, class _ForwardIterator2>
_ForwardIterator1
__find_end(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
           _ForwardIterator2 __first2, _ForwardIterator2 __last2, _BinaryPredicate __pred,
           forward_iterator_tag, forward_iterator_tag)
{
    // modeled after search algorithm
    _ForwardIterator1 __r = __last1;  // __last1 is the "default" answer
    if (__first2 == __last2)
        return __r;
    while (true)
    {
        while (true)
        {
            if (__first1 == __last1)         // if source exhausted return last correct answer
                return __r;                  //    (or __last1 if never found)
            if (__pred(*__first1, *__first2))
                break;
            ++__first1;
        }
        // *__first1 matches *__first2, now match elements after here
        _ForwardIterator1 __m1 = __first1;
        _ForwardIterator2 __m2 = __first2;
        while (true)
        {
            if (++__m2 == __last2)
            {                         // Pattern exhaused, record answer and search for another one
                __r = __first1;
                ++__first1;
                break;
            }
            if (++__m1 == __last1)     // Source exhausted, return last answer
                return __r;
            if (!__pred(*__m1, *__m2))  // mismatch, restart with a new __first
            {
                ++__first1;
                break;
            }  // else there is a match, check next elements
        }
    }
}

template <class _BinaryPredicate, class _BidirectionalIterator1, class _BidirectionalIterator2>
_BidirectionalIterator1
__find_end(_BidirectionalIterator1 __first1, _BidirectionalIterator1 __last1,
           _BidirectionalIterator2 __first2, _BidirectionalIterator2 __last2, _BinaryPredicate __pred,
           bidirectional_iterator_tag, bidirectional_iterator_tag)
{
    // modeled after search algorithm (in reverse)
    if (__first2 == __last2)
        return __last1;  // Everything matches an empty sequence
    _BidirectionalIterator1 __l1 = __last1;
    _BidirectionalIterator2 __l2 = __last2;
    --__l2;
    while (true)
    {
        // Find last element in sequence 1 that matchs *(__last2-1), with a mininum of loop checks
        while (true)
        {
            if (__first1 == __l1)  // return __last1 if no element matches *__first2
                return __last1;
            if (__pred(*--__l1, *__l2))
                break;
        }
        // *__l1 matches *__l2, now match elements before here
        _BidirectionalIterator1 __m1 = __l1;
        _BidirectionalIterator2 __m2 = __l2;
        while (true)
        {
            if (__m2 == __first2)  // If pattern exhausted, __m1 is the answer (works for 1 element pattern)
                return __m1;
            if (__m1 == __first1)  // Otherwise if source exhaused, pattern not found
                return __last1;
            if (!__pred(*--__m1, *--__m2))  // if there is a mismatch, restart with a new __l1
            {
                break;
            }  // else there is a match, check next elements
        }
    }
}

template <class _BinaryPredicate, class _RandomAccessIterator1, class _RandomAccessIterator2>
_RandomAccessIterator1
__find_end(_RandomAccessIterator1 __first1, _RandomAccessIterator1 __last1,
           _RandomAccessIterator2 __first2, _RandomAccessIterator2 __last2, _BinaryPredicate __pred,
           random_access_iterator_tag, random_access_iterator_tag)
{
    // Take advantage of knowing source and pattern lengths.  Stop short when source is smaller than pattern
    typename iterator_traits<_RandomAccessIterator2>::difference_type __len2 = __last2 - __first2;
    if (__len2 == 0)
        return __last1;
    typename iterator_traits<_RandomAccessIterator1>::difference_type __len1 = __last1 - __first1;
    if (__len1 < __len2)
        return __last1;
    const _RandomAccessIterator1 __s = __first1 + (__len2 - 1);  // End of pattern match can't go before here
    _RandomAccessIterator1 __l1 = __last1;
    _RandomAccessIterator2 __l2 = __last2;
    --__l2;
    while (true)
    {
        while (true)
        {
            if (__s == __l1)
                return __last1;
            if (__pred(*--__l1, *__l2))
                break;
        }
        _RandomAccessIterator1 __m1 = __l1;
        _RandomAccessIterator2 __m2 = __l2;
        while (true)
        {
            if (__m2 == __first2)
                return __m1;
                                 // no need to check range on __m1 because __s guarantees we have enough source
            if (!__pred(*--__m1, *--__m2))
            {
                break;
            }
        }
    }
}

template <class _ForwardIterator1, class _ForwardIterator2, class _BinaryPredicate>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator1
find_end(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
         _ForwardIterator2 __first2, _ForwardIterator2 __last2, _BinaryPredicate __pred)
{
    return _VSTD::__find_end<typename add_lvalue_reference<_BinaryPredicate>::type>
                         (__first1, __last1, __first2, __last2, __pred,
                          typename iterator_traits<_ForwardIterator1>::iterator_category(),
                          typename iterator_traits<_ForwardIterator2>::iterator_category());
}

template <class _ForwardIterator1, class _ForwardIterator2>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator1
find_end(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
         _ForwardIterator2 __first2, _ForwardIterator2 __last2)
{
    typedef typename iterator_traits<_ForwardIterator1>::value_type __v1;
    typedef typename iterator_traits<_ForwardIterator2>::value_type __v2;
    return _VSTD::find_end(__first1, __last1, __first2, __last2, __equal_to<__v1, __v2>());
}

// find_first_of

template <class _ForwardIterator1, class _ForwardIterator2, class _BinaryPredicate>
_ForwardIterator1
find_first_of(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
              _ForwardIterator2 __first2, _ForwardIterator2 __last2, _BinaryPredicate __pred)
{
    for (; __first1 != __last1; ++__first1)
        for (_ForwardIterator2 __j = __first2; __j != __last2; ++__j)
            if (__pred(*__first1, *__j))
                return __first1;
    return __last1;
}

template <class _ForwardIterator1, class _ForwardIterator2>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator1
find_first_of(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
              _ForwardIterator2 __first2, _ForwardIterator2 __last2)
{
    typedef typename iterator_traits<_ForwardIterator1>::value_type __v1;
    typedef typename iterator_traits<_ForwardIterator2>::value_type __v2;
    return _VSTD::find_first_of(__first1, __last1, __first2, __last2, __equal_to<__v1, __v2>());
}

// adjacent_find

template <class _ForwardIterator, class _BinaryPredicate>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
adjacent_find(_ForwardIterator __first, _ForwardIterator __last, _BinaryPredicate __pred)
{
    if (__first != __last)
    {
        _ForwardIterator __i = __first;
        while (++__i != __last)
        {
            if (__pred(*__first, *__i))
                return __first;
            __first = __i;
        }
    }
    return __last;
}

template <class _ForwardIterator>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
adjacent_find(_ForwardIterator __first, _ForwardIterator __last)
{
    typedef typename iterator_traits<_ForwardIterator>::value_type __v;
    return _VSTD::adjacent_find(__first, __last, __equal_to<__v>());
}

// count

template <class _InputIterator, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
typename iterator_traits<_InputIterator>::difference_type
count(_InputIterator __first, _InputIterator __last, const _Tp& __value_)
{
    typename iterator_traits<_InputIterator>::difference_type __r(0);
    for (; __first != __last; ++__first)
        if (*__first == __value_)
            ++__r;
    return __r;
}

// count_if

template <class _InputIterator, class _Predicate>
inline _LIBCPP_INLINE_VISIBILITY
typename iterator_traits<_InputIterator>::difference_type
count_if(_InputIterator __first, _InputIterator __last, _Predicate __pred)
{
    typename iterator_traits<_InputIterator>::difference_type __r(0);
    for (; __first != __last; ++__first)
        if (__pred(*__first))
            ++__r;
    return __r;
}

// mismatch

template <class _InputIterator1, class _InputIterator2, class _BinaryPredicate>
inline _LIBCPP_INLINE_VISIBILITY
pair<_InputIterator1, _InputIterator2>
mismatch(_InputIterator1 __first1, _InputIterator1 __last1,
         _InputIterator2 __first2, _BinaryPredicate __pred)
{
    for (; __first1 != __last1; ++__first1, ++__first2)
        if (!__pred(*__first1, *__first2))
            break;
    return pair<_InputIterator1, _InputIterator2>(__first1, __first2);
}

template <class _InputIterator1, class _InputIterator2>
inline _LIBCPP_INLINE_VISIBILITY
pair<_InputIterator1, _InputIterator2>
mismatch(_InputIterator1 __first1, _InputIterator1 __last1, _InputIterator2 __first2)
{
    typedef typename iterator_traits<_InputIterator1>::value_type __v1;
    typedef typename iterator_traits<_InputIterator2>::value_type __v2;
    return _VSTD::mismatch(__first1, __last1, __first2, __equal_to<__v1, __v2>());
}

#if _LIBCPP_STD_VER > 11
template <class _InputIterator1, class _InputIterator2, class _BinaryPredicate>
inline _LIBCPP_INLINE_VISIBILITY
pair<_InputIterator1, _InputIterator2>
mismatch(_InputIterator1 __first1, _InputIterator1 __last1,
         _InputIterator2 __first2, _InputIterator2 __last2,
         _BinaryPredicate __pred)
{
    for (; __first1 != __last1 && __first2 != __last2; ++__first1, ++__first2)
        if (!__pred(*__first1, *__first2))
            break;
    return pair<_InputIterator1, _InputIterator2>(__first1, __first2);
}

template <class _InputIterator1, class _InputIterator2>
inline _LIBCPP_INLINE_VISIBILITY
pair<_InputIterator1, _InputIterator2>
mismatch(_InputIterator1 __first1, _InputIterator1 __last1,
         _InputIterator2 __first2, _InputIterator2 __last2)
{
    typedef typename iterator_traits<_InputIterator1>::value_type __v1;
    typedef typename iterator_traits<_InputIterator2>::value_type __v2;
    return _VSTD::mismatch(__first1, __last1, __first2, __last2, __equal_to<__v1, __v2>());
}
#endif
# 1155 "/usr/include/c++/v1/algorithm" 3

// equal

template <class _InputIterator1, class _InputIterator2, class _BinaryPredicate>
inline _LIBCPP_INLINE_VISIBILITY
bool
equal(_InputIterator1 __first1, _InputIterator1 __last1, _InputIterator2 __first2, _BinaryPredicate __pred)
{
    for (; __first1 != __last1; ++__first1, ++__first2)
        if (!__pred(*__first1, *__first2))
            return false;
    return true;
}

template <class _InputIterator1, class _InputIterator2>
inline _LIBCPP_INLINE_VISIBILITY
bool
equal(_InputIterator1 __first1, _InputIterator1 __last1, _InputIterator2 __first2)
{
    typedef typename iterator_traits<_InputIterator1>::value_type __v1;
    typedef typename iterator_traits<_InputIterator2>::value_type __v2;
    return _VSTD::equal(__first1, __last1, __first2, __equal_to<__v1, __v2>());
}

#if _LIBCPP_STD_VER > 11
template <class _BinaryPredicate, class _InputIterator1, class _InputIterator2>
inline _LIBCPP_INLINE_VISIBILITY
bool
__equal(_InputIterator1 __first1, _InputIterator1 __last1, 
        _InputIterator2 __first2, _InputIterator2 __last2, _BinaryPredicate __pred,
        input_iterator_tag, input_iterator_tag )
{
    for (; __first1 != __last1 && __first2 != __last2; ++__first1, ++__first2)
        if (!__pred(*__first1, *__first2))
            return false;
    return __first1 == __last1 && __first2 == __last2;
}

template <class _BinaryPredicate, class _RandomAccessIterator1, class _RandomAccessIterator2>
inline _LIBCPP_INLINE_VISIBILITY
bool
__equal(_RandomAccessIterator1 __first1, _RandomAccessIterator1 __last1, 
        _RandomAccessIterator2 __first2, _RandomAccessIterator2 __last2, _BinaryPredicate __pred, 
      random_access_iterator_tag, random_access_iterator_tag )
{
    if ( _VSTD::distance(__first1, __last1) != _VSTD::distance(__first2, __last2))
        return false;
    return _VSTD::equal<_RandomAccessIterator1, _RandomAccessIterator2,
                        typename add_lvalue_reference<_BinaryPredicate>::type>
                       (__first1, __last1, __first2, __pred );
}

template <class _InputIterator1, class _InputIterator2, class _BinaryPredicate>
inline _LIBCPP_INLINE_VISIBILITY
bool
equal(_InputIterator1 __first1, _InputIterator1 __last1, 
      _InputIterator2 __first2, _InputIterator2 __last2, _BinaryPredicate __pred )
{
    return _VSTD::__equal<typename add_lvalue_reference<_BinaryPredicate>::type>
       (__first1, __last1, __first2, __last2, __pred, 
        typename iterator_traits<_InputIterator1>::iterator_category(),
        typename iterator_traits<_InputIterator2>::iterator_category());
}

template <class _InputIterator1, class _InputIterator2>
inline _LIBCPP_INLINE_VISIBILITY
bool
equal(_InputIterator1 __first1, _InputIterator1 __last1, 
      _InputIterator2 __first2, _InputIterator2 __last2)
{
    typedef typename iterator_traits<_InputIterator1>::value_type __v1;
    typedef typename iterator_traits<_InputIterator2>::value_type __v2;
    return _VSTD::__equal(__first1, __last1, __first2, __last2, __equal_to<__v1, __v2>(),
        typename iterator_traits<_InputIterator1>::iterator_category(),
        typename iterator_traits<_InputIterator2>::iterator_category());
}
#endif
# 1232 "/usr/include/c++/v1/algorithm" 3

// is_permutation

template<class _ForwardIterator1, class _ForwardIterator2, class _BinaryPredicate>
bool
is_permutation(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
               _ForwardIterator2 __first2, _BinaryPredicate __pred)
{
    // shorten sequences as much as possible by lopping of any equal parts
    for (; __first1 != __last1; ++__first1, ++__first2)
        if (!__pred(*__first1, *__first2))
            goto __not_done;
    return true;
__not_done:
    // __first1 != __last1 && *__first1 != *__first2
    typedef typename iterator_traits<_ForwardIterator1>::difference_type _D1;
    _D1 __l1 = _VSTD::distance(__first1, __last1);
    if (__l1 == _D1(1))
        return false;
    _ForwardIterator2 __last2 = _VSTD::next(__first2, __l1);
    // For each element in [f1, l1) see if there are the same number of
    //    equal elements in [f2, l2)
    for (_ForwardIterator1 __i = __first1; __i != __last1; ++__i)
    {
        // Have we already counted the number of *__i in [f1, l1)?
        for (_ForwardIterator1 __j = __first1; __j != __i; ++__j)
            if (__pred(*__j, *__i))
                goto __next_iter;
        {
            // Count number of *__i in [f2, l2)
            _D1 __c2 = 0;
            for (_ForwardIterator2 __j = __first2; __j != __last2; ++__j)
                if (__pred(*__i, *__j))
                    ++__c2;
            if (__c2 == 0)
                return false;
            // Count number of *__i in [__i, l1) (we can start with 1)
            _D1 __c1 = 1;
            for (_ForwardIterator1 __j = _VSTD::next(__i); __j != __last1; ++__j)
                if (__pred(*__i, *__j))
                    ++__c1;
            if (__c1 != __c2)
                return false;
        }
__next_iter:;
    }
    return true;
}

template<class _ForwardIterator1, class _ForwardIterator2>
inline _LIBCPP_INLINE_VISIBILITY
bool
is_permutation(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
               _ForwardIterator2 __first2)
{
    typedef typename iterator_traits<_ForwardIterator1>::value_type __v1;
    typedef typename iterator_traits<_ForwardIterator2>::value_type __v2;
    return _VSTD::is_permutation(__first1, __last1, __first2, __equal_to<__v1, __v2>());
}

#if _LIBCPP_STD_VER > 11
template<class _BinaryPredicate, class _ForwardIterator1, class _ForwardIterator2>
bool
__is_permutation(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
                 _ForwardIterator2 __first2, _ForwardIterator2 __last2, 
                 _BinaryPredicate __pred,
                 forward_iterator_tag, forward_iterator_tag )
{
    // shorten sequences as much as possible by lopping of any equal parts
    for (; __first1 != __last1 && __first2 != __last2; ++__first1, ++__first2)
        if (!__pred(*__first1, *__first2))
            goto __not_done;
    return __first1 == __last1 && __first2 == __last2;
__not_done:
    // __first1 != __last1 && __first2 != __last2 && *__first1 != *__first2
    typedef typename iterator_traits<_ForwardIterator1>::difference_type _D1;
    _D1 __l1 = _VSTD::distance(__first1, __last1);

    typedef typename iterator_traits<_ForwardIterator2>::difference_type _D2;
    _D2 __l2 = _VSTD::distance(__first2, __last2);
    if (__l1 != __l2)
        return false;

    // For each element in [f1, l1) see if there are the same number of
    //    equal elements in [f2, l2)
    for (_ForwardIterator1 __i = __first1; __i != __last1; ++__i)
    {
        // Have we already counted the number of *__i in [f1, l1)?
        for (_ForwardIterator1 __j = __first1; __j != __i; ++__j)
            if (__pred(*__j, *__i))
                goto __next_iter;
        {
            // Count number of *__i in [f2, l2)
            _D1 __c2 = 0;
            for (_ForwardIterator2 __j = __first2; __j != __last2; ++__j)
                if (__pred(*__i, *__j))
                    ++__c2;
            if (__c2 == 0)
                return false;
            // Count number of *__i in [__i, l1) (we can start with 1)
            _D1 __c1 = 1;
            for (_ForwardIterator1 __j = _VSTD::next(__i); __j != __last1; ++__j)
                if (__pred(*__i, *__j))
                    ++__c1;
            if (__c1 != __c2)
                return false;
        }
__next_iter:;
    }
    return true;
}

template<class _BinaryPredicate, class _RandomAccessIterator1, class _RandomAccessIterator2>
bool
__is_permutation(_RandomAccessIterator1 __first1, _RandomAccessIterator2 __last1,
               _RandomAccessIterator1 __first2, _RandomAccessIterator2 __last2, 
               _BinaryPredicate __pred,
               random_access_iterator_tag, random_access_iterator_tag )
{
    if ( _VSTD::distance(__first1, __last1) != _VSTD::distance(__first2, __last2))
        return false;
    return _VSTD::is_permutation<_RandomAccessIterator1, _RandomAccessIterator2,
                                 typename add_lvalue_reference<_BinaryPredicate>::type>
                                (__first1, __last1, __first2, __pred );
}

template<class _ForwardIterator1, class _ForwardIterator2, class _BinaryPredicate>
inline _LIBCPP_INLINE_VISIBILITY
bool
is_permutation(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
               _ForwardIterator2 __first2, _ForwardIterator2 __last2,
               _BinaryPredicate __pred )
{
    return _VSTD::__is_permutation<typename add_lvalue_reference<_BinaryPredicate>::type>
       (__first1, __last1, __first2, __last2, __pred,
        typename iterator_traits<_ForwardIterator1>::iterator_category(),
        typename iterator_traits<_ForwardIterator2>::iterator_category());
}

template<class _ForwardIterator1, class _ForwardIterator2>
inline _LIBCPP_INLINE_VISIBILITY
bool
is_permutation(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
               _ForwardIterator2 __first2, _ForwardIterator2 __last2)
{
    typedef typename iterator_traits<_ForwardIterator1>::value_type __v1;
    typedef typename iterator_traits<_ForwardIterator2>::value_type __v2;
    return _VSTD::__is_permutation(__first1, __last1, __first2, __last2,
        __equal_to<__v1, __v2>(),
        typename iterator_traits<_ForwardIterator1>::iterator_category(),
        typename iterator_traits<_ForwardIterator2>::iterator_category());
}
#endif
# 1385 "/usr/include/c++/v1/algorithm" 3

// search

template <class _BinaryPredicate, class _ForwardIterator1, class _ForwardIterator2>
_ForwardIterator1
__search(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
         _ForwardIterator2 __first2, _ForwardIterator2 __last2, _BinaryPredicate __pred,
         forward_iterator_tag, forward_iterator_tag)
{
    if (__first2 == __last2)
        return __first1;  // Everything matches an empty sequence
    while (true)
    {
        // Find first element in sequence 1 that matchs *__first2, with a mininum of loop checks
        while (true)
        {
            if (__first1 == __last1)  // return __last1 if no element matches *__first2
                return __last1;
            if (__pred(*__first1, *__first2))
                break;
            ++__first1;
        }
        // *__first1 matches *__first2, now match elements after here
        _ForwardIterator1 __m1 = __first1;
        _ForwardIterator2 __m2 = __first2;
        while (true)
        {
            if (++__m2 == __last2)  // If pattern exhausted, __first1 is the answer (works for 1 element pattern)
                return __first1;
            if (++__m1 == __last1)  // Otherwise if source exhaused, pattern not found
                return __last1;
            if (!__pred(*__m1, *__m2))  // if there is a mismatch, restart with a new __first1
            {
                ++__first1;
                break;
            }  // else there is a match, check next elements
        }
    }
}

template <class _BinaryPredicate, class _RandomAccessIterator1, class _RandomAccessIterator2>
_RandomAccessIterator1
__search(_RandomAccessIterator1 __first1, _RandomAccessIterator1 __last1,
           _RandomAccessIterator2 __first2, _RandomAccessIterator2 __last2, _BinaryPredicate __pred,
           random_access_iterator_tag, random_access_iterator_tag)
{
    typedef typename std::iterator_traits<_RandomAccessIterator1>::difference_type _D1;
    typedef typename std::iterator_traits<_RandomAccessIterator2>::difference_type _D2;
    // Take advantage of knowing source and pattern lengths.  Stop short when source is smaller than pattern
    _D2 __len2 = __last2 - __first2;
    if (__len2 == 0)
        return __first1;
    _D1 __len1 = __last1 - __first1;
    if (__len1 < __len2)
        return __last1;
    const _RandomAccessIterator1 __s = __last1 - (__len2 - 1);  // Start of pattern match can't go beyond here
    while (true)
    {
#if !_LIBCPP_UNROLL_LOOPS
        while (true)
        {
            if (__first1 == __s)
                return __last1;
            if (__pred(*__first1, *__first2))
                break;
            ++__first1;
        }
#else  // !_LIBCPP_UNROLL_LOOPS
# 1453 "/usr/include/c++/v1/algorithm" 3
        for (_D1 __loop_unroll = (__s - __first1) / 4; __loop_unroll > 0; --__loop_unroll)
        {
            if (__pred(*__first1, *__first2))
                goto __phase2;
            if (__pred(*++__first1, *__first2))
                goto __phase2;
            if (__pred(*++__first1, *__first2))
                goto __phase2;
            if (__pred(*++__first1, *__first2))
                goto __phase2;
            ++__first1;
        }
        switch (__s - __first1)
        {
        case 3:
            if (__pred(*__first1, *__first2))
                break;
            ++__first1;
        case 2:
            if (__pred(*__first1, *__first2))
                break;
            ++__first1;
        case 1:
            if (__pred(*__first1, *__first2))
                break;
        case 0:
            return __last1;
        }
    __phase2:
#endif  // !_LIBCPP_UNROLL_LOOPS
# 1483 "/usr/include/c++/v1/algorithm" 3
        _RandomAccessIterator1 __m1 = __first1;
        _RandomAccessIterator2 __m2 = __first2;
#if !_LIBCPP_UNROLL_LOOPS
         while (true)
         {
             if (++__m2 == __last2)
                 return __first1;
             ++__m1;          // no need to check range on __m1 because __s guarantees we have enough source
             if (!__pred(*__m1, *__m2))
             {
                 ++__first1;
                 break;
             }
         }
#else  // !_LIBCPP_UNROLL_LOOPS
# 1498 "/usr/include/c++/v1/algorithm" 3
        ++__m2;
        ++__m1;
        for (_D2 __loop_unroll = (__last2 - __m2) / 4; __loop_unroll > 0; --__loop_unroll)
        {
            if (!__pred(*__m1, *__m2))
                goto __continue;
            if (!__pred(*++__m1, *++__m2))
                goto __continue;
            if (!__pred(*++__m1, *++__m2))
                goto __continue;
            if (!__pred(*++__m1, *++__m2))
                goto __continue;
            ++__m1;
            ++__m2;
        }
        switch (__last2 - __m2)
        {
        case 3:
            if (!__pred(*__m1, *__m2))
                break;
            ++__m1;
            ++__m2;
        case 2:
            if (!__pred(*__m1, *__m2))
                break;
            ++__m1;
            ++__m2;
        case 1:
            if (!__pred(*__m1, *__m2))
                break;
        case 0:
            return __first1;
        }
    __continue:
        ++__first1;
#endif  // !_LIBCPP_UNROLL_LOOPS
# 1534 "/usr/include/c++/v1/algorithm" 3
    }
}

template <class _ForwardIterator1, class _ForwardIterator2, class _BinaryPredicate>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator1
search(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
       _ForwardIterator2 __first2, _ForwardIterator2 __last2, _BinaryPredicate __pred)
{
    return _VSTD::__search<typename add_lvalue_reference<_BinaryPredicate>::type>
                         (__first1, __last1, __first2, __last2, __pred,
                          typename std::iterator_traits<_ForwardIterator1>::iterator_category(),
                          typename std::iterator_traits<_ForwardIterator2>::iterator_category());
}

template <class _ForwardIterator1, class _ForwardIterator2>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator1
search(_ForwardIterator1 __first1, _ForwardIterator1 __last1,
       _ForwardIterator2 __first2, _ForwardIterator2 __last2)
{
    typedef typename std::iterator_traits<_ForwardIterator1>::value_type __v1;
    typedef typename std::iterator_traits<_ForwardIterator2>::value_type __v2;
    return _VSTD::search(__first1, __last1, __first2, __last2, __equal_to<__v1, __v2>());
}

// search_n

template <class _BinaryPredicate, class _ForwardIterator, class _Size, class _Tp>
_ForwardIterator
__search_n(_ForwardIterator __first, _ForwardIterator __last,
           _Size __count, const _Tp& __value_, _BinaryPredicate __pred, forward_iterator_tag)
{
    if (__count <= 0)
        return __first;
    while (true)
    {
        // Find first element in sequence that matchs __value_, with a mininum of loop checks
        while (true)
        {
            if (__first == __last)  // return __last if no element matches __value_
                return __last;
            if (__pred(*__first, __value_))
                break;
            ++__first;
        }
        // *__first matches __value_, now match elements after here
        _ForwardIterator __m = __first;
        _Size __c(0);
        while (true)
        {
            if (++__c == __count)  // If pattern exhausted, __first is the answer (works for 1 element pattern)
                return __first;
            if (++__m == __last)  // Otherwise if source exhaused, pattern not found
                return __last;
            if (!__pred(*__m, __value_))  // if there is a mismatch, restart with a new __first
            {
                __first = __m;
                ++__first;
                break;
            }  // else there is a match, check next elements
        }
    }
}

template <class _BinaryPredicate, class _RandomAccessIterator, class _Size, class _Tp>
_RandomAccessIterator
__search_n(_RandomAccessIterator __first, _RandomAccessIterator __last,
           _Size __count, const _Tp& __value_, _BinaryPredicate __pred, random_access_iterator_tag)
{
    if (__count <= 0)
        return __first;
    _Size __len = static_cast<_Size>(__last - __first);
    if (__len < __count)
        return __last;
    const _RandomAccessIterator __s = __last - (__count - 1);  // Start of pattern match can't go beyond here
    while (true)
    {
        // Find first element in sequence that matchs __value_, with a mininum of loop checks
        while (true)
        {
            if (__first >= __s)  // return __last if no element matches __value_
                return __last;
            if (__pred(*__first, __value_))
                break;
            ++__first;
        }
        // *__first matches __value_, now match elements after here
        _RandomAccessIterator __m = __first;
        _Size __c(0);
        while (true)
        {
            if (++__c == __count)  // If pattern exhausted, __first is the answer (works for 1 element pattern)
                return __first;
             ++__m;          // no need to check range on __m because __s guarantees we have enough source
            if (!__pred(*__m, __value_))  // if there is a mismatch, restart with a new __first
            {
                __first = __m;
                ++__first;
                break;
            }  // else there is a match, check next elements
        }
    }
}

template <class _ForwardIterator, class _Size, class _Tp, class _BinaryPredicate>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
search_n(_ForwardIterator __first, _ForwardIterator __last,
         _Size __count, const _Tp& __value_, _BinaryPredicate __pred)
{
    return _VSTD::__search_n<typename add_lvalue_reference<_BinaryPredicate>::type>
           (__first, __last, __count, __value_, __pred, typename iterator_traits<_ForwardIterator>::iterator_category());
}

template <class _ForwardIterator, class _Size, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
search_n(_ForwardIterator __first, _ForwardIterator __last, _Size __count, const _Tp& __value_)
{
    typedef typename iterator_traits<_ForwardIterator>::value_type __v;
    return _VSTD::search_n(__first, __last, __count, __value_, __equal_to<__v, _Tp>());
}

// copy

template <class _Iter>
struct __libcpp_is_trivial_iterator
{
    static const bool value = is_pointer<_Iter>::value;
};

template <class _Iter>
struct __libcpp_is_trivial_iterator<move_iterator<_Iter> >
{
    static const bool value = is_pointer<_Iter>::value;
};

template <class _Iter>
struct __libcpp_is_trivial_iterator<__wrap_iter<_Iter> >
{
    static const bool value = is_pointer<_Iter>::value;
};

template <class _Iter>
inline _LIBCPP_INLINE_VISIBILITY
_Iter
__unwrap_iter(_Iter __i)
{
    return __i;
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_trivially_copy_assignable<_Tp>::value,
    _Tp*
>::type
__unwrap_iter(move_iterator<_Tp*> __i)
{
    return __i.base();
}

#if _LIBCPP_DEBUG_LEVEL < 2

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_trivially_copy_assignable<_Tp>::value,
    _Tp*
>::type
__unwrap_iter(__wrap_iter<_Tp*> __i)
{
    return __i.base();
}

#endif  // _LIBCPP_DEBUG_LEVEL < 2
# 1713 "/usr/include/c++/v1/algorithm" 3

template <class _InputIterator, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
__copy(_InputIterator __first, _InputIterator __last, _OutputIterator __result)
{
    for (; __first != __last; ++__first, ++__result)
        *__result = *__first;
    return __result;
}

template <class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_same<typename remove_const<_Tp>::type, _Up>::value &&
    is_trivially_copy_assignable<_Up>::value,
    _Up*
>::type
__copy(_Tp* __first, _Tp* __last, _Up* __result)
{
    const size_t __n = static_cast<size_t>(__last - __first);
    _VSTD::memmove(__result, __first, __n * sizeof(_Up));
    return __result + __n;
}

template <class _InputIterator, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
copy(_InputIterator __first, _InputIterator __last, _OutputIterator __result)
{
    return _VSTD::__copy(__unwrap_iter(__first), __unwrap_iter(__last), __unwrap_iter(__result));
}

// copy_backward

template <class _BidirectionalIterator, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
__copy_backward(_BidirectionalIterator __first, _BidirectionalIterator __last, _OutputIterator __result)
{
    while (__first != __last)
        *--__result = *--__last;
    return __result;
}

template <class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_same<typename remove_const<_Tp>::type, _Up>::value &&
    is_trivially_copy_assignable<_Up>::value,
    _Up*
>::type
__copy_backward(_Tp* __first, _Tp* __last, _Up* __result)
{
    const size_t __n = static_cast<size_t>(__last - __first);
    __result -= __n;
    _VSTD::memmove(__result, __first, __n * sizeof(_Up));
    return __result;
}

template <class _BidirectionalIterator1, class _BidirectionalIterator2>
inline _LIBCPP_INLINE_VISIBILITY
_BidirectionalIterator2
copy_backward(_BidirectionalIterator1 __first, _BidirectionalIterator1 __last,
              _BidirectionalIterator2 __result)
{
    return _VSTD::__copy_backward(__unwrap_iter(__first), __unwrap_iter(__last), __unwrap_iter(__result));
}

// copy_if

template<class _InputIterator, class _OutputIterator, class _Predicate>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
copy_if(_InputIterator __first, _InputIterator __last,
        _OutputIterator __result, _Predicate __pred)
{
    for (; __first != __last; ++__first)
    {
        if (__pred(*__first))
        {
            *__result = *__first;
            ++__result;
        }
    }
    return __result;
}

// copy_n

template<class _InputIterator, class _Size, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    __is_input_iterator<_InputIterator>::value &&
   !__is_random_access_iterator<_InputIterator>::value,
    _OutputIterator
>::type
copy_n(_InputIterator __first, _Size __n, _OutputIterator __result)
{
    if (__n > 0)
    {
        *__result = *__first;
        ++__result;
        for (--__n; __n > 0; --__n)
        {
            ++__first;
            *__result = *__first;
            ++__result;
        }
    }
    return __result;
}

template<class _InputIterator, class _Size, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    __is_random_access_iterator<_InputIterator>::value,
    _OutputIterator
>::type
copy_n(_InputIterator __first, _Size __n, _OutputIterator __result)
{
    return _VSTD::copy(__first, __first + __n, __result);
}

// move

template <class _InputIterator, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
__move(_InputIterator __first, _InputIterator __last, _OutputIterator __result)
{
    for (; __first != __last; ++__first, ++__result)
        *__result = _VSTD::move(*__first);
    return __result;
}

template <class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_same<typename remove_const<_Tp>::type, _Up>::value &&
    is_trivially_copy_assignable<_Up>::value,
    _Up*
>::type
__move(_Tp* __first, _Tp* __last, _Up* __result)
{
    const size_t __n = static_cast<size_t>(__last - __first);
    _VSTD::memmove(__result, __first, __n * sizeof(_Up));
    return __result + __n;
}

template <class _InputIterator, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
move(_InputIterator __first, _InputIterator __last, _OutputIterator __result)
{
    return _VSTD::__move(__unwrap_iter(__first), __unwrap_iter(__last), __unwrap_iter(__result));
}

// move_backward

template <class _InputIterator, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
__move_backward(_InputIterator __first, _InputIterator __last, _OutputIterator __result)
{
    while (__first != __last)
        *--__result = _VSTD::move(*--__last);
    return __result;
}

template <class _Tp, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_same<typename remove_const<_Tp>::type, _Up>::value &&
    is_trivially_copy_assignable<_Up>::value,
    _Up*
>::type
__move_backward(_Tp* __first, _Tp* __last, _Up* __result)
{
    const size_t __n = static_cast<size_t>(__last - __first);
    __result -= __n;
    _VSTD::memmove(__result, __first, __n * sizeof(_Up));
    return __result;
}

template <class _BidirectionalIterator1, class _BidirectionalIterator2>
inline _LIBCPP_INLINE_VISIBILITY
_BidirectionalIterator2
move_backward(_BidirectionalIterator1 __first, _BidirectionalIterator1 __last,
              _BidirectionalIterator2 __result)
{
    return _VSTD::__move_backward(__unwrap_iter(__first), __unwrap_iter(__last), __unwrap_iter(__result));
}

// iter_swap

// moved to <type_traits> for better swap / noexcept support

// transform

template <class _InputIterator, class _OutputIterator, class _UnaryOperation>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
transform(_InputIterator __first, _InputIterator __last, _OutputIterator __result, _UnaryOperation __op)
{
    for (; __first != __last; ++__first, ++__result)
        *__result = __op(*__first);
    return __result;
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator, class _BinaryOperation>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
transform(_InputIterator1 __first1, _InputIterator1 __last1, _InputIterator2 __first2,
          _OutputIterator __result, _BinaryOperation __binary_op)
{
    for (; __first1 != __last1; ++__first1, ++__first2, ++__result)
        *__result = __binary_op(*__first1, *__first2);
    return __result;
}

// replace

template <class _ForwardIterator, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void
replace(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __old_value, const _Tp& __new_value)
{
    for (; __first != __last; ++__first)
        if (*__first == __old_value)
            *__first = __new_value;
}

// replace_if

template <class _ForwardIterator, class _Predicate, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void
replace_if(_ForwardIterator __first, _ForwardIterator __last, _Predicate __pred, const _Tp& __new_value)
{
    for (; __first != __last; ++__first)
        if (__pred(*__first))
            *__first = __new_value;
}

// replace_copy

template <class _InputIterator, class _OutputIterator, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
replace_copy(_InputIterator __first, _InputIterator __last, _OutputIterator __result,
             const _Tp& __old_value, const _Tp& __new_value)
{
    for (; __first != __last; ++__first, ++__result)
        if (*__first == __old_value)
            *__result = __new_value;
        else
            *__result = *__first;
    return __result;
}

// replace_copy_if

template <class _InputIterator, class _OutputIterator, class _Predicate, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
replace_copy_if(_InputIterator __first, _InputIterator __last, _OutputIterator __result,
                _Predicate __pred, const _Tp& __new_value)
{
    for (; __first != __last; ++__first, ++__result)
        if (__pred(*__first))
            *__result = __new_value;
        else
            *__result = *__first;
    return __result;
}

// fill_n

template <class _OutputIterator, class _Size, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
__fill_n(_OutputIterator __first, _Size __n, const _Tp& __value_)
{
    for (; __n > 0; ++__first, --__n)
        *__first = __value_;
    return __first;
}

template <class _Tp, class _Size, class _Up>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value && sizeof(_Tp) == 1 &&
    !is_same<_Tp, bool>::value &&
    is_integral<_Up>::value && sizeof(_Up) == 1,
    _Tp*
>::type
__fill_n(_Tp* __first, _Size __n,_Up __value_)
{
    if (__n > 0)
        _VSTD::memset(__first, (unsigned char)__value_, (size_t)(__n));
    return __first + __n;
}

template <class _OutputIterator, class _Size, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
fill_n(_OutputIterator __first, _Size __n, const _Tp& __value_)
{
   return _VSTD::__fill_n(__first, __n, __value_);
}

// fill

template <class _ForwardIterator, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void
__fill(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_, forward_iterator_tag)
{
    for (; __first != __last; ++__first)
        *__first = __value_;
}

template <class _RandomAccessIterator, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void
__fill(_RandomAccessIterator __first, _RandomAccessIterator __last, const _Tp& __value_, random_access_iterator_tag)
{
    _VSTD::fill_n(__first, __last - __first, __value_);
}

template <class _ForwardIterator, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void
fill(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_)
{
    _VSTD::__fill(__first, __last, __value_, typename iterator_traits<_ForwardIterator>::iterator_category());
}

// generate

template <class _ForwardIterator, class _Generator>
inline _LIBCPP_INLINE_VISIBILITY
void
generate(_ForwardIterator __first, _ForwardIterator __last, _Generator __gen)
{
    for (; __first != __last; ++__first)
        *__first = __gen();
}

// generate_n

template <class _OutputIterator, class _Size, class _Generator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
generate_n(_OutputIterator __first, _Size __n, _Generator __gen)
{
    for (; __n > 0; ++__first, --__n)
        *__first = __gen();
    return __first;
}

// remove

template <class _ForwardIterator, class _Tp>
_ForwardIterator
remove(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_)
{
    __first = _VSTD::find(__first, __last, __value_);
    if (__first != __last)
    {
        _ForwardIterator __i = __first;
        while (++__i != __last)
        {
            if (!(*__i == __value_))
            {
                *__first = _VSTD::move(*__i);
                ++__first;
            }
        }
    }
    return __first;
}

// remove_if

template <class _ForwardIterator, class _Predicate>
_ForwardIterator
remove_if(_ForwardIterator __first, _ForwardIterator __last, _Predicate __pred)
{
    __first = _VSTD::find_if<_ForwardIterator, typename add_lvalue_reference<_Predicate>::type>
                           (__first, __last, __pred);
    if (__first != __last)
    {
        _ForwardIterator __i = __first;
        while (++__i != __last)
        {
            if (!__pred(*__i))
            {
                *__first = _VSTD::move(*__i);
                ++__first;
            }
        }
    }
    return __first;
}

// remove_copy

template <class _InputIterator, class _OutputIterator, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
remove_copy(_InputIterator __first, _InputIterator __last, _OutputIterator __result, const _Tp& __value_)
{
    for (; __first != __last; ++__first)
    {
        if (!(*__first == __value_))
        {
            *__result = *__first;
            ++__result;
        }
    }
    return __result;
}

// remove_copy_if

template <class _InputIterator, class _OutputIterator, class _Predicate>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
remove_copy_if(_InputIterator __first, _InputIterator __last, _OutputIterator __result, _Predicate __pred)
{
    for (; __first != __last; ++__first)
    {
        if (!__pred(*__first))
        {
            *__result = *__first;
            ++__result;
        }
    }
    return __result;
}

// unique

template <class _ForwardIterator, class _BinaryPredicate>
_ForwardIterator
unique(_ForwardIterator __first, _ForwardIterator __last, _BinaryPredicate __pred)
{
    __first = _VSTD::adjacent_find<_ForwardIterator, typename add_lvalue_reference<_BinaryPredicate>::type>
                                 (__first, __last, __pred);
    if (__first != __last)
    {
        // ...  a  a  ?  ...
        //      f     i
        _ForwardIterator __i = __first;
        for (++__i; ++__i != __last;)
            if (!__pred(*__first, *__i))
                *++__first = _VSTD::move(*__i);
        ++__first;
    }
    return __first;
}

template <class _ForwardIterator>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
unique(_ForwardIterator __first, _ForwardIterator __last)
{
    typedef typename iterator_traits<_ForwardIterator>::value_type __v;
    return _VSTD::unique(__first, __last, __equal_to<__v>());
}

// unique_copy

template <class _BinaryPredicate, class _InputIterator, class _OutputIterator>
_OutputIterator
__unique_copy(_InputIterator __first, _InputIterator __last, _OutputIterator __result, _BinaryPredicate __pred,
              input_iterator_tag, output_iterator_tag)
{
    if (__first != __last)
    {
        typename iterator_traits<_InputIterator>::value_type __t(*__first);
        *__result = __t;
        ++__result;
        while (++__first != __last)
        {
            if (!__pred(__t, *__first))
            {
                __t = *__first;
                *__result = __t;
                ++__result;
            }
        }
    }
    return __result;
}

template <class _BinaryPredicate, class _ForwardIterator, class _OutputIterator>
_OutputIterator
__unique_copy(_ForwardIterator __first, _ForwardIterator __last, _OutputIterator __result, _BinaryPredicate __pred,
              forward_iterator_tag, output_iterator_tag)
{
    if (__first != __last)
    {
        _ForwardIterator __i = __first;
        *__result = *__i;
        ++__result;
        while (++__first != __last)
        {
            if (!__pred(*__i, *__first))
            {
                *__result = *__first;
                ++__result;
                __i = __first;
            }
        }
    }
    return __result;
}

template <class _BinaryPredicate, class _InputIterator, class _ForwardIterator>
_ForwardIterator
__unique_copy(_InputIterator __first, _InputIterator __last, _ForwardIterator __result, _BinaryPredicate __pred,
              input_iterator_tag, forward_iterator_tag)
{
    if (__first != __last)
    {
        *__result = *__first;
        while (++__first != __last)
            if (!__pred(*__result, *__first))
                *++__result = *__first;
        ++__result;
    }
    return __result;
}

template <class _InputIterator, class _OutputIterator, class _BinaryPredicate>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
unique_copy(_InputIterator __first, _InputIterator __last, _OutputIterator __result, _BinaryPredicate __pred)
{
    return _VSTD::__unique_copy<typename add_lvalue_reference<_BinaryPredicate>::type>
                              (__first, __last, __result, __pred,
                               typename iterator_traits<_InputIterator>::iterator_category(),
                               typename iterator_traits<_OutputIterator>::iterator_category());
}

template <class _InputIterator, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
unique_copy(_InputIterator __first, _InputIterator __last, _OutputIterator __result)
{
    typedef typename iterator_traits<_InputIterator>::value_type __v;
    return _VSTD::unique_copy(__first, __last, __result, __equal_to<__v>());
}

// reverse

template <class _BidirectionalIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
__reverse(_BidirectionalIterator __first, _BidirectionalIterator __last, bidirectional_iterator_tag)
{
    while (__first != __last)
    {
        if (__first == --__last)
            break;
        swap(*__first, *__last);
        ++__first;
    }
}

template <class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
__reverse(_RandomAccessIterator __first, _RandomAccessIterator __last, random_access_iterator_tag)
{
    if (__first != __last)
        for (; __first < --__last; ++__first)
            swap(*__first, *__last);
}

template <class _BidirectionalIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
reverse(_BidirectionalIterator __first, _BidirectionalIterator __last)
{
    _VSTD::__reverse(__first, __last, typename iterator_traits<_BidirectionalIterator>::iterator_category());
}

// reverse_copy

template <class _BidirectionalIterator, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
reverse_copy(_BidirectionalIterator __first, _BidirectionalIterator __last, _OutputIterator __result)
{
    for (; __first != __last; ++__result)
        *__result = *--__last;
    return __result;
}

// rotate

template <class _ForwardIterator>
_ForwardIterator
__rotate_left(_ForwardIterator __first, _ForwardIterator __last)
{
    typedef typename iterator_traits<_ForwardIterator>::value_type value_type;
    value_type __tmp = _VSTD::move(*__first);
    _ForwardIterator __lm1 = _VSTD::move(_VSTD::next(__first), __last, __first);
    *__lm1 = _VSTD::move(__tmp);
    return __lm1;
}

template <class _BidirectionalIterator>
_BidirectionalIterator
__rotate_right(_BidirectionalIterator __first, _BidirectionalIterator __last)
{
    typedef typename iterator_traits<_BidirectionalIterator>::value_type value_type;
    _BidirectionalIterator __lm1 = _VSTD::prev(__last);
    value_type __tmp = _VSTD::move(*__lm1);
    _BidirectionalIterator __fp1 = _VSTD::move_backward(__first, __lm1, __last);
    *__first = _VSTD::move(__tmp);
    return __fp1;
}

template <class _ForwardIterator>
_ForwardIterator
__rotate_forward(_ForwardIterator __first, _ForwardIterator __middle, _ForwardIterator __last)
{
    _ForwardIterator __i = __middle;
    while (true)
    {
        swap(*__first, *__i);
        ++__first;
        if (++__i == __last)
            break;
        if (__first == __middle)
            __middle = __i;
    }
    _ForwardIterator __r = __first;
    if (__first != __middle)
    {
        __i = __middle;
        while (true)
        {
            swap(*__first, *__i);
            ++__first;
            if (++__i == __last)
            {
                if (__first == __middle)
                    break;
                __i = __middle;
            }
            else if (__first == __middle)
                __middle = __i;
        }
    }
    return __r;
}

template<typename _Integral>
inline _LIBCPP_INLINE_VISIBILITY
_Integral
__gcd(_Integral __x, _Integral __y)
{
    do
    {
        _Integral __t = __x % __y;
        __x = __y;
        __y = __t;
    } while (__y);
    return __x;
}

template<typename _RandomAccessIterator>
_RandomAccessIterator
__rotate_gcd(_RandomAccessIterator __first, _RandomAccessIterator __middle, _RandomAccessIterator __last)
{
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    typedef typename iterator_traits<_RandomAccessIterator>::value_type value_type;

    const difference_type __m1 = __middle - __first;
    const difference_type __m2 = __last - __middle;
    if (__m1 == __m2)
    {
        _VSTD::swap_ranges(__first, __middle, __middle);
        return __middle;
    }
    const difference_type __g = _VSTD::__gcd(__m1, __m2);
    for (_RandomAccessIterator __p = __first + __g; __p != __first;)
    {
        value_type __t(_VSTD::move(*--__p));
        _RandomAccessIterator __p1 = __p;
        _RandomAccessIterator __p2 = __p1 + __m1;
        do
        {
            *__p1 = _VSTD::move(*__p2);
            __p1 = __p2;
            const difference_type __d = __last - __p2;
            if (__m1 < __d)
                __p2 += __m1;
            else
                __p2 = __first + (__m1 - __d);
        } while (__p2 != __p);
        *__p1 = _VSTD::move(__t);
    }
    return __first + __m2;
}

template <class _ForwardIterator>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
__rotate(_ForwardIterator __first, _ForwardIterator __middle, _ForwardIterator __last,
         _VSTD::forward_iterator_tag)
{
    typedef typename _VSTD::iterator_traits<_ForwardIterator>::value_type value_type;
    if (_VSTD::is_trivially_move_assignable<value_type>::value)
    {
        if (_VSTD::next(__first) == __middle)
            return _VSTD::__rotate_left(__first, __last);
    }
    return _VSTD::__rotate_forward(__first, __middle, __last);
}

template <class _BidirectionalIterator>
inline _LIBCPP_INLINE_VISIBILITY
_BidirectionalIterator
__rotate(_BidirectionalIterator __first, _BidirectionalIterator __middle, _BidirectionalIterator __last,
         _VSTD::bidirectional_iterator_tag)
{
    typedef typename _VSTD::iterator_traits<_BidirectionalIterator>::value_type value_type;
    if (_VSTD::is_trivially_move_assignable<value_type>::value)
    {
        if (_VSTD::next(__first) == __middle)
            return _VSTD::__rotate_left(__first, __last);
        if (_VSTD::next(__middle) == __last)
            return _VSTD::__rotate_right(__first, __last);
    }
    return _VSTD::__rotate_forward(__first, __middle, __last);
}

template <class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
_RandomAccessIterator
__rotate(_RandomAccessIterator __first, _RandomAccessIterator __middle, _RandomAccessIterator __last,
         _VSTD::random_access_iterator_tag)
{
    typedef typename _VSTD::iterator_traits<_RandomAccessIterator>::value_type value_type;
    if (_VSTD::is_trivially_move_assignable<value_type>::value)
    {
        if (_VSTD::next(__first) == __middle)
            return _VSTD::__rotate_left(__first, __last);
        if (_VSTD::next(__middle) == __last)
            return _VSTD::__rotate_right(__first, __last);
        return _VSTD::__rotate_gcd(__first, __middle, __last);
    }
    return _VSTD::__rotate_forward(__first, __middle, __last);
}

template <class _ForwardIterator>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
rotate(_ForwardIterator __first, _ForwardIterator __middle, _ForwardIterator __last)
{
    if (__first == __middle)
        return __last;
    if (__middle == __last)
        return __first;
    return _VSTD::__rotate(__first, __middle, __last,
                           typename _VSTD::iterator_traits<_ForwardIterator>::iterator_category());
}

// rotate_copy

template <class _ForwardIterator, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
rotate_copy(_ForwardIterator __first, _ForwardIterator __middle, _ForwardIterator __last, _OutputIterator __result)
{
    return _VSTD::copy(__first, __middle, _VSTD::copy(__middle, __last, __result));
}

// min_element

template <class _ForwardIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
min_element(_ForwardIterator __first, _ForwardIterator __last, _Compare __comp)
{
    if (__first != __last)
    {
        _ForwardIterator __i = __first;
        while (++__i != __last)
            if (__comp(*__i, *__first))
                __first = __i;
    }
    return __first;
}

template <class _ForwardIterator>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
min_element(_ForwardIterator __first, _ForwardIterator __last)
{
    return _VSTD::min_element(__first, __last,
              __less<typename iterator_traits<_ForwardIterator>::value_type>());
}

// min

template <class _Tp, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
const _Tp&
min(const _Tp& __a, const _Tp& __b, _Compare __comp)
{
    return __comp(__b, __a) ? __b : __a;
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
const _Tp&
min(const _Tp& __a, const _Tp& __b)
{
    return _VSTD::min(__a, __b, __less<_Tp>());
}

#ifndef _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS

template<class _Tp, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
_Tp
min(initializer_list<_Tp> __t, _Compare __comp)
{
    return *_VSTD::min_element(__t.begin(), __t.end(), __comp);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_Tp
min(initializer_list<_Tp> __t)
{
    return *_VSTD::min_element(__t.begin(), __t.end());
}

#endif  // _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
# 2568 "/usr/include/c++/v1/algorithm" 3

// max_element

template <class _ForwardIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
max_element(_ForwardIterator __first, _ForwardIterator __last, _Compare __comp)
{
    if (__first != __last)
    {
        _ForwardIterator __i = __first;
        while (++__i != __last)
            if (__comp(*__first, *__i))
                __first = __i;
    }
    return __first;
}

template <class _ForwardIterator>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
max_element(_ForwardIterator __first, _ForwardIterator __last)
{
    return _VSTD::max_element(__first, __last,
              __less<typename iterator_traits<_ForwardIterator>::value_type>());
}

// max

template <class _Tp, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
const _Tp&
max(const _Tp& __a, const _Tp& __b, _Compare __comp)
{
    return __comp(__a, __b) ? __b : __a;
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
const _Tp&
max(const _Tp& __a, const _Tp& __b)
{
    return _VSTD::max(__a, __b, __less<_Tp>());
}

#ifndef _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS

template<class _Tp, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
_Tp
max(initializer_list<_Tp> __t, _Compare __comp)
{
    return *_VSTD::max_element(__t.begin(), __t.end(), __comp);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_Tp
max(initializer_list<_Tp> __t)
{
    return *_VSTD::max_element(__t.begin(), __t.end());
}

#endif  // _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
# 2632 "/usr/include/c++/v1/algorithm" 3

// minmax_element

template <class _ForwardIterator, class _Compare>
std::pair<_ForwardIterator, _ForwardIterator>
minmax_element(_ForwardIterator __first, _ForwardIterator __last, _Compare __comp)
{
  std::pair<_ForwardIterator, _ForwardIterator> __result(__first, __first);
  if (__first != __last)
  {
      if (++__first != __last)
      {
          if (__comp(*__first, *__result.first))
              __result.first = __first;
          else
              __result.second = __first;
          while (++__first != __last)
          {
              _ForwardIterator __i = __first;
              if (++__first == __last)
              {
                  if (__comp(*__i, *__result.first))
                      __result.first = __i;
                  else if (!__comp(*__i, *__result.second))
                      __result.second = __i;
                  break;
              }
              else
              {
                  if (__comp(*__first, *__i))
                  {
                      if (__comp(*__first, *__result.first))
                          __result.first = __first;
                      if (!__comp(*__i, *__result.second))
                          __result.second = __i;
                  }
                  else
                  {
                      if (__comp(*__i, *__result.first))
                          __result.first = __i;
                      if (!__comp(*__first, *__result.second))
                          __result.second = __first;
                  }
              }
          }
      }
  }
  return __result;
}

template <class _ForwardIterator>
inline _LIBCPP_INLINE_VISIBILITY
std::pair<_ForwardIterator, _ForwardIterator>
minmax_element(_ForwardIterator __first, _ForwardIterator __last)
{
    return _VSTD::minmax_element(__first, __last, __less<typename iterator_traits<_ForwardIterator>::value_type>());
}

// minmax

template<class _Tp, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
pair<const _Tp&, const _Tp&>
minmax(const _Tp& __a, const _Tp& __b, _Compare __comp)
{
    return __comp(__b, __a) ? pair<const _Tp&, const _Tp&>(__b, __a) :
                              pair<const _Tp&, const _Tp&>(__a, __b);
}

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
pair<const _Tp&, const _Tp&>
minmax(const _Tp& __a, const _Tp& __b)
{
    return _VSTD::minmax(__a, __b, __less<_Tp>());
}

#ifndef _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS

template<class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
pair<_Tp, _Tp>
minmax(initializer_list<_Tp> __t)
{
    pair<const _Tp*, const _Tp*> __p =
                                   _VSTD::minmax_element(__t.begin(), __t.end());
    return pair<_Tp, _Tp>(*__p.first, *__p.second);
}

template<class _Tp, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
pair<_Tp, _Tp>
minmax(initializer_list<_Tp> __t, _Compare __comp)
{
    pair<const _Tp*, const _Tp*> __p =
                           _VSTD::minmax_element(__t.begin(), __t.end(), __comp);
    return pair<_Tp, _Tp>(*__p.first, *__p.second);
}

#endif  // _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
# 2732 "/usr/include/c++/v1/algorithm" 3

// random_shuffle

// __independent_bits_engine

template <unsigned long long _Xp, size_t _Rp>
struct __log2_imp
{
    static const size_t value = _Xp & ((unsigned long long)(1) << _Rp) ? _Rp
                                           : __log2_imp<_Xp, _Rp - 1>::value;
};

template <unsigned long long _Xp>
struct __log2_imp<_Xp, 0>
{
    static const size_t value = 0;
};

template <size_t _Rp>
struct __log2_imp<0, _Rp>
{
    static const size_t value = _Rp + 1;
};

template <class _UI, _UI _Xp>
struct __log2
{
    static const size_t value = __log2_imp<_Xp,
                                         sizeof(_UI) * __CHAR_BIT__ - 1>::value;
};

template<class _Engine, class _UIntType>
class __independent_bits_engine
{
public:
    // types
    typedef _UIntType result_type;

private:
    typedef typename _Engine::result_type _Engine_result_type;
    typedef typename conditional
        <
            sizeof(_Engine_result_type) <= sizeof(result_type),
                result_type,
                _Engine_result_type
        >::type _Working_result_type;

    _Engine& __e_;
    size_t __w_;
    size_t __w0_;
    size_t __n_;
    size_t __n0_;
    _Working_result_type __y0_;
    _Working_result_type __y1_;
    _Engine_result_type __mask0_;
    _Engine_result_type __mask1_;

#ifdef _LIBCPP_HAS_NO_CONSTEXPR
    static const _Working_result_type _Rp = _Engine::_Max - _Engine::_Min
                                          + _Working_result_type(1);
#else
# 2793 "/usr/include/c++/v1/algorithm" 3
    static _LIBCPP_CONSTEXPR const _Working_result_type _Rp = _Engine::max() - _Engine::min()
                                                      + _Working_result_type(1);
#endif
# 2796 "/usr/include/c++/v1/algorithm" 3
    static _LIBCPP_CONSTEXPR const size_t __m = __log2<_Working_result_type, _Rp>::value;
    static _LIBCPP_CONSTEXPR const size_t _WDt = numeric_limits<_Working_result_type>::digits;
    static _LIBCPP_CONSTEXPR const size_t _EDt = numeric_limits<_Engine_result_type>::digits;

public:
    // constructors and seeding functions
    __independent_bits_engine(_Engine& __e, size_t __w);

    // generating functions
    result_type operator()() {return __eval(integral_constant<bool, _Rp != 0>());}

private:
    result_type __eval(false_type);
    result_type __eval(true_type);
};

template<class _Engine, class _UIntType>
__independent_bits_engine<_Engine, _UIntType>
    ::__independent_bits_engine(_Engine& __e, size_t __w)
        : __e_(__e),
          __w_(__w)
{
    __n_ = __w_ / __m + (__w_ % __m != 0);
    __w0_ = __w_ / __n_;
    if (_Rp == 0)
        __y0_ = _Rp;
    else if (__w0_ < _WDt)
        __y0_ = (_Rp >> __w0_) << __w0_;
    else
        __y0_ = 0;
    if (_Rp - __y0_ > __y0_ / __n_)
    {
        ++__n_;
        __w0_ = __w_ / __n_;
        if (__w0_ < _WDt)
            __y0_ = (_Rp >> __w0_) << __w0_;
        else
            __y0_ = 0;
    }
    __n0_ = __n_ - __w_ % __n_;
    if (__w0_ < _WDt - 1)
        __y1_ = (_Rp >> (__w0_ + 1)) << (__w0_ + 1);
    else
        __y1_ = 0;
    __mask0_ = __w0_ > 0 ? _Engine_result_type(~0) >> (_EDt - __w0_) :
                          _Engine_result_type(0);
    __mask1_ = __w0_ < _EDt - 1 ?
                               _Engine_result_type(~0) >> (_EDt - (__w0_ + 1)) :
                               _Engine_result_type(~0);
}

template<class _Engine, class _UIntType>
inline
_UIntType
__independent_bits_engine<_Engine, _UIntType>::__eval(false_type)
{
    return static_cast<result_type>(__e_() & __mask0_);
}

template<class _Engine, class _UIntType>
_UIntType
__independent_bits_engine<_Engine, _UIntType>::__eval(true_type)
{
    result_type _Sp = 0;
    for (size_t __k = 0; __k < __n0_; ++__k)
    {
        _Engine_result_type __u;
        do
        {
            __u = __e_() - _Engine::min();
        } while (__u >= __y0_);
        if (__w0_ < _WDt)
            _Sp <<= __w0_;
        else
            _Sp = 0;
        _Sp += __u & __mask0_;
    }
    for (size_t __k = __n0_; __k < __n_; ++__k)
    {
        _Engine_result_type __u;
        do
        {
            __u = __e_() - _Engine::min();
        } while (__u >= __y1_);
        if (__w0_ < _WDt - 1)
            _Sp <<= __w0_ + 1;
        else
            _Sp = 0;
        _Sp += __u & __mask1_;
    }
    return _Sp;
}

// uniform_int_distribution

template<class _IntType = int>
class uniform_int_distribution
{
public:
    // types
    typedef _IntType result_type;

    class param_type
    {
        result_type __a_;
        result_type __b_;
    public:
        typedef uniform_int_distribution distribution_type;

        explicit param_type(result_type __a = 0,
                            result_type __b = numeric_limits<result_type>::max())
            : __a_(__a), __b_(__b) {}

        result_type a() const {return __a_;}
        result_type b() const {return __b_;}

        friend bool operator==(const param_type& __x, const param_type& __y)
            {return __x.__a_ == __y.__a_ && __x.__b_ == __y.__b_;}
        friend bool operator!=(const param_type& __x, const param_type& __y)
            {return !(__x == __y);}
    };

private:
    param_type __p_;

public:
    // constructors and reset functions
    explicit uniform_int_distribution(result_type __a = 0,
                                      result_type __b = numeric_limits<result_type>::max())
        : __p_(param_type(__a, __b)) {}
    explicit uniform_int_distribution(const param_type& __p) : __p_(__p) {}
    void reset() {}

    // generating functions
    template<class _URNG> result_type operator()(_URNG& __g)
        {return (*this)(__g, __p_);}
    template<class _URNG> result_type operator()(_URNG& __g, const param_type& __p);

    // property functions
    result_type a() const {return __p_.a();}
    result_type b() const {return __p_.b();}

    param_type param() const {return __p_;}
    void param(const param_type& __p) {__p_ = __p;}

    result_type min() const {return a();}
    result_type max() const {return b();}

    friend bool operator==(const uniform_int_distribution& __x,
                           const uniform_int_distribution& __y)
        {return __x.__p_ == __y.__p_;}
    friend bool operator!=(const uniform_int_distribution& __x,
                           const uniform_int_distribution& __y)
            {return !(__x == __y);}
};

template<class _IntType>
template<class _URNG>
typename uniform_int_distribution<_IntType>::result_type
uniform_int_distribution<_IntType>::operator()(_URNG& __g, const param_type& __p)
{
    typedef typename conditional<sizeof(result_type) <= sizeof(uint32_t),
                                            uint32_t, uint64_t>::type _UIntType;
    const _UIntType _Rp = __p.b() - __p.a() + _UIntType(1);
    if (_Rp == 1)
        return __p.a();
    const size_t _Dt = numeric_limits<_UIntType>::digits;
    typedef __independent_bits_engine<_URNG, _UIntType> _Eng;
    if (_Rp == 0)
        return static_cast<result_type>(_Eng(__g, _Dt)());
    size_t __w = _Dt - __clz(_Rp) - 1;
    if ((_Rp & (_UIntType(~0) >> (_Dt - __w))) != 0)
        ++__w;
    _Eng __e(__g, __w);
    _UIntType __u;
    do
    {
        __u = __e();
    } while (__u >= _Rp);
    return static_cast<result_type>(__u + __p.a());
}

class _LIBCPP_TYPE_VIS __rs_default;

_LIBCPP_FUNC_VIS __rs_default __rs_get();

class _LIBCPP_TYPE_VIS __rs_default
{
    static unsigned __c_;

    __rs_default();
public:
    typedef uint_fast32_t result_type;

    static const result_type _Min = 0;
    static const result_type _Max = 0xFFFFFFFF;

    __rs_default(const __rs_default&);
    ~__rs_default();

    result_type operator()();

    static _LIBCPP_CONSTEXPR result_type min() {return _Min;}
    static _LIBCPP_CONSTEXPR result_type max() {return _Max;}

    friend _LIBCPP_FUNC_VIS __rs_default __rs_get();
};

_LIBCPP_FUNC_VIS __rs_default __rs_get();

template <class _RandomAccessIterator>
void
random_shuffle(_RandomAccessIterator __first, _RandomAccessIterator __last)
{
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    typedef uniform_int_distribution<ptrdiff_t> _Dp;
    typedef typename _Dp::param_type _Pp;
    difference_type __d = __last - __first;
    if (__d > 1)
    {
        _Dp __uid;
        __rs_default __g = __rs_get();
        for (--__last, --__d; __first < __last; ++__first, --__d)
        {
            difference_type __i = __uid(__g, _Pp(0, __d));
            if (__i != difference_type(0))
                swap(*__first, *(__first + __i));
        }
    }
}

template <class _RandomAccessIterator, class _RandomNumberGenerator>
void
random_shuffle(_RandomAccessIterator __first, _RandomAccessIterator __last,
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
               _RandomNumberGenerator&& __rand)
#else
# 3033 "/usr/include/c++/v1/algorithm" 3
               _RandomNumberGenerator& __rand)
#endif
# 3035 "/usr/include/c++/v1/algorithm" 3
{
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    difference_type __d = __last - __first;
    if (__d > 1)
    {
        for (--__last; __first < __last; ++__first, --__d)
        {
            difference_type __i = __rand(__d);
            swap(*__first, *(__first + __i));
        }
    }
}

template<class _RandomAccessIterator, class _UniformRandomNumberGenerator>
    void shuffle(_RandomAccessIterator __first, _RandomAccessIterator __last,
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
                 _UniformRandomNumberGenerator&& __g)
#else
# 3053 "/usr/include/c++/v1/algorithm" 3
                 _UniformRandomNumberGenerator& __g)
#endif
# 3055 "/usr/include/c++/v1/algorithm" 3
{
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    typedef uniform_int_distribution<ptrdiff_t> _Dp;
    typedef typename _Dp::param_type _Pp;
    difference_type __d = __last - __first;
    if (__d > 1)
    {
        _Dp __uid;
        for (--__last, --__d; __first < __last; ++__first, --__d)
        {
            difference_type __i = __uid(__g, _Pp(0, __d));
            if (__i != difference_type(0))
                swap(*__first, *(__first + __i));
        }
    }
}

template <class _InputIterator, class _Predicate>
bool
is_partitioned(_InputIterator __first, _InputIterator __last, _Predicate __pred)
{
    for (; __first != __last; ++__first)
        if (!__pred(*__first))
            break;
    for (; __first != __last; ++__first)
        if (__pred(*__first))
            return false;
    return true;
}

// partition

template <class _Predicate, class _ForwardIterator>
_ForwardIterator
__partition(_ForwardIterator __first, _ForwardIterator __last, _Predicate __pred, forward_iterator_tag)
{
    while (true)
    {
        if (__first == __last)
            return __first;
        if (!__pred(*__first))
            break;
        ++__first;
    }
    for (_ForwardIterator __p = __first; ++__p != __last;)
    {
        if (__pred(*__p))
        {
            swap(*__first, *__p);
            ++__first;
        }
    }
    return __first;
}

template <class _Predicate, class _BidirectionalIterator>
_BidirectionalIterator
__partition(_BidirectionalIterator __first, _BidirectionalIterator __last, _Predicate __pred,
            bidirectional_iterator_tag)
{
    while (true)
    {
        while (true)
        {
            if (__first == __last)
                return __first;
            if (!__pred(*__first))
                break;
            ++__first;
        }
        do
        {
            if (__first == --__last)
                return __first;
        } while (!__pred(*__last));
        swap(*__first, *__last);
        ++__first;
    }
}

template <class _ForwardIterator, class _Predicate>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
partition(_ForwardIterator __first, _ForwardIterator __last, _Predicate __pred)
{
    return _VSTD::__partition<typename add_lvalue_reference<_Predicate>::type>
                            (__first, __last, __pred, typename iterator_traits<_ForwardIterator>::iterator_category());
}

// partition_copy

template <class _InputIterator, class _OutputIterator1,
          class _OutputIterator2, class _Predicate>
pair<_OutputIterator1, _OutputIterator2>
partition_copy(_InputIterator __first, _InputIterator __last,
               _OutputIterator1 __out_true, _OutputIterator2 __out_false,
               _Predicate __pred)
{
    for (; __first != __last; ++__first)
    {
        if (__pred(*__first))
        {
            *__out_true = *__first;
            ++__out_true;
        }
        else
        {
            *__out_false = *__first;
            ++__out_false;
        }
    }
    return pair<_OutputIterator1, _OutputIterator2>(__out_true, __out_false);
}

// partition_point

template<class _ForwardIterator, class _Predicate>
_ForwardIterator
partition_point(_ForwardIterator __first, _ForwardIterator __last, _Predicate __pred)
{
    typedef typename iterator_traits<_ForwardIterator>::difference_type difference_type;
    difference_type __len = _VSTD::distance(__first, __last);
    while (__len != 0)
    {
        difference_type __l2 = __len / 2;
        _ForwardIterator __m = __first;
        _VSTD::advance(__m, __l2);
        if (__pred(*__m))
        {
            __first = ++__m;
            __len -= __l2 + 1;
        }
        else
            __len = __l2;
    }
    return __first;
}

// stable_partition

template <class _Predicate, class _ForwardIterator, class _Distance, class _Pair>
_ForwardIterator
__stable_partition(_ForwardIterator __first, _ForwardIterator __last, _Predicate __pred,
                   _Distance __len, _Pair __p, forward_iterator_tag __fit)
{
    // *__first is known to be false
    // __len >= 1
    if (__len == 1)
        return __first;
    if (__len == 2)
    {
        _ForwardIterator __m = __first;
        if (__pred(*++__m))
        {
            swap(*__first, *__m);
            return __m;
        }
        return __first;
    }
    if (__len <= __p.second)
    {   // The buffer is big enough to use
        typedef typename iterator_traits<_ForwardIterator>::value_type value_type;
        __destruct_n __d(0);
        unique_ptr<value_type, __destruct_n&> __h(__p.first, __d);
        // Move the falses into the temporary buffer, and the trues to the front of the line
        // Update __first to always point to the end of the trues
        value_type* __t = __p.first;
        ::new(__t) value_type(_VSTD::move(*__first));
        __d.__incr((value_type*)0);
        ++__t;
        _ForwardIterator __i = __first;
        while (++__i != __last)
        {
            if (__pred(*__i))
            {
                *__first = _VSTD::move(*__i);
                ++__first;
            }
            else
            {
                ::new(__t) value_type(_VSTD::move(*__i));
                __d.__incr((value_type*)0);
                ++__t;
            }
        }
        // All trues now at start of range, all falses in buffer
        // Move falses back into range, but don't mess up __first which points to first false
        __i = __first;
        for (value_type* __t2 = __p.first; __t2 < __t; ++__t2, ++__i)
            *__i = _VSTD::move(*__t2);
        // __h destructs moved-from values out of the temp buffer, but doesn't deallocate buffer
        return __first;
    }
    // Else not enough buffer, do in place
    // __len >= 3
    _ForwardIterator __m = __first;
    _Distance __len2 = __len / 2;  // __len2 >= 2
    _VSTD::advance(__m, __len2);
    // recurse on [__first, __m), *__first know to be false
    // F?????????????????
    // f       m         l
    typedef typename add_lvalue_reference<_Predicate>::type _PredRef;
    _ForwardIterator __first_false = __stable_partition<_PredRef>(__first, __m, __pred, __len2, __p, __fit);
    // TTTFFFFF??????????
    // f  ff   m         l
    // recurse on [__m, __last], except increase __m until *(__m) is false, *__last know to be true
    _ForwardIterator __m1 = __m;
    _ForwardIterator __second_false = __last;
    _Distance __len_half = __len - __len2;
    while (__pred(*__m1))
    {
        if (++__m1 == __last)
            goto __second_half_done;
        --__len_half;
    }
    // TTTFFFFFTTTF??????
    // f  ff   m  m1     l
    __second_false = __stable_partition<_PredRef>(__m1, __last, __pred, __len_half, __p, __fit);
__second_half_done:
    // TTTFFFFFTTTTTFFFFF
    // f  ff   m    sf   l
    return _VSTD::rotate(__first_false, __m, __second_false);
    // TTTTTTTTFFFFFFFFFF
    //         |
}

struct __return_temporary_buffer
{
    template <class _Tp>
    _LIBCPP_INLINE_VISIBILITY void operator()(_Tp* __p) const {_VSTD::return_temporary_buffer(__p);}
};

template <class _Predicate, class _ForwardIterator>
_ForwardIterator
__stable_partition(_ForwardIterator __first, _ForwardIterator __last, _Predicate __pred,
                   forward_iterator_tag)
{
    const unsigned __alloc_limit = 3;  // might want to make this a function of trivial assignment
    // Either prove all true and return __first or point to first false
    while (true)
    {
        if (__first == __last)
            return __first;
        if (!__pred(*__first))
            break;
        ++__first;
    }
    // We now have a reduced range [__first, __last)
    // *__first is known to be false
    typedef typename iterator_traits<_ForwardIterator>::difference_type difference_type;
    typedef typename iterator_traits<_ForwardIterator>::value_type value_type;
    difference_type __len = _VSTD::distance(__first, __last);
    pair<value_type*, ptrdiff_t> __p(0, 0);
    unique_ptr<value_type, __return_temporary_buffer> __h;
    if (__len >= __alloc_limit)
    {
        __p = _VSTD::get_temporary_buffer<value_type>(__len);
        __h.reset(__p.first);
    }
    return __stable_partition<typename add_lvalue_reference<_Predicate>::type>
                             (__first, __last, __pred, __len, __p, forward_iterator_tag());
}

template <class _Predicate, class _BidirectionalIterator, class _Distance, class _Pair>
_BidirectionalIterator
__stable_partition(_BidirectionalIterator __first, _BidirectionalIterator __last, _Predicate __pred,
                   _Distance __len, _Pair __p, bidirectional_iterator_tag __bit)
{
    // *__first is known to be false
    // *__last is known to be true
    // __len >= 2
    if (__len == 2)
    {
        swap(*__first, *__last);
        return __last;
    }
    if (__len == 3)
    {
        _BidirectionalIterator __m = __first;
        if (__pred(*++__m))
        {
            swap(*__first, *__m);
            swap(*__m, *__last);
            return __last;
        }
        swap(*__m, *__last);
        swap(*__first, *__m);
        return __m;
    }
    if (__len <= __p.second)
    {   // The buffer is big enough to use
        typedef typename iterator_traits<_BidirectionalIterator>::value_type value_type;
        __destruct_n __d(0);
        unique_ptr<value_type, __destruct_n&> __h(__p.first, __d);
        // Move the falses into the temporary buffer, and the trues to the front of the line
        // Update __first to always point to the end of the trues
        value_type* __t = __p.first;
        ::new(__t) value_type(_VSTD::move(*__first));
        __d.__incr((value_type*)0);
        ++__t;
        _BidirectionalIterator __i = __first;
        while (++__i != __last)
        {
            if (__pred(*__i))
            {
                *__first = _VSTD::move(*__i);
                ++__first;
            }
            else
            {
                ::new(__t) value_type(_VSTD::move(*__i));
                __d.__incr((value_type*)0);
                ++__t;
            }
        }
        // move *__last, known to be true
        *__first = _VSTD::move(*__i);
        __i = ++__first;
        // All trues now at start of range, all falses in buffer
        // Move falses back into range, but don't mess up __first which points to first false
        for (value_type* __t2 = __p.first; __t2 < __t; ++__t2, ++__i)
            *__i = _VSTD::move(*__t2);
        // __h destructs moved-from values out of the temp buffer, but doesn't deallocate buffer
        return __first;
    }
    // Else not enough buffer, do in place
    // __len >= 4
    _BidirectionalIterator __m = __first;
    _Distance __len2 = __len / 2;  // __len2 >= 2
    _VSTD::advance(__m, __len2);
    // recurse on [__first, __m-1], except reduce __m-1 until *(__m-1) is true, *__first know to be false
    // F????????????????T
    // f       m        l
    _BidirectionalIterator __m1 = __m;
    _BidirectionalIterator __first_false = __first;
    _Distance __len_half = __len2;
    while (!__pred(*--__m1))
    {
        if (__m1 == __first)
            goto __first_half_done;
        --__len_half;
    }
    // F???TFFF?????????T
    // f   m1  m        l
    typedef typename add_lvalue_reference<_Predicate>::type _PredRef;
    __first_false = __stable_partition<_PredRef>(__first, __m1, __pred, __len_half, __p, __bit);
__first_half_done:
    // TTTFFFFF?????????T
    // f  ff   m        l
    // recurse on [__m, __last], except increase __m until *(__m) is false, *__last know to be true
    __m1 = __m;
    _BidirectionalIterator __second_false = __last;
    ++__second_false;
    __len_half = __len - __len2;
    while (__pred(*__m1))
    {
        if (++__m1 == __last)
            goto __second_half_done;
        --__len_half;
    }
    // TTTFFFFFTTTF?????T
    // f  ff   m  m1    l
    __second_false = __stable_partition<_PredRef>(__m1, __last, __pred, __len_half, __p, __bit);
__second_half_done:
    // TTTFFFFFTTTTTFFFFF
    // f  ff   m    sf  l
    return _VSTD::rotate(__first_false, __m, __second_false);
    // TTTTTTTTFFFFFFFFFF
    //         |
}

template <class _Predicate, class _BidirectionalIterator>
_BidirectionalIterator
__stable_partition(_BidirectionalIterator __first, _BidirectionalIterator __last, _Predicate __pred,
                   bidirectional_iterator_tag)
{
    typedef typename iterator_traits<_BidirectionalIterator>::difference_type difference_type;
    typedef typename iterator_traits<_BidirectionalIterator>::value_type value_type;
    const difference_type __alloc_limit = 4;  // might want to make this a function of trivial assignment
    // Either prove all true and return __first or point to first false
    while (true)
    {
        if (__first == __last)
            return __first;
        if (!__pred(*__first))
            break;
        ++__first;
    }
    // __first points to first false, everything prior to __first is already set.
    // Either prove [__first, __last) is all false and return __first, or point __last to last true
    do
    {
        if (__first == --__last)
            return __first;
    } while (!__pred(*__last));
    // We now have a reduced range [__first, __last]
    // *__first is known to be false
    // *__last is known to be true
    // __len >= 2
    difference_type __len = _VSTD::distance(__first, __last) + 1;
    pair<value_type*, ptrdiff_t> __p(0, 0);
    unique_ptr<value_type, __return_temporary_buffer> __h;
    if (__len >= __alloc_limit)
    {
        __p = _VSTD::get_temporary_buffer<value_type>(__len);
        __h.reset(__p.first);
    }
    return __stable_partition<typename add_lvalue_reference<_Predicate>::type>
                             (__first, __last, __pred, __len, __p, bidirectional_iterator_tag());
}

template <class _ForwardIterator, class _Predicate>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
stable_partition(_ForwardIterator __first, _ForwardIterator __last, _Predicate __pred)
{
    return __stable_partition<typename add_lvalue_reference<_Predicate>::type>
                             (__first, __last, __pred, typename iterator_traits<_ForwardIterator>::iterator_category());
}

// is_sorted_until

template <class _ForwardIterator, class _Compare>
_ForwardIterator
is_sorted_until(_ForwardIterator __first, _ForwardIterator __last, _Compare __comp)
{
    if (__first != __last)
    {
        _ForwardIterator __i = __first;
        while (++__i != __last)
        {
            if (__comp(*__i, *__first))
                return __i;
            __first = __i;
        }
    }
    return __last;
}

template<class _ForwardIterator>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
is_sorted_until(_ForwardIterator __first, _ForwardIterator __last)
{
    return _VSTD::is_sorted_until(__first, __last, __less<typename iterator_traits<_ForwardIterator>::value_type>());
}

// is_sorted

template <class _ForwardIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
bool
is_sorted(_ForwardIterator __first, _ForwardIterator __last, _Compare __comp)
{
    return _VSTD::is_sorted_until(__first, __last, __comp) == __last;
}

template<class _ForwardIterator>
inline _LIBCPP_INLINE_VISIBILITY
bool
is_sorted(_ForwardIterator __first, _ForwardIterator __last)
{
    return _VSTD::is_sorted(__first, __last, __less<typename iterator_traits<_ForwardIterator>::value_type>());
}

// sort

// stable, 2-3 compares, 0-2 swaps

template <class _Compare, class _ForwardIterator>
unsigned
__sort3(_ForwardIterator __x, _ForwardIterator __y, _ForwardIterator __z, _Compare __c)
{
    unsigned __r = 0;
    if (!__c(*__y, *__x))          // if x <= y
    {
        if (!__c(*__z, *__y))      // if y <= z
            return __r;            // x <= y && y <= z
                                   // x <= y && y > z
        swap(*__y, *__z);          // x <= z && y < z
        __r = 1;
        if (__c(*__y, *__x))       // if x > y
        {
            swap(*__x, *__y);      // x < y && y <= z
            __r = 2;
        }
        return __r;                // x <= y && y < z
    }
    if (__c(*__z, *__y))           // x > y, if y > z
    {
        swap(*__x, *__z);          // x < y && y < z
        __r = 1;
        return __r;
    }
    swap(*__x, *__y);              // x > y && y <= z
    __r = 1;                       // x < y && x <= z
    if (__c(*__z, *__y))           // if y > z
    {
        swap(*__y, *__z);          // x <= y && y < z
        __r = 2;
    }
    return __r;
}                                  // x <= y && y <= z

// stable, 3-6 compares, 0-5 swaps

template <class _Compare, class _ForwardIterator>
unsigned
__sort4(_ForwardIterator __x1, _ForwardIterator __x2, _ForwardIterator __x3,
            _ForwardIterator __x4, _Compare __c)
{
    unsigned __r = __sort3<_Compare>(__x1, __x2, __x3, __c);
    if (__c(*__x4, *__x3))
    {
        swap(*__x3, *__x4);
        ++__r;
        if (__c(*__x3, *__x2))
        {
            swap(*__x2, *__x3);
            ++__r;
            if (__c(*__x2, *__x1))
            {
                swap(*__x1, *__x2);
                ++__r;
            }
        }
    }
    return __r;
}

// stable, 4-10 compares, 0-9 swaps

template <class _Compare, class _ForwardIterator>
unsigned
__sort5(_ForwardIterator __x1, _ForwardIterator __x2, _ForwardIterator __x3,
            _ForwardIterator __x4, _ForwardIterator __x5, _Compare __c)
{
    unsigned __r = __sort4<_Compare>(__x1, __x2, __x3, __x4, __c);
    if (__c(*__x5, *__x4))
    {
        swap(*__x4, *__x5);
        ++__r;
        if (__c(*__x4, *__x3))
        {
            swap(*__x3, *__x4);
            ++__r;
            if (__c(*__x3, *__x2))
            {
                swap(*__x2, *__x3);
                ++__r;
                if (__c(*__x2, *__x1))
                {
                    swap(*__x1, *__x2);
                    ++__r;
                }
            }
        }
    }
    return __r;
}

// Assumes size > 0
template <class _Compare, class _BirdirectionalIterator>
void
__selection_sort(_BirdirectionalIterator __first, _BirdirectionalIterator __last, _Compare __comp)
{
    _BirdirectionalIterator __lm1 = __last;
    for (--__lm1; __first != __lm1; ++__first)
    {
        _BirdirectionalIterator __i = _VSTD::min_element<_BirdirectionalIterator,
                                                        typename add_lvalue_reference<_Compare>::type>
                                                       (__first, __last, __comp);
        if (__i != __first)
            swap(*__first, *__i);
    }
}

template <class _Compare, class _BirdirectionalIterator>
void
__insertion_sort(_BirdirectionalIterator __first, _BirdirectionalIterator __last, _Compare __comp)
{
    typedef typename iterator_traits<_BirdirectionalIterator>::value_type value_type;
    if (__first != __last)
    {
        _BirdirectionalIterator __i = __first;
        for (++__i; __i != __last; ++__i)
        {
            _BirdirectionalIterator __j = __i;
            value_type __t(_VSTD::move(*__j));
            for (_BirdirectionalIterator __k = __i; __k != __first && __comp(__t,  *--__k); --__j)
                *__j = _VSTD::move(*__k);
            *__j = _VSTD::move(__t);
        }
    }
}

template <class _Compare, class _RandomAccessIterator>
void
__insertion_sort_3(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
    typedef typename iterator_traits<_RandomAccessIterator>::value_type value_type;
    _RandomAccessIterator __j = __first+2;
    __sort3<_Compare>(__first, __first+1, __j, __comp);
    for (_RandomAccessIterator __i = __j+1; __i != __last; ++__i)
    {
        if (__comp(*__i, *__j))
        {
            value_type __t(_VSTD::move(*__i));
            _RandomAccessIterator __k = __j;
            __j = __i;
            do
            {
                *__j = _VSTD::move(*__k);
                __j = __k;
            } while (__j != __first && __comp(__t, *--__k));
            *__j = _VSTD::move(__t);
        }
        __j = __i;
    }
}

template <class _Compare, class _RandomAccessIterator>
bool
__insertion_sort_incomplete(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
    switch (__last - __first)
    {
    case 0:
    case 1:
        return true;
    case 2:
        if (__comp(*--__last, *__first))
            swap(*__first, *__last);
        return true;
    case 3:
        _VSTD::__sort3<_Compare>(__first, __first+1, --__last, __comp);
        return true;
    case 4:
        _VSTD::__sort4<_Compare>(__first, __first+1, __first+2, --__last, __comp);
        return true;
    case 5:
        _VSTD::__sort5<_Compare>(__first, __first+1, __first+2, __first+3, --__last, __comp);
        return true;
    }
    typedef typename iterator_traits<_RandomAccessIterator>::value_type value_type;
    _RandomAccessIterator __j = __first+2;
    __sort3<_Compare>(__first, __first+1, __j, __comp);
    const unsigned __limit = 8;
    unsigned __count = 0;
    for (_RandomAccessIterator __i = __j+1; __i != __last; ++__i)
    {
        if (__comp(*__i, *__j))
        {
            value_type __t(_VSTD::move(*__i));
            _RandomAccessIterator __k = __j;
            __j = __i;
            do
            {
                *__j = _VSTD::move(*__k);
                __j = __k;
            } while (__j != __first && __comp(__t, *--__k));
            *__j = _VSTD::move(__t);
            if (++__count == __limit)
                return ++__i == __last;
        }
        __j = __i;
    }
    return true;
}

template <class _Compare, class _BirdirectionalIterator>
void
__insertion_sort_move(_BirdirectionalIterator __first1, _BirdirectionalIterator __last1,
                      typename iterator_traits<_BirdirectionalIterator>::value_type* __first2, _Compare __comp)
{
    typedef typename iterator_traits<_BirdirectionalIterator>::value_type value_type;
    if (__first1 != __last1)
    {
        __destruct_n __d(0);
        unique_ptr<value_type, __destruct_n&> __h(__first2, __d);
        value_type* __last2 = __first2;
        ::new(__last2) value_type(_VSTD::move(*__first1));
        __d.__incr((value_type*)0);
        for (++__last2; ++__first1 != __last1; ++__last2)
        {
            value_type* __j2 = __last2;
            value_type* __i2 = __j2;
            if (__comp(*__first1, *--__i2))
            {
                ::new(__j2) value_type(_VSTD::move(*__i2));
                __d.__incr((value_type*)0);
                for (--__j2; __i2 != __first2 && __comp(*__first1,  *--__i2); --__j2)
                    *__j2 = _VSTD::move(*__i2);
                *__j2 = _VSTD::move(*__first1);
            }
            else
            {
                ::new(__j2) value_type(_VSTD::move(*__first1));
                __d.__incr((value_type*)0);
            }
        }
        __h.release();
    }
}

template <class _Compare, class _RandomAccessIterator>
void
__sort(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
    // _Compare is known to be a reference type
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    typedef typename iterator_traits<_RandomAccessIterator>::value_type value_type;
    const difference_type __limit = is_trivially_copy_constructible<value_type>::value &&
                                    is_trivially_copy_assignable<value_type>::value ? 30 : 6;
    while (true)
    {
    __restart:
        difference_type __len = __last - __first;
        switch (__len)
        {
        case 0:
        case 1:
            return;
        case 2:
            if (__comp(*--__last, *__first))
                swap(*__first, *__last);
            return;
        case 3:
            _VSTD::__sort3<_Compare>(__first, __first+1, --__last, __comp);
            return;
        case 4:
            _VSTD::__sort4<_Compare>(__first, __first+1, __first+2, --__last, __comp);
            return;
        case 5:
            _VSTD::__sort5<_Compare>(__first, __first+1, __first+2, __first+3, --__last, __comp);
            return;
        }
        if (__len <= __limit)
        {
            _VSTD::__insertion_sort_3<_Compare>(__first, __last, __comp);
            return;
        }
        // __len > 5
        _RandomAccessIterator __m = __first;
        _RandomAccessIterator __lm1 = __last;
        --__lm1;
        unsigned __n_swaps;
        {
        difference_type __delta;
        if (__len >= 1000)
        {
            __delta = __len/2;
            __m += __delta;
            __delta /= 2;
            __n_swaps = _VSTD::__sort5<_Compare>(__first, __first + __delta, __m, __m+__delta, __lm1, __comp);
        }
        else
        {
            __delta = __len/2;
            __m += __delta;
            __n_swaps = _VSTD::__sort3<_Compare>(__first, __m, __lm1, __comp);
        }
        }
        // *__m is median
        // partition [__first, __m) < *__m and *__m <= [__m, __last)
        // (this inhibits tossing elements equivalent to __m around unnecessarily)
        _RandomAccessIterator __i = __first;
        _RandomAccessIterator __j = __lm1;
        // j points beyond range to be tested, *__m is known to be <= *__lm1
        // The search going up is known to be guarded but the search coming down isn't.
        // Prime the downward search with a guard.
        if (!__comp(*__i, *__m))  // if *__first == *__m
        {
            // *__first == *__m, *__first doesn't go in first part
            // manually guard downward moving __j against __i
            while (true)
            {
                if (__i == --__j)
                {
                    // *__first == *__m, *__m <= all other elements
                    // Parition instead into [__first, __i) == *__first and *__first < [__i, __last)
                    ++__i;  // __first + 1
                    __j = __last;
                    if (!__comp(*__first, *--__j))  // we need a guard if *__first == *(__last-1)
                    {
                        while (true)
                        {
                            if (__i == __j)
                                return;  // [__first, __last) all equivalent elements
                            if (__comp(*__first, *__i))
                            {
                                swap(*__i, *__j);
                                ++__n_swaps;
                                ++__i;
                                break;
                            }
                            ++__i;
                        }
                    }
                    // [__first, __i) == *__first and *__first < [__j, __last) and __j == __last - 1
                    if (__i == __j)
                        return;
                    while (true)
                    {
                        while (!__comp(*__first, *__i))
                            ++__i;
                        while (__comp(*__first, *--__j))
                            ;
                        if (__i >= __j)
                            break;
                        swap(*__i, *__j);
                        ++__n_swaps;
                        ++__i;
                    }
                    // [__first, __i) == *__first and *__first < [__i, __last)
                    // The first part is sorted, sort the secod part
                    // _VSTD::__sort<_Compare>(__i, __last, __comp);
                    __first = __i;
                    goto __restart;
                }
                if (__comp(*__j, *__m))
                {
                    swap(*__i, *__j);
                    ++__n_swaps;
                    break;  // found guard for downward moving __j, now use unguarded partition
                }
            }
        }
        // It is known that *__i < *__m
        ++__i;
        // j points beyond range to be tested, *__m is known to be <= *__lm1
        // if not yet partitioned...
        if (__i < __j)
        {
            // known that *(__i - 1) < *__m
            // known that __i <= __m
            while (true)
            {
                // __m still guards upward moving __i
                while (__comp(*__i, *__m))
                    ++__i;
                // It is now known that a guard exists for downward moving __j
                while (!__comp(*--__j, *__m))
                    ;
                if (__i > __j)
                    break;
                swap(*__i, *__j);
                ++__n_swaps;
                // It is known that __m != __j
                // If __m just moved, follow it
                if (__m == __i)
                    __m = __j;
                ++__i;
            }
        }
        // [__first, __i) < *__m and *__m <= [__i, __last)
        if (__i != __m && __comp(*__m, *__i))
        {
            swap(*__i, *__m);
            ++__n_swaps;
        }
        // [__first, __i) < *__i and *__i <= [__i+1, __last)
        // If we were given a perfect partition, see if insertion sort is quick...
        if (__n_swaps == 0)
        {
            bool __fs = _VSTD::__insertion_sort_incomplete<_Compare>(__first, __i, __comp);
            if (_VSTD::__insertion_sort_incomplete<_Compare>(__i+1, __last, __comp))
            {
                if (__fs)
                    return;
                __last = __i;
                continue;
            }
            else
            {
                if (__fs)
                {
                    __first = ++__i;
                    continue;
                }
            }
        }
        // sort smaller range with recursive call and larger with tail recursion elimination
        if (__i - __first < __last - __i)
        {
            _VSTD::__sort<_Compare>(__first, __i, __comp);
            // _VSTD::__sort<_Compare>(__i+1, __last, __comp);
            __first = ++__i;
        }
        else
        {
            _VSTD::__sort<_Compare>(__i+1, __last, __comp);
            // _VSTD::__sort<_Compare>(__first, __i, __comp);
            __last = __i;
        }
    }
}

// This forwarder keeps the top call and the recursive calls using the same instantiation, forcing a reference _Compare
template <class _RandomAccessIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
void
sort(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    __sort<_Comp_ref>(__first, __last, __c);
#else  // _LIBCPP_DEBUG
# 3964 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    __sort<_Comp_ref>(__first, __last, __comp);
#endif  // _LIBCPP_DEBUG
# 3967 "/usr/include/c++/v1/algorithm" 3
}

template <class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
sort(_RandomAccessIterator __first, _RandomAccessIterator __last)
{
    _VSTD::sort(__first, __last, __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void
sort(_Tp** __first, _Tp** __last)
{
    _VSTD::sort((size_t*)__first, (size_t*)__last, __less<size_t>());
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
void
sort(__wrap_iter<_Tp*> __first, __wrap_iter<_Tp*> __last)
{
    _VSTD::sort(__first.base(), __last.base());
}

template <class _Tp, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
void
sort(__wrap_iter<_Tp*> __first, __wrap_iter<_Tp*> __last, _Compare __comp)
{
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    _VSTD::sort<_Tp*, _Comp_ref>(__first.base(), __last.base(), __comp);
}

#ifdef _LIBCPP_MSVC
#pragma warning( push )
#pragma warning( disable: 4231)
#endif // _LIBCPP_MSVC
# 4006 "/usr/include/c++/v1/algorithm" 3
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<char>&, char*>(char*, char*, __less<char>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<wchar_t>&, wchar_t*>(wchar_t*, wchar_t*, __less<wchar_t>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<signed char>&, signed char*>(signed char*, signed char*, __less<signed char>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<unsigned char>&, unsigned char*>(unsigned char*, unsigned char*, __less<unsigned char>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<short>&, short*>(short*, short*, __less<short>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<unsigned short>&, unsigned short*>(unsigned short*, unsigned short*, __less<unsigned short>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<int>&, int*>(int*, int*, __less<int>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<unsigned>&, unsigned*>(unsigned*, unsigned*, __less<unsigned>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<long>&, long*>(long*, long*, __less<long>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<unsigned long>&, unsigned long*>(unsigned long*, unsigned long*, __less<unsigned long>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<long long>&, long long*>(long long*, long long*, __less<long long>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<unsigned long long>&, unsigned long long*>(unsigned long long*, unsigned long long*, __less<unsigned long long>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<float>&, float*>(float*, float*, __less<float>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<double>&, double*>(double*, double*, __less<double>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS void __sort<__less<long double>&, long double*>(long double*, long double*, __less<long double>&))

_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<char>&, char*>(char*, char*, __less<char>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<wchar_t>&, wchar_t*>(wchar_t*, wchar_t*, __less<wchar_t>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<signed char>&, signed char*>(signed char*, signed char*, __less<signed char>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<unsigned char>&, unsigned char*>(unsigned char*, unsigned char*, __less<unsigned char>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<short>&, short*>(short*, short*, __less<short>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<unsigned short>&, unsigned short*>(unsigned short*, unsigned short*, __less<unsigned short>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<int>&, int*>(int*, int*, __less<int>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<unsigned>&, unsigned*>(unsigned*, unsigned*, __less<unsigned>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<long>&, long*>(long*, long*, __less<long>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<unsigned long>&, unsigned long*>(unsigned long*, unsigned long*, __less<unsigned long>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<long long>&, long long*>(long long*, long long*, __less<long long>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<unsigned long long>&, unsigned long long*>(unsigned long long*, unsigned long long*, __less<unsigned long long>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<float>&, float*>(float*, float*, __less<float>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<double>&, double*>(double*, double*, __less<double>&))
_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS bool __insertion_sort_incomplete<__less<long double>&, long double*>(long double*, long double*, __less<long double>&))

_LIBCPP_EXTERN_TEMPLATE(_LIBCPP_FUNC_VIS unsigned __sort5<__less<long double>&, long double*>(long double*, long double*, long double*, long double*, long double*, __less<long double>&))
#ifdef _LIBCPP_MSVC
#pragma warning( pop )
#endif  // _LIBCPP_MSVC
# 4042 "/usr/include/c++/v1/algorithm" 3

// lower_bound

template <class _Compare, class _ForwardIterator, class _Tp>
_ForwardIterator
__lower_bound(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_, _Compare __comp)
{
    typedef typename iterator_traits<_ForwardIterator>::difference_type difference_type;
    difference_type __len = _VSTD::distance(__first, __last);
    while (__len != 0)
    {
        difference_type __l2 = __len / 2;
        _ForwardIterator __m = __first;
        _VSTD::advance(__m, __l2);
        if (__comp(*__m, __value_))
        {
            __first = ++__m;
            __len -= __l2 + 1;
        }
        else
            __len = __l2;
    }
    return __first;
}

template <class _ForwardIterator, class _Tp, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
lower_bound(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_, _Compare __comp)
{
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    return __lower_bound<_Comp_ref>(__first, __last, __value_, __c);
#else  // _LIBCPP_DEBUG
# 4077 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    return __lower_bound<_Comp_ref>(__first, __last, __value_, __comp);
#endif  // _LIBCPP_DEBUG
# 4080 "/usr/include/c++/v1/algorithm" 3
}

template <class _ForwardIterator, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
lower_bound(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_)
{
    return _VSTD::lower_bound(__first, __last, __value_,
                             __less<typename iterator_traits<_ForwardIterator>::value_type, _Tp>());
}

// upper_bound

template <class _Compare, class _ForwardIterator, class _Tp>
_ForwardIterator
__upper_bound(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_, _Compare __comp)
{
    typedef typename iterator_traits<_ForwardIterator>::difference_type difference_type;
    difference_type __len = _VSTD::distance(__first, __last);
    while (__len != 0)
    {
        difference_type __l2 = __len / 2;
        _ForwardIterator __m = __first;
        _VSTD::advance(__m, __l2);
        if (__comp(__value_, *__m))
            __len = __l2;
        else
        {
            __first = ++__m;
            __len -= __l2 + 1;
        }
    }
    return __first;
}

template <class _ForwardIterator, class _Tp, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
upper_bound(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_, _Compare __comp)
{
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    return __upper_bound<_Comp_ref>(__first, __last, __value_, __c);
#else  // _LIBCPP_DEBUG
# 4125 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    return __upper_bound<_Comp_ref>(__first, __last, __value_, __comp);
#endif  // _LIBCPP_DEBUG
# 4128 "/usr/include/c++/v1/algorithm" 3
}

template <class _ForwardIterator, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
_ForwardIterator
upper_bound(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_)
{
    return _VSTD::upper_bound(__first, __last, __value_,
                             __less<_Tp, typename iterator_traits<_ForwardIterator>::value_type>());
}

// equal_range

template <class _Compare, class _ForwardIterator, class _Tp>
pair<_ForwardIterator, _ForwardIterator>
__equal_range(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_, _Compare __comp)
{
    typedef typename iterator_traits<_ForwardIterator>::difference_type difference_type;
    difference_type __len = _VSTD::distance(__first, __last);
    while (__len != 0)
    {
        difference_type __l2 = __len / 2;
        _ForwardIterator __m = __first;
        _VSTD::advance(__m, __l2);
        if (__comp(*__m, __value_))
        {
            __first = ++__m;
            __len -= __l2 + 1;
        }
        else if (__comp(__value_, *__m))
        {
            __last = __m;
            __len = __l2;
        }
        else
        {
            _ForwardIterator __mp1 = __m;
            return pair<_ForwardIterator, _ForwardIterator>
                   (
                      __lower_bound<_Compare>(__first, __m, __value_, __comp),
                      __upper_bound<_Compare>(++__mp1, __last, __value_, __comp)
                   );
        }
    }
    return pair<_ForwardIterator, _ForwardIterator>(__first, __first);
}

template <class _ForwardIterator, class _Tp, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
pair<_ForwardIterator, _ForwardIterator>
equal_range(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_, _Compare __comp)
{
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    return __equal_range<_Comp_ref>(__first, __last, __value_, __c);
#else  // _LIBCPP_DEBUG
# 4185 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    return __equal_range<_Comp_ref>(__first, __last, __value_, __comp);
#endif  // _LIBCPP_DEBUG
# 4188 "/usr/include/c++/v1/algorithm" 3
}

template <class _ForwardIterator, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
pair<_ForwardIterator, _ForwardIterator>
equal_range(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_)
{
    return _VSTD::equal_range(__first, __last, __value_,
                             __less<typename iterator_traits<_ForwardIterator>::value_type, _Tp>());
}

// binary_search

template <class _Compare, class _ForwardIterator, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
__binary_search(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_, _Compare __comp)
{
    __first = __lower_bound<_Compare>(__first, __last, __value_, __comp);
    return __first != __last && !__comp(__value_, *__first);
}

template <class _ForwardIterator, class _Tp, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
bool
binary_search(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_, _Compare __comp)
{
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    return __binary_search<_Comp_ref>(__first, __last, __value_, __c);
#else  // _LIBCPP_DEBUG
# 4220 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    return __binary_search<_Comp_ref>(__first, __last, __value_, __comp);
#endif  // _LIBCPP_DEBUG
# 4223 "/usr/include/c++/v1/algorithm" 3
}

template <class _ForwardIterator, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
bool
binary_search(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __value_)
{
    return _VSTD::binary_search(__first, __last, __value_,
                             __less<typename iterator_traits<_ForwardIterator>::value_type, _Tp>());
}

// merge

template <class _Compare, class _InputIterator1, class _InputIterator2, class _OutputIterator>
_OutputIterator
__merge(_InputIterator1 __first1, _InputIterator1 __last1,
        _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result, _Compare __comp)
{
    for (; __first1 != __last1; ++__result)
    {
        if (__first2 == __last2)
            return _VSTD::copy(__first1, __last1, __result);
        if (__comp(*__first2, *__first1))
        {
            *__result = *__first2;
            ++__first2;
        }
        else
        {
            *__result = *__first1;
            ++__first1;
        }
    }
    return _VSTD::copy(__first2, __last2, __result);
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
merge(_InputIterator1 __first1, _InputIterator1 __last1,
      _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result, _Compare __comp)
{
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    return _VSTD::__merge<_Comp_ref>(__first1, __last1, __first2, __last2, __result, __c);
#else  // _LIBCPP_DEBUG
# 4270 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    return _VSTD::__merge<_Comp_ref>(__first1, __last1, __first2, __last2, __result, __comp);
#endif  // _LIBCPP_DEBUG
# 4273 "/usr/include/c++/v1/algorithm" 3
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
merge(_InputIterator1 __first1, _InputIterator1 __last1,
      _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result)
{
    typedef typename iterator_traits<_InputIterator1>::value_type __v1;
    typedef typename iterator_traits<_InputIterator2>::value_type __v2;
    return merge(__first1, __last1, __first2, __last2, __result, __less<__v1, __v2>());
}

// inplace_merge

template <class _Compare, class _BidirectionalIterator>
void
__buffered_inplace_merge(_BidirectionalIterator __first, _BidirectionalIterator __middle, _BidirectionalIterator __last,
                _Compare __comp, typename iterator_traits<_BidirectionalIterator>::difference_type __len1,
                                 typename iterator_traits<_BidirectionalIterator>::difference_type __len2,
                typename iterator_traits<_BidirectionalIterator>::value_type* __buff)
{
    typedef typename iterator_traits<_BidirectionalIterator>::value_type value_type;
    typedef typename iterator_traits<_BidirectionalIterator>::difference_type difference_type;
    typedef typename iterator_traits<_BidirectionalIterator>::pointer pointer;
    __destruct_n __d(0);
    unique_ptr<value_type, __destruct_n&> __h2(__buff, __d);
    if (__len1 <= __len2)
    {
        value_type* __p = __buff;
        for (_BidirectionalIterator __i = __first; __i != __middle; __d.__incr((value_type*)0), ++__i, ++__p)
            ::new(__p) value_type(_VSTD::move(*__i));
        __merge<_Compare>(move_iterator<value_type*>(__buff),
                          move_iterator<value_type*>(__p),
                          move_iterator<_BidirectionalIterator>(__middle),
                          move_iterator<_BidirectionalIterator>(__last),
                          __first, __comp);
    }
    else
    {
        value_type* __p = __buff;
        for (_BidirectionalIterator __i = __middle; __i != __last; __d.__incr((value_type*)0), ++__i, ++__p)
            ::new(__p) value_type(_VSTD::move(*__i));
        typedef reverse_iterator<_BidirectionalIterator> _RBi;
        typedef reverse_iterator<value_type*> _Rv;
        __merge(move_iterator<_RBi>(_RBi(__middle)), move_iterator<_RBi>(_RBi(__first)),
                move_iterator<_Rv>(_Rv(__p)), move_iterator<_Rv>(_Rv(__buff)),
                _RBi(__last), __negate<_Compare>(__comp));
    }
}

template <class _Compare, class _BidirectionalIterator>
void
__inplace_merge(_BidirectionalIterator __first, _BidirectionalIterator __middle, _BidirectionalIterator __last,
                _Compare __comp, typename iterator_traits<_BidirectionalIterator>::difference_type __len1,
                                 typename iterator_traits<_BidirectionalIterator>::difference_type __len2,
                typename iterator_traits<_BidirectionalIterator>::value_type* __buff, ptrdiff_t __buff_size)
{
    typedef typename iterator_traits<_BidirectionalIterator>::value_type value_type;
    typedef typename iterator_traits<_BidirectionalIterator>::difference_type difference_type;
    while (true)
    {
        // if __middle == __last, we're done
        if (__len2 == 0)
            return;
        // shrink [__first, __middle) as much as possible (with no moves), returning if it shrinks to 0
        for (; true; ++__first, --__len1)
        {
            if (__len1 == 0)
                return;
            if (__comp(*__middle, *__first))
                break;
        }
        if (__len1 <= __buff_size || __len2 <= __buff_size)
        {
            __buffered_inplace_merge<_Compare>(__first, __middle, __last, __comp, __len1, __len2, __buff);
            return;
        }
        // __first < __middle < __last
        // *__first > *__middle
        // partition [__first, __m1) [__m1, __middle) [__middle, __m2) [__m2, __last) such that
        //     all elements in:
        //         [__first, __m1)  <= [__middle, __m2)
        //         [__middle, __m2) <  [__m1, __middle)
        //         [__m1, __middle) <= [__m2, __last)
        //     and __m1 or __m2 is in the middle of its range
        _BidirectionalIterator __m1;  // "median" of [__first, __middle)
        _BidirectionalIterator __m2;  // "median" of [__middle, __last)
        difference_type __len11;      // distance(__first, __m1)
        difference_type __len21;      // distance(__middle, __m2)
        // binary search smaller range
        if (__len1 < __len2)
        {   // __len >= 1, __len2 >= 2
            __len21 = __len2 / 2;
            __m2 = __middle;
            _VSTD::advance(__m2, __len21);
            __m1 = __upper_bound<_Compare>(__first, __middle, *__m2, __comp);
            __len11 = _VSTD::distance(__first, __m1);
        }
        else
        {
            if (__len1 == 1)
            {   // __len1 >= __len2 && __len2 > 0, therefore __len2 == 1
                // It is known *__first > *__middle
                swap(*__first, *__middle);
                return;
            }
            // __len1 >= 2, __len2 >= 1
            __len11 = __len1 / 2;
            __m1 = __first;
            _VSTD::advance(__m1, __len11);
            __m2 = __lower_bound<_Compare>(__middle, __last, *__m1, __comp);
            __len21 = _VSTD::distance(__middle, __m2);
        }
        difference_type __len12 = __len1 - __len11;  // distance(__m1, __middle)
        difference_type __len22 = __len2 - __len21;  // distance(__m2, __last)
        // [__first, __m1) [__m1, __middle) [__middle, __m2) [__m2, __last)
        // swap middle two partitions
        __middle = _VSTD::rotate(__m1, __middle, __m2);
        // __len12 and __len21 now have swapped meanings
        // merge smaller range with recurisve call and larger with tail recursion elimination
        if (__len11 + __len21 < __len12 + __len22)
        {
            __inplace_merge<_Compare>(__first, __m1, __middle, __comp, __len11, __len21, __buff, __buff_size);
//          __inplace_merge<_Compare>(__middle, __m2, __last, __comp, __len12, __len22, __buff, __buff_size);
            __first = __middle;
            __middle = __m2;
            __len1 = __len12;
            __len2 = __len22;
        }
        else
        {
            __inplace_merge<_Compare>(__middle, __m2, __last, __comp, __len12, __len22, __buff, __buff_size);
//          __inplace_merge<_Compare>(__first, __m1, __middle, __comp, __len11, __len21, __buff, __buff_size);
            __last = __middle;
            __middle = __m1;
            __len1 = __len11;
            __len2 = __len21;
        }
    }
}

template <class _Tp>
struct __inplace_merge_switch
{
    static const unsigned value = is_trivially_copy_assignable<_Tp>::value;
};

template <class _BidirectionalIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
void
inplace_merge(_BidirectionalIterator __first, _BidirectionalIterator __middle, _BidirectionalIterator __last,
              _Compare __comp)
{
    typedef typename iterator_traits<_BidirectionalIterator>::value_type value_type;
    typedef typename iterator_traits<_BidirectionalIterator>::difference_type difference_type;
    difference_type __len1 = _VSTD::distance(__first, __middle);
    difference_type __len2 = _VSTD::distance(__middle, __last);
    difference_type __buf_size = _VSTD::min(__len1, __len2);
    pair<value_type*, ptrdiff_t> __buf(0, 0);
    unique_ptr<value_type, __return_temporary_buffer> __h;
    if (__inplace_merge_switch<value_type>::value && __buf_size > 8)
    {
        __buf = _VSTD::get_temporary_buffer<value_type>(__buf_size);
        __h.reset(__buf.first);
    }
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    return _VSTD::__inplace_merge<_Comp_ref>(__first, __middle, __last, __c, __len1, __len2,
                                            __buf.first, __buf.second);
#else  // _LIBCPP_DEBUG
# 4445 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    return _VSTD::__inplace_merge<_Comp_ref>(__first, __middle, __last, __comp, __len1, __len2,
                                            __buf.first, __buf.second);
#endif  // _LIBCPP_DEBUG
# 4449 "/usr/include/c++/v1/algorithm" 3
}

template <class _BidirectionalIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
inplace_merge(_BidirectionalIterator __first, _BidirectionalIterator __middle, _BidirectionalIterator __last)
{
    _VSTD::inplace_merge(__first, __middle, __last,
                        __less<typename iterator_traits<_BidirectionalIterator>::value_type>());
}

// stable_sort

template <class _Compare, class _InputIterator1, class _InputIterator2>
void
__merge_move_construct(_InputIterator1 __first1, _InputIterator1 __last1,
        _InputIterator2 __first2, _InputIterator2 __last2,
        typename iterator_traits<_InputIterator1>::value_type* __result, _Compare __comp)
{
    typedef typename iterator_traits<_InputIterator1>::value_type value_type;
    __destruct_n __d(0);
    unique_ptr<value_type, __destruct_n&> __h(__result, __d);
    for (; true; ++__result)
    {
        if (__first1 == __last1)
        {
            for (; __first2 != __last2; ++__first2, ++__result, __d.__incr((value_type*)0))
                ::new (__result) value_type(_VSTD::move(*__first2));
            __h.release();
            return;
        }
        if (__first2 == __last2)
        {
            for (; __first1 != __last1; ++__first1, ++__result, __d.__incr((value_type*)0))
                ::new (__result) value_type(_VSTD::move(*__first1));
            __h.release();
            return;
        }
        if (__comp(*__first2, *__first1))
        {
            ::new (__result) value_type(_VSTD::move(*__first2));
            __d.__incr((value_type*)0);
            ++__first2;
        }
        else
        {
            ::new (__result) value_type(_VSTD::move(*__first1));
            __d.__incr((value_type*)0);
            ++__first1;
        }
    }
}

template <class _Compare, class _InputIterator1, class _InputIterator2, class _OutputIterator>
void
__merge_move_assign(_InputIterator1 __first1, _InputIterator1 __last1,
        _InputIterator2 __first2, _InputIterator2 __last2,
        _OutputIterator __result, _Compare __comp)
{
    for (; __first1 != __last1; ++__result)
    {
        if (__first2 == __last2)
        {
            for (; __first1 != __last1; ++__first1, ++__result)
                *__result = _VSTD::move(*__first1);
            return;
        }
        if (__comp(*__first2, *__first1))
        {
            *__result = _VSTD::move(*__first2);
            ++__first2;
        }
        else
        {
            *__result = _VSTD::move(*__first1);
            ++__first1;
        }
    }
    for (; __first2 != __last2; ++__first2, ++__result)
        *__result = _VSTD::move(*__first2);
}

template <class _Compare, class _RandomAccessIterator>
void
__stable_sort(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp,
              typename iterator_traits<_RandomAccessIterator>::difference_type __len,
              typename iterator_traits<_RandomAccessIterator>::value_type* __buff, ptrdiff_t __buff_size);

template <class _Compare, class _RandomAccessIterator>
void
__stable_sort_move(_RandomAccessIterator __first1, _RandomAccessIterator __last1, _Compare __comp,
                   typename iterator_traits<_RandomAccessIterator>::difference_type __len,
                   typename iterator_traits<_RandomAccessIterator>::value_type* __first2)
{
    typedef typename iterator_traits<_RandomAccessIterator>::value_type value_type;
    switch (__len)
    {
    case 0:
        return;
    case 1:
        ::new(__first2) value_type(_VSTD::move(*__first1));
        return;
    case 2:
       __destruct_n __d(0);
        unique_ptr<value_type, __destruct_n&> __h2(__first2, __d);
         if (__comp(*--__last1, *__first1))
        {
            ::new(__first2) value_type(_VSTD::move(*__last1));
            __d.__incr((value_type*)0);
            ++__first2;
            ::new(__first2) value_type(_VSTD::move(*__first1));
        }
        else
        {
            ::new(__first2) value_type(_VSTD::move(*__first1));
            __d.__incr((value_type*)0);
            ++__first2;
            ::new(__first2) value_type(_VSTD::move(*__last1));
        }
        __h2.release();
        return;
    }
    if (__len <= 8)
    {
        __insertion_sort_move<_Compare>(__first1, __last1, __first2, __comp);
        return;
    }
    typename iterator_traits<_RandomAccessIterator>::difference_type __l2 = __len / 2;
    _RandomAccessIterator __m = __first1 + __l2;
    __stable_sort<_Compare>(__first1, __m, __comp, __l2, __first2, __l2);
    __stable_sort<_Compare>(__m, __last1, __comp, __len - __l2, __first2 + __l2, __len - __l2);
    __merge_move_construct<_Compare>(__first1, __m, __m, __last1, __first2, __comp);
}

template <class _Tp>
struct __stable_sort_switch
{
    static const unsigned value = 128*is_trivially_copy_assignable<_Tp>::value;
};

template <class _Compare, class _RandomAccessIterator>
void
__stable_sort(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp,
              typename iterator_traits<_RandomAccessIterator>::difference_type __len,
              typename iterator_traits<_RandomAccessIterator>::value_type* __buff, ptrdiff_t __buff_size)
{
    typedef typename iterator_traits<_RandomAccessIterator>::value_type value_type;
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    switch (__len)
    {
    case 0:
    case 1:
        return;
    case 2:
        if (__comp(*--__last, *__first))
            swap(*__first, *__last);
        return;
    }
    if (__len <= static_cast<difference_type>(__stable_sort_switch<value_type>::value))
    {
        __insertion_sort<_Compare>(__first, __last, __comp);
        return;
    }
    typename iterator_traits<_RandomAccessIterator>::difference_type __l2 = __len / 2;
    _RandomAccessIterator __m = __first + __l2;
    if (__len <= __buff_size)
    {
        __destruct_n __d(0);
        unique_ptr<value_type, __destruct_n&> __h2(__buff, __d);
        __stable_sort_move<_Compare>(__first, __m, __comp, __l2, __buff);
        __d.__set(__l2, (value_type*)0);
        __stable_sort_move<_Compare>(__m, __last, __comp, __len - __l2, __buff + __l2);
        __d.__set(__len, (value_type*)0);
        __merge_move_assign<_Compare>(__buff, __buff + __l2, __buff + __l2, __buff + __len, __first, __comp);
//         __merge<_Compare>(move_iterator<value_type*>(__buff),
//                           move_iterator<value_type*>(__buff + __l2),
//                           move_iterator<_RandomAccessIterator>(__buff + __l2),
//                           move_iterator<_RandomAccessIterator>(__buff + __len),
//                           __first, __comp);
        return;
    }
    __stable_sort<_Compare>(__first, __m, __comp, __l2, __buff, __buff_size);
    __stable_sort<_Compare>(__m, __last, __comp, __len - __l2, __buff, __buff_size);
    __inplace_merge<_Compare>(__first, __m, __last, __comp, __l2, __len - __l2, __buff, __buff_size);
}

template <class _RandomAccessIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
void
stable_sort(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
    typedef typename iterator_traits<_RandomAccessIterator>::value_type value_type;
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    difference_type __len = __last - __first;
    pair<value_type*, ptrdiff_t> __buf(0, 0);
    unique_ptr<value_type, __return_temporary_buffer> __h;
    if (__len > static_cast<difference_type>(__stable_sort_switch<value_type>::value))
    {
        __buf = _VSTD::get_temporary_buffer<value_type>(__len);
        __h.reset(__buf.first);
    }
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    __stable_sort<_Comp_ref>(__first, __last, __c, __len, __buf.first, __buf.second);
#else  // _LIBCPP_DEBUG
# 4655 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    __stable_sort<_Comp_ref>(__first, __last, __comp, __len, __buf.first, __buf.second);
#endif  // _LIBCPP_DEBUG
# 4658 "/usr/include/c++/v1/algorithm" 3
}

template <class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
stable_sort(_RandomAccessIterator __first, _RandomAccessIterator __last)
{
    _VSTD::stable_sort(__first, __last, __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

// is_heap_until

template <class _RandomAccessIterator, class _Compare>
_RandomAccessIterator
is_heap_until(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
    typedef typename _VSTD::iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    difference_type __len = __last - __first;
    difference_type __p = 0;
    difference_type __c = 1;
    _RandomAccessIterator __pp = __first;
    while (__c < __len)
    {
        _RandomAccessIterator __cp = __first + __c;
        if (__comp(*__pp, *__cp))
            return __cp;
        ++__c;
        ++__cp;
        if (__c == __len)
            return __last;
        if (__comp(*__pp, *__cp))
            return __cp;
        ++__p;
        ++__pp;
        __c = 2 * __p + 1;
    }
    return __last;
}

template<class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
_RandomAccessIterator
is_heap_until(_RandomAccessIterator __first, _RandomAccessIterator __last)
{
    return _VSTD::is_heap_until(__first, __last, __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

// is_heap

template <class _RandomAccessIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
bool
is_heap(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
    return _VSTD::is_heap_until(__first, __last, __comp) == __last;
}

template<class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
bool
is_heap(_RandomAccessIterator __first, _RandomAccessIterator __last)
{
    return _VSTD::is_heap(__first, __last, __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

// push_heap

template <class _Compare, class _RandomAccessIterator>
void
__push_heap_front(_RandomAccessIterator __first, _RandomAccessIterator, _Compare __comp,
                  typename iterator_traits<_RandomAccessIterator>::difference_type __len)
{
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    typedef typename iterator_traits<_RandomAccessIterator>::value_type value_type;
    if (__len > 1)
    {
        difference_type __p = 0;
        _RandomAccessIterator __pp = __first;
        difference_type __c = 2;
        _RandomAccessIterator __cp = __first + __c;
        if (__c == __len || __comp(*__cp, *(__cp - 1)))
        {
            --__c;
            --__cp;
        }
        if (__comp(*__pp, *__cp))
        {
            value_type __t(_VSTD::move(*__pp));
            do
            {
                *__pp = _VSTD::move(*__cp);
                __pp = __cp;
                __p = __c;
                __c = (__p + 1) * 2;
                if (__c > __len)
                    break;
                __cp = __first + __c;
                if (__c == __len || __comp(*__cp, *(__cp - 1)))
                {
                    --__c;
                    --__cp;
                }
            } while (__comp(__t, *__cp));
            *__pp = _VSTD::move(__t);
        }
    }
}

template <class _Compare, class _RandomAccessIterator>
void
__push_heap_back(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp,
                 typename iterator_traits<_RandomAccessIterator>::difference_type __len)
{
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    typedef typename iterator_traits<_RandomAccessIterator>::value_type value_type;
    if (__len > 1)
    {
        __len = (__len - 2) / 2;
        _RandomAccessIterator __ptr = __first + __len;
        if (__comp(*__ptr, *--__last))
        {
            value_type __t(_VSTD::move(*__last));
            do
            {
                *__last = _VSTD::move(*__ptr);
                __last = __ptr;
                if (__len == 0)
                    break;
                __len = (__len - 1) / 2;
                __ptr = __first + __len;
            } while (__comp(*__ptr, __t));
            *__last = _VSTD::move(__t);
        }
    }
}

template <class _RandomAccessIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
void
push_heap(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    __push_heap_back<_Comp_ref>(__first, __last, __c, __last - __first);
#else  // _LIBCPP_DEBUG
# 4804 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    __push_heap_back<_Comp_ref>(__first, __last, __comp, __last - __first);
#endif  // _LIBCPP_DEBUG
# 4807 "/usr/include/c++/v1/algorithm" 3
}

template <class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
push_heap(_RandomAccessIterator __first, _RandomAccessIterator __last)
{
    _VSTD::push_heap(__first, __last, __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

// pop_heap

template <class _Compare, class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
__pop_heap(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp,
           typename iterator_traits<_RandomAccessIterator>::difference_type __len)
{
    if (__len > 1)
    {
        swap(*__first, *--__last);
        __push_heap_front<_Compare>(__first, __last, __comp, __len-1);
    }
}

template <class _RandomAccessIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
void
pop_heap(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    __pop_heap<_Comp_ref>(__first, __last, __c, __last - __first);
#else  // _LIBCPP_DEBUG
# 4842 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    __pop_heap<_Comp_ref>(__first, __last, __comp, __last - __first);
#endif  // _LIBCPP_DEBUG
# 4845 "/usr/include/c++/v1/algorithm" 3
}

template <class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
pop_heap(_RandomAccessIterator __first, _RandomAccessIterator __last)
{
    _VSTD::pop_heap(__first, __last, __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

// make_heap

template <class _Compare, class _RandomAccessIterator>
void
__make_heap(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    difference_type __n = __last - __first;
    if (__n > 1)
    {
        __last = __first;
        ++__last;
        for (difference_type __i = 1; __i < __n;)
            __push_heap_back<_Compare>(__first, ++__last, __comp, ++__i);
    }
}

template <class _RandomAccessIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
void
make_heap(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    __make_heap<_Comp_ref>(__first, __last, __c);
#else  // _LIBCPP_DEBUG
# 4882 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    __make_heap<_Comp_ref>(__first, __last, __comp);
#endif  // _LIBCPP_DEBUG
# 4885 "/usr/include/c++/v1/algorithm" 3
}

template <class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
make_heap(_RandomAccessIterator __first, _RandomAccessIterator __last)
{
    _VSTD::make_heap(__first, __last, __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

// sort_heap

template <class _Compare, class _RandomAccessIterator>
void
__sort_heap(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    for (difference_type __n = __last - __first; __n > 1; --__last, --__n)
        __pop_heap<_Compare>(__first, __last, __comp, __n);
}

template <class _RandomAccessIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
void
sort_heap(_RandomAccessIterator __first, _RandomAccessIterator __last, _Compare __comp)
{
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    __sort_heap<_Comp_ref>(__first, __last, __c);
#else  // _LIBCPP_DEBUG
# 4916 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    __sort_heap<_Comp_ref>(__first, __last, __comp);
#endif  // _LIBCPP_DEBUG
# 4919 "/usr/include/c++/v1/algorithm" 3
}

template <class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
sort_heap(_RandomAccessIterator __first, _RandomAccessIterator __last)
{
    _VSTD::sort_heap(__first, __last, __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

// partial_sort

template <class _Compare, class _RandomAccessIterator>
void
__partial_sort(_RandomAccessIterator __first, _RandomAccessIterator __middle, _RandomAccessIterator __last,
             _Compare __comp)
{
    __make_heap<_Compare>(__first, __middle, __comp);
    typename iterator_traits<_RandomAccessIterator>::difference_type __len = __middle - __first;
    for (_RandomAccessIterator __i = __middle; __i != __last; ++__i)
    {
        if (__comp(*__i, *__first))
        {
            swap(*__i, *__first);
            __push_heap_front<_Compare>(__first, __middle, __comp, __len);
        }
    }
    __sort_heap<_Compare>(__first, __middle, __comp);
}

template <class _RandomAccessIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
void
partial_sort(_RandomAccessIterator __first, _RandomAccessIterator __middle, _RandomAccessIterator __last,
             _Compare __comp)
{
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    __partial_sort<_Comp_ref>(__first, __middle, __last, __c);
#else  // _LIBCPP_DEBUG
# 4960 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    __partial_sort<_Comp_ref>(__first, __middle, __last, __comp);
#endif  // _LIBCPP_DEBUG
# 4963 "/usr/include/c++/v1/algorithm" 3
}

template <class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
partial_sort(_RandomAccessIterator __first, _RandomAccessIterator __middle, _RandomAccessIterator __last)
{
    _VSTD::partial_sort(__first, __middle, __last,
                       __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

// partial_sort_copy

template <class _Compare, class _InputIterator, class _RandomAccessIterator>
_RandomAccessIterator
__partial_sort_copy(_InputIterator __first, _InputIterator __last,
                    _RandomAccessIterator __result_first, _RandomAccessIterator __result_last, _Compare __comp)
{
    _RandomAccessIterator __r = __result_first;
    if (__r != __result_last)
    {
        typename iterator_traits<_RandomAccessIterator>::difference_type __len = 0;
        for (; __first != __last && __r != __result_last; ++__first, ++__r, ++__len)
            *__r = *__first;
        __make_heap<_Compare>(__result_first, __r, __comp);
        for (; __first != __last; ++__first)
            if (__comp(*__first, *__result_first))
            {
                *__result_first = *__first;
                __push_heap_front<_Compare>(__result_first, __r, __comp, __len);
            }
        __sort_heap<_Compare>(__result_first, __r, __comp);
    }
    return __r;
}

template <class _InputIterator, class _RandomAccessIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
_RandomAccessIterator
partial_sort_copy(_InputIterator __first, _InputIterator __last,
                  _RandomAccessIterator __result_first, _RandomAccessIterator __result_last, _Compare __comp)
{
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    return __partial_sort_copy<_Comp_ref>(__first, __last, __result_first, __result_last, __c);
#else  // _LIBCPP_DEBUG
# 5010 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    return __partial_sort_copy<_Comp_ref>(__first, __last, __result_first, __result_last, __comp);
#endif  // _LIBCPP_DEBUG
# 5013 "/usr/include/c++/v1/algorithm" 3
}

template <class _InputIterator, class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
_RandomAccessIterator
partial_sort_copy(_InputIterator __first, _InputIterator __last,
                  _RandomAccessIterator __result_first, _RandomAccessIterator __result_last)
{
    return _VSTD::partial_sort_copy(__first, __last, __result_first, __result_last,
                                   __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

// nth_element

template <class _Compare, class _RandomAccessIterator>
void
__nth_element(_RandomAccessIterator __first, _RandomAccessIterator __nth, _RandomAccessIterator __last, _Compare __comp)
{
    // _Compare is known to be a reference type
    typedef typename iterator_traits<_RandomAccessIterator>::difference_type difference_type;
    const difference_type __limit = 7;
    while (true)
    {
    __restart:
        if (__nth == __last)
            return;
        difference_type __len = __last - __first;
        switch (__len)
        {
        case 0:
        case 1:
            return;
        case 2:
            if (__comp(*--__last, *__first))
                swap(*__first, *__last);
            return;
        case 3:
            {
            _RandomAccessIterator __m = __first;
            _VSTD::__sort3<_Compare>(__first, ++__m, --__last, __comp);
            return;
            }
        }
        if (__len <= __limit)
        {
            __selection_sort<_Compare>(__first, __last, __comp);
            return;
        }
        // __len > __limit >= 3
        _RandomAccessIterator __m = __first + __len/2;
        _RandomAccessIterator __lm1 = __last;
        unsigned __n_swaps = _VSTD::__sort3<_Compare>(__first, __m, --__lm1, __comp);
        // *__m is median
        // partition [__first, __m) < *__m and *__m <= [__m, __last)
        // (this inhibits tossing elements equivalent to __m around unnecessarily)
        _RandomAccessIterator __i = __first;
        _RandomAccessIterator __j = __lm1;
        // j points beyond range to be tested, *__lm1 is known to be <= *__m
        // The search going up is known to be guarded but the search coming down isn't.
        // Prime the downward search with a guard.
        if (!__comp(*__i, *__m))  // if *__first == *__m
        {
            // *__first == *__m, *__first doesn't go in first part
            // manually guard downward moving __j against __i
            while (true)
            {
                if (__i == --__j)
                {
                    // *__first == *__m, *__m <= all other elements
                    // Parition instead into [__first, __i) == *__first and *__first < [__i, __last)
                    ++__i;  // __first + 1
                    __j = __last;
                    if (!__comp(*__first, *--__j))  // we need a guard if *__first == *(__last-1)
                    {
                        while (true)
                        {
                            if (__i == __j)
                                return;  // [__first, __last) all equivalent elements
                            if (__comp(*__first, *__i))
                            {
                                swap(*__i, *__j);
                                ++__n_swaps;
                                ++__i;
                                break;
                            }
                            ++__i;
                        }
                    }
                    // [__first, __i) == *__first and *__first < [__j, __last) and __j == __last - 1
                    if (__i == __j)
                        return;
                    while (true)
                    {
                        while (!__comp(*__first, *__i))
                            ++__i;
                        while (__comp(*__first, *--__j))
                            ;
                        if (__i >= __j)
                            break;
                        swap(*__i, *__j);
                        ++__n_swaps;
                        ++__i;
                    }
                    // [__first, __i) == *__first and *__first < [__i, __last)
                    // The first part is sorted,
                    if (__nth < __i)
                        return;
                    // __nth_element the secod part
                    // __nth_element<_Compare>(__i, __nth, __last, __comp);
                    __first = __i;
                    goto __restart;
                }
                if (__comp(*__j, *__m))
                {
                    swap(*__i, *__j);
                    ++__n_swaps;
                    break;  // found guard for downward moving __j, now use unguarded partition
                }
            }
        }
        ++__i;
        // j points beyond range to be tested, *__lm1 is known to be <= *__m
        // if not yet partitioned...
        if (__i < __j)
        {
            // known that *(__i - 1) < *__m
            while (true)
            {
                // __m still guards upward moving __i
                while (__comp(*__i, *__m))
                    ++__i;
                // It is now known that a guard exists for downward moving __j
                while (!__comp(*--__j, *__m))
                    ;
                if (__i >= __j)
                    break;
                swap(*__i, *__j);
                ++__n_swaps;
                // It is known that __m != __j
                // If __m just moved, follow it
                if (__m == __i)
                    __m = __j;
                ++__i;
            }
        }
        // [__first, __i) < *__m and *__m <= [__i, __last)
        if (__i != __m && __comp(*__m, *__i))
        {
            swap(*__i, *__m);
            ++__n_swaps;
        }
        // [__first, __i) < *__i and *__i <= [__i+1, __last)
        if (__nth == __i)
            return;
        if (__n_swaps == 0)
        {
            // We were given a perfectly partitioned sequence.  Coincidence?
            if (__nth < __i)
            {
                // Check for [__first, __i) already sorted
                __j = __m = __first;
                while (++__j != __i)
                {
                    if (__comp(*__j, *__m))
                        // not yet sorted, so sort
                        goto not_sorted;
                    __m = __j;
                }
                // [__first, __i) sorted
                return;
            }
            else
            {
                // Check for [__i, __last) already sorted
                __j = __m = __i;
                while (++__j != __last)
                {
                    if (__comp(*__j, *__m))
                        // not yet sorted, so sort
                        goto not_sorted;
                    __m = __j;
                }
                // [__i, __last) sorted
                return;
            }
        }
not_sorted:
        // __nth_element on range containing __nth
        if (__nth < __i)
        {
            // __nth_element<_Compare>(__first, __nth, __i, __comp);
            __last = __i;
        }
        else
        {
            // __nth_element<_Compare>(__i+1, __nth, __last, __comp);
            __first = ++__i;
        }
    }
}

template <class _RandomAccessIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
void
nth_element(_RandomAccessIterator __first, _RandomAccessIterator __nth, _RandomAccessIterator __last, _Compare __comp)
{
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    __nth_element<_Comp_ref>(__first, __nth, __last, __c);
#else  // _LIBCPP_DEBUG
# 5224 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    __nth_element<_Comp_ref>(__first, __nth, __last, __comp);
#endif  // _LIBCPP_DEBUG
# 5227 "/usr/include/c++/v1/algorithm" 3
}

template <class _RandomAccessIterator>
inline _LIBCPP_INLINE_VISIBILITY
void
nth_element(_RandomAccessIterator __first, _RandomAccessIterator __nth, _RandomAccessIterator __last)
{
    _VSTD::nth_element(__first, __nth, __last, __less<typename iterator_traits<_RandomAccessIterator>::value_type>());
}

// includes

template <class _Compare, class _InputIterator1, class _InputIterator2>
bool
__includes(_InputIterator1 __first1, _InputIterator1 __last1, _InputIterator2 __first2, _InputIterator2 __last2,
           _Compare __comp)
{
    for (; __first2 != __last2; ++__first1)
    {
        if (__first1 == __last1 || __comp(*__first2, *__first1))
            return false;
        if (!__comp(*__first1, *__first2))
            ++__first2;
    }
    return true;
}

template <class _InputIterator1, class _InputIterator2, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
bool
includes(_InputIterator1 __first1, _InputIterator1 __last1, _InputIterator2 __first2, _InputIterator2 __last2,
         _Compare __comp)
{
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    return __includes<_Comp_ref>(__first1, __last1, __first2, __last2, __c);
#else  // _LIBCPP_DEBUG
# 5265 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    return __includes<_Comp_ref>(__first1, __last1, __first2, __last2, __comp);
#endif  // _LIBCPP_DEBUG
# 5268 "/usr/include/c++/v1/algorithm" 3
}

template <class _InputIterator1, class _InputIterator2>
inline _LIBCPP_INLINE_VISIBILITY
bool
includes(_InputIterator1 __first1, _InputIterator1 __last1, _InputIterator2 __first2, _InputIterator2 __last2)
{
    return _VSTD::includes(__first1, __last1, __first2, __last2,
                          __less<typename iterator_traits<_InputIterator1>::value_type,
                                 typename iterator_traits<_InputIterator2>::value_type>());
}

// set_union

template <class _Compare, class _InputIterator1, class _InputIterator2, class _OutputIterator>
_OutputIterator
__set_union(_InputIterator1 __first1, _InputIterator1 __last1,
            _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result, _Compare __comp)
{
    for (; __first1 != __last1; ++__result)
    {
        if (__first2 == __last2)
            return _VSTD::copy(__first1, __last1, __result);
        if (__comp(*__first2, *__first1))
        {
            *__result = *__first2;
            ++__first2;
        }
        else
        {
            *__result = *__first1;
            if (!__comp(*__first1, *__first2))
                ++__first2;
            ++__first1;
        }
    }
    return _VSTD::copy(__first2, __last2, __result);
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
set_union(_InputIterator1 __first1, _InputIterator1 __last1,
          _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result, _Compare __comp)
{
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    return __set_union<_Comp_ref>(__first1, __last1, __first2, __last2, __result, __c);
#else  // _LIBCPP_DEBUG
# 5318 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    return __set_union<_Comp_ref>(__first1, __last1, __first2, __last2, __result, __comp);
#endif  // _LIBCPP_DEBUG
# 5321 "/usr/include/c++/v1/algorithm" 3
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
set_union(_InputIterator1 __first1, _InputIterator1 __last1,
          _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result)
{
    return _VSTD::set_union(__first1, __last1, __first2, __last2, __result,
                          __less<typename iterator_traits<_InputIterator1>::value_type,
                                 typename iterator_traits<_InputIterator2>::value_type>());
}

// set_intersection

template <class _Compare, class _InputIterator1, class _InputIterator2, class _OutputIterator>
_OutputIterator
__set_intersection(_InputIterator1 __first1, _InputIterator1 __last1,
                   _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result, _Compare __comp)
{
    while (__first1 != __last1 && __first2 != __last2)
    {
        if (__comp(*__first1, *__first2))
            ++__first1;
        else
        {
            if (!__comp(*__first2, *__first1))
            {
                *__result = *__first1;
                ++__result;
                ++__first1;
            }
            ++__first2;
        }
    }
    return __result;
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
set_intersection(_InputIterator1 __first1, _InputIterator1 __last1,
                 _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result, _Compare __comp)
{
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    return __set_intersection<_Comp_ref>(__first1, __last1, __first2, __last2, __result, __c);
#else  // _LIBCPP_DEBUG
# 5370 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    return __set_intersection<_Comp_ref>(__first1, __last1, __first2, __last2, __result, __comp);
#endif  // _LIBCPP_DEBUG
# 5373 "/usr/include/c++/v1/algorithm" 3
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
set_intersection(_InputIterator1 __first1, _InputIterator1 __last1,
                 _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result)
{
    return _VSTD::set_intersection(__first1, __last1, __first2, __last2, __result,
                                  __less<typename iterator_traits<_InputIterator1>::value_type,
                                         typename iterator_traits<_InputIterator2>::value_type>());
}

// set_difference

template <class _Compare, class _InputIterator1, class _InputIterator2, class _OutputIterator>
_OutputIterator
__set_difference(_InputIterator1 __first1, _InputIterator1 __last1,
                 _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result, _Compare __comp)
{
    while (__first1 != __last1)
    {
        if (__first2 == __last2)
            return _VSTD::copy(__first1, __last1, __result);
        if (__comp(*__first1, *__first2))
        {
            *__result = *__first1;
            ++__result;
            ++__first1;
        }
        else
        {
            if (!__comp(*__first2, *__first1))
                ++__first1;
            ++__first2;
        }
    }
    return __result;
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
set_difference(_InputIterator1 __first1, _InputIterator1 __last1,
               _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result, _Compare __comp)
{
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    return __set_difference<_Comp_ref>(__first1, __last1, __first2, __last2, __result, __c);
#else  // _LIBCPP_DEBUG
# 5424 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    return __set_difference<_Comp_ref>(__first1, __last1, __first2, __last2, __result, __comp);
#endif  // _LIBCPP_DEBUG
# 5427 "/usr/include/c++/v1/algorithm" 3
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
set_difference(_InputIterator1 __first1, _InputIterator1 __last1,
               _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result)
{
    return _VSTD::set_difference(__first1, __last1, __first2, __last2, __result,
                                __less<typename iterator_traits<_InputIterator1>::value_type,
                                       typename iterator_traits<_InputIterator2>::value_type>());
}

// set_symmetric_difference

template <class _Compare, class _InputIterator1, class _InputIterator2, class _OutputIterator>
_OutputIterator
__set_symmetric_difference(_InputIterator1 __first1, _InputIterator1 __last1,
                           _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result, _Compare __comp)
{
    while (__first1 != __last1)
    {
        if (__first2 == __last2)
            return _VSTD::copy(__first1, __last1, __result);
        if (__comp(*__first1, *__first2))
        {
            *__result = *__first1;
            ++__result;
            ++__first1;
        }
        else
        {
            if (__comp(*__first2, *__first1))
            {
                *__result = *__first2;
                ++__result;
            }
            else
                ++__first1;
            ++__first2;
        }
    }
    return _VSTD::copy(__first2, __last2, __result);
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
set_symmetric_difference(_InputIterator1 __first1, _InputIterator1 __last1,
                         _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result, _Compare __comp)
{
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    return __set_symmetric_difference<_Comp_ref>(__first1, __last1, __first2, __last2, __result, __c);
#else  // _LIBCPP_DEBUG
# 5483 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    return __set_symmetric_difference<_Comp_ref>(__first1, __last1, __first2, __last2, __result, __comp);
#endif  // _LIBCPP_DEBUG
# 5486 "/usr/include/c++/v1/algorithm" 3
}

template <class _InputIterator1, class _InputIterator2, class _OutputIterator>
inline _LIBCPP_INLINE_VISIBILITY
_OutputIterator
set_symmetric_difference(_InputIterator1 __first1, _InputIterator1 __last1,
                         _InputIterator2 __first2, _InputIterator2 __last2, _OutputIterator __result)
{
    return _VSTD::set_symmetric_difference(__first1, __last1, __first2, __last2, __result,
                                          __less<typename iterator_traits<_InputIterator1>::value_type,
                                                 typename iterator_traits<_InputIterator2>::value_type>());
}

// lexicographical_compare

template <class _Compare, class _InputIterator1, class _InputIterator2>
bool
__lexicographical_compare(_InputIterator1 __first1, _InputIterator1 __last1,
                          _InputIterator2 __first2, _InputIterator2 __last2, _Compare __comp)
{
    for (; __first2 != __last2; ++__first1, ++__first2)
    {
        if (__first1 == __last1 || __comp(*__first1, *__first2))
            return true;
        if (__comp(*__first2, *__first1))
            return false;
    }
    return false;
}

template <class _InputIterator1, class _InputIterator2, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
bool
lexicographical_compare(_InputIterator1 __first1, _InputIterator1 __last1,
                        _InputIterator2 __first2, _InputIterator2 __last2, _Compare __comp)
{
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    return __lexicographical_compare<_Comp_ref>(__first1, __last1, __first2, __last2, __c);
#else  // _LIBCPP_DEBUG
# 5527 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    return __lexicographical_compare<_Comp_ref>(__first1, __last1, __first2, __last2, __comp);
#endif  // _LIBCPP_DEBUG
# 5530 "/usr/include/c++/v1/algorithm" 3
}

template <class _InputIterator1, class _InputIterator2>
inline _LIBCPP_INLINE_VISIBILITY
bool
lexicographical_compare(_InputIterator1 __first1, _InputIterator1 __last1,
                        _InputIterator2 __first2, _InputIterator2 __last2)
{
    return _VSTD::lexicographical_compare(__first1, __last1, __first2, __last2,
                                         __less<typename iterator_traits<_InputIterator1>::value_type,
                                                typename iterator_traits<_InputIterator2>::value_type>());
}

// next_permutation

template <class _Compare, class _BidirectionalIterator>
bool
__next_permutation(_BidirectionalIterator __first, _BidirectionalIterator __last, _Compare __comp)
{
    _BidirectionalIterator __i = __last;
    if (__first == __last || __first == --__i)
        return false;
    while (true)
    {
        _BidirectionalIterator __ip1 = __i;
        if (__comp(*--__i, *__ip1))
        {
            _BidirectionalIterator __j = __last;
            while (!__comp(*__i, *--__j))
                ;
            swap(*__i, *__j);
            _VSTD::reverse(__ip1, __last);
            return true;
        }
        if (__i == __first)
        {
            _VSTD::reverse(__first, __last);
            return false;
        }
    }
}

template <class _BidirectionalIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
bool
next_permutation(_BidirectionalIterator __first, _BidirectionalIterator __last, _Compare __comp)
{
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    return __next_permutation<_Comp_ref>(__first, __last, __c);
#else  // _LIBCPP_DEBUG
# 5582 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    return __next_permutation<_Comp_ref>(__first, __last, __comp);
#endif  // _LIBCPP_DEBUG
# 5585 "/usr/include/c++/v1/algorithm" 3
}

template <class _BidirectionalIterator>
inline _LIBCPP_INLINE_VISIBILITY
bool
next_permutation(_BidirectionalIterator __first, _BidirectionalIterator __last)
{
    return _VSTD::next_permutation(__first, __last,
                                  __less<typename iterator_traits<_BidirectionalIterator>::value_type>());
}

// prev_permutation

template <class _Compare, class _BidirectionalIterator>
bool
__prev_permutation(_BidirectionalIterator __first, _BidirectionalIterator __last, _Compare __comp)
{
    _BidirectionalIterator __i = __last;
    if (__first == __last || __first == --__i)
        return false;
    while (true)
    {
        _BidirectionalIterator __ip1 = __i;
        if (__comp(*__ip1, *--__i))
        {
            _BidirectionalIterator __j = __last;
            while (!__comp(*--__j, *__i))
                ;
            swap(*__i, *__j);
            _VSTD::reverse(__ip1, __last);
            return true;
        }
        if (__i == __first)
        {
            _VSTD::reverse(__first, __last);
            return false;
        }
    }
}

template <class _BidirectionalIterator, class _Compare>
inline _LIBCPP_INLINE_VISIBILITY
bool
prev_permutation(_BidirectionalIterator __first, _BidirectionalIterator __last, _Compare __comp)
{
#ifdef _LIBCPP_DEBUG
    typedef typename add_lvalue_reference<__debug_less<_Compare> >::type _Comp_ref;
    __debug_less<_Compare> __c(__comp);
    return __prev_permutation<_Comp_ref>(__first, __last, __c);
#else  // _LIBCPP_DEBUG
# 5635 "/usr/include/c++/v1/algorithm" 3
    typedef typename add_lvalue_reference<_Compare>::type _Comp_ref;
    return __prev_permutation<_Comp_ref>(__first, __last, __comp);
#endif  // _LIBCPP_DEBUG
# 5638 "/usr/include/c++/v1/algorithm" 3
}

template <class _BidirectionalIterator>
inline _LIBCPP_INLINE_VISIBILITY
bool
prev_permutation(_BidirectionalIterator __first, _BidirectionalIterator __last)
{
    return _VSTD::prev_permutation(__first, __last,
                                  __less<typename iterator_traits<_BidirectionalIterator>::value_type>());
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value,
    _Tp
>::type
__rotate_left(_Tp __t, _Tp __n = 1)
{
    const unsigned __bits = static_cast<unsigned>(sizeof(_Tp) * __CHAR_BIT__ - 1);
    __n &= __bits;
    return static_cast<_Tp>((__t << __n) | (static_cast<typename make_unsigned<_Tp>::type>(__t) >> (__bits - __n)));
}

template <class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_integral<_Tp>::value,
    _Tp
>::type
__rotate_right(_Tp __t, _Tp __n = 1)
{
    const unsigned __bits = static_cast<unsigned>(sizeof(_Tp) * __CHAR_BIT__ - 1);
    __n &= __bits;
    return static_cast<_Tp>((__t << (__bits - __n)) | (static_cast<typename make_unsigned<_Tp>::type>(__t) >> __n));
}

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_ALGORITHM
# 5680 "/usr/include/c++/v1/algorithm" 3
# 440 "/usr/include/c++/v1/string" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 441 "/usr/include/c++/v1/string" 3
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 442 "/usr/include/c++/v1/string" 3
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 443 "/usr/include/c++/v1/string" 3
#if 0 /* expanded by -frewrite-includes */
#include <stdexcept>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/stdexcept" 1 3
// -*- C++ -*-
//===--------------------------- stdexcept --------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_STDEXCEPT
#define _LIBCPP_STDEXCEPT

/*
    stdexcept synopsis

namespace std
{

class logic_error;
    class domain_error;
    class invalid_argument;
    class length_error;
    class out_of_range;
class runtime_error;
    class range_error;
    class overflow_error;
    class underflow_error;

for each class xxx_error:

class xxx_error : public exception // at least indirectly
{
public:
    explicit xxx_error(const string& what_arg);
    explicit xxx_error(const char*   what_arg);

    virtual const char* what() const noexcept // returns what_arg
};

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 46 "/usr/include/c++/v1/stdexcept" 3
#if 0 /* expanded by -frewrite-includes */
#include <exception>
#endif /* expanded by -frewrite-includes */
# 47 "/usr/include/c++/v1/stdexcept" 3
#if 0 /* expanded by -frewrite-includes */
#include <iosfwd>  // for string forward decl
#endif /* expanded by -frewrite-includes */
# 48 "/usr/include/c++/v1/stdexcept" 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 51 "/usr/include/c++/v1/stdexcept" 3
#endif
# 52 "/usr/include/c++/v1/stdexcept" 3

namespace std  // purposefully not using versioning namespace
{

class _LIBCPP_EXCEPTION_ABI logic_error
    : public exception
{
private:
    void* __imp_;
public:
    explicit logic_error(const string&);
    explicit logic_error(const char*);

    logic_error(const logic_error&) _NOEXCEPT;
    logic_error& operator=(const logic_error&) _NOEXCEPT;

    virtual ~logic_error() _NOEXCEPT;

    virtual const char* what() const _NOEXCEPT;
};

class _LIBCPP_EXCEPTION_ABI runtime_error
    : public exception
{
private:
    void* __imp_;
public:
    explicit runtime_error(const string&);
    explicit runtime_error(const char*);

    runtime_error(const runtime_error&) _NOEXCEPT;
    runtime_error& operator=(const runtime_error&) _NOEXCEPT;

    virtual ~runtime_error() _NOEXCEPT;

    virtual const char* what() const _NOEXCEPT;
};

class _LIBCPP_EXCEPTION_ABI domain_error
    : public logic_error
{
public:
    _LIBCPP_INLINE_VISIBILITY explicit domain_error(const string& __s) : logic_error(__s) {}
    _LIBCPP_INLINE_VISIBILITY explicit domain_error(const char* __s)   : logic_error(__s) {}

    virtual ~domain_error() _NOEXCEPT;
};

class _LIBCPP_EXCEPTION_ABI invalid_argument
    : public logic_error
{
public:
    _LIBCPP_INLINE_VISIBILITY explicit invalid_argument(const string& __s) : logic_error(__s) {}
    _LIBCPP_INLINE_VISIBILITY explicit invalid_argument(const char* __s)   : logic_error(__s) {}

    virtual ~invalid_argument() _NOEXCEPT;
};

class _LIBCPP_EXCEPTION_ABI length_error
    : public logic_error
{
public:
    _LIBCPP_INLINE_VISIBILITY explicit length_error(const string& __s) : logic_error(__s) {}
    _LIBCPP_INLINE_VISIBILITY explicit length_error(const char* __s)   : logic_error(__s) {}

    virtual ~length_error() _NOEXCEPT;
};

class _LIBCPP_EXCEPTION_ABI out_of_range
    : public logic_error
{
public:
    _LIBCPP_INLINE_VISIBILITY explicit out_of_range(const string& __s) : logic_error(__s) {}
    _LIBCPP_INLINE_VISIBILITY explicit out_of_range(const char* __s)   : logic_error(__s) {}

    virtual ~out_of_range() _NOEXCEPT;
};

class _LIBCPP_EXCEPTION_ABI range_error
    : public runtime_error
{
public:
    _LIBCPP_INLINE_VISIBILITY explicit range_error(const string& __s) : runtime_error(__s) {}
    _LIBCPP_INLINE_VISIBILITY explicit range_error(const char* __s)   : runtime_error(__s) {}

    virtual ~range_error() _NOEXCEPT;
};

class _LIBCPP_EXCEPTION_ABI overflow_error
    : public runtime_error
{
public:
    _LIBCPP_INLINE_VISIBILITY explicit overflow_error(const string& __s) : runtime_error(__s) {}
    _LIBCPP_INLINE_VISIBILITY explicit overflow_error(const char* __s)   : runtime_error(__s) {}

    virtual ~overflow_error() _NOEXCEPT;
};

class _LIBCPP_EXCEPTION_ABI underflow_error
    : public runtime_error
{
public:
    _LIBCPP_INLINE_VISIBILITY explicit underflow_error(const string& __s) : runtime_error(__s) {}
    _LIBCPP_INLINE_VISIBILITY explicit underflow_error(const char* __s)   : runtime_error(__s) {}

    virtual ~underflow_error() _NOEXCEPT;
};

}  // std

#endif  // _LIBCPP_STDEXCEPT
# 163 "/usr/include/c++/v1/stdexcept" 3
# 444 "/usr/include/c++/v1/string" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 445 "/usr/include/c++/v1/string" 3
#if 0 /* expanded by -frewrite-includes */
#include <initializer_list>
#endif /* expanded by -frewrite-includes */
# 446 "/usr/include/c++/v1/string" 3
#if 0 /* expanded by -frewrite-includes */
#include <__functional_base>
#endif /* expanded by -frewrite-includes */
# 447 "/usr/include/c++/v1/string" 3
#ifndef _LIBCPP_HAS_NO_UNICODE_CHARS
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 449 "/usr/include/c++/v1/string" 3
#endif
# 450 "/usr/include/c++/v1/string" 3
#if defined(_LIBCPP_NO_EXCEPTIONS)
#if 0 /* expanded by -frewrite-includes */
#include <cassert>
#endif /* expanded by -frewrite-includes */
# 452 "/usr/include/c++/v1/string" 3
#endif
# 453 "/usr/include/c++/v1/string" 3

#if 0 /* expanded by -frewrite-includes */
#include <__undef_min_max>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/__undef_min_max" 1 3
// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifdef min
#if defined(_MSC_VER) && ! defined(__clang__)
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 16 "/usr/include/c++/v1/__undef_min_max" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 18 "/usr/include/c++/v1/__undef_min_max" 3
#undef min
#endif
# 20 "/usr/include/c++/v1/__undef_min_max" 3

#ifdef max
#if defined(_MSC_VER) && ! defined(__clang__)
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 26 "/usr/include/c++/v1/__undef_min_max" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 28 "/usr/include/c++/v1/__undef_min_max" 3
#undef max
#endif
# 30 "/usr/include/c++/v1/__undef_min_max" 3
# 455 "/usr/include/c++/v1/string" 2 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 458 "/usr/include/c++/v1/string" 3
#endif
# 459 "/usr/include/c++/v1/string" 3

_LIBCPP_BEGIN_NAMESPACE_STD

// fpos

template <class _StateT>
class _LIBCPP_TYPE_VIS_ONLY fpos
{
private:
    _StateT __st_;
    streamoff __off_;
public:
    _LIBCPP_INLINE_VISIBILITY fpos(streamoff __off = streamoff()) : __st_(), __off_(__off) {}

    _LIBCPP_INLINE_VISIBILITY operator streamoff() const {return __off_;}

    _LIBCPP_INLINE_VISIBILITY _StateT state() const {return __st_;}
    _LIBCPP_INLINE_VISIBILITY void state(_StateT __st) {__st_ = __st;}

    _LIBCPP_INLINE_VISIBILITY fpos& operator+=(streamoff __off) {__off_ += __off; return *this;}
    _LIBCPP_INLINE_VISIBILITY fpos  operator+ (streamoff __off) const {fpos __t(*this); __t += __off; return __t;}
    _LIBCPP_INLINE_VISIBILITY fpos& operator-=(streamoff __off) {__off_ -= __off; return *this;}
    _LIBCPP_INLINE_VISIBILITY fpos  operator- (streamoff __off) const {fpos __t(*this); __t -= __off; return __t;}
};

template <class _StateT>
inline _LIBCPP_INLINE_VISIBILITY
streamoff operator-(const fpos<_StateT>& __x, const fpos<_StateT>& __y)
    {return streamoff(__x) - streamoff(__y);}

template <class _StateT>
inline _LIBCPP_INLINE_VISIBILITY
bool operator==(const fpos<_StateT>& __x, const fpos<_StateT>& __y)
    {return streamoff(__x) == streamoff(__y);}

template <class _StateT>
inline _LIBCPP_INLINE_VISIBILITY
bool operator!=(const fpos<_StateT>& __x, const fpos<_StateT>& __y)
    {return streamoff(__x) != streamoff(__y);}

// char_traits

template <class _CharT>
struct _LIBCPP_TYPE_VIS_ONLY char_traits
{
    typedef _CharT    char_type;
    typedef int       int_type;
    typedef streamoff off_type;
    typedef streampos pos_type;
    typedef mbstate_t state_type;

    _LIBCPP_INLINE_VISIBILITY
    static void assign(char_type& __c1, const char_type& __c2) _NOEXCEPT
        {__c1 = __c2;}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR bool eq(char_type __c1, char_type __c2) _NOEXCEPT
        {return __c1 == __c2;}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR bool lt(char_type __c1, char_type __c2) _NOEXCEPT
        {return __c1 < __c2;}

    static int              compare(const char_type* __s1, const char_type* __s2, size_t __n);
    static size_t           length(const char_type* __s);
    static const char_type* find(const char_type* __s, size_t __n, const char_type& __a);
    static char_type*       move(char_type* __s1, const char_type* __s2, size_t __n);
    static char_type*       copy(char_type* __s1, const char_type* __s2, size_t __n);
    static char_type*       assign(char_type* __s, size_t __n, char_type __a);

    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR int_type  not_eof(int_type __c) _NOEXCEPT
        {return eq_int_type(__c, eof()) ? ~eof() : __c;}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR char_type to_char_type(int_type __c) _NOEXCEPT
        {return char_type(__c);}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR int_type  to_int_type(char_type __c) _NOEXCEPT
        {return int_type(__c);}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR bool      eq_int_type(int_type __c1, int_type __c2) _NOEXCEPT
        {return __c1 == __c2;}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR int_type  eof() _NOEXCEPT
        {return int_type(EOF);}
};

template <class _CharT>
int
char_traits<_CharT>::compare(const char_type* __s1, const char_type* __s2, size_t __n)
{
    for (; __n; --__n, ++__s1, ++__s2)
    {
        if (lt(*__s1, *__s2))
            return -1;
        if (lt(*__s2, *__s1))
            return 1;
    }
    return 0;
}

template <class _CharT>
inline _LIBCPP_INLINE_VISIBILITY
size_t
char_traits<_CharT>::length(const char_type* __s)
{
    size_t __len = 0;
    for (; !eq(*__s, char_type(0)); ++__s)
        ++__len;
    return __len;
}

template <class _CharT>
inline _LIBCPP_INLINE_VISIBILITY
const _CharT*
char_traits<_CharT>::find(const char_type* __s, size_t __n, const char_type& __a)
{
    for (; __n; --__n)
    {
        if (eq(*__s, __a))
            return __s;
        ++__s;
    }
    return 0;
}

template <class _CharT>
_CharT*
char_traits<_CharT>::move(char_type* __s1, const char_type* __s2, size_t __n)
{
    char_type* __r = __s1;
    if (__s1 < __s2)
    {
        for (; __n; --__n, ++__s1, ++__s2)
            assign(*__s1, *__s2);
    }
    else if (__s2 < __s1)
    {
        __s1 += __n;
        __s2 += __n;
        for (; __n; --__n)
            assign(*--__s1, *--__s2);
    }
    return __r;
}

template <class _CharT>
inline _LIBCPP_INLINE_VISIBILITY
_CharT*
char_traits<_CharT>::copy(char_type* __s1, const char_type* __s2, size_t __n)
{
    _LIBCPP_ASSERT(__s2 < __s1 || __s2 >= __s1+__n, "char_traits::copy overlapped range");
    char_type* __r = __s1;
    for (; __n; --__n, ++__s1, ++__s2)
        assign(*__s1, *__s2);
    return __r;
}

template <class _CharT>
inline _LIBCPP_INLINE_VISIBILITY
_CharT*
char_traits<_CharT>::assign(char_type* __s, size_t __n, char_type __a)
{
    char_type* __r = __s;
    for (; __n; --__n, ++__s)
        assign(*__s, __a);
    return __r;
}

// char_traits<char>

template <>
struct _LIBCPP_TYPE_VIS_ONLY char_traits<char>
{
    typedef char      char_type;
    typedef int       int_type;
    typedef streamoff off_type;
    typedef streampos pos_type;
    typedef mbstate_t state_type;

    _LIBCPP_INLINE_VISIBILITY
    static void assign(char_type& __c1, const char_type& __c2) _NOEXCEPT
        {__c1 = __c2;}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR bool eq(char_type __c1, char_type __c2) _NOEXCEPT
            {return __c1 == __c2;}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR bool lt(char_type __c1, char_type __c2) _NOEXCEPT
        {return (unsigned char)__c1 < (unsigned char)__c2;}

    _LIBCPP_INLINE_VISIBILITY
    static int compare(const char_type* __s1, const char_type* __s2, size_t __n)
        {return memcmp(__s1, __s2, __n);}
    _LIBCPP_INLINE_VISIBILITY
    static size_t length(const char_type* __s) {return strlen(__s);}
    _LIBCPP_INLINE_VISIBILITY
    static const char_type* find(const char_type* __s, size_t __n, const char_type& __a)
        {return (const char_type*)memchr(__s, to_int_type(__a), __n);}
    _LIBCPP_INLINE_VISIBILITY
    static char_type* move(char_type* __s1, const char_type* __s2, size_t __n)
        {return (char_type*)memmove(__s1, __s2, __n);}
    _LIBCPP_INLINE_VISIBILITY
    static char_type* copy(char_type* __s1, const char_type* __s2, size_t __n)
        {
            _LIBCPP_ASSERT(__s2 < __s1 || __s2 >= __s1+__n, "char_traits::copy overlapped range");
            return (char_type*)memcpy(__s1, __s2, __n);
        }
    _LIBCPP_INLINE_VISIBILITY
    static char_type* assign(char_type* __s, size_t __n, char_type __a)
        {return (char_type*)memset(__s, to_int_type(__a), __n);}

    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR int_type  not_eof(int_type __c) _NOEXCEPT
        {return eq_int_type(__c, eof()) ? ~eof() : __c;}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR char_type to_char_type(int_type __c) _NOEXCEPT
        {return char_type(__c);}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR int_type to_int_type(char_type __c) _NOEXCEPT
        {return int_type((unsigned char)__c);}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR bool eq_int_type(int_type __c1, int_type __c2) _NOEXCEPT
        {return __c1 == __c2;}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR int_type  eof() _NOEXCEPT
        {return int_type(EOF);}
};

// char_traits<wchar_t>

template <>
struct _LIBCPP_TYPE_VIS_ONLY char_traits<wchar_t>
{
    typedef wchar_t   char_type;
    typedef wint_t    int_type;
    typedef streamoff off_type;
    typedef streampos pos_type;
    typedef mbstate_t state_type;

    _LIBCPP_INLINE_VISIBILITY
    static void assign(char_type& __c1, const char_type& __c2) _NOEXCEPT
        {__c1 = __c2;}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR bool eq(char_type __c1, char_type __c2) _NOEXCEPT
        {return __c1 == __c2;}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR bool lt(char_type __c1, char_type __c2) _NOEXCEPT
        {return __c1 < __c2;}

    _LIBCPP_INLINE_VISIBILITY
    static int compare(const char_type* __s1, const char_type* __s2, size_t __n)
        {return wmemcmp(__s1, __s2, __n);}
    _LIBCPP_INLINE_VISIBILITY
    static size_t length(const char_type* __s)
        {return wcslen(__s);}
    _LIBCPP_INLINE_VISIBILITY
    static const char_type* find(const char_type* __s, size_t __n, const char_type& __a)
        {return (const char_type*)wmemchr(__s, __a, __n);}
    _LIBCPP_INLINE_VISIBILITY
    static char_type* move(char_type* __s1, const char_type* __s2, size_t __n)
        {return (char_type*)wmemmove(__s1, __s2, __n);}
    _LIBCPP_INLINE_VISIBILITY
    static char_type* copy(char_type* __s1, const char_type* __s2, size_t __n)
        {
            _LIBCPP_ASSERT(__s2 < __s1 || __s2 >= __s1+__n, "char_traits::copy overlapped range");
            return (char_type*)wmemcpy(__s1, __s2, __n);
        }
    _LIBCPP_INLINE_VISIBILITY
    static char_type* assign(char_type* __s, size_t __n, char_type __a)
        {return (char_type*)wmemset(__s, __a, __n);}

    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR int_type  not_eof(int_type __c) _NOEXCEPT
        {return eq_int_type(__c, eof()) ? ~eof() : __c;}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR char_type to_char_type(int_type __c) _NOEXCEPT
        {return char_type(__c);}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR int_type to_int_type(char_type __c) _NOEXCEPT
        {return int_type(__c);}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR bool eq_int_type(int_type __c1, int_type __c2) _NOEXCEPT
        {return __c1 == __c2;}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR int_type eof() _NOEXCEPT
        {return int_type(WEOF);}
};

#ifndef _LIBCPP_HAS_NO_UNICODE_CHARS

template <>
struct _LIBCPP_TYPE_VIS_ONLY char_traits<char16_t>
{
    typedef char16_t       char_type;
    typedef uint_least16_t int_type;
    typedef streamoff      off_type;
    typedef u16streampos   pos_type;
    typedef mbstate_t      state_type;

    _LIBCPP_INLINE_VISIBILITY
    static void assign(char_type& __c1, const char_type& __c2) _NOEXCEPT
        {__c1 = __c2;}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR bool eq(char_type __c1, char_type __c2) _NOEXCEPT
        {return __c1 == __c2;}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR bool lt(char_type __c1, char_type __c2) _NOEXCEPT
        {return __c1 < __c2;}

    static int              compare(const char_type* __s1, const char_type* __s2, size_t __n);
    static size_t           length(const char_type* __s);
    static const char_type* find(const char_type* __s, size_t __n, const char_type& __a);
    static char_type*       move(char_type* __s1, const char_type* __s2, size_t __n);
    static char_type*       copy(char_type* __s1, const char_type* __s2, size_t __n);
    static char_type*       assign(char_type* __s, size_t __n, char_type __a);

    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR int_type  not_eof(int_type __c) _NOEXCEPT
        {return eq_int_type(__c, eof()) ? ~eof() : __c;}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR char_type to_char_type(int_type __c) _NOEXCEPT
        {return char_type(__c);}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR int_type to_int_type(char_type __c) _NOEXCEPT
        {return int_type(__c);}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR bool eq_int_type(int_type __c1, int_type __c2) _NOEXCEPT
        {return __c1 == __c2;}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR int_type eof() _NOEXCEPT
        {return int_type(0xDFFF);}
};

inline _LIBCPP_INLINE_VISIBILITY
int
char_traits<char16_t>::compare(const char_type* __s1, const char_type* __s2, size_t __n)
{
    for (; __n; --__n, ++__s1, ++__s2)
    {
        if (lt(*__s1, *__s2))
            return -1;
        if (lt(*__s2, *__s1))
            return 1;
    }
    return 0;
}

inline _LIBCPP_INLINE_VISIBILITY
size_t
char_traits<char16_t>::length(const char_type* __s)
{
    size_t __len = 0;
    for (; !eq(*__s, char_type(0)); ++__s)
        ++__len;
    return __len;
}

inline _LIBCPP_INLINE_VISIBILITY
const char16_t*
char_traits<char16_t>::find(const char_type* __s, size_t __n, const char_type& __a)
{
    for (; __n; --__n)
    {
        if (eq(*__s, __a))
            return __s;
        ++__s;
    }
    return 0;
}

inline _LIBCPP_INLINE_VISIBILITY
char16_t*
char_traits<char16_t>::move(char_type* __s1, const char_type* __s2, size_t __n)
{
    char_type* __r = __s1;
    if (__s1 < __s2)
    {
        for (; __n; --__n, ++__s1, ++__s2)
            assign(*__s1, *__s2);
    }
    else if (__s2 < __s1)
    {
        __s1 += __n;
        __s2 += __n;
        for (; __n; --__n)
            assign(*--__s1, *--__s2);
    }
    return __r;
}

inline _LIBCPP_INLINE_VISIBILITY
char16_t*
char_traits<char16_t>::copy(char_type* __s1, const char_type* __s2, size_t __n)
{
    _LIBCPP_ASSERT(__s2 < __s1 || __s2 >= __s1+__n, "char_traits::copy overlapped range");
    char_type* __r = __s1;
    for (; __n; --__n, ++__s1, ++__s2)
        assign(*__s1, *__s2);
    return __r;
}

inline _LIBCPP_INLINE_VISIBILITY
char16_t*
char_traits<char16_t>::assign(char_type* __s, size_t __n, char_type __a)
{
    char_type* __r = __s;
    for (; __n; --__n, ++__s)
        assign(*__s, __a);
    return __r;
}

template <>
struct _LIBCPP_TYPE_VIS_ONLY char_traits<char32_t>
{
    typedef char32_t       char_type;
    typedef uint_least32_t int_type;
    typedef streamoff      off_type;
    typedef u32streampos   pos_type;
    typedef mbstate_t      state_type;

    _LIBCPP_INLINE_VISIBILITY
    static void assign(char_type& __c1, const char_type& __c2) _NOEXCEPT
        {__c1 = __c2;}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR bool eq(char_type __c1, char_type __c2) _NOEXCEPT
        {return __c1 == __c2;}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR bool lt(char_type __c1, char_type __c2) _NOEXCEPT
        {return __c1 < __c2;}

    static int              compare(const char_type* __s1, const char_type* __s2, size_t __n);
    static size_t           length(const char_type* __s);
    static const char_type* find(const char_type* __s, size_t __n, const char_type& __a);
    static char_type*       move(char_type* __s1, const char_type* __s2, size_t __n);
    static char_type*       copy(char_type* __s1, const char_type* __s2, size_t __n);
    static char_type*       assign(char_type* __s, size_t __n, char_type __a);

    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR int_type  not_eof(int_type __c) _NOEXCEPT
        {return eq_int_type(__c, eof()) ? ~eof() : __c;}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR char_type to_char_type(int_type __c) _NOEXCEPT
        {return char_type(__c);}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR int_type to_int_type(char_type __c) _NOEXCEPT
        {return int_type(__c);}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR bool eq_int_type(int_type __c1, int_type __c2) _NOEXCEPT
        {return __c1 == __c2;}
    _LIBCPP_INLINE_VISIBILITY
    static _LIBCPP_CONSTEXPR int_type eof() _NOEXCEPT
        {return int_type(0xFFFFFFFF);}
};

inline _LIBCPP_INLINE_VISIBILITY
int
char_traits<char32_t>::compare(const char_type* __s1, const char_type* __s2, size_t __n)
{
    for (; __n; --__n, ++__s1, ++__s2)
    {
        if (lt(*__s1, *__s2))
            return -1;
        if (lt(*__s2, *__s1))
            return 1;
    }
    return 0;
}

inline _LIBCPP_INLINE_VISIBILITY
size_t
char_traits<char32_t>::length(const char_type* __s)
{
    size_t __len = 0;
    for (; !eq(*__s, char_type(0)); ++__s)
        ++__len;
    return __len;
}

inline _LIBCPP_INLINE_VISIBILITY
const char32_t*
char_traits<char32_t>::find(const char_type* __s, size_t __n, const char_type& __a)
{
    for (; __n; --__n)
    {
        if (eq(*__s, __a))
            return __s;
        ++__s;
    }
    return 0;
}

inline _LIBCPP_INLINE_VISIBILITY
char32_t*
char_traits<char32_t>::move(char_type* __s1, const char_type* __s2, size_t __n)
{
    char_type* __r = __s1;
    if (__s1 < __s2)
    {
        for (; __n; --__n, ++__s1, ++__s2)
            assign(*__s1, *__s2);
    }
    else if (__s2 < __s1)
    {
        __s1 += __n;
        __s2 += __n;
        for (; __n; --__n)
            assign(*--__s1, *--__s2);
    }
    return __r;
}

inline _LIBCPP_INLINE_VISIBILITY
char32_t*
char_traits<char32_t>::copy(char_type* __s1, const char_type* __s2, size_t __n)
{
    _LIBCPP_ASSERT(__s2 < __s1 || __s2 >= __s1+__n, "char_traits::copy overlapped range");
    char_type* __r = __s1;
    for (; __n; --__n, ++__s1, ++__s2)
        assign(*__s1, *__s2);
    return __r;
}

inline _LIBCPP_INLINE_VISIBILITY
char32_t*
char_traits<char32_t>::assign(char_type* __s, size_t __n, char_type __a)
{
    char_type* __r = __s;
    for (; __n; --__n, ++__s)
        assign(*__s, __a);
    return __r;
}

#endif  // _LIBCPP_HAS_NO_UNICODE_CHARS
# 990 "/usr/include/c++/v1/string" 3

// basic_string

template<class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>
operator+(const basic_string<_CharT, _Traits, _Allocator>& __x,
          const basic_string<_CharT, _Traits, _Allocator>& __y);

template<class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>
operator+(const _CharT* __x, const basic_string<_CharT,_Traits,_Allocator>& __y);

template<class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>
operator+(_CharT __x, const basic_string<_CharT,_Traits,_Allocator>& __y);

template<class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>
operator+(const basic_string<_CharT, _Traits, _Allocator>& __x, const _CharT* __y);

template<class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>
operator+(const basic_string<_CharT, _Traits, _Allocator>& __x, _CharT __y);

template <bool>
class _LIBCPP_TYPE_VIS_ONLY __basic_string_common
{
protected:
    void __throw_length_error() const;
    void __throw_out_of_range() const;
};

template <bool __b>
void
__basic_string_common<__b>::__throw_length_error() const
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    throw length_error("basic_string");
#else
# 1029 "/usr/include/c++/v1/string" 3
    assert(!"basic_string length_error");
#endif
# 1031 "/usr/include/c++/v1/string" 3
}

template <bool __b>
void
__basic_string_common<__b>::__throw_out_of_range() const
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    throw out_of_range("basic_string");
#else
# 1040 "/usr/include/c++/v1/string" 3
    assert(!"basic_string out_of_range");
#endif
# 1042 "/usr/include/c++/v1/string" 3
}

#ifdef _LIBCPP_MSVC
#pragma warning( push )
#pragma warning( disable: 4231 )
#endif // _LIBCPP_MSVC
# 1048 "/usr/include/c++/v1/string" 3
_LIBCPP_EXTERN_TEMPLATE(class _LIBCPP_TYPE_VIS __basic_string_common<true>)
#ifdef _LIBCPP_MSVC
#pragma warning( pop )
#endif // _LIBCPP_MSVC
# 1052 "/usr/include/c++/v1/string" 3

#ifdef _LIBCPP_ALTERNATE_STRING_LAYOUT

template <class _CharT, size_t = sizeof(_CharT)>
struct __padding
{
    unsigned char __xx[sizeof(_CharT)-1];
};

template <class _CharT>
struct __padding<_CharT, 1>
{
};

#endif  // _LIBCPP_ALTERNATE_STRING_LAYOUT
# 1067 "/usr/include/c++/v1/string" 3

template<class _CharT, class _Traits, class _Allocator>
class _LIBCPP_TYPE_VIS_ONLY basic_string
    : private __basic_string_common<true>
{
public:
    typedef basic_string                                 __self;
    typedef _Traits                                      traits_type;
    typedef typename traits_type::char_type              value_type;
    typedef _Allocator                                   allocator_type;
    typedef allocator_traits<allocator_type>             __alloc_traits;
    typedef typename __alloc_traits::size_type           size_type;
    typedef typename __alloc_traits::difference_type     difference_type;
    typedef value_type&                                  reference;
    typedef const value_type&                            const_reference;
    typedef typename __alloc_traits::pointer             pointer;
    typedef typename __alloc_traits::const_pointer       const_pointer;

    static_assert(is_pod<value_type>::value, "Character type of basic_string must be a POD");
    static_assert((is_same<_CharT, value_type>::value),
                  "traits_type::char_type must be the same type as CharT");
    static_assert((is_same<typename allocator_type::value_type, value_type>::value),
                  "Allocator::value_type must be same type as value_type");
#if defined(_LIBCPP_RAW_ITERATORS)
    typedef pointer                                      iterator;
    typedef const_pointer                                const_iterator;
#else  // defined(_LIBCPP_RAW_ITERATORS)
# 1094 "/usr/include/c++/v1/string" 3
    typedef __wrap_iter<pointer>                         iterator;
    typedef __wrap_iter<const_pointer>                   const_iterator;
#endif  // defined(_LIBCPP_RAW_ITERATORS)
# 1097 "/usr/include/c++/v1/string" 3
    typedef _VSTD::reverse_iterator<iterator>             reverse_iterator;
    typedef _VSTD::reverse_iterator<const_iterator>       const_reverse_iterator;

private:

#ifdef _LIBCPP_ALTERNATE_STRING_LAYOUT

    struct __long
    {
        pointer   __data_;
        size_type __size_;
        size_type __cap_;
    };

#if _LIBCPP_BIG_ENDIAN
    enum {__short_mask = 0x01};
    enum {__long_mask  = 0x1ul};
#else  // _LIBCPP_BIG_ENDIAN
# 1115 "/usr/include/c++/v1/string" 3
    enum {__short_mask = 0x80};
    enum {__long_mask  = ~(size_type(~0) >> 1)};
#endif  // _LIBCPP_BIG_ENDIAN
# 1118 "/usr/include/c++/v1/string" 3

    enum {__min_cap = (sizeof(__long) - 1)/sizeof(value_type) > 2 ?
                      (sizeof(__long) - 1)/sizeof(value_type) : 2};

    struct __short
    {
        value_type __data_[__min_cap];
        struct
            : __padding<value_type>
        {
            unsigned char __size_;
        };
    };

#else
# 1133 "/usr/include/c++/v1/string" 3

    struct __long
    {
        size_type __cap_;
        size_type __size_;
        pointer   __data_;
    };

#if _LIBCPP_BIG_ENDIAN
    enum {__short_mask = 0x80};
    enum {__long_mask  = ~(size_type(~0) >> 1)};
#else  // _LIBCPP_BIG_ENDIAN
# 1145 "/usr/include/c++/v1/string" 3
    enum {__short_mask = 0x01};
    enum {__long_mask  = 0x1ul};
#endif  // _LIBCPP_BIG_ENDIAN
# 1148 "/usr/include/c++/v1/string" 3

    enum {__min_cap = (sizeof(__long) - 1)/sizeof(value_type) > 2 ?
                      (sizeof(__long) - 1)/sizeof(value_type) : 2};

    struct __short
    {
        union
        {
            unsigned char __size_;
            value_type __lx;
        };
        value_type __data_[__min_cap];
    };

#endif  // _LIBCPP_ALTERNATE_STRING_LAYOUT
# 1163 "/usr/include/c++/v1/string" 3

    union __ulx{__long __lx; __short __lxx;};

    enum {__n_words = sizeof(__ulx) / sizeof(size_type)};

    struct __raw
    {
        size_type __words[__n_words];
    };

    struct __rep
    {
        union
        {
            __long  __l;
            __short __s;
            __raw   __r;
        };
    };

    __compressed_pair<__rep, allocator_type> __r_;

public:
    static const size_type npos = -1;

    _LIBCPP_INLINE_VISIBILITY basic_string()
        _NOEXCEPT_(is_nothrow_default_constructible<allocator_type>::value);
    _LIBCPP_INLINE_VISIBILITY explicit basic_string(const allocator_type& __a);
    basic_string(const basic_string& __str);
    basic_string(const basic_string& __str, const allocator_type& __a);
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    _LIBCPP_INLINE_VISIBILITY
    basic_string(basic_string&& __str)
        _NOEXCEPT_(is_nothrow_move_constructible<allocator_type>::value);
    _LIBCPP_INLINE_VISIBILITY
    basic_string(basic_string&& __str, const allocator_type& __a);
#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 1200 "/usr/include/c++/v1/string" 3
    _LIBCPP_INLINE_VISIBILITY basic_string(const value_type* __s);
    _LIBCPP_INLINE_VISIBILITY
    basic_string(const value_type* __s, const allocator_type& __a);
    _LIBCPP_INLINE_VISIBILITY
    basic_string(const value_type* __s, size_type __n);
    _LIBCPP_INLINE_VISIBILITY
    basic_string(const value_type* __s, size_type __n, const allocator_type& __a);
    _LIBCPP_INLINE_VISIBILITY
    basic_string(size_type __n, value_type __c);
    _LIBCPP_INLINE_VISIBILITY
    basic_string(size_type __n, value_type __c, const allocator_type& __a);
    basic_string(const basic_string& __str, size_type __pos, size_type __n = npos,
                 const allocator_type& __a = allocator_type());
    template<class _InputIterator>
        _LIBCPP_INLINE_VISIBILITY
        basic_string(_InputIterator __first, _InputIterator __last);
    template<class _InputIterator>
        _LIBCPP_INLINE_VISIBILITY
        basic_string(_InputIterator __first, _InputIterator __last, const allocator_type& __a);
#ifndef _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
    _LIBCPP_INLINE_VISIBILITY
    basic_string(initializer_list<value_type> __il);
    _LIBCPP_INLINE_VISIBILITY
    basic_string(initializer_list<value_type> __il, const allocator_type& __a);
#endif  // _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
# 1225 "/usr/include/c++/v1/string" 3

    ~basic_string();

    basic_string& operator=(const basic_string& __str);
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    _LIBCPP_INLINE_VISIBILITY
    basic_string& operator=(basic_string&& __str)
        _NOEXCEPT_(__alloc_traits::propagate_on_container_move_assignment::value &&
                   is_nothrow_move_assignable<allocator_type>::value);
#endif
# 1235 "/usr/include/c++/v1/string" 3
    _LIBCPP_INLINE_VISIBILITY basic_string& operator=(const value_type* __s) {return assign(__s);}
    basic_string& operator=(value_type __c);
#ifndef _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
    _LIBCPP_INLINE_VISIBILITY
    basic_string& operator=(initializer_list<value_type> __il) {return assign(__il.begin(), __il.size());}
#endif  // _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
# 1241 "/usr/include/c++/v1/string" 3

#if _LIBCPP_DEBUG_LEVEL >= 2
    _LIBCPP_INLINE_VISIBILITY
    iterator begin() _NOEXCEPT
        {return iterator(this, __get_pointer());}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator begin() const _NOEXCEPT
        {return const_iterator(this, __get_pointer());}
    _LIBCPP_INLINE_VISIBILITY
    iterator end() _NOEXCEPT
        {return iterator(this, __get_pointer() + size());}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator end() const _NOEXCEPT
        {return const_iterator(this, __get_pointer() + size());}
#else
# 1256 "/usr/include/c++/v1/string" 3
    _LIBCPP_INLINE_VISIBILITY
    iterator begin() _NOEXCEPT
        {return iterator(__get_pointer());}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator begin() const _NOEXCEPT
        {return const_iterator(__get_pointer());}
    _LIBCPP_INLINE_VISIBILITY
    iterator end() _NOEXCEPT
        {return iterator(__get_pointer() + size());}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator end() const _NOEXCEPT
        {return const_iterator(__get_pointer() + size());}
#endif  // _LIBCPP_DEBUG_LEVEL >= 2
# 1269 "/usr/include/c++/v1/string" 3
    _LIBCPP_INLINE_VISIBILITY
    reverse_iterator rbegin() _NOEXCEPT
        {return reverse_iterator(end());}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator rbegin() const _NOEXCEPT
        {return const_reverse_iterator(end());}
    _LIBCPP_INLINE_VISIBILITY
    reverse_iterator rend() _NOEXCEPT
        {return reverse_iterator(begin());}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator rend() const _NOEXCEPT
        {return const_reverse_iterator(begin());}

    _LIBCPP_INLINE_VISIBILITY
    const_iterator cbegin() const _NOEXCEPT
        {return begin();}
    _LIBCPP_INLINE_VISIBILITY
    const_iterator cend() const _NOEXCEPT
        {return end();}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator crbegin() const _NOEXCEPT
        {return rbegin();}
    _LIBCPP_INLINE_VISIBILITY
    const_reverse_iterator crend() const _NOEXCEPT
        {return rend();}

    _LIBCPP_INLINE_VISIBILITY size_type size() const _NOEXCEPT
        {return __is_long() ? __get_long_size() : __get_short_size();}
    _LIBCPP_INLINE_VISIBILITY size_type length() const _NOEXCEPT {return size();}
    _LIBCPP_INLINE_VISIBILITY size_type max_size() const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY size_type capacity() const _NOEXCEPT
        {return (__is_long() ? __get_long_cap() : __min_cap) - 1;}

    void resize(size_type __n, value_type __c);
    _LIBCPP_INLINE_VISIBILITY void resize(size_type __n) {resize(__n, value_type());}

    void reserve(size_type res_arg = 0);
    _LIBCPP_INLINE_VISIBILITY
    void shrink_to_fit() _NOEXCEPT {reserve();}
    _LIBCPP_INLINE_VISIBILITY
    void clear() _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY bool empty() const _NOEXCEPT {return size() == 0;}

    _LIBCPP_INLINE_VISIBILITY const_reference operator[](size_type __pos) const;
    _LIBCPP_INLINE_VISIBILITY reference       operator[](size_type __pos);

    const_reference at(size_type __n) const;
    reference       at(size_type __n);

    _LIBCPP_INLINE_VISIBILITY basic_string& operator+=(const basic_string& __str) {return append(__str);}
    _LIBCPP_INLINE_VISIBILITY basic_string& operator+=(const value_type* __s)         {return append(__s);}
    _LIBCPP_INLINE_VISIBILITY basic_string& operator+=(value_type __c)            {push_back(__c); return *this;}
#ifndef _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
    _LIBCPP_INLINE_VISIBILITY basic_string& operator+=(initializer_list<value_type> __il) {return append(__il);}
#endif  // _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
# 1324 "/usr/include/c++/v1/string" 3

    _LIBCPP_INLINE_VISIBILITY
    basic_string& append(const basic_string& __str);
    basic_string& append(const basic_string& __str, size_type __pos, size_type __n);
    basic_string& append(const value_type* __s, size_type __n);
    basic_string& append(const value_type* __s);
    basic_string& append(size_type __n, value_type __c);
    template<class _InputIterator>
        typename enable_if
        <
             __is_input_iterator  <_InputIterator>::value &&
            !__is_forward_iterator<_InputIterator>::value,
            basic_string&
        >::type
        append(_InputIterator __first, _InputIterator __last);
    template<class _ForwardIterator>
        typename enable_if
        <
            __is_forward_iterator<_ForwardIterator>::value,
            basic_string&
        >::type
        append(_ForwardIterator __first, _ForwardIterator __last);
#ifndef _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
    _LIBCPP_INLINE_VISIBILITY
    basic_string& append(initializer_list<value_type> __il) {return append(__il.begin(), __il.size());}
#endif  // _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
# 1350 "/usr/include/c++/v1/string" 3

    void push_back(value_type __c);
    _LIBCPP_INLINE_VISIBILITY
    void pop_back();
    _LIBCPP_INLINE_VISIBILITY reference       front();
    _LIBCPP_INLINE_VISIBILITY const_reference front() const;
    _LIBCPP_INLINE_VISIBILITY reference       back();
    _LIBCPP_INLINE_VISIBILITY const_reference back() const;

    _LIBCPP_INLINE_VISIBILITY
    basic_string& assign(const basic_string& __str);
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    _LIBCPP_INLINE_VISIBILITY
    basic_string& assign(basic_string&& str)
        {*this = _VSTD::move(str); return *this;}
#endif
# 1366 "/usr/include/c++/v1/string" 3
    basic_string& assign(const basic_string& __str, size_type __pos, size_type __n);
    basic_string& assign(const value_type* __s, size_type __n);
    basic_string& assign(const value_type* __s);
    basic_string& assign(size_type __n, value_type __c);
    template<class _InputIterator>
        typename enable_if
        <
             __is_input_iterator  <_InputIterator>::value &&
            !__is_forward_iterator<_InputIterator>::value,
            basic_string&
        >::type
        assign(_InputIterator __first, _InputIterator __last);
    template<class _ForwardIterator>
        typename enable_if
        <
            __is_forward_iterator<_ForwardIterator>::value,
            basic_string&
        >::type
        assign(_ForwardIterator __first, _ForwardIterator __last);
#ifndef _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
    _LIBCPP_INLINE_VISIBILITY
    basic_string& assign(initializer_list<value_type> __il) {return assign(__il.begin(), __il.size());}
#endif  // _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
# 1389 "/usr/include/c++/v1/string" 3

    _LIBCPP_INLINE_VISIBILITY
    basic_string& insert(size_type __pos1, const basic_string& __str);
    basic_string& insert(size_type __pos1, const basic_string& __str, size_type __pos2, size_type __n);
    basic_string& insert(size_type __pos, const value_type* __s, size_type __n);
    basic_string& insert(size_type __pos, const value_type* __s);
    basic_string& insert(size_type __pos, size_type __n, value_type __c);
    iterator      insert(const_iterator __pos, value_type __c);
    _LIBCPP_INLINE_VISIBILITY
    iterator      insert(const_iterator __pos, size_type __n, value_type __c);
    template<class _InputIterator>
        typename enable_if
        <
             __is_input_iterator  <_InputIterator>::value &&
            !__is_forward_iterator<_InputIterator>::value,
            iterator
        >::type
        insert(const_iterator __pos, _InputIterator __first, _InputIterator __last);
    template<class _ForwardIterator>
        typename enable_if
        <
            __is_forward_iterator<_ForwardIterator>::value,
            iterator
        >::type
        insert(const_iterator __pos, _ForwardIterator __first, _ForwardIterator __last);
#ifndef _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
    _LIBCPP_INLINE_VISIBILITY
    iterator insert(const_iterator __pos, initializer_list<value_type> __il)
                    {return insert(__pos, __il.begin(), __il.end());}
#endif  // _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
# 1419 "/usr/include/c++/v1/string" 3

    basic_string& erase(size_type __pos = 0, size_type __n = npos);
    _LIBCPP_INLINE_VISIBILITY
    iterator      erase(const_iterator __pos);
    _LIBCPP_INLINE_VISIBILITY
    iterator      erase(const_iterator __first, const_iterator __last);

    _LIBCPP_INLINE_VISIBILITY
    basic_string& replace(size_type __pos1, size_type __n1, const basic_string& __str);
    basic_string& replace(size_type __pos1, size_type __n1, const basic_string& __str, size_type __pos2, size_type __n2);
    basic_string& replace(size_type __pos, size_type __n1, const value_type* __s, size_type __n2);
    basic_string& replace(size_type __pos, size_type __n1, const value_type* __s);
    basic_string& replace(size_type __pos, size_type __n1, size_type __n2, value_type __c);
    _LIBCPP_INLINE_VISIBILITY
    basic_string& replace(const_iterator __i1, const_iterator __i2, const basic_string& __str);
    _LIBCPP_INLINE_VISIBILITY
    basic_string& replace(const_iterator __i1, const_iterator __i2, const value_type* __s, size_type __n);
    _LIBCPP_INLINE_VISIBILITY
    basic_string& replace(const_iterator __i1, const_iterator __i2, const value_type* __s);
    _LIBCPP_INLINE_VISIBILITY
    basic_string& replace(const_iterator __i1, const_iterator __i2, size_type __n, value_type __c);
    template<class _InputIterator>
        typename enable_if
        <
            __is_input_iterator<_InputIterator>::value,
            basic_string&
        >::type
        replace(const_iterator __i1, const_iterator __i2, _InputIterator __j1, _InputIterator __j2);
#ifndef _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
    _LIBCPP_INLINE_VISIBILITY
    basic_string& replace(const_iterator __i1, const_iterator __i2, initializer_list<value_type> __il)
        {return replace(__i1, __i2, __il.begin(), __il.end());}
#endif  // _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
# 1452 "/usr/include/c++/v1/string" 3

    size_type copy(value_type* __s, size_type __n, size_type __pos = 0) const;
    _LIBCPP_INLINE_VISIBILITY
    basic_string substr(size_type __pos = 0, size_type __n = npos) const;

    _LIBCPP_INLINE_VISIBILITY
    void swap(basic_string& __str)
        _NOEXCEPT_(!__alloc_traits::propagate_on_container_swap::value ||
                   __is_nothrow_swappable<allocator_type>::value);

    _LIBCPP_INLINE_VISIBILITY
    const value_type* c_str() const _NOEXCEPT {return data();}
    _LIBCPP_INLINE_VISIBILITY
    const value_type* data() const _NOEXCEPT  {return _VSTD::__to_raw_pointer(__get_pointer());}

    _LIBCPP_INLINE_VISIBILITY
    allocator_type get_allocator() const _NOEXCEPT {return __alloc();}

    _LIBCPP_INLINE_VISIBILITY
    size_type find(const basic_string& __str, size_type __pos = 0) const _NOEXCEPT;
    size_type find(const value_type* __s, size_type __pos, size_type __n) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    size_type find(const value_type* __s, size_type __pos = 0) const _NOEXCEPT;
    size_type find(value_type __c, size_type __pos = 0) const _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    size_type rfind(const basic_string& __str, size_type __pos = npos) const _NOEXCEPT;
    size_type rfind(const value_type* __s, size_type __pos, size_type __n) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    size_type rfind(const value_type* __s, size_type __pos = npos) const _NOEXCEPT;
    size_type rfind(value_type __c, size_type __pos = npos) const _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    size_type find_first_of(const basic_string& __str, size_type __pos = 0) const _NOEXCEPT;
    size_type find_first_of(const value_type* __s, size_type __pos, size_type __n) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    size_type find_first_of(const value_type* __s, size_type __pos = 0) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    size_type find_first_of(value_type __c, size_type __pos = 0) const _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    size_type find_last_of(const basic_string& __str, size_type __pos = npos) const _NOEXCEPT;
    size_type find_last_of(const value_type* __s, size_type __pos, size_type __n) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    size_type find_last_of(const value_type* __s, size_type __pos = npos) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    size_type find_last_of(value_type __c, size_type __pos = npos) const _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    size_type find_first_not_of(const basic_string& __str, size_type __pos = 0) const _NOEXCEPT;
    size_type find_first_not_of(const value_type* __s, size_type __pos, size_type __n) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    size_type find_first_not_of(const value_type* __s, size_type __pos = 0) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    size_type find_first_not_of(value_type __c, size_type __pos = 0) const _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    size_type find_last_not_of(const basic_string& __str, size_type __pos = npos) const _NOEXCEPT;
    size_type find_last_not_of(const value_type* __s, size_type __pos, size_type __n) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    size_type find_last_not_of(const value_type* __s, size_type __pos = npos) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    size_type find_last_not_of(value_type __c, size_type __pos = npos) const _NOEXCEPT;

    _LIBCPP_INLINE_VISIBILITY
    int compare(const basic_string& __str) const _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY
    int compare(size_type __pos1, size_type __n1, const basic_string& __str) const;
    int compare(size_type __pos1, size_type __n1, const basic_string& __str, size_type __pos2, size_type __n2) const;
    int compare(const value_type* __s) const _NOEXCEPT;
    int compare(size_type __pos1, size_type __n1, const value_type* __s) const;
    int compare(size_type __pos1, size_type __n1, const value_type* __s, size_type __n2) const;

    _LIBCPP_INLINE_VISIBILITY bool __invariants() const;

    _LIBCPP_INLINE_VISIBILITY
    bool __is_long() const _NOEXCEPT
        {return bool(__r_.first().__s.__size_ & __short_mask);}

#if _LIBCPP_DEBUG_LEVEL >= 2

    bool __dereferenceable(const const_iterator* __i) const;
    bool __decrementable(const const_iterator* __i) const;
    bool __addable(const const_iterator* __i, ptrdiff_t __n) const;
    bool __subscriptable(const const_iterator* __i, ptrdiff_t __n) const;

#endif  // _LIBCPP_DEBUG_LEVEL >= 2
# 1539 "/usr/include/c++/v1/string" 3

private:
    _LIBCPP_INLINE_VISIBILITY
    allocator_type& __alloc() _NOEXCEPT
        {return __r_.second();}
    _LIBCPP_INLINE_VISIBILITY
    const allocator_type& __alloc() const _NOEXCEPT
        {return __r_.second();}

#ifdef _LIBCPP_ALTERNATE_STRING_LAYOUT

    _LIBCPP_INLINE_VISIBILITY
    void __set_short_size(size_type __s) _NOEXCEPT
#   if _LIBCPP_BIG_ENDIAN
        {__r_.first().__s.__size_ = (unsigned char)(__s << 1);}
#   else
# 1555 "/usr/include/c++/v1/string" 3
        {__r_.first().__s.__size_ = (unsigned char)(__s);}
#   endif
# 1557 "/usr/include/c++/v1/string" 3

    _LIBCPP_INLINE_VISIBILITY
    size_type __get_short_size() const _NOEXCEPT
#   if _LIBCPP_BIG_ENDIAN
        {return __r_.first().__s.__size_ >> 1;}
#   else
# 1563 "/usr/include/c++/v1/string" 3
        {return __r_.first().__s.__size_;}
#   endif
# 1565 "/usr/include/c++/v1/string" 3

#else  // _LIBCPP_ALTERNATE_STRING_LAYOUT
# 1567 "/usr/include/c++/v1/string" 3

    _LIBCPP_INLINE_VISIBILITY
    void __set_short_size(size_type __s) _NOEXCEPT
#   if _LIBCPP_BIG_ENDIAN
        {__r_.first().__s.__size_ = (unsigned char)(__s);}
#   else
# 1573 "/usr/include/c++/v1/string" 3
        {__r_.first().__s.__size_ = (unsigned char)(__s << 1);}
#   endif
# 1575 "/usr/include/c++/v1/string" 3

    _LIBCPP_INLINE_VISIBILITY
    size_type __get_short_size() const _NOEXCEPT
#   if _LIBCPP_BIG_ENDIAN
        {return __r_.first().__s.__size_;}
#   else
# 1581 "/usr/include/c++/v1/string" 3
        {return __r_.first().__s.__size_ >> 1;}
#   endif
# 1583 "/usr/include/c++/v1/string" 3

#endif  // _LIBCPP_ALTERNATE_STRING_LAYOUT
# 1585 "/usr/include/c++/v1/string" 3

    _LIBCPP_INLINE_VISIBILITY
    void __set_long_size(size_type __s) _NOEXCEPT
        {__r_.first().__l.__size_ = __s;}
    _LIBCPP_INLINE_VISIBILITY
    size_type __get_long_size() const _NOEXCEPT
        {return __r_.first().__l.__size_;}
    _LIBCPP_INLINE_VISIBILITY
    void __set_size(size_type __s) _NOEXCEPT
        {if (__is_long()) __set_long_size(__s); else __set_short_size(__s);}

    _LIBCPP_INLINE_VISIBILITY
    void __set_long_cap(size_type __s) _NOEXCEPT
        {__r_.first().__l.__cap_  = __long_mask | __s;}
    _LIBCPP_INLINE_VISIBILITY
    size_type __get_long_cap() const _NOEXCEPT
        {return __r_.first().__l.__cap_ & size_type(~__long_mask);}

    _LIBCPP_INLINE_VISIBILITY
    void __set_long_pointer(pointer __p) _NOEXCEPT
        {__r_.first().__l.__data_ = __p;}
    _LIBCPP_INLINE_VISIBILITY
    pointer __get_long_pointer() _NOEXCEPT
        {return __r_.first().__l.__data_;}
    _LIBCPP_INLINE_VISIBILITY
    const_pointer __get_long_pointer() const _NOEXCEPT
        {return __r_.first().__l.__data_;}
    _LIBCPP_INLINE_VISIBILITY
    pointer __get_short_pointer() _NOEXCEPT
        {return pointer_traits<pointer>::pointer_to(__r_.first().__s.__data_[0]);}
    _LIBCPP_INLINE_VISIBILITY
    const_pointer __get_short_pointer() const _NOEXCEPT
        {return pointer_traits<const_pointer>::pointer_to(__r_.first().__s.__data_[0]);}
    _LIBCPP_INLINE_VISIBILITY
    pointer __get_pointer() _NOEXCEPT
        {return __is_long() ? __get_long_pointer() : __get_short_pointer();}
    _LIBCPP_INLINE_VISIBILITY
    const_pointer __get_pointer() const _NOEXCEPT
        {return __is_long() ? __get_long_pointer() : __get_short_pointer();}

    _LIBCPP_INLINE_VISIBILITY
    void __zero() _NOEXCEPT
        {
            size_type (&__a)[__n_words] = __r_.first().__r.__words;
            for (unsigned __i = 0; __i < __n_words; ++__i)
                __a[__i] = 0;
        }

    template <size_type __a> static
        _LIBCPP_INLINE_VISIBILITY
        size_type __align_it(size_type __s) _NOEXCEPT
            {return __s + (__a-1) & ~(__a-1);}
    enum {__alignment = 16};
    static _LIBCPP_INLINE_VISIBILITY
    size_type __recommend(size_type __s) _NOEXCEPT
        {return (__s < __min_cap ? __min_cap :
                 __align_it<sizeof(value_type) < __alignment ?
                            __alignment/sizeof(value_type) : 1 > (__s+1)) - 1;}

    void __init(const value_type* __s, size_type __sz, size_type __reserve);
    void __init(const value_type* __s, size_type __sz);
    void __init(size_type __n, value_type __c);

    template <class _InputIterator>
    typename enable_if
    <
         __is_input_iterator  <_InputIterator>::value &&
        !__is_forward_iterator<_InputIterator>::value,
        void
    >::type
    __init(_InputIterator __first, _InputIterator __last);

    template <class _ForwardIterator>
    typename enable_if
    <
        __is_forward_iterator<_ForwardIterator>::value,
        void
    >::type
    __init(_ForwardIterator __first, _ForwardIterator __last);

    void __grow_by(size_type __old_cap, size_type __delta_cap, size_type __old_sz,
                   size_type __n_copy,  size_type __n_del,     size_type __n_add = 0);
    void __grow_by_and_replace(size_type __old_cap, size_type __delta_cap, size_type __old_sz,
                               size_type __n_copy,  size_type __n_del,
                               size_type __n_add, const value_type* __p_new_stuff);

    _LIBCPP_INLINE_VISIBILITY
    void __erase_to_end(size_type __pos);

    _LIBCPP_INLINE_VISIBILITY
    void __copy_assign_alloc(const basic_string& __str)
        {__copy_assign_alloc(__str, integral_constant<bool,
                      __alloc_traits::propagate_on_container_copy_assignment::value>());}

    _LIBCPP_INLINE_VISIBILITY
    void __copy_assign_alloc(const basic_string& __str, true_type)
        {
            if (__alloc() != __str.__alloc())
            {
                clear();
                shrink_to_fit();
            }
            __alloc() = __str.__alloc();
        }

    _LIBCPP_INLINE_VISIBILITY
    void __copy_assign_alloc(const basic_string&, false_type) _NOEXCEPT
        {}

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    _LIBCPP_INLINE_VISIBILITY
    void __move_assign(basic_string& __str, false_type);
    _LIBCPP_INLINE_VISIBILITY
    void __move_assign(basic_string& __str, true_type)
        _NOEXCEPT_(is_nothrow_move_assignable<allocator_type>::value);
#endif
# 1701 "/usr/include/c++/v1/string" 3

    _LIBCPP_INLINE_VISIBILITY
    void
    __move_assign_alloc(basic_string& __str)
        _NOEXCEPT_(
            !__alloc_traits::propagate_on_container_move_assignment::value ||
            is_nothrow_move_assignable<allocator_type>::value)
    {__move_assign_alloc(__str, integral_constant<bool,
                      __alloc_traits::propagate_on_container_move_assignment::value>());}

    _LIBCPP_INLINE_VISIBILITY
    void __move_assign_alloc(basic_string& __c, true_type)
        _NOEXCEPT_(is_nothrow_move_assignable<allocator_type>::value)
        {
            __alloc() = _VSTD::move(__c.__alloc());
        }

    _LIBCPP_INLINE_VISIBILITY
    void __move_assign_alloc(basic_string&, false_type)
        _NOEXCEPT
        {}

    _LIBCPP_INLINE_VISIBILITY
    static void __swap_alloc(allocator_type& __x, allocator_type& __y)
        _NOEXCEPT_(!__alloc_traits::propagate_on_container_swap::value ||
                   __is_nothrow_swappable<allocator_type>::value)
        {__swap_alloc(__x, __y, integral_constant<bool,
                      __alloc_traits::propagate_on_container_swap::value>());}

    _LIBCPP_INLINE_VISIBILITY
    static void __swap_alloc(allocator_type& __x, allocator_type& __y, true_type)
        _NOEXCEPT_(__is_nothrow_swappable<allocator_type>::value)
        {
            using _VSTD::swap;
            swap(__x, __y);
        }
    _LIBCPP_INLINE_VISIBILITY
    static void __swap_alloc(allocator_type&, allocator_type&, false_type) _NOEXCEPT
        {}

    _LIBCPP_INLINE_VISIBILITY void __invalidate_all_iterators();
    _LIBCPP_INLINE_VISIBILITY void __invalidate_iterators_past(size_type);

    friend basic_string operator+<>(const basic_string&, const basic_string&);
    friend basic_string operator+<>(const value_type*, const basic_string&);
    friend basic_string operator+<>(value_type, const basic_string&);
    friend basic_string operator+<>(const basic_string&, const value_type*);
    friend basic_string operator+<>(const basic_string&, value_type);
};

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
basic_string<_CharT, _Traits, _Allocator>::__invalidate_all_iterators()
{
#if _LIBCPP_DEBUG_LEVEL >= 2
    __get_db()->__invalidate_all(this);
#endif  // _LIBCPP_DEBUG_LEVEL >= 2
# 1759 "/usr/include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
basic_string<_CharT, _Traits, _Allocator>::__invalidate_iterators_past(size_type
#if _LIBCPP_DEBUG_LEVEL >= 2
                                                                        __pos
#endif
# 1768 "/usr/include/c++/v1/string" 3
                                                                      )
{
#if _LIBCPP_DEBUG_LEVEL >= 2
    __c_node* __c = __get_db()->__find_c_and_lock(this);
    if (__c)
    {
        const_pointer __new_last = __get_pointer() + __pos;
        for (__i_node** __p = __c->end_; __p != __c->beg_; )
        {
            --__p;
            const_iterator* __i = static_cast<const_iterator*>((*__p)->__i_);
            if (__i->base() > __new_last)
            {
                (*__p)->__c_ = nullptr;
                if (--__c->end_ != __p)
                    memmove(__p, __p+1, (__c->end_ - __p)*sizeof(__i_node*));
            }
        }
        __get_db()->unlock();
    }
#endif  // _LIBCPP_DEBUG_LEVEL >= 2
# 1789 "/usr/include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>::basic_string()
    _NOEXCEPT_(is_nothrow_default_constructible<allocator_type>::value)
{
#if _LIBCPP_DEBUG_LEVEL >= 2
    __get_db()->__insert_c(this);
#endif
# 1799 "/usr/include/c++/v1/string" 3
    __zero();
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>::basic_string(const allocator_type& __a)
    : __r_(__a)
{
#if _LIBCPP_DEBUG_LEVEL >= 2
    __get_db()->__insert_c(this);
#endif
# 1810 "/usr/include/c++/v1/string" 3
    __zero();
}

template <class _CharT, class _Traits, class _Allocator>
void
basic_string<_CharT, _Traits, _Allocator>::__init(const value_type* __s, size_type __sz, size_type __reserve)
{
    if (__reserve > max_size())
        this->__throw_length_error();
    pointer __p;
    if (__reserve < __min_cap)
    {
        __set_short_size(__sz);
        __p = __get_short_pointer();
    }
    else
    {
        size_type __cap = __recommend(__reserve);
        __p = __alloc_traits::allocate(__alloc(), __cap+1);
        __set_long_pointer(__p);
        __set_long_cap(__cap+1);
        __set_long_size(__sz);
    }
    traits_type::copy(_VSTD::__to_raw_pointer(__p), __s, __sz);
    traits_type::assign(__p[__sz], value_type());
}

template <class _CharT, class _Traits, class _Allocator>
void
basic_string<_CharT, _Traits, _Allocator>::__init(const value_type* __s, size_type __sz)
{
    if (__sz > max_size())
        this->__throw_length_error();
    pointer __p;
    if (__sz < __min_cap)
    {
        __set_short_size(__sz);
        __p = __get_short_pointer();
    }
    else
    {
        size_type __cap = __recommend(__sz);
        __p = __alloc_traits::allocate(__alloc(), __cap+1);
        __set_long_pointer(__p);
        __set_long_cap(__cap+1);
        __set_long_size(__sz);
    }
    traits_type::copy(_VSTD::__to_raw_pointer(__p), __s, __sz);
    traits_type::assign(__p[__sz], value_type());
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>::basic_string(const value_type* __s)
{
    _LIBCPP_ASSERT(__s != nullptr, "basic_string(const char*) detected nullptr");
    __init(__s, traits_type::length(__s));
#if _LIBCPP_DEBUG_LEVEL >= 2
    __get_db()->__insert_c(this);
#endif
# 1870 "/usr/include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>::basic_string(const value_type* __s, const allocator_type& __a)
    : __r_(__a)
{
    _LIBCPP_ASSERT(__s != nullptr, "basic_string(const char*, allocator) detected nullptr");
    __init(__s, traits_type::length(__s));
#if _LIBCPP_DEBUG_LEVEL >= 2
    __get_db()->__insert_c(this);
#endif
# 1882 "/usr/include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>::basic_string(const value_type* __s, size_type __n)
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "basic_string(const char*, n) detected nullptr");
    __init(__s, __n);
#if _LIBCPP_DEBUG_LEVEL >= 2
    __get_db()->__insert_c(this);
#endif
# 1893 "/usr/include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>::basic_string(const value_type* __s, size_type __n, const allocator_type& __a)
    : __r_(__a)
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "basic_string(const char*, n, allocator) detected nullptr");
    __init(__s, __n);
#if _LIBCPP_DEBUG_LEVEL >= 2
    __get_db()->__insert_c(this);
#endif
# 1905 "/usr/include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>::basic_string(const basic_string& __str)
    : __r_(__alloc_traits::select_on_container_copy_construction(__str.__alloc()))
{
    if (!__str.__is_long())
        __r_.first().__r = __str.__r_.first().__r;
    else
        __init(_VSTD::__to_raw_pointer(__str.__get_long_pointer()), __str.__get_long_size());
#if _LIBCPP_DEBUG_LEVEL >= 2
    __get_db()->__insert_c(this);
#endif
# 1918 "/usr/include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>::basic_string(const basic_string& __str, const allocator_type& __a)
    : __r_(__a)
{
    if (!__str.__is_long())
        __r_.first().__r = __str.__r_.first().__r;
    else
        __init(_VSTD::__to_raw_pointer(__str.__get_long_pointer()), __str.__get_long_size());
#if _LIBCPP_DEBUG_LEVEL >= 2
    __get_db()->__insert_c(this);
#endif
# 1931 "/usr/include/c++/v1/string" 3
}

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>::basic_string(basic_string&& __str)
        _NOEXCEPT_(is_nothrow_move_constructible<allocator_type>::value)
    : __r_(_VSTD::move(__str.__r_))
{
    __str.__zero();
#if _LIBCPP_DEBUG_LEVEL >= 2
    __get_db()->__insert_c(this);
    if (__is_long())
        __get_db()->swap(this, &__str);
#endif
# 1947 "/usr/include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>::basic_string(basic_string&& __str, const allocator_type& __a)
    : __r_(__a)
{
    if (__a == __str.__alloc() || !__str.__is_long())
        __r_.first().__r = __str.__r_.first().__r;
    else
        __init(_VSTD::__to_raw_pointer(__str.__get_long_pointer()), __str.__get_long_size());
    __str.__zero();
#if _LIBCPP_DEBUG_LEVEL >= 2
    __get_db()->__insert_c(this);
    if (__is_long())
        __get_db()->swap(this, &__str);
#endif
# 1964 "/usr/include/c++/v1/string" 3
}

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 1967 "/usr/include/c++/v1/string" 3

template <class _CharT, class _Traits, class _Allocator>
void
basic_string<_CharT, _Traits, _Allocator>::__init(size_type __n, value_type __c)
{
    if (__n > max_size())
        this->__throw_length_error();
    pointer __p;
    if (__n < __min_cap)
    {
        __set_short_size(__n);
        __p = __get_short_pointer();
    }
    else
    {
        size_type __cap = __recommend(__n);
        __p = __alloc_traits::allocate(__alloc(), __cap+1);
        __set_long_pointer(__p);
        __set_long_cap(__cap+1);
        __set_long_size(__n);
    }
    traits_type::assign(_VSTD::__to_raw_pointer(__p), __n, __c);
    traits_type::assign(__p[__n], value_type());
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>::basic_string(size_type __n, value_type __c)
{
    __init(__n, __c);
#if _LIBCPP_DEBUG_LEVEL >= 2
    __get_db()->__insert_c(this);
#endif
# 2000 "/usr/include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>::basic_string(size_type __n, value_type __c, const allocator_type& __a)
    : __r_(__a)
{
    __init(__n, __c);
#if _LIBCPP_DEBUG_LEVEL >= 2
    __get_db()->__insert_c(this);
#endif
# 2011 "/usr/include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>::basic_string(const basic_string& __str, size_type __pos, size_type __n,
                                                        const allocator_type& __a)
    : __r_(__a)
{
    size_type __str_sz = __str.size();
    if (__pos > __str_sz)
        this->__throw_out_of_range();
    __init(__str.data() + __pos, _VSTD::min(__n, __str_sz - __pos));
#if _LIBCPP_DEBUG_LEVEL >= 2
    __get_db()->__insert_c(this);
#endif
# 2025 "/usr/include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
template <class _InputIterator>
typename enable_if
<
     __is_input_iterator  <_InputIterator>::value &&
    !__is_forward_iterator<_InputIterator>::value,
    void
>::type
basic_string<_CharT, _Traits, _Allocator>::__init(_InputIterator __first, _InputIterator __last)
{
    __zero();
#ifndef _LIBCPP_NO_EXCEPTIONS
    try
    {
#endif  // _LIBCPP_NO_EXCEPTIONS
# 2042 "/usr/include/c++/v1/string" 3
    for (; __first != __last; ++__first)
        push_back(*__first);
#ifndef _LIBCPP_NO_EXCEPTIONS
    }
    catch (...)
    {
        if (__is_long())
            __alloc_traits::deallocate(__alloc(), __get_long_pointer(), __get_long_cap());
        throw;
    }
#endif  // _LIBCPP_NO_EXCEPTIONS
# 2053 "/usr/include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
template <class _ForwardIterator>
typename enable_if
<
    __is_forward_iterator<_ForwardIterator>::value,
    void
>::type
basic_string<_CharT, _Traits, _Allocator>::__init(_ForwardIterator __first, _ForwardIterator __last)
{
    size_type __sz = static_cast<size_type>(_VSTD::distance(__first, __last));
    if (__sz > max_size())
        this->__throw_length_error();
    pointer __p;
    if (__sz < __min_cap)
    {
        __set_short_size(__sz);
        __p = __get_short_pointer();
    }
    else
    {
        size_type __cap = __recommend(__sz);
        __p = __alloc_traits::allocate(__alloc(), __cap+1);
        __set_long_pointer(__p);
        __set_long_cap(__cap+1);
        __set_long_size(__sz);
    }
    for (; __first != __last; ++__first, ++__p)
        traits_type::assign(*__p, *__first);
    traits_type::assign(*__p, value_type());
}

template <class _CharT, class _Traits, class _Allocator>
template<class _InputIterator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>::basic_string(_InputIterator __first, _InputIterator __last)
{
    __init(__first, __last);
#if _LIBCPP_DEBUG_LEVEL >= 2
    __get_db()->__insert_c(this);
#endif
# 2095 "/usr/include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
template<class _InputIterator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>::basic_string(_InputIterator __first, _InputIterator __last,
                                                        const allocator_type& __a)
    : __r_(__a)
{
    __init(__first, __last);
#if _LIBCPP_DEBUG_LEVEL >= 2
    __get_db()->__insert_c(this);
#endif
# 2108 "/usr/include/c++/v1/string" 3
}

#ifndef _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>::basic_string(initializer_list<value_type> __il)
{
    __init(__il.begin(), __il.end());
#if _LIBCPP_DEBUG_LEVEL >= 2
    __get_db()->__insert_c(this);
#endif
# 2120 "/usr/include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>::basic_string(initializer_list<value_type> __il, const allocator_type& __a)
    : __r_(__a)
{
    __init(__il.begin(), __il.end());
#if _LIBCPP_DEBUG_LEVEL >= 2
    __get_db()->__insert_c(this);
#endif
# 2131 "/usr/include/c++/v1/string" 3
}

#endif  // _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
# 2134 "/usr/include/c++/v1/string" 3

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>::~basic_string()
{
#if _LIBCPP_DEBUG_LEVEL >= 2
    __get_db()->__erase_c(this);
#endif
# 2141 "/usr/include/c++/v1/string" 3
    if (__is_long())
        __alloc_traits::deallocate(__alloc(), __get_long_pointer(), __get_long_cap());
}

template <class _CharT, class _Traits, class _Allocator>
void
basic_string<_CharT, _Traits, _Allocator>::__grow_by_and_replace
    (size_type __old_cap, size_type __delta_cap, size_type __old_sz,
     size_type __n_copy,  size_type __n_del,     size_type __n_add, const value_type* __p_new_stuff)
{
    size_type __ms = max_size();
    if (__delta_cap > __ms - __old_cap - 1)
        this->__throw_length_error();
    pointer __old_p = __get_pointer();
    size_type __cap = __old_cap < __ms / 2 - __alignment ?
                          __recommend(_VSTD::max(__old_cap + __delta_cap, 2 * __old_cap)) :
                          __ms - 1;
    pointer __p = __alloc_traits::allocate(__alloc(), __cap+1);
    __invalidate_all_iterators();
    if (__n_copy != 0)
        traits_type::copy(_VSTD::__to_raw_pointer(__p),
                          _VSTD::__to_raw_pointer(__old_p), __n_copy);
    if (__n_add != 0)
        traits_type::copy(_VSTD::__to_raw_pointer(__p) + __n_copy, __p_new_stuff, __n_add);
    size_type __sec_cp_sz = __old_sz - __n_del - __n_copy;
    if (__sec_cp_sz != 0)
        traits_type::copy(_VSTD::__to_raw_pointer(__p) + __n_copy + __n_add,
                          _VSTD::__to_raw_pointer(__old_p) + __n_copy + __n_del, __sec_cp_sz);
    if (__old_cap+1 != __min_cap)
        __alloc_traits::deallocate(__alloc(), __old_p, __old_cap+1);
    __set_long_pointer(__p);
    __set_long_cap(__cap+1);
    __old_sz = __n_copy + __n_add + __sec_cp_sz;
    __set_long_size(__old_sz);
    traits_type::assign(__p[__old_sz], value_type());
}

template <class _CharT, class _Traits, class _Allocator>
void
basic_string<_CharT, _Traits, _Allocator>::__grow_by(size_type __old_cap, size_type __delta_cap, size_type __old_sz,
                                                     size_type __n_copy,  size_type __n_del,     size_type __n_add)
{
    size_type __ms = max_size();
    if (__delta_cap > __ms - __old_cap)
        this->__throw_length_error();
    pointer __old_p = __get_pointer();
    size_type __cap = __old_cap < __ms / 2 - __alignment ?
                          __recommend(_VSTD::max(__old_cap + __delta_cap, 2 * __old_cap)) :
                          __ms - 1;
    pointer __p = __alloc_traits::allocate(__alloc(), __cap+1);
    __invalidate_all_iterators();
    if (__n_copy != 0)
        traits_type::copy(_VSTD::__to_raw_pointer(__p),
                          _VSTD::__to_raw_pointer(__old_p), __n_copy);
    size_type __sec_cp_sz = __old_sz - __n_del - __n_copy;
    if (__sec_cp_sz != 0)
        traits_type::copy(_VSTD::__to_raw_pointer(__p) + __n_copy + __n_add,
                          _VSTD::__to_raw_pointer(__old_p) + __n_copy + __n_del,
                          __sec_cp_sz);
    if (__old_cap+1 != __min_cap)
        __alloc_traits::deallocate(__alloc(), __old_p, __old_cap+1);
    __set_long_pointer(__p);
    __set_long_cap(__cap+1);
}

// assign

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::assign(const value_type* __s, size_type __n)
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string::assign recieved nullptr");
    size_type __cap = capacity();
    if (__cap >= __n)
    {
        value_type* __p = _VSTD::__to_raw_pointer(__get_pointer());
        traits_type::move(__p, __s, __n);
        traits_type::assign(__p[__n], value_type());
        __set_size(__n);
        __invalidate_iterators_past(__n);
    }
    else
    {
        size_type __sz = size();
        __grow_by_and_replace(__cap, __n - __cap, __sz, 0, __sz, __n, __s);
    }
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::assign(size_type __n, value_type __c)
{
    size_type __cap = capacity();
    if (__cap < __n)
    {
        size_type __sz = size();
        __grow_by(__cap, __n - __cap, __sz, 0, __sz);
    }
    else
        __invalidate_iterators_past(__n);
    value_type* __p = _VSTD::__to_raw_pointer(__get_pointer());
    traits_type::assign(__p, __n, __c);
    traits_type::assign(__p[__n], value_type());
    __set_size(__n);
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::operator=(value_type __c)
{
    pointer __p;
    if (__is_long())
    {
        __p = __get_long_pointer();
        __set_long_size(1);
    }
    else
    {
        __p = __get_short_pointer();
        __set_short_size(1);
    }
    traits_type::assign(*__p, __c);
    traits_type::assign(*++__p, value_type());
    __invalidate_iterators_past(1);
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::operator=(const basic_string& __str)
{
    if (this != &__str)
    {
        __copy_assign_alloc(__str);
        assign(__str);
    }
    return *this;
}

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
basic_string<_CharT, _Traits, _Allocator>::__move_assign(basic_string& __str, false_type)
{
    if (__alloc() != __str.__alloc())
        assign(__str);
    else
        __move_assign(__str, true_type());
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
basic_string<_CharT, _Traits, _Allocator>::__move_assign(basic_string& __str, true_type)
    _NOEXCEPT_(is_nothrow_move_assignable<allocator_type>::value)
{
    clear();
    shrink_to_fit();
    __r_.first() = __str.__r_.first();
    __move_assign_alloc(__str);
    __str.__zero();
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::operator=(basic_string&& __str)
    _NOEXCEPT_(__alloc_traits::propagate_on_container_move_assignment::value &&
               is_nothrow_move_assignable<allocator_type>::value)
{
    __move_assign(__str, integral_constant<bool,
          __alloc_traits::propagate_on_container_move_assignment::value>());
    return *this;
}

#endif
# 2321 "/usr/include/c++/v1/string" 3

template <class _CharT, class _Traits, class _Allocator>
template<class _InputIterator>
typename enable_if
<
     __is_input_iterator  <_InputIterator>::value &&
    !__is_forward_iterator<_InputIterator>::value,
    basic_string<_CharT, _Traits, _Allocator>&
>::type
basic_string<_CharT, _Traits, _Allocator>::assign(_InputIterator __first, _InputIterator __last)
{
    clear();
    for (; __first != __last; ++__first)
        push_back(*__first);
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
template<class _ForwardIterator>
typename enable_if
<
    __is_forward_iterator<_ForwardIterator>::value,
    basic_string<_CharT, _Traits, _Allocator>&
>::type
basic_string<_CharT, _Traits, _Allocator>::assign(_ForwardIterator __first, _ForwardIterator __last)
{
    size_type __n = static_cast<size_type>(_VSTD::distance(__first, __last));
    size_type __cap = capacity();
    if (__cap < __n)
    {
        size_type __sz = size();
        __grow_by(__cap, __n - __cap, __sz, 0, __sz);
    }
    else
        __invalidate_iterators_past(__n);
    pointer __p = __get_pointer();
    for (; __first != __last; ++__first, ++__p)
        traits_type::assign(*__p, *__first);
    traits_type::assign(*__p, value_type());
    __set_size(__n);
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::assign(const basic_string& __str)
{
    return assign(__str.data(), __str.size());
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::assign(const basic_string& __str, size_type __pos, size_type __n)
{
    size_type __sz = __str.size();
    if (__pos > __sz)
        this->__throw_out_of_range();
    return assign(__str.data() + __pos, _VSTD::min(__n, __sz - __pos));
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::assign(const value_type* __s)
{
    _LIBCPP_ASSERT(__s != nullptr, "string::assign recieved nullptr");
    return assign(__s, traits_type::length(__s));
}

// append

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::append(const value_type* __s, size_type __n)
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string::append recieved nullptr");
    size_type __cap = capacity();
    size_type __sz = size();
    if (__cap - __sz >= __n)
    {
        if (__n)
        {
            value_type* __p = _VSTD::__to_raw_pointer(__get_pointer());
            traits_type::copy(__p + __sz, __s, __n);
            __sz += __n;
            __set_size(__sz);
            traits_type::assign(__p[__sz], value_type());
        }
    }
    else
        __grow_by_and_replace(__cap, __sz + __n - __cap, __sz, __sz, 0, __n, __s);
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::append(size_type __n, value_type __c)
{
    if (__n)
    {
        size_type __cap = capacity();
        size_type __sz = size();
        if (__cap - __sz < __n)
            __grow_by(__cap, __sz + __n - __cap, __sz, __sz, 0);
        pointer __p = __get_pointer();
        traits_type::assign(_VSTD::__to_raw_pointer(__p) + __sz, __n, __c);
        __sz += __n;
        __set_size(__sz);
        traits_type::assign(__p[__sz], value_type());
    }
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
void
basic_string<_CharT, _Traits, _Allocator>::push_back(value_type __c)
{
    bool __is_short = !__is_long();
    size_type __cap;
    size_type __sz;
    if (__is_short)
    {
        __cap = __min_cap - 1;
        __sz = __get_short_size();
    }
    else
    {
        __cap = __get_long_cap() - 1;
        __sz = __get_long_size();
    }
    if (__sz == __cap)
    {
        __grow_by(__cap, 1, __sz, __sz, 0);
        __is_short = !__is_long();
    }
    pointer __p;
    if (__is_short)
    {
        __p = __get_short_pointer() + __sz;
        __set_short_size(__sz+1);
    }
    else
    {
        __p = __get_long_pointer() + __sz;
        __set_long_size(__sz+1);
    }
    traits_type::assign(*__p, __c);
    traits_type::assign(*++__p, value_type());
}

template <class _CharT, class _Traits, class _Allocator>
template<class _InputIterator>
typename enable_if
<
     __is_input_iterator  <_InputIterator>::value &&
    !__is_forward_iterator<_InputIterator>::value,
    basic_string<_CharT, _Traits, _Allocator>&
>::type
basic_string<_CharT, _Traits, _Allocator>::append(_InputIterator __first, _InputIterator __last)
{
    for (; __first != __last; ++__first)
        push_back(*__first);
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
template<class _ForwardIterator>
typename enable_if
<
    __is_forward_iterator<_ForwardIterator>::value,
    basic_string<_CharT, _Traits, _Allocator>&
>::type
basic_string<_CharT, _Traits, _Allocator>::append(_ForwardIterator __first, _ForwardIterator __last)
{
    size_type __sz = size();
    size_type __cap = capacity();
    size_type __n = static_cast<size_type>(_VSTD::distance(__first, __last));
    if (__n)
    {
        if (__cap - __sz < __n)
            __grow_by(__cap, __sz + __n - __cap, __sz, __sz, 0);
        pointer __p = __get_pointer() + __sz;
        for (; __first != __last; ++__p, ++__first)
            traits_type::assign(*__p, *__first);
        traits_type::assign(*__p, value_type());
        __set_size(__sz + __n);
    }
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::append(const basic_string& __str)
{
    return append(__str.data(), __str.size());
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::append(const basic_string& __str, size_type __pos, size_type __n)
{
    size_type __sz = __str.size();
    if (__pos > __sz)
        this->__throw_out_of_range();
    return append(__str.data() + __pos, _VSTD::min(__n, __sz - __pos));
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::append(const value_type* __s)
{
    _LIBCPP_ASSERT(__s != nullptr, "string::append recieved nullptr");
    return append(__s, traits_type::length(__s));
}

// insert

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::insert(size_type __pos, const value_type* __s, size_type __n)
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string::insert recieved nullptr");
    size_type __sz = size();
    if (__pos > __sz)
        this->__throw_out_of_range();
    size_type __cap = capacity();
    if (__cap - __sz >= __n)
    {
        if (__n)
        {
            value_type* __p = _VSTD::__to_raw_pointer(__get_pointer());
            size_type __n_move = __sz - __pos;
            if (__n_move != 0)
            {
                if (__p + __pos <= __s && __s < __p + __sz)
                    __s += __n;
                traits_type::move(__p + __pos + __n, __p + __pos, __n_move);
            }
            traits_type::move(__p + __pos, __s, __n);
            __sz += __n;
            __set_size(__sz);
            traits_type::assign(__p[__sz], value_type());
        }
    }
    else
        __grow_by_and_replace(__cap, __sz + __n - __cap, __sz, __pos, 0, __n, __s);
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::insert(size_type __pos, size_type __n, value_type __c)
{
    size_type __sz = size();
    if (__pos > __sz)
        this->__throw_out_of_range();
    if (__n)
    {
        size_type __cap = capacity();
        value_type* __p;
        if (__cap - __sz >= __n)
        {
            __p = _VSTD::__to_raw_pointer(__get_pointer());
            size_type __n_move = __sz - __pos;
            if (__n_move != 0)
                traits_type::move(__p + __pos + __n, __p + __pos, __n_move);
        }
        else
        {
            __grow_by(__cap, __sz + __n - __cap, __sz, __pos, 0, __n);
            __p = _VSTD::__to_raw_pointer(__get_long_pointer());
        }
        traits_type::assign(__p + __pos, __n, __c);
        __sz += __n;
        __set_size(__sz);
        traits_type::assign(__p[__sz], value_type());
    }
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
template<class _InputIterator>
typename enable_if
<
     __is_input_iterator  <_InputIterator>::value &&
    !__is_forward_iterator<_InputIterator>::value,
    typename basic_string<_CharT, _Traits, _Allocator>::iterator
>::type
basic_string<_CharT, _Traits, _Allocator>::insert(const_iterator __pos, _InputIterator __first, _InputIterator __last)
{
#if _LIBCPP_DEBUG_LEVEL >= 2
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__pos) == this,
        "string::insert(iterator, range) called with an iterator not"
        " referring to this string");
#endif
# 2617 "/usr/include/c++/v1/string" 3
    size_type __old_sz = size();
    difference_type __ip = __pos - begin();
    for (; __first != __last; ++__first)
        push_back(*__first);
    pointer __p = __get_pointer();
    _VSTD::rotate(__p + __ip, __p + __old_sz, __p + size());
#if _LIBCPP_DEBUG_LEVEL >= 2
    return iterator(this, __p + __ip);
#else
# 2626 "/usr/include/c++/v1/string" 3
    return iterator(__p + __ip);
#endif
# 2628 "/usr/include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
template<class _ForwardIterator>
typename enable_if
<
    __is_forward_iterator<_ForwardIterator>::value,
    typename basic_string<_CharT, _Traits, _Allocator>::iterator
>::type
basic_string<_CharT, _Traits, _Allocator>::insert(const_iterator __pos, _ForwardIterator __first, _ForwardIterator __last)
{
#if _LIBCPP_DEBUG_LEVEL >= 2
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__pos) == this,
        "string::insert(iterator, range) called with an iterator not"
        " referring to this string");
#endif
# 2644 "/usr/include/c++/v1/string" 3
    size_type __ip = static_cast<size_type>(__pos - begin());
    size_type __sz = size();
    size_type __cap = capacity();
    size_type __n = static_cast<size_type>(_VSTD::distance(__first, __last));
    if (__n)
    {
        value_type* __p;
        if (__cap - __sz >= __n)
        {
            __p = _VSTD::__to_raw_pointer(__get_pointer());
            size_type __n_move = __sz - __ip;
            if (__n_move != 0)
                traits_type::move(__p + __ip + __n, __p + __ip, __n_move);
        }
        else
        {
            __grow_by(__cap, __sz + __n - __cap, __sz, __ip, 0, __n);
            __p = _VSTD::__to_raw_pointer(__get_long_pointer());
        }
        __sz += __n;
        __set_size(__sz);
        traits_type::assign(__p[__sz], value_type());
        for (__p += __ip; __first != __last; ++__p, ++__first)
            traits_type::assign(*__p, *__first);
    }
    return begin() + __ip;
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::insert(size_type __pos1, const basic_string& __str)
{
    return insert(__pos1, __str.data(), __str.size());
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::insert(size_type __pos1, const basic_string& __str,
                                                  size_type __pos2, size_type __n)
{
    size_type __str_sz = __str.size();
    if (__pos2 > __str_sz)
        this->__throw_out_of_range();
    return insert(__pos1, __str.data() + __pos2, _VSTD::min(__n, __str_sz - __pos2));
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::insert(size_type __pos, const value_type* __s)
{
    _LIBCPP_ASSERT(__s != nullptr, "string::insert recieved nullptr");
    return insert(__pos, __s, traits_type::length(__s));
}

template <class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::iterator
basic_string<_CharT, _Traits, _Allocator>::insert(const_iterator __pos, value_type __c)
{
    size_type __ip = static_cast<size_type>(__pos - begin());
    size_type __sz = size();
    size_type __cap = capacity();
    value_type* __p;
    if (__cap == __sz)
    {
        __grow_by(__cap, 1, __sz, __ip, 0, 1);
        __p = _VSTD::__to_raw_pointer(__get_long_pointer());
    }
    else
    {
        __p = _VSTD::__to_raw_pointer(__get_pointer());
        size_type __n_move = __sz - __ip;
        if (__n_move != 0)
            traits_type::move(__p + __ip + 1, __p + __ip, __n_move);
    }
    traits_type::assign(__p[__ip], __c);
    traits_type::assign(__p[++__sz], value_type());
    __set_size(__sz);
    return begin() + static_cast<difference_type>(__ip);
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::iterator
basic_string<_CharT, _Traits, _Allocator>::insert(const_iterator __pos, size_type __n, value_type __c)
{
#if _LIBCPP_DEBUG_LEVEL >= 2
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__pos) == this,
        "string::insert(iterator, n, value) called with an iterator not"
        " referring to this string");
#endif
# 2735 "/usr/include/c++/v1/string" 3
    difference_type __p = __pos - begin();
    insert(static_cast<size_type>(__p), __n, __c);
    return begin() + __p;
}

// replace

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::replace(size_type __pos, size_type __n1, const value_type* __s, size_type __n2)
{
    _LIBCPP_ASSERT(__n2 == 0 || __s != nullptr, "string::replace recieved nullptr");
    size_type __sz = size();
    if (__pos > __sz)
        this->__throw_out_of_range();
    __n1 = _VSTD::min(__n1, __sz - __pos);
    size_type __cap = capacity();
    if (__cap - __sz + __n1 >= __n2)
    {
        value_type* __p = _VSTD::__to_raw_pointer(__get_pointer());
        if (__n1 != __n2)
        {
            size_type __n_move = __sz - __pos - __n1;
            if (__n_move != 0)
            {
                if (__n1 > __n2)
                {
                    traits_type::move(__p + __pos, __s, __n2);
                    traits_type::move(__p + __pos + __n2, __p + __pos + __n1, __n_move);
                    goto __finish;
                }
                if (__p + __pos < __s && __s < __p + __sz)
                {
                    if (__p + __pos + __n1 <= __s)
                        __s += __n2 - __n1;
                    else // __p + __pos < __s < __p + __pos + __n1
                    {
                        traits_type::move(__p + __pos, __s, __n1);
                        __pos += __n1;
                        __s += __n2;
                        __n2 -= __n1;
                        __n1 = 0;
                    }
                }
                traits_type::move(__p + __pos + __n2, __p + __pos + __n1, __n_move);
            }
        }
        traits_type::move(__p + __pos, __s, __n2);
__finish:
        __sz += __n2 - __n1;
        __set_size(__sz);
        __invalidate_iterators_past(__sz);
        traits_type::assign(__p[__sz], value_type());
    }
    else
        __grow_by_and_replace(__cap, __sz - __n1 + __n2 - __cap, __sz, __pos, __n1, __n2, __s);
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::replace(size_type __pos, size_type __n1, size_type __n2, value_type __c)
{
    size_type __sz = size();
    if (__pos > __sz)
        this->__throw_out_of_range();
    __n1 = _VSTD::min(__n1, __sz - __pos);
    size_type __cap = capacity();
    value_type* __p;
    if (__cap - __sz + __n1 >= __n2)
    {
        __p = _VSTD::__to_raw_pointer(__get_pointer());
        if (__n1 != __n2)
        {
            size_type __n_move = __sz - __pos - __n1;
            if (__n_move != 0)
                traits_type::move(__p + __pos + __n2, __p + __pos + __n1, __n_move);
        }
    }
    else
    {
        __grow_by(__cap, __sz - __n1 + __n2 - __cap, __sz, __pos, __n1, __n2);
        __p = _VSTD::__to_raw_pointer(__get_long_pointer());
    }
    traits_type::assign(__p + __pos, __n2, __c);
    __sz += __n2 - __n1;
    __set_size(__sz);
    __invalidate_iterators_past(__sz);
    traits_type::assign(__p[__sz], value_type());
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
template<class _InputIterator>
typename enable_if
<
    __is_input_iterator<_InputIterator>::value,
    basic_string<_CharT, _Traits, _Allocator>&
>::type
basic_string<_CharT, _Traits, _Allocator>::replace(const_iterator __i1, const_iterator __i2,
                                                   _InputIterator __j1, _InputIterator __j2)
{
    for (; true; ++__i1, ++__j1)
    {
        if (__i1 == __i2)
        {
            if (__j1 != __j2)
                insert(__i1, __j1, __j2);
            break;
        }
        if (__j1 == __j2)
        {
            erase(__i1, __i2);
            break;
        }
        traits_type::assign(const_cast<value_type&>(*__i1), *__j1);
    }
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::replace(size_type __pos1, size_type __n1, const basic_string& __str)
{
    return replace(__pos1, __n1, __str.data(), __str.size());
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::replace(size_type __pos1, size_type __n1, const basic_string& __str,
                                                   size_type __pos2, size_type __n2)
{
    size_type __str_sz = __str.size();
    if (__pos2 > __str_sz)
        this->__throw_out_of_range();
    return replace(__pos1, __n1, __str.data() + __pos2, _VSTD::min(__n2, __str_sz - __pos2));
}

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::replace(size_type __pos, size_type __n1, const value_type* __s)
{
    _LIBCPP_ASSERT(__s != nullptr, "string::replace recieved nullptr");
    return replace(__pos, __n1, __s, traits_type::length(__s));
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::replace(const_iterator __i1, const_iterator __i2, const basic_string& __str)
{
    return replace(static_cast<size_type>(__i1 - begin()), static_cast<size_type>(__i2 - __i1),
                   __str.data(), __str.size());
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::replace(const_iterator __i1, const_iterator __i2, const value_type* __s, size_type __n)
{
    return replace(static_cast<size_type>(__i1 - begin()), static_cast<size_type>(__i2 - __i1), __s, __n);
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::replace(const_iterator __i1, const_iterator __i2, const value_type* __s)
{
    return replace(static_cast<size_type>(__i1 - begin()), static_cast<size_type>(__i2 - __i1), __s);
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::replace(const_iterator __i1, const_iterator __i2, size_type __n, value_type __c)
{
    return replace(static_cast<size_type>(__i1 - begin()), static_cast<size_type>(__i2 - __i1), __n, __c);
}

// erase

template <class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>&
basic_string<_CharT, _Traits, _Allocator>::erase(size_type __pos, size_type __n)
{
    size_type __sz = size();
    if (__pos > __sz)
        this->__throw_out_of_range();
    if (__n)
    {
        value_type* __p = _VSTD::__to_raw_pointer(__get_pointer());
        __n = _VSTD::min(__n, __sz - __pos);
        size_type __n_move = __sz - __pos - __n;
        if (__n_move != 0)
            traits_type::move(__p + __pos, __p + __pos + __n, __n_move);
        __sz -= __n;
        __set_size(__sz);
        __invalidate_iterators_past(__sz);
        traits_type::assign(__p[__sz], value_type());
    }
    return *this;
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::iterator
basic_string<_CharT, _Traits, _Allocator>::erase(const_iterator __pos)
{
#if _LIBCPP_DEBUG_LEVEL >= 2
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__pos) == this,
        "string::erase(iterator) called with an iterator not"
        " referring to this string");
#endif
# 2949 "/usr/include/c++/v1/string" 3
    _LIBCPP_ASSERT(__pos != end(),
        "string::erase(iterator) called with a non-dereferenceable iterator");
    iterator __b = begin();
    size_type __r = static_cast<size_type>(__pos - __b);
    erase(__r, 1);
    return __b + static_cast<difference_type>(__r);
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::iterator
basic_string<_CharT, _Traits, _Allocator>::erase(const_iterator __first, const_iterator __last)
{
#if _LIBCPP_DEBUG_LEVEL >= 2
    _LIBCPP_ASSERT(__get_const_db()->__find_c_from_i(&__first) == this,
        "string::erase(iterator,  iterator) called with an iterator not"
        " referring to this string");
#endif
# 2967 "/usr/include/c++/v1/string" 3
    _LIBCPP_ASSERT(__first <= __last, "string::erase(first, last) called with invalid range");
    iterator __b = begin();
    size_type __r = static_cast<size_type>(__first - __b);
    erase(__r, static_cast<size_type>(__last - __first));
    return __b + static_cast<difference_type>(__r);
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
basic_string<_CharT, _Traits, _Allocator>::pop_back()
{
    _LIBCPP_ASSERT(!empty(), "string::pop_back(): string is already empty");
    size_type __sz;
    if (__is_long())
    {
        __sz = __get_long_size() - 1;
        __set_long_size(__sz);
        traits_type::assign(*(__get_long_pointer() + __sz), value_type());
    }
    else
    {
        __sz = __get_short_size() - 1;
        __set_short_size(__sz);
        traits_type::assign(*(__get_short_pointer() + __sz), value_type());
    }
    __invalidate_iterators_past(__sz);
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
basic_string<_CharT, _Traits, _Allocator>::clear() _NOEXCEPT
{
    __invalidate_all_iterators();
    if (__is_long())
    {
        traits_type::assign(*__get_long_pointer(), value_type());
        __set_long_size(0);
    }
    else
    {
        traits_type::assign(*__get_short_pointer(), value_type());
        __set_short_size(0);
    }
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
basic_string<_CharT, _Traits, _Allocator>::__erase_to_end(size_type __pos)
{
    if (__is_long())
    {
        traits_type::assign(*(__get_long_pointer() + __pos), value_type());
        __set_long_size(__pos);
    }
    else
    {
        traits_type::assign(*(__get_short_pointer() + __pos), value_type());
        __set_short_size(__pos);
    }
    __invalidate_iterators_past(__pos);
}

template <class _CharT, class _Traits, class _Allocator>
void
basic_string<_CharT, _Traits, _Allocator>::resize(size_type __n, value_type __c)
{
    size_type __sz = size();
    if (__n > __sz)
        append(__n - __sz, __c);
    else
        __erase_to_end(__n);
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::max_size() const _NOEXCEPT
{
    size_type __m = __alloc_traits::max_size(__alloc());
#if _LIBCPP_BIG_ENDIAN
    return (__m <= ~__long_mask ? __m : __m/2) - __alignment;
#else
# 3052 "/usr/include/c++/v1/string" 3
    return __m - __alignment;
#endif
# 3054 "/usr/include/c++/v1/string" 3
}

template <class _CharT, class _Traits, class _Allocator>
void
basic_string<_CharT, _Traits, _Allocator>::reserve(size_type __res_arg)
{
    if (__res_arg > max_size())
        this->__throw_length_error();
    size_type __cap = capacity();
    size_type __sz = size();
    __res_arg = _VSTD::max(__res_arg, __sz);
    __res_arg = __recommend(__res_arg);
    if (__res_arg != __cap)
    {
        pointer __new_data, __p;
        bool __was_long, __now_long;
        if (__res_arg == __min_cap - 1)
        {
            __was_long = true;
            __now_long = false;
            __new_data = __get_short_pointer();
            __p = __get_long_pointer();
        }
        else
        {
            if (__res_arg > __cap)
                __new_data = __alloc_traits::allocate(__alloc(), __res_arg+1);
            else
            {
            #ifndef _LIBCPP_NO_EXCEPTIONS
                try
                {
            #endif  // _LIBCPP_NO_EXCEPTIONS
# 3087 "/usr/include/c++/v1/string" 3
                    __new_data = __alloc_traits::allocate(__alloc(), __res_arg+1);
            #ifndef _LIBCPP_NO_EXCEPTIONS
                }
                catch (...)
                {
                    return;
                }
            #else  // _LIBCPP_NO_EXCEPTIONS
# 3095 "/usr/include/c++/v1/string" 3
                if (__new_data == nullptr)
                    return;
            #endif  // _LIBCPP_NO_EXCEPTIONS
# 3098 "/usr/include/c++/v1/string" 3
            }
            __now_long = true;
            __was_long = __is_long();
            __p = __get_pointer();
        }
        traits_type::copy(_VSTD::__to_raw_pointer(__new_data),
                          _VSTD::__to_raw_pointer(__p), size()+1);
        if (__was_long)
            __alloc_traits::deallocate(__alloc(), __p, __cap+1);
        if (__now_long)
        {
            __set_long_cap(__res_arg+1);
            __set_long_size(__sz);
            __set_long_pointer(__new_data);
        }
        else
            __set_short_size(__sz);
        __invalidate_all_iterators();
    }
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::const_reference
basic_string<_CharT, _Traits, _Allocator>::operator[](size_type __pos) const
{
    _LIBCPP_ASSERT(__pos <= size(), "string index out of bounds");
    return *(data() + __pos);
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::reference
basic_string<_CharT, _Traits, _Allocator>::operator[](size_type __pos)
{
    _LIBCPP_ASSERT(__pos <= size(), "string index out of bounds");
    return *(__get_pointer() + __pos);
}

template <class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::const_reference
basic_string<_CharT, _Traits, _Allocator>::at(size_type __n) const
{
    if (__n >= size())
        this->__throw_out_of_range();
    return (*this)[__n];
}

template <class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::reference
basic_string<_CharT, _Traits, _Allocator>::at(size_type __n)
{
    if (__n >= size())
        this->__throw_out_of_range();
    return (*this)[__n];
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::reference
basic_string<_CharT, _Traits, _Allocator>::front()
{
    _LIBCPP_ASSERT(!empty(), "string::front(): string is empty");
    return *__get_pointer();
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::const_reference
basic_string<_CharT, _Traits, _Allocator>::front() const
{
    _LIBCPP_ASSERT(!empty(), "string::front(): string is empty");
    return *data();
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::reference
basic_string<_CharT, _Traits, _Allocator>::back()
{
    _LIBCPP_ASSERT(!empty(), "string::back(): string is empty");
    return *(__get_pointer() + size() - 1);
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::const_reference
basic_string<_CharT, _Traits, _Allocator>::back() const
{
    _LIBCPP_ASSERT(!empty(), "string::back(): string is empty");
    return *(data() + size() - 1);
}

template <class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::copy(value_type* __s, size_type __n, size_type __pos) const
{
    size_type __sz = size();
    if (__pos > __sz)
        this->__throw_out_of_range();
    size_type __rlen = _VSTD::min(__n, __sz - __pos);
    traits_type::copy(__s, data() + __pos, __rlen);
    return __rlen;
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>
basic_string<_CharT, _Traits, _Allocator>::substr(size_type __pos, size_type __n) const
{
    return basic_string(*this, __pos, __n, __alloc());
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
basic_string<_CharT, _Traits, _Allocator>::swap(basic_string& __str)
        _NOEXCEPT_(!__alloc_traits::propagate_on_container_swap::value ||
                   __is_nothrow_swappable<allocator_type>::value)
{
#if _LIBCPP_DEBUG_LEVEL >= 2
    if (!__is_long())
        __get_db()->__invalidate_all(this);
    if (!__str.__is_long())
        __get_db()->__invalidate_all(&__str);
    __get_db()->swap(this, &__str);
#endif
# 3225 "/usr/include/c++/v1/string" 3
    _VSTD::swap(__r_.first(), __str.__r_.first());
    __swap_alloc(__alloc(), __str.__alloc());
}

// find

template <class _Traits>
struct _LIBCPP_HIDDEN __traits_eq
{
    typedef typename _Traits::char_type char_type;
    _LIBCPP_INLINE_VISIBILITY
    bool operator()(const char_type& __x, const char_type& __y) _NOEXCEPT
        {return _Traits::eq(__x, __y);}
};

template<class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find(const value_type* __s,
                                                size_type __pos,
                                                size_type __n) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string::find(): recieved nullptr");
    size_type __sz = size();
    if (__pos > __sz || __sz - __pos < __n)
        return npos;
    if (__n == 0)
        return __pos;
    const value_type* __p = data();
    const value_type* __r = _VSTD::search(__p + __pos, __p + __sz, __s, __s + __n,
                                     __traits_eq<traits_type>());
    if (__r == __p + __sz)
        return npos;
    return static_cast<size_type>(__r - __p);
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find(const basic_string& __str,
                                                size_type __pos) const _NOEXCEPT
{
    return find(__str.data(), __pos, __str.size());
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find(const value_type* __s,
                                                size_type __pos) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__s != nullptr, "string::find(): recieved nullptr");
    return find(__s, __pos, traits_type::length(__s));
}

template<class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find(value_type __c,
                                                size_type __pos) const _NOEXCEPT
{
    size_type __sz = size();
    if (__pos >= __sz)
        return npos;
    const value_type* __p = data();
    const value_type* __r = traits_type::find(__p + __pos, __sz - __pos, __c);
    if (__r == 0)
        return npos;
    return static_cast<size_type>(__r - __p);
}

// rfind

template<class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::rfind(const value_type* __s,
                                                 size_type __pos,
                                                 size_type __n) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string::rfind(): recieved nullptr");
    size_type __sz = size();
    __pos = _VSTD::min(__pos, __sz);
    if (__n < __sz - __pos)
        __pos += __n;
    else
        __pos = __sz;
    const value_type* __p = data();
    const value_type* __r = _VSTD::find_end(__p, __p + __pos, __s, __s + __n,
                                       __traits_eq<traits_type>());
    if (__n > 0 && __r == __p + __pos)
        return npos;
    return static_cast<size_type>(__r - __p);
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::rfind(const basic_string& __str,
                                                 size_type __pos) const _NOEXCEPT
{
    return rfind(__str.data(), __pos, __str.size());
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::rfind(const value_type* __s,
                                                 size_type __pos) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__s != nullptr, "string::rfind(): recieved nullptr");
    return rfind(__s, __pos, traits_type::length(__s));
}

template<class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::rfind(value_type __c,
                                                 size_type __pos) const _NOEXCEPT
{
    size_type __sz = size();
    if (__sz)
    {
        if (__pos < __sz)
            ++__pos;
        else
            __pos = __sz;
        const value_type* __p = data();
        for (const value_type* __ps = __p + __pos; __ps != __p;)
        {
            if (traits_type::eq(*--__ps, __c))
                return static_cast<size_type>(__ps - __p);
        }
    }
    return npos;
}

// find_first_of

template<class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_first_of(const value_type* __s,
                                                         size_type __pos,
                                                         size_type __n) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string::find_first_of(): recieved nullptr");
    size_type __sz = size();
    if (__pos >= __sz || __n == 0)
        return npos;
    const value_type* __p = data();
    const value_type* __r = _VSTD::find_first_of(__p + __pos, __p + __sz, __s,
                                            __s + __n, __traits_eq<traits_type>());
    if (__r == __p + __sz)
        return npos;
    return static_cast<size_type>(__r - __p);
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_first_of(const basic_string& __str,
                                                         size_type __pos) const _NOEXCEPT
{
    return find_first_of(__str.data(), __pos, __str.size());
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_first_of(const value_type* __s,
                                                         size_type __pos) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__s != nullptr, "string::find_first_of(): recieved nullptr");
    return find_first_of(__s, __pos, traits_type::length(__s));
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_first_of(value_type __c,
                                                         size_type __pos) const _NOEXCEPT
{
    return find(__c, __pos);
}

// find_last_of

template<class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_last_of(const value_type* __s,
                                                        size_type __pos,
                                                        size_type __n) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string::find_last_of(): recieved nullptr");
    if (__n != 0)
    {
        size_type __sz = size();
        if (__pos < __sz)
            ++__pos;
        else
            __pos = __sz;
        const value_type* __p = data();
        for (const value_type* __ps = __p + __pos; __ps != __p;)
        {
            const value_type* __r = traits_type::find(__s, __n, *--__ps);
            if (__r)
                return static_cast<size_type>(__ps - __p);
        }
    }
    return npos;
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_last_of(const basic_string& __str,
                                                        size_type __pos) const _NOEXCEPT
{
    return find_last_of(__str.data(), __pos, __str.size());
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_last_of(const value_type* __s,
                                                        size_type __pos) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__s != nullptr, "string::find_last_of(): recieved nullptr");
    return find_last_of(__s, __pos, traits_type::length(__s));
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_last_of(value_type __c,
                                                        size_type __pos) const _NOEXCEPT
{
    return rfind(__c, __pos);
}

// find_first_not_of

template<class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_first_not_of(const value_type* __s,
                                                             size_type __pos,
                                                             size_type __n) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string::find_first_not_of(): recieved nullptr");
    size_type __sz = size();
    if (__pos < __sz)
    {
        const value_type* __p = data();
        const value_type* __pe = __p + __sz;
        for (const value_type* __ps = __p + __pos; __ps != __pe; ++__ps)
            if (traits_type::find(__s, __n, *__ps) == 0)
                return static_cast<size_type>(__ps - __p);
    }
    return npos;
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_first_not_of(const basic_string& __str,
                                                             size_type __pos) const _NOEXCEPT
{
    return find_first_not_of(__str.data(), __pos, __str.size());
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_first_not_of(const value_type* __s,
                                                             size_type __pos) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__s != nullptr, "string::find_first_not_of(): recieved nullptr");
    return find_first_not_of(__s, __pos, traits_type::length(__s));
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_first_not_of(value_type __c,
                                                             size_type __pos) const _NOEXCEPT
{
    size_type __sz = size();
    if (__pos < __sz)
    {
        const value_type* __p = data();
        const value_type* __pe = __p + __sz;
        for (const value_type* __ps = __p + __pos; __ps != __pe; ++__ps)
            if (!traits_type::eq(*__ps, __c))
                return static_cast<size_type>(__ps - __p);
    }
    return npos;
}

// find_last_not_of

template<class _CharT, class _Traits, class _Allocator>
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_last_not_of(const value_type* __s,
                                                            size_type __pos,
                                                            size_type __n) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__n == 0 || __s != nullptr, "string::find_last_not_of(): recieved nullptr");
    size_type __sz = size();
    if (__pos < __sz)
        ++__pos;
    else
        __pos = __sz;
    const value_type* __p = data();
    for (const value_type* __ps = __p + __pos; __ps != __p;)
        if (traits_type::find(__s, __n, *--__ps) == 0)
            return static_cast<size_type>(__ps - __p);
    return npos;
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_last_not_of(const basic_string& __str,
                                                            size_type __pos) const _NOEXCEPT
{
    return find_last_not_of(__str.data(), __pos, __str.size());
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_last_not_of(const value_type* __s,
                                                            size_type __pos) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__s != nullptr, "string::find_last_not_of(): recieved nullptr");
    return find_last_not_of(__s, __pos, traits_type::length(__s));
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_string<_CharT, _Traits, _Allocator>::size_type
basic_string<_CharT, _Traits, _Allocator>::find_last_not_of(value_type __c,
                                                            size_type __pos) const _NOEXCEPT
{
    size_type __sz = size();
    if (__pos < __sz)
        ++__pos;
    else
        __pos = __sz;
    const value_type* __p = data();
    for (const value_type* __ps = __p + __pos; __ps != __p;)
        if (!traits_type::eq(*--__ps, __c))
            return static_cast<size_type>(__ps - __p);
    return npos;
}

// compare

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
int
basic_string<_CharT, _Traits, _Allocator>::compare(const basic_string& __str) const _NOEXCEPT
{
    size_t __lhs_sz = size();
    size_t __rhs_sz = __str.size();
    int __result = traits_type::compare(data(), __str.data(),
                                        _VSTD::min(__lhs_sz, __rhs_sz));
    if (__result != 0)
        return __result;
    if (__lhs_sz < __rhs_sz)
        return -1;
    if (__lhs_sz > __rhs_sz)
        return 1;
    return 0;
}

template <class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
int
basic_string<_CharT, _Traits, _Allocator>::compare(size_type __pos1,
                                                   size_type __n1,
                                                   const basic_string& __str) const
{
    return compare(__pos1, __n1, __str.data(), __str.size());
}

template <class _CharT, class _Traits, class _Allocator>
int
basic_string<_CharT, _Traits, _Allocator>::compare(size_type __pos1,
                                                   size_type __n1,
                                                   const basic_string& __str,
                                                   size_type __pos2,
                                                   size_type __n2) const
{
    size_type __sz = __str.size();
    if (__pos2 > __sz)
        this->__throw_out_of_range();
    return compare(__pos1, __n1, __str.data() + __pos2, _VSTD::min(__n2,
                                                                  __sz - __pos2));
}

template <class _CharT, class _Traits, class _Allocator>
int
basic_string<_CharT, _Traits, _Allocator>::compare(const value_type* __s) const _NOEXCEPT
{
    _LIBCPP_ASSERT(__s != nullptr, "string::compare(): recieved nullptr");
    return compare(0, npos, __s, traits_type::length(__s));
}

template <class _CharT, class _Traits, class _Allocator>
int
basic_string<_CharT, _Traits, _Allocator>::compare(size_type __pos1,
                                                   size_type __n1,
                                                   const value_type* __s) const
{
    _LIBCPP_ASSERT(__s != nullptr, "string::compare(): recieved nullptr");
    return compare(__pos1, __n1, __s, traits_type::length(__s));
}

template <class _CharT, class _Traits, class _Allocator>
int
basic_string<_CharT, _Traits, _Allocator>::compare(size_type __pos1,
                                                   size_type __n1,
                                                   const value_type* __s,
                                                   size_type __n2) const
{
    _LIBCPP_ASSERT(__n2 == 0 || __s != nullptr, "string::compare(): recieved nullptr");
    size_type __sz = size();
    if (__pos1 > __sz || __n2 == npos)
        this->__throw_out_of_range();
    size_type __rlen = _VSTD::min(__n1, __sz - __pos1);
    int __r = traits_type::compare(data() + __pos1, __s, _VSTD::min(__rlen, __n2));
    if (__r == 0)
    {
        if (__rlen < __n2)
            __r = -1;
        else if (__rlen > __n2)
            __r = 1;
    }
    return __r;
}

// __invariants

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
basic_string<_CharT, _Traits, _Allocator>::__invariants() const
{
    if (size() > capacity())
        return false;
    if (capacity() < __min_cap - 1)
        return false;
    if (data() == 0)
        return false;
    if (data()[size()] != value_type(0))
        return false;
    return true;
}

// operator==

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const basic_string<_CharT, _Traits, _Allocator>& __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    size_t __lhs_sz = __lhs.size();
    return __lhs_sz == __rhs.size() && _Traits::compare(__lhs.data(),
                                                        __rhs.data(),
                                                        __lhs_sz) == 0;
}

template<class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const basic_string<char, char_traits<char>, _Allocator>& __lhs,
           const basic_string<char, char_traits<char>, _Allocator>& __rhs) _NOEXCEPT
{
    size_t __lhs_sz = __lhs.size();
    if (__lhs_sz != __rhs.size())
        return false;
    const char* __lp = __lhs.data();
    const char* __rp = __rhs.data();
    if (__lhs.__is_long())
        return char_traits<char>::compare(__lp, __rp, __lhs_sz) == 0;
    for (; __lhs_sz != 0; --__lhs_sz, ++__lp, ++__rp)
        if (*__lp != *__rp)
            return false;
    return true;
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const _CharT* __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    return __rhs.compare(__lhs) == 0;
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const basic_string<_CharT,_Traits,_Allocator>& __lhs,
           const _CharT* __rhs) _NOEXCEPT
{
    return __lhs.compare(__rhs) == 0;
}

// operator!=

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const basic_string<_CharT,_Traits,_Allocator>& __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    return !(__lhs == __rhs);
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const _CharT* __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    return !(__lhs == __rhs);
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const basic_string<_CharT, _Traits, _Allocator>& __lhs,
           const _CharT* __rhs) _NOEXCEPT
{
    return !(__lhs == __rhs);
}

// operator<

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator< (const basic_string<_CharT, _Traits, _Allocator>& __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    return __lhs.compare(__rhs) < 0;
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator< (const basic_string<_CharT, _Traits, _Allocator>& __lhs,
           const _CharT* __rhs) _NOEXCEPT
{
    return __lhs.compare(__rhs) < 0;
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator< (const _CharT* __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    return __rhs.compare(__lhs) > 0;
}

// operator>

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator> (const basic_string<_CharT, _Traits, _Allocator>& __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    return __rhs < __lhs;
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator> (const basic_string<_CharT, _Traits, _Allocator>& __lhs,
           const _CharT* __rhs) _NOEXCEPT
{
    return __rhs < __lhs;
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator> (const _CharT* __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    return __rhs < __lhs;
}

// operator<=

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const basic_string<_CharT, _Traits, _Allocator>& __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    return !(__rhs < __lhs);
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const basic_string<_CharT, _Traits, _Allocator>& __lhs,
           const _CharT* __rhs) _NOEXCEPT
{
    return !(__rhs < __lhs);
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator<=(const _CharT* __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    return !(__rhs < __lhs);
}

// operator>=

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const basic_string<_CharT, _Traits, _Allocator>& __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    return !(__lhs < __rhs);
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const basic_string<_CharT, _Traits, _Allocator>& __lhs,
           const _CharT* __rhs) _NOEXCEPT
{
    return !(__lhs < __rhs);
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator>=(const _CharT* __lhs,
           const basic_string<_CharT, _Traits, _Allocator>& __rhs) _NOEXCEPT
{
    return !(__lhs < __rhs);
}

// operator +

template<class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>
operator+(const basic_string<_CharT, _Traits, _Allocator>& __lhs,
          const basic_string<_CharT, _Traits, _Allocator>& __rhs)
{
    basic_string<_CharT, _Traits, _Allocator> __r(__lhs.get_allocator());
    typename basic_string<_CharT, _Traits, _Allocator>::size_type __lhs_sz = __lhs.size();
    typename basic_string<_CharT, _Traits, _Allocator>::size_type __rhs_sz = __rhs.size();
    __r.__init(__lhs.data(), __lhs_sz, __lhs_sz + __rhs_sz);
    __r.append(__rhs.data(), __rhs_sz);
    return __r;
}

template<class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>
operator+(const _CharT* __lhs , const basic_string<_CharT,_Traits,_Allocator>& __rhs)
{
    basic_string<_CharT, _Traits, _Allocator> __r(__rhs.get_allocator());
    typename basic_string<_CharT, _Traits, _Allocator>::size_type __lhs_sz = _Traits::length(__lhs);
    typename basic_string<_CharT, _Traits, _Allocator>::size_type __rhs_sz = __rhs.size();
    __r.__init(__lhs, __lhs_sz, __lhs_sz + __rhs_sz);
    __r.append(__rhs.data(), __rhs_sz);
    return __r;
}

template<class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>
operator+(_CharT __lhs, const basic_string<_CharT,_Traits,_Allocator>& __rhs)
{
    basic_string<_CharT, _Traits, _Allocator> __r(__rhs.get_allocator());
    typename basic_string<_CharT, _Traits, _Allocator>::size_type __rhs_sz = __rhs.size();
    __r.__init(&__lhs, 1, 1 + __rhs_sz);
    __r.append(__rhs.data(), __rhs_sz);
    return __r;
}

template<class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>
operator+(const basic_string<_CharT, _Traits, _Allocator>& __lhs, const _CharT* __rhs)
{
    basic_string<_CharT, _Traits, _Allocator> __r(__lhs.get_allocator());
    typename basic_string<_CharT, _Traits, _Allocator>::size_type __lhs_sz = __lhs.size();
    typename basic_string<_CharT, _Traits, _Allocator>::size_type __rhs_sz = _Traits::length(__rhs);
    __r.__init(__lhs.data(), __lhs_sz, __lhs_sz + __rhs_sz);
    __r.append(__rhs, __rhs_sz);
    return __r;
}

template<class _CharT, class _Traits, class _Allocator>
basic_string<_CharT, _Traits, _Allocator>
operator+(const basic_string<_CharT, _Traits, _Allocator>& __lhs, _CharT __rhs)
{
    basic_string<_CharT, _Traits, _Allocator> __r(__lhs.get_allocator());
    typename basic_string<_CharT, _Traits, _Allocator>::size_type __lhs_sz = __lhs.size();
    __r.__init(__lhs.data(), __lhs_sz, __lhs_sz + 1);
    __r.push_back(__rhs);
    return __r;
}

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>
operator+(basic_string<_CharT, _Traits, _Allocator>&& __lhs, const basic_string<_CharT, _Traits, _Allocator>& __rhs)
{
    return _VSTD::move(__lhs.append(__rhs));
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>
operator+(const basic_string<_CharT, _Traits, _Allocator>& __lhs, basic_string<_CharT, _Traits, _Allocator>&& __rhs)
{
    return _VSTD::move(__rhs.insert(0, __lhs));
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>
operator+(basic_string<_CharT, _Traits, _Allocator>&& __lhs, basic_string<_CharT, _Traits, _Allocator>&& __rhs)
{
    return _VSTD::move(__lhs.append(__rhs));
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>
operator+(const _CharT* __lhs , basic_string<_CharT,_Traits,_Allocator>&& __rhs)
{
    return _VSTD::move(__rhs.insert(0, __lhs));
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>
operator+(_CharT __lhs, basic_string<_CharT,_Traits,_Allocator>&& __rhs)
{
    __rhs.insert(__rhs.begin(), __lhs);
    return _VSTD::move(__rhs);
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>
operator+(basic_string<_CharT, _Traits, _Allocator>&& __lhs, const _CharT* __rhs)
{
    return _VSTD::move(__lhs.append(__rhs));
}

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_string<_CharT, _Traits, _Allocator>
operator+(basic_string<_CharT, _Traits, _Allocator>&& __lhs, _CharT __rhs)
{
    __lhs.push_back(__rhs);
    return _VSTD::move(__lhs);
}

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 3999 "/usr/include/c++/v1/string" 3

// swap

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(basic_string<_CharT, _Traits, _Allocator>& __lhs,
     basic_string<_CharT, _Traits, _Allocator>& __rhs)
     _NOEXCEPT_(_NOEXCEPT_(__lhs.swap(__rhs)))
{
    __lhs.swap(__rhs);
}

#ifndef _LIBCPP_HAS_NO_UNICODE_CHARS

typedef basic_string<char16_t> u16string;
typedef basic_string<char32_t> u32string;

#endif  // _LIBCPP_HAS_NO_UNICODE_CHARS
# 4018 "/usr/include/c++/v1/string" 3

_LIBCPP_FUNC_VIS int                stoi  (const string& __str, size_t* __idx = 0, int __base = 10);
_LIBCPP_FUNC_VIS long               stol  (const string& __str, size_t* __idx = 0, int __base = 10);
_LIBCPP_FUNC_VIS unsigned long      stoul (const string& __str, size_t* __idx = 0, int __base = 10);
_LIBCPP_FUNC_VIS long long          stoll (const string& __str, size_t* __idx = 0, int __base = 10);
_LIBCPP_FUNC_VIS unsigned long long stoull(const string& __str, size_t* __idx = 0, int __base = 10);

_LIBCPP_FUNC_VIS float       stof (const string& __str, size_t* __idx = 0);
_LIBCPP_FUNC_VIS double      stod (const string& __str, size_t* __idx = 0);
_LIBCPP_FUNC_VIS long double stold(const string& __str, size_t* __idx = 0);

_LIBCPP_FUNC_VIS string to_string(int __val);
_LIBCPP_FUNC_VIS string to_string(unsigned __val);
_LIBCPP_FUNC_VIS string to_string(long __val);
_LIBCPP_FUNC_VIS string to_string(unsigned long __val);
_LIBCPP_FUNC_VIS string to_string(long long __val);
_LIBCPP_FUNC_VIS string to_string(unsigned long long __val);
_LIBCPP_FUNC_VIS string to_string(float __val);
_LIBCPP_FUNC_VIS string to_string(double __val);
_LIBCPP_FUNC_VIS string to_string(long double __val);

_LIBCPP_FUNC_VIS int                stoi  (const wstring& __str, size_t* __idx = 0, int __base = 10);
_LIBCPP_FUNC_VIS long               stol  (const wstring& __str, size_t* __idx = 0, int __base = 10);
_LIBCPP_FUNC_VIS unsigned long      stoul (const wstring& __str, size_t* __idx = 0, int __base = 10);
_LIBCPP_FUNC_VIS long long          stoll (const wstring& __str, size_t* __idx = 0, int __base = 10);
_LIBCPP_FUNC_VIS unsigned long long stoull(const wstring& __str, size_t* __idx = 0, int __base = 10);

_LIBCPP_FUNC_VIS float       stof (const wstring& __str, size_t* __idx = 0);
_LIBCPP_FUNC_VIS double      stod (const wstring& __str, size_t* __idx = 0);
_LIBCPP_FUNC_VIS long double stold(const wstring& __str, size_t* __idx = 0);

_LIBCPP_FUNC_VIS wstring to_wstring(int __val);
_LIBCPP_FUNC_VIS wstring to_wstring(unsigned __val);
_LIBCPP_FUNC_VIS wstring to_wstring(long __val);
_LIBCPP_FUNC_VIS wstring to_wstring(unsigned long __val);
_LIBCPP_FUNC_VIS wstring to_wstring(long long __val);
_LIBCPP_FUNC_VIS wstring to_wstring(unsigned long long __val);
_LIBCPP_FUNC_VIS wstring to_wstring(float __val);
_LIBCPP_FUNC_VIS wstring to_wstring(double __val);
_LIBCPP_FUNC_VIS wstring to_wstring(long double __val);

template<class _CharT, class _Traits, class _Allocator>
    const typename basic_string<_CharT, _Traits, _Allocator>::size_type
                   basic_string<_CharT, _Traits, _Allocator>::npos;

template<class _Ptr>
size_t _LIBCPP_INLINE_VISIBILITY __do_string_hash(_Ptr __p, _Ptr __e)
{
    typedef typename iterator_traits<_Ptr>::value_type value_type;
    return __murmur2_or_cityhash<size_t>()(__p, (__e-__p)*sizeof(value_type));
}

template<class _CharT, class _Traits, class _Allocator>
struct _LIBCPP_TYPE_VIS_ONLY hash<basic_string<_CharT, _Traits, _Allocator> >
    : public unary_function<basic_string<_CharT, _Traits, _Allocator>, size_t>
{
    size_t
        operator()(const basic_string<_CharT, _Traits, _Allocator>& __val) const _NOEXCEPT;
};

template<class _CharT, class _Traits, class _Allocator>
size_t
hash<basic_string<_CharT, _Traits, _Allocator> >::operator()(
        const basic_string<_CharT, _Traits, _Allocator>& __val) const _NOEXCEPT
{
    return __do_string_hash(__val.data(), __val.data() + __val.size());
}

template<class _CharT, class _Traits, class _Allocator>
basic_ostream<_CharT, _Traits>&
operator<<(basic_ostream<_CharT, _Traits>& __os,
           const basic_string<_CharT, _Traits, _Allocator>& __str);

template<class _CharT, class _Traits, class _Allocator>
basic_istream<_CharT, _Traits>&
operator>>(basic_istream<_CharT, _Traits>& __is,
           basic_string<_CharT, _Traits, _Allocator>& __str);

template<class _CharT, class _Traits, class _Allocator>
basic_istream<_CharT, _Traits>&
getline(basic_istream<_CharT, _Traits>& __is,
        basic_string<_CharT, _Traits, _Allocator>& __str, _CharT __dlm);

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_istream<_CharT, _Traits>&
getline(basic_istream<_CharT, _Traits>& __is,
        basic_string<_CharT, _Traits, _Allocator>& __str);

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_istream<_CharT, _Traits>&
getline(basic_istream<_CharT, _Traits>&& __is,
        basic_string<_CharT, _Traits, _Allocator>& __str, _CharT __dlm);

template<class _CharT, class _Traits, class _Allocator>
inline _LIBCPP_INLINE_VISIBILITY
basic_istream<_CharT, _Traits>&
getline(basic_istream<_CharT, _Traits>&& __is,
        basic_string<_CharT, _Traits, _Allocator>& __str);

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 4122 "/usr/include/c++/v1/string" 3

#if _LIBCPP_DEBUG_LEVEL >= 2

template<class _CharT, class _Traits, class _Allocator>
bool
basic_string<_CharT, _Traits, _Allocator>::__dereferenceable(const const_iterator* __i) const
{
    return this->data() <= _VSTD::__to_raw_pointer(__i->base()) &&
           _VSTD::__to_raw_pointer(__i->base()) < this->data() + this->size();
}

template<class _CharT, class _Traits, class _Allocator>
bool
basic_string<_CharT, _Traits, _Allocator>::__decrementable(const const_iterator* __i) const
{
    return this->data() < _VSTD::__to_raw_pointer(__i->base()) &&
           _VSTD::__to_raw_pointer(__i->base()) <= this->data() + this->size();
}

template<class _CharT, class _Traits, class _Allocator>
bool
basic_string<_CharT, _Traits, _Allocator>::__addable(const const_iterator* __i, ptrdiff_t __n) const
{
    const value_type* __p = _VSTD::__to_raw_pointer(__i->base()) + __n;
    return this->data() <= __p && __p <= this->data() + this->size();
}

template<class _CharT, class _Traits, class _Allocator>
bool
basic_string<_CharT, _Traits, _Allocator>::__subscriptable(const const_iterator* __i, ptrdiff_t __n) const
{
    const value_type* __p = _VSTD::__to_raw_pointer(__i->base()) + __n;
    return this->data() <= __p && __p < this->data() + this->size();
}

#endif  // _LIBCPP_DEBUG_LEVEL >= 2
# 4158 "/usr/include/c++/v1/string" 3

#if _LIBCPP_STD_VER > 11 
// Literal suffixes for basic_string [basic.string.literals]
inline namespace literals
{
  inline namespace string_literals
  {
    inline _LIBCPP_INLINE_VISIBILITY
    basic_string<char> operator "" s( const char *__str, size_t __len )
    {
        return basic_string<char> (__str, __len);
    }

    inline _LIBCPP_INLINE_VISIBILITY
    basic_string<wchar_t> operator "" s( const wchar_t *__str, size_t __len )
    {
        return basic_string<wchar_t> (__str, __len);
    }

    inline _LIBCPP_INLINE_VISIBILITY
    basic_string<char16_t> operator "" s( const char16_t *__str, size_t __len )
    {
        return basic_string<char16_t> (__str, __len);
    }

    inline _LIBCPP_INLINE_VISIBILITY
    basic_string<char32_t> operator "" s( const char32_t *__str, size_t __len )
    {
        return basic_string<char32_t> (__str, __len);
    }
  }
}
#endif
# 4191 "/usr/include/c++/v1/string" 3

_LIBCPP_EXTERN_TEMPLATE(class _LIBCPP_TYPE_VIS basic_string<char>)
_LIBCPP_EXTERN_TEMPLATE(class _LIBCPP_TYPE_VIS basic_string<wchar_t>)
_LIBCPP_EXTERN_TEMPLATE(string operator+<char, char_traits<char>, allocator<char> >(char const*, string const&))

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_STRING
# 4199 "/usr/include/c++/v1/string" 3
# 16 "/usr/include/c++/v1/__locale" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 17 "/usr/include/c++/v1/__locale" 3
#if 0 /* expanded by -frewrite-includes */
#include <utility>
#endif /* expanded by -frewrite-includes */
# 18 "/usr/include/c++/v1/__locale" 3
#if 0 /* expanded by -frewrite-includes */
#include <mutex>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/mutex" 1 3
// -*- C++ -*-
//===--------------------------- mutex ------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_MUTEX
#define _LIBCPP_MUTEX

/*
    mutex synopsis

namespace std
{

class mutex
{
public:
     constexpr mutex() noexcept;
     ~mutex();

    mutex(const mutex&) = delete;
    mutex& operator=(const mutex&) = delete;

    void lock();
    bool try_lock();
    void unlock();

    typedef pthread_mutex_t* native_handle_type;
    native_handle_type native_handle();
};

class recursive_mutex
{
public:
     recursive_mutex();
     ~recursive_mutex();

    recursive_mutex(const recursive_mutex&) = delete;
    recursive_mutex& operator=(const recursive_mutex&) = delete;

    void lock();
    bool try_lock() noexcept;
    void unlock();

    typedef pthread_mutex_t* native_handle_type;
    native_handle_type native_handle();
};

class timed_mutex
{
public:
     timed_mutex();
     ~timed_mutex();

    timed_mutex(const timed_mutex&) = delete;
    timed_mutex& operator=(const timed_mutex&) = delete;

    void lock();
    bool try_lock();
    template <class Rep, class Period>
        bool try_lock_for(const chrono::duration<Rep, Period>& rel_time);
    template <class Clock, class Duration>
        bool try_lock_until(const chrono::time_point<Clock, Duration>& abs_time);
    void unlock();
};

class recursive_timed_mutex
{
public:
     recursive_timed_mutex();
     ~recursive_timed_mutex();

    recursive_timed_mutex(const recursive_timed_mutex&) = delete;
    recursive_timed_mutex& operator=(const recursive_timed_mutex&) = delete;

    void lock();
    bool try_lock() noexcept;
    template <class Rep, class Period>
        bool try_lock_for(const chrono::duration<Rep, Period>& rel_time);
    template <class Clock, class Duration>
        bool try_lock_until(const chrono::time_point<Clock, Duration>& abs_time);
    void unlock();
};

struct defer_lock_t {};
struct try_to_lock_t {};
struct adopt_lock_t {};

constexpr defer_lock_t  defer_lock{};
constexpr try_to_lock_t try_to_lock{};
constexpr adopt_lock_t  adopt_lock{};

template <class Mutex>
class lock_guard
{
public:
    typedef Mutex mutex_type;

    explicit lock_guard(mutex_type& m);
    lock_guard(mutex_type& m, adopt_lock_t);
    ~lock_guard();

    lock_guard(lock_guard const&) = delete;
    lock_guard& operator=(lock_guard const&) = delete;
};

template <class Mutex>
class unique_lock
{
public:
    typedef Mutex mutex_type;
    unique_lock() noexcept;
    explicit unique_lock(mutex_type& m);
    unique_lock(mutex_type& m, defer_lock_t) noexcept;
    unique_lock(mutex_type& m, try_to_lock_t);
    unique_lock(mutex_type& m, adopt_lock_t);
    template <class Clock, class Duration>
        unique_lock(mutex_type& m, const chrono::time_point<Clock, Duration>& abs_time);
    template <class Rep, class Period>
        unique_lock(mutex_type& m, const chrono::duration<Rep, Period>& rel_time);
    ~unique_lock();

    unique_lock(unique_lock const&) = delete;
    unique_lock& operator=(unique_lock const&) = delete;

    unique_lock(unique_lock&& u) noexcept;
    unique_lock& operator=(unique_lock&& u) noexcept;

    void lock();
    bool try_lock();

    template <class Rep, class Period>
        bool try_lock_for(const chrono::duration<Rep, Period>& rel_time);
    template <class Clock, class Duration>
        bool try_lock_until(const chrono::time_point<Clock, Duration>& abs_time);

    void unlock();

    void swap(unique_lock& u) noexcept;
    mutex_type* release() noexcept;

    bool owns_lock() const noexcept;
    explicit operator bool () const noexcept;
    mutex_type* mutex() const noexcept;
};

template <class Mutex>
  void swap(unique_lock<Mutex>& x, unique_lock<Mutex>& y) noexcept;

template <class L1, class L2, class... L3>
  int try_lock(L1&, L2&, L3&...);
template <class L1, class L2, class... L3>
  void lock(L1&, L2&, L3&...);

struct once_flag
{
    constexpr once_flag() noexcept;

    once_flag(const once_flag&) = delete;
    once_flag& operator=(const once_flag&) = delete;
};

template<class Callable, class ...Args>
  void call_once(once_flag& flag, Callable&& func, Args&&... args);

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 176 "/usr/include/c++/v1/mutex" 3
#if 0 /* expanded by -frewrite-includes */
#include <__mutex_base>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/__mutex_base" 1 3
// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP___MUTEX_BASE
#define _LIBCPP___MUTEX_BASE

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 15 "/usr/include/c++/v1/__mutex_base" 3
#if 0 /* expanded by -frewrite-includes */
#include <chrono>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/chrono" 1 3
// -*- C++ -*-
//===---------------------------- chrono ----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CHRONO
#define _LIBCPP_CHRONO

/*
    chrono synopsis

namespace std
{
namespace chrono
{

template <class ToDuration, class Rep, class Period>
constexpr
ToDuration
duration_cast(const duration<Rep, Period>& fd);

template <class Rep> struct treat_as_floating_point : is_floating_point<Rep> {};

template <class Rep>
struct duration_values
{
public:
    static constexpr Rep zero();
    static constexpr Rep max();
    static constexpr Rep min();
};

// duration

template <class Rep, class Period = ratio<1>>
class duration
{
    static_assert(!__is_duration<Rep>::value, "A duration representation can not be a duration");
    static_assert(__is_ratio<Period>::value, "Second template parameter of duration must be a std::ratio");
    static_assert(Period::num > 0, "duration period must be positive");
public:
    typedef Rep rep;
    typedef Period period;

    constexpr duration() = default;
    template <class Rep2>
        constexpr explicit duration(const Rep2& r,
            typename enable_if
            <
               is_convertible<Rep2, rep>::value &&
               (treat_as_floating_point<rep>::value ||
               !treat_as_floating_point<rep>::value && !treat_as_floating_point<Rep2>::value)
            >::type* = 0);

    // conversions
    template <class Rep2, class Period2>
        constexpr duration(const duration<Rep2, Period2>& d,
            typename enable_if
            <
                treat_as_floating_point<rep>::value ||
                ratio_divide<Period2, period>::type::den == 1
            >::type* = 0);

    // observer

    constexpr rep count() const;

    // arithmetic

    constexpr duration  operator+() const;
    constexpr duration  operator-() const;
    duration& operator++();
    duration  operator++(int);
    duration& operator--();
    duration  operator--(int);

    duration& operator+=(const duration& d);
    duration& operator-=(const duration& d);

    duration& operator*=(const rep& rhs);
    duration& operator/=(const rep& rhs);

    // special values

    static constexpr duration zero();
    static constexpr duration min();
    static constexpr duration max();
};

typedef duration<long long,         nano> nanoseconds;
typedef duration<long long,        micro> microseconds;
typedef duration<long long,        milli> milliseconds;
typedef duration<long long              > seconds;
typedef duration<     long, ratio<  60> > minutes;
typedef duration<     long, ratio<3600> > hours;

template <class Clock, class Duration = typename Clock::duration>
class time_point
{
public:
    typedef Clock                     clock;
    typedef Duration                  duration;
    typedef typename duration::rep    rep;
    typedef typename duration::period period;
private:
    duration d_;  // exposition only

public:
    time_point();  // has value "epoch" // constexpr in C++14
    explicit time_point(const duration& d);  // same as time_point() + d // constexpr in C++14

    // conversions
    template <class Duration2>
       time_point(const time_point<clock, Duration2>& t); // constexpr in C++14

    // observer

    duration time_since_epoch() const; // constexpr in C++14

    // arithmetic

    time_point& operator+=(const duration& d);
    time_point& operator-=(const duration& d);

    // special values

    static constexpr time_point min();
    static constexpr time_point max();
};

} // chrono

// common_type traits
template <class Rep1, class Period1, class Rep2, class Period2>
  struct common_type<chrono::duration<Rep1, Period1>, chrono::duration<Rep2, Period2>>;

template <class Clock, class Duration1, class Duration2>
  struct common_type<chrono::time_point<Clock, Duration1>, chrono::time_point<Clock, Duration2>>;

namespace chrono {

// duration arithmetic
template <class Rep1, class Period1, class Rep2, class Period2>
  constexpr
  typename common_type<duration<Rep1, Period1>, duration<Rep2, Period2>>::type
  operator+(const duration<Rep1, Period1>& lhs, const duration<Rep2, Period2>& rhs);
template <class Rep1, class Period1, class Rep2, class Period2>
  constexpr
  typename common_type<duration<Rep1, Period1>, duration<Rep2, Period2>>::type
  operator-(const duration<Rep1, Period1>& lhs, const duration<Rep2, Period2>& rhs);
template <class Rep1, class Period, class Rep2>
  constexpr
  duration<typename common_type<Rep1, Rep2>::type, Period>
  operator*(const duration<Rep1, Period>& d, const Rep2& s);
template <class Rep1, class Period, class Rep2>
  constexpr
  duration<typename common_type<Rep1, Rep2>::type, Period>
  operator*(const Rep1& s, const duration<Rep2, Period>& d);
template <class Rep1, class Period, class Rep2>
  constexpr
  duration<typename common_type<Rep1, Rep2>::type, Period>
  operator/(const duration<Rep1, Period>& d, const Rep2& s);
template <class Rep1, class Period1, class Rep2, class Period2>
  constexpr
  typename common_type<Rep1, Rep2>::type
  operator/(const duration<Rep1, Period1>& lhs, const duration<Rep2, Period2>& rhs);

// duration comparisons
template <class Rep1, class Period1, class Rep2, class Period2>
   constexpr
   bool operator==(const duration<Rep1, Period1>& lhs, const duration<Rep2, Period2>& rhs);
template <class Rep1, class Period1, class Rep2, class Period2>
   constexpr
   bool operator!=(const duration<Rep1, Period1>& lhs, const duration<Rep2, Period2>& rhs);
template <class Rep1, class Period1, class Rep2, class Period2>
   constexpr
   bool operator< (const duration<Rep1, Period1>& lhs, const duration<Rep2, Period2>& rhs);
template <class Rep1, class Period1, class Rep2, class Period2>
   constexpr
   bool operator<=(const duration<Rep1, Period1>& lhs, const duration<Rep2, Period2>& rhs);
template <class Rep1, class Period1, class Rep2, class Period2>
   constexpr
   bool operator> (const duration<Rep1, Period1>& lhs, const duration<Rep2, Period2>& rhs);
template <class Rep1, class Period1, class Rep2, class Period2>
   constexpr
   bool operator>=(const duration<Rep1, Period1>& lhs, const duration<Rep2, Period2>& rhs);

// duration_cast
template <class ToDuration, class Rep, class Period>
  ToDuration duration_cast(const duration<Rep, Period>& d);

// time_point arithmetic (all constexpr in C++14)
template <class Clock, class Duration1, class Rep2, class Period2>
  time_point<Clock, typename common_type<Duration1, duration<Rep2, Period2>>::type>
  operator+(const time_point<Clock, Duration1>& lhs, const duration<Rep2, Period2>& rhs);
template <class Rep1, class Period1, class Clock, class Duration2>
  time_point<Clock, typename common_type<duration<Rep1, Period1>, Duration2>::type>
  operator+(const duration<Rep1, Period1>& lhs, const time_point<Clock, Duration2>& rhs);
template <class Clock, class Duration1, class Rep2, class Period2>
  time_point<Clock, typename common_type<Duration1, duration<Rep2, Period2>>::type>
  operator-(const time_point<Clock, Duration1>& lhs, const duration<Rep2, Period2>& rhs);
template <class Clock, class Duration1, class Duration2>
  typename common_type<Duration1, Duration2>::type
  operator-(const time_point<Clock, Duration1>& lhs, const time_point<Clock, Duration2>& rhs);

// time_point comparisons (all constexpr in C++14)
template <class Clock, class Duration1, class Duration2>
   bool operator==(const time_point<Clock, Duration1>& lhs, const time_point<Clock, Duration2>& rhs);
template <class Clock, class Duration1, class Duration2>
   bool operator!=(const time_point<Clock, Duration1>& lhs, const time_point<Clock, Duration2>& rhs);
template <class Clock, class Duration1, class Duration2>
   bool operator< (const time_point<Clock, Duration1>& lhs, const time_point<Clock, Duration2>& rhs);
template <class Clock, class Duration1, class Duration2>
   bool operator<=(const time_point<Clock, Duration1>& lhs, const time_point<Clock, Duration2>& rhs);
template <class Clock, class Duration1, class Duration2>
   bool operator> (const time_point<Clock, Duration1>& lhs, const time_point<Clock, Duration2>& rhs);
template <class Clock, class Duration1, class Duration2>
   bool operator>=(const time_point<Clock, Duration1>& lhs, const time_point<Clock, Duration2>& rhs);

// time_point_cast (constexpr in C++14)

template <class ToDuration, class Clock, class Duration>
  time_point<Clock, ToDuration> time_point_cast(const time_point<Clock, Duration>& t);

// Clocks

class system_clock
{
public:
    typedef microseconds                     duration;
    typedef duration::rep                    rep;
    typedef duration::period                 period;
    typedef chrono::time_point<system_clock> time_point;
    static const bool is_steady =            false; // constexpr in C++14

    static time_point now() noexcept;
    static time_t     to_time_t  (const time_point& __t) noexcept;
    static time_point from_time_t(time_t __t) noexcept;
};

class steady_clock
{
public:
    typedef nanoseconds                                   duration;
    typedef duration::rep                                 rep;
    typedef duration::period                              period;
    typedef chrono::time_point<steady_clock, duration>    time_point;
    static const bool is_steady =                         true; // constexpr in C++14

    static time_point now() noexcept;
};

typedef steady_clock high_resolution_clock;

}  // chrono

constexpr chrono::hours                                 operator "" h(unsigned long long); // C++14
constexpr chrono::duration<unspecified , ratio<3600,1>> operator "" h(long double); // C++14
constexpr chrono::minutes                               operator "" min(unsigned long long); // C++14
constexpr chrono::duration<unspecified , ratio<60,1>>   operator "" min(long double); // C++14
constexpr chrono::seconds                               operator "" s(unsigned long long); // C++14
constexpr chrono::duration<unspecified >                operator "" s(long double); // C++14
constexpr chrono::milliseconds                          operator "" ms(unsigned long long); // C++14
constexpr chrono::duration<unspecified , milli>         operator "" ms(long double); // C++14
constexpr chrono::microseconds                          operator "" us(unsigned long long); // C++14
constexpr chrono::duration<unspecified , micro>         operator "" us(long double); // C++14
constexpr chrono::nanoseconds                           operator "" ns(unsigned long long); // C++14
constexpr chrono::duration<unspecified , nano>          operator "" ns(long double); // C++14

}  // std
*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 279 "/usr/include/c++/v1/chrono" 3
#if 0 /* expanded by -frewrite-includes */
#include <ctime>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/ctime" 1 3
// -*- C++ -*-
//===---------------------------- ctime -----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CTIME
#define _LIBCPP_CTIME

/*
    ctime synopsis

Macros:

    NULL
    CLOCKS_PER_SEC

namespace std
{

Types:

    clock_t
    size_t
    time_t
    tm

clock_t clock();
double difftime(time_t time1, time_t time0);
time_t mktime(tm* timeptr);
time_t time(time_t* timer);
char* asctime(const tm* timeptr);
char* ctime(const time_t* timer);
tm*    gmtime(const time_t* timer);
tm* localtime(const time_t* timer);
size_t strftime(char* restrict s, size_t maxsize, const char* restrict format,
                const tm* restrict timeptr);

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 48 "/usr/include/c++/v1/ctime" 3
#if 0 /* expanded by -frewrite-includes */
#include <time.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/time.h" 1 3 4
/*
 * Copyright (c) 1989, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)time.h	8.3 (Berkeley) 1/21/94
 */

/*
 * $FreeBSD: head/include/time.h 245428 2013-01-14 18:01:19Z dim $
 */

#ifndef _TIME_H_
#define	_TIME_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 45 "/usr/include/time.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_null.h>
#endif /* expanded by -frewrite-includes */
# 46 "/usr/include/time.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 47 "/usr/include/time.h" 3 4

#if __POSIX_VISIBLE > 0 && __POSIX_VISIBLE < 200112 || __BSD_VISIBLE
/*
 * Frequency of the clock ticks reported by times().  Deprecated - use
 * sysconf(_SC_CLK_TCK) instead.  (Removed in 1003.1-2001.)
 */
#define	CLK_TCK		128
#endif
# 55 "/usr/include/time.h" 3 4

/* Frequency of the clock ticks reported by clock().  */
#define	CLOCKS_PER_SEC	128

#ifndef _CLOCK_T_DECLARED
typedef	__clock_t	clock_t;
#define	_CLOCK_T_DECLARED
#endif
# 63 "/usr/include/time.h" 3 4

#ifndef _TIME_T_DECLARED
typedef	__time_t	time_t;
#define	_TIME_T_DECLARED
#endif
# 68 "/usr/include/time.h" 3 4

#ifndef _SIZE_T_DECLARED
typedef	__size_t	size_t;
#define	_SIZE_T_DECLARED
#endif
# 73 "/usr/include/time.h" 3 4

#if __POSIX_VISIBLE >= 199309
/*
 * New in POSIX 1003.1b-1993.
 */
#ifndef _CLOCKID_T_DECLARED
typedef	__clockid_t	clockid_t;
#define	_CLOCKID_T_DECLARED
#endif
# 82 "/usr/include/time.h" 3 4

#ifndef _TIMER_T_DECLARED
typedef	__timer_t	timer_t;
#define	_TIMER_T_DECLARED
#endif
# 87 "/usr/include/time.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/timespec.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/sys/timespec.h" 1 3 4
/*-
 * Copyright (c) 1982, 1986, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)time.h	8.5 (Berkeley) 5/4/95
 * from: FreeBSD: src/sys/sys/time.h,v 1.43 2000/03/20 14:09:05 phk Exp
 *	$FreeBSD: head/sys/sys/timespec.h 205792 2010-03-28 13:13:22Z ed $
 */

#ifndef _SYS_TIMESPEC_H_
#define _SYS_TIMESPEC_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 38 "/usr/include/sys/timespec.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_timespec.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/sys/_timespec.h" 1 3 4
/*-
 * Copyright (c) 1982, 1986, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)time.h	8.5 (Berkeley) 5/4/95
 * from: FreeBSD: src/sys/sys/time.h,v 1.43 2000/03/20 14:09:05 phk Exp
 *	$FreeBSD: head/sys/sys/_timespec.h 205792 2010-03-28 13:13:22Z ed $
 */

#ifndef _SYS__TIMESPEC_H_
#define	_SYS__TIMESPEC_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 38 "/usr/include/sys/_timespec.h" 3 4

#ifndef _TIME_T_DECLARED
typedef	__time_t	time_t;
#define	_TIME_T_DECLARED
#endif
# 43 "/usr/include/sys/_timespec.h" 3 4

struct timespec {
	time_t	tv_sec;		/* seconds */
	long	tv_nsec;	/* and nanoseconds */
};

#endif /* !_SYS__TIMESPEC_H_ */
# 50 "/usr/include/sys/_timespec.h" 3 4
# 39 "/usr/include/sys/timespec.h" 2 3 4

#if __BSD_VISIBLE
#define	TIMEVAL_TO_TIMESPEC(tv, ts)					\
	do {								\
		(ts)->tv_sec = (tv)->tv_sec;				\
		(ts)->tv_nsec = (tv)->tv_usec * 1000;			\
	} while (0)
#define	TIMESPEC_TO_TIMEVAL(tv, ts)					\
	do {								\
		(tv)->tv_sec = (ts)->tv_sec;				\
		(tv)->tv_usec = (ts)->tv_nsec / 1000;			\
	} while (0)

#endif /* __BSD_VISIBLE */
# 53 "/usr/include/sys/timespec.h" 3 4

/*
 * Structure defined by POSIX.1b to be like a itimerval, but with
 * timespecs. Used in the timer_*() system calls.
 */
struct itimerspec {
	struct timespec  it_interval;
	struct timespec  it_value;
};

#endif /* _SYS_TIMESPEC_H_ */
# 64 "/usr/include/sys/timespec.h" 3 4
# 89 "/usr/include/time.h" 2 3 4
#endif /* __POSIX_VISIBLE >= 199309 */
# 90 "/usr/include/time.h" 3 4

#if __POSIX_VISIBLE >= 200112
#ifndef _PID_T_DECLARED
typedef	__pid_t		pid_t;
#define	_PID_T_DECLARED
#endif
# 96 "/usr/include/time.h" 3 4
#endif
# 97 "/usr/include/time.h" 3 4

/* These macros are also in sys/time.h. */
#if !defined(CLOCK_REALTIME) && __POSIX_VISIBLE >= 200112
#define CLOCK_REALTIME	0
#ifdef __BSD_VISIBLE
#define CLOCK_VIRTUAL	1
#define CLOCK_PROF	2
#endif
# 105 "/usr/include/time.h" 3 4
#define CLOCK_MONOTONIC	4
#define CLOCK_UPTIME	5		/* FreeBSD-specific. */
#define CLOCK_UPTIME_PRECISE	7	/* FreeBSD-specific. */
#define CLOCK_UPTIME_FAST	8	/* FreeBSD-specific. */
#define CLOCK_REALTIME_PRECISE	9	/* FreeBSD-specific. */
#define CLOCK_REALTIME_FAST	10	/* FreeBSD-specific. */
#define CLOCK_MONOTONIC_PRECISE	11	/* FreeBSD-specific. */
#define CLOCK_MONOTONIC_FAST	12	/* FreeBSD-specific. */
#define CLOCK_SECOND	13		/* FreeBSD-specific. */
#define CLOCK_THREAD_CPUTIME_ID	14
#define	CLOCK_PROCESS_CPUTIME_ID	15
#endif /* !defined(CLOCK_REALTIME) && __POSIX_VISIBLE >= 200112 */
# 117 "/usr/include/time.h" 3 4

#if !defined(TIMER_ABSTIME) && __POSIX_VISIBLE >= 200112
#if __BSD_VISIBLE
#define TIMER_RELTIME	0x0	/* relative timer */
#endif
# 122 "/usr/include/time.h" 3 4
#define TIMER_ABSTIME	0x1	/* absolute timer */
#endif /* !defined(TIMER_ABSTIME) && __POSIX_VISIBLE >= 200112 */
# 124 "/usr/include/time.h" 3 4

struct tm {
	int	tm_sec;		/* seconds after the minute [0-60] */
	int	tm_min;		/* minutes after the hour [0-59] */
	int	tm_hour;	/* hours since midnight [0-23] */
	int	tm_mday;	/* day of the month [1-31] */
	int	tm_mon;		/* months since January [0-11] */
	int	tm_year;	/* years since 1900 */
	int	tm_wday;	/* days since Sunday [0-6] */
	int	tm_yday;	/* days since January 1 [0-365] */
	int	tm_isdst;	/* Daylight Savings Time flag */
	long	tm_gmtoff;	/* offset from UTC in seconds */
	char	*tm_zone;	/* timezone abbreviation */
};

#if __POSIX_VISIBLE
extern char *tzname[];
#endif
# 142 "/usr/include/time.h" 3 4

__BEGIN_DECLS
char *asctime(const struct tm *);
clock_t clock(void);
char *ctime(const time_t *);
double difftime(time_t, time_t);
/* XXX missing: getdate() */
struct tm *gmtime(const time_t *);
struct tm *localtime(const time_t *);
time_t mktime(struct tm *);
size_t strftime(char * __restrict, size_t, const char * __restrict,
    const struct tm * __restrict);
time_t time(time_t *);
#if __POSIX_VISIBLE >= 200112
struct sigevent;
int timer_create(clockid_t, struct sigevent *__restrict, timer_t *__restrict);
int timer_delete(timer_t);
int timer_gettime(timer_t, struct itimerspec *);
int timer_getoverrun(timer_t);
int timer_settime(timer_t, int, const struct itimerspec *__restrict,
	struct itimerspec *__restrict);
#endif
# 164 "/usr/include/time.h" 3 4
#if __POSIX_VISIBLE
void tzset(void);
#endif
# 167 "/usr/include/time.h" 3 4

#if __POSIX_VISIBLE >= 199309
int clock_getres(clockid_t, struct timespec *);
int clock_gettime(clockid_t, struct timespec *);
int clock_settime(clockid_t, const struct timespec *);
/* XXX missing: clock_nanosleep() */
int nanosleep(const struct timespec *, struct timespec *);
#endif /* __POSIX_VISIBLE >= 199309 */
# 175 "/usr/include/time.h" 3 4

#if __POSIX_VISIBLE >= 200112
int clock_getcpuclockid(pid_t, clockid_t *);
#endif
# 179 "/usr/include/time.h" 3 4

#if __POSIX_VISIBLE >= 199506
char *asctime_r(const struct tm *, char *);
char *ctime_r(const time_t *, char *);
struct tm *gmtime_r(const time_t *, struct tm *);
struct tm *localtime_r(const time_t *, struct tm *);
#endif
# 186 "/usr/include/time.h" 3 4

#if __XSI_VISIBLE
char *strptime(const char * __restrict, const char * __restrict,
    struct tm * __restrict);
#endif
# 191 "/usr/include/time.h" 3 4

#if __BSD_VISIBLE
char *timezone(int, int);	/* XXX XSI conflict */
void tzsetwall(void);
time_t timelocal(struct tm * const);
time_t timegm(struct tm * const);
#endif /* __BSD_VISIBLE */
# 198 "/usr/include/time.h" 3 4

#if __POSIX_VISIBLE >= 200809 || defined(_XLOCALE_H_)
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_time.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/xlocale/_time.h" 1 3 4
/*-
 * Copyright (c) 2011, 2012 The FreeBSD Foundation
 * All rights reserved.
 *
 * This software was developed by David Chisnall under sponsorship from
 * the FreeBSD Foundation.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/include/xlocale/_time.h 231673 2012-02-14 12:03:23Z theraven $
 */

#ifndef _LOCALE_T_DEFINED
#define _LOCALE_T_DEFINED
typedef struct	_xlocale *locale_t;
#endif
# 36 "/usr/include/xlocale/_time.h" 3 4

/*
 * This file is included from both locale.h and xlocale.h.  We need to expose
 * the declarations unconditionally if we are included from xlocale.h, but only
 * if we are in POSIX2008 mode if included from locale.h.
 */
#ifndef _XLOCALE_LOCALE1_H
#define _XLOCALE_LOCALE1_H

size_t	 strftime_l(char * __restrict, size_t, const char * __restrict,
	    const struct tm * __restrict, locale_t) __strftimelike(3, 0);

#endif /* _XLOCALE_LOCALE1_H */
# 49 "/usr/include/xlocale/_time.h" 3 4

#ifdef _XLOCALE_H_
#ifndef _XLOCALE_LOCALE2_H
#define _XLOCALE_LOCALE2_H

char	*strptime_l(const char * __restrict, const char * __restrict,
           struct tm * __restrict, locale_t);

#endif /* _XLOCALE_LOCALE2_H */
# 58 "/usr/include/xlocale/_time.h" 3 4
#endif /* _XLOCALE_H_ */
# 59 "/usr/include/xlocale/_time.h" 3 4
# 201 "/usr/include/time.h" 2 3 4
#endif
# 202 "/usr/include/time.h" 3 4
__END_DECLS

#endif /* !_TIME_H_ */
# 205 "/usr/include/time.h" 3 4
# 49 "/usr/include/c++/v1/ctime" 2 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 52 "/usr/include/c++/v1/ctime" 3
#endif
# 53 "/usr/include/c++/v1/ctime" 3

_LIBCPP_BEGIN_NAMESPACE_STD

using ::clock_t;
using ::size_t;
using ::time_t;
using ::tm;
using ::clock;
using ::difftime;
using ::mktime;
using ::time;
using ::asctime;
using ::ctime;
using ::gmtime;
using ::localtime;
using ::strftime;

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_CTIME
# 73 "/usr/include/c++/v1/ctime" 3
# 280 "/usr/include/c++/v1/chrono" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 281 "/usr/include/c++/v1/chrono" 3
#if 0 /* expanded by -frewrite-includes */
#include <ratio>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/ratio" 1 3
// -*- C++ -*-
//===---------------------------- ratio -----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_RATIO
#define _LIBCPP_RATIO

/*
    ratio synopsis

namespace std
{

template <intmax_t N, intmax_t D = 1>
class ratio
{
public:
    static const intmax_t num;
    static const intmax_t den;
    typedef ratio<num, den> type;
};

// ratio arithmetic
template <class R1, class R2> using ratio_add = ...;
template <class R1, class R2> using ratio_subtract = ...;
template <class R1, class R2> using ratio_multiply = ...;
template <class R1, class R2> using ratio_divide = ...;

// ratio comparison
template <class R1, class R2> struct ratio_equal;
template <class R1, class R2> struct ratio_not_equal;
template <class R1, class R2> struct ratio_less;
template <class R1, class R2> struct ratio_less_equal;
template <class R1, class R2> struct ratio_greater;
template <class R1, class R2> struct ratio_greater_equal;

// convenience SI typedefs
typedef ratio<1, 1000000000000000000000000> yocto;  // not supported
typedef ratio<1,    1000000000000000000000> zepto;  // not supported
typedef ratio<1,       1000000000000000000> atto;
typedef ratio<1,          1000000000000000> femto;
typedef ratio<1,             1000000000000> pico;
typedef ratio<1,                1000000000> nano;
typedef ratio<1,                   1000000> micro;
typedef ratio<1,                      1000> milli;
typedef ratio<1,                       100> centi;
typedef ratio<1,                        10> deci;
typedef ratio<                       10, 1> deca;
typedef ratio<                      100, 1> hecto;
typedef ratio<                     1000, 1> kilo;
typedef ratio<                  1000000, 1> mega;
typedef ratio<               1000000000, 1> giga;
typedef ratio<            1000000000000, 1> tera;
typedef ratio<         1000000000000000, 1> peta;
typedef ratio<      1000000000000000000, 1> exa;
typedef ratio<   1000000000000000000000, 1> zetta;  // not supported
typedef ratio<1000000000000000000000000, 1> yotta;  // not supported

}
*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 69 "/usr/include/c++/v1/ratio" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 70 "/usr/include/c++/v1/ratio" 3
#if 0 /* expanded by -frewrite-includes */
#include <climits>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/climits" 1 3
// -*- C++ -*-
//===--------------------------- climits ----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CLIMITS
#define _LIBCPP_CLIMITS

/*
    climits synopsis

Macros:

    CHAR_BIT
    SCHAR_MIN
    SCHAR_MAX
    UCHAR_MAX
    CHAR_MIN
    CHAR_MAX
    MB_LEN_MAX
    SHRT_MIN
    SHRT_MAX
    USHRT_MAX
    INT_MIN
    INT_MAX
    UINT_MAX
    LONG_MIN
    LONG_MAX
    ULONG_MAX
    LLONG_MIN   // C99
    LLONG_MAX   // C99
    ULLONG_MAX  // C99

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 42 "/usr/include/c++/v1/climits" 3
#if 0 /* expanded by -frewrite-includes */
#include <limits.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/limits.h" 1 3 4
/*-
 * Copyright (c) 1988, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)limits.h	8.2 (Berkeley) 1/4/94
 * $FreeBSD: head/include/limits.h 219271 2011-03-04 19:28:27Z jilles $
 */

#ifndef _LIMITS_H_
#define	_LIMITS_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 37 "/usr/include/limits.h" 3 4

#if __POSIX_VISIBLE
#define	_POSIX_ARG_MAX		4096
#define	_POSIX_LINK_MAX		8
#define	_POSIX_MAX_CANON	255
#define	_POSIX_MAX_INPUT	255
#define	_POSIX_NAME_MAX		14
#define	_POSIX_PIPE_BUF		512
#define	_POSIX_SSIZE_MAX	32767
#define	_POSIX_STREAM_MAX	8

#if __POSIX_VISIBLE >= 200112
#define	_POSIX_CHILD_MAX	25
#define	_POSIX_NGROUPS_MAX	8
#define	_POSIX_OPEN_MAX		20
#define	_POSIX_PATH_MAX		256
#define	_POSIX_TZNAME_MAX	6
#else
# 55 "/usr/include/limits.h" 3 4
#define	_POSIX_CHILD_MAX	6
#define	_POSIX_NGROUPS_MAX	0
#define	_POSIX_OPEN_MAX		16
#define	_POSIX_PATH_MAX		255
#define	_POSIX_TZNAME_MAX	3
#endif
# 61 "/usr/include/limits.h" 3 4

#define	BC_BASE_MAX		   99	/* max ibase/obase values in bc(1) */
#define	BC_DIM_MAX		 2048	/* max array elements in bc(1) */
#define	BC_SCALE_MAX		   99	/* max scale value in bc(1) */
#define	BC_STRING_MAX		 1000	/* max const string length in bc(1) */
#define	COLL_WEIGHTS_MAX	    0	/* max weights for order keyword */
#define	EXPR_NEST_MAX		   32	/* max expressions nested in expr(1) */
#define	LINE_MAX		 2048	/* max bytes in an input line */
#define	RE_DUP_MAX		  255	/* max RE's in interval notation */

#define	_POSIX2_BC_BASE_MAX	99
#define	_POSIX2_BC_DIM_MAX	2048
#define	_POSIX2_BC_SCALE_MAX	99
#define	_POSIX2_BC_STRING_MAX	1000
#define	_POSIX2_EQUIV_CLASS_MAX	2
#define	_POSIX2_EXPR_NEST_MAX	32
#define	_POSIX2_LINE_MAX	2048
#define	_POSIX2_RE_DUP_MAX	255
#endif
# 80 "/usr/include/limits.h" 3 4

#if __POSIX_VISIBLE >= 199309
#define	_POSIX_AIO_LISTIO_MAX	2
#define	_POSIX_AIO_MAX		1
#define	_POSIX_DELAYTIMER_MAX	32
#define	_POSIX_MQ_OPEN_MAX	8
#define	_POSIX_MQ_PRIO_MAX	32
#define	_POSIX_RTSIG_MAX	8
#define	_POSIX_SEM_NSEMS_MAX	256
#define	_POSIX_SEM_VALUE_MAX	32767
#define	_POSIX_SIGQUEUE_MAX	32
#define	_POSIX_TIMER_MAX	32

#define	_POSIX_CLOCKRES_MIN	20000000
#endif
# 95 "/usr/include/limits.h" 3 4

#if __POSIX_VISIBLE >= 199506
#define	_POSIX_THREAD_DESTRUCTOR_ITERATIONS 4
#define	_POSIX_THREAD_KEYS_MAX	128
#define	_POSIX_THREAD_THREADS_MAX 64
#endif
# 101 "/usr/include/limits.h" 3 4

#if __POSIX_VISIBLE >= 200112
#define	_POSIX_HOST_NAME_MAX	255
#define	_POSIX_LOGIN_NAME_MAX	9
#define	_POSIX_SS_REPL_MAX	4
#define	_POSIX_SYMLINK_MAX	255
#define	_POSIX_SYMLOOP_MAX	8
#define	_POSIX_TRACE_EVENT_NAME_MAX 30
#define	_POSIX_TRACE_NAME_MAX	8
#define	_POSIX_TRACE_SYS_MAX	8
#define	_POSIX_TRACE_USER_EVENT_MAX 32
#define	_POSIX_TTY_NAME_MAX	9
#define	_POSIX2_CHARCLASS_NAME_MAX 14
#define	_POSIX2_COLL_WEIGHTS_MAX 2

#define	_POSIX_RE_DUP_MAX	_POSIX2_RE_DUP_MAX
#endif
# 118 "/usr/include/limits.h" 3 4

#if __XSI_VISIBLE || __POSIX_VISIBLE >= 200809
#define	NL_ARGMAX		99	/* max # of position args for printf */
#define	NL_MSGMAX		32767
#define	NL_SETMAX		255
#define	NL_TEXTMAX		2048
#endif
# 125 "/usr/include/limits.h" 3 4

#if __XSI_VISIBLE
#define	_XOPEN_IOV_MAX		16
#define	_XOPEN_NAME_MAX		255
#define	_XOPEN_PATH_MAX		1024
#define	PASS_MAX		128	/* _PASSWORD_LEN from <pwd.h> */

#define	NL_LANGMAX		31	/* max LANG name length */
#define	NL_NMAX			1
#endif
# 135 "/usr/include/limits.h" 3 4

#define	MB_LEN_MAX		6	/* 31-bit UTF-8 */

#if 0 /* expanded by -frewrite-includes */
#include <sys/limits.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/sys/limits.h" 1 3 4
/*-
 * Copyright (c) 1988, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/sys/sys/limits.h 219271 2011-03-04 19:28:27Z jilles $
 */

#ifndef _SYS_LIMITS_H_
#define	_SYS_LIMITS_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 36 "/usr/include/sys/limits.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <machine/_limits.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/machine/_limits.h" 1 3 4
/*-
 * This file is in the public domain.
 */
/* $FreeBSD: head/sys/amd64/include/_limits.h 232262 2012-02-28 18:24:28Z tijl $ */

#if 0 /* expanded by -frewrite-includes */
#include <x86/_limits.h>
#endif /* expanded by -frewrite-includes */
# 7 "/usr/include/machine/_limits.h" 3 4
# 37 "/usr/include/sys/limits.h" 2 3 4

#define	CHAR_BIT	__CHAR_BIT	/* number of bits in a char */

#define	SCHAR_MAX	__SCHAR_MAX	/* max value for a signed char */
#define	SCHAR_MIN	__SCHAR_MIN	/* min value for a signed char */

#define	UCHAR_MAX	__UCHAR_MAX	/* max value for an unsigned char */

#ifdef __CHAR_UNSIGNED__
#define	CHAR_MAX	UCHAR_MAX	/* max value for a char */
#define	CHAR_MIN	0		/* min value for a char */
#else
# 49 "/usr/include/sys/limits.h" 3 4
#define	CHAR_MAX	SCHAR_MAX
#define	CHAR_MIN	SCHAR_MIN
#endif
# 52 "/usr/include/sys/limits.h" 3 4

#define	USHRT_MAX	__USHRT_MAX	/* max value for an unsigned short */
#define	SHRT_MAX	__SHRT_MAX	/* max value for a short */
#define	SHRT_MIN	__SHRT_MIN	/* min value for a short */

#define	UINT_MAX	__UINT_MAX	/* max value for an unsigned int */
#define	INT_MAX		__INT_MAX	/* max value for an int */
#define	INT_MIN		__INT_MIN	/* min value for an int */

#define	ULONG_MAX	__ULONG_MAX	/* max for an unsigned long */
#define	LONG_MAX	__LONG_MAX	/* max for a long */
#define	LONG_MIN	__LONG_MIN	/* min for a long */

#ifdef __LONG_LONG_SUPPORTED
#define	ULLONG_MAX	__ULLONG_MAX	/* max for an unsigned long long */
#define	LLONG_MAX	__LLONG_MAX	/* max for a long long */
#define	LLONG_MIN	__LLONG_MIN	/* min for a long long */
#endif
# 70 "/usr/include/sys/limits.h" 3 4

#if __POSIX_VISIBLE || __XSI_VISIBLE
#define	SSIZE_MAX	__SSIZE_MAX	/* max value for an ssize_t */
#endif
# 74 "/usr/include/sys/limits.h" 3 4

#if __POSIX_VISIBLE >= 200112 || __XSI_VISIBLE
#define	SIZE_T_MAX	__SIZE_T_MAX	/* max value for a size_t */

#define	OFF_MAX		__OFF_MAX	/* max value for an off_t */
#define	OFF_MIN		__OFF_MIN	/* min value for an off_t */
#endif
# 81 "/usr/include/sys/limits.h" 3 4

#if __BSD_VISIBLE
#define	GID_MAX		UINT_MAX	/* max value for a gid_t */
#define	UID_MAX		UINT_MAX	/* max value for a uid_t */

#define	UQUAD_MAX	(__UQUAD_MAX)	/* max value for a uquad_t */
#define	QUAD_MAX	(__QUAD_MAX)	/* max value for a quad_t */
#define	QUAD_MIN	(__QUAD_MIN)	/* min value for a quad_t */
#endif
# 90 "/usr/include/sys/limits.h" 3 4

#if __XSI_VISIBLE || __POSIX_VISIBLE >= 200809
#define	LONG_BIT	__LONG_BIT
#define	WORD_BIT	__WORD_BIT
#endif
# 95 "/usr/include/sys/limits.h" 3 4

#if __POSIX_VISIBLE
#define	MQ_PRIO_MAX	64
#endif
# 99 "/usr/include/sys/limits.h" 3 4

#endif /* !_SYS_LIMITS_H_ */
# 101 "/usr/include/sys/limits.h" 3 4
# 139 "/usr/include/limits.h" 2 3 4

#if __POSIX_VISIBLE
#if 0 /* expanded by -frewrite-includes */
#include <sys/syslimits.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/sys/syslimits.h" 1 3 4
/*-
 * Copyright (c) 1988, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)syslimits.h	8.1 (Berkeley) 6/2/93
 * $FreeBSD: head/sys/sys/syslimits.h 194498 2009-06-19 17:10:35Z brooks $
 */

#ifndef _SYS_SYSLIMITS_H_
#define _SYS_SYSLIMITS_H_

#if !defined(_KERNEL) && !defined(_LIMITS_H_) && !defined(_SYS_PARAM_H_)
#ifndef _SYS_CDEFS_H_
#error this file needs sys/cdefs.h as a prerequisite
#endif
# 40 "/usr/include/sys/syslimits.h" 3 4
#ifdef __CC_SUPPORTS_WARNING
#warning "No user-serviceable parts inside."
#endif
# 43 "/usr/include/sys/syslimits.h" 3 4
#endif
# 44 "/usr/include/sys/syslimits.h" 3 4

/*
 * Do not add any new variables here.  (See the comment at the end of
 * the file for why.)
 */
#define	ARG_MAX			262144	/* max bytes for an exec function */
#ifndef CHILD_MAX
#define	CHILD_MAX		   40	/* max simultaneous processes */
#endif
# 53 "/usr/include/sys/syslimits.h" 3 4
#define	LINK_MAX		32767	/* max file link count */
#define	MAX_CANON		  255	/* max bytes in term canon input line */
#define	MAX_INPUT		  255	/* max bytes in terminal input */
#define	NAME_MAX		  255	/* max bytes in a file name */
#ifndef NGROUPS_MAX
#define	NGROUPS_MAX	 	 1023	/* max supplemental group id's */
#endif
# 60 "/usr/include/sys/syslimits.h" 3 4
#ifndef OPEN_MAX
#define	OPEN_MAX		   64	/* max open files per process */
#endif
# 63 "/usr/include/sys/syslimits.h" 3 4
#define	PATH_MAX		 1024	/* max bytes in pathname */
#define	PIPE_BUF		  512	/* max bytes for atomic pipe writes */
#define	IOV_MAX			 1024	/* max elements in i/o vector */

/*
 * We leave the following values undefined to force applications to either
 * assume conservative values or call sysconf() to get the current value.
 *
 * HOST_NAME_MAX
 *
 * (We should do this for most of the values currently defined here,
 * but many programs are not prepared to deal with this yet.)
 */
#endif
# 77 "/usr/include/sys/syslimits.h" 3 4
# 142 "/usr/include/limits.h" 2 3 4
#endif
# 143 "/usr/include/limits.h" 3 4

#endif /* !_LIMITS_H_ */
# 145 "/usr/include/limits.h" 3 4
# 43 "/usr/include/c++/v1/climits" 2 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 46 "/usr/include/c++/v1/climits" 3
#endif
# 47 "/usr/include/c++/v1/climits" 3

#endif  // _LIBCPP_CLIMITS
# 49 "/usr/include/c++/v1/climits" 3
# 71 "/usr/include/c++/v1/ratio" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 72 "/usr/include/c++/v1/ratio" 3

#if 0 /* expanded by -frewrite-includes */
#include <__undef_min_max>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/__undef_min_max" 1 3
// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifdef min
#if defined(_MSC_VER) && ! defined(__clang__)
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 16 "/usr/include/c++/v1/__undef_min_max" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 18 "/usr/include/c++/v1/__undef_min_max" 3
#undef min
#endif
# 20 "/usr/include/c++/v1/__undef_min_max" 3

#ifdef max
#if defined(_MSC_VER) && ! defined(__clang__)
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 26 "/usr/include/c++/v1/__undef_min_max" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 28 "/usr/include/c++/v1/__undef_min_max" 3
#undef max
#endif
# 30 "/usr/include/c++/v1/__undef_min_max" 3
# 74 "/usr/include/c++/v1/ratio" 2 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 77 "/usr/include/c++/v1/ratio" 3
#endif
# 78 "/usr/include/c++/v1/ratio" 3

_LIBCPP_BEGIN_NAMESPACE_STD

// __static_gcd

template <intmax_t _Xp, intmax_t _Yp>
struct __static_gcd
{
    static const intmax_t value = __static_gcd<_Yp, _Xp % _Yp>::value;
};

template <intmax_t _Xp>
struct __static_gcd<_Xp, 0>
{
    static const intmax_t value = _Xp;
};

template <>
struct __static_gcd<0, 0>
{
    static const intmax_t value = 1;
};

// __static_lcm

template <intmax_t _Xp, intmax_t _Yp>
struct __static_lcm
{
    static const intmax_t value = _Xp / __static_gcd<_Xp, _Yp>::value * _Yp;
};

template <intmax_t _Xp>
struct __static_abs
{
    static const intmax_t value = _Xp < 0 ? -_Xp : _Xp;
};

template <intmax_t _Xp>
struct __static_sign
{
    static const intmax_t value = _Xp == 0 ? 0 : (_Xp < 0 ? -1 : 1);
};

template <intmax_t _Xp, intmax_t _Yp, intmax_t = __static_sign<_Yp>::value>
class __ll_add;

template <intmax_t _Xp, intmax_t _Yp>
class __ll_add<_Xp, _Yp, 1>
{
    static const intmax_t min = (1LL << (sizeof(intmax_t) * CHAR_BIT - 1)) + 1;
    static const intmax_t max = -min;

    static_assert(_Xp <= max - _Yp, "overflow in __ll_add");
public:
    static const intmax_t value = _Xp + _Yp;
};

template <intmax_t _Xp, intmax_t _Yp>
class __ll_add<_Xp, _Yp, 0>
{
public:
    static const intmax_t value = _Xp;
};

template <intmax_t _Xp, intmax_t _Yp>
class __ll_add<_Xp, _Yp, -1>
{
    static const intmax_t min = (1LL << (sizeof(intmax_t) * CHAR_BIT - 1)) + 1;
    static const intmax_t max = -min;

    static_assert(min - _Yp <= _Xp, "overflow in __ll_add");
public:
    static const intmax_t value = _Xp + _Yp;
};

template <intmax_t _Xp, intmax_t _Yp, intmax_t = __static_sign<_Yp>::value>
class __ll_sub;

template <intmax_t _Xp, intmax_t _Yp>
class __ll_sub<_Xp, _Yp, 1>
{
    static const intmax_t min = (1LL << (sizeof(intmax_t) * CHAR_BIT - 1)) + 1;
    static const intmax_t max = -min;

    static_assert(min + _Yp <= _Xp, "overflow in __ll_sub");
public:
    static const intmax_t value = _Xp - _Yp;
};

template <intmax_t _Xp, intmax_t _Yp>
class __ll_sub<_Xp, _Yp, 0>
{
public:
    static const intmax_t value = _Xp;
};

template <intmax_t _Xp, intmax_t _Yp>
class __ll_sub<_Xp, _Yp, -1>
{
    static const intmax_t min = (1LL << (sizeof(intmax_t) * CHAR_BIT - 1)) + 1;
    static const intmax_t max = -min;

    static_assert(_Xp <= max + _Yp, "overflow in __ll_sub");
public:
    static const intmax_t value = _Xp - _Yp;
};

template <intmax_t _Xp, intmax_t _Yp>
class __ll_mul
{
    static const intmax_t nan = (1LL << (sizeof(intmax_t) * CHAR_BIT - 1));
    static const intmax_t min = nan + 1;
    static const intmax_t max = -min;
    static const intmax_t __a_x = __static_abs<_Xp>::value;
    static const intmax_t __a_y = __static_abs<_Yp>::value;

    static_assert(_Xp != nan && _Yp != nan && __a_x <= max / __a_y, "overflow in __ll_mul");
public:
    static const intmax_t value = _Xp * _Yp;
};

template <intmax_t _Yp>
class __ll_mul<0, _Yp>
{
public:
    static const intmax_t value = 0;
};

template <intmax_t _Xp>
class __ll_mul<_Xp, 0>
{
public:
    static const intmax_t value = 0;
};

template <>
class __ll_mul<0, 0>
{
public:
    static const intmax_t value = 0;
};

// Not actually used but left here in case needed in future maintenance
template <intmax_t _Xp, intmax_t _Yp>
class __ll_div
{
    static const intmax_t nan = (1LL << (sizeof(intmax_t) * CHAR_BIT - 1));
    static const intmax_t min = nan + 1;
    static const intmax_t max = -min;

    static_assert(_Xp != nan && _Yp != nan && _Yp != 0, "overflow in __ll_div");
public:
    static const intmax_t value = _Xp / _Yp;
};

template <intmax_t _Num, intmax_t _Den = 1>
class _LIBCPP_TYPE_VIS_ONLY ratio
{
    static_assert(__static_abs<_Num>::value >= 0, "ratio numerator is out of range");
    static_assert(_Den != 0, "ratio divide by 0");
    static_assert(__static_abs<_Den>::value >  0, "ratio denominator is out of range");
    static const intmax_t __na = __static_abs<_Num>::value;
    static const intmax_t __da = __static_abs<_Den>::value;
    static const intmax_t __s = __static_sign<_Num>::value * __static_sign<_Den>::value;
    static const intmax_t __gcd = __static_gcd<__na, __da>::value;
public:
    static const intmax_t num = __s * __na / __gcd;
    static const intmax_t den = __da / __gcd;

    typedef ratio<num, den> type;
};

template <intmax_t _Num, intmax_t _Den> const intmax_t ratio<_Num, _Den>::num;
template <intmax_t _Num, intmax_t _Den> const intmax_t ratio<_Num, _Den>::den;

template <class _Tp>                    struct __is_ratio                     : false_type {};
template <intmax_t _Num, intmax_t _Den> struct __is_ratio<ratio<_Num, _Den> > : true_type  {};

typedef ratio<1LL, 1000000000000000000LL> atto;
typedef ratio<1LL,    1000000000000000LL> femto;
typedef ratio<1LL,       1000000000000LL> pico;
typedef ratio<1LL,          1000000000LL> nano;
typedef ratio<1LL,             1000000LL> micro;
typedef ratio<1LL,                1000LL> milli;
typedef ratio<1LL,                 100LL> centi;
typedef ratio<1LL,                  10LL> deci;
typedef ratio<                 10LL, 1LL> deca;
typedef ratio<                100LL, 1LL> hecto;
typedef ratio<               1000LL, 1LL> kilo;
typedef ratio<            1000000LL, 1LL> mega;
typedef ratio<         1000000000LL, 1LL> giga;
typedef ratio<      1000000000000LL, 1LL> tera;
typedef ratio<   1000000000000000LL, 1LL> peta;
typedef ratio<1000000000000000000LL, 1LL> exa;

template <class _R1, class _R2>
struct __ratio_multiply
{
private:
    static const intmax_t __gcd_n1_d2 = __static_gcd<_R1::num, _R2::den>::value;
    static const intmax_t __gcd_d1_n2 = __static_gcd<_R1::den, _R2::num>::value;
public:
    typedef typename ratio
        <
            __ll_mul<_R1::num / __gcd_n1_d2, _R2::num / __gcd_d1_n2>::value,
            __ll_mul<_R2::den / __gcd_n1_d2, _R1::den / __gcd_d1_n2>::value
        >::type type;
};

#ifndef _LIBCPP_HAS_NO_TEMPLATE_ALIASES

template <class _R1, class _R2> using ratio_multiply
                                    = typename __ratio_multiply<_R1, _R2>::type;

#else  // _LIBCPP_HAS_NO_TEMPLATE_ALIASES
# 293 "/usr/include/c++/v1/ratio" 3

template <class _R1, class _R2>
struct _LIBCPP_TYPE_VIS_ONLY ratio_multiply
    : public __ratio_multiply<_R1, _R2>::type {};

#endif  // _LIBCPP_HAS_NO_TEMPLATE_ALIASES
# 299 "/usr/include/c++/v1/ratio" 3

template <class _R1, class _R2>
struct __ratio_divide
{
private:
    static const intmax_t __gcd_n1_n2 = __static_gcd<_R1::num, _R2::num>::value;
    static const intmax_t __gcd_d1_d2 = __static_gcd<_R1::den, _R2::den>::value;
public:
    typedef typename ratio
        <
            __ll_mul<_R1::num / __gcd_n1_n2, _R2::den / __gcd_d1_d2>::value,
            __ll_mul<_R2::num / __gcd_n1_n2, _R1::den / __gcd_d1_d2>::value
        >::type type;
};

#ifndef _LIBCPP_HAS_NO_TEMPLATE_ALIASES

template <class _R1, class _R2> using ratio_divide
                                      = typename __ratio_divide<_R1, _R2>::type;

#else  // _LIBCPP_HAS_NO_TEMPLATE_ALIASES
# 320 "/usr/include/c++/v1/ratio" 3

template <class _R1, class _R2>
struct _LIBCPP_TYPE_VIS_ONLY ratio_divide
    : public __ratio_divide<_R1, _R2>::type {};

#endif  // _LIBCPP_HAS_NO_TEMPLATE_ALIASES
# 326 "/usr/include/c++/v1/ratio" 3

template <class _R1, class _R2>
struct __ratio_add
{
private:
    static const intmax_t __gcd_n1_n2 = __static_gcd<_R1::num, _R2::num>::value;
    static const intmax_t __gcd_d1_d2 = __static_gcd<_R1::den, _R2::den>::value;
public:
    typedef typename ratio_multiply
        <
            ratio<__gcd_n1_n2, _R1::den / __gcd_d1_d2>,
            ratio
            <
                __ll_add
                <
                    __ll_mul<_R1::num / __gcd_n1_n2, _R2::den / __gcd_d1_d2>::value,
                    __ll_mul<_R2::num / __gcd_n1_n2, _R1::den / __gcd_d1_d2>::value
                >::value,
                _R2::den
            >
        >::type type;
};

#ifndef _LIBCPP_HAS_NO_TEMPLATE_ALIASES

template <class _R1, class _R2> using ratio_add
                                         = typename __ratio_add<_R1, _R2>::type;

#else  // _LIBCPP_HAS_NO_TEMPLATE_ALIASES
# 355 "/usr/include/c++/v1/ratio" 3

template <class _R1, class _R2>
struct _LIBCPP_TYPE_VIS_ONLY ratio_add
    : public __ratio_add<_R1, _R2>::type {};

#endif  // _LIBCPP_HAS_NO_TEMPLATE_ALIASES
# 361 "/usr/include/c++/v1/ratio" 3

template <class _R1, class _R2>
struct __ratio_subtract
{
private:
    static const intmax_t __gcd_n1_n2 = __static_gcd<_R1::num, _R2::num>::value;
    static const intmax_t __gcd_d1_d2 = __static_gcd<_R1::den, _R2::den>::value;
public:
    typedef typename ratio_multiply
        <
            ratio<__gcd_n1_n2, _R1::den / __gcd_d1_d2>,
            ratio
            <
                __ll_sub
                <
                    __ll_mul<_R1::num / __gcd_n1_n2, _R2::den / __gcd_d1_d2>::value,
                    __ll_mul<_R2::num / __gcd_n1_n2, _R1::den / __gcd_d1_d2>::value
                >::value,
                _R2::den
            >
        >::type type;
};

#ifndef _LIBCPP_HAS_NO_TEMPLATE_ALIASES

template <class _R1, class _R2> using ratio_subtract
                                    = typename __ratio_subtract<_R1, _R2>::type;

#else  // _LIBCPP_HAS_NO_TEMPLATE_ALIASES
# 390 "/usr/include/c++/v1/ratio" 3

template <class _R1, class _R2>
struct _LIBCPP_TYPE_VIS_ONLY ratio_subtract
    : public __ratio_subtract<_R1, _R2>::type {};

#endif  // _LIBCPP_HAS_NO_TEMPLATE_ALIASES
# 396 "/usr/include/c++/v1/ratio" 3

// ratio_equal

template <class _R1, class _R2>
struct _LIBCPP_TYPE_VIS_ONLY ratio_equal
    : public integral_constant<bool, _R1::num == _R2::num && _R1::den == _R2::den> {};

template <class _R1, class _R2>
struct _LIBCPP_TYPE_VIS_ONLY ratio_not_equal
    : public integral_constant<bool, !ratio_equal<_R1, _R2>::value> {};

// ratio_less

template <class _R1, class _R2, bool _Odd = false,
          intmax_t _Q1 = _R1::num / _R1::den, intmax_t _M1 = _R1::num % _R1::den,
          intmax_t _Q2 = _R2::num / _R2::den, intmax_t _M2 = _R2::num % _R2::den>
struct __ratio_less1
{
    static const bool value = _Odd ? _Q2 < _Q1 : _Q1 < _Q2;
};

template <class _R1, class _R2, bool _Odd, intmax_t _Qp>
struct __ratio_less1<_R1, _R2, _Odd, _Qp, 0, _Qp, 0>
{
    static const bool value = false;
};

template <class _R1, class _R2, bool _Odd, intmax_t _Qp, intmax_t _M2>
struct __ratio_less1<_R1, _R2, _Odd, _Qp, 0, _Qp, _M2>
{
    static const bool value = !_Odd;
};

template <class _R1, class _R2, bool _Odd, intmax_t _Qp, intmax_t _M1>
struct __ratio_less1<_R1, _R2, _Odd, _Qp, _M1, _Qp, 0>
{
    static const bool value = _Odd;
};

template <class _R1, class _R2, bool _Odd, intmax_t _Qp, intmax_t _M1,
                                                        intmax_t _M2>
struct __ratio_less1<_R1, _R2, _Odd, _Qp, _M1, _Qp, _M2>
{
    static const bool value = __ratio_less1<ratio<_R1::den, _M1>,
                                            ratio<_R2::den, _M2>, !_Odd>::value;
};

template <class _R1, class _R2, intmax_t _S1 = __static_sign<_R1::num>::value,
                                intmax_t _S2 = __static_sign<_R2::num>::value>
struct __ratio_less
{
    static const bool value = _S1 < _S2;
};

template <class _R1, class _R2>
struct __ratio_less<_R1, _R2, 1LL, 1LL>
{
    static const bool value = __ratio_less1<_R1, _R2>::value;
};

template <class _R1, class _R2>
struct __ratio_less<_R1, _R2, -1LL, -1LL>
{
    static const bool value = __ratio_less1<ratio<-_R2::num, _R2::den>, ratio<-_R1::num, _R1::den> >::value;
};

template <class _R1, class _R2>
struct _LIBCPP_TYPE_VIS_ONLY ratio_less
    : public integral_constant<bool, __ratio_less<_R1, _R2>::value> {};

template <class _R1, class _R2>
struct _LIBCPP_TYPE_VIS_ONLY ratio_less_equal
    : public integral_constant<bool, !ratio_less<_R2, _R1>::value> {};

template <class _R1, class _R2>
struct _LIBCPP_TYPE_VIS_ONLY ratio_greater
    : public integral_constant<bool, ratio_less<_R2, _R1>::value> {};

template <class _R1, class _R2>
struct _LIBCPP_TYPE_VIS_ONLY ratio_greater_equal
    : public integral_constant<bool, !ratio_less<_R1, _R2>::value> {};

template <class _R1, class _R2>
struct __ratio_gcd
{
    typedef ratio<__static_gcd<_R1::num, _R2::num>::value,
                  __static_lcm<_R1::den, _R2::den>::value> type;
};

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_RATIO
# 488 "/usr/include/c++/v1/ratio" 3
# 282 "/usr/include/c++/v1/chrono" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <limits>
#endif /* expanded by -frewrite-includes */
# 283 "/usr/include/c++/v1/chrono" 3

#if 0 /* expanded by -frewrite-includes */
#include <__undef_min_max>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/__undef_min_max" 1 3
// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifdef min
#if defined(_MSC_VER) && ! defined(__clang__)
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 16 "/usr/include/c++/v1/__undef_min_max" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 18 "/usr/include/c++/v1/__undef_min_max" 3
#undef min
#endif
# 20 "/usr/include/c++/v1/__undef_min_max" 3

#ifdef max
#if defined(_MSC_VER) && ! defined(__clang__)
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 26 "/usr/include/c++/v1/__undef_min_max" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 28 "/usr/include/c++/v1/__undef_min_max" 3
#undef max
#endif
# 30 "/usr/include/c++/v1/__undef_min_max" 3
# 285 "/usr/include/c++/v1/chrono" 2 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 288 "/usr/include/c++/v1/chrono" 3
#endif
# 289 "/usr/include/c++/v1/chrono" 3

_LIBCPP_BEGIN_NAMESPACE_STD

namespace chrono
{

template <class _Rep, class _Period = ratio<1> > class _LIBCPP_TYPE_VIS_ONLY duration;

template <class _Tp>
struct __is_duration : false_type {};

template <class _Rep, class _Period>
struct __is_duration<duration<_Rep, _Period> > : true_type  {};

template <class _Rep, class _Period>
struct __is_duration<const duration<_Rep, _Period> > : true_type  {};

template <class _Rep, class _Period>
struct __is_duration<volatile duration<_Rep, _Period> > : true_type  {};

template <class _Rep, class _Period>
struct __is_duration<const volatile duration<_Rep, _Period> > : true_type  {};

} // chrono

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
struct _LIBCPP_TYPE_VIS_ONLY common_type<chrono::duration<_Rep1, _Period1>,
                                         chrono::duration<_Rep2, _Period2> >
{
    typedef chrono::duration<typename common_type<_Rep1, _Rep2>::type,
                             typename __ratio_gcd<_Period1, _Period2>::type> type;
};

namespace chrono {

// duration_cast

template <class _FromDuration, class _ToDuration,
          class _Period = typename ratio_divide<typename _FromDuration::period, typename _ToDuration::period>::type,
          bool = _Period::num == 1,
          bool = _Period::den == 1>
struct __duration_cast;

template <class _FromDuration, class _ToDuration, class _Period>
struct __duration_cast<_FromDuration, _ToDuration, _Period, true, true>
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    _ToDuration operator()(const _FromDuration& __fd) const
    {
        return _ToDuration(static_cast<typename _ToDuration::rep>(__fd.count()));
    }
};

template <class _FromDuration, class _ToDuration, class _Period>
struct __duration_cast<_FromDuration, _ToDuration, _Period, true, false>
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    _ToDuration operator()(const _FromDuration& __fd) const
    {
        typedef typename common_type<typename _ToDuration::rep, typename _FromDuration::rep, intmax_t>::type _Ct;
        return _ToDuration(static_cast<typename _ToDuration::rep>(
                           static_cast<_Ct>(__fd.count()) / static_cast<_Ct>(_Period::den)));
    }
};

template <class _FromDuration, class _ToDuration, class _Period>
struct __duration_cast<_FromDuration, _ToDuration, _Period, false, true>
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    _ToDuration operator()(const _FromDuration& __fd) const
    {
        typedef typename common_type<typename _ToDuration::rep, typename _FromDuration::rep, intmax_t>::type _Ct;
        return _ToDuration(static_cast<typename _ToDuration::rep>(
                           static_cast<_Ct>(__fd.count()) * static_cast<_Ct>(_Period::num)));
    }
};

template <class _FromDuration, class _ToDuration, class _Period>
struct __duration_cast<_FromDuration, _ToDuration, _Period, false, false>
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    _ToDuration operator()(const _FromDuration& __fd) const
    {
        typedef typename common_type<typename _ToDuration::rep, typename _FromDuration::rep, intmax_t>::type _Ct;
        return _ToDuration(static_cast<typename _ToDuration::rep>(
                           static_cast<_Ct>(__fd.count()) * static_cast<_Ct>(_Period::num)
                                                          / static_cast<_Ct>(_Period::den)));
    }
};

template <class _ToDuration, class _Rep, class _Period>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
typename enable_if
<
    __is_duration<_ToDuration>::value,
    _ToDuration
>::type
duration_cast(const duration<_Rep, _Period>& __fd)
{
    return __duration_cast<duration<_Rep, _Period>, _ToDuration>()(__fd);
}

template <class _Rep>
struct _LIBCPP_TYPE_VIS_ONLY treat_as_floating_point : is_floating_point<_Rep> {};

template <class _Rep>
struct _LIBCPP_TYPE_VIS_ONLY duration_values
{
public:
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR _Rep zero() {return _Rep(0);}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR _Rep max()  {return numeric_limits<_Rep>::max();}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR _Rep min()  {return numeric_limits<_Rep>::lowest();}
};

// duration

template <class _Rep, class _Period>
class _LIBCPP_TYPE_VIS_ONLY duration
{
    static_assert(!__is_duration<_Rep>::value, "A duration representation can not be a duration");
    static_assert(__is_ratio<_Period>::value, "Second template parameter of duration must be a std::ratio");
    static_assert(_Period::num > 0, "duration period must be positive");

    template <class _R1, class _R2>
    struct __no_overflow
    {
    private:
        static const intmax_t __gcd_n1_n2 = __static_gcd<_R1::num, _R2::num>::value;
        static const intmax_t __gcd_d1_d2 = __static_gcd<_R1::den, _R2::den>::value;
        static const intmax_t __n1 = _R1::num / __gcd_n1_n2;
        static const intmax_t __d1 = _R1::den / __gcd_d1_d2;
        static const intmax_t __n2 = _R2::num / __gcd_n1_n2;
        static const intmax_t __d2 = _R2::den / __gcd_d1_d2;
        static const intmax_t max = -((intmax_t(1) << (sizeof(intmax_t) * CHAR_BIT - 1)) + 1);

        template <intmax_t _Xp, intmax_t _Yp, bool __overflow>
        struct __mul    // __overflow == false
        {
            static const intmax_t value = _Xp * _Yp;
        };

        template <intmax_t _Xp, intmax_t _Yp>
        struct __mul<_Xp, _Yp, true>
        {
            static const intmax_t value = 1;
        };

    public:
        static const bool value = (__n1 <= max / __d2) && (__n2 <= max / __d1);
        typedef ratio<__mul<__n1, __d2, !value>::value,
                      __mul<__n2, __d1, !value>::value> type;
    };
    
public:
    typedef _Rep rep;
    typedef _Period period;
private:
    rep __rep_;
public:

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
#ifndef _LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS
        duration() = default;
#else
# 454 "/usr/include/c++/v1/chrono" 3
        duration() {}
#endif
# 456 "/usr/include/c++/v1/chrono" 3

    template <class _Rep2>
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
        explicit duration(const _Rep2& __r,
            typename enable_if
            <
               is_convertible<_Rep2, rep>::value &&
               (treat_as_floating_point<rep>::value ||
               !treat_as_floating_point<_Rep2>::value)
            >::type* = 0)
                : __rep_(__r) {}

    // conversions
    template <class _Rep2, class _Period2>
        _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
        duration(const duration<_Rep2, _Period2>& __d,
            typename enable_if
            <
                __no_overflow<_Period2, period>::value && (
                treat_as_floating_point<rep>::value ||
                (__no_overflow<_Period2, period>::type::den == 1 &&
                 !treat_as_floating_point<_Rep2>::value))
            >::type* = 0)
                : __rep_(_VSTD::chrono::duration_cast<duration>(__d).count()) {}

    // observer

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR rep count() const {return __rep_;}

    // arithmetic

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR duration  operator+() const {return *this;}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR duration  operator-() const {return duration(-__rep_);}
    _LIBCPP_INLINE_VISIBILITY duration& operator++()      {++__rep_; return *this;}
    _LIBCPP_INLINE_VISIBILITY duration  operator++(int)   {return duration(__rep_++);}
    _LIBCPP_INLINE_VISIBILITY duration& operator--()      {--__rep_; return *this;}
    _LIBCPP_INLINE_VISIBILITY duration  operator--(int)   {return duration(__rep_--);}

    _LIBCPP_INLINE_VISIBILITY duration& operator+=(const duration& __d) {__rep_ += __d.count(); return *this;}
    _LIBCPP_INLINE_VISIBILITY duration& operator-=(const duration& __d) {__rep_ -= __d.count(); return *this;}

    _LIBCPP_INLINE_VISIBILITY duration& operator*=(const rep& rhs) {__rep_ *= rhs; return *this;}
    _LIBCPP_INLINE_VISIBILITY duration& operator/=(const rep& rhs) {__rep_ /= rhs; return *this;}
    _LIBCPP_INLINE_VISIBILITY duration& operator%=(const rep& rhs) {__rep_ %= rhs; return *this;}
    _LIBCPP_INLINE_VISIBILITY duration& operator%=(const duration& rhs) {__rep_ %= rhs.count(); return *this;}

    // special values

    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR duration zero() {return duration(duration_values<rep>::zero());}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR duration min()  {return duration(duration_values<rep>::min());}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR duration max()  {return duration(duration_values<rep>::max());}
};

typedef duration<long long,         nano> nanoseconds;
typedef duration<long long,        micro> microseconds;
typedef duration<long long,        milli> milliseconds;
typedef duration<long long              > seconds;
typedef duration<     long, ratio<  60> > minutes;
typedef duration<     long, ratio<3600> > hours;

// Duration ==

template <class _LhsDuration, class _RhsDuration>
struct __duration_eq
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    bool operator()(const _LhsDuration& __lhs, const _RhsDuration& __rhs) const
        {
            typedef typename common_type<_LhsDuration, _RhsDuration>::type _Ct;
            return _Ct(__lhs).count() == _Ct(__rhs).count();
        }
};

template <class _LhsDuration>
struct __duration_eq<_LhsDuration, _LhsDuration>
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    bool operator()(const _LhsDuration& __lhs, const _LhsDuration& __rhs) const
        {return __lhs.count() == __rhs.count();}
};

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
bool
operator==(const duration<_Rep1, _Period1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    return __duration_eq<duration<_Rep1, _Period1>, duration<_Rep2, _Period2> >()(__lhs, __rhs);
}

// Duration !=

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
bool
operator!=(const duration<_Rep1, _Period1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    return !(__lhs == __rhs);
}

// Duration <

template <class _LhsDuration, class _RhsDuration>
struct __duration_lt
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    bool operator()(const _LhsDuration& __lhs, const _RhsDuration& __rhs) const
        {
            typedef typename common_type<_LhsDuration, _RhsDuration>::type _Ct;
            return _Ct(__lhs).count() < _Ct(__rhs).count();
        }
};

template <class _LhsDuration>
struct __duration_lt<_LhsDuration, _LhsDuration>
{
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR
    bool operator()(const _LhsDuration& __lhs, const _LhsDuration& __rhs) const
        {return __lhs.count() < __rhs.count();}
};

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
bool
operator< (const duration<_Rep1, _Period1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    return __duration_lt<duration<_Rep1, _Period1>, duration<_Rep2, _Period2> >()(__lhs, __rhs);
}

// Duration >

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
bool
operator> (const duration<_Rep1, _Period1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    return __rhs < __lhs;
}

// Duration <=

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
bool
operator<=(const duration<_Rep1, _Period1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    return !(__rhs < __lhs);
}

// Duration >=

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
bool
operator>=(const duration<_Rep1, _Period1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    return !(__lhs < __rhs);
}

// Duration +

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
typename common_type<duration<_Rep1, _Period1>, duration<_Rep2, _Period2> >::type
operator+(const duration<_Rep1, _Period1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    typedef typename common_type<duration<_Rep1, _Period1>, duration<_Rep2, _Period2> >::type _Cd;
    return _Cd(_Cd(__lhs).count() + _Cd(__rhs).count());
}

// Duration -

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
typename common_type<duration<_Rep1, _Period1>, duration<_Rep2, _Period2> >::type
operator-(const duration<_Rep1, _Period1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    typedef typename common_type<duration<_Rep1, _Period1>, duration<_Rep2, _Period2> >::type _Cd;
    return _Cd(_Cd(__lhs).count() - _Cd(__rhs).count());
}

// Duration *

template <class _Rep1, class _Period, class _Rep2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
typename enable_if
<
    is_convertible<_Rep2, typename common_type<_Rep1, _Rep2>::type>::value,
    duration<typename common_type<_Rep1, _Rep2>::type, _Period>
>::type
operator*(const duration<_Rep1, _Period>& __d, const _Rep2& __s)
{
    typedef typename common_type<_Rep1, _Rep2>::type _Cr;
    typedef duration<_Cr, _Period> _Cd;
    return _Cd(_Cd(__d).count() * static_cast<_Cr>(__s));
}

template <class _Rep1, class _Period, class _Rep2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
typename enable_if
<
    is_convertible<_Rep1, typename common_type<_Rep1, _Rep2>::type>::value,
    duration<typename common_type<_Rep1, _Rep2>::type, _Period>
>::type
operator*(const _Rep1& __s, const duration<_Rep2, _Period>& __d)
{
    return __d * __s;
}

// Duration /

template <class _Duration, class _Rep, bool = __is_duration<_Rep>::value>
struct __duration_divide_result
{
};

template <class _Duration, class _Rep2,
    bool = is_convertible<_Rep2,
                          typename common_type<typename _Duration::rep, _Rep2>::type>::value>
struct __duration_divide_imp
{
};

template <class _Rep1, class _Period, class _Rep2>
struct __duration_divide_imp<duration<_Rep1, _Period>, _Rep2, true>
{
    typedef duration<typename common_type<_Rep1, _Rep2>::type, _Period> type;
};

template <class _Rep1, class _Period, class _Rep2>
struct __duration_divide_result<duration<_Rep1, _Period>, _Rep2, false>
    : __duration_divide_imp<duration<_Rep1, _Period>, _Rep2>
{
};

template <class _Rep1, class _Period, class _Rep2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
typename __duration_divide_result<duration<_Rep1, _Period>, _Rep2>::type
operator/(const duration<_Rep1, _Period>& __d, const _Rep2& __s)
{
    typedef typename common_type<_Rep1, _Rep2>::type _Cr;
    typedef duration<_Cr, _Period> _Cd;
    return _Cd(_Cd(__d).count() / static_cast<_Cr>(__s));
}

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
typename common_type<_Rep1, _Rep2>::type
operator/(const duration<_Rep1, _Period1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    typedef typename common_type<duration<_Rep1, _Period1>, duration<_Rep2, _Period2> >::type _Ct;
    return _Ct(__lhs).count() / _Ct(__rhs).count();
}

// Duration %

template <class _Rep1, class _Period, class _Rep2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
typename __duration_divide_result<duration<_Rep1, _Period>, _Rep2>::type
operator%(const duration<_Rep1, _Period>& __d, const _Rep2& __s)
{
    typedef typename common_type<_Rep1, _Rep2>::type _Cr;
    typedef duration<_Cr, _Period> _Cd;
    return _Cd(_Cd(__d).count() % static_cast<_Cr>(__s));
}

template <class _Rep1, class _Period1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY
_LIBCPP_CONSTEXPR
typename common_type<duration<_Rep1, _Period1>, duration<_Rep2, _Period2> >::type
operator%(const duration<_Rep1, _Period1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    typedef typename common_type<_Rep1, _Rep2>::type _Cr;
    typedef typename common_type<duration<_Rep1, _Period1>, duration<_Rep2, _Period2> >::type _Cd;
    return _Cd(static_cast<_Cr>(_Cd(__lhs).count()) % static_cast<_Cr>(_Cd(__rhs).count()));
}

//////////////////////////////////////////////////////////
///////////////////// time_point /////////////////////////
//////////////////////////////////////////////////////////

template <class _Clock, class _Duration = typename _Clock::duration>
class _LIBCPP_TYPE_VIS_ONLY time_point
{
    static_assert(__is_duration<_Duration>::value,
                  "Second template parameter of time_point must be a std::chrono::duration");
public:
    typedef _Clock                    clock;
    typedef _Duration                 duration;
    typedef typename duration::rep    rep;
    typedef typename duration::period period;
private:
    duration __d_;

public:
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11 time_point() : __d_(duration::zero()) {}
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11 explicit time_point(const duration& __d) : __d_(__d) {}

    // conversions
    template <class _Duration2>
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
    time_point(const time_point<clock, _Duration2>& t,
        typename enable_if
        <
            is_convertible<_Duration2, duration>::value
        >::type* = 0)
            : __d_(t.time_since_epoch()) {}

    // observer

    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11 duration time_since_epoch() const {return __d_;}

    // arithmetic

    _LIBCPP_INLINE_VISIBILITY time_point& operator+=(const duration& __d) {__d_ += __d; return *this;}
    _LIBCPP_INLINE_VISIBILITY time_point& operator-=(const duration& __d) {__d_ -= __d; return *this;}

    // special values

    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR time_point min() {return time_point(duration::min());}
    _LIBCPP_INLINE_VISIBILITY static _LIBCPP_CONSTEXPR time_point max() {return time_point(duration::max());}
};

} // chrono

template <class _Clock, class _Duration1, class _Duration2>
struct _LIBCPP_TYPE_VIS_ONLY common_type<chrono::time_point<_Clock, _Duration1>,
                                         chrono::time_point<_Clock, _Duration2> >
{
    typedef chrono::time_point<_Clock, typename common_type<_Duration1, _Duration2>::type> type;
};

namespace chrono {

template <class _ToDuration, class _Clock, class _Duration>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
time_point<_Clock, _ToDuration>
time_point_cast(const time_point<_Clock, _Duration>& __t)
{
    return time_point<_Clock, _ToDuration>(_VSTD::chrono::duration_cast<_ToDuration>(__t.time_since_epoch()));
}

// time_point ==

template <class _Clock, class _Duration1, class _Duration2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator==(const time_point<_Clock, _Duration1>& __lhs, const time_point<_Clock, _Duration2>& __rhs)
{
    return __lhs.time_since_epoch() == __rhs.time_since_epoch();
}

// time_point !=

template <class _Clock, class _Duration1, class _Duration2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator!=(const time_point<_Clock, _Duration1>& __lhs, const time_point<_Clock, _Duration2>& __rhs)
{
    return !(__lhs == __rhs);
}

// time_point <

template <class _Clock, class _Duration1, class _Duration2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator<(const time_point<_Clock, _Duration1>& __lhs, const time_point<_Clock, _Duration2>& __rhs)
{
    return __lhs.time_since_epoch() < __rhs.time_since_epoch();
}

// time_point >

template <class _Clock, class _Duration1, class _Duration2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator>(const time_point<_Clock, _Duration1>& __lhs, const time_point<_Clock, _Duration2>& __rhs)
{
    return __rhs < __lhs;
}

// time_point <=

template <class _Clock, class _Duration1, class _Duration2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator<=(const time_point<_Clock, _Duration1>& __lhs, const time_point<_Clock, _Duration2>& __rhs)
{
    return !(__rhs < __lhs);
}

// time_point >=

template <class _Clock, class _Duration1, class _Duration2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
bool
operator>=(const time_point<_Clock, _Duration1>& __lhs, const time_point<_Clock, _Duration2>& __rhs)
{
    return !(__lhs < __rhs);
}

// time_point operator+(time_point x, duration y);

template <class _Clock, class _Duration1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
time_point<_Clock, typename common_type<_Duration1, duration<_Rep2, _Period2> >::type>
operator+(const time_point<_Clock, _Duration1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    typedef time_point<_Clock, typename common_type<_Duration1, duration<_Rep2, _Period2> >::type> _Tr;
    return _Tr (__lhs.time_since_epoch() + __rhs);
}

// time_point operator+(duration x, time_point y);

template <class _Rep1, class _Period1, class _Clock, class _Duration2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
time_point<_Clock, typename common_type<duration<_Rep1, _Period1>, _Duration2>::type>
operator+(const duration<_Rep1, _Period1>& __lhs, const time_point<_Clock, _Duration2>& __rhs)
{
    return __rhs + __lhs;
}

// time_point operator-(time_point x, duration y);

template <class _Clock, class _Duration1, class _Rep2, class _Period2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
time_point<_Clock, typename common_type<_Duration1, duration<_Rep2, _Period2> >::type>
operator-(const time_point<_Clock, _Duration1>& __lhs, const duration<_Rep2, _Period2>& __rhs)
{
    return __lhs + (-__rhs);
}

// duration operator-(time_point x, time_point y);

template <class _Clock, class _Duration1, class _Duration2>
inline _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR_AFTER_CXX11
typename common_type<_Duration1, _Duration2>::type
operator-(const time_point<_Clock, _Duration1>& __lhs, const time_point<_Clock, _Duration2>& __rhs)
{
    return __lhs.time_since_epoch() - __rhs.time_since_epoch();
}

//////////////////////////////////////////////////////////
/////////////////////// clocks ///////////////////////////
//////////////////////////////////////////////////////////

class _LIBCPP_TYPE_VIS system_clock
{
public:
    typedef microseconds                     duration;
    typedef duration::rep                    rep;
    typedef duration::period                 period;
    typedef chrono::time_point<system_clock> time_point;
    static _LIBCPP_CONSTEXPR_AFTER_CXX11 const bool is_steady = false;

    static time_point now() _NOEXCEPT;
    static time_t     to_time_t  (const time_point& __t) _NOEXCEPT;
    static time_point from_time_t(time_t __t) _NOEXCEPT;
};

class _LIBCPP_TYPE_VIS steady_clock
{
public:
    typedef nanoseconds                                   duration;
    typedef duration::rep                                 rep;
    typedef duration::period                              period;
    typedef chrono::time_point<steady_clock, duration>    time_point;
    static _LIBCPP_CONSTEXPR_AFTER_CXX11 const bool is_steady = true;

    static time_point now() _NOEXCEPT;
};

typedef steady_clock high_resolution_clock;

} // chrono

#if _LIBCPP_STD_VER > 11
// Suffixes for duration literals [time.duration.literals]
inline namespace literals
{ 
  inline namespace chrono_literals
  {

    constexpr chrono::hours operator"" h(unsigned long long __h)
    {
        return chrono::hours(static_cast<chrono::hours::rep>(__h));
    }

    constexpr chrono::duration<long double, ratio<3600,1>> operator"" h(long double __h)
    {
        return chrono::duration<long double, ratio<3600,1>>(__h);
    }


    constexpr chrono::minutes operator"" min(unsigned long long __m)
    {
        return chrono::minutes(static_cast<chrono::minutes::rep>(__m));
    }

    constexpr chrono::duration<long double, ratio<60,1>> operator"" min(long double __m)
    {
        return chrono::duration<long double, ratio<60,1>> (__m);
    }


    constexpr chrono::seconds operator"" s(unsigned long long __s)
    {
        return chrono::seconds(static_cast<chrono::seconds::rep>(__s));
    }

    constexpr chrono::duration<long double> operator"" s(long double __s)
    {
        return chrono::duration<long double> (__s);
    }


    constexpr chrono::milliseconds operator"" ms(unsigned long long __ms)
    {
        return chrono::milliseconds(static_cast<chrono::milliseconds::rep>(__ms));
    }

    constexpr chrono::duration<long double, milli> operator"" ms(long double __ms)
    {
        return chrono::duration<long double, milli>(__ms);
    }


    constexpr chrono::microseconds operator"" us(unsigned long long __us)
    {
        return chrono::microseconds(static_cast<chrono::microseconds::rep>(__us));
    }

    constexpr chrono::duration<long double, micro> operator"" us(long double __us)
    {
        return chrono::duration<long double, micro> (__us);
    }
    

    constexpr chrono::nanoseconds operator"" ns(unsigned long long __ns)
    {
        return chrono::nanoseconds(static_cast<chrono::nanoseconds::rep>(__ns));
    }

    constexpr chrono::duration<long double, nano> operator"" ns(long double __ns)
    {
        return chrono::duration<long double, nano> (__ns);
    }

}}

namespace chrono { // hoist the literals into namespace std::chrono
   using namespace literals::chrono_literals;
}

#endif
# 1024 "/usr/include/c++/v1/chrono" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_CHRONO
# 1028 "/usr/include/c++/v1/chrono" 3
# 16 "/usr/include/c++/v1/__mutex_base" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <system_error>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/system_error" 1 3
// -*- C++ -*-
//===---------------------------- system_error ----------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_SYSTEM_ERROR
#define _LIBCPP_SYSTEM_ERROR

/*
    system_error synopsis

namespace std
{

class error_category
{
public:
    virtual ~error_category() noexcept;

    constexpr error_category();
    error_category(const error_category&) = delete;
    error_category& operator=(const error_category&) = delete;

    virtual const char* name() const noexcept = 0;
    virtual error_condition default_error_condition(int ev) const noexcept;
    virtual bool equivalent(int code, const error_condition& condition) const noexcept;
    virtual bool equivalent(const error_code& code, int condition) const noexcept;
    virtual string message(int ev) const = 0;

    bool operator==(const error_category& rhs) const noexcept;
    bool operator!=(const error_category& rhs) const noexcept;
    bool operator<(const error_category& rhs) const noexcept;
};

const error_category& generic_category() noexcept;
const error_category& system_category() noexcept;

template <class T> struct is_error_code_enum
    : public false_type {};

template <class T> struct is_error_condition_enum
    : public false_type {};

class error_code
{
public:
    // constructors:
    error_code() noexcept;
    error_code(int val, const error_category& cat) noexcept;
    template <class ErrorCodeEnum>
        error_code(ErrorCodeEnum e) noexcept;

    // modifiers:
    void assign(int val, const error_category& cat) noexcept;
    template <class ErrorCodeEnum>
        error_code& operator=(ErrorCodeEnum e) noexcept;
    void clear() noexcept;

    // observers:
    int value() const noexcept;
    const error_category& category() const noexcept;
    error_condition default_error_condition() const noexcept;
    string message() const;
    explicit operator bool() const noexcept;
};

// non-member functions:
bool operator<(const error_code& lhs, const error_code& rhs) noexcept;
template <class charT, class traits>
    basic_ostream<charT,traits>&
    operator<<(basic_ostream<charT,traits>& os, const error_code& ec);

class error_condition
{
public:
    // constructors:
    error_condition() noexcept;
    error_condition(int val, const error_category& cat) noexcept;
    template <class ErrorConditionEnum>
        error_condition(ErrorConditionEnum e) noexcept;

    // modifiers:
    void assign(int val, const error_category& cat) noexcept;
    template <class ErrorConditionEnum>
        error_condition& operator=(ErrorConditionEnum e) noexcept;
    void clear() noexcept;

    // observers:
    int value() const noexcept;
    const error_category& category() const noexcept;
    string message() const noexcept;
    explicit operator bool() const noexcept;
};

bool operator<(const error_condition& lhs, const error_condition& rhs) noexcept;

class system_error
    : public runtime_error
{
public:
    system_error(error_code ec, const string& what_arg);
    system_error(error_code ec, const char* what_arg);
    system_error(error_code ec);
    system_error(int ev, const error_category& ecat, const string& what_arg);
    system_error(int ev, const error_category& ecat, const char* what_arg);
    system_error(int ev, const error_category& ecat);

    const error_code& code() const noexcept;
    const char* what() const noexcept;
};

enum class errc
{
    address_family_not_supported,       // EAFNOSUPPORT
    address_in_use,                     // EADDRINUSE
    address_not_available,              // EADDRNOTAVAIL
    already_connected,                  // EISCONN
    argument_list_too_long,             // E2BIG
    argument_out_of_domain,             // EDOM
    bad_address,                        // EFAULT
    bad_file_descriptor,                // EBADF
    bad_message,                        // EBADMSG
    broken_pipe,                        // EPIPE
    connection_aborted,                 // ECONNABORTED
    connection_already_in_progress,     // EALREADY
    connection_refused,                 // ECONNREFUSED
    connection_reset,                   // ECONNRESET
    cross_device_link,                  // EXDEV
    destination_address_required,       // EDESTADDRREQ
    device_or_resource_busy,            // EBUSY
    directory_not_empty,                // ENOTEMPTY
    executable_format_error,            // ENOEXEC
    file_exists,                        // EEXIST
    file_too_large,                     // EFBIG
    filename_too_long,                  // ENAMETOOLONG
    function_not_supported,             // ENOSYS
    host_unreachable,                   // EHOSTUNREACH
    identifier_removed,                 // EIDRM
    illegal_byte_sequence,              // EILSEQ
    inappropriate_io_control_operation, // ENOTTY
    interrupted,                        // EINTR
    invalid_argument,                   // EINVAL
    invalid_seek,                       // ESPIPE
    io_error,                           // EIO
    is_a_directory,                     // EISDIR
    message_size,                       // EMSGSIZE
    network_down,                       // ENETDOWN
    network_reset,                      // ENETRESET
    network_unreachable,                // ENETUNREACH
    no_buffer_space,                    // ENOBUFS
    no_child_process,                   // ECHILD
    no_link,                            // ENOLINK
    no_lock_available,                  // ENOLCK
    no_message_available,               // ENODATA
    no_message,                         // ENOMSG
    no_protocol_option,                 // ENOPROTOOPT
    no_space_on_device,                 // ENOSPC
    no_stream_resources,                // ENOSR
    no_such_device_or_address,          // ENXIO
    no_such_device,                     // ENODEV
    no_such_file_or_directory,          // ENOENT
    no_such_process,                    // ESRCH
    not_a_directory,                    // ENOTDIR
    not_a_socket,                       // ENOTSOCK
    not_a_stream,                       // ENOSTR
    not_connected,                      // ENOTCONN
    not_enough_memory,                  // ENOMEM
    not_supported,                      // ENOTSUP
    operation_canceled,                 // ECANCELED
    operation_in_progress,              // EINPROGRESS
    operation_not_permitted,            // EPERM
    operation_not_supported,            // EOPNOTSUPP
    operation_would_block,              // EWOULDBLOCK
    owner_dead,                         // EOWNERDEAD
    permission_denied,                  // EACCES
    protocol_error,                     // EPROTO
    protocol_not_supported,             // EPROTONOSUPPORT
    read_only_file_system,              // EROFS
    resource_deadlock_would_occur,      // EDEADLK
    resource_unavailable_try_again,     // EAGAIN
    result_out_of_range,                // ERANGE
    state_not_recoverable,              // ENOTRECOVERABLE
    stream_timeout,                     // ETIME
    text_file_busy,                     // ETXTBSY
    timed_out,                          // ETIMEDOUT
    too_many_files_open_in_system,      // ENFILE
    too_many_files_open,                // EMFILE
    too_many_links,                     // EMLINK
    too_many_symbolic_link_levels,      // ELOOP
    value_too_large,                    // EOVERFLOW
    wrong_protocol_type                 // EPROTOTYPE
};

template <> struct is_error_condition_enum<errc>
    : true_type { }

error_code make_error_code(errc e) noexcept;
error_condition make_error_condition(errc e) noexcept;

// Comparison operators:
bool operator==(const error_code& lhs, const error_code& rhs) noexcept;
bool operator==(const error_code& lhs, const error_condition& rhs) noexcept;
bool operator==(const error_condition& lhs, const error_code& rhs) noexcept;
bool operator==(const error_condition& lhs, const error_condition& rhs) noexcept;
bool operator!=(const error_code& lhs, const error_code& rhs) noexcept;
bool operator!=(const error_code& lhs, const error_condition& rhs) noexcept;
bool operator!=(const error_condition& lhs, const error_code& rhs) noexcept;
bool operator!=(const error_condition& lhs, const error_condition& rhs) noexcept;

template <> struct hash<std::error_code>;

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 222 "/usr/include/c++/v1/system_error" 3
#if 0 /* expanded by -frewrite-includes */
#include <cerrno>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/cerrno" 1 3
// -*- C++ -*-
//===-------------------------- cerrno ------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CERRNO
#define _LIBCPP_CERRNO

/*
    cerrno synopsis

Macros:

    EDOM
    EILSEQ  // C99
    ERANGE
    errno

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 27 "/usr/include/c++/v1/cerrno" 3
#if 0 /* expanded by -frewrite-includes */
#include <errno.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/errno.h" 1 3 4
/*-
 * Copyright (c) 1982, 1986, 1989, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)errno.h	8.5 (Berkeley) 1/21/94
 * $FreeBSD: head/sys/sys/errno.h 250250 2013-05-04 19:07:22Z pluknet $
 */

#ifndef _SYS_ERRNO_H_
#define _SYS_ERRNO_H_

#ifndef _KERNEL
#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 43 "/usr/include/errno.h" 3 4
__BEGIN_DECLS
int *	__error(void);
__END_DECLS
#define	errno		(* __error())
#endif
# 48 "/usr/include/errno.h" 3 4

#define	EPERM		1		/* Operation not permitted */
#define	ENOENT		2		/* No such file or directory */
#define	ESRCH		3		/* No such process */
#define	EINTR		4		/* Interrupted system call */
#define	EIO		5		/* Input/output error */
#define	ENXIO		6		/* Device not configured */
#define	E2BIG		7		/* Argument list too long */
#define	ENOEXEC		8		/* Exec format error */
#define	EBADF		9		/* Bad file descriptor */
#define	ECHILD		10		/* No child processes */
#define	EDEADLK		11		/* Resource deadlock avoided */
					/* 11 was EAGAIN */
#define	ENOMEM		12		/* Cannot allocate memory */
#define	EACCES		13		/* Permission denied */
#define	EFAULT		14		/* Bad address */
#ifndef _POSIX_SOURCE
#define	ENOTBLK		15		/* Block device required */
#endif
# 67 "/usr/include/errno.h" 3 4
#define	EBUSY		16		/* Device busy */
#define	EEXIST		17		/* File exists */
#define	EXDEV		18		/* Cross-device link */
#define	ENODEV		19		/* Operation not supported by device */
#define	ENOTDIR		20		/* Not a directory */
#define	EISDIR		21		/* Is a directory */
#define	EINVAL		22		/* Invalid argument */
#define	ENFILE		23		/* Too many open files in system */
#define	EMFILE		24		/* Too many open files */
#define	ENOTTY		25		/* Inappropriate ioctl for device */
#ifndef _POSIX_SOURCE
#define	ETXTBSY		26		/* Text file busy */
#endif
# 80 "/usr/include/errno.h" 3 4
#define	EFBIG		27		/* File too large */
#define	ENOSPC		28		/* No space left on device */
#define	ESPIPE		29		/* Illegal seek */
#define	EROFS		30		/* Read-only filesystem */
#define	EMLINK		31		/* Too many links */
#define	EPIPE		32		/* Broken pipe */

/* math software */
#define	EDOM		33		/* Numerical argument out of domain */
#define	ERANGE		34		/* Result too large */

/* non-blocking and interrupt i/o */
#define	EAGAIN		35		/* Resource temporarily unavailable */
#ifndef _POSIX_SOURCE
#define	EWOULDBLOCK	EAGAIN		/* Operation would block */
#define	EINPROGRESS	36		/* Operation now in progress */
#define	EALREADY	37		/* Operation already in progress */

/* ipc/network software -- argument errors */
#define	ENOTSOCK	38		/* Socket operation on non-socket */
#define	EDESTADDRREQ	39		/* Destination address required */
#define	EMSGSIZE	40		/* Message too long */
#define	EPROTOTYPE	41		/* Protocol wrong type for socket */
#define	ENOPROTOOPT	42		/* Protocol not available */
#define	EPROTONOSUPPORT	43		/* Protocol not supported */
#define	ESOCKTNOSUPPORT	44		/* Socket type not supported */
#define	EOPNOTSUPP	45		/* Operation not supported */
#define	ENOTSUP		EOPNOTSUPP	/* Operation not supported */
#define	EPFNOSUPPORT	46		/* Protocol family not supported */
#define	EAFNOSUPPORT	47		/* Address family not supported by protocol family */
#define	EADDRINUSE	48		/* Address already in use */
#define	EADDRNOTAVAIL	49		/* Can't assign requested address */

/* ipc/network software -- operational errors */
#define	ENETDOWN	50		/* Network is down */
#define	ENETUNREACH	51		/* Network is unreachable */
#define	ENETRESET	52		/* Network dropped connection on reset */
#define	ECONNABORTED	53		/* Software caused connection abort */
#define	ECONNRESET	54		/* Connection reset by peer */
#define	ENOBUFS		55		/* No buffer space available */
#define	EISCONN		56		/* Socket is already connected */
#define	ENOTCONN	57		/* Socket is not connected */
#define	ESHUTDOWN	58		/* Can't send after socket shutdown */
#define	ETOOMANYREFS	59		/* Too many references: can't splice */
#define	ETIMEDOUT	60		/* Operation timed out */
#define	ECONNREFUSED	61		/* Connection refused */

#define	ELOOP		62		/* Too many levels of symbolic links */
#endif /* _POSIX_SOURCE */
# 129 "/usr/include/errno.h" 3 4
#define	ENAMETOOLONG	63		/* File name too long */

/* should be rearranged */
#ifndef _POSIX_SOURCE
#define	EHOSTDOWN	64		/* Host is down */
#define	EHOSTUNREACH	65		/* No route to host */
#endif /* _POSIX_SOURCE */
# 136 "/usr/include/errno.h" 3 4
#define	ENOTEMPTY	66		/* Directory not empty */

/* quotas & mush */
#ifndef _POSIX_SOURCE
#define	EPROCLIM	67		/* Too many processes */
#define	EUSERS		68		/* Too many users */
#define	EDQUOT		69		/* Disc quota exceeded */

/* Network File System */
#define	ESTALE		70		/* Stale NFS file handle */
#define	EREMOTE		71		/* Too many levels of remote in path */
#define	EBADRPC		72		/* RPC struct is bad */
#define	ERPCMISMATCH	73		/* RPC version wrong */
#define	EPROGUNAVAIL	74		/* RPC prog. not avail */
#define	EPROGMISMATCH	75		/* Program version wrong */
#define	EPROCUNAVAIL	76		/* Bad procedure for program */
#endif /* _POSIX_SOURCE */
# 153 "/usr/include/errno.h" 3 4

#define	ENOLCK		77		/* No locks available */
#define	ENOSYS		78		/* Function not implemented */

#ifndef _POSIX_SOURCE
#define	EFTYPE		79		/* Inappropriate file type or format */
#define	EAUTH		80		/* Authentication error */
#define	ENEEDAUTH	81		/* Need authenticator */
#define	EIDRM		82		/* Identifier removed */
#define	ENOMSG		83		/* No message of desired type */
#define	EOVERFLOW	84		/* Value too large to be stored in data type */
#define	ECANCELED	85		/* Operation canceled */
#define	EILSEQ		86		/* Illegal byte sequence */
#define	ENOATTR		87		/* Attribute not found */

#define	EDOOFUS		88		/* Programming error */
#endif /* _POSIX_SOURCE */
# 170 "/usr/include/errno.h" 3 4

#define	EBADMSG		89		/* Bad message */
#define	EMULTIHOP	90		/* Multihop attempted */
#define	ENOLINK		91		/* Link has been severed */
#define	EPROTO		92		/* Protocol error */

#ifndef _POSIX_SOURCE
#define	ENOTCAPABLE	93		/* Capabilities insufficient */
#define	ECAPMODE	94		/* Not permitted in capability mode */
#define	ENOTRECOVERABLE	95		/* State not recoverable */
#define	EOWNERDEAD	96		/* Previous owner died */
#endif /* _POSIX_SOURCE */
# 182 "/usr/include/errno.h" 3 4

#ifndef _POSIX_SOURCE
#define	ELAST		96		/* Must be equal largest errno */
#endif /* _POSIX_SOURCE */
# 186 "/usr/include/errno.h" 3 4

#ifdef _KERNEL
/* pseudo-errors returned inside kernel to modify return to process */
#define	ERESTART	(-1)		/* restart syscall */
#define	EJUSTRETURN	(-2)		/* don't modify regs, just return */
#define	ENOIOCTL	(-3)		/* ioctl not handled by this layer */
#define	EDIRIOCTL	(-4)		/* do direct ioctl in GEOM */
#endif
# 194 "/usr/include/errno.h" 3 4

#endif
# 196 "/usr/include/errno.h" 3 4
# 28 "/usr/include/c++/v1/cerrno" 2 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 31 "/usr/include/c++/v1/cerrno" 3
#endif
# 32 "/usr/include/c++/v1/cerrno" 3

#if !defined(EOWNERDEAD) || !defined(ENOTRECOVERABLE)

#ifdef ELAST

const int __elast1 = ELAST+1;
const int __elast2 = ELAST+2;

#else
# 41 "/usr/include/c++/v1/cerrno" 3

const int __elast1 = 104;
const int __elast2 = 105;

#endif
# 46 "/usr/include/c++/v1/cerrno" 3

#ifdef ENOTRECOVERABLE

#define EOWNERDEAD __elast1

#ifdef ELAST
#undef ELAST
#define ELAST EOWNERDEAD
#endif
# 55 "/usr/include/c++/v1/cerrno" 3

#elif defined(EOWNERDEAD)
# 57 "/usr/include/c++/v1/cerrno" 3

#define ENOTRECOVERABLE __elast1
#ifdef ELAST
#undef ELAST
#define ELAST ENOTRECOVERABLE
#endif
# 63 "/usr/include/c++/v1/cerrno" 3

#else  // defined(EOWNERDEAD)
# 65 "/usr/include/c++/v1/cerrno" 3

#define EOWNERDEAD __elast1
#define ENOTRECOVERABLE __elast2
#ifdef ELAST
#undef ELAST
#define ELAST ENOTRECOVERABLE
#endif
# 72 "/usr/include/c++/v1/cerrno" 3

#endif  // defined(EOWNERDEAD)
# 74 "/usr/include/c++/v1/cerrno" 3

#endif  // !defined(EOWNERDEAD) || !defined(ENOTRECOVERABLE)
# 76 "/usr/include/c++/v1/cerrno" 3

//  supply errno values likely to be missing, particularly on Windows

#ifndef EAFNOSUPPORT
#define EAFNOSUPPORT 9901
#endif
# 82 "/usr/include/c++/v1/cerrno" 3

#ifndef EADDRINUSE
#define EADDRINUSE 9902
#endif
# 86 "/usr/include/c++/v1/cerrno" 3

#ifndef EADDRNOTAVAIL
#define EADDRNOTAVAIL 9903
#endif
# 90 "/usr/include/c++/v1/cerrno" 3

#ifndef EISCONN
#define EISCONN 9904
#endif
# 94 "/usr/include/c++/v1/cerrno" 3

#ifndef EBADMSG
#define EBADMSG 9905
#endif
# 98 "/usr/include/c++/v1/cerrno" 3

#ifndef ECONNABORTED
#define ECONNABORTED 9906
#endif
# 102 "/usr/include/c++/v1/cerrno" 3

#ifndef EALREADY
#define EALREADY 9907
#endif
# 106 "/usr/include/c++/v1/cerrno" 3

#ifndef ECONNREFUSED
#define ECONNREFUSED 9908
#endif
# 110 "/usr/include/c++/v1/cerrno" 3

#ifndef ECONNRESET
#define ECONNRESET 9909
#endif
# 114 "/usr/include/c++/v1/cerrno" 3

#ifndef EDESTADDRREQ
#define EDESTADDRREQ 9910
#endif
# 118 "/usr/include/c++/v1/cerrno" 3

#ifndef EHOSTUNREACH
#define EHOSTUNREACH 9911
#endif
# 122 "/usr/include/c++/v1/cerrno" 3

#ifndef EIDRM
#define EIDRM 9912
#endif
# 126 "/usr/include/c++/v1/cerrno" 3

#ifndef EMSGSIZE
#define EMSGSIZE 9913
#endif
# 130 "/usr/include/c++/v1/cerrno" 3

#ifndef ENETDOWN
#define ENETDOWN 9914
#endif
# 134 "/usr/include/c++/v1/cerrno" 3

#ifndef ENETRESET
#define ENETRESET 9915
#endif
# 138 "/usr/include/c++/v1/cerrno" 3

#ifndef ENETUNREACH
#define ENETUNREACH 9916
#endif
# 142 "/usr/include/c++/v1/cerrno" 3

#ifndef ENOBUFS
#define ENOBUFS 9917
#endif
# 146 "/usr/include/c++/v1/cerrno" 3

#ifndef ENOLINK
#define ENOLINK 9918
#endif
# 150 "/usr/include/c++/v1/cerrno" 3

#ifndef ENODATA
#define ENODATA 9919
#endif
# 154 "/usr/include/c++/v1/cerrno" 3

#ifndef ENOMSG
#define ENOMSG 9920
#endif
# 158 "/usr/include/c++/v1/cerrno" 3

#ifndef ENOPROTOOPT
#define ENOPROTOOPT 9921
#endif
# 162 "/usr/include/c++/v1/cerrno" 3

#ifndef ENOSR
#define ENOSR 9922
#endif
# 166 "/usr/include/c++/v1/cerrno" 3

#ifndef ENOTSOCK
#define ENOTSOCK 9923
#endif
# 170 "/usr/include/c++/v1/cerrno" 3

#ifndef ENOSTR
#define ENOSTR 9924
#endif
# 174 "/usr/include/c++/v1/cerrno" 3

#ifndef ENOTCONN
#define ENOTCONN 9925
#endif
# 178 "/usr/include/c++/v1/cerrno" 3

#ifndef ENOTSUP
#define ENOTSUP 9926
#endif
# 182 "/usr/include/c++/v1/cerrno" 3

#ifndef ECANCELED
#define ECANCELED 9927
#endif
# 186 "/usr/include/c++/v1/cerrno" 3

#ifndef EINPROGRESS
#define EINPROGRESS 9928
#endif
# 190 "/usr/include/c++/v1/cerrno" 3

#ifndef EOPNOTSUPP
#define EOPNOTSUPP 9929
#endif
# 194 "/usr/include/c++/v1/cerrno" 3

#ifndef EWOULDBLOCK
#define EWOULDBLOCK 9930
#endif
# 198 "/usr/include/c++/v1/cerrno" 3

#ifndef EOWNERDEAD
#define EOWNERDEAD  9931
#endif
# 202 "/usr/include/c++/v1/cerrno" 3

#ifndef EPROTO
#define EPROTO 9932
#endif
# 206 "/usr/include/c++/v1/cerrno" 3

#ifndef EPROTONOSUPPORT
#define EPROTONOSUPPORT 9933
#endif
# 210 "/usr/include/c++/v1/cerrno" 3

#ifndef ENOTRECOVERABLE
#define ENOTRECOVERABLE 9934
#endif
# 214 "/usr/include/c++/v1/cerrno" 3

#ifndef ETIME
#define ETIME 9935
#endif
# 218 "/usr/include/c++/v1/cerrno" 3

#ifndef ETXTBSY
#define ETXTBSY 9936
#endif
# 222 "/usr/include/c++/v1/cerrno" 3

#ifndef ETIMEDOUT
#define ETIMEDOUT 9938
#endif
# 226 "/usr/include/c++/v1/cerrno" 3

#ifndef ELOOP
#define ELOOP 9939
#endif
# 230 "/usr/include/c++/v1/cerrno" 3

#ifndef EOVERFLOW
#define EOVERFLOW 9940
#endif
# 234 "/usr/include/c++/v1/cerrno" 3

#ifndef EPROTOTYPE
#define EPROTOTYPE 9941
#endif
# 238 "/usr/include/c++/v1/cerrno" 3

#ifndef ENOSYS
#define ENOSYS 9942
#endif
# 242 "/usr/include/c++/v1/cerrno" 3

#ifndef EINVAL
#define EINVAL 9943
#endif
# 246 "/usr/include/c++/v1/cerrno" 3

#ifndef ERANGE
#define ERANGE 9944
#endif
# 250 "/usr/include/c++/v1/cerrno" 3

#ifndef EILSEQ
#define EILSEQ 9945
#endif
# 254 "/usr/include/c++/v1/cerrno" 3

//  Windows Mobile doesn't appear to define these:

#ifndef E2BIG
#define E2BIG 9946
#endif
# 260 "/usr/include/c++/v1/cerrno" 3

#ifndef EDOM
#define EDOM 9947
#endif
# 264 "/usr/include/c++/v1/cerrno" 3

#ifndef EFAULT
#define EFAULT 9948
#endif
# 268 "/usr/include/c++/v1/cerrno" 3

#ifndef EBADF
#define EBADF 9949
#endif
# 272 "/usr/include/c++/v1/cerrno" 3

#ifndef EPIPE
#define EPIPE 9950
#endif
# 276 "/usr/include/c++/v1/cerrno" 3

#ifndef EXDEV
#define EXDEV 9951
#endif
# 280 "/usr/include/c++/v1/cerrno" 3

#ifndef EBUSY
#define EBUSY 9952
#endif
# 284 "/usr/include/c++/v1/cerrno" 3

#ifndef ENOTEMPTY
#define ENOTEMPTY 9953
#endif
# 288 "/usr/include/c++/v1/cerrno" 3

#ifndef ENOEXEC
#define ENOEXEC 9954
#endif
# 292 "/usr/include/c++/v1/cerrno" 3

#ifndef EEXIST
#define EEXIST 9955
#endif
# 296 "/usr/include/c++/v1/cerrno" 3

#ifndef EFBIG
#define EFBIG 9956
#endif
# 300 "/usr/include/c++/v1/cerrno" 3

#ifndef ENAMETOOLONG
#define ENAMETOOLONG 9957
#endif
# 304 "/usr/include/c++/v1/cerrno" 3

#ifndef ENOTTY
#define ENOTTY 9958
#endif
# 308 "/usr/include/c++/v1/cerrno" 3

#ifndef EINTR
#define EINTR 9959
#endif
# 312 "/usr/include/c++/v1/cerrno" 3

#ifndef ESPIPE
#define ESPIPE 9960
#endif
# 316 "/usr/include/c++/v1/cerrno" 3

#ifndef EIO
#define EIO 9961
#endif
# 320 "/usr/include/c++/v1/cerrno" 3

#ifndef EISDIR
#define EISDIR 9962
#endif
# 324 "/usr/include/c++/v1/cerrno" 3

#ifndef ECHILD
#define ECHILD 9963
#endif
# 328 "/usr/include/c++/v1/cerrno" 3

#ifndef ENOLCK
#define ENOLCK 9964
#endif
# 332 "/usr/include/c++/v1/cerrno" 3

#ifndef ENOSPC
#define ENOSPC 9965
#endif
# 336 "/usr/include/c++/v1/cerrno" 3

#ifndef ENXIO
#define ENXIO 9966
#endif
# 340 "/usr/include/c++/v1/cerrno" 3

#ifndef ENODEV
#define ENODEV 9967
#endif
# 344 "/usr/include/c++/v1/cerrno" 3

#ifndef ENOENT
#define ENOENT 9968
#endif
# 348 "/usr/include/c++/v1/cerrno" 3

#ifndef ESRCH
#define ESRCH 9969
#endif
# 352 "/usr/include/c++/v1/cerrno" 3

#ifndef ENOTDIR
#define ENOTDIR 9970
#endif
# 356 "/usr/include/c++/v1/cerrno" 3

#ifndef ENOMEM
#define ENOMEM 9971
#endif
# 360 "/usr/include/c++/v1/cerrno" 3

#ifndef EPERM
#define EPERM 9972
#endif
# 364 "/usr/include/c++/v1/cerrno" 3

#ifndef EACCES
#define EACCES 9973
#endif
# 368 "/usr/include/c++/v1/cerrno" 3

#ifndef EROFS
#define EROFS 9974
#endif
# 372 "/usr/include/c++/v1/cerrno" 3

#ifndef EDEADLK
#define EDEADLK 9975
#endif
# 376 "/usr/include/c++/v1/cerrno" 3

#ifndef EAGAIN
#define EAGAIN 9976
#endif
# 380 "/usr/include/c++/v1/cerrno" 3

#ifndef ENFILE
#define ENFILE 9977
#endif
# 384 "/usr/include/c++/v1/cerrno" 3

#ifndef EMFILE
#define EMFILE 9978
#endif
# 388 "/usr/include/c++/v1/cerrno" 3

#ifndef EMLINK
#define EMLINK 9979
#endif
# 392 "/usr/include/c++/v1/cerrno" 3

#endif  // _LIBCPP_CERRNO
# 394 "/usr/include/c++/v1/cerrno" 3
# 223 "/usr/include/c++/v1/system_error" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 224 "/usr/include/c++/v1/system_error" 3
#if 0 /* expanded by -frewrite-includes */
#include <stdexcept>
#endif /* expanded by -frewrite-includes */
# 225 "/usr/include/c++/v1/system_error" 3
#if 0 /* expanded by -frewrite-includes */
#include <__functional_base>
#endif /* expanded by -frewrite-includes */
# 226 "/usr/include/c++/v1/system_error" 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 229 "/usr/include/c++/v1/system_error" 3
#endif
# 230 "/usr/include/c++/v1/system_error" 3

_LIBCPP_BEGIN_NAMESPACE_STD

// is_error_code_enum

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_error_code_enum
    : public false_type {};

// is_error_condition_enum

template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY is_error_condition_enum
    : public false_type {};

// Some error codes are not present on all platforms, so we provide equivalents
// for them:

//enum class errc
_LIBCPP_DECLARE_STRONG_ENUM(errc)
{
    address_family_not_supported        = EAFNOSUPPORT,
    address_in_use                      = EADDRINUSE,
    address_not_available               = EADDRNOTAVAIL,
    already_connected                   = EISCONN,
    argument_list_too_long              = E2BIG,
    argument_out_of_domain              = EDOM,
    bad_address                         = EFAULT,
    bad_file_descriptor                 = EBADF,
    bad_message                         = EBADMSG,
    broken_pipe                         = EPIPE,
    connection_aborted                  = ECONNABORTED,
    connection_already_in_progress      = EALREADY,
    connection_refused                  = ECONNREFUSED,
    connection_reset                    = ECONNRESET,
    cross_device_link                   = EXDEV,
    destination_address_required        = EDESTADDRREQ,
    device_or_resource_busy             = EBUSY,
    directory_not_empty                 = ENOTEMPTY,
    executable_format_error             = ENOEXEC,
    file_exists                         = EEXIST,
    file_too_large                      = EFBIG,
    filename_too_long                   = ENAMETOOLONG,
    function_not_supported              = ENOSYS,
    host_unreachable                    = EHOSTUNREACH,
    identifier_removed                  = EIDRM,
    illegal_byte_sequence               = EILSEQ,
    inappropriate_io_control_operation  = ENOTTY,
    interrupted                         = EINTR,
    invalid_argument                    = EINVAL,
    invalid_seek                        = ESPIPE,
    io_error                            = EIO,
    is_a_directory                      = EISDIR,
    message_size                        = EMSGSIZE,
    network_down                        = ENETDOWN,
    network_reset                       = ENETRESET,
    network_unreachable                 = ENETUNREACH,
    no_buffer_space                     = ENOBUFS,
    no_child_process                    = ECHILD,
    no_link                             = ENOLINK,
    no_lock_available                   = ENOLCK,
#ifdef ENODATA
    no_message_available                = ENODATA,
#else
# 294 "/usr/include/c++/v1/system_error" 3
    no_message_available                = ENOMSG,
#endif
# 296 "/usr/include/c++/v1/system_error" 3
    no_message                          = ENOMSG,
    no_protocol_option                  = ENOPROTOOPT,
    no_space_on_device                  = ENOSPC,
#ifdef ENOSR
    no_stream_resources                 = ENOSR,
#else
# 302 "/usr/include/c++/v1/system_error" 3
    no_stream_resources                 = ENOMEM,
#endif
# 304 "/usr/include/c++/v1/system_error" 3
    no_such_device_or_address           = ENXIO,
    no_such_device                      = ENODEV,
    no_such_file_or_directory           = ENOENT,
    no_such_process                     = ESRCH,
    not_a_directory                     = ENOTDIR,
    not_a_socket                        = ENOTSOCK,
#ifdef ENOSTR
    not_a_stream                        = ENOSTR,
#else
# 313 "/usr/include/c++/v1/system_error" 3
    not_a_stream                        = EINVAL,
#endif
# 315 "/usr/include/c++/v1/system_error" 3
    not_connected                       = ENOTCONN,
    not_enough_memory                   = ENOMEM,
    not_supported                       = ENOTSUP,
    operation_canceled                  = ECANCELED,
    operation_in_progress               = EINPROGRESS,
    operation_not_permitted             = EPERM,
    operation_not_supported             = EOPNOTSUPP,
    operation_would_block               = EWOULDBLOCK,
    owner_dead                          = EOWNERDEAD,
    permission_denied                   = EACCES,
    protocol_error                      = EPROTO,
    protocol_not_supported              = EPROTONOSUPPORT,
    read_only_file_system               = EROFS,
    resource_deadlock_would_occur       = EDEADLK,
    resource_unavailable_try_again      = EAGAIN,
    result_out_of_range                 = ERANGE,
    state_not_recoverable               = ENOTRECOVERABLE,
#ifdef ETIME
    stream_timeout                      = ETIME,
#else
# 335 "/usr/include/c++/v1/system_error" 3
    stream_timeout                      = ETIMEDOUT,
#endif
# 337 "/usr/include/c++/v1/system_error" 3
    text_file_busy                      = ETXTBSY,
    timed_out                           = ETIMEDOUT,
    too_many_files_open_in_system       = ENFILE,
    too_many_files_open                 = EMFILE,
    too_many_links                      = EMLINK,
    too_many_symbolic_link_levels       = ELOOP,
    value_too_large                     = EOVERFLOW,
    wrong_protocol_type                 = EPROTOTYPE
};
_LIBCPP_DECLARE_STRONG_ENUM_EPILOG(errc)

template <>
struct _LIBCPP_TYPE_VIS_ONLY is_error_condition_enum<errc>
    : true_type { };

#ifdef _LIBCPP_HAS_NO_STRONG_ENUMS
template <>
struct _LIBCPP_TYPE_VIS_ONLY is_error_condition_enum<errc::__lx>
    : true_type { };
#endif
# 357 "/usr/include/c++/v1/system_error" 3

class _LIBCPP_TYPE_VIS error_condition;
class _LIBCPP_TYPE_VIS error_code;

// class error_category

class _LIBCPP_HIDDEN __do_message;

class _LIBCPP_TYPE_VIS error_category
{
public:
    virtual ~error_category() _NOEXCEPT;

#ifdef _LIBCPP_BUILDING_SYSTEM_ERROR
    error_category() _NOEXCEPT;
#else
# 373 "/usr/include/c++/v1/system_error" 3
    _LIBCPP_ALWAYS_INLINE
    _LIBCPP_CONSTEXPR_AFTER_CXX11 error_category() _NOEXCEPT _LIBCPP_DEFAULT;
#endif
# 376 "/usr/include/c++/v1/system_error" 3
private:
    error_category(const error_category&);// = delete;
    error_category& operator=(const error_category&);// = delete;

public:
    virtual const char* name() const _NOEXCEPT = 0;
    virtual error_condition default_error_condition(int __ev) const _NOEXCEPT;
    virtual bool equivalent(int __code, const error_condition& __condition) const _NOEXCEPT;
    virtual bool equivalent(const error_code& __code, int __condition) const _NOEXCEPT;
    virtual string message(int __ev) const = 0;

    _LIBCPP_ALWAYS_INLINE
    bool operator==(const error_category& __rhs) const _NOEXCEPT {return this == &__rhs;}

    _LIBCPP_ALWAYS_INLINE
    bool operator!=(const error_category& __rhs) const _NOEXCEPT {return !(*this == __rhs);}

    _LIBCPP_ALWAYS_INLINE
    bool operator< (const error_category& __rhs) const _NOEXCEPT {return this < &__rhs;}

    friend class _LIBCPP_HIDDEN __do_message;
};

class _LIBCPP_HIDDEN __do_message
    : public error_category
{
public:
    virtual string message(int ev) const;
};

_LIBCPP_FUNC_VIS const error_category& generic_category() _NOEXCEPT;
_LIBCPP_FUNC_VIS const error_category& system_category() _NOEXCEPT;

class _LIBCPP_TYPE_VIS error_condition
{
    int __val_;
    const error_category* __cat_;
public:
    _LIBCPP_ALWAYS_INLINE
    error_condition() _NOEXCEPT : __val_(0), __cat_(&generic_category()) {}

    _LIBCPP_ALWAYS_INLINE
    error_condition(int __val, const error_category& __cat) _NOEXCEPT
        : __val_(__val), __cat_(&__cat) {}

    template <class _Ep>
        _LIBCPP_ALWAYS_INLINE
        error_condition(_Ep __e,
              typename enable_if<is_error_condition_enum<_Ep>::value>::type* = 0
                                                                     ) _NOEXCEPT
            {*this = make_error_condition(__e);}

    _LIBCPP_ALWAYS_INLINE
    void assign(int __val, const error_category& __cat) _NOEXCEPT
    {
        __val_ = __val;
        __cat_ = &__cat;
    }

    template <class _Ep>
        _LIBCPP_ALWAYS_INLINE
        typename enable_if
        <
            is_error_condition_enum<_Ep>::value,
            error_condition&
        >::type
        operator=(_Ep __e) _NOEXCEPT
            {*this = make_error_condition(__e); return *this;}

    _LIBCPP_ALWAYS_INLINE
    void clear() _NOEXCEPT
    {
        __val_ = 0;
        __cat_ = &generic_category();
    }

    _LIBCPP_ALWAYS_INLINE
    int value() const _NOEXCEPT {return __val_;}

    _LIBCPP_ALWAYS_INLINE
    const error_category& category() const _NOEXCEPT {return *__cat_;}
    string message() const;

    _LIBCPP_ALWAYS_INLINE
        _LIBCPP_EXPLICIT
        operator bool() const _NOEXCEPT {return __val_ != 0;}
};

inline _LIBCPP_INLINE_VISIBILITY
error_condition
make_error_condition(errc __e) _NOEXCEPT
{
    return error_condition(static_cast<int>(__e), generic_category());
}

inline _LIBCPP_INLINE_VISIBILITY
bool
operator<(const error_condition& __x, const error_condition& __y) _NOEXCEPT
{
    return __x.category() < __y.category()
        || (__x.category() == __y.category() && __x.value() < __y.value());
}

// error_code

class _LIBCPP_TYPE_VIS error_code
{
    int __val_;
    const error_category* __cat_;
public:
    _LIBCPP_ALWAYS_INLINE
    error_code() _NOEXCEPT : __val_(0), __cat_(&system_category()) {}

    _LIBCPP_ALWAYS_INLINE
    error_code(int __val, const error_category& __cat) _NOEXCEPT
        : __val_(__val), __cat_(&__cat) {}

    template <class _Ep>
        _LIBCPP_ALWAYS_INLINE
        error_code(_Ep __e,
                   typename enable_if<is_error_code_enum<_Ep>::value>::type* = 0
                                                                     ) _NOEXCEPT
            {*this = make_error_code(__e);}

    _LIBCPP_ALWAYS_INLINE
    void assign(int __val, const error_category& __cat) _NOEXCEPT
    {
        __val_ = __val;
        __cat_ = &__cat;
    }

    template <class _Ep>
        _LIBCPP_ALWAYS_INLINE
        typename enable_if
        <
            is_error_code_enum<_Ep>::value,
            error_code&
        >::type
        operator=(_Ep __e) _NOEXCEPT
            {*this = make_error_code(__e); return *this;}

    _LIBCPP_ALWAYS_INLINE
    void clear() _NOEXCEPT
    {
        __val_ = 0;
        __cat_ = &system_category();
    }

    _LIBCPP_ALWAYS_INLINE
    int value() const _NOEXCEPT {return __val_;}

    _LIBCPP_ALWAYS_INLINE
    const error_category& category() const _NOEXCEPT {return *__cat_;}

    _LIBCPP_ALWAYS_INLINE
    error_condition default_error_condition() const _NOEXCEPT
        {return __cat_->default_error_condition(__val_);}

    string message() const;

    _LIBCPP_ALWAYS_INLINE
        _LIBCPP_EXPLICIT
        operator bool() const _NOEXCEPT {return __val_ != 0;}
};

inline _LIBCPP_INLINE_VISIBILITY
error_code
make_error_code(errc __e) _NOEXCEPT
{
    return error_code(static_cast<int>(__e), generic_category());
}

inline _LIBCPP_INLINE_VISIBILITY
bool
operator<(const error_code& __x, const error_code& __y) _NOEXCEPT
{
    return __x.category() < __y.category()
        || (__x.category() == __y.category() && __x.value() < __y.value());
}

inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const error_code& __x, const error_code& __y) _NOEXCEPT
{
    return __x.category() == __y.category() && __x.value() == __y.value();
}

inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const error_code& __x, const error_condition& __y) _NOEXCEPT
{
    return __x.category().equivalent(__x.value(), __y)
        || __y.category().equivalent(__x, __y.value());
}

inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const error_condition& __x, const error_code& __y) _NOEXCEPT
{
    return __y == __x;
}

inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const error_condition& __x, const error_condition& __y) _NOEXCEPT
{
    return __x.category() == __y.category() && __x.value() == __y.value();
}

inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const error_code& __x, const error_code& __y) _NOEXCEPT
{return !(__x == __y);}

inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const error_code& __x, const error_condition& __y) _NOEXCEPT
{return !(__x == __y);}

inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const error_condition& __x, const error_code& __y) _NOEXCEPT
{return !(__x == __y);}

inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const error_condition& __x, const error_condition& __y) _NOEXCEPT
{return !(__x == __y);}

template <>
struct _LIBCPP_TYPE_VIS_ONLY hash<error_code>
    : public unary_function<error_code, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(const error_code& __ec) const _NOEXCEPT
    {
        return static_cast<size_t>(__ec.value());
    }
};

// system_error

class _LIBCPP_TYPE_VIS system_error
    : public runtime_error
{
    error_code __ec_;
public:
    system_error(error_code __ec, const string& __what_arg);
    system_error(error_code __ec, const char* __what_arg);
    system_error(error_code __ec);
    system_error(int __ev, const error_category& __ecat, const string& __what_arg);
    system_error(int __ev, const error_category& __ecat, const char* __what_arg);
    system_error(int __ev, const error_category& __ecat);
    ~system_error() _NOEXCEPT;

    _LIBCPP_ALWAYS_INLINE
    const error_code& code() const _NOEXCEPT {return __ec_;}

private:
    static string __init(const error_code&, string);
};

_LIBCPP_FUNC_VIS void __throw_system_error(int ev, const char* what_arg);

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_SYSTEM_ERROR
# 643 "/usr/include/c++/v1/system_error" 3
# 17 "/usr/include/c++/v1/__mutex_base" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <pthread.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/pthread.h" 1 3 4
/*
 * Copyright (c) 1993, 1994 by Chris Provenzano, proven@mit.edu
 * Copyright (c) 1995-1998 by John Birrell <jb@cimlogic.com.au>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *  This product includes software developed by Chris Provenzano.
 * 4. The name of Chris Provenzano may not be used to endorse or promote 
 *	  products derived from this software without specific prior written
 *	  permission.
 *
 * THIS SOFTWARE IS PROVIDED BY CHRIS PROVENZANO ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL CHRIS PROVENZANO BE LIABLE FOR ANY 
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/include/pthread.h 270943 2014-09-01 18:34:30Z ed $
 */
#ifndef _PTHREAD_H_
#define _PTHREAD_H_

/*
 * Header files.
 */
#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/usr/include/pthread.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthreadtypes.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/sys/_pthreadtypes.h" 1 3 4
/*
 * Copyright (c) 1993, 1994 by Chris Provenzano, proven@mit.edu
 * Copyright (c) 1995-1998 by John Birrell <jb@cimlogic.com.au>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *  This product includes software developed by Chris Provenzano.
 * 4. The name of Chris Provenzano may not be used to endorse or promote 
 *	  products derived from this software without specific prior written
 *	  permission.
 *
 * THIS SOFTWARE IS PROVIDED BY CHRIS PROVENZANO ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL CHRIS PROVENZANO BE LIABLE FOR ANY 
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/sys/sys/_pthreadtypes.h 189828 2009-03-14 20:10:14Z das $
 */

#ifndef _SYS__PTHREADTYPES_H_
#define _SYS__PTHREADTYPES_H_

/*
 * Forward structure definitions.
 *
 * These are mostly opaque to the user.
 */
struct pthread;
struct pthread_attr;
struct pthread_cond;
struct pthread_cond_attr;
struct pthread_mutex;
struct pthread_mutex_attr;
struct pthread_once;
struct pthread_rwlock;
struct pthread_rwlockattr;
struct pthread_barrier;
struct pthread_barrier_attr;
struct pthread_spinlock;

/*
 * Primitive system data type definitions required by P1003.1c.
 *
 * Note that P1003.1c specifies that there are no defined comparison
 * or assignment operators for the types pthread_attr_t, pthread_cond_t,
 * pthread_condattr_t, pthread_mutex_t, pthread_mutexattr_t.
 */
#ifndef _PTHREAD_T_DECLARED
typedef struct	pthread			*pthread_t;
#define	_PTHREAD_T_DECLARED
#endif
# 68 "/usr/include/sys/_pthreadtypes.h" 3 4
typedef struct	pthread_attr		*pthread_attr_t;
typedef struct	pthread_mutex		*pthread_mutex_t;
typedef struct	pthread_mutex_attr	*pthread_mutexattr_t;
typedef struct	pthread_cond		*pthread_cond_t;
typedef struct	pthread_cond_attr	*pthread_condattr_t;
typedef int     			pthread_key_t;
typedef struct	pthread_once		pthread_once_t;
typedef struct	pthread_rwlock		*pthread_rwlock_t;
typedef struct	pthread_rwlockattr	*pthread_rwlockattr_t;
typedef struct	pthread_barrier		*pthread_barrier_t;
typedef struct	pthread_barrierattr	*pthread_barrierattr_t;
typedef struct	pthread_spinlock	*pthread_spinlock_t;

/*
 * Additional type definitions:
 *
 * Note that P1003.1c reserves the prefixes pthread_ and PTHREAD_ for
 * use in header symbols.
 */
typedef void	*pthread_addr_t;
typedef void	*(*pthread_startroutine_t)(void *);

/*
 * Once definitions.
 */
struct pthread_once {
	int		state;
	pthread_mutex_t	mutex;
};

#endif /* ! _SYS__PTHREADTYPES_H_ */
# 99 "/usr/include/sys/_pthreadtypes.h" 3 4
# 43 "/usr/include/pthread.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <machine/_limits.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/machine/_limits.h" 1 3 4
/*-
 * This file is in the public domain.
 */
/* $FreeBSD: head/sys/amd64/include/_limits.h 232262 2012-02-28 18:24:28Z tijl $ */

#if 0 /* expanded by -frewrite-includes */
#include <x86/_limits.h>
#endif /* expanded by -frewrite-includes */
# 7 "/usr/include/machine/_limits.h" 3 4
# 44 "/usr/include/pthread.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <machine/_types.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/machine/_types.h" 1 3 4
/*-
 * This file is in the public domain.
 */
/* $FreeBSD: head/sys/amd64/include/_types.h 232261 2012-02-28 18:15:28Z tijl $ */

#if 0 /* expanded by -frewrite-includes */
#include <x86/_types.h>
#endif /* expanded by -frewrite-includes */
# 7 "/usr/include/machine/_types.h" 3 4
# 45 "/usr/include/pthread.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_sigset.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/sys/_sigset.h" 1 3 4
/*-
 * Copyright (c) 1982, 1986, 1989, 1991, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)signal.h	8.4 (Berkeley) 5/4/95
 * $FreeBSD: head/sys/sys/_sigset.h 139825 2005-01-07 02:29:27Z imp $
 */

#ifndef _SYS__SIGSET_H_
#define	_SYS__SIGSET_H_

/*
 * sigset_t macros.
 */
#define	_SIG_WORDS	4
#define	_SIG_MAXSIG	128
#define	_SIG_IDX(sig)	((sig) - 1)
#define	_SIG_WORD(sig)	(_SIG_IDX(sig) >> 5)
#define	_SIG_BIT(sig)	(1 << (_SIG_IDX(sig) & 31))
#define	_SIG_VALID(sig)	((sig) <= _SIG_MAXSIG && (sig) > 0)

typedef struct __sigset {
	__uint32_t __bits[_SIG_WORDS];
} __sigset_t;

#if defined(_KERNEL) && defined(COMPAT_43)
typedef unsigned int osigset_t;
#endif
# 58 "/usr/include/sys/_sigset.h" 3 4

#endif /* !_SYS__SIGSET_H_ */
# 60 "/usr/include/sys/_sigset.h" 3 4
# 46 "/usr/include/pthread.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sched.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/sched.h" 1 3 4
/*-
 * Copyright (c) 1996, 1997
 *      HD Associates, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by HD Associates, Inc
 *      and Jukka Antero Ukkonen.
 * 4. Neither the name of the author nor the names of any co-contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY HD ASSOCIATES AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL HD ASSOCIATES OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

/*-
 * Copyright (c) 2002-2008, Jeffrey Roberson <jeff@freebsd.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice unmodified, this list of conditions, and the following
 *    disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $FreeBSD: head/sys/sys/sched.h 253604 2013-07-24 09:45:31Z avg $
 */

#ifndef _SCHED_H_
#define	_SCHED_H_

#ifdef _KERNEL
/*
 * General scheduling info.
 *
 * sched_load:
 *	Total runnable non-ithread threads in the system.
 *
 * sched_runnable:
 *	Runnable threads for this processor.
 */
int	sched_load(void);
int	sched_rr_interval(void);
int	sched_runnable(void);

/* 
 * Proc related scheduling hooks.
 */
void	sched_exit(struct proc *p, struct thread *childtd);
void	sched_fork(struct thread *td, struct thread *childtd);
void	sched_fork_exit(struct thread *td);
void	sched_class(struct thread *td, int class);
void	sched_nice(struct proc *p, int nice);

/*
 * Threads are switched in and out, block on resources, have temporary
 * priorities inherited from their procs, and use up cpu time.
 */
void	sched_exit_thread(struct thread *td, struct thread *child);
void	sched_fork_thread(struct thread *td, struct thread *child);
void	sched_lend_prio(struct thread *td, u_char prio);
void	sched_lend_user_prio(struct thread *td, u_char pri);
fixpt_t	sched_pctcpu(struct thread *td);
void	sched_prio(struct thread *td, u_char prio);
void	sched_sleep(struct thread *td, int prio);
void	sched_switch(struct thread *td, struct thread *newtd, int flags);
void	sched_throw(struct thread *td);
void	sched_unlend_prio(struct thread *td, u_char prio);
void	sched_user_prio(struct thread *td, u_char prio);
void	sched_userret(struct thread *td);
void	sched_wakeup(struct thread *td);
void	sched_preempt(struct thread *td);
#ifdef	RACCT
#ifdef	SCHED_4BSD
fixpt_t	sched_pctcpu_delta(struct thread *td);
#endif
# 110 "/usr/include/sched.h" 3 4
#endif
# 111 "/usr/include/sched.h" 3 4

/*
 * Threads are moved on and off of run queues
 */
void	sched_add(struct thread *td, int flags);
void	sched_clock(struct thread *td);
void	sched_rem(struct thread *td);
void	sched_tick(int cnt);
void	sched_relinquish(struct thread *td);
struct thread *sched_choose(void);
void	sched_idletd(void *);

/*
 * Binding makes cpu affinity permanent while pinning is used to temporarily
 * hold a thread on a particular CPU.
 */
void	sched_bind(struct thread *td, int cpu);
static __inline void sched_pin(void);
void	sched_unbind(struct thread *td);
static __inline void sched_unpin(void);
int	sched_is_bound(struct thread *td);
void	sched_affinity(struct thread *td);

/*
 * These procedures tell the process data structure allocation code how
 * many bytes to actually allocate.
 */
int	sched_sizeof_proc(void);
int	sched_sizeof_thread(void);

/*
 * This routine provides a consistent thread name for use with KTR graphing
 * functions.
 */
char	*sched_tdname(struct thread *td);
#ifdef KTR
void	sched_clear_tdname(struct thread *td);
#endif
# 149 "/usr/include/sched.h" 3 4

static __inline void
sched_pin(void)
{
	curthread->td_pinned++;
	__compiler_membar();
}

static __inline void
sched_unpin(void)
{
	__compiler_membar();
	curthread->td_pinned--;
}

/* sched_add arguments (formerly setrunqueue) */
#define	SRQ_BORING	0x0000		/* No special circumstances. */
#define	SRQ_YIELDING	0x0001		/* We are yielding (from mi_switch). */
#define	SRQ_OURSELF	0x0002		/* It is ourself (from mi_switch). */
#define	SRQ_INTR	0x0004		/* It is probably urgent. */
#define	SRQ_PREEMPTED	0x0008		/* has been preempted.. be kind */
#define	SRQ_BORROWING	0x0010		/* Priority updated due to prio_lend */

/* Scheduler stats. */
#ifdef SCHED_STATS
DPCPU_DECLARE(long, sched_switch_stats[SWT_COUNT]);

#define	SCHED_STAT_DEFINE_VAR(name, ptr, descr)				\
static void name ## _add_proc(void *dummy __unused)			\
{									\
									\
	SYSCTL_ADD_PROC(NULL,						\
	    SYSCTL_STATIC_CHILDREN(_kern_sched_stats), OID_AUTO,	\
	    #name, CTLTYPE_LONG|CTLFLAG_RD|CTLFLAG_MPSAFE,		\
	    ptr, 0, sysctl_dpcpu_long, "LU", descr);			\
}									\
SYSINIT(name, SI_SUB_LAST, SI_ORDER_MIDDLE, name ## _add_proc, NULL);

#define	SCHED_STAT_DEFINE(name, descr)					\
    DPCPU_DEFINE(unsigned long, name);					\
    SCHED_STAT_DEFINE_VAR(name, &DPCPU_NAME(name), descr)
/*
 * Sched stats are always incremented in critical sections so no atomic
 * is necesssary to increment them.
 */
#define SCHED_STAT_INC(var)     DPCPU_GET(var)++;
#else
# 196 "/usr/include/sched.h" 3 4
#define	SCHED_STAT_DEFINE_VAR(name, descr, ptr)
#define	SCHED_STAT_DEFINE(name, descr)
#define SCHED_STAT_INC(var)			(void)0
#endif
# 200 "/usr/include/sched.h" 3 4

/*
 * Fixup scheduler state for proc0 and thread0
 */
void schedinit(void);
#endif /* _KERNEL */
# 206 "/usr/include/sched.h" 3 4

/* POSIX 1003.1b Process Scheduling */

/*
 * POSIX scheduling policies
 */
#define SCHED_FIFO      1
#define SCHED_OTHER     2
#define SCHED_RR        3

struct sched_param {
        int     sched_priority;
};

/*
 * POSIX scheduling declarations for userland.
 */
#ifndef _KERNEL
#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 225 "/usr/include/sched.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 226 "/usr/include/sched.h" 3 4

#ifndef _PID_T_DECLARED
typedef __pid_t         pid_t;
#define _PID_T_DECLARED
#endif
# 231 "/usr/include/sched.h" 3 4

struct timespec;

__BEGIN_DECLS
int     sched_get_priority_max(int);
int     sched_get_priority_min(int);
int     sched_getparam(pid_t, struct sched_param *);
int     sched_getscheduler(pid_t);
int     sched_rr_get_interval(pid_t, struct timespec *);
int     sched_setparam(pid_t, const struct sched_param *);
int     sched_setscheduler(pid_t, int, const struct sched_param *);
int     sched_yield(void);
__END_DECLS

#endif
# 246 "/usr/include/sched.h" 3 4
#endif /* !_SCHED_H_ */
# 247 "/usr/include/sched.h" 3 4
# 47 "/usr/include/pthread.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <time.h>
#endif /* expanded by -frewrite-includes */
# 48 "/usr/include/pthread.h" 3 4

/*
 * Run-time invariant values:
 */
#define PTHREAD_DESTRUCTOR_ITERATIONS		4
#define PTHREAD_KEYS_MAX			256
#define PTHREAD_STACK_MIN			__MINSIGSTKSZ
#define PTHREAD_THREADS_MAX			__ULONG_MAX
#define PTHREAD_BARRIER_SERIAL_THREAD		-1

/*
 * Flags for threads and thread attributes.
 */
#define PTHREAD_DETACHED            0x1
#define PTHREAD_SCOPE_SYSTEM        0x2
#define PTHREAD_INHERIT_SCHED       0x4
#define PTHREAD_NOFLOAT             0x8

#define PTHREAD_CREATE_DETACHED     PTHREAD_DETACHED
#define PTHREAD_CREATE_JOINABLE     0
#define PTHREAD_SCOPE_PROCESS       0
#define PTHREAD_EXPLICIT_SCHED      0

/*
 * Flags for read/write lock attributes
 */
#define PTHREAD_PROCESS_PRIVATE     0
#define PTHREAD_PROCESS_SHARED      1	

/*
 * Flags for cancelling threads
 */
#define PTHREAD_CANCEL_ENABLE		0
#define PTHREAD_CANCEL_DISABLE		1
#define PTHREAD_CANCEL_DEFERRED		0
#define PTHREAD_CANCEL_ASYNCHRONOUS	2
#define PTHREAD_CANCELED		((void *) 1)

/*
 * Flags for once initialization.
 */
#define PTHREAD_NEEDS_INIT  0
#define PTHREAD_DONE_INIT   1

/*
 * Static once initialization values. 
 */
#define PTHREAD_ONCE_INIT   { PTHREAD_NEEDS_INIT, NULL }

/*
 * Static initialization values. 
 */
#define PTHREAD_MUTEX_INITIALIZER	NULL
#define PTHREAD_ADAPTIVE_MUTEX_INITIALIZER_NP	((pthread_mutex_t)1)
#define PTHREAD_COND_INITIALIZER	NULL
#define PTHREAD_RWLOCK_INITIALIZER	NULL

/*
 * Default attribute arguments (draft 4, deprecated).
 */
#ifndef PTHREAD_KERNEL
#define pthread_condattr_default    NULL
#define pthread_mutexattr_default   NULL
#define pthread_attr_default        NULL
#endif
# 113 "/usr/include/pthread.h" 3 4

#define PTHREAD_PRIO_NONE	0
#define PTHREAD_PRIO_INHERIT	1
#define PTHREAD_PRIO_PROTECT	2

/*
 * Mutex types (Single UNIX Specification, Version 2, 1997).
 *
 * Note that a mutex attribute with one of the following types:
 *
 *	PTHREAD_MUTEX_NORMAL
 *	PTHREAD_MUTEX_RECURSIVE
 *
 * will deviate from POSIX specified semantics.
 */
enum pthread_mutextype {
	PTHREAD_MUTEX_ERRORCHECK	= 1,	/* Default POSIX mutex */
	PTHREAD_MUTEX_RECURSIVE		= 2,	/* Recursive mutex */
	PTHREAD_MUTEX_NORMAL		= 3,	/* No error checking */
	PTHREAD_MUTEX_ADAPTIVE_NP	= 4,	/* Adaptive mutex, spins briefly before blocking on lock */
	PTHREAD_MUTEX_TYPE_MAX
};

#define PTHREAD_MUTEX_DEFAULT		PTHREAD_MUTEX_ERRORCHECK

struct _pthread_cleanup_info {
	__uintptr_t	pthread_cleanup_pad[8];
};

/*
 * Thread function prototype definitions:
 */
__BEGIN_DECLS
int		pthread_atfork(void (*)(void), void (*)(void), void (*)(void));
int		pthread_attr_destroy(pthread_attr_t *);
int		pthread_attr_getstack(const pthread_attr_t * __restrict, 
			void ** __restrict, size_t * __restrict);
int		pthread_attr_getstacksize(const pthread_attr_t *, size_t *);
int		pthread_attr_getguardsize(const pthread_attr_t *, size_t *);
int		pthread_attr_getstackaddr(const pthread_attr_t *, void **);
int		pthread_attr_getdetachstate(const pthread_attr_t *, int *);
int		pthread_attr_init(pthread_attr_t *);
int		pthread_attr_setstacksize(pthread_attr_t *, size_t);
int		pthread_attr_setguardsize(pthread_attr_t *, size_t);
int		pthread_attr_setstack(pthread_attr_t *, void *, size_t);
int		pthread_attr_setstackaddr(pthread_attr_t *, void *);
int		pthread_attr_setdetachstate(pthread_attr_t *, int);
int		pthread_barrier_destroy(pthread_barrier_t *);
int		pthread_barrier_init(pthread_barrier_t *,
			const pthread_barrierattr_t *, unsigned);
int		pthread_barrier_wait(pthread_barrier_t *);
int		pthread_barrierattr_destroy(pthread_barrierattr_t *);
int		pthread_barrierattr_getpshared(const pthread_barrierattr_t *,
			int *);
int		pthread_barrierattr_init(pthread_barrierattr_t *);
int		pthread_barrierattr_setpshared(pthread_barrierattr_t *, int);

#define		pthread_cleanup_push(cleanup_routine, cleanup_arg)		\
		{								\
			struct _pthread_cleanup_info __cleanup_info__;		\
			__pthread_cleanup_push_imp(cleanup_routine, cleanup_arg,\
				&__cleanup_info__);				\
			{

#define		pthread_cleanup_pop(execute)					\
				(void)0;					\
			}							\
			__pthread_cleanup_pop_imp(execute);			\
		}

int		pthread_condattr_destroy(pthread_condattr_t *);
int		pthread_condattr_getclock(const pthread_condattr_t *,
			clockid_t *);
int		pthread_condattr_getpshared(const pthread_condattr_t *, int *);
int		pthread_condattr_init(pthread_condattr_t *);
int		pthread_condattr_setclock(pthread_condattr_t *, clockid_t);
int		pthread_condattr_setpshared(pthread_condattr_t *, int);
int		pthread_cond_broadcast(pthread_cond_t *);
int		pthread_cond_destroy(pthread_cond_t *);
int		pthread_cond_init(pthread_cond_t *,
			const pthread_condattr_t *);
int		pthread_cond_signal(pthread_cond_t *);
int		pthread_cond_timedwait(pthread_cond_t *,
			pthread_mutex_t *__mutex, const struct timespec *)
		    __requires_exclusive(*__mutex);
int		pthread_cond_wait(pthread_cond_t *, pthread_mutex_t *__mutex)
		    __requires_exclusive(*__mutex);
int		pthread_create(pthread_t *, const pthread_attr_t *,
			void *(*) (void *), void *);
int		pthread_detach(pthread_t);
int		pthread_equal(pthread_t, pthread_t);
void		pthread_exit(void *) __dead2;
void		*pthread_getspecific(pthread_key_t);
int		pthread_getcpuclockid(pthread_t, clockid_t *);
int		pthread_join(pthread_t, void **);
int		pthread_key_create(pthread_key_t *,
			void (*) (void *));
int		pthread_key_delete(pthread_key_t);
int		pthread_mutexattr_init(pthread_mutexattr_t *);
int		pthread_mutexattr_destroy(pthread_mutexattr_t *);
int		pthread_mutexattr_getpshared(const pthread_mutexattr_t *,
			int *);
int		pthread_mutexattr_gettype(pthread_mutexattr_t *, int *);
int		pthread_mutexattr_settype(pthread_mutexattr_t *, int);
int		pthread_mutexattr_setpshared(pthread_mutexattr_t *, int);
int		pthread_mutex_destroy(pthread_mutex_t *__mutex)
		    __requires_unlocked(*__mutex);
int		pthread_mutex_init(pthread_mutex_t *__mutex,
			const pthread_mutexattr_t *)
		    __requires_unlocked(*__mutex);
int		pthread_mutex_lock(pthread_mutex_t *__mutex)
                    __locks_exclusive(*__mutex);
int		pthread_mutex_trylock(pthread_mutex_t *__mutex)
                    __trylocks_exclusive(0, *__mutex);
int		pthread_mutex_timedlock(pthread_mutex_t *__mutex,
			const struct timespec *)
                    __trylocks_exclusive(0, *__mutex);
int		pthread_mutex_unlock(pthread_mutex_t *__mutex)
		    __unlocks(*__mutex);
int		pthread_once(pthread_once_t *, void (*) (void));
int		pthread_rwlock_destroy(pthread_rwlock_t *__rwlock)
		    __requires_unlocked(*__rwlock);
int		pthread_rwlock_init(pthread_rwlock_t *__rwlock,
			const pthread_rwlockattr_t *)
		    __requires_unlocked(*__rwlock);
int		pthread_rwlock_rdlock(pthread_rwlock_t *__rwlock)
                    __locks_shared(*__rwlock);
int		pthread_rwlock_timedrdlock(pthread_rwlock_t *__rwlock,
			const struct timespec *)
                    __trylocks_shared(0, *__rwlock);
int		pthread_rwlock_timedwrlock(pthread_rwlock_t *__rwlock,
			const struct timespec *)
                    __trylocks_exclusive(0, *__rwlock);
int		pthread_rwlock_tryrdlock(pthread_rwlock_t *__rwlock)
                    __trylocks_shared(0, *__rwlock);
int		pthread_rwlock_trywrlock(pthread_rwlock_t *__rwlock)
                    __trylocks_exclusive(0, *__rwlock);
int		pthread_rwlock_unlock(pthread_rwlock_t *__rwlock)
		    __unlocks(*__rwlock);
int		pthread_rwlock_wrlock(pthread_rwlock_t *__rwlock)
                    __locks_exclusive(*__rwlock);
int		pthread_rwlockattr_destroy(pthread_rwlockattr_t *);
int		pthread_rwlockattr_getkind_np(const pthread_rwlockattr_t *,
			int *);
int		pthread_rwlockattr_getpshared(const pthread_rwlockattr_t *,
			int *);
int		pthread_rwlockattr_init(pthread_rwlockattr_t *);
int		pthread_rwlockattr_setkind_np(pthread_rwlockattr_t *, int);
int		pthread_rwlockattr_setpshared(pthread_rwlockattr_t *, int);
pthread_t	pthread_self(void);
int		pthread_setspecific(pthread_key_t, const void *);

int		pthread_spin_init(pthread_spinlock_t *__spin, int)
		    __requires_unlocked(*__spin);
int		pthread_spin_destroy(pthread_spinlock_t *__spin)
		    __requires_unlocked(*__spin);
int		pthread_spin_lock(pthread_spinlock_t *__spin)
                    __locks_exclusive(*__spin);
int		pthread_spin_trylock(pthread_spinlock_t *__spin)
                    __trylocks_exclusive(0, *__spin);
int		pthread_spin_unlock(pthread_spinlock_t *__spin)
		    __unlocks(*__spin);
int		pthread_cancel(pthread_t);
int		pthread_setcancelstate(int, int *);
int		pthread_setcanceltype(int, int *);
void		pthread_testcancel(void);

#if __BSD_VISIBLE
int		pthread_getprio(pthread_t);
int		pthread_setprio(pthread_t, int);
void		pthread_yield(void);
#endif
# 285 "/usr/include/pthread.h" 3 4

int		pthread_mutexattr_getprioceiling(pthread_mutexattr_t *,
			int *);
int		pthread_mutexattr_setprioceiling(pthread_mutexattr_t *,
			int);
int		pthread_mutex_getprioceiling(pthread_mutex_t *, int *);
int		pthread_mutex_setprioceiling(pthread_mutex_t *, int, int *);

int		pthread_mutexattr_getprotocol(pthread_mutexattr_t *, int *);
int		pthread_mutexattr_setprotocol(pthread_mutexattr_t *, int);

int		pthread_attr_getinheritsched(const pthread_attr_t *, int *);
int		pthread_attr_getschedparam(const pthread_attr_t *,
			struct sched_param *);
int		pthread_attr_getschedpolicy(const pthread_attr_t *, int *);
int		pthread_attr_getscope(const pthread_attr_t *, int *);
int		pthread_attr_setinheritsched(pthread_attr_t *, int);
int		pthread_attr_setschedparam(pthread_attr_t *,
			const struct sched_param *);
int		pthread_attr_setschedpolicy(pthread_attr_t *, int);
int		pthread_attr_setscope(pthread_attr_t *, int);
int		pthread_getschedparam(pthread_t pthread, int *,
			struct sched_param *);
int		pthread_setschedparam(pthread_t, int,
			const struct sched_param *);
#if __XSI_VISIBLE
int		pthread_getconcurrency(void);
int		pthread_setconcurrency(int);
#endif
# 314 "/usr/include/pthread.h" 3 4

void		__pthread_cleanup_push_imp(void (*)(void *), void *,
			struct _pthread_cleanup_info *);
void		__pthread_cleanup_pop_imp(int);
__END_DECLS

#endif
# 321 "/usr/include/pthread.h" 3 4
# 18 "/usr/include/c++/v1/__mutex_base" 2 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 21 "/usr/include/c++/v1/__mutex_base" 3
#endif
# 22 "/usr/include/c++/v1/__mutex_base" 3

_LIBCPP_BEGIN_NAMESPACE_STD

class _LIBCPP_TYPE_VIS mutex
{
    pthread_mutex_t __m_;

public:
    _LIBCPP_INLINE_VISIBILITY
#ifndef _LIBCPP_HAS_NO_CONSTEXPR
     constexpr mutex() _NOEXCEPT : __m_(PTHREAD_MUTEX_INITIALIZER) {}
#else
# 34 "/usr/include/c++/v1/__mutex_base" 3
     mutex() _NOEXCEPT {__m_ = (pthread_mutex_t)PTHREAD_MUTEX_INITIALIZER;}
#endif
# 36 "/usr/include/c++/v1/__mutex_base" 3
     ~mutex();

private:
    mutex(const mutex&);// = delete;
    mutex& operator=(const mutex&);// = delete;

public:
    void lock();
    bool try_lock() _NOEXCEPT;
    void unlock() _NOEXCEPT;

    typedef pthread_mutex_t* native_handle_type;
    _LIBCPP_INLINE_VISIBILITY native_handle_type native_handle() {return &__m_;}
};

struct _LIBCPP_TYPE_VIS defer_lock_t {};
struct _LIBCPP_TYPE_VIS try_to_lock_t {};
struct _LIBCPP_TYPE_VIS adopt_lock_t {};

#if defined(_LIBCPP_HAS_NO_CONSTEXPR) || defined(_LIBCPP_BUILDING_MUTEX)

extern const defer_lock_t  defer_lock;
extern const try_to_lock_t try_to_lock;
extern const adopt_lock_t  adopt_lock;

#else
# 62 "/usr/include/c++/v1/__mutex_base" 3

constexpr defer_lock_t  defer_lock  = defer_lock_t();
constexpr try_to_lock_t try_to_lock = try_to_lock_t();
constexpr adopt_lock_t  adopt_lock  = adopt_lock_t();

#endif
# 68 "/usr/include/c++/v1/__mutex_base" 3

template <class _Mutex>
class _LIBCPP_TYPE_VIS_ONLY lock_guard
{
public:
    typedef _Mutex mutex_type;

private:
    mutex_type& __m_;
public:

    _LIBCPP_INLINE_VISIBILITY
    explicit lock_guard(mutex_type& __m)
        : __m_(__m) {__m_.lock();}
    _LIBCPP_INLINE_VISIBILITY
    lock_guard(mutex_type& __m, adopt_lock_t)
        : __m_(__m) {}
    _LIBCPP_INLINE_VISIBILITY
    ~lock_guard() {__m_.unlock();}

private:
    lock_guard(lock_guard const&);// = delete;
    lock_guard& operator=(lock_guard const&);// = delete;
};

template <class _Mutex>
class _LIBCPP_TYPE_VIS_ONLY unique_lock
{
public:
    typedef _Mutex mutex_type;

private:
    mutex_type* __m_;
    bool __owns_;

public:
    _LIBCPP_INLINE_VISIBILITY
    unique_lock() _NOEXCEPT : __m_(nullptr), __owns_(false) {}
    _LIBCPP_INLINE_VISIBILITY
    explicit unique_lock(mutex_type& __m)
        : __m_(&__m), __owns_(true) {__m_->lock();}
    _LIBCPP_INLINE_VISIBILITY
    unique_lock(mutex_type& __m, defer_lock_t) _NOEXCEPT
        : __m_(&__m), __owns_(false) {}
    _LIBCPP_INLINE_VISIBILITY
    unique_lock(mutex_type& __m, try_to_lock_t)
        : __m_(&__m), __owns_(__m.try_lock()) {}
    _LIBCPP_INLINE_VISIBILITY
    unique_lock(mutex_type& __m, adopt_lock_t)
        : __m_(&__m), __owns_(true) {}
    template <class _Clock, class _Duration>
    _LIBCPP_INLINE_VISIBILITY
        unique_lock(mutex_type& __m, const chrono::time_point<_Clock, _Duration>& __t)
            : __m_(&__m), __owns_(__m.try_lock_until(__t)) {}
    template <class _Rep, class _Period>
    _LIBCPP_INLINE_VISIBILITY
        unique_lock(mutex_type& __m, const chrono::duration<_Rep, _Period>& __d)
            : __m_(&__m), __owns_(__m.try_lock_for(__d)) {}
    _LIBCPP_INLINE_VISIBILITY
    ~unique_lock()
    {
        if (__owns_)
            __m_->unlock();
    }

private:
    unique_lock(unique_lock const&); // = delete;
    unique_lock& operator=(unique_lock const&); // = delete;

public:
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    _LIBCPP_INLINE_VISIBILITY
    unique_lock(unique_lock&& __u) _NOEXCEPT
        : __m_(__u.__m_), __owns_(__u.__owns_)
        {__u.__m_ = nullptr; __u.__owns_ = false;}
    _LIBCPP_INLINE_VISIBILITY
    unique_lock& operator=(unique_lock&& __u) _NOEXCEPT
        {
            if (__owns_)
                __m_->unlock();
            __m_ = __u.__m_;
            __owns_ = __u.__owns_;
            __u.__m_ = nullptr;
            __u.__owns_ = false;
            return *this;
        }

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 156 "/usr/include/c++/v1/__mutex_base" 3

    void lock();
    bool try_lock();

    template <class _Rep, class _Period>
        bool try_lock_for(const chrono::duration<_Rep, _Period>& __d);
    template <class _Clock, class _Duration>
        bool try_lock_until(const chrono::time_point<_Clock, _Duration>& __t);

    void unlock();

    _LIBCPP_INLINE_VISIBILITY
    void swap(unique_lock& __u) _NOEXCEPT
    {
        _VSTD::swap(__m_, __u.__m_);
        _VSTD::swap(__owns_, __u.__owns_);
    }
    _LIBCPP_INLINE_VISIBILITY
    mutex_type* release() _NOEXCEPT
    {
        mutex_type* __m = __m_;
        __m_ = nullptr;
        __owns_ = false;
        return __m;
    }

    _LIBCPP_INLINE_VISIBILITY
    bool owns_lock() const _NOEXCEPT {return __owns_;}
    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_EXPLICIT
        operator bool () const _NOEXCEPT {return __owns_;}
    _LIBCPP_INLINE_VISIBILITY
    mutex_type* mutex() const _NOEXCEPT {return __m_;}
};

template <class _Mutex>
void
unique_lock<_Mutex>::lock()
{
    if (__m_ == nullptr)
        __throw_system_error(EPERM, "unique_lock::lock: references null mutex");
    if (__owns_)
        __throw_system_error(EDEADLK, "unique_lock::lock: already locked");
    __m_->lock();
    __owns_ = true;
}

template <class _Mutex>
bool
unique_lock<_Mutex>::try_lock()
{
    if (__m_ == nullptr)
        __throw_system_error(EPERM, "unique_lock::try_lock: references null mutex");
    if (__owns_)
        __throw_system_error(EDEADLK, "unique_lock::try_lock: already locked");
    __owns_ = __m_->try_lock();
    return __owns_;
}

template <class _Mutex>
template <class _Rep, class _Period>
bool
unique_lock<_Mutex>::try_lock_for(const chrono::duration<_Rep, _Period>& __d)
{
    if (__m_ == nullptr)
        __throw_system_error(EPERM, "unique_lock::try_lock_for: references null mutex");
    if (__owns_)
        __throw_system_error(EDEADLK, "unique_lock::try_lock_for: already locked");
    __owns_ = __m_->try_lock_for(__d);
    return __owns_;
}

template <class _Mutex>
template <class _Clock, class _Duration>
bool
unique_lock<_Mutex>::try_lock_until(const chrono::time_point<_Clock, _Duration>& __t)
{
    if (__m_ == nullptr)
        __throw_system_error(EPERM, "unique_lock::try_lock_until: references null mutex");
    if (__owns_)
        __throw_system_error(EDEADLK, "unique_lock::try_lock_until: already locked");
    __owns_ = __m_->try_lock_until(__t);
    return __owns_;
}

template <class _Mutex>
void
unique_lock<_Mutex>::unlock()
{
    if (!__owns_)
        __throw_system_error(EPERM, "unique_lock::unlock: not locked");
    __m_->unlock();
    __owns_ = false;
}

template <class _Mutex>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(unique_lock<_Mutex>& __x, unique_lock<_Mutex>& __y) _NOEXCEPT
    {__x.swap(__y);}

struct _LIBCPP_TYPE_VIS cv_status
{
    enum __lx {
        no_timeout,
        timeout
    };

    __lx __v_;

    _LIBCPP_INLINE_VISIBILITY cv_status(__lx __v) : __v_(__v) {}
    _LIBCPP_INLINE_VISIBILITY operator int() const {return __v_;}

};

class _LIBCPP_TYPE_VIS condition_variable
{
    pthread_cond_t __cv_;
public:
    _LIBCPP_INLINE_VISIBILITY
#ifndef _LIBCPP_HAS_NO_CONSTEXPR
    constexpr condition_variable() : __cv_(PTHREAD_COND_INITIALIZER) {}
#else
# 279 "/usr/include/c++/v1/__mutex_base" 3
    condition_variable() {__cv_ = (pthread_cond_t)PTHREAD_COND_INITIALIZER;}
#endif
# 281 "/usr/include/c++/v1/__mutex_base" 3
    ~condition_variable();

private:
    condition_variable(const condition_variable&); // = delete;
    condition_variable& operator=(const condition_variable&); // = delete;

public:
    void notify_one() _NOEXCEPT;
    void notify_all() _NOEXCEPT;

    void wait(unique_lock<mutex>& __lk);
    template <class _Predicate>
        void wait(unique_lock<mutex>& __lk, _Predicate __pred);

    template <class _Clock, class _Duration>
        cv_status
        wait_until(unique_lock<mutex>& __lk,
                   const chrono::time_point<_Clock, _Duration>& __t);

    template <class _Clock, class _Duration, class _Predicate>
        bool
        wait_until(unique_lock<mutex>& __lk,
                   const chrono::time_point<_Clock, _Duration>& __t,
                   _Predicate __pred);

    template <class _Rep, class _Period>
        cv_status
        wait_for(unique_lock<mutex>& __lk,
                 const chrono::duration<_Rep, _Period>& __d);

    template <class _Rep, class _Period, class _Predicate>
        bool
        wait_for(unique_lock<mutex>& __lk,
                 const chrono::duration<_Rep, _Period>& __d,
                 _Predicate __pred);

    typedef pthread_cond_t* native_handle_type;
    _LIBCPP_INLINE_VISIBILITY native_handle_type native_handle() {return &__cv_;}

private:
    void __do_timed_wait(unique_lock<mutex>& __lk,
                 chrono::time_point<chrono::system_clock, chrono::nanoseconds>);
};

template <class _To, class _Rep, class _Period>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    chrono::__is_duration<_To>::value,
    _To
>::type
__ceil(chrono::duration<_Rep, _Period> __d)
{
    using namespace chrono;
    _To __r = duration_cast<_To>(__d);
    if (__r < __d)
        ++__r;
    return __r;
}

template <class _Predicate>
void
condition_variable::wait(unique_lock<mutex>& __lk, _Predicate __pred)
{
    while (!__pred())
        wait(__lk);
}

template <class _Clock, class _Duration>
cv_status
condition_variable::wait_until(unique_lock<mutex>& __lk,
                               const chrono::time_point<_Clock, _Duration>& __t)
{
    using namespace chrono;
    wait_for(__lk, __t - _Clock::now());
    return _Clock::now() < __t ? cv_status::no_timeout : cv_status::timeout;
}

template <class _Clock, class _Duration, class _Predicate>
bool
condition_variable::wait_until(unique_lock<mutex>& __lk,
                   const chrono::time_point<_Clock, _Duration>& __t,
                   _Predicate __pred)
{
    while (!__pred())
    {
        if (wait_until(__lk, __t) == cv_status::timeout)
            return __pred();
    }
    return true;
}

template <class _Rep, class _Period>
cv_status
condition_variable::wait_for(unique_lock<mutex>& __lk,
                             const chrono::duration<_Rep, _Period>& __d)
{
    using namespace chrono;
    if (__d <= __d.zero())
        return cv_status::timeout;
    typedef time_point<system_clock, duration<long double, nano> > __sys_tpf;
    typedef time_point<system_clock, nanoseconds> __sys_tpi;
    __sys_tpf _Max = __sys_tpi::max();
    system_clock::time_point __s_now = system_clock::now();
    steady_clock::time_point __c_now = steady_clock::now();
    if (_Max - __d > __s_now)
        __do_timed_wait(__lk, __s_now + __ceil<nanoseconds>(__d));
    else
        __do_timed_wait(__lk, __sys_tpi::max());
    return steady_clock::now() - __c_now < __d ? cv_status::no_timeout :
                                                 cv_status::timeout;
}

template <class _Rep, class _Period, class _Predicate>
inline _LIBCPP_INLINE_VISIBILITY
bool
condition_variable::wait_for(unique_lock<mutex>& __lk,
                             const chrono::duration<_Rep, _Period>& __d,
                             _Predicate __pred)
{
    return wait_until(__lk, chrono::steady_clock::now() + __d,
                      _VSTD::move(__pred));
}

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP___MUTEX_BASE
# 408 "/usr/include/c++/v1/__mutex_base" 3
# 177 "/usr/include/c++/v1/mutex" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <functional>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/functional" 1 3
// -*- C++ -*-
//===------------------------ functional ----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_FUNCTIONAL
#define _LIBCPP_FUNCTIONAL

/*
    functional synopsis

namespace std
{

template <class Arg, class Result>
struct unary_function
{
    typedef Arg    argument_type;
    typedef Result result_type;
};

template <class Arg1, class Arg2, class Result>
struct binary_function
{
    typedef Arg1   first_argument_type;
    typedef Arg2   second_argument_type;
    typedef Result result_type;
};

template <class T>
class reference_wrapper
    : public unary_function<T1, R> // if wrapping a unary functor
    : public binary_function<T1, T2, R> // if wraping a binary functor
{
public:
    // types
    typedef T type;
    typedef see below result_type; // Not always defined

    // construct/copy/destroy
    reference_wrapper(T&) noexcept;
    reference_wrapper(T&&) = delete; // do not bind to temps
    reference_wrapper(const reference_wrapper<T>& x) noexcept;

    // assignment
    reference_wrapper& operator=(const reference_wrapper<T>& x) noexcept;

    // access
    operator T& () const noexcept;
    T& get() const noexcept;

    // invoke
    template <class... ArgTypes>
      typename result_of<T&(ArgTypes&&...)>::type
          operator() (ArgTypes&&...) const;
};

template <class T> reference_wrapper<T> ref(T& t) noexcept;
template <class T> void ref(const T&& t) = delete;
template <class T> reference_wrapper<T> ref(reference_wrapper<T>t) noexcept;

template <class T> reference_wrapper<const T> cref(const T& t) noexcept;
template <class T> void cref(const T&& t) = delete;
template <class T> reference_wrapper<const T> cref(reference_wrapper<T> t) noexcept;

template <class T> // <class T=void> in C++14
struct plus : binary_function<T, T, T>
{
    T operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct minus : binary_function<T, T, T>
{
    T operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct multiplies : binary_function<T, T, T>
{
    T operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct divides : binary_function<T, T, T>
{
    T operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct modulus : binary_function<T, T, T>
{
    T operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct negate : unary_function<T, T>
{
    T operator()(const T& x) const;
};

template <class T> // <class T=void> in C++14
struct equal_to : binary_function<T, T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct not_equal_to : binary_function<T, T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct greater : binary_function<T, T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct less : binary_function<T, T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct greater_equal : binary_function<T, T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct less_equal : binary_function<T, T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct logical_and : binary_function<T, T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct logical_or : binary_function<T, T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct logical_not : unary_function<T, bool>
{
    bool operator()(const T& x) const;
};

template <class T> // <class T=void> in C++14
struct bit_and : unary_function<T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct bit_or : unary_function<T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T> // <class T=void> in C++14
struct bit_xor : unary_function<T, bool>
{
    bool operator()(const T& x, const T& y) const;
};

template <class T=void> // C++14
struct bit_xor : unary_function<T, bool>
{
    bool operator()(const T& x) const;
};

template <class Predicate>
class unary_negate
    : public unary_function<typename Predicate::argument_type, bool>
{
public:
    explicit unary_negate(const Predicate& pred);
    bool operator()(const typename Predicate::argument_type& x) const;
};

template <class Predicate> unary_negate<Predicate> not1(const Predicate& pred);

template <class Predicate>
class binary_negate
    : public binary_function<typename Predicate::first_argument_type,
                             typename Predicate::second_argument_type,
                             bool>
{
public:
    explicit binary_negate(const Predicate& pred);
    bool operator()(const typename Predicate::first_argument_type& x,
                    const typename Predicate::second_argument_type& y) const;
};

template <class Predicate> binary_negate<Predicate> not2(const Predicate& pred);

template<class T> struct is_bind_expression;
template<class T> struct is_placeholder;

template<class Fn, class... BoundArgs>
  unspecified bind(Fn&&, BoundArgs&&...);
template<class R, class Fn, class... BoundArgs>
  unspecified bind(Fn&&, BoundArgs&&...);

namespace placeholders {
  // M is the implementation-defined number of placeholders
  extern unspecified _1;
  extern unspecified _2;
  .
  .
  .
  extern unspecified _Mp;
}

template <class Operation>
class binder1st
    : public unary_function<typename Operation::second_argument_type,
                            typename Operation::result_type>
{
protected:
    Operation                               op;
    typename Operation::first_argument_type value;
public:
    binder1st(const Operation& x, const typename Operation::first_argument_type y);
    typename Operation::result_type operator()(      typename Operation::second_argument_type& x) const;
    typename Operation::result_type operator()(const typename Operation::second_argument_type& x) const;
};

template <class Operation, class T>
binder1st<Operation> bind1st(const Operation& op, const T& x);

template <class Operation>
class binder2nd
    : public unary_function<typename Operation::first_argument_type,
                            typename Operation::result_type>
{
protected:
    Operation                                op;
    typename Operation::second_argument_type value;
public:
    binder2nd(const Operation& x, const typename Operation::second_argument_type y);
    typename Operation::result_type operator()(      typename Operation::first_argument_type& x) const;
    typename Operation::result_type operator()(const typename Operation::first_argument_type& x) const;
};

template <class Operation, class T>
binder2nd<Operation> bind2nd(const Operation& op, const T& x);

template <class Arg, class Result>
class pointer_to_unary_function : public unary_function<Arg, Result>
{
public:
    explicit pointer_to_unary_function(Result (*f)(Arg));
    Result operator()(Arg x) const;
};

template <class Arg, class Result>
pointer_to_unary_function<Arg,Result> ptr_fun(Result (*f)(Arg));

template <class Arg1, class Arg2, class Result>
class pointer_to_binary_function : public binary_function<Arg1, Arg2, Result>
{
public:
    explicit pointer_to_binary_function(Result (*f)(Arg1, Arg2));
    Result operator()(Arg1 x, Arg2 y) const;
};

template <class Arg1, class Arg2, class Result>
pointer_to_binary_function<Arg1,Arg2,Result> ptr_fun(Result (*f)(Arg1,Arg2));

template<class S, class T>
class mem_fun_t : public unary_function<T*, S>
{
public:
    explicit mem_fun_t(S (T::*p)());
    S operator()(T* p) const;
};

template<class S, class T, class A>
class mem_fun1_t : public binary_function<T*, A, S>
{
public:
    explicit mem_fun1_t(S (T::*p)(A));
    S operator()(T* p, A x) const;
};

template<class S, class T>          mem_fun_t<S,T>    mem_fun(S (T::*f)());
template<class S, class T, class A> mem_fun1_t<S,T,A> mem_fun(S (T::*f)(A));

template<class S, class T>
class mem_fun_ref_t : public unary_function<T, S>
{
public:
    explicit mem_fun_ref_t(S (T::*p)());
    S operator()(T& p) const;
};

template<class S, class T, class A>
class mem_fun1_ref_t : public binary_function<T, A, S>
{
public:
    explicit mem_fun1_ref_t(S (T::*p)(A));
    S operator()(T& p, A x) const;
};

template<class S, class T>          mem_fun_ref_t<S,T>    mem_fun_ref(S (T::*f)());
template<class S, class T, class A> mem_fun1_ref_t<S,T,A> mem_fun_ref(S (T::*f)(A));

template <class S, class T>
class const_mem_fun_t : public unary_function<const T*, S>
{
public:
    explicit const_mem_fun_t(S (T::*p)() const);
    S operator()(const T* p) const;
};

template <class S, class T, class A>
class const_mem_fun1_t : public binary_function<const T*, A, S>
{
public:
    explicit const_mem_fun1_t(S (T::*p)(A) const);
    S operator()(const T* p, A x) const;
};

template <class S, class T>          const_mem_fun_t<S,T>    mem_fun(S (T::*f)() const);
template <class S, class T, class A> const_mem_fun1_t<S,T,A> mem_fun(S (T::*f)(A) const);

template <class S, class T>
class const_mem_fun_ref_t : public unary_function<T, S>
{
public:
    explicit const_mem_fun_ref_t(S (T::*p)() const);
    S operator()(const T& p) const;
};

template <class S, class T, class A>
class const_mem_fun1_ref_t : public binary_function<T, A, S>
{
public:
    explicit const_mem_fun1_ref_t(S (T::*p)(A) const);
    S operator()(const T& p, A x) const;
};

template <class S, class T>          const_mem_fun_ref_t<S,T>    mem_fun_ref(S (T::*f)() const);
template <class S, class T, class A> const_mem_fun1_ref_t<S,T,A> mem_fun_ref(S (T::*f)(A) const);

template<class R, class T> unspecified mem_fn(R T::*);

class bad_function_call
    : public exception
{
};

template<class> class function; // undefined

template<class R, class... ArgTypes>
class function<R(ArgTypes...)>
  : public unary_function<T1, R>      // iff sizeof...(ArgTypes) == 1 and
                                      // ArgTypes contains T1
  : public binary_function<T1, T2, R> // iff sizeof...(ArgTypes) == 2 and
                                      // ArgTypes contains T1 and T2
{
public:
    typedef R result_type;

    // construct/copy/destroy:
    function() noexcept;
    function(nullptr_t) noexcept;
    function(const function&);
    function(function&&) noexcept;
    template<class F>
      function(F);
    template<Allocator Alloc>
      function(allocator_arg_t, const Alloc&) noexcept;
    template<Allocator Alloc>
      function(allocator_arg_t, const Alloc&, nullptr_t) noexcept;
    template<Allocator Alloc>
      function(allocator_arg_t, const Alloc&, const function&);
    template<Allocator Alloc>
      function(allocator_arg_t, const Alloc&, function&&);
    template<class F, Allocator Alloc>
      function(allocator_arg_t, const Alloc&, F);

    function& operator=(const function&);
    function& operator=(function&&) noexcept;
    function& operator=(nullptr_t) noexcept;
    template<class F>
      function& operator=(F&&);
    template<class F>
      function& operator=(reference_wrapper<F>) noexcept;

    ~function();

    // function modifiers:
    void swap(function&) noexcept;
    template<class F, class Alloc>
      void assign(F&&, const Alloc&);

    // function capacity:
    explicit operator bool() const noexcept;

    // function invocation:
    R operator()(ArgTypes...) const;

    // function target access:
    const std::type_info& target_type() const noexcept;
    template <typename T>       T* target() noexcept;
    template <typename T> const T* target() const noexcept;
};

// Null pointer comparisons:
template <class R, class ... ArgTypes>
  bool operator==(const function<R(ArgTypes...)>&, nullptr_t) noexcept;

template <class R, class ... ArgTypes>
  bool operator==(nullptr_t, const function<R(ArgTypes...)>&) noexcept;

template <class R, class ... ArgTypes>
  bool operator!=(const function<R(ArgTypes...)>&, nullptr_t) noexcept;

template <class  R, class ... ArgTypes>
  bool operator!=(nullptr_t, const function<R(ArgTypes...)>&) noexcept;

// specialized algorithms:
template <class  R, class ... ArgTypes>
  void swap(function<R(ArgTypes...)>&, function<R(ArgTypes...)>&) noexcept;

template <class T> struct hash;

template <> struct hash<bool>;
template <> struct hash<char>;
template <> struct hash<signed char>;
template <> struct hash<unsigned char>;
template <> struct hash<char16_t>;
template <> struct hash<char32_t>;
template <> struct hash<wchar_t>;
template <> struct hash<short>;
template <> struct hash<unsigned short>;
template <> struct hash<int>;
template <> struct hash<unsigned int>;
template <> struct hash<long>;
template <> struct hash<long long>;
template <> struct hash<unsigned long>;
template <> struct hash<unsigned long long>;

template <> struct hash<float>;
template <> struct hash<double>;
template <> struct hash<long double>;

template<class T> struct hash<T*>;

}  // std

POLICY:  For non-variadic implementations, the number of arguments is limited
         to 3.  It is hoped that the need for non-variadic implementations
         will be minimal.

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 474 "/usr/include/c++/v1/functional" 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 475 "/usr/include/c++/v1/functional" 3
#if 0 /* expanded by -frewrite-includes */
#include <typeinfo>
#endif /* expanded by -frewrite-includes */
# 476 "/usr/include/c++/v1/functional" 3
#if 0 /* expanded by -frewrite-includes */
#include <exception>
#endif /* expanded by -frewrite-includes */
# 477 "/usr/include/c++/v1/functional" 3
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 478 "/usr/include/c++/v1/functional" 3
#if 0 /* expanded by -frewrite-includes */
#include <tuple>
#endif /* expanded by -frewrite-includes */
# 479 "/usr/include/c++/v1/functional" 3

#if 0 /* expanded by -frewrite-includes */
#include <__functional_base>
#endif /* expanded by -frewrite-includes */
# 481 "/usr/include/c++/v1/functional" 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 484 "/usr/include/c++/v1/functional" 3
#endif
# 485 "/usr/include/c++/v1/functional" 3

_LIBCPP_BEGIN_NAMESPACE_STD

#if _LIBCPP_STD_VER > 11
template <class _Tp = void>
#else
# 491 "/usr/include/c++/v1/functional" 3
template <class _Tp>
#endif
# 493 "/usr/include/c++/v1/functional" 3
struct _LIBCPP_TYPE_VIS_ONLY plus : binary_function<_Tp, _Tp, _Tp>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    _Tp operator()(const _Tp& __x, const _Tp& __y) const
        {return __x + __y;}
};

#if _LIBCPP_STD_VER > 11
template <>
struct _LIBCPP_TYPE_VIS_ONLY plus<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
        { return _VSTD::forward<_T1>(__t) + _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 511 "/usr/include/c++/v1/functional" 3


#if _LIBCPP_STD_VER > 11
template <class _Tp = void>
#else
# 516 "/usr/include/c++/v1/functional" 3
template <class _Tp>
#endif
# 518 "/usr/include/c++/v1/functional" 3
struct _LIBCPP_TYPE_VIS_ONLY minus : binary_function<_Tp, _Tp, _Tp>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    _Tp operator()(const _Tp& __x, const _Tp& __y) const
        {return __x - __y;}
};

#if _LIBCPP_STD_VER > 11
template <>
struct _LIBCPP_TYPE_VIS_ONLY minus<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
        { return _VSTD::forward<_T1>(__t) - _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 536 "/usr/include/c++/v1/functional" 3


#if _LIBCPP_STD_VER > 11
template <class _Tp = void>
#else
# 541 "/usr/include/c++/v1/functional" 3
template <class _Tp>
#endif
# 543 "/usr/include/c++/v1/functional" 3
struct _LIBCPP_TYPE_VIS_ONLY multiplies : binary_function<_Tp, _Tp, _Tp>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    _Tp operator()(const _Tp& __x, const _Tp& __y) const
        {return __x * __y;}
};

#if _LIBCPP_STD_VER > 11
template <>
struct _LIBCPP_TYPE_VIS_ONLY multiplies<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
        { return _VSTD::forward<_T1>(__t) * _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 561 "/usr/include/c++/v1/functional" 3


#if _LIBCPP_STD_VER > 11
template <class _Tp = void>
#else
# 566 "/usr/include/c++/v1/functional" 3
template <class _Tp>
#endif
# 568 "/usr/include/c++/v1/functional" 3
struct _LIBCPP_TYPE_VIS_ONLY divides : binary_function<_Tp, _Tp, _Tp>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    _Tp operator()(const _Tp& __x, const _Tp& __y) const
        {return __x / __y;}
};

#if _LIBCPP_STD_VER > 11
template <>
struct _LIBCPP_TYPE_VIS_ONLY divides<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
        { return _VSTD::forward<_T1>(__t) / _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 586 "/usr/include/c++/v1/functional" 3


#if _LIBCPP_STD_VER > 11
template <class _Tp = void>
#else
# 591 "/usr/include/c++/v1/functional" 3
template <class _Tp>
#endif
# 593 "/usr/include/c++/v1/functional" 3
struct _LIBCPP_TYPE_VIS_ONLY modulus : binary_function<_Tp, _Tp, _Tp>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    _Tp operator()(const _Tp& __x, const _Tp& __y) const
        {return __x % __y;}
};

#if _LIBCPP_STD_VER > 11
template <>
struct _LIBCPP_TYPE_VIS_ONLY modulus<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
        { return _VSTD::forward<_T1>(__t) % _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 611 "/usr/include/c++/v1/functional" 3


#if _LIBCPP_STD_VER > 11
template <class _Tp = void>
#else
# 616 "/usr/include/c++/v1/functional" 3
template <class _Tp>
#endif
# 618 "/usr/include/c++/v1/functional" 3
struct _LIBCPP_TYPE_VIS_ONLY negate : unary_function<_Tp, _Tp>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    _Tp operator()(const _Tp& __x) const
        {return -__x;}
};

#if _LIBCPP_STD_VER > 11
template <>
struct _LIBCPP_TYPE_VIS_ONLY negate<void>
{
    template <class _Tp>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_Tp&& __x) const
        { return -_VSTD::forward<_Tp>(__x); }
    typedef void is_transparent;
};
#endif
# 636 "/usr/include/c++/v1/functional" 3


#if _LIBCPP_STD_VER > 11
template <class _Tp = void>
#else
# 641 "/usr/include/c++/v1/functional" 3
template <class _Tp>
#endif
# 643 "/usr/include/c++/v1/functional" 3
struct _LIBCPP_TYPE_VIS_ONLY equal_to : binary_function<_Tp, _Tp, bool>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _Tp& __x, const _Tp& __y) const
        {return __x == __y;}
};

#if _LIBCPP_STD_VER > 11
template <>
struct _LIBCPP_TYPE_VIS_ONLY equal_to<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
        { return _VSTD::forward<_T1>(__t) == _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 661 "/usr/include/c++/v1/functional" 3


#if _LIBCPP_STD_VER > 11
template <class _Tp = void>
#else
# 666 "/usr/include/c++/v1/functional" 3
template <class _Tp>
#endif
# 668 "/usr/include/c++/v1/functional" 3
struct _LIBCPP_TYPE_VIS_ONLY not_equal_to : binary_function<_Tp, _Tp, bool>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _Tp& __x, const _Tp& __y) const
        {return __x != __y;}
};

#if _LIBCPP_STD_VER > 11
template <>
struct _LIBCPP_TYPE_VIS_ONLY not_equal_to<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
        { return _VSTD::forward<_T1>(__t) != _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 686 "/usr/include/c++/v1/functional" 3


#if _LIBCPP_STD_VER > 11
template <class _Tp = void>
#else
# 691 "/usr/include/c++/v1/functional" 3
template <class _Tp>
#endif
# 693 "/usr/include/c++/v1/functional" 3
struct _LIBCPP_TYPE_VIS_ONLY greater : binary_function<_Tp, _Tp, bool>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _Tp& __x, const _Tp& __y) const
        {return __x > __y;}
};

#if _LIBCPP_STD_VER > 11
template <>
struct _LIBCPP_TYPE_VIS_ONLY greater<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
        { return _VSTD::forward<_T1>(__t) > _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 711 "/usr/include/c++/v1/functional" 3


// less in <__functional_base>

#if _LIBCPP_STD_VER > 11
template <class _Tp = void>
#else
# 718 "/usr/include/c++/v1/functional" 3
template <class _Tp>
#endif
# 720 "/usr/include/c++/v1/functional" 3
struct _LIBCPP_TYPE_VIS_ONLY greater_equal : binary_function<_Tp, _Tp, bool>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _Tp& __x, const _Tp& __y) const
        {return __x >= __y;}
};

#if _LIBCPP_STD_VER > 11
template <>
struct _LIBCPP_TYPE_VIS_ONLY greater_equal<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
        { return _VSTD::forward<_T1>(__t) >= _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 738 "/usr/include/c++/v1/functional" 3


#if _LIBCPP_STD_VER > 11
template <class _Tp = void>
#else
# 743 "/usr/include/c++/v1/functional" 3
template <class _Tp>
#endif
# 745 "/usr/include/c++/v1/functional" 3
struct _LIBCPP_TYPE_VIS_ONLY less_equal : binary_function<_Tp, _Tp, bool>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _Tp& __x, const _Tp& __y) const
        {return __x <= __y;}
};

#if _LIBCPP_STD_VER > 11
template <>
struct _LIBCPP_TYPE_VIS_ONLY less_equal<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
        { return _VSTD::forward<_T1>(__t) <= _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 763 "/usr/include/c++/v1/functional" 3


#if _LIBCPP_STD_VER > 11
template <class _Tp = void>
#else
# 768 "/usr/include/c++/v1/functional" 3
template <class _Tp>
#endif
# 770 "/usr/include/c++/v1/functional" 3
struct _LIBCPP_TYPE_VIS_ONLY logical_and : binary_function<_Tp, _Tp, bool>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _Tp& __x, const _Tp& __y) const
        {return __x && __y;}
};

#if _LIBCPP_STD_VER > 11
template <>
struct _LIBCPP_TYPE_VIS_ONLY logical_and<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
        { return _VSTD::forward<_T1>(__t) && _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 788 "/usr/include/c++/v1/functional" 3


#if _LIBCPP_STD_VER > 11
template <class _Tp = void>
#else
# 793 "/usr/include/c++/v1/functional" 3
template <class _Tp>
#endif
# 795 "/usr/include/c++/v1/functional" 3
struct _LIBCPP_TYPE_VIS_ONLY logical_or : binary_function<_Tp, _Tp, bool>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _Tp& __x, const _Tp& __y) const
        {return __x || __y;}
};

#if _LIBCPP_STD_VER > 11
template <>
struct _LIBCPP_TYPE_VIS_ONLY logical_or<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
        { return _VSTD::forward<_T1>(__t) || _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 813 "/usr/include/c++/v1/functional" 3


#if _LIBCPP_STD_VER > 11
template <class _Tp = void>
#else
# 818 "/usr/include/c++/v1/functional" 3
template <class _Tp>
#endif
# 820 "/usr/include/c++/v1/functional" 3
struct _LIBCPP_TYPE_VIS_ONLY logical_not : unary_function<_Tp, bool>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool operator()(const _Tp& __x) const
        {return !__x;}
};

#if _LIBCPP_STD_VER > 11
template <>
struct _LIBCPP_TYPE_VIS_ONLY logical_not<void>
{
    template <class _Tp>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_Tp&& __x) const
        { return !_VSTD::forward<_Tp>(__x); }
    typedef void is_transparent;
};
#endif
# 838 "/usr/include/c++/v1/functional" 3


#if _LIBCPP_STD_VER > 11
template <class _Tp = void>
#else
# 843 "/usr/include/c++/v1/functional" 3
template <class _Tp>
#endif
# 845 "/usr/include/c++/v1/functional" 3
struct _LIBCPP_TYPE_VIS_ONLY bit_and : binary_function<_Tp, _Tp, _Tp>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    _Tp operator()(const _Tp& __x, const _Tp& __y) const
        {return __x & __y;}
};

#if _LIBCPP_STD_VER > 11
template <>
struct _LIBCPP_TYPE_VIS_ONLY bit_and<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
        { return _VSTD::forward<_T1>(__t) & _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 863 "/usr/include/c++/v1/functional" 3


#if _LIBCPP_STD_VER > 11
template <class _Tp = void>
#else
# 868 "/usr/include/c++/v1/functional" 3
template <class _Tp>
#endif
# 870 "/usr/include/c++/v1/functional" 3
struct _LIBCPP_TYPE_VIS_ONLY bit_or : binary_function<_Tp, _Tp, _Tp>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    _Tp operator()(const _Tp& __x, const _Tp& __y) const
        {return __x | __y;}
};

#if _LIBCPP_STD_VER > 11
template <>
struct _LIBCPP_TYPE_VIS_ONLY bit_or<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
        { return _VSTD::forward<_T1>(__t) | _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 888 "/usr/include/c++/v1/functional" 3


#if _LIBCPP_STD_VER > 11
template <class _Tp = void>
#else
# 893 "/usr/include/c++/v1/functional" 3
template <class _Tp>
#endif
# 895 "/usr/include/c++/v1/functional" 3
struct _LIBCPP_TYPE_VIS_ONLY bit_xor : binary_function<_Tp, _Tp, _Tp>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    _Tp operator()(const _Tp& __x, const _Tp& __y) const
        {return __x ^ __y;}
};

#if _LIBCPP_STD_VER > 11
template <>
struct _LIBCPP_TYPE_VIS_ONLY bit_xor<void>
{
    template <class _T1, class _T2>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_T1&& __t, _T2&& __u) const
        { return _VSTD::forward<_T1>(__t) ^ _VSTD::forward<_T2>(__u); }
    typedef void is_transparent;
};
#endif
# 913 "/usr/include/c++/v1/functional" 3


#if _LIBCPP_STD_VER > 11
template <class _Tp = void>
struct _LIBCPP_TYPE_VIS_ONLY bit_not : unary_function<_Tp, _Tp>
{
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    _Tp operator()(const _Tp& __x) const
        {return ~__x;}
};

template <>
struct _LIBCPP_TYPE_VIS_ONLY bit_not<void>
{
    template <class _Tp>
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    auto operator()(_Tp&& __x) const
        { return ~_VSTD::forward<_Tp>(__x); }
    typedef void is_transparent;
};
#endif
# 934 "/usr/include/c++/v1/functional" 3

template <class _Predicate>
class _LIBCPP_TYPE_VIS_ONLY unary_negate
    : public unary_function<typename _Predicate::argument_type, bool>
{
    _Predicate __pred_;
public:
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    explicit unary_negate(const _Predicate& __pred)
        : __pred_(__pred) {}
    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool operator()(const typename _Predicate::argument_type& __x) const
        {return !__pred_(__x);}
};

template <class _Predicate>
inline _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
unary_negate<_Predicate>
not1(const _Predicate& __pred) {return unary_negate<_Predicate>(__pred);}

template <class _Predicate>
class _LIBCPP_TYPE_VIS_ONLY binary_negate
    : public binary_function<typename _Predicate::first_argument_type,
                             typename _Predicate::second_argument_type,
                             bool>
{
    _Predicate __pred_;
public:
    _LIBCPP_INLINE_VISIBILITY explicit _LIBCPP_CONSTEXPR_AFTER_CXX11 
    binary_negate(const _Predicate& __pred) : __pred_(__pred) {}

    _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
    bool operator()(const typename _Predicate::first_argument_type& __x,
                    const typename _Predicate::second_argument_type& __y) const
        {return !__pred_(__x, __y);}
};

template <class _Predicate>
inline _LIBCPP_CONSTEXPR_AFTER_CXX11 _LIBCPP_INLINE_VISIBILITY
binary_negate<_Predicate>
not2(const _Predicate& __pred) {return binary_negate<_Predicate>(__pred);}

template <class __Operation>
class _LIBCPP_TYPE_VIS_ONLY binder1st
    : public unary_function<typename __Operation::second_argument_type,
                            typename __Operation::result_type>
{
protected:
    __Operation                               op;
    typename __Operation::first_argument_type value;
public:
    _LIBCPP_INLINE_VISIBILITY binder1st(const __Operation& __x,
                               const typename __Operation::first_argument_type __y)
        : op(__x), value(__y) {}
    _LIBCPP_INLINE_VISIBILITY typename __Operation::result_type operator()
        (typename __Operation::second_argument_type& __x) const
            {return op(value, __x);}
    _LIBCPP_INLINE_VISIBILITY typename __Operation::result_type operator()
        (const typename __Operation::second_argument_type& __x) const
            {return op(value, __x);}
};

template <class __Operation, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
binder1st<__Operation>
bind1st(const __Operation& __op, const _Tp& __x)
    {return binder1st<__Operation>(__op, __x);}

template <class __Operation>
class _LIBCPP_TYPE_VIS_ONLY binder2nd
    : public unary_function<typename __Operation::first_argument_type,
                            typename __Operation::result_type>
{
protected:
    __Operation                                op;
    typename __Operation::second_argument_type value;
public:
    _LIBCPP_INLINE_VISIBILITY
    binder2nd(const __Operation& __x, const typename __Operation::second_argument_type __y)
        : op(__x), value(__y) {}
    _LIBCPP_INLINE_VISIBILITY typename __Operation::result_type operator()
        (      typename __Operation::first_argument_type& __x) const
            {return op(__x, value);}
    _LIBCPP_INLINE_VISIBILITY typename __Operation::result_type operator()
        (const typename __Operation::first_argument_type& __x) const
            {return op(__x, value);}
};

template <class __Operation, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
binder2nd<__Operation>
bind2nd(const __Operation& __op, const _Tp& __x)
    {return binder2nd<__Operation>(__op, __x);}

template <class _Arg, class _Result>
class _LIBCPP_TYPE_VIS_ONLY pointer_to_unary_function
    : public unary_function<_Arg, _Result>
{
    _Result (*__f_)(_Arg);
public:
    _LIBCPP_INLINE_VISIBILITY explicit pointer_to_unary_function(_Result (*__f)(_Arg))
        : __f_(__f) {}
    _LIBCPP_INLINE_VISIBILITY _Result operator()(_Arg __x) const
        {return __f_(__x);}
};

template <class _Arg, class _Result>
inline _LIBCPP_INLINE_VISIBILITY
pointer_to_unary_function<_Arg,_Result>
ptr_fun(_Result (*__f)(_Arg))
    {return pointer_to_unary_function<_Arg,_Result>(__f);}

template <class _Arg1, class _Arg2, class _Result>
class _LIBCPP_TYPE_VIS_ONLY pointer_to_binary_function
    : public binary_function<_Arg1, _Arg2, _Result>
{
    _Result (*__f_)(_Arg1, _Arg2);
public:
    _LIBCPP_INLINE_VISIBILITY explicit pointer_to_binary_function(_Result (*__f)(_Arg1, _Arg2))
        : __f_(__f) {}
    _LIBCPP_INLINE_VISIBILITY _Result operator()(_Arg1 __x, _Arg2 __y) const
        {return __f_(__x, __y);}
};

template <class _Arg1, class _Arg2, class _Result>
inline _LIBCPP_INLINE_VISIBILITY
pointer_to_binary_function<_Arg1,_Arg2,_Result>
ptr_fun(_Result (*__f)(_Arg1,_Arg2))
    {return pointer_to_binary_function<_Arg1,_Arg2,_Result>(__f);}

template<class _Sp, class _Tp>
class _LIBCPP_TYPE_VIS_ONLY mem_fun_t : public unary_function<_Tp*, _Sp>
{
    _Sp (_Tp::*__p_)();
public:
    _LIBCPP_INLINE_VISIBILITY explicit mem_fun_t(_Sp (_Tp::*__p)())
        : __p_(__p) {}
    _LIBCPP_INLINE_VISIBILITY _Sp operator()(_Tp* __p) const
        {return (__p->*__p_)();}
};

template<class _Sp, class _Tp, class _Ap>
class _LIBCPP_TYPE_VIS_ONLY mem_fun1_t : public binary_function<_Tp*, _Ap, _Sp>
{
    _Sp (_Tp::*__p_)(_Ap);
public:
    _LIBCPP_INLINE_VISIBILITY explicit mem_fun1_t(_Sp (_Tp::*__p)(_Ap))
        : __p_(__p) {}
    _LIBCPP_INLINE_VISIBILITY _Sp operator()(_Tp* __p, _Ap __x) const
        {return (__p->*__p_)(__x);}
};

template<class _Sp, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
mem_fun_t<_Sp,_Tp>
mem_fun(_Sp (_Tp::*__f)())
    {return mem_fun_t<_Sp,_Tp>(__f);}

template<class _Sp, class _Tp, class _Ap>
inline _LIBCPP_INLINE_VISIBILITY
mem_fun1_t<_Sp,_Tp,_Ap>
mem_fun(_Sp (_Tp::*__f)(_Ap))
    {return mem_fun1_t<_Sp,_Tp,_Ap>(__f);}

template<class _Sp, class _Tp>
class _LIBCPP_TYPE_VIS_ONLY mem_fun_ref_t : public unary_function<_Tp, _Sp>
{
    _Sp (_Tp::*__p_)();
public:
    _LIBCPP_INLINE_VISIBILITY explicit mem_fun_ref_t(_Sp (_Tp::*__p)())
        : __p_(__p) {}
    _LIBCPP_INLINE_VISIBILITY _Sp operator()(_Tp& __p) const
        {return (__p.*__p_)();}
};

template<class _Sp, class _Tp, class _Ap>
class _LIBCPP_TYPE_VIS_ONLY mem_fun1_ref_t : public binary_function<_Tp, _Ap, _Sp>
{
    _Sp (_Tp::*__p_)(_Ap);
public:
    _LIBCPP_INLINE_VISIBILITY explicit mem_fun1_ref_t(_Sp (_Tp::*__p)(_Ap))
        : __p_(__p) {}
    _LIBCPP_INLINE_VISIBILITY _Sp operator()(_Tp& __p, _Ap __x) const
        {return (__p.*__p_)(__x);}
};

template<class _Sp, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
mem_fun_ref_t<_Sp,_Tp>
mem_fun_ref(_Sp (_Tp::*__f)())
    {return mem_fun_ref_t<_Sp,_Tp>(__f);}

template<class _Sp, class _Tp, class _Ap>
inline _LIBCPP_INLINE_VISIBILITY
mem_fun1_ref_t<_Sp,_Tp,_Ap>
mem_fun_ref(_Sp (_Tp::*__f)(_Ap))
    {return mem_fun1_ref_t<_Sp,_Tp,_Ap>(__f);}

template <class _Sp, class _Tp>
class _LIBCPP_TYPE_VIS_ONLY const_mem_fun_t : public unary_function<const _Tp*, _Sp>
{
    _Sp (_Tp::*__p_)() const;
public:
    _LIBCPP_INLINE_VISIBILITY explicit const_mem_fun_t(_Sp (_Tp::*__p)() const)
        : __p_(__p) {}
    _LIBCPP_INLINE_VISIBILITY _Sp operator()(const _Tp* __p) const
        {return (__p->*__p_)();}
};

template <class _Sp, class _Tp, class _Ap>
class _LIBCPP_TYPE_VIS_ONLY const_mem_fun1_t : public binary_function<const _Tp*, _Ap, _Sp>
{
    _Sp (_Tp::*__p_)(_Ap) const;
public:
    _LIBCPP_INLINE_VISIBILITY explicit const_mem_fun1_t(_Sp (_Tp::*__p)(_Ap) const)
        : __p_(__p) {}
    _LIBCPP_INLINE_VISIBILITY _Sp operator()(const _Tp* __p, _Ap __x) const
        {return (__p->*__p_)(__x);}
};

template <class _Sp, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
const_mem_fun_t<_Sp,_Tp>
mem_fun(_Sp (_Tp::*__f)() const)
    {return const_mem_fun_t<_Sp,_Tp>(__f);}

template <class _Sp, class _Tp, class _Ap>
inline _LIBCPP_INLINE_VISIBILITY
const_mem_fun1_t<_Sp,_Tp,_Ap>
mem_fun(_Sp (_Tp::*__f)(_Ap) const)
    {return const_mem_fun1_t<_Sp,_Tp,_Ap>(__f);}

template <class _Sp, class _Tp>
class _LIBCPP_TYPE_VIS_ONLY const_mem_fun_ref_t : public unary_function<_Tp, _Sp>
{
    _Sp (_Tp::*__p_)() const;
public:
    _LIBCPP_INLINE_VISIBILITY explicit const_mem_fun_ref_t(_Sp (_Tp::*__p)() const)
        : __p_(__p) {}
    _LIBCPP_INLINE_VISIBILITY _Sp operator()(const _Tp& __p) const
        {return (__p.*__p_)();}
};

template <class _Sp, class _Tp, class _Ap>
class _LIBCPP_TYPE_VIS_ONLY const_mem_fun1_ref_t
    : public binary_function<_Tp, _Ap, _Sp>
{
    _Sp (_Tp::*__p_)(_Ap) const;
public:
    _LIBCPP_INLINE_VISIBILITY explicit const_mem_fun1_ref_t(_Sp (_Tp::*__p)(_Ap) const)
        : __p_(__p) {}
    _LIBCPP_INLINE_VISIBILITY _Sp operator()(const _Tp& __p, _Ap __x) const
        {return (__p.*__p_)(__x);}
};

template <class _Sp, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
const_mem_fun_ref_t<_Sp,_Tp>
mem_fun_ref(_Sp (_Tp::*__f)() const)
    {return const_mem_fun_ref_t<_Sp,_Tp>(__f);}

template <class _Sp, class _Tp, class _Ap>
inline _LIBCPP_INLINE_VISIBILITY
const_mem_fun1_ref_t<_Sp,_Tp,_Ap>
mem_fun_ref(_Sp (_Tp::*__f)(_Ap) const)
    {return const_mem_fun1_ref_t<_Sp,_Tp,_Ap>(__f);}

#ifdef _LIBCPP_HAS_NO_VARIADICS

#if 0 /* expanded by -frewrite-includes */
#include <__functional_03>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/__functional_03" 1 3
// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_FUNCTIONAL_03
#define _LIBCPP_FUNCTIONAL_03

// manual variadic expansion for <functional>

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 18 "/usr/include/c++/v1/__functional_03" 3
#endif
# 19 "/usr/include/c++/v1/__functional_03" 3

template <class _Tp>
class __mem_fn
    : public __weak_result_type<_Tp>
{
public:
    // types
    typedef _Tp type;
private:
    type __f_;

public:
    _LIBCPP_INLINE_VISIBILITY __mem_fn(type __f) : __f_(__f) {}

    // invoke

    typename __invoke_return<type>::type
       operator() () const
       {
           return __invoke(__f_);
       }

    template <class _A0>
       typename __invoke_return0<type, _A0>::type
          operator() (_A0& __a0) const
          {
              return __invoke(__f_, __a0);
          }

    template <class _A0, class _A1>
       typename __invoke_return1<type, _A0, _A1>::type
          operator() (_A0& __a0, _A1& __a1) const
          {
              return __invoke(__f_, __a0, __a1);
          }

    template <class _A0, class _A1, class _A2>
       typename __invoke_return2<type, _A0, _A1, _A2>::type
          operator() (_A0& __a0, _A1& __a1, _A2& __a2) const
          {
              return __invoke(__f_, __a0, __a1, __a2);
          }
};

template<class _Rp, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
__mem_fn<_Rp _Tp::*>
mem_fn(_Rp _Tp::* __pm)
{
    return __mem_fn<_Rp _Tp::*>(__pm);
}

template<class _Rp, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
__mem_fn<_Rp (_Tp::*)()>
mem_fn(_Rp (_Tp::* __pm)())
{
    return __mem_fn<_Rp (_Tp::*)()>(__pm);
}

template<class _Rp, class _Tp, class _A0>
inline _LIBCPP_INLINE_VISIBILITY
__mem_fn<_Rp (_Tp::*)(_A0)>
mem_fn(_Rp (_Tp::* __pm)(_A0))
{
    return __mem_fn<_Rp (_Tp::*)(_A0)>(__pm);
}

template<class _Rp, class _Tp, class _A0, class _A1>
inline _LIBCPP_INLINE_VISIBILITY
__mem_fn<_Rp (_Tp::*)(_A0, _A1)>
mem_fn(_Rp (_Tp::* __pm)(_A0, _A1))
{
    return __mem_fn<_Rp (_Tp::*)(_A0, _A1)>(__pm);
}

template<class _Rp, class _Tp, class _A0, class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
__mem_fn<_Rp (_Tp::*)(_A0, _A1, _A2)>
mem_fn(_Rp (_Tp::* __pm)(_A0, _A1, _A2))
{
    return __mem_fn<_Rp (_Tp::*)(_A0, _A1, _A2)>(__pm);
}

template<class _Rp, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
__mem_fn<_Rp (_Tp::*)() const>
mem_fn(_Rp (_Tp::* __pm)() const)
{
    return __mem_fn<_Rp (_Tp::*)() const>(__pm);
}

template<class _Rp, class _Tp, class _A0>
inline _LIBCPP_INLINE_VISIBILITY
__mem_fn<_Rp (_Tp::*)(_A0) const>
mem_fn(_Rp (_Tp::* __pm)(_A0) const)
{
    return __mem_fn<_Rp (_Tp::*)(_A0) const>(__pm);
}

template<class _Rp, class _Tp, class _A0, class _A1>
inline _LIBCPP_INLINE_VISIBILITY
__mem_fn<_Rp (_Tp::*)(_A0, _A1) const>
mem_fn(_Rp (_Tp::* __pm)(_A0, _A1) const)
{
    return __mem_fn<_Rp (_Tp::*)(_A0, _A1) const>(__pm);
}

template<class _Rp, class _Tp, class _A0, class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
__mem_fn<_Rp (_Tp::*)(_A0, _A1, _A2) const>
mem_fn(_Rp (_Tp::* __pm)(_A0, _A1, _A2) const)
{
    return __mem_fn<_Rp (_Tp::*)(_A0, _A1, _A2) const>(__pm);
}

template<class _Rp, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
__mem_fn<_Rp (_Tp::*)() volatile>
mem_fn(_Rp (_Tp::* __pm)() volatile)
{
    return __mem_fn<_Rp (_Tp::*)() volatile>(__pm);
}

template<class _Rp, class _Tp, class _A0>
inline _LIBCPP_INLINE_VISIBILITY
__mem_fn<_Rp (_Tp::*)(_A0) volatile>
mem_fn(_Rp (_Tp::* __pm)(_A0) volatile)
{
    return __mem_fn<_Rp (_Tp::*)(_A0) volatile>(__pm);
}

template<class _Rp, class _Tp, class _A0, class _A1>
inline _LIBCPP_INLINE_VISIBILITY
__mem_fn<_Rp (_Tp::*)(_A0, _A1) volatile>
mem_fn(_Rp (_Tp::* __pm)(_A0, _A1) volatile)
{
    return __mem_fn<_Rp (_Tp::*)(_A0, _A1) volatile>(__pm);
}

template<class _Rp, class _Tp, class _A0, class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
__mem_fn<_Rp (_Tp::*)(_A0, _A1, _A2) volatile>
mem_fn(_Rp (_Tp::* __pm)(_A0, _A1, _A2) volatile)
{
    return __mem_fn<_Rp (_Tp::*)(_A0, _A1, _A2) volatile>(__pm);
}

template<class _Rp, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
__mem_fn<_Rp (_Tp::*)() const volatile>
mem_fn(_Rp (_Tp::* __pm)() const volatile)
{
    return __mem_fn<_Rp (_Tp::*)() const volatile>(__pm);
}

template<class _Rp, class _Tp, class _A0>
inline _LIBCPP_INLINE_VISIBILITY
__mem_fn<_Rp (_Tp::*)(_A0) const volatile>
mem_fn(_Rp (_Tp::* __pm)(_A0) const volatile)
{
    return __mem_fn<_Rp (_Tp::*)(_A0) const volatile>(__pm);
}

template<class _Rp, class _Tp, class _A0, class _A1>
inline _LIBCPP_INLINE_VISIBILITY
__mem_fn<_Rp (_Tp::*)(_A0, _A1) const volatile>
mem_fn(_Rp (_Tp::* __pm)(_A0, _A1) const volatile)
{
    return __mem_fn<_Rp (_Tp::*)(_A0, _A1) const volatile>(__pm);
}

template<class _Rp, class _Tp, class _A0, class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
__mem_fn<_Rp (_Tp::*)(_A0, _A1, _A2) const volatile>
mem_fn(_Rp (_Tp::* __pm)(_A0, _A1, _A2) const volatile)
{
    return __mem_fn<_Rp (_Tp::*)(_A0, _A1, _A2) const volatile>(__pm);
}

// bad_function_call

class _LIBCPP_EXCEPTION_ABI bad_function_call
    : public exception
{
};

template<class _Fp> class _LIBCPP_TYPE_VIS_ONLY function; // undefined

namespace __function
{

template<class _Fp>
struct __maybe_derive_from_unary_function
{
};

template<class _Rp, class _A1>
struct __maybe_derive_from_unary_function<_Rp(_A1)>
    : public unary_function<_A1, _Rp>
{
};

template<class _Fp>
struct __maybe_derive_from_binary_function
{
};

template<class _Rp, class _A1, class _A2>
struct __maybe_derive_from_binary_function<_Rp(_A1, _A2)>
    : public binary_function<_A1, _A2, _Rp>
{
};

template<class _Fp> class __base;

template<class _Rp>
class __base<_Rp()>
{
    __base(const __base&);
    __base& operator=(const __base&);
public:
    __base() {}
    virtual ~__base() {}
    virtual __base* __clone() const = 0;
    virtual void __clone(__base*) const = 0;
    virtual void destroy() = 0;
    virtual void destroy_deallocate() = 0;
    virtual _Rp operator()() = 0;
#ifndef _LIBCPP_NO_RTTI
    virtual const void* target(const type_info&) const = 0;
    virtual const std::type_info& target_type() const = 0;
#endif  // _LIBCPP_NO_RTTI
# 252 "/usr/include/c++/v1/__functional_03" 3
};

template<class _Rp, class _A0>
class __base<_Rp(_A0)>
{
    __base(const __base&);
    __base& operator=(const __base&);
public:
    __base() {}
    virtual ~__base() {}
    virtual __base* __clone() const = 0;
    virtual void __clone(__base*) const = 0;
    virtual void destroy() = 0;
    virtual void destroy_deallocate() = 0;
    virtual _Rp operator()(_A0) = 0;
#ifndef _LIBCPP_NO_RTTI
    virtual const void* target(const type_info&) const = 0;
    virtual const std::type_info& target_type() const = 0;
#endif  // _LIBCPP_NO_RTTI
# 271 "/usr/include/c++/v1/__functional_03" 3
};

template<class _Rp, class _A0, class _A1>
class __base<_Rp(_A0, _A1)>
{
    __base(const __base&);
    __base& operator=(const __base&);
public:
    __base() {}
    virtual ~__base() {}
    virtual __base* __clone() const = 0;
    virtual void __clone(__base*) const = 0;
    virtual void destroy() = 0;
    virtual void destroy_deallocate() = 0;
    virtual _Rp operator()(_A0, _A1) = 0;
#ifndef _LIBCPP_NO_RTTI
    virtual const void* target(const type_info&) const = 0;
    virtual const std::type_info& target_type() const = 0;
#endif  // _LIBCPP_NO_RTTI
# 290 "/usr/include/c++/v1/__functional_03" 3
};

template<class _Rp, class _A0, class _A1, class _A2>
class __base<_Rp(_A0, _A1, _A2)>
{
    __base(const __base&);
    __base& operator=(const __base&);
public:
    __base() {}
    virtual ~__base() {}
    virtual __base* __clone() const = 0;
    virtual void __clone(__base*) const = 0;
    virtual void destroy() = 0;
    virtual void destroy_deallocate() = 0;
    virtual _Rp operator()(_A0, _A1, _A2) = 0;
#ifndef _LIBCPP_NO_RTTI
    virtual const void* target(const type_info&) const = 0;
    virtual const std::type_info& target_type() const = 0;
#endif  // _LIBCPP_NO_RTTI
# 309 "/usr/include/c++/v1/__functional_03" 3
};

template<class _FD, class _Alloc, class _FB> class __func;

template<class _Fp, class _Alloc, class _Rp>
class __func<_Fp, _Alloc, _Rp()>
    : public  __base<_Rp()>
{
    __compressed_pair<_Fp, _Alloc> __f_;
public:
    explicit __func(_Fp __f) : __f_(_VSTD::move(__f)) {}
    explicit __func(_Fp __f, _Alloc __a) : __f_(_VSTD::move(__f), _VSTD::move(__a)) {}
    virtual __base<_Rp()>* __clone() const;
    virtual void __clone(__base<_Rp()>*) const;
    virtual void destroy();
    virtual void destroy_deallocate();
    virtual _Rp operator()();
#ifndef _LIBCPP_NO_RTTI
    virtual const void* target(const type_info&) const;
    virtual const std::type_info& target_type() const;
#endif  // _LIBCPP_NO_RTTI
# 330 "/usr/include/c++/v1/__functional_03" 3
};

template<class _Fp, class _Alloc, class _Rp>
__base<_Rp()>*
__func<_Fp, _Alloc, _Rp()>::__clone() const
{
    typedef typename _Alloc::template rebind<__func>::other _Ap;
    _Ap __a(__f_.second());
    typedef __allocator_destructor<_Ap> _Dp;
    unique_ptr<__func, _Dp> __hold(__a.allocate(1), _Dp(__a, 1));
    ::new (__hold.get()) __func(__f_.first(), _Alloc(__a));
    return __hold.release();
}

template<class _Fp, class _Alloc, class _Rp>
void
__func<_Fp, _Alloc, _Rp()>::__clone(__base<_Rp()>* __p) const
{
    ::new (__p) __func(__f_.first(), __f_.second());
}

template<class _Fp, class _Alloc, class _Rp>
void
__func<_Fp, _Alloc, _Rp()>::destroy()
{
    __f_.~__compressed_pair<_Fp, _Alloc>();
}

template<class _Fp, class _Alloc, class _Rp>
void
__func<_Fp, _Alloc, _Rp()>::destroy_deallocate()
{
    typedef typename _Alloc::template rebind<__func>::other _Ap;
    _Ap __a(__f_.second());
    __f_.~__compressed_pair<_Fp, _Alloc>();
    __a.deallocate(this, 1);
}

template<class _Fp, class _Alloc, class _Rp>
_Rp
__func<_Fp, _Alloc, _Rp()>::operator()()
{
    return __invoke(__f_.first());
}

#ifndef _LIBCPP_NO_RTTI

template<class _Fp, class _Alloc, class _Rp>
const void*
__func<_Fp, _Alloc, _Rp()>::target(const type_info& __ti) const
{
    if (__ti == typeid(_Fp))
        return &__f_.first();
    return (const void*)0;
}

template<class _Fp, class _Alloc, class _Rp>
const std::type_info&
__func<_Fp, _Alloc, _Rp()>::target_type() const
{
    return typeid(_Fp);
}

#endif  // _LIBCPP_NO_RTTI
# 394 "/usr/include/c++/v1/__functional_03" 3

template<class _Fp, class _Alloc, class _Rp, class _A0>
class __func<_Fp, _Alloc, _Rp(_A0)>
    : public  __base<_Rp(_A0)>
{
    __compressed_pair<_Fp, _Alloc> __f_;
public:
    _LIBCPP_INLINE_VISIBILITY explicit __func(_Fp __f) : __f_(_VSTD::move(__f)) {}
    _LIBCPP_INLINE_VISIBILITY explicit __func(_Fp __f, _Alloc __a)
        : __f_(_VSTD::move(__f), _VSTD::move(__a)) {}
    virtual __base<_Rp(_A0)>* __clone() const;
    virtual void __clone(__base<_Rp(_A0)>*) const;
    virtual void destroy();
    virtual void destroy_deallocate();
    virtual _Rp operator()(_A0);
#ifndef _LIBCPP_NO_RTTI
    virtual const void* target(const type_info&) const;
    virtual const std::type_info& target_type() const;
#endif  // _LIBCPP_NO_RTTI
# 413 "/usr/include/c++/v1/__functional_03" 3
};

template<class _Fp, class _Alloc, class _Rp, class _A0>
__base<_Rp(_A0)>*
__func<_Fp, _Alloc, _Rp(_A0)>::__clone() const
{
    typedef typename _Alloc::template rebind<__func>::other _Ap;
    _Ap __a(__f_.second());
    typedef __allocator_destructor<_Ap> _Dp;
    unique_ptr<__func, _Dp> __hold(__a.allocate(1), _Dp(__a, 1));
    ::new (__hold.get()) __func(__f_.first(), _Alloc(__a));
    return __hold.release();
}

template<class _Fp, class _Alloc, class _Rp, class _A0>
void
__func<_Fp, _Alloc, _Rp(_A0)>::__clone(__base<_Rp(_A0)>* __p) const
{
    ::new (__p) __func(__f_.first(), __f_.second());
}

template<class _Fp, class _Alloc, class _Rp, class _A0>
void
__func<_Fp, _Alloc, _Rp(_A0)>::destroy()
{
    __f_.~__compressed_pair<_Fp, _Alloc>();
}

template<class _Fp, class _Alloc, class _Rp, class _A0>
void
__func<_Fp, _Alloc, _Rp(_A0)>::destroy_deallocate()
{
    typedef typename _Alloc::template rebind<__func>::other _Ap;
    _Ap __a(__f_.second());
    __f_.~__compressed_pair<_Fp, _Alloc>();
    __a.deallocate(this, 1);
}

template<class _Fp, class _Alloc, class _Rp, class _A0>
_Rp
__func<_Fp, _Alloc, _Rp(_A0)>::operator()(_A0 __a0)
{
    return __invoke(__f_.first(), __a0);
}

#ifndef _LIBCPP_NO_RTTI

template<class _Fp, class _Alloc, class _Rp, class _A0>
const void*
__func<_Fp, _Alloc, _Rp(_A0)>::target(const type_info& __ti) const
{
    if (__ti == typeid(_Fp))
        return &__f_.first();
    return (const void*)0;
}

template<class _Fp, class _Alloc, class _Rp, class _A0>
const std::type_info&
__func<_Fp, _Alloc, _Rp(_A0)>::target_type() const
{
    return typeid(_Fp);
}

#endif  // _LIBCPP_NO_RTTI
# 477 "/usr/include/c++/v1/__functional_03" 3

template<class _Fp, class _Alloc, class _Rp, class _A0, class _A1>
class __func<_Fp, _Alloc, _Rp(_A0, _A1)>
    : public  __base<_Rp(_A0, _A1)>
{
    __compressed_pair<_Fp, _Alloc> __f_;
public:
    _LIBCPP_INLINE_VISIBILITY explicit __func(_Fp __f) : __f_(_VSTD::move(__f)) {}
    _LIBCPP_INLINE_VISIBILITY explicit __func(_Fp __f, _Alloc __a)
        : __f_(_VSTD::move(__f), _VSTD::move(__a)) {}
    virtual __base<_Rp(_A0, _A1)>* __clone() const;
    virtual void __clone(__base<_Rp(_A0, _A1)>*) const;
    virtual void destroy();
    virtual void destroy_deallocate();
    virtual _Rp operator()(_A0, _A1);
#ifndef _LIBCPP_NO_RTTI
    virtual const void* target(const type_info&) const;
    virtual const std::type_info& target_type() const;
#endif  // _LIBCPP_NO_RTTI
# 496 "/usr/include/c++/v1/__functional_03" 3
};

template<class _Fp, class _Alloc, class _Rp, class _A0, class _A1>
__base<_Rp(_A0, _A1)>*
__func<_Fp, _Alloc, _Rp(_A0, _A1)>::__clone() const
{
    typedef typename _Alloc::template rebind<__func>::other _Ap;
    _Ap __a(__f_.second());
    typedef __allocator_destructor<_Ap> _Dp;
    unique_ptr<__func, _Dp> __hold(__a.allocate(1), _Dp(__a, 1));
    ::new (__hold.get()) __func(__f_.first(), _Alloc(__a));
    return __hold.release();
}

template<class _Fp, class _Alloc, class _Rp, class _A0, class _A1>
void
__func<_Fp, _Alloc, _Rp(_A0, _A1)>::__clone(__base<_Rp(_A0, _A1)>* __p) const
{
    ::new (__p) __func(__f_.first(), __f_.second());
}

template<class _Fp, class _Alloc, class _Rp, class _A0, class _A1>
void
__func<_Fp, _Alloc, _Rp(_A0, _A1)>::destroy()
{
    __f_.~__compressed_pair<_Fp, _Alloc>();
}

template<class _Fp, class _Alloc, class _Rp, class _A0, class _A1>
void
__func<_Fp, _Alloc, _Rp(_A0, _A1)>::destroy_deallocate()
{
    typedef typename _Alloc::template rebind<__func>::other _Ap;
    _Ap __a(__f_.second());
    __f_.~__compressed_pair<_Fp, _Alloc>();
    __a.deallocate(this, 1);
}

template<class _Fp, class _Alloc, class _Rp, class _A0, class _A1>
_Rp
__func<_Fp, _Alloc, _Rp(_A0, _A1)>::operator()(_A0 __a0, _A1 __a1)
{
    return __invoke(__f_.first(), __a0, __a1);
}

#ifndef _LIBCPP_NO_RTTI

template<class _Fp, class _Alloc, class _Rp, class _A0, class _A1>
const void*
__func<_Fp, _Alloc, _Rp(_A0, _A1)>::target(const type_info& __ti) const
{
    if (__ti == typeid(_Fp))
        return &__f_.first();
    return (const void*)0;
}

template<class _Fp, class _Alloc, class _Rp, class _A0, class _A1>
const std::type_info&
__func<_Fp, _Alloc, _Rp(_A0, _A1)>::target_type() const
{
    return typeid(_Fp);
}

#endif  // _LIBCPP_NO_RTTI
# 560 "/usr/include/c++/v1/__functional_03" 3

template<class _Fp, class _Alloc, class _Rp, class _A0, class _A1, class _A2>
class __func<_Fp, _Alloc, _Rp(_A0, _A1, _A2)>
    : public  __base<_Rp(_A0, _A1, _A2)>
{
    __compressed_pair<_Fp, _Alloc> __f_;
public:
    _LIBCPP_INLINE_VISIBILITY explicit __func(_Fp __f) : __f_(_VSTD::move(__f)) {}
    _LIBCPP_INLINE_VISIBILITY explicit __func(_Fp __f, _Alloc __a)
        : __f_(_VSTD::move(__f), _VSTD::move(__a)) {}
    virtual __base<_Rp(_A0, _A1, _A2)>* __clone() const;
    virtual void __clone(__base<_Rp(_A0, _A1, _A2)>*) const;
    virtual void destroy();
    virtual void destroy_deallocate();
    virtual _Rp operator()(_A0, _A1, _A2);
#ifndef _LIBCPP_NO_RTTI
    virtual const void* target(const type_info&) const;
    virtual const std::type_info& target_type() const;
#endif  // _LIBCPP_NO_RTTI
# 579 "/usr/include/c++/v1/__functional_03" 3
};

template<class _Fp, class _Alloc, class _Rp, class _A0, class _A1, class _A2>
__base<_Rp(_A0, _A1, _A2)>*
__func<_Fp, _Alloc, _Rp(_A0, _A1, _A2)>::__clone() const
{
    typedef typename _Alloc::template rebind<__func>::other _Ap;
    _Ap __a(__f_.second());
    typedef __allocator_destructor<_Ap> _Dp;
    unique_ptr<__func, _Dp> __hold(__a.allocate(1), _Dp(__a, 1));
    ::new (__hold.get()) __func(__f_.first(), _Alloc(__a));
    return __hold.release();
}

template<class _Fp, class _Alloc, class _Rp, class _A0, class _A1, class _A2>
void
__func<_Fp, _Alloc, _Rp(_A0, _A1, _A2)>::__clone(__base<_Rp(_A0, _A1, _A2)>* __p) const
{
    ::new (__p) __func(__f_.first(), __f_.second());
}

template<class _Fp, class _Alloc, class _Rp, class _A0, class _A1, class _A2>
void
__func<_Fp, _Alloc, _Rp(_A0, _A1, _A2)>::destroy()
{
    __f_.~__compressed_pair<_Fp, _Alloc>();
}

template<class _Fp, class _Alloc, class _Rp, class _A0, class _A1, class _A2>
void
__func<_Fp, _Alloc, _Rp(_A0, _A1, _A2)>::destroy_deallocate()
{
    typedef typename _Alloc::template rebind<__func>::other _Ap;
    _Ap __a(__f_.second());
    __f_.~__compressed_pair<_Fp, _Alloc>();
    __a.deallocate(this, 1);
}

template<class _Fp, class _Alloc, class _Rp, class _A0, class _A1, class _A2>
_Rp
__func<_Fp, _Alloc, _Rp(_A0, _A1, _A2)>::operator()(_A0 __a0, _A1 __a1, _A2 __a2)
{
    return __invoke(__f_.first(), __a0, __a1, __a2);
}

#ifndef _LIBCPP_NO_RTTI

template<class _Fp, class _Alloc, class _Rp, class _A0, class _A1, class _A2>
const void*
__func<_Fp, _Alloc, _Rp(_A0, _A1, _A2)>::target(const type_info& __ti) const
{
    if (__ti == typeid(_Fp))
        return &__f_.first();
    return (const void*)0;
}

template<class _Fp, class _Alloc, class _Rp, class _A0, class _A1, class _A2>
const std::type_info&
__func<_Fp, _Alloc, _Rp(_A0, _A1, _A2)>::target_type() const
{
    return typeid(_Fp);
}

#endif  // _LIBCPP_NO_RTTI
# 643 "/usr/include/c++/v1/__functional_03" 3

}  // __function

template<class _Rp>
class _LIBCPP_TYPE_VIS_ONLY function<_Rp()>
{
    typedef __function::__base<_Rp()> __base;
    aligned_storage<3*sizeof(void*)>::type __buf_;
    __base* __f_;

    template <class _Fp>
        static bool __not_null(const _Fp&) {return true;}
    template <class _R2>
        static bool __not_null(const function<_Rp()>& __p) {return __p;}
public:
    typedef _Rp result_type;

    // 20.7.16.2.1, construct/copy/destroy:
    _LIBCPP_INLINE_VISIBILITY explicit function() : __f_(0) {}
    _LIBCPP_INLINE_VISIBILITY function(nullptr_t) : __f_(0) {}
    function(const function&);
    template<class _Fp>
      function(_Fp,
               typename enable_if<!is_integral<_Fp>::value>::type* = 0);

    template<class _Alloc>
      _LIBCPP_INLINE_VISIBILITY
      function(allocator_arg_t, const _Alloc&) : __f_(0) {}
    template<class _Alloc>
      _LIBCPP_INLINE_VISIBILITY
      function(allocator_arg_t, const _Alloc&, nullptr_t) : __f_(0) {}
    template<class _Alloc>
      function(allocator_arg_t, const _Alloc&, const function&);
    template<class _Fp, class _Alloc>
      function(allocator_arg_t, const _Alloc& __a, _Fp __f,
               typename enable_if<!is_integral<_Fp>::value>::type* = 0);

    function& operator=(const function&);
    function& operator=(nullptr_t);
    template<class _Fp>
      typename enable_if
      <
        !is_integral<_Fp>::value,
        function&
      >::type
      operator=(_Fp);

    ~function();

    // 20.7.16.2.2, function modifiers:
    void swap(function&);
    template<class _Fp, class _Alloc>
      _LIBCPP_INLINE_VISIBILITY
      void assign(_Fp __f, const _Alloc& __a)
        {function(allocator_arg, __a, __f).swap(*this);}

    // 20.7.16.2.3, function capacity:
    _LIBCPP_INLINE_VISIBILITY operator bool() const {return __f_;}

private:
    // deleted overloads close possible hole in the type system
    template<class _R2>
      bool operator==(const function<_R2()>&) const;// = delete;
    template<class _R2>
      bool operator!=(const function<_R2()>&) const;// = delete;
public:
    // 20.7.16.2.4, function invocation:
    _Rp operator()() const;

#ifndef _LIBCPP_NO_RTTI
    // 20.7.16.2.5, function target access:
    const std::type_info& target_type() const;
    template <typename _Tp> _Tp* target();
    template <typename _Tp> const _Tp* target() const;
#endif  // _LIBCPP_NO_RTTI
# 718 "/usr/include/c++/v1/__functional_03" 3
};

template<class _Rp>
function<_Rp()>::function(const function& __f)
{
    if (__f.__f_ == 0)
        __f_ = 0;
    else if (__f.__f_ == (const __base*)&__f.__buf_)
    {
        __f_ = (__base*)&__buf_;
        __f.__f_->__clone(__f_);
    }
    else
        __f_ = __f.__f_->__clone();
}

template<class _Rp>
template<class _Alloc>
function<_Rp()>::function(allocator_arg_t, const _Alloc&, const function& __f)
{
    if (__f.__f_ == 0)
        __f_ = 0;
    else if (__f.__f_ == (const __base*)&__f.__buf_)
    {
        __f_ = (__base*)&__buf_;
        __f.__f_->__clone(__f_);
    }
    else
        __f_ = __f.__f_->__clone();
}

template<class _Rp>
template <class _Fp>
function<_Rp()>::function(_Fp __f,
                                     typename enable_if<!is_integral<_Fp>::value>::type*)
    : __f_(0)
{
    if (__not_null(__f))
    {
        typedef __function::__func<_Fp, allocator<_Fp>, _Rp()> _FF;
        if (sizeof(_FF) <= sizeof(__buf_))
        {
            __f_ = (__base*)&__buf_;
            ::new (__f_) _FF(__f);
        }
        else
        {
            typedef allocator<_FF> _Ap;
            _Ap __a;
            typedef __allocator_destructor<_Ap> _Dp;
            unique_ptr<__base, _Dp> __hold(__a.allocate(1), _Dp(__a, 1));
            ::new (__hold.get()) _FF(__f, allocator<_Fp>(__a));
            __f_ = __hold.release();
        }
    }
}

template<class _Rp>
template <class _Fp, class _Alloc>
function<_Rp()>::function(allocator_arg_t, const _Alloc& __a0, _Fp __f,
                                     typename enable_if<!is_integral<_Fp>::value>::type*)
    : __f_(0)
{
    typedef allocator_traits<_Alloc> __alloc_traits;
    if (__not_null(__f))
    {
        typedef __function::__func<_Fp, _Alloc, _Rp()> _FF;
        if (sizeof(_FF) <= sizeof(__buf_))
        {
            __f_ = (__base*)&__buf_;
            ::new (__f_) _FF(__f);
        }
        else
        {
            typedef typename __alloc_traits::template
#ifndef _LIBCPP_HAS_NO_TEMPLATE_ALIASES
                rebind_alloc<_FF>
#else
# 796 "/usr/include/c++/v1/__functional_03" 3
                rebind_alloc<_FF>::other
#endif
# 798 "/usr/include/c++/v1/__functional_03" 3
                                                         _Ap;
            _Ap __a(__a0);
            typedef __allocator_destructor<_Ap> _Dp;
            unique_ptr<__base, _Dp> __hold(__a.allocate(1), _Dp(__a, 1));
            ::new (__hold.get()) _FF(__f, _Alloc(__a));
            __f_ = __hold.release();
        }
    }
}

template<class _Rp>
function<_Rp()>&
function<_Rp()>::operator=(const function& __f)
{
    function(__f).swap(*this);
    return *this;
}

template<class _Rp>
function<_Rp()>&
function<_Rp()>::operator=(nullptr_t)
{
    if (__f_ == (__base*)&__buf_)
        __f_->destroy();
    else if (__f_)
        __f_->destroy_deallocate();
    __f_ = 0;
}

template<class _Rp>
template <class _Fp>
typename enable_if
<
    !is_integral<_Fp>::value,
    function<_Rp()>&
>::type
function<_Rp()>::operator=(_Fp __f)
{
    function(_VSTD::move(__f)).swap(*this);
    return *this;
}

template<class _Rp>
function<_Rp()>::~function()
{
    if (__f_ == (__base*)&__buf_)
        __f_->destroy();
    else if (__f_)
        __f_->destroy_deallocate();
}

template<class _Rp>
void
function<_Rp()>::swap(function& __f)
{
    if (__f_ == (__base*)&__buf_ && __f.__f_ == (__base*)&__f.__buf_)
    {
        typename aligned_storage<sizeof(__buf_)>::type __tempbuf;
        __base* __t = (__base*)&__tempbuf;
        __f_->__clone(__t);
        __f_->destroy();
        __f_ = 0;
        __f.__f_->__clone((__base*)&__buf_);
        __f.__f_->destroy();
        __f.__f_ = 0;
        __f_ = (__base*)&__buf_;
        __t->__clone((__base*)&__f.__buf_);
        __t->destroy();
        __f.__f_ = (__base*)&__f.__buf_;
    }
    else if (__f_ == (__base*)&__buf_)
    {
        __f_->__clone((__base*)&__f.__buf_);
        __f_->destroy();
        __f_ = __f.__f_;
        __f.__f_ = (__base*)&__f.__buf_;
    }
    else if (__f.__f_ == (__base*)&__f.__buf_)
    {
        __f.__f_->__clone((__base*)&__buf_);
        __f.__f_->destroy();
        __f.__f_ = __f_;
        __f_ = (__base*)&__buf_;
    }
    else
        _VSTD::swap(__f_, __f.__f_);
}

template<class _Rp>
_Rp
function<_Rp()>::operator()() const
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    if (__f_ == 0)
        throw bad_function_call();
#endif  // _LIBCPP_NO_EXCEPTIONS
# 894 "/usr/include/c++/v1/__functional_03" 3
    return (*__f_)();
}

#ifndef _LIBCPP_NO_RTTI

template<class _Rp>
const std::type_info&
function<_Rp()>::target_type() const
{
    if (__f_ == 0)
        return typeid(void);
    return __f_->target_type();
}

template<class _Rp>
template <typename _Tp>
_Tp*
function<_Rp()>::target()
{
    if (__f_ == 0)
        return (_Tp*)0;
    return (_Tp*)__f_->target(typeid(_Tp));
}

template<class _Rp>
template <typename _Tp>
const _Tp*
function<_Rp()>::target() const
{
    if (__f_ == 0)
        return (const _Tp*)0;
    return (const _Tp*)__f_->target(typeid(_Tp));
}

#endif  // _LIBCPP_NO_RTTI
# 929 "/usr/include/c++/v1/__functional_03" 3

template<class _Rp, class _A0>
class _LIBCPP_TYPE_VIS_ONLY function<_Rp(_A0)>
    : public unary_function<_A0, _Rp>
{
    typedef __function::__base<_Rp(_A0)> __base;
    aligned_storage<3*sizeof(void*)>::type __buf_;
    __base* __f_;

    template <class _Fp>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(const _Fp&) {return true;}
    template <class _R2, class _B0>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(_R2 (*__p)(_B0)) {return __p;}
    template <class _R2, class _Cp>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(_R2 (_Cp::*__p)()) {return __p;}
    template <class _R2, class _Cp>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(_R2 (_Cp::*__p)() const) {return __p;}
    template <class _R2, class _Cp>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(_R2 (_Cp::*__p)() volatile) {return __p;}
    template <class _R2, class _Cp>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(_R2 (_Cp::*__p)() const volatile) {return __p;}
    template <class _R2, class _B0>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(const function<_Rp(_B0)>& __p) {return __p;}
public:
    typedef _Rp result_type;

    // 20.7.16.2.1, construct/copy/destroy:
    _LIBCPP_INLINE_VISIBILITY explicit function() : __f_(0) {}
    _LIBCPP_INLINE_VISIBILITY function(nullptr_t) : __f_(0) {}
    function(const function&);
    template<class _Fp>
      function(_Fp,
               typename enable_if<!is_integral<_Fp>::value>::type* = 0);

    template<class _Alloc>
      _LIBCPP_INLINE_VISIBILITY
      function(allocator_arg_t, const _Alloc&) : __f_(0) {}
    template<class _Alloc>
      _LIBCPP_INLINE_VISIBILITY
      function(allocator_arg_t, const _Alloc&, nullptr_t) : __f_(0) {}
    template<class _Alloc>
      function(allocator_arg_t, const _Alloc&, const function&);
    template<class _Fp, class _Alloc>
      function(allocator_arg_t, const _Alloc& __a, _Fp __f,
               typename enable_if<!is_integral<_Fp>::value>::type* = 0);

    function& operator=(const function&);
    function& operator=(nullptr_t);
    template<class _Fp>
      typename enable_if
      <
        !is_integral<_Fp>::value,
        function&
      >::type
      operator=(_Fp);

    ~function();

    // 20.7.16.2.2, function modifiers:
    void swap(function&);
    template<class _Fp, class _Alloc>
      _LIBCPP_INLINE_VISIBILITY
      void assign(_Fp __f, const _Alloc& __a)
        {function(allocator_arg, __a, __f).swap(*this);}

    // 20.7.16.2.3, function capacity:
    _LIBCPP_INLINE_VISIBILITY operator bool() const {return __f_;}

private:
    // deleted overloads close possible hole in the type system
    template<class _R2, class _B0>
      bool operator==(const function<_R2(_B0)>&) const;// = delete;
    template<class _R2, class _B0>
      bool operator!=(const function<_R2(_B0)>&) const;// = delete;
public:
    // 20.7.16.2.4, function invocation:
    _Rp operator()(_A0) const;

#ifndef _LIBCPP_NO_RTTI
    // 20.7.16.2.5, function target access:
    const std::type_info& target_type() const;
    template <typename _Tp> _Tp* target();
    template <typename _Tp> const _Tp* target() const;
#endif  // _LIBCPP_NO_RTTI
# 1020 "/usr/include/c++/v1/__functional_03" 3
};

template<class _Rp, class _A0>
function<_Rp(_A0)>::function(const function& __f)
{
    if (__f.__f_ == 0)
        __f_ = 0;
    else if (__f.__f_ == (const __base*)&__f.__buf_)
    {
        __f_ = (__base*)&__buf_;
        __f.__f_->__clone(__f_);
    }
    else
        __f_ = __f.__f_->__clone();
}

template<class _Rp, class _A0>
template<class _Alloc>
function<_Rp(_A0)>::function(allocator_arg_t, const _Alloc&, const function& __f)
{
    if (__f.__f_ == 0)
        __f_ = 0;
    else if (__f.__f_ == (const __base*)&__f.__buf_)
    {
        __f_ = (__base*)&__buf_;
        __f.__f_->__clone(__f_);
    }
    else
        __f_ = __f.__f_->__clone();
}

template<class _Rp, class _A0>
template <class _Fp>
function<_Rp(_A0)>::function(_Fp __f,
                                     typename enable_if<!is_integral<_Fp>::value>::type*)
    : __f_(0)
{
    if (__not_null(__f))
    {
        typedef __function::__func<_Fp, allocator<_Fp>, _Rp(_A0)> _FF;
        if (sizeof(_FF) <= sizeof(__buf_))
        {
            __f_ = (__base*)&__buf_;
            ::new (__f_) _FF(__f);
        }
        else
        {
            typedef allocator<_FF> _Ap;
            _Ap __a;
            typedef __allocator_destructor<_Ap> _Dp;
            unique_ptr<__base, _Dp> __hold(__a.allocate(1), _Dp(__a, 1));
            ::new (__hold.get()) _FF(__f, allocator<_Fp>(__a));
            __f_ = __hold.release();
        }
    }
}

template<class _Rp, class _A0>
template <class _Fp, class _Alloc>
function<_Rp(_A0)>::function(allocator_arg_t, const _Alloc& __a0, _Fp __f,
                                     typename enable_if<!is_integral<_Fp>::value>::type*)
    : __f_(0)
{
    typedef allocator_traits<_Alloc> __alloc_traits;
    if (__not_null(__f))
    {
        typedef __function::__func<_Fp, _Alloc, _Rp(_A0)> _FF;
        if (sizeof(_FF) <= sizeof(__buf_))
        {
            __f_ = (__base*)&__buf_;
            ::new (__f_) _FF(__f);
        }
        else
        {
            typedef typename __alloc_traits::template
#ifndef _LIBCPP_HAS_NO_TEMPLATE_ALIASES
                rebind_alloc<_FF>
#else
# 1098 "/usr/include/c++/v1/__functional_03" 3
                rebind_alloc<_FF>::other
#endif
# 1100 "/usr/include/c++/v1/__functional_03" 3
                                                         _Ap;
            _Ap __a(__a0);
            typedef __allocator_destructor<_Ap> _Dp;
            unique_ptr<__base, _Dp> __hold(__a.allocate(1), _Dp(__a, 1));
            ::new (__hold.get()) _FF(__f, _Alloc(__a));
            __f_ = __hold.release();
        }
    }
}

template<class _Rp, class _A0>
function<_Rp(_A0)>&
function<_Rp(_A0)>::operator=(const function& __f)
{
    function(__f).swap(*this);
    return *this;
}

template<class _Rp, class _A0>
function<_Rp(_A0)>&
function<_Rp(_A0)>::operator=(nullptr_t)
{
    if (__f_ == (__base*)&__buf_)
        __f_->destroy();
    else if (__f_)
        __f_->destroy_deallocate();
    __f_ = 0;
}

template<class _Rp, class _A0>
template <class _Fp>
typename enable_if
<
    !is_integral<_Fp>::value,
    function<_Rp(_A0)>&
>::type
function<_Rp(_A0)>::operator=(_Fp __f)
{
    function(_VSTD::move(__f)).swap(*this);
    return *this;
}

template<class _Rp, class _A0>
function<_Rp(_A0)>::~function()
{
    if (__f_ == (__base*)&__buf_)
        __f_->destroy();
    else if (__f_)
        __f_->destroy_deallocate();
}

template<class _Rp, class _A0>
void
function<_Rp(_A0)>::swap(function& __f)
{
    if (__f_ == (__base*)&__buf_ && __f.__f_ == (__base*)&__f.__buf_)
    {
        typename aligned_storage<sizeof(__buf_)>::type __tempbuf;
        __base* __t = (__base*)&__tempbuf;
        __f_->__clone(__t);
        __f_->destroy();
        __f_ = 0;
        __f.__f_->__clone((__base*)&__buf_);
        __f.__f_->destroy();
        __f.__f_ = 0;
        __f_ = (__base*)&__buf_;
        __t->__clone((__base*)&__f.__buf_);
        __t->destroy();
        __f.__f_ = (__base*)&__f.__buf_;
    }
    else if (__f_ == (__base*)&__buf_)
    {
        __f_->__clone((__base*)&__f.__buf_);
        __f_->destroy();
        __f_ = __f.__f_;
        __f.__f_ = (__base*)&__f.__buf_;
    }
    else if (__f.__f_ == (__base*)&__f.__buf_)
    {
        __f.__f_->__clone((__base*)&__buf_);
        __f.__f_->destroy();
        __f.__f_ = __f_;
        __f_ = (__base*)&__buf_;
    }
    else
        _VSTD::swap(__f_, __f.__f_);
}

template<class _Rp, class _A0>
_Rp
function<_Rp(_A0)>::operator()(_A0 __a0) const
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    if (__f_ == 0)
        throw bad_function_call();
#endif  // _LIBCPP_NO_EXCEPTIONS
# 1196 "/usr/include/c++/v1/__functional_03" 3
    return (*__f_)(__a0);
}

#ifndef _LIBCPP_NO_RTTI

template<class _Rp, class _A0>
const std::type_info&
function<_Rp(_A0)>::target_type() const
{
    if (__f_ == 0)
        return typeid(void);
    return __f_->target_type();
}

template<class _Rp, class _A0>
template <typename _Tp>
_Tp*
function<_Rp(_A0)>::target()
{
    if (__f_ == 0)
        return (_Tp*)0;
    return (_Tp*)__f_->target(typeid(_Tp));
}

template<class _Rp, class _A0>
template <typename _Tp>
const _Tp*
function<_Rp(_A0)>::target() const
{
    if (__f_ == 0)
        return (const _Tp*)0;
    return (const _Tp*)__f_->target(typeid(_Tp));
}

#endif  // _LIBCPP_NO_RTTI
# 1231 "/usr/include/c++/v1/__functional_03" 3

template<class _Rp, class _A0, class _A1>
class _LIBCPP_TYPE_VIS_ONLY function<_Rp(_A0, _A1)>
    : public binary_function<_A0, _A1, _Rp>
{
    typedef __function::__base<_Rp(_A0, _A1)> __base;
    aligned_storage<3*sizeof(void*)>::type __buf_;
    __base* __f_;

    template <class _Fp>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(const _Fp&) {return true;}
    template <class _R2, class _B0, class _B1>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(_R2 (*__p)(_B0, _B1)) {return __p;}
    template <class _R2, class _Cp, class _B1>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(_R2 (_Cp::*__p)(_B1)) {return __p;}
    template <class _R2, class _Cp, class _B1>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(_R2 (_Cp::*__p)(_B1) const) {return __p;}
    template <class _R2, class _Cp, class _B1>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(_R2 (_Cp::*__p)(_B1) volatile) {return __p;}
    template <class _R2, class _Cp, class _B1>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(_R2 (_Cp::*__p)(_B1) const volatile) {return __p;}
    template <class _R2, class _B0, class _B1>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(const function<_Rp(_B0, _B1)>& __p) {return __p;}
public:
    typedef _Rp result_type;

    // 20.7.16.2.1, construct/copy/destroy:
    _LIBCPP_INLINE_VISIBILITY explicit function() : __f_(0) {}
    _LIBCPP_INLINE_VISIBILITY function(nullptr_t) : __f_(0) {}
    function(const function&);
    template<class _Fp>
      function(_Fp,
               typename enable_if<!is_integral<_Fp>::value>::type* = 0);

    template<class _Alloc>
      _LIBCPP_INLINE_VISIBILITY
      function(allocator_arg_t, const _Alloc&) : __f_(0) {}
    template<class _Alloc>
      _LIBCPP_INLINE_VISIBILITY
      function(allocator_arg_t, const _Alloc&, nullptr_t) : __f_(0) {}
    template<class _Alloc>
      function(allocator_arg_t, const _Alloc&, const function&);
    template<class _Fp, class _Alloc>
      function(allocator_arg_t, const _Alloc& __a, _Fp __f,
               typename enable_if<!is_integral<_Fp>::value>::type* = 0);

    function& operator=(const function&);
    function& operator=(nullptr_t);
    template<class _Fp>
      typename enable_if
      <
        !is_integral<_Fp>::value,
        function&
      >::type
      operator=(_Fp);

    ~function();

    // 20.7.16.2.2, function modifiers:
    void swap(function&);
    template<class _Fp, class _Alloc>
      _LIBCPP_INLINE_VISIBILITY
      void assign(_Fp __f, const _Alloc& __a)
        {function(allocator_arg, __a, __f).swap(*this);}

    // 20.7.16.2.3, function capacity:
    operator bool() const {return __f_;}

private:
    // deleted overloads close possible hole in the type system
    template<class _R2, class _B0, class _B1>
      bool operator==(const function<_R2(_B0, _B1)>&) const;// = delete;
    template<class _R2, class _B0, class _B1>
      bool operator!=(const function<_R2(_B0, _B1)>&) const;// = delete;
public:
    // 20.7.16.2.4, function invocation:
    _Rp operator()(_A0, _A1) const;

#ifndef _LIBCPP_NO_RTTI
    // 20.7.16.2.5, function target access:
    const std::type_info& target_type() const;
    template <typename _Tp> _Tp* target();
    template <typename _Tp> const _Tp* target() const;
#endif  // _LIBCPP_NO_RTTI
# 1322 "/usr/include/c++/v1/__functional_03" 3
};

template<class _Rp, class _A0, class _A1>
function<_Rp(_A0, _A1)>::function(const function& __f)
{
    if (__f.__f_ == 0)
        __f_ = 0;
    else if (__f.__f_ == (const __base*)&__f.__buf_)
    {
        __f_ = (__base*)&__buf_;
        __f.__f_->__clone(__f_);
    }
    else
        __f_ = __f.__f_->__clone();
}

template<class _Rp, class _A0, class _A1>
template<class _Alloc>
function<_Rp(_A0, _A1)>::function(allocator_arg_t, const _Alloc&, const function& __f)
{
    if (__f.__f_ == 0)
        __f_ = 0;
    else if (__f.__f_ == (const __base*)&__f.__buf_)
    {
        __f_ = (__base*)&__buf_;
        __f.__f_->__clone(__f_);
    }
    else
        __f_ = __f.__f_->__clone();
}

template<class _Rp, class _A0, class _A1>
template <class _Fp>
function<_Rp(_A0, _A1)>::function(_Fp __f,
                                 typename enable_if<!is_integral<_Fp>::value>::type*)
    : __f_(0)
{
    if (__not_null(__f))
    {
        typedef __function::__func<_Fp, allocator<_Fp>, _Rp(_A0, _A1)> _FF;
        if (sizeof(_FF) <= sizeof(__buf_))
        {
            __f_ = (__base*)&__buf_;
            ::new (__f_) _FF(__f);
        }
        else
        {
            typedef allocator<_FF> _Ap;
            _Ap __a;
            typedef __allocator_destructor<_Ap> _Dp;
            unique_ptr<__base, _Dp> __hold(__a.allocate(1), _Dp(__a, 1));
            ::new (__hold.get()) _FF(__f, allocator<_Fp>(__a));
            __f_ = __hold.release();
        }
    }
}

template<class _Rp, class _A0, class _A1>
template <class _Fp, class _Alloc>
function<_Rp(_A0, _A1)>::function(allocator_arg_t, const _Alloc& __a0, _Fp __f,
                                 typename enable_if<!is_integral<_Fp>::value>::type*)
    : __f_(0)
{
    typedef allocator_traits<_Alloc> __alloc_traits;
    if (__not_null(__f))
    {
        typedef __function::__func<_Fp, _Alloc, _Rp(_A0, _A1)> _FF;
        if (sizeof(_FF) <= sizeof(__buf_))
        {
            __f_ = (__base*)&__buf_;
            ::new (__f_) _FF(__f);
        }
        else
        {
            typedef typename __alloc_traits::template
#ifndef _LIBCPP_HAS_NO_TEMPLATE_ALIASES
                rebind_alloc<_FF>
#else
# 1400 "/usr/include/c++/v1/__functional_03" 3
                rebind_alloc<_FF>::other
#endif
# 1402 "/usr/include/c++/v1/__functional_03" 3
                                                         _Ap;
            _Ap __a(__a0);
            typedef __allocator_destructor<_Ap> _Dp;
            unique_ptr<__base, _Dp> __hold(__a.allocate(1), _Dp(__a, 1));
            ::new (__hold.get()) _FF(__f, _Alloc(__a));
            __f_ = __hold.release();
        }
    }
}

template<class _Rp, class _A0, class _A1>
function<_Rp(_A0, _A1)>&
function<_Rp(_A0, _A1)>::operator=(const function& __f)
{
    function(__f).swap(*this);
    return *this;
}

template<class _Rp, class _A0, class _A1>
function<_Rp(_A0, _A1)>&
function<_Rp(_A0, _A1)>::operator=(nullptr_t)
{
    if (__f_ == (__base*)&__buf_)
        __f_->destroy();
    else if (__f_)
        __f_->destroy_deallocate();
    __f_ = 0;
}

template<class _Rp, class _A0, class _A1>
template <class _Fp>
typename enable_if
<
    !is_integral<_Fp>::value,
    function<_Rp(_A0, _A1)>&
>::type
function<_Rp(_A0, _A1)>::operator=(_Fp __f)
{
    function(_VSTD::move(__f)).swap(*this);
    return *this;
}

template<class _Rp, class _A0, class _A1>
function<_Rp(_A0, _A1)>::~function()
{
    if (__f_ == (__base*)&__buf_)
        __f_->destroy();
    else if (__f_)
        __f_->destroy_deallocate();
}

template<class _Rp, class _A0, class _A1>
void
function<_Rp(_A0, _A1)>::swap(function& __f)
{
    if (__f_ == (__base*)&__buf_ && __f.__f_ == (__base*)&__f.__buf_)
    {
        typename aligned_storage<sizeof(__buf_)>::type __tempbuf;
        __base* __t = (__base*)&__tempbuf;
        __f_->__clone(__t);
        __f_->destroy();
        __f_ = 0;
        __f.__f_->__clone((__base*)&__buf_);
        __f.__f_->destroy();
        __f.__f_ = 0;
        __f_ = (__base*)&__buf_;
        __t->__clone((__base*)&__f.__buf_);
        __t->destroy();
        __f.__f_ = (__base*)&__f.__buf_;
    }
    else if (__f_ == (__base*)&__buf_)
    {
        __f_->__clone((__base*)&__f.__buf_);
        __f_->destroy();
        __f_ = __f.__f_;
        __f.__f_ = (__base*)&__f.__buf_;
    }
    else if (__f.__f_ == (__base*)&__f.__buf_)
    {
        __f.__f_->__clone((__base*)&__buf_);
        __f.__f_->destroy();
        __f.__f_ = __f_;
        __f_ = (__base*)&__buf_;
    }
    else
        _VSTD::swap(__f_, __f.__f_);
}

template<class _Rp, class _A0, class _A1>
_Rp
function<_Rp(_A0, _A1)>::operator()(_A0 __a0, _A1 __a1) const
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    if (__f_ == 0)
        throw bad_function_call();
#endif  // _LIBCPP_NO_EXCEPTIONS
# 1498 "/usr/include/c++/v1/__functional_03" 3
    return (*__f_)(__a0, __a1);
}

#ifndef _LIBCPP_NO_RTTI

template<class _Rp, class _A0, class _A1>
const std::type_info&
function<_Rp(_A0, _A1)>::target_type() const
{
    if (__f_ == 0)
        return typeid(void);
    return __f_->target_type();
}

template<class _Rp, class _A0, class _A1>
template <typename _Tp>
_Tp*
function<_Rp(_A0, _A1)>::target()
{
    if (__f_ == 0)
        return (_Tp*)0;
    return (_Tp*)__f_->target(typeid(_Tp));
}

template<class _Rp, class _A0, class _A1>
template <typename _Tp>
const _Tp*
function<_Rp(_A0, _A1)>::target() const
{
    if (__f_ == 0)
        return (const _Tp*)0;
    return (const _Tp*)__f_->target(typeid(_Tp));
}

#endif  // _LIBCPP_NO_RTTI
# 1533 "/usr/include/c++/v1/__functional_03" 3

template<class _Rp, class _A0, class _A1, class _A2>
class _LIBCPP_TYPE_VIS_ONLY function<_Rp(_A0, _A1, _A2)>
{
    typedef __function::__base<_Rp(_A0, _A1, _A2)> __base;
    aligned_storage<3*sizeof(void*)>::type __buf_;
    __base* __f_;

    template <class _Fp>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(const _Fp&) {return true;}
    template <class _R2, class _B0, class _B1, class _B2>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(_R2 (*__p)(_B0, _B1, _B2)) {return __p;}
    template <class _R2, class _Cp, class _B1, class _B2>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(_R2 (_Cp::*__p)(_B1, _B2)) {return __p;}
    template <class _R2, class _Cp, class _B1, class _B2>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(_R2 (_Cp::*__p)(_B1, _B2) const) {return __p;}
    template <class _R2, class _Cp, class _B1, class _B2>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(_R2 (_Cp::*__p)(_B1, _B2) volatile) {return __p;}
    template <class _R2, class _Cp, class _B1, class _B2>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(_R2 (_Cp::*__p)(_B1, _B2) const volatile) {return __p;}
    template <class _R2, class _B0, class _B1, class _B2>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(const function<_Rp(_B0, _B1, _B2)>& __p) {return __p;}
public:
    typedef _Rp result_type;

    // 20.7.16.2.1, construct/copy/destroy:
    _LIBCPP_INLINE_VISIBILITY explicit function() : __f_(0) {}
    _LIBCPP_INLINE_VISIBILITY function(nullptr_t) : __f_(0) {}
    function(const function&);
    template<class _Fp>
      function(_Fp,
               typename enable_if<!is_integral<_Fp>::value>::type* = 0);

    template<class _Alloc>
      _LIBCPP_INLINE_VISIBILITY
      function(allocator_arg_t, const _Alloc&) : __f_(0) {}
    template<class _Alloc>
      _LIBCPP_INLINE_VISIBILITY
      function(allocator_arg_t, const _Alloc&, nullptr_t) : __f_(0) {}
    template<class _Alloc>
      function(allocator_arg_t, const _Alloc&, const function&);
    template<class _Fp, class _Alloc>
      function(allocator_arg_t, const _Alloc& __a, _Fp __f,
               typename enable_if<!is_integral<_Fp>::value>::type* = 0);

    function& operator=(const function&);
    function& operator=(nullptr_t);
    template<class _Fp>
      typename enable_if
      <
        !is_integral<_Fp>::value,
        function&
      >::type
      operator=(_Fp);

    ~function();

    // 20.7.16.2.2, function modifiers:
    void swap(function&);
    template<class _Fp, class _Alloc>
      _LIBCPP_INLINE_VISIBILITY
      void assign(_Fp __f, const _Alloc& __a)
        {function(allocator_arg, __a, __f).swap(*this);}

    // 20.7.16.2.3, function capacity:
    _LIBCPP_INLINE_VISIBILITY operator bool() const {return __f_;}

private:
    // deleted overloads close possible hole in the type system
    template<class _R2, class _B0, class _B1, class _B2>
      bool operator==(const function<_R2(_B0, _B1, _B2)>&) const;// = delete;
    template<class _R2, class _B0, class _B1, class _B2>
      bool operator!=(const function<_R2(_B0, _B1, _B2)>&) const;// = delete;
public:
    // 20.7.16.2.4, function invocation:
    _Rp operator()(_A0, _A1, _A2) const;

#ifndef _LIBCPP_NO_RTTI
    // 20.7.16.2.5, function target access:
    const std::type_info& target_type() const;
    template <typename _Tp> _Tp* target();
    template <typename _Tp> const _Tp* target() const;
#endif  // _LIBCPP_NO_RTTI
# 1623 "/usr/include/c++/v1/__functional_03" 3
};

template<class _Rp, class _A0, class _A1, class _A2>
function<_Rp(_A0, _A1, _A2)>::function(const function& __f)
{
    if (__f.__f_ == 0)
        __f_ = 0;
    else if (__f.__f_ == (const __base*)&__f.__buf_)
    {
        __f_ = (__base*)&__buf_;
        __f.__f_->__clone(__f_);
    }
    else
        __f_ = __f.__f_->__clone();
}

template<class _Rp, class _A0, class _A1, class _A2>
template<class _Alloc>
function<_Rp(_A0, _A1, _A2)>::function(allocator_arg_t, const _Alloc&,
                                      const function& __f)
{
    if (__f.__f_ == 0)
        __f_ = 0;
    else if (__f.__f_ == (const __base*)&__f.__buf_)
    {
        __f_ = (__base*)&__buf_;
        __f.__f_->__clone(__f_);
    }
    else
        __f_ = __f.__f_->__clone();
}

template<class _Rp, class _A0, class _A1, class _A2>
template <class _Fp>
function<_Rp(_A0, _A1, _A2)>::function(_Fp __f,
                                     typename enable_if<!is_integral<_Fp>::value>::type*)
    : __f_(0)
{
    if (__not_null(__f))
    {
        typedef __function::__func<_Fp, allocator<_Fp>, _Rp(_A0, _A1, _A2)> _FF;
        if (sizeof(_FF) <= sizeof(__buf_))
        {
            __f_ = (__base*)&__buf_;
            ::new (__f_) _FF(__f);
        }
        else
        {
            typedef allocator<_FF> _Ap;
            _Ap __a;
            typedef __allocator_destructor<_Ap> _Dp;
            unique_ptr<__base, _Dp> __hold(__a.allocate(1), _Dp(__a, 1));
            ::new (__hold.get()) _FF(__f, allocator<_Fp>(__a));
            __f_ = __hold.release();
        }
    }
}

template<class _Rp, class _A0, class _A1, class _A2>
template <class _Fp, class _Alloc>
function<_Rp(_A0, _A1, _A2)>::function(allocator_arg_t, const _Alloc& __a0, _Fp __f,
                                     typename enable_if<!is_integral<_Fp>::value>::type*)
    : __f_(0)
{
    typedef allocator_traits<_Alloc> __alloc_traits;
    if (__not_null(__f))
    {
        typedef __function::__func<_Fp, _Alloc, _Rp(_A0, _A1, _A2)> _FF;
        if (sizeof(_FF) <= sizeof(__buf_))
        {
            __f_ = (__base*)&__buf_;
            ::new (__f_) _FF(__f);
        }
        else
        {
            typedef typename __alloc_traits::template
#ifndef _LIBCPP_HAS_NO_TEMPLATE_ALIASES
                rebind_alloc<_FF>
#else
# 1702 "/usr/include/c++/v1/__functional_03" 3
                rebind_alloc<_FF>::other
#endif
# 1704 "/usr/include/c++/v1/__functional_03" 3
                                                         _Ap;
            _Ap __a(__a0);
            typedef __allocator_destructor<_Ap> _Dp;
            unique_ptr<__base, _Dp> __hold(__a.allocate(1), _Dp(__a, 1));
            ::new (__hold.get()) _FF(__f, _Alloc(__a));
            __f_ = __hold.release();
        }
    }
}

template<class _Rp, class _A0, class _A1, class _A2>
function<_Rp(_A0, _A1, _A2)>&
function<_Rp(_A0, _A1, _A2)>::operator=(const function& __f)
{
    function(__f).swap(*this);
    return *this;
}

template<class _Rp, class _A0, class _A1, class _A2>
function<_Rp(_A0, _A1, _A2)>&
function<_Rp(_A0, _A1, _A2)>::operator=(nullptr_t)
{
    if (__f_ == (__base*)&__buf_)
        __f_->destroy();
    else if (__f_)
        __f_->destroy_deallocate();
    __f_ = 0;
}

template<class _Rp, class _A0, class _A1, class _A2>
template <class _Fp>
typename enable_if
<
    !is_integral<_Fp>::value,
    function<_Rp(_A0, _A1, _A2)>&
>::type
function<_Rp(_A0, _A1, _A2)>::operator=(_Fp __f)
{
    function(_VSTD::move(__f)).swap(*this);
    return *this;
}

template<class _Rp, class _A0, class _A1, class _A2>
function<_Rp(_A0, _A1, _A2)>::~function()
{
    if (__f_ == (__base*)&__buf_)
        __f_->destroy();
    else if (__f_)
        __f_->destroy_deallocate();
}

template<class _Rp, class _A0, class _A1, class _A2>
void
function<_Rp(_A0, _A1, _A2)>::swap(function& __f)
{
    if (__f_ == (__base*)&__buf_ && __f.__f_ == (__base*)&__f.__buf_)
    {
        typename aligned_storage<sizeof(__buf_)>::type __tempbuf;
        __base* __t = (__base*)&__tempbuf;
        __f_->__clone(__t);
        __f_->destroy();
        __f_ = 0;
        __f.__f_->__clone((__base*)&__buf_);
        __f.__f_->destroy();
        __f.__f_ = 0;
        __f_ = (__base*)&__buf_;
        __t->__clone((__base*)&__f.__buf_);
        __t->destroy();
        __f.__f_ = (__base*)&__f.__buf_;
    }
    else if (__f_ == (__base*)&__buf_)
    {
        __f_->__clone((__base*)&__f.__buf_);
        __f_->destroy();
        __f_ = __f.__f_;
        __f.__f_ = (__base*)&__f.__buf_;
    }
    else if (__f.__f_ == (__base*)&__f.__buf_)
    {
        __f.__f_->__clone((__base*)&__buf_);
        __f.__f_->destroy();
        __f.__f_ = __f_;
        __f_ = (__base*)&__buf_;
    }
    else
        _VSTD::swap(__f_, __f.__f_);
}

template<class _Rp, class _A0, class _A1, class _A2>
_Rp
function<_Rp(_A0, _A1, _A2)>::operator()(_A0 __a0, _A1 __a1, _A2 __a2) const
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    if (__f_ == 0)
        throw bad_function_call();
#endif  // _LIBCPP_NO_EXCEPTIONS
# 1800 "/usr/include/c++/v1/__functional_03" 3
    return (*__f_)(__a0, __a1, __a2);
}

#ifndef _LIBCPP_NO_RTTI

template<class _Rp, class _A0, class _A1, class _A2>
const std::type_info&
function<_Rp(_A0, _A1, _A2)>::target_type() const
{
    if (__f_ == 0)
        return typeid(void);
    return __f_->target_type();
}

template<class _Rp, class _A0, class _A1, class _A2>
template <typename _Tp>
_Tp*
function<_Rp(_A0, _A1, _A2)>::target()
{
    if (__f_ == 0)
        return (_Tp*)0;
    return (_Tp*)__f_->target(typeid(_Tp));
}

template<class _Rp, class _A0, class _A1, class _A2>
template <typename _Tp>
const _Tp*
function<_Rp(_A0, _A1, _A2)>::target() const
{
    if (__f_ == 0)
        return (const _Tp*)0;
    return (const _Tp*)__f_->target(typeid(_Tp));
}

#endif  // _LIBCPP_NO_RTTI
# 1835 "/usr/include/c++/v1/__functional_03" 3

template <class _Fp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const function<_Fp>& __f, nullptr_t) {return !__f;}

template <class _Fp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(nullptr_t, const function<_Fp>& __f) {return !__f;}

template <class _Fp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const function<_Fp>& __f, nullptr_t) {return (bool)__f;}

template <class _Fp>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(nullptr_t, const function<_Fp>& __f) {return (bool)__f;}

template <class _Fp>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(function<_Fp>& __x, function<_Fp>& __y)
{return __x.swap(__y);}

template<class _Tp> struct __is_bind_expression : public false_type {};
template<class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_bind_expression
    : public __is_bind_expression<typename remove_cv<_Tp>::type> {};

template<class _Tp> struct __is_placeholder : public integral_constant<int, 0> {};
template<class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_placeholder
    : public __is_placeholder<typename remove_cv<_Tp>::type> {};

namespace placeholders
{

template <int _Np> struct __ph {};

extern __ph<1>   _1;
extern __ph<2>   _2;
extern __ph<3>   _3;
extern __ph<4>   _4;
extern __ph<5>   _5;
extern __ph<6>   _6;
extern __ph<7>   _7;
extern __ph<8>   _8;
extern __ph<9>   _9;
extern __ph<10> _10;

}  // placeholders

template<int _Np>
struct __is_placeholder<placeholders::__ph<_Np> >
    : public integral_constant<int, _Np> {};

template <class _Tp, class _Uj>
inline _LIBCPP_INLINE_VISIBILITY
_Tp&
__mu(reference_wrapper<_Tp> __t, _Uj&)
{
    return __t.get();
}
/*
template <bool _IsBindExpr, class _Ti, class ..._Uj>
struct __mu_return1 {};

template <class _Ti, class ..._Uj>
struct __mu_return1<true, _Ti, _Uj...>
{
    typedef typename result_of<_Ti(_Uj...)>::type type;
};

template <class _Ti, class ..._Uj, size_t ..._Indx>
inline _LIBCPP_INLINE_VISIBILITY
typename __mu_return1<true, _Ti, _Uj...>::type
__mu_expand(_Ti& __ti, tuple<_Uj...>&& __uj, __tuple_indices<_Indx...>)
{
    __ti(_VSTD::forward<typename tuple_element<_Indx, _Uj>::type>(get<_Indx>(__uj))...);
}

template <class _Ti, class ..._Uj>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_bind_expression<_Ti>::value,
    typename __mu_return1<is_bind_expression<_Ti>::value, _Ti, _Uj...>::type
>::type
__mu(_Ti& __ti, tuple<_Uj...>& __uj)
{
    typedef typename __make_tuple_indices<sizeof...(_Uj)>::type __indices;
    return  __mu_expand(__ti, __uj, __indices());
}

template <bool IsPh, class _Ti, class _Uj>
struct __mu_return2 {};

template <class _Ti, class _Uj>
struct __mu_return2<true, _Ti, _Uj>
{
    typedef typename tuple_element<is_placeholder<_Ti>::value - 1, _Uj>::type type;
};

template <class _Ti, class _Uj>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    0 < is_placeholder<_Ti>::value,
    typename __mu_return2<0 < is_placeholder<_Ti>::value, _Ti, _Uj>::type
>::type
__mu(_Ti&, _Uj& __uj)
{
    const size_t _Indx = is_placeholder<_Ti>::value - 1;
    // compiler bug workaround
    typename tuple_element<_Indx, _Uj>::type __t = get<_Indx>(__uj);
    return __t;
//    return _VSTD::forward<typename tuple_element<_Indx, _Uj>::type>(get<_Indx>(__uj));
}

template <class _Ti, class _Uj>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_bind_expression<_Ti>::value &&
    is_placeholder<_Ti>::value == 0 &&
    !__is_reference_wrapper<_Ti>::value,
    _Ti&
>::type
__mu(_Ti& __ti, _Uj& __uj)
{
    return __ti;
}

template <class _Ti, bool IsBindEx, bool IsPh, class _TupleUj>
struct ____mu_return;

template <class _Ti, class ..._Uj>
struct ____mu_return<_Ti, true, false, tuple<_Uj...> >
{
    typedef typename result_of<_Ti(_Uj...)>::type type;
};

template <class _Ti, class _TupleUj>
struct ____mu_return<_Ti, false, true, _TupleUj>
{
    typedef typename tuple_element<is_placeholder<_Ti>::value - 1,
                                   _TupleUj>::type&& type;
};

template <class _Ti, class _TupleUj>
struct ____mu_return<_Ti, false, false, _TupleUj>
{
    typedef _Ti& type;
};

template <class _Ti, class _TupleUj>
struct __mu_return
    : public ____mu_return<_Ti,
                           is_bind_expression<_Ti>::value,
                           0 < is_placeholder<_Ti>::value,
                           _TupleUj>
{
};

template <class _Ti, class _TupleUj>
struct __mu_return<reference_wrapper<_Ti>, _TupleUj>
{
    typedef _Ti& type;
};

template <class _Fp, class _BoundArgs, class _TupleUj>
struct __bind_return;

template <class _Fp, class ..._BoundArgs, class _TupleUj>
struct __bind_return<_Fp, tuple<_BoundArgs...>, _TupleUj>
{
    typedef typename __ref_return
    <
        _Fp&,
        typename __mu_return
        <
            _BoundArgs,
            _TupleUj
        >::type...
    >::type type;
};

template <class _Fp, class ..._BoundArgs, class _TupleUj>
struct __bind_return<_Fp, const tuple<_BoundArgs...>, _TupleUj>
{
    typedef typename __ref_return
    <
        _Fp&,
        typename __mu_return
        <
            const _BoundArgs,
            _TupleUj
        >::type...
    >::type type;
};

template <class _Fp, class _BoundArgs, size_t ..._Indx, class _Args>
inline _LIBCPP_INLINE_VISIBILITY
typename __bind_return<_Fp, _BoundArgs, _Args>::type
__apply_functor(_Fp& __f, _BoundArgs& __bound_args, __tuple_indices<_Indx...>,
                _Args&& __args)
{
    return __invoke(__f, __mu(get<_Indx>(__bound_args), __args)...);
}

template<class _Fp, class ..._BoundArgs>
class __bind
{
    _Fp __f_;
    tuple<_BoundArgs...> __bound_args_;

    typedef typename __make_tuple_indices<sizeof...(_BoundArgs)>::type __indices;
public:
    template <class _Gp, class ..._BA>
      explicit __bind(_Gp&& __f, _BA&& ...__bound_args)
        : __f_(_VSTD::forward<_Gp>(__f)),
          __bound_args_(_VSTD::forward<_BA>(__bound_args)...) {}

    template <class ..._Args>
        typename __bind_return<_Fp, tuple<_BoundArgs...>, tuple<_Args&&...> >::type
        operator()(_Args&& ...__args)
        {
            // compiler bug workaround
            return __apply_functor(__f_, __bound_args_, __indices(),
                                  tuple<_Args&&...>(__args...));
        }

    template <class ..._Args>
        typename __bind_return<_Fp, tuple<_BoundArgs...>, tuple<_Args&&...> >::type
        operator()(_Args&& ...__args) const
        {
            return __apply_functor(__f_, __bound_args_, __indices(),
                                   tuple<_Args&&...>(__args...));
        }
};

template<class _Fp, class ..._BoundArgs>
struct __is_bind_expression<__bind<_Fp, _BoundArgs...> > : public true_type {};

template<class _Rp, class _Fp, class ..._BoundArgs>
class __bind_r
    : public __bind<_Fp, _BoundArgs...>
{
    typedef __bind<_Fp, _BoundArgs...> base;
public:
    typedef _Rp result_type;

    template <class _Gp, class ..._BA>
      explicit __bind_r(_Gp&& __f, _BA&& ...__bound_args)
        : base(_VSTD::forward<_Gp>(__f),
               _VSTD::forward<_BA>(__bound_args)...) {}

    template <class ..._Args>
        result_type
        operator()(_Args&& ...__args)
        {
            return base::operator()(_VSTD::forward<_Args>(__args)...);
        }

    template <class ..._Args>
        result_type
        operator()(_Args&& ...__args) const
        {
            return base::operator()(_VSTD::forward<_Args>(__args)...);
        }
};

template<class _Rp, class _Fp, class ..._BoundArgs>
struct __is_bind_expression<__bind_r<_Rp, _Fp, _BoundArgs...> > : public true_type {};

template<class _Fp, class ..._BoundArgs>
inline _LIBCPP_INLINE_VISIBILITY
__bind<typename decay<_Fp>::type, typename decay<_BoundArgs>::type...>
bind(_Fp&& __f, _BoundArgs&&... __bound_args)
{
    typedef __bind<typename decay<_Fp>::type, typename decay<_BoundArgs>::type...> type;
    return type(_VSTD::forward<_Fp>(__f), _VSTD::forward<_BoundArgs>(__bound_args)...);
}

template<class _Rp, class _Fp, class ..._BoundArgs>
inline _LIBCPP_INLINE_VISIBILITY
__bind_r<_Rp, typename decay<_Fp>::type, typename decay<_BoundArgs>::type...>
bind(_Fp&& __f, _BoundArgs&&... __bound_args)
{
    typedef __bind_r<_Rp, typename decay<_Fp>::type, typename decay<_BoundArgs>::type...> type;
    return type(_VSTD::forward<_Fp>(__f), _VSTD::forward<_BoundArgs>(__bound_args)...);
}
*/

#endif  // _LIBCPP_FUNCTIONAL_03
# 2131 "/usr/include/c++/v1/__functional_03" 3
# 1204 "/usr/include/c++/v1/functional" 2 3

#else  // _LIBCPP_HAS_NO_VARIADICS
# 1206 "/usr/include/c++/v1/functional" 3

template <class _Tp>
class __mem_fn
    : public __weak_result_type<_Tp>
{
public:
    // types
    typedef _Tp type;
private:
    type __f_;

public:
    _LIBCPP_INLINE_VISIBILITY __mem_fn(type __f) : __f_(__f) {}

    // invoke
    template <class... _ArgTypes>
       _LIBCPP_INLINE_VISIBILITY
       typename __invoke_return<type, _ArgTypes...>::type
          operator() (_ArgTypes&&... __args) const
          {
              return __invoke(__f_, _VSTD::forward<_ArgTypes>(__args)...);
          }
};

template<class _Rp, class _Tp>
inline _LIBCPP_INLINE_VISIBILITY
__mem_fn<_Rp _Tp::*>
mem_fn(_Rp _Tp::* __pm)
{
    return __mem_fn<_Rp _Tp::*>(__pm);
}

// bad_function_call

class _LIBCPP_EXCEPTION_ABI bad_function_call
    : public exception
{
};

template<class _Fp> class _LIBCPP_TYPE_VIS_ONLY function; // undefined

namespace __function
{

template<class _Rp, class ..._ArgTypes>
struct __maybe_derive_from_unary_function
{
};

template<class _Rp, class _A1>
struct __maybe_derive_from_unary_function<_Rp(_A1)>
    : public unary_function<_A1, _Rp>
{
};

template<class _Rp, class ..._ArgTypes>
struct __maybe_derive_from_binary_function
{
};

template<class _Rp, class _A1, class _A2>
struct __maybe_derive_from_binary_function<_Rp(_A1, _A2)>
    : public binary_function<_A1, _A2, _Rp>
{
};

template<class _Fp> class __base;

template<class _Rp, class ..._ArgTypes>
class __base<_Rp(_ArgTypes...)>
{
    __base(const __base&);
    __base& operator=(const __base&);
public:
    _LIBCPP_INLINE_VISIBILITY __base() {}
    _LIBCPP_INLINE_VISIBILITY virtual ~__base() {}
    virtual __base* __clone() const = 0;
    virtual void __clone(__base*) const = 0;
    virtual void destroy() _NOEXCEPT = 0;
    virtual void destroy_deallocate() _NOEXCEPT = 0;
    virtual _Rp operator()(_ArgTypes&& ...) = 0;
#ifndef _LIBCPP_NO_RTTI
    virtual const void* target(const type_info&) const _NOEXCEPT = 0;
    virtual const std::type_info& target_type() const _NOEXCEPT = 0;
#endif  // _LIBCPP_NO_RTTI
# 1291 "/usr/include/c++/v1/functional" 3
};

template<class _FD, class _Alloc, class _FB> class __func;

template<class _Fp, class _Alloc, class _Rp, class ..._ArgTypes>
class __func<_Fp, _Alloc, _Rp(_ArgTypes...)>
    : public  __base<_Rp(_ArgTypes...)>
{
    __compressed_pair<_Fp, _Alloc> __f_;
public:
    _LIBCPP_INLINE_VISIBILITY
    explicit __func(_Fp&& __f)
        : __f_(piecewise_construct, _VSTD::forward_as_tuple(_VSTD::move(__f)),
                                    _VSTD::forward_as_tuple()) {}
    _LIBCPP_INLINE_VISIBILITY
    explicit __func(const _Fp& __f, const _Alloc& __a)
        : __f_(piecewise_construct, _VSTD::forward_as_tuple(__f),
                                    _VSTD::forward_as_tuple(__a)) {}

    _LIBCPP_INLINE_VISIBILITY
    explicit __func(const _Fp& __f, _Alloc&& __a)
        : __f_(piecewise_construct, _VSTD::forward_as_tuple(__f),
                                    _VSTD::forward_as_tuple(_VSTD::move(__a))) {}

    _LIBCPP_INLINE_VISIBILITY
    explicit __func(_Fp&& __f, _Alloc&& __a)
        : __f_(piecewise_construct, _VSTD::forward_as_tuple(_VSTD::move(__f)),
                                    _VSTD::forward_as_tuple(_VSTD::move(__a))) {}
    virtual __base<_Rp(_ArgTypes...)>* __clone() const;
    virtual void __clone(__base<_Rp(_ArgTypes...)>*) const;
    virtual void destroy() _NOEXCEPT;
    virtual void destroy_deallocate() _NOEXCEPT;
    virtual _Rp operator()(_ArgTypes&& ... __arg);
#ifndef _LIBCPP_NO_RTTI
    virtual const void* target(const type_info&) const _NOEXCEPT;
    virtual const std::type_info& target_type() const _NOEXCEPT;
#endif  // _LIBCPP_NO_RTTI
# 1328 "/usr/include/c++/v1/functional" 3
};

template<class _Fp, class _Alloc, class _Rp, class ..._ArgTypes>
__base<_Rp(_ArgTypes...)>*
__func<_Fp, _Alloc, _Rp(_ArgTypes...)>::__clone() const
{
    typedef typename _Alloc::template rebind<__func>::other _Ap;
    _Ap __a(__f_.second());
    typedef __allocator_destructor<_Ap> _Dp;
    unique_ptr<__func, _Dp> __hold(__a.allocate(1), _Dp(__a, 1));
    ::new (__hold.get()) __func(__f_.first(), _Alloc(__a));
    return __hold.release();
}

template<class _Fp, class _Alloc, class _Rp, class ..._ArgTypes>
void
__func<_Fp, _Alloc, _Rp(_ArgTypes...)>::__clone(__base<_Rp(_ArgTypes...)>* __p) const
{
    ::new (__p) __func(__f_.first(), __f_.second());
}

template<class _Fp, class _Alloc, class _Rp, class ..._ArgTypes>
void
__func<_Fp, _Alloc, _Rp(_ArgTypes...)>::destroy() _NOEXCEPT
{
    __f_.~__compressed_pair<_Fp, _Alloc>();
}

template<class _Fp, class _Alloc, class _Rp, class ..._ArgTypes>
void
__func<_Fp, _Alloc, _Rp(_ArgTypes...)>::destroy_deallocate() _NOEXCEPT
{
    typedef typename _Alloc::template rebind<__func>::other _Ap;
    _Ap __a(__f_.second());
    __f_.~__compressed_pair<_Fp, _Alloc>();
    __a.deallocate(this, 1);
}

template<class _Fp, class _Alloc, class _Rp, class ..._ArgTypes>
_Rp
__func<_Fp, _Alloc, _Rp(_ArgTypes...)>::operator()(_ArgTypes&& ... __arg)
{
    return __invoke(__f_.first(), _VSTD::forward<_ArgTypes>(__arg)...);
}

#ifndef _LIBCPP_NO_RTTI

template<class _Fp, class _Alloc, class _Rp, class ..._ArgTypes>
const void*
__func<_Fp, _Alloc, _Rp(_ArgTypes...)>::target(const type_info& __ti) const _NOEXCEPT
{
    if (__ti == typeid(_Fp))
        return &__f_.first();
    return (const void*)0;
}

template<class _Fp, class _Alloc, class _Rp, class ..._ArgTypes>
const std::type_info&
__func<_Fp, _Alloc, _Rp(_ArgTypes...)>::target_type() const _NOEXCEPT
{
    return typeid(_Fp);
}

#endif  // _LIBCPP_NO_RTTI
# 1392 "/usr/include/c++/v1/functional" 3

}  // __function

template<class _Rp, class ..._ArgTypes>
class _LIBCPP_TYPE_VIS_ONLY function<_Rp(_ArgTypes...)>
    : public __function::__maybe_derive_from_unary_function<_Rp(_ArgTypes...)>,
      public __function::__maybe_derive_from_binary_function<_Rp(_ArgTypes...)>
{
    typedef __function::__base<_Rp(_ArgTypes...)> __base;
    typename aligned_storage<3*sizeof(void*)>::type __buf_;
    __base* __f_;

    template <class _Fp>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(const _Fp&) {return true;}
    template <class _R2, class ..._Ap>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(_R2 (*__p)(_Ap...)) {return __p;}
    template <class _R2, class _Cp, class ..._Ap>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(_R2 (_Cp::*__p)(_Ap...)) {return __p;}
    template <class _R2, class _Cp, class ..._Ap>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(_R2 (_Cp::*__p)(_Ap...) const) {return __p;}
    template <class _R2, class _Cp, class ..._Ap>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(_R2 (_Cp::*__p)(_Ap...) volatile) {return __p;}
    template <class _R2, class _Cp, class ..._Ap>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(_R2 (_Cp::*__p)(_Ap...) const volatile) {return __p;}
    template <class _R2, class ..._Ap>
        _LIBCPP_INLINE_VISIBILITY
        static bool __not_null(const function<_Rp(_Ap...)>& __p) {return __p;}

    template <class _Fp, bool = !is_same<_Fp, function>::value &&
                                __invokable<_Fp&, _ArgTypes...>::value>
        struct __callable;
    template <class _Fp>
        struct __callable<_Fp, true>
        {
            static const bool value =
                is_convertible<typename __invoke_of<_Fp&, _ArgTypes...>::type,
                               _Rp>::value;
        };
    template <class _Fp>
        struct __callable<_Fp, false>
        {
            static const bool value = false;
        };
public:
    typedef _Rp result_type;

    // construct/copy/destroy:
    _LIBCPP_INLINE_VISIBILITY
    function() _NOEXCEPT : __f_(0) {}
    _LIBCPP_INLINE_VISIBILITY
    function(nullptr_t) _NOEXCEPT : __f_(0) {}
    function(const function&);
    function(function&&) _NOEXCEPT;
    template<class _Fp>
      function(_Fp, typename enable_if
                                     <
                                        __callable<_Fp>::value &&
                                        !is_same<_Fp, function>::value
                                      >::type* = 0);

    template<class _Alloc>
      _LIBCPP_INLINE_VISIBILITY
      function(allocator_arg_t, const _Alloc&) _NOEXCEPT : __f_(0) {}
    template<class _Alloc>
      _LIBCPP_INLINE_VISIBILITY
      function(allocator_arg_t, const _Alloc&, nullptr_t) _NOEXCEPT : __f_(0) {}
    template<class _Alloc>
      function(allocator_arg_t, const _Alloc&, const function&);
    template<class _Alloc>
      function(allocator_arg_t, const _Alloc&, function&&);
    template<class _Fp, class _Alloc>
      function(allocator_arg_t, const _Alloc& __a, _Fp __f,
               typename enable_if<__callable<_Fp>::value>::type* = 0);

    function& operator=(const function&);
    function& operator=(function&&) _NOEXCEPT;
    function& operator=(nullptr_t) _NOEXCEPT;
    template<class _Fp>
      typename enable_if
      <
        __callable<typename decay<_Fp>::type>::value &&
        !is_same<typename remove_reference<_Fp>::type, function>::value,
        function&
      >::type
      operator=(_Fp&&);

    ~function();

    // function modifiers:
    void swap(function&) _NOEXCEPT;
    template<class _Fp, class _Alloc>
      _LIBCPP_INLINE_VISIBILITY
      void assign(_Fp&& __f, const _Alloc& __a)
        {function(allocator_arg, __a, _VSTD::forward<_Fp>(__f)).swap(*this);}

    // function capacity:
    _LIBCPP_INLINE_VISIBILITY
        _LIBCPP_EXPLICIT operator bool() const _NOEXCEPT {return __f_;}

    // deleted overloads close possible hole in the type system
    template<class _R2, class... _ArgTypes2>
      bool operator==(const function<_R2(_ArgTypes2...)>&) const = delete;
    template<class _R2, class... _ArgTypes2>
      bool operator!=(const function<_R2(_ArgTypes2...)>&) const = delete;
public:
    // function invocation:
    _Rp operator()(_ArgTypes...) const;

#ifndef _LIBCPP_NO_RTTI
    // function target access:
    const std::type_info& target_type() const _NOEXCEPT;
    template <typename _Tp> _Tp* target() _NOEXCEPT;
    template <typename _Tp> const _Tp* target() const _NOEXCEPT;
#endif  // _LIBCPP_NO_RTTI
# 1512 "/usr/include/c++/v1/functional" 3
};

template<class _Rp, class ..._ArgTypes>
function<_Rp(_ArgTypes...)>::function(const function& __f)
{
    if (__f.__f_ == 0)
        __f_ = 0;
    else if (__f.__f_ == (const __base*)&__f.__buf_)
    {
        __f_ = (__base*)&__buf_;
        __f.__f_->__clone(__f_);
    }
    else
        __f_ = __f.__f_->__clone();
}

template<class _Rp, class ..._ArgTypes>
template <class _Alloc>
function<_Rp(_ArgTypes...)>::function(allocator_arg_t, const _Alloc&,
                                     const function& __f)
{
    if (__f.__f_ == 0)
        __f_ = 0;
    else if (__f.__f_ == (const __base*)&__f.__buf_)
    {
        __f_ = (__base*)&__buf_;
        __f.__f_->__clone(__f_);
    }
    else
        __f_ = __f.__f_->__clone();
}

template<class _Rp, class ..._ArgTypes>
function<_Rp(_ArgTypes...)>::function(function&& __f) _NOEXCEPT
{
    if (__f.__f_ == 0)
        __f_ = 0;
    else if (__f.__f_ == (__base*)&__f.__buf_)
    {
        __f_ = (__base*)&__buf_;
        __f.__f_->__clone(__f_);
    }
    else
    {
        __f_ = __f.__f_;
        __f.__f_ = 0;
    }
}

template<class _Rp, class ..._ArgTypes>
template <class _Alloc>
function<_Rp(_ArgTypes...)>::function(allocator_arg_t, const _Alloc&,
                                     function&& __f)
{
    if (__f.__f_ == 0)
        __f_ = 0;
    else if (__f.__f_ == (__base*)&__f.__buf_)
    {
        __f_ = (__base*)&__buf_;
        __f.__f_->__clone(__f_);
    }
    else
    {
        __f_ = __f.__f_;
        __f.__f_ = 0;
    }
}

template<class _Rp, class ..._ArgTypes>
template <class _Fp>
function<_Rp(_ArgTypes...)>::function(_Fp __f,
                                     typename enable_if
                                     <
                                        __callable<_Fp>::value &&
                                        !is_same<_Fp, function>::value
                                     >::type*)
    : __f_(0)
{
    if (__not_null(__f))
    {
        typedef __function::__func<_Fp, allocator<_Fp>, _Rp(_ArgTypes...)> _FF;
        if (sizeof(_FF) <= sizeof(__buf_) && is_nothrow_copy_constructible<_Fp>::value)
        {
            __f_ = (__base*)&__buf_;
            ::new (__f_) _FF(_VSTD::move(__f));
        }
        else
        {
            typedef allocator<_FF> _Ap;
            _Ap __a;
            typedef __allocator_destructor<_Ap> _Dp;
            unique_ptr<__base, _Dp> __hold(__a.allocate(1), _Dp(__a, 1));
            ::new (__hold.get()) _FF(_VSTD::move(__f), allocator<_Fp>(__a));
            __f_ = __hold.release();
        }
    }
}

template<class _Rp, class ..._ArgTypes>
template <class _Fp, class _Alloc>
function<_Rp(_ArgTypes...)>::function(allocator_arg_t, const _Alloc& __a0, _Fp __f,
                                     typename enable_if<__callable<_Fp>::value>::type*)
    : __f_(0)
{
    typedef allocator_traits<_Alloc> __alloc_traits;
    if (__not_null(__f))
    {
        typedef __function::__func<_Fp, _Alloc, _Rp(_ArgTypes...)> _FF;
        if (sizeof(_FF) <= sizeof(__buf_) && is_nothrow_copy_constructible<_Fp>::value)
        {
            __f_ = (__base*)&__buf_;
            ::new (__f_) _FF(_VSTD::move(__f));
        }
        else
        {
            typedef typename __alloc_traits::template
#ifndef _LIBCPP_HAS_NO_TEMPLATE_ALIASES
                rebind_alloc<_FF>
#else
# 1631 "/usr/include/c++/v1/functional" 3
                rebind_alloc<_FF>::other
#endif
# 1633 "/usr/include/c++/v1/functional" 3
                                                         _Ap;
            _Ap __a(__a0);
            typedef __allocator_destructor<_Ap> _Dp;
            unique_ptr<__base, _Dp> __hold(__a.allocate(1), _Dp(__a, 1));
            ::new (__hold.get()) _FF(_VSTD::move(__f), _Alloc(__a));
            __f_ = __hold.release();
        }
    }
}

template<class _Rp, class ..._ArgTypes>
function<_Rp(_ArgTypes...)>&
function<_Rp(_ArgTypes...)>::operator=(const function& __f)
{
    function(__f).swap(*this);
    return *this;
}

template<class _Rp, class ..._ArgTypes>
function<_Rp(_ArgTypes...)>&
function<_Rp(_ArgTypes...)>::operator=(function&& __f) _NOEXCEPT
{
    if (__f_ == (__base*)&__buf_)
        __f_->destroy();
    else if (__f_)
        __f_->destroy_deallocate();
    __f_ = 0;
    if (__f.__f_ == 0)
        __f_ = 0;
    else if (__f.__f_ == (__base*)&__f.__buf_)
    {
        __f_ = (__base*)&__buf_;
        __f.__f_->__clone(__f_);
    }
    else
    {
        __f_ = __f.__f_;
        __f.__f_ = 0;
    }
    return *this;
}

template<class _Rp, class ..._ArgTypes>
function<_Rp(_ArgTypes...)>&
function<_Rp(_ArgTypes...)>::operator=(nullptr_t) _NOEXCEPT
{
    if (__f_ == (__base*)&__buf_)
        __f_->destroy();
    else if (__f_)
        __f_->destroy_deallocate();
    __f_ = 0;
    return *this;
}

template<class _Rp, class ..._ArgTypes>
template <class _Fp>
typename enable_if
<
    function<_Rp(_ArgTypes...)>::template __callable<typename decay<_Fp>::type>::value &&
    !is_same<typename remove_reference<_Fp>::type, function<_Rp(_ArgTypes...)>>::value,
    function<_Rp(_ArgTypes...)>&
>::type
function<_Rp(_ArgTypes...)>::operator=(_Fp&& __f)
{
    function(_VSTD::forward<_Fp>(__f)).swap(*this);
    return *this;
}

template<class _Rp, class ..._ArgTypes>
function<_Rp(_ArgTypes...)>::~function()
{
    if (__f_ == (__base*)&__buf_)
        __f_->destroy();
    else if (__f_)
        __f_->destroy_deallocate();
}

template<class _Rp, class ..._ArgTypes>
void
function<_Rp(_ArgTypes...)>::swap(function& __f) _NOEXCEPT
{
    if (__f_ == (__base*)&__buf_ && __f.__f_ == (__base*)&__f.__buf_)
    {
        typename aligned_storage<sizeof(__buf_)>::type __tempbuf;
        __base* __t = (__base*)&__tempbuf;
        __f_->__clone(__t);
        __f_->destroy();
        __f_ = 0;
        __f.__f_->__clone((__base*)&__buf_);
        __f.__f_->destroy();
        __f.__f_ = 0;
        __f_ = (__base*)&__buf_;
        __t->__clone((__base*)&__f.__buf_);
        __t->destroy();
        __f.__f_ = (__base*)&__f.__buf_;
    }
    else if (__f_ == (__base*)&__buf_)
    {
        __f_->__clone((__base*)&__f.__buf_);
        __f_->destroy();
        __f_ = __f.__f_;
        __f.__f_ = (__base*)&__f.__buf_;
    }
    else if (__f.__f_ == (__base*)&__f.__buf_)
    {
        __f.__f_->__clone((__base*)&__buf_);
        __f.__f_->destroy();
        __f.__f_ = __f_;
        __f_ = (__base*)&__buf_;
    }
    else
        _VSTD::swap(__f_, __f.__f_);
}

template<class _Rp, class ..._ArgTypes>
_Rp
function<_Rp(_ArgTypes...)>::operator()(_ArgTypes... __arg) const
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    if (__f_ == 0)
        throw bad_function_call();
#endif  // _LIBCPP_NO_EXCEPTIONS
# 1755 "/usr/include/c++/v1/functional" 3
    return (*__f_)(_VSTD::forward<_ArgTypes>(__arg)...);
}

#ifndef _LIBCPP_NO_RTTI

template<class _Rp, class ..._ArgTypes>
const std::type_info&
function<_Rp(_ArgTypes...)>::target_type() const _NOEXCEPT
{
    if (__f_ == 0)
        return typeid(void);
    return __f_->target_type();
}

template<class _Rp, class ..._ArgTypes>
template <typename _Tp>
_Tp*
function<_Rp(_ArgTypes...)>::target() _NOEXCEPT
{
    if (__f_ == 0)
        return (_Tp*)0;
    return (_Tp*)__f_->target(typeid(_Tp));
}

template<class _Rp, class ..._ArgTypes>
template <typename _Tp>
const _Tp*
function<_Rp(_ArgTypes...)>::target() const _NOEXCEPT
{
    if (__f_ == 0)
        return (const _Tp*)0;
    return (const _Tp*)__f_->target(typeid(_Tp));
}

#endif  // _LIBCPP_NO_RTTI
# 1790 "/usr/include/c++/v1/functional" 3

template <class _Rp, class... _ArgTypes>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(const function<_Rp(_ArgTypes...)>& __f, nullptr_t) _NOEXCEPT {return !__f;}

template <class _Rp, class... _ArgTypes>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator==(nullptr_t, const function<_Rp(_ArgTypes...)>& __f) _NOEXCEPT {return !__f;}

template <class _Rp, class... _ArgTypes>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(const function<_Rp(_ArgTypes...)>& __f, nullptr_t) _NOEXCEPT {return (bool)__f;}

template <class _Rp, class... _ArgTypes>
inline _LIBCPP_INLINE_VISIBILITY
bool
operator!=(nullptr_t, const function<_Rp(_ArgTypes...)>& __f) _NOEXCEPT {return (bool)__f;}

template <class _Rp, class... _ArgTypes>
inline _LIBCPP_INLINE_VISIBILITY
void
swap(function<_Rp(_ArgTypes...)>& __x, function<_Rp(_ArgTypes...)>& __y) _NOEXCEPT
{return __x.swap(__y);}

template<class _Tp> struct __is_bind_expression : public false_type {};
template<class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_bind_expression
    : public __is_bind_expression<typename remove_cv<_Tp>::type> {};

template<class _Tp> struct __is_placeholder : public integral_constant<int, 0> {};
template<class _Tp> struct _LIBCPP_TYPE_VIS_ONLY is_placeholder
    : public __is_placeholder<typename remove_cv<_Tp>::type> {};

namespace placeholders
{

template <int _Np> struct __ph {};

_LIBCPP_FUNC_VIS extern __ph<1>   _1;
_LIBCPP_FUNC_VIS extern __ph<2>   _2;
_LIBCPP_FUNC_VIS extern __ph<3>   _3;
_LIBCPP_FUNC_VIS extern __ph<4>   _4;
_LIBCPP_FUNC_VIS extern __ph<5>   _5;
_LIBCPP_FUNC_VIS extern __ph<6>   _6;
_LIBCPP_FUNC_VIS extern __ph<7>   _7;
_LIBCPP_FUNC_VIS extern __ph<8>   _8;
_LIBCPP_FUNC_VIS extern __ph<9>   _9;
_LIBCPP_FUNC_VIS extern __ph<10> _10;

}  // placeholders

template<int _Np>
struct __is_placeholder<placeholders::__ph<_Np> >
    : public integral_constant<int, _Np> {};

template <class _Tp, class _Uj>
inline _LIBCPP_INLINE_VISIBILITY
_Tp&
__mu(reference_wrapper<_Tp> __t, _Uj&)
{
    return __t.get();
}

template <class _Ti, class ..._Uj, size_t ..._Indx>
inline _LIBCPP_INLINE_VISIBILITY
typename __invoke_of<_Ti&, _Uj...>::type
__mu_expand(_Ti& __ti, tuple<_Uj...>& __uj, __tuple_indices<_Indx...>)
{
    return __ti(_VSTD::forward<_Uj>(get<_Indx>(__uj))...);
}

template <class _Ti, class ..._Uj>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_bind_expression<_Ti>::value,
    typename __invoke_of<_Ti&, _Uj...>::type
>::type
__mu(_Ti& __ti, tuple<_Uj...>& __uj)
{
    typedef typename __make_tuple_indices<sizeof...(_Uj)>::type __indices;
    return  __mu_expand(__ti, __uj, __indices());
}

template <bool IsPh, class _Ti, class _Uj>
struct __mu_return2 {};

template <class _Ti, class _Uj>
struct __mu_return2<true, _Ti, _Uj>
{
    typedef typename tuple_element<is_placeholder<_Ti>::value - 1, _Uj>::type type;
};

template <class _Ti, class _Uj>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    0 < is_placeholder<_Ti>::value,
    typename __mu_return2<0 < is_placeholder<_Ti>::value, _Ti, _Uj>::type
>::type
__mu(_Ti&, _Uj& __uj)
{
    const size_t _Indx = is_placeholder<_Ti>::value - 1;
    return _VSTD::forward<typename tuple_element<_Indx, _Uj>::type>(get<_Indx>(__uj));
}

template <class _Ti, class _Uj>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    !is_bind_expression<_Ti>::value &&
    is_placeholder<_Ti>::value == 0 &&
    !__is_reference_wrapper<_Ti>::value,
    _Ti&
>::type
__mu(_Ti& __ti, _Uj&)
{
    return __ti;
}

template <class _Ti, bool IsReferenceWrapper, bool IsBindEx, bool IsPh,
          class _TupleUj>
struct ____mu_return;

template <bool _Invokable, class _Ti, class ..._Uj>
struct ____mu_return_invokable  // false
{
    typedef __nat type;
};

template <class _Ti, class ..._Uj>
struct ____mu_return_invokable<true, _Ti, _Uj...>
{
    typedef typename __invoke_of<_Ti&, _Uj...>::type type;
};

template <class _Ti, class ..._Uj>
struct ____mu_return<_Ti, false, true, false, tuple<_Uj...> >
    : public ____mu_return_invokable<__invokable<_Ti&, _Uj...>::value, _Ti, _Uj...>
{
};

template <class _Ti, class _TupleUj>
struct ____mu_return<_Ti, false, false, true, _TupleUj>
{
    typedef typename tuple_element<is_placeholder<_Ti>::value - 1,
                                   _TupleUj>::type&& type;
};

template <class _Ti, class _TupleUj>
struct ____mu_return<_Ti, true, false, false, _TupleUj>
{
    typedef typename _Ti::type& type;
};

template <class _Ti, class _TupleUj>
struct ____mu_return<_Ti, false, false, false, _TupleUj>
{
    typedef _Ti& type;
};

template <class _Ti, class _TupleUj>
struct __mu_return
    : public ____mu_return<_Ti,
                           __is_reference_wrapper<_Ti>::value,
                           is_bind_expression<_Ti>::value,
                           0 < is_placeholder<_Ti>::value &&
                           is_placeholder<_Ti>::value <= tuple_size<_TupleUj>::value,
                           _TupleUj>
{
};

template <class _Fp, class _BoundArgs, class _TupleUj>
struct _is_valid_bind_return
{
    static const bool value = false;
};

template <class _Fp, class ..._BoundArgs, class _TupleUj>
struct _is_valid_bind_return<_Fp, tuple<_BoundArgs...>, _TupleUj>
{
    static const bool value = __invokable<_Fp,
                    typename __mu_return<_BoundArgs, _TupleUj>::type...>::value;
};

template <class _Fp, class ..._BoundArgs, class _TupleUj>
struct _is_valid_bind_return<_Fp, const tuple<_BoundArgs...>, _TupleUj>
{
    static const bool value = __invokable<_Fp,
                    typename __mu_return<const _BoundArgs, _TupleUj>::type...>::value;
};

template <class _Fp, class _BoundArgs, class _TupleUj,
          bool = _is_valid_bind_return<_Fp, _BoundArgs, _TupleUj>::value>
struct __bind_return;

template <class _Fp, class ..._BoundArgs, class _TupleUj>
struct __bind_return<_Fp, tuple<_BoundArgs...>, _TupleUj, true>
{
    typedef typename __invoke_of
    <
        _Fp&,
        typename __mu_return
        <
            _BoundArgs,
            _TupleUj
        >::type...
    >::type type;
};

template <class _Fp, class ..._BoundArgs, class _TupleUj>
struct __bind_return<_Fp, const tuple<_BoundArgs...>, _TupleUj, true>
{
    typedef typename __invoke_of
    <
        _Fp&,
        typename __mu_return
        <
            const _BoundArgs,
            _TupleUj
        >::type...
    >::type type;
};

template <class _Fp, class _BoundArgs, size_t ..._Indx, class _Args>
inline _LIBCPP_INLINE_VISIBILITY
typename __bind_return<_Fp, _BoundArgs, _Args>::type
__apply_functor(_Fp& __f, _BoundArgs& __bound_args, __tuple_indices<_Indx...>,
                _Args&& __args)
{
    return __invoke(__f, __mu(get<_Indx>(__bound_args), __args)...);
}

template<class _Fp, class ..._BoundArgs>
class __bind
    : public __weak_result_type<typename decay<_Fp>::type>
{
protected:
    typedef typename decay<_Fp>::type _Fd;
    typedef tuple<typename decay<_BoundArgs>::type...> _Td;
private:
    _Fd __f_;
    _Td __bound_args_;

    typedef typename __make_tuple_indices<sizeof...(_BoundArgs)>::type __indices;
public:
#ifdef _LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS

    _LIBCPP_INLINE_VISIBILITY
    __bind(const __bind& __b)
        : __f_(__b.__f_),
          __bound_args_(__b.__bound_args_) {}

    _LIBCPP_INLINE_VISIBILITY
    __bind& operator=(const __bind& __b)
    {
        __f_ = __b.__f_;
        __bound_args_ = __b.__bound_args_;
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY
    __bind(__bind&& __b)
        : __f_(_VSTD::move(__b.__f_)),
          __bound_args_(_VSTD::move(__b.__bound_args_)) {}

    _LIBCPP_INLINE_VISIBILITY
    __bind& operator=(__bind&& __b)
    {
        __f_ = _VSTD::move(__b.__f_);
        __bound_args_ = _VSTD::move(__b.__bound_args_);
        return *this;
    }

#endif  // _LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS
# 2067 "/usr/include/c++/v1/functional" 3

    template <class _Gp, class ..._BA,
              class = typename enable_if
                               <
                                  is_constructible<_Fd, _Gp>::value &&
                                  !is_same<typename remove_reference<_Gp>::type,
                                           __bind>::value
                               >::type>
      _LIBCPP_INLINE_VISIBILITY
      explicit __bind(_Gp&& __f, _BA&& ...__bound_args)
        : __f_(_VSTD::forward<_Gp>(__f)),
          __bound_args_(_VSTD::forward<_BA>(__bound_args)...) {}

    template <class ..._Args>
        _LIBCPP_INLINE_VISIBILITY
        typename __bind_return<_Fd, _Td, tuple<_Args&&...> >::type
        operator()(_Args&& ...__args)
        {
            return __apply_functor(__f_, __bound_args_, __indices(),
                                  tuple<_Args&&...>(_VSTD::forward<_Args>(__args)...));
        }

    template <class ..._Args>
        _LIBCPP_INLINE_VISIBILITY
        typename __bind_return<const _Fd, const _Td, tuple<_Args&&...> >::type
        operator()(_Args&& ...__args) const
        {
            return __apply_functor(__f_, __bound_args_, __indices(),
                                   tuple<_Args&&...>(_VSTD::forward<_Args>(__args)...));
        }
};

template<class _Fp, class ..._BoundArgs>
struct __is_bind_expression<__bind<_Fp, _BoundArgs...> > : public true_type {};

template<class _Rp, class _Fp, class ..._BoundArgs>
class __bind_r
    : public __bind<_Fp, _BoundArgs...>
{
    typedef __bind<_Fp, _BoundArgs...> base;
    typedef typename base::_Fd _Fd;
    typedef typename base::_Td _Td;
public:
    typedef _Rp result_type;

#ifdef _LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS

    _LIBCPP_INLINE_VISIBILITY
    __bind_r(const __bind_r& __b)
        : base(_VSTD::forward<const base&>(__b)) {}

    _LIBCPP_INLINE_VISIBILITY
    __bind_r& operator=(const __bind_r& __b)
    {
        base::operator=(_VSTD::forward<const base&>(__b));
        return *this;
    }

    _LIBCPP_INLINE_VISIBILITY
    __bind_r(__bind_r&& __b)
        : base(_VSTD::forward<base>(__b)) {}

    _LIBCPP_INLINE_VISIBILITY
    __bind_r& operator=(__bind_r&& __b)
    {
        base::operator=(_VSTD::forward<base>(__b));
        return *this;
    }

#endif  // _LIBCPP_HAS_NO_DEFAULTED_FUNCTIONS
# 2137 "/usr/include/c++/v1/functional" 3

    template <class _Gp, class ..._BA,
              class = typename enable_if
                               <
                                  is_constructible<_Fd, _Gp>::value &&
                                  !is_same<typename remove_reference<_Gp>::type,
                                           __bind_r>::value
                               >::type>
      _LIBCPP_INLINE_VISIBILITY
      explicit __bind_r(_Gp&& __f, _BA&& ...__bound_args)
        : base(_VSTD::forward<_Gp>(__f),
               _VSTD::forward<_BA>(__bound_args)...) {}

    template <class ..._Args>
        _LIBCPP_INLINE_VISIBILITY
        typename enable_if
        <
            is_convertible<typename __bind_return<_Fd, _Td, tuple<_Args&&...> >::type,
                           result_type>::value,
            result_type
        >::type
        operator()(_Args&& ...__args)
        {
            return base::operator()(_VSTD::forward<_Args>(__args)...);
        }

    template <class ..._Args>
        _LIBCPP_INLINE_VISIBILITY
        typename enable_if
        <
            is_convertible<typename __bind_return<const _Fd, const _Td, tuple<_Args&&...> >::type,
                           result_type>::value,
            result_type
        >::type
        operator()(_Args&& ...__args) const
        {
            return base::operator()(_VSTD::forward<_Args>(__args)...);
        }
};

template<class _Rp, class _Fp, class ..._BoundArgs>
struct __is_bind_expression<__bind_r<_Rp, _Fp, _BoundArgs...> > : public true_type {};

template<class _Fp, class ..._BoundArgs>
inline _LIBCPP_INLINE_VISIBILITY
__bind<_Fp, _BoundArgs...>
bind(_Fp&& __f, _BoundArgs&&... __bound_args)
{
    typedef __bind<_Fp, _BoundArgs...> type;
    return type(_VSTD::forward<_Fp>(__f), _VSTD::forward<_BoundArgs>(__bound_args)...);
}

template<class _Rp, class _Fp, class ..._BoundArgs>
inline _LIBCPP_INLINE_VISIBILITY
__bind_r<_Rp, _Fp, _BoundArgs...>
bind(_Fp&& __f, _BoundArgs&&... __bound_args)
{
    typedef __bind_r<_Rp, _Fp, _BoundArgs...> type;
    return type(_VSTD::forward<_Fp>(__f), _VSTD::forward<_BoundArgs>(__bound_args)...);
}

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 2199 "/usr/include/c++/v1/functional" 3

template <>
struct _LIBCPP_TYPE_VIS_ONLY hash<bool>
    : public unary_function<bool, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(bool __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TYPE_VIS_ONLY hash<char>
    : public unary_function<char, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(char __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TYPE_VIS_ONLY hash<signed char>
    : public unary_function<signed char, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(signed char __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TYPE_VIS_ONLY hash<unsigned char>
    : public unary_function<unsigned char, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(unsigned char __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

#ifndef _LIBCPP_HAS_NO_UNICODE_CHARS

template <>
struct _LIBCPP_TYPE_VIS_ONLY hash<char16_t>
    : public unary_function<char16_t, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(char16_t __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TYPE_VIS_ONLY hash<char32_t>
    : public unary_function<char32_t, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(char32_t __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

#endif  // _LIBCPP_HAS_NO_UNICODE_CHARS
# 2251 "/usr/include/c++/v1/functional" 3

template <>
struct _LIBCPP_TYPE_VIS_ONLY hash<wchar_t>
    : public unary_function<wchar_t, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(wchar_t __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TYPE_VIS_ONLY hash<short>
    : public unary_function<short, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(short __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TYPE_VIS_ONLY hash<unsigned short>
    : public unary_function<unsigned short, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(unsigned short __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TYPE_VIS_ONLY hash<int>
    : public unary_function<int, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(int __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TYPE_VIS_ONLY hash<unsigned int>
    : public unary_function<unsigned int, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(unsigned int __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TYPE_VIS_ONLY hash<long>
    : public unary_function<long, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(long __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TYPE_VIS_ONLY hash<unsigned long>
    : public unary_function<unsigned long, size_t>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(unsigned long __v) const _NOEXCEPT {return static_cast<size_t>(__v);}
};

template <>
struct _LIBCPP_TYPE_VIS_ONLY hash<long long>
    : public __scalar_hash<long long>
{
};

template <>
struct _LIBCPP_TYPE_VIS_ONLY hash<unsigned long long>
    : public __scalar_hash<unsigned long long>
{
};

template <>
struct _LIBCPP_TYPE_VIS_ONLY hash<float>
    : public __scalar_hash<float>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(float __v) const _NOEXCEPT
    {
        // -0.0 and 0.0 should return same hash
       if (__v == 0)
           return 0;
        return __scalar_hash<float>::operator()(__v);
    }
};

template <>
struct _LIBCPP_TYPE_VIS_ONLY hash<double>
    : public __scalar_hash<double>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(double __v) const _NOEXCEPT
    {
        // -0.0 and 0.0 should return same hash
       if (__v == 0)
           return 0;
        return __scalar_hash<double>::operator()(__v);
    }
};

template <>
struct _LIBCPP_TYPE_VIS_ONLY hash<long double>
    : public __scalar_hash<long double>
{
    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(long double __v) const _NOEXCEPT
    {
        // -0.0 and 0.0 should return same hash
        if (__v == 0)
            return 0;
#if defined(__i386__)
        // Zero out padding bits
        union
        {
            long double __t;
            struct
            {
                size_t __a;
                size_t __b;
                size_t __c;
                size_t __d;
            };
        } __u;
        __u.__a = 0;
        __u.__b = 0;
        __u.__c = 0;
        __u.__d = 0;
        __u.__t = __v;
        return __u.__a ^ __u.__b ^ __u.__c ^ __u.__d;
#elif defined(__x86_64__)
# 2378 "/usr/include/c++/v1/functional" 3
        // Zero out padding bits
        union
        {
            long double __t;
            struct
            {
                size_t __a;
                size_t __b;
            };
        } __u;
        __u.__a = 0;
        __u.__b = 0;
        __u.__t = __v;
        return __u.__a ^ __u.__b;
#else
# 2393 "/usr/include/c++/v1/functional" 3
        return __scalar_hash<long double>::operator()(__v);
#endif
# 2395 "/usr/include/c++/v1/functional" 3
    }
};

#if _LIBCPP_STD_VER > 11
template <class _Tp>
struct _LIBCPP_TYPE_VIS_ONLY hash
    : public unary_function<_Tp, size_t>
{
    static_assert(is_enum<_Tp>::value, "This hash only works for enumeration types");

    _LIBCPP_INLINE_VISIBILITY
    size_t operator()(_Tp __v) const _NOEXCEPT
    {
        typedef typename underlying_type<_Tp>::type type;
        return hash<type>{}(static_cast<type>(__v));
    }
};
#endif
# 2413 "/usr/include/c++/v1/functional" 3

// struct hash<T*> in <memory>

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_FUNCTIONAL
# 2419 "/usr/include/c++/v1/functional" 3
# 178 "/usr/include/c++/v1/mutex" 2 3
#ifndef _LIBCPP_HAS_NO_VARIADICS
#if 0 /* expanded by -frewrite-includes */
#include <tuple>
#endif /* expanded by -frewrite-includes */
# 180 "/usr/include/c++/v1/mutex" 3
#endif
# 181 "/usr/include/c++/v1/mutex" 3

#if 0 /* expanded by -frewrite-includes */
#include <__undef_min_max>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/__undef_min_max" 1 3
// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifdef min
#if defined(_MSC_VER) && ! defined(__clang__)
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 16 "/usr/include/c++/v1/__undef_min_max" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 18 "/usr/include/c++/v1/__undef_min_max" 3
#undef min
#endif
# 20 "/usr/include/c++/v1/__undef_min_max" 3

#ifdef max
#if defined(_MSC_VER) && ! defined(__clang__)
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 26 "/usr/include/c++/v1/__undef_min_max" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 28 "/usr/include/c++/v1/__undef_min_max" 3
#undef max
#endif
# 30 "/usr/include/c++/v1/__undef_min_max" 3
# 183 "/usr/include/c++/v1/mutex" 2 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 186 "/usr/include/c++/v1/mutex" 3
#endif
# 187 "/usr/include/c++/v1/mutex" 3

_LIBCPP_BEGIN_NAMESPACE_STD

class _LIBCPP_TYPE_VIS recursive_mutex
{
    pthread_mutex_t __m_;

public:
     recursive_mutex();
     ~recursive_mutex();

private:
    recursive_mutex(const recursive_mutex&); // = delete;
    recursive_mutex& operator=(const recursive_mutex&); // = delete;

public:
    void lock();
    bool try_lock() _NOEXCEPT;
    void unlock()  _NOEXCEPT;

    typedef pthread_mutex_t* native_handle_type;
    _LIBCPP_INLINE_VISIBILITY
    native_handle_type native_handle() {return &__m_;}
};

class _LIBCPP_TYPE_VIS timed_mutex
{
    mutex              __m_;
    condition_variable __cv_;
    bool               __locked_;
public:
     timed_mutex();
     ~timed_mutex();

private:
    timed_mutex(const timed_mutex&); // = delete;
    timed_mutex& operator=(const timed_mutex&); // = delete;

public:
    void lock();
    bool try_lock() _NOEXCEPT;
    template <class _Rep, class _Period>
        _LIBCPP_INLINE_VISIBILITY
        bool try_lock_for(const chrono::duration<_Rep, _Period>& __d)
            {return try_lock_until(chrono::steady_clock::now() + __d);}
    template <class _Clock, class _Duration>
        bool try_lock_until(const chrono::time_point<_Clock, _Duration>& __t);
    void unlock() _NOEXCEPT;
};

template <class _Clock, class _Duration>
bool
timed_mutex::try_lock_until(const chrono::time_point<_Clock, _Duration>& __t)
{
    using namespace chrono;
    unique_lock<mutex> __lk(__m_);
    bool no_timeout = _Clock::now() < __t;
    while (no_timeout && __locked_)
        no_timeout = __cv_.wait_until(__lk, __t) == cv_status::no_timeout;
    if (!__locked_)
    {
        __locked_ = true;
        return true;
    }
    return false;
}

class _LIBCPP_TYPE_VIS recursive_timed_mutex
{
    mutex              __m_;
    condition_variable __cv_;
    size_t             __count_;
    pthread_t          __id_;
public:
     recursive_timed_mutex();
     ~recursive_timed_mutex();

private:
    recursive_timed_mutex(const recursive_timed_mutex&); // = delete;
    recursive_timed_mutex& operator=(const recursive_timed_mutex&); // = delete;

public:
    void lock();
    bool try_lock() _NOEXCEPT;
    template <class _Rep, class _Period>
        _LIBCPP_INLINE_VISIBILITY
        bool try_lock_for(const chrono::duration<_Rep, _Period>& __d)
            {return try_lock_until(chrono::steady_clock::now() + __d);}
    template <class _Clock, class _Duration>
        bool try_lock_until(const chrono::time_point<_Clock, _Duration>& __t);
    void unlock() _NOEXCEPT;
};

template <class _Clock, class _Duration>
bool
recursive_timed_mutex::try_lock_until(const chrono::time_point<_Clock, _Duration>& __t)
{
    using namespace chrono;
    pthread_t __id = pthread_self();
    unique_lock<mutex> lk(__m_);
    if (pthread_equal(__id, __id_))
    {
        if (__count_ == numeric_limits<size_t>::max())
            return false;
        ++__count_;
        return true;
    }
    bool no_timeout = _Clock::now() < __t;
    while (no_timeout && __count_ != 0)
        no_timeout = __cv_.wait_until(lk, __t) == cv_status::no_timeout;
    if (__count_ == 0)
    {
        __count_ = 1;
        __id_ = __id;
        return true;
    }
    return false;
}

template <class _L0, class _L1>
int
try_lock(_L0& __l0, _L1& __l1)
{
    unique_lock<_L0> __u0(__l0, try_to_lock);
    if (__u0.owns_lock())
    {
        if (__l1.try_lock())
        {
            __u0.release();
            return -1;
        }
        else
            return 1;
    }
    return 0;
}

#ifndef _LIBCPP_HAS_NO_VARIADICS

template <class _L0, class _L1, class _L2, class... _L3>
int
try_lock(_L0& __l0, _L1& __l1, _L2& __l2, _L3&... __l3)
{
    int __r = 0;
    unique_lock<_L0> __u0(__l0, try_to_lock);
    if (__u0.owns_lock())
    {
        __r = try_lock(__l1, __l2, __l3...);
        if (__r == -1)
            __u0.release();
        else
            ++__r;
    }
    return __r;
}

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 344 "/usr/include/c++/v1/mutex" 3

template <class _L0, class _L1>
void
lock(_L0& __l0, _L1& __l1)
{
    while (true)
    {
        {
            unique_lock<_L0> __u0(__l0);
            if (__l1.try_lock())
            {
                __u0.release();
                break;
            }
        }
        sched_yield();
        {
            unique_lock<_L1> __u1(__l1);
            if (__l0.try_lock())
            {
                __u1.release();
                break;
            }
        }
        sched_yield();
    }
}

#ifndef _LIBCPP_HAS_NO_VARIADICS

template <class _L0, class _L1, class _L2, class ..._L3>
void
__lock_first(int __i, _L0& __l0, _L1& __l1, _L2& __l2, _L3& ...__l3)
{
    while (true)
    {
        switch (__i)
        {
        case 0:
            {
                unique_lock<_L0> __u0(__l0);
                __i = try_lock(__l1, __l2, __l3...);
                if (__i == -1)
                {
                    __u0.release();
                    return;
                }
            }
            ++__i;
            sched_yield();
            break;
        case 1:
            {
                unique_lock<_L1> __u1(__l1);
                __i = try_lock(__l2, __l3..., __l0);
                if (__i == -1)
                {
                    __u1.release();
                    return;
                }
            }
            if (__i == sizeof...(_L3) + 1)
                __i = 0;
            else
                __i += 2;
            sched_yield();
            break;
        default:
            __lock_first(__i - 2, __l2, __l3..., __l0, __l1);
            return;
        }
    }
}

template <class _L0, class _L1, class _L2, class ..._L3>
inline _LIBCPP_INLINE_VISIBILITY
void
lock(_L0& __l0, _L1& __l1, _L2& __l2, _L3& ...__l3)
{
    __lock_first(0, __l0, __l1, __l2, __l3...);
}

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 427 "/usr/include/c++/v1/mutex" 3

struct _LIBCPP_TYPE_VIS once_flag;

#ifndef _LIBCPP_HAS_NO_VARIADICS

template<class _Callable, class... _Args>
_LIBCPP_INLINE_VISIBILITY
void call_once(once_flag&, _Callable&&, _Args&&...);

#else  // _LIBCPP_HAS_NO_VARIADICS
# 437 "/usr/include/c++/v1/mutex" 3

template<class _Callable>
_LIBCPP_INLINE_VISIBILITY
void call_once(once_flag&, _Callable);

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 443 "/usr/include/c++/v1/mutex" 3

struct _LIBCPP_TYPE_VIS_ONLY once_flag
{
    _LIBCPP_INLINE_VISIBILITY
    _LIBCPP_CONSTEXPR
        once_flag() _NOEXCEPT : __state_(0) {}

private:
    once_flag(const once_flag&); // = delete;
    once_flag& operator=(const once_flag&); // = delete;

    unsigned long __state_;

#ifndef _LIBCPP_HAS_NO_VARIADICS
    template<class _Callable, class... _Args>
    friend
    void call_once(once_flag&, _Callable&&, _Args&&...);
#else  // _LIBCPP_HAS_NO_VARIADICS
# 461 "/usr/include/c++/v1/mutex" 3
    template<class _Callable>
    friend
    void call_once(once_flag&, _Callable);
#endif  // _LIBCPP_HAS_NO_VARIADICS
# 465 "/usr/include/c++/v1/mutex" 3
};

#ifndef _LIBCPP_HAS_NO_VARIADICS

template <class _Fp>
class __call_once_param
{
    _Fp __f_;
public:
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    _LIBCPP_INLINE_VISIBILITY
    explicit __call_once_param(_Fp&& __f) : __f_(_VSTD::move(__f)) {}
#else
# 478 "/usr/include/c++/v1/mutex" 3
    _LIBCPP_INLINE_VISIBILITY
    explicit __call_once_param(const _Fp& __f) : __f_(__f) {}
#endif
# 481 "/usr/include/c++/v1/mutex" 3

    _LIBCPP_INLINE_VISIBILITY
    void operator()()
    {
        typedef typename __make_tuple_indices<tuple_size<_Fp>::value, 1>::type _Index;
        __execute(_Index());
    }

private:
    template <size_t ..._Indices>
    _LIBCPP_INLINE_VISIBILITY
    void __execute(__tuple_indices<_Indices...>)
    {
        __invoke(_VSTD::move(_VSTD::get<0>(__f_)), _VSTD::move(_VSTD::get<_Indices>(__f_))...);
    }
};

#else
# 499 "/usr/include/c++/v1/mutex" 3

template <class _Fp>
class __call_once_param
{
    _Fp __f_;
public:
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    _LIBCPP_INLINE_VISIBILITY
    explicit __call_once_param(_Fp&& __f) : __f_(_VSTD::move(__f)) {}
#else
# 509 "/usr/include/c++/v1/mutex" 3
    _LIBCPP_INLINE_VISIBILITY
    explicit __call_once_param(const _Fp& __f) : __f_(__f) {}
#endif
# 512 "/usr/include/c++/v1/mutex" 3

    _LIBCPP_INLINE_VISIBILITY
    void operator()()
    {
        __f_();
    }
};

#endif
# 521 "/usr/include/c++/v1/mutex" 3

template <class _Fp>
void
__call_once_proxy(void* __vp)
{
    __call_once_param<_Fp>* __p = static_cast<__call_once_param<_Fp>*>(__vp);
    (*__p)();
}

_LIBCPP_FUNC_VIS void __call_once(volatile unsigned long&, void*, void(*)(void*));

#ifndef _LIBCPP_HAS_NO_VARIADICS

template<class _Callable, class... _Args>
inline _LIBCPP_INLINE_VISIBILITY
void
call_once(once_flag& __flag, _Callable&& __func, _Args&&... __args)
{
    if (__flag.__state_ != ~0ul)
    {
        typedef tuple<typename decay<_Callable>::type, typename decay<_Args>::type...> _Gp;
        __call_once_param<_Gp> __p(_Gp(__decay_copy(_VSTD::forward<_Callable>(__func)),
                                __decay_copy(_VSTD::forward<_Args>(__args))...));
        __call_once(__flag.__state_, &__p, &__call_once_proxy<_Gp>);
    }
}

#else  // _LIBCPP_HAS_NO_VARIADICS
# 549 "/usr/include/c++/v1/mutex" 3

template<class _Callable>
inline _LIBCPP_INLINE_VISIBILITY
void
call_once(once_flag& __flag, _Callable __func)
{
    if (__flag.__state_ != ~0ul)
    {
        __call_once_param<_Callable> __p(__func);
        __call_once(__flag.__state_, &__p, &__call_once_proxy<_Callable>);
    }
}

#endif  // _LIBCPP_HAS_NO_VARIADICS
# 563 "/usr/include/c++/v1/mutex" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_MUTEX
# 567 "/usr/include/c++/v1/mutex" 3
# 19 "/usr/include/c++/v1/__locale" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <cstdint>
#endif /* expanded by -frewrite-includes */
# 20 "/usr/include/c++/v1/__locale" 3
#if 0 /* expanded by -frewrite-includes */
#include <cctype>
#endif /* expanded by -frewrite-includes */
# 21 "/usr/include/c++/v1/__locale" 3
#if 0 /* expanded by -frewrite-includes */
#include <locale.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/locale.h" 1 3 4
/*
 * Copyright (c) 1991, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)locale.h	8.1 (Berkeley) 6/2/93
 * $FreeBSD: head/include/locale.h 232498 2012-03-04 15:31:13Z theraven $
 */

#ifndef _LOCALE_H_
#define _LOCALE_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/_null.h>
#endif /* expanded by -frewrite-includes */
# 37 "/usr/include/locale.h" 3 4

struct lconv {
	char	*decimal_point;
	char	*thousands_sep;
	char	*grouping;
	char	*int_curr_symbol;
	char	*currency_symbol;
	char	*mon_decimal_point;
	char	*mon_thousands_sep;
	char	*mon_grouping;
	char	*positive_sign;
	char	*negative_sign;
	char	int_frac_digits;
	char	frac_digits;
	char	p_cs_precedes;
	char	p_sep_by_space;
	char	n_cs_precedes;
	char	n_sep_by_space;
	char	p_sign_posn;
	char	n_sign_posn;
	char	int_p_cs_precedes;
	char	int_n_cs_precedes;
	char	int_p_sep_by_space;
	char	int_n_sep_by_space;
	char	int_p_sign_posn;
	char	int_n_sign_posn;
};

#define	LC_ALL		0
#define	LC_COLLATE	1
#define	LC_CTYPE	2
#define	LC_MONETARY	3
#define	LC_NUMERIC	4
#define	LC_TIME		5
#define	LC_MESSAGES	6

#define	_LC_LAST	7		/* marks end */

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 76 "/usr/include/locale.h" 3 4

__BEGIN_DECLS
struct lconv	*localeconv(void);
char		*setlocale(int, const char *);

#if __POSIX_VISIBLE >= 200809
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_locale.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/xlocale/_locale.h" 1 3 4
/*-
 * Copyright (c) 2011, 2012 The FreeBSD Foundation
 * All rights reserved.
 *
 * This software was developed by David Chisnall under sponsorship from
 * the FreeBSD Foundation.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/include/xlocale/_locale.h 231673 2012-02-14 12:03:23Z theraven $
 */

#ifndef _XLOCALE_LOCALE_H
#define _XLOCALE_LOCALE_H

#define LC_COLLATE_MASK  (1<<0)
#define LC_CTYPE_MASK    (1<<1)
#define LC_MESSAGES_MASK (1<<2)
#define LC_MONETARY_MASK (1<<3)
#define LC_NUMERIC_MASK  (1<<4)
#define LC_TIME_MASK     (1<<5)
#define LC_ALL_MASK      (LC_COLLATE_MASK | LC_CTYPE_MASK | LC_MESSAGES_MASK | \
			  LC_MONETARY_MASK | LC_NUMERIC_MASK | LC_TIME_MASK)
#define LC_GLOBAL_LOCALE ((locale_t)-1)

#ifndef _LOCALE_T_DEFINED
#define _LOCALE_T_DEFINED
typedef struct	_xlocale *locale_t;
#endif
# 49 "/usr/include/xlocale/_locale.h" 3 4

locale_t	 duplocale(locale_t base);
int		 freelocale(locale_t loc);
locale_t	 newlocale(int mask, const char *locale, locale_t base);
const char	*querylocale(int mask, locale_t loc);
locale_t	 uselocale(locale_t loc);

#endif /* _XLOCALE_LOCALE_H */
# 57 "/usr/include/xlocale/_locale.h" 3 4
# 83 "/usr/include/locale.h" 2 3 4
#endif
# 84 "/usr/include/locale.h" 3 4
__END_DECLS


#endif /* _LOCALE_H_ */
# 88 "/usr/include/locale.h" 3 4
# 22 "/usr/include/c++/v1/__locale" 2 3
#if defined(_LIBCPP_MSVCRT) || defined(__MINGW32__)
#if 0 /* expanded by -frewrite-includes */
# include <support/win32/locale_win32.h>
#endif /* expanded by -frewrite-includes */
# 24 "/usr/include/c++/v1/__locale" 3
#elif _AIX
# 25 "/usr/include/c++/v1/__locale" 3
#if 0 /* expanded by -frewrite-includes */
# include <support/ibm/xlocale.h>
#endif /* expanded by -frewrite-includes */
# 26 "/usr/include/c++/v1/__locale" 3
#elif (defined(__GLIBC__) || defined(__APPLE__) || defined(__FreeBSD__) || defined(__sun__)) || defined(__EMSCRIPTEN__) || defined(__IBMCPP__)
# 27 "/usr/include/c++/v1/__locale" 3
#if 0 /* expanded by -frewrite-includes */
# include <xlocale.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/xlocale.h" 1 3 4
/*-
 * Copyright (c) 2011, 2012 The FreeBSD Foundation
 * All rights reserved.
 *
 * This software was developed by David Chisnall under sponsorship from
 * the FreeBSD Foundation.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/include/xlocale.h 232498 2012-03-04 15:31:13Z theraven $
 */

#ifndef _XLOCALE_H_
#define _XLOCALE_H_

#if 0 /* expanded by -frewrite-includes */
#include <locale.h>
#endif /* expanded by -frewrite-includes */
# 36 "/usr/include/xlocale.h" 3 4
__BEGIN_DECLS
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_locale.h>
#endif /* expanded by -frewrite-includes */
# 38 "/usr/include/xlocale.h" 3 4

#ifdef _STRING_H_
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_string.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/xlocale/_string.h" 1 3 4
/*-
 * Copyright (c) 2011, 2012 The FreeBSD Foundation
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/include/xlocale/_string.h 266865 2014-05-30 01:09:07Z pfg $
 */

#ifndef _LOCALE_T_DEFINED
#define _LOCALE_T_DEFINED
typedef struct	_xlocale *locale_t;
#endif
# 33 "/usr/include/xlocale/_string.h" 3 4

/*
 * This file is included from both string.h and xlocale.h.  We need to expose
 * the declarations unconditionally if we are included from xlocale.h, but only
 * if we are in POSIX2008 mode if included from string.h.
 */

#ifndef _XLOCALE_STRING1_H
#define _XLOCALE_STRING1_H

/*
 * POSIX2008 functions
 */
int	 strcoll_l(const char *, const char *, locale_t);
size_t	 strxfrm_l(char *, const char *, size_t, locale_t);
#endif /* _XLOCALE_STRING1_H */
# 49 "/usr/include/xlocale/_string.h" 3 4

/*
 * xlocale extensions
 */
#ifdef _XLOCALE_H_
#ifndef _XLOCALE_STRING2_H
#define _XLOCALE_STRING2_H
char	*strcasestr_l(const char *, const char *, locale_t);

#endif /* _XLOCALE_STRING2_H */
# 59 "/usr/include/xlocale/_string.h" 3 4
#endif /* _XLOCALE_H_ */
# 60 "/usr/include/xlocale/_string.h" 3 4
# 41 "/usr/include/xlocale.h" 2 3 4
#endif
# 42 "/usr/include/xlocale.h" 3 4

#ifdef _INTTYPES_H_
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_inttypes.h>
#endif /* expanded by -frewrite-includes */
# 45 "/usr/include/xlocale.h" 3 4
#endif
# 46 "/usr/include/xlocale.h" 3 4

#ifdef _MONETARY_H_
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_monetary.h>
#endif /* expanded by -frewrite-includes */
# 49 "/usr/include/xlocale.h" 3 4
#endif
# 50 "/usr/include/xlocale.h" 3 4

#ifdef _STDLIB_H_
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_stdlib.h>
#endif /* expanded by -frewrite-includes */
# 53 "/usr/include/xlocale.h" 3 4
#endif
# 54 "/usr/include/xlocale.h" 3 4

#ifdef _TIME_H_
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_time.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/xlocale/_time.h" 1 3 4
/*-
 * Copyright (c) 2011, 2012 The FreeBSD Foundation
 * All rights reserved.
 *
 * This software was developed by David Chisnall under sponsorship from
 * the FreeBSD Foundation.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/include/xlocale/_time.h 231673 2012-02-14 12:03:23Z theraven $
 */

#ifndef _LOCALE_T_DEFINED
#define _LOCALE_T_DEFINED
typedef struct	_xlocale *locale_t;
#endif
# 36 "/usr/include/xlocale/_time.h" 3 4

/*
 * This file is included from both locale.h and xlocale.h.  We need to expose
 * the declarations unconditionally if we are included from xlocale.h, but only
 * if we are in POSIX2008 mode if included from locale.h.
 */
#ifndef _XLOCALE_LOCALE1_H
#define _XLOCALE_LOCALE1_H

size_t	 strftime_l(char * __restrict, size_t, const char * __restrict,
	    const struct tm * __restrict, locale_t) __strftimelike(3, 0);

#endif /* _XLOCALE_LOCALE1_H */
# 49 "/usr/include/xlocale/_time.h" 3 4

#ifdef _XLOCALE_H_
#ifndef _XLOCALE_LOCALE2_H
#define _XLOCALE_LOCALE2_H

char	*strptime_l(const char * __restrict, const char * __restrict,
           struct tm * __restrict, locale_t);

#endif /* _XLOCALE_LOCALE2_H */
# 58 "/usr/include/xlocale/_time.h" 3 4
#endif /* _XLOCALE_H_ */
# 59 "/usr/include/xlocale/_time.h" 3 4
# 57 "/usr/include/xlocale.h" 2 3 4
#endif
# 58 "/usr/include/xlocale.h" 3 4

#ifdef _LANGINFO_H_
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_langinfo.h>
#endif /* expanded by -frewrite-includes */
# 61 "/usr/include/xlocale.h" 3 4
#endif
# 62 "/usr/include/xlocale.h" 3 4

#ifdef _CTYPE_H_
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_ctype.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/xlocale/_ctype.h" 1 3 4
/*-
 * Copyright (c) 2011 The FreeBSD Foundation
 * All rights reserved.
 *
 * This software was developed by David Chisnall under sponsorship from
 * the FreeBSD Foundation.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/include/xlocale/_ctype.h 243032 2012-11-14 17:44:37Z demon $
 */


#if	(defined(_XLOCALE_WCTYPES) && !defined(_XLOCALE_WCTYPE_H)) || \
	(!defined(_XLOCALE_WCTYPES) && !defined(_XLOCALE_CTYPE_H))

#ifdef _XLOCALE_WCTYPES
#define _XLOCALE_WCTYPE_H
#else
# 39 "/usr/include/xlocale/_ctype.h" 3 4
#define _XLOCALE_CTYPE_H
#endif
# 41 "/usr/include/xlocale/_ctype.h" 3 4

#ifndef _LOCALE_T_DEFINED
#define _LOCALE_T_DEFINED
typedef struct	_xlocale *locale_t;
#endif
# 46 "/usr/include/xlocale/_ctype.h" 3 4

#ifndef _XLOCALE_RUN_FUNCTIONS_DEFINED
#define _XLOCALE_RUN_FUNCTIONS_DEFINED 1
unsigned long	 ___runetype_l(__ct_rune_t, locale_t) __pure;
__ct_rune_t	 ___tolower_l(__ct_rune_t, locale_t) __pure;
__ct_rune_t	 ___toupper_l(__ct_rune_t, locale_t) __pure;
_RuneLocale	*__runes_for_locale(locale_t, int*);
#endif
# 54 "/usr/include/xlocale/_ctype.h" 3 4

#ifndef _XLOCALE_INLINE
#if defined(__GNUC__) && !defined(__GNUC_STDC_INLINE__)
/* GNU89 inline has nonstandard semantics. */
#define _XLOCALE_INLINE extern __inline
#else
# 60 "/usr/include/xlocale/_ctype.h" 3 4
/* Hack to work around people who define inline away */
#ifdef inline
#define _XLOCALE_INLINE static __inline
#else
# 64 "/usr/include/xlocale/_ctype.h" 3 4
/* Define with C++ / C99 compatible semantics */
#define _XLOCALE_INLINE inline
#endif
# 67 "/usr/include/xlocale/_ctype.h" 3 4
#endif
# 68 "/usr/include/xlocale/_ctype.h" 3 4
#endif /* _XLOCALE_INLINE */
# 69 "/usr/include/xlocale/_ctype.h" 3 4

#ifdef _XLOCALE_WCTYPES
_XLOCALE_INLINE int
__maskrune_l(__ct_rune_t __c, unsigned long __f, locale_t __loc);
_XLOCALE_INLINE int
__istype_l(__ct_rune_t __c, unsigned long __f, locale_t __loc);

_XLOCALE_INLINE int
__maskrune_l(__ct_rune_t __c, unsigned long __f, locale_t __loc)
{
	int __limit;
	_RuneLocale *runes = __runes_for_locale(__loc, &__limit);
	return ((__c < 0 || __c >= _CACHED_RUNES) ? ___runetype_l(__c, __loc) :
	        runes->__runetype[__c]) & __f;
}

_XLOCALE_INLINE int
__istype_l(__ct_rune_t __c, unsigned long __f, locale_t __loc)
{
	return (!!__maskrune_l(__c, __f, __loc));
}

#define XLOCALE_ISCTYPE(fname, cat) \
		_XLOCALE_INLINE int isw##fname##_l(int, locale_t);\
		_XLOCALE_INLINE int isw##fname##_l(int __c, locale_t __l)\
		{ return __istype_l(__c, cat, __l); }
#else
# 96 "/usr/include/xlocale/_ctype.h" 3 4
_XLOCALE_INLINE int
__sbmaskrune_l(__ct_rune_t __c, unsigned long __f, locale_t __loc);
_XLOCALE_INLINE int
__sbistype_l(__ct_rune_t __c, unsigned long __f, locale_t __loc);

_XLOCALE_INLINE int
__sbmaskrune_l(__ct_rune_t __c, unsigned long __f, locale_t __loc)
{
	int __limit;
	_RuneLocale *runes = __runes_for_locale(__loc, &__limit);
	return (__c < 0 || __c >= __limit) ? 0 :
	       runes->__runetype[__c] & __f;
}

_XLOCALE_INLINE int
__sbistype_l(__ct_rune_t __c, unsigned long __f, locale_t __loc)
{
	return (!!__sbmaskrune_l(__c, __f, __loc));
}

#define XLOCALE_ISCTYPE(__fname, __cat) \
		_XLOCALE_INLINE int is##__fname##_l(int, locale_t); \
		_XLOCALE_INLINE int is##__fname##_l(int __c, locale_t __l)\
		{ return __sbistype_l(__c, __cat, __l); }
#endif
# 121 "/usr/include/xlocale/_ctype.h" 3 4

XLOCALE_ISCTYPE(alnum, _CTYPE_A|_CTYPE_D)
XLOCALE_ISCTYPE(alpha, _CTYPE_A)
XLOCALE_ISCTYPE(blank, _CTYPE_B)
XLOCALE_ISCTYPE(cntrl, _CTYPE_C)
XLOCALE_ISCTYPE(digit, _CTYPE_D)
XLOCALE_ISCTYPE(graph, _CTYPE_G)
XLOCALE_ISCTYPE(hexnumber, _CTYPE_X)
XLOCALE_ISCTYPE(ideogram, _CTYPE_I)
XLOCALE_ISCTYPE(lower, _CTYPE_L)
XLOCALE_ISCTYPE(number, _CTYPE_D)
XLOCALE_ISCTYPE(phonogram, _CTYPE_Q)
XLOCALE_ISCTYPE(print, _CTYPE_R)
XLOCALE_ISCTYPE(punct, _CTYPE_P)
XLOCALE_ISCTYPE(rune, 0xFFFFFF00L)
XLOCALE_ISCTYPE(space, _CTYPE_S)
XLOCALE_ISCTYPE(special, _CTYPE_T)
XLOCALE_ISCTYPE(upper, _CTYPE_U)
XLOCALE_ISCTYPE(xdigit, _CTYPE_X)
#undef XLOCALE_ISCTYPE

#ifdef _XLOCALE_WCTYPES
_XLOCALE_INLINE int towlower_l(int, locale_t);
_XLOCALE_INLINE int __wcwidth_l(__ct_rune_t, locale_t);
_XLOCALE_INLINE int towupper_l(int, locale_t);

_XLOCALE_INLINE int towlower_l(int __c, locale_t __l)
{
	int __limit;
	_RuneLocale *__runes = __runes_for_locale(__l, &__limit);
	return (__c < 0 || __c >= _CACHED_RUNES) ? ___tolower_l(__c, __l) :
	       __runes->__maplower[__c];
}
_XLOCALE_INLINE int towupper_l(int __c, locale_t __l)
{
	int __limit;
	_RuneLocale *__runes = __runes_for_locale(__l, &__limit);
	return (__c < 0 || __c >= _CACHED_RUNES) ? ___toupper_l(__c, __l) :
	       __runes->__mapupper[__c];
}
_XLOCALE_INLINE int
__wcwidth_l(__ct_rune_t _c, locale_t __l)
{
	unsigned int _x;

	if (_c == 0)
		return (0);
	_x = (unsigned int)__maskrune_l(_c, _CTYPE_SWM|_CTYPE_R, __l);
	if ((_x & _CTYPE_SWM) != 0)
		return ((_x & _CTYPE_SWM) >> _CTYPE_SWS);
	return ((_x & _CTYPE_R) != 0 ? 1 : -1);
}
int iswctype_l(wint_t __wc, wctype_t __charclass, locale_t __l);
wctype_t wctype_l(const char *property, locale_t __l);
wint_t towctrans_l(wint_t __wc, wctrans_t desc, locale_t __l);
wint_t nextwctype_l(wint_t __wc, wctype_t wct, locale_t __l);
wctrans_t wctrans_l(const char *__charclass, locale_t __l);
#undef _XLOCALE_WCTYPES
#else
# 180 "/usr/include/xlocale/_ctype.h" 3 4
_XLOCALE_INLINE int digittoint_l(int, locale_t);
_XLOCALE_INLINE int tolower_l(int, locale_t);
_XLOCALE_INLINE int toupper_l(int, locale_t);

_XLOCALE_INLINE int digittoint_l(int __c, locale_t __l)
{ return __sbmaskrune_l((__c), 0xFF, __l); }

_XLOCALE_INLINE int tolower_l(int __c, locale_t __l)
{
	int __limit;
	_RuneLocale *__runes = __runes_for_locale(__l, &__limit);
	return (__c < 0 || __c >= __limit) ? __c :
	       __runes->__maplower[__c];
}
_XLOCALE_INLINE int toupper_l(int __c, locale_t __l)
{
	int __limit;
	_RuneLocale *__runes = __runes_for_locale(__l, &__limit);
	return (__c < 0 || __c >= __limit) ? __c :
	       __runes->__mapupper[__c];
}
#endif
# 202 "/usr/include/xlocale/_ctype.h" 3 4
#endif /* (defined(_XLOCALE_WCTYPES) && !defined(_XLOCALE_WCTYPE_H)) || \
	(!defined(_XLOCALE_WCTYPES) && !defined(_XLOCALE_CTYPE_H)) */
# 204 "/usr/include/xlocale/_ctype.h" 3 4
# 65 "/usr/include/xlocale.h" 2 3 4
#endif
# 66 "/usr/include/xlocale.h" 3 4

#ifdef _WCTYPE_H_
#define _XLOCALE_WCTYPES 1
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_ctype.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/xlocale/_ctype.h" 1 3 4
/*-
 * Copyright (c) 2011 The FreeBSD Foundation
 * All rights reserved.
 *
 * This software was developed by David Chisnall under sponsorship from
 * the FreeBSD Foundation.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/include/xlocale/_ctype.h 243032 2012-11-14 17:44:37Z demon $
 */


#if	(defined(_XLOCALE_WCTYPES) && !defined(_XLOCALE_WCTYPE_H)) || \
	(!defined(_XLOCALE_WCTYPES) && !defined(_XLOCALE_CTYPE_H))

#ifdef _XLOCALE_WCTYPES
#define _XLOCALE_WCTYPE_H
#else
# 39 "/usr/include/xlocale/_ctype.h" 3 4
#define _XLOCALE_CTYPE_H
#endif
# 41 "/usr/include/xlocale/_ctype.h" 3 4

#ifndef _LOCALE_T_DEFINED
#define _LOCALE_T_DEFINED
typedef struct	_xlocale *locale_t;
#endif
# 46 "/usr/include/xlocale/_ctype.h" 3 4

#ifndef _XLOCALE_RUN_FUNCTIONS_DEFINED
#define _XLOCALE_RUN_FUNCTIONS_DEFINED 1
unsigned long	 ___runetype_l(__ct_rune_t, locale_t) __pure;
__ct_rune_t	 ___tolower_l(__ct_rune_t, locale_t) __pure;
__ct_rune_t	 ___toupper_l(__ct_rune_t, locale_t) __pure;
_RuneLocale	*__runes_for_locale(locale_t, int*);
#endif
# 54 "/usr/include/xlocale/_ctype.h" 3 4

#ifndef _XLOCALE_INLINE
#if defined(__GNUC__) && !defined(__GNUC_STDC_INLINE__)
/* GNU89 inline has nonstandard semantics. */
#define _XLOCALE_INLINE extern __inline
#else
# 60 "/usr/include/xlocale/_ctype.h" 3 4
/* Hack to work around people who define inline away */
#ifdef inline
#define _XLOCALE_INLINE static __inline
#else
# 64 "/usr/include/xlocale/_ctype.h" 3 4
/* Define with C++ / C99 compatible semantics */
#define _XLOCALE_INLINE inline
#endif
# 67 "/usr/include/xlocale/_ctype.h" 3 4
#endif
# 68 "/usr/include/xlocale/_ctype.h" 3 4
#endif /* _XLOCALE_INLINE */
# 69 "/usr/include/xlocale/_ctype.h" 3 4

#ifdef _XLOCALE_WCTYPES
_XLOCALE_INLINE int
__maskrune_l(__ct_rune_t __c, unsigned long __f, locale_t __loc);
_XLOCALE_INLINE int
__istype_l(__ct_rune_t __c, unsigned long __f, locale_t __loc);

_XLOCALE_INLINE int
__maskrune_l(__ct_rune_t __c, unsigned long __f, locale_t __loc)
{
	int __limit;
	_RuneLocale *runes = __runes_for_locale(__loc, &__limit);
	return ((__c < 0 || __c >= _CACHED_RUNES) ? ___runetype_l(__c, __loc) :
	        runes->__runetype[__c]) & __f;
}

_XLOCALE_INLINE int
__istype_l(__ct_rune_t __c, unsigned long __f, locale_t __loc)
{
	return (!!__maskrune_l(__c, __f, __loc));
}

#define XLOCALE_ISCTYPE(fname, cat) \
		_XLOCALE_INLINE int isw##fname##_l(int, locale_t);\
		_XLOCALE_INLINE int isw##fname##_l(int __c, locale_t __l)\
		{ return __istype_l(__c, cat, __l); }
#else
# 96 "/usr/include/xlocale/_ctype.h" 3 4
_XLOCALE_INLINE int
__sbmaskrune_l(__ct_rune_t __c, unsigned long __f, locale_t __loc);
_XLOCALE_INLINE int
__sbistype_l(__ct_rune_t __c, unsigned long __f, locale_t __loc);

_XLOCALE_INLINE int
__sbmaskrune_l(__ct_rune_t __c, unsigned long __f, locale_t __loc)
{
	int __limit;
	_RuneLocale *runes = __runes_for_locale(__loc, &__limit);
	return (__c < 0 || __c >= __limit) ? 0 :
	       runes->__runetype[__c] & __f;
}

_XLOCALE_INLINE int
__sbistype_l(__ct_rune_t __c, unsigned long __f, locale_t __loc)
{
	return (!!__sbmaskrune_l(__c, __f, __loc));
}

#define XLOCALE_ISCTYPE(__fname, __cat) \
		_XLOCALE_INLINE int is##__fname##_l(int, locale_t); \
		_XLOCALE_INLINE int is##__fname##_l(int __c, locale_t __l)\
		{ return __sbistype_l(__c, __cat, __l); }
#endif
# 121 "/usr/include/xlocale/_ctype.h" 3 4

XLOCALE_ISCTYPE(alnum, _CTYPE_A|_CTYPE_D)
XLOCALE_ISCTYPE(alpha, _CTYPE_A)
XLOCALE_ISCTYPE(blank, _CTYPE_B)
XLOCALE_ISCTYPE(cntrl, _CTYPE_C)
XLOCALE_ISCTYPE(digit, _CTYPE_D)
XLOCALE_ISCTYPE(graph, _CTYPE_G)
XLOCALE_ISCTYPE(hexnumber, _CTYPE_X)
XLOCALE_ISCTYPE(ideogram, _CTYPE_I)
XLOCALE_ISCTYPE(lower, _CTYPE_L)
XLOCALE_ISCTYPE(number, _CTYPE_D)
XLOCALE_ISCTYPE(phonogram, _CTYPE_Q)
XLOCALE_ISCTYPE(print, _CTYPE_R)
XLOCALE_ISCTYPE(punct, _CTYPE_P)
XLOCALE_ISCTYPE(rune, 0xFFFFFF00L)
XLOCALE_ISCTYPE(space, _CTYPE_S)
XLOCALE_ISCTYPE(special, _CTYPE_T)
XLOCALE_ISCTYPE(upper, _CTYPE_U)
XLOCALE_ISCTYPE(xdigit, _CTYPE_X)
#undef XLOCALE_ISCTYPE

#ifdef _XLOCALE_WCTYPES
_XLOCALE_INLINE int towlower_l(int, locale_t);
_XLOCALE_INLINE int __wcwidth_l(__ct_rune_t, locale_t);
_XLOCALE_INLINE int towupper_l(int, locale_t);

_XLOCALE_INLINE int towlower_l(int __c, locale_t __l)
{
	int __limit;
	_RuneLocale *__runes = __runes_for_locale(__l, &__limit);
	return (__c < 0 || __c >= _CACHED_RUNES) ? ___tolower_l(__c, __l) :
	       __runes->__maplower[__c];
}
_XLOCALE_INLINE int towupper_l(int __c, locale_t __l)
{
	int __limit;
	_RuneLocale *__runes = __runes_for_locale(__l, &__limit);
	return (__c < 0 || __c >= _CACHED_RUNES) ? ___toupper_l(__c, __l) :
	       __runes->__mapupper[__c];
}
_XLOCALE_INLINE int
__wcwidth_l(__ct_rune_t _c, locale_t __l)
{
	unsigned int _x;

	if (_c == 0)
		return (0);
	_x = (unsigned int)__maskrune_l(_c, _CTYPE_SWM|_CTYPE_R, __l);
	if ((_x & _CTYPE_SWM) != 0)
		return ((_x & _CTYPE_SWM) >> _CTYPE_SWS);
	return ((_x & _CTYPE_R) != 0 ? 1 : -1);
}
int iswctype_l(wint_t __wc, wctype_t __charclass, locale_t __l);
wctype_t wctype_l(const char *property, locale_t __l);
wint_t towctrans_l(wint_t __wc, wctrans_t desc, locale_t __l);
wint_t nextwctype_l(wint_t __wc, wctype_t wct, locale_t __l);
wctrans_t wctrans_l(const char *__charclass, locale_t __l);
#undef _XLOCALE_WCTYPES
#else
# 180 "/usr/include/xlocale/_ctype.h" 3 4
_XLOCALE_INLINE int digittoint_l(int, locale_t);
_XLOCALE_INLINE int tolower_l(int, locale_t);
_XLOCALE_INLINE int toupper_l(int, locale_t);

_XLOCALE_INLINE int digittoint_l(int __c, locale_t __l)
{ return __sbmaskrune_l((__c), 0xFF, __l); }

_XLOCALE_INLINE int tolower_l(int __c, locale_t __l)
{
	int __limit;
	_RuneLocale *__runes = __runes_for_locale(__l, &__limit);
	return (__c < 0 || __c >= __limit) ? __c :
	       __runes->__maplower[__c];
}
_XLOCALE_INLINE int toupper_l(int __c, locale_t __l)
{
	int __limit;
	_RuneLocale *__runes = __runes_for_locale(__l, &__limit);
	return (__c < 0 || __c >= __limit) ? __c :
	       __runes->__mapupper[__c];
}
#endif
# 202 "/usr/include/xlocale/_ctype.h" 3 4
#endif /* (defined(_XLOCALE_WCTYPES) && !defined(_XLOCALE_WCTYPE_H)) || \
	(!defined(_XLOCALE_WCTYPES) && !defined(_XLOCALE_CTYPE_H)) */
# 204 "/usr/include/xlocale/_ctype.h" 3 4
# 70 "/usr/include/xlocale.h" 2 3 4
#endif
# 71 "/usr/include/xlocale.h" 3 4

#ifdef _STDIO_H_
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_stdio.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/xlocale/_stdio.h" 1 3 4
/*-
 * Copyright (c) 2011, 2012 The FreeBSD Foundation
 * All rights reserved.
 *
 * This software was developed by David Chisnall under sponsorship from
 * the FreeBSD Foundation.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/include/xlocale/_stdio.h 231673 2012-02-14 12:03:23Z theraven $
 */

int	 asprintf_l(char **, locale_t, const char *, ...) __printflike(3, 4);
int	 dprintf_l(int, locale_t, const char * __restrict, ...)
	    __printflike(3, 4);
int	 fprintf_l(FILE * __restrict, locale_t, const char * __restrict, ...)
	    __printflike(3, 4);
int	 fscanf_l(FILE * __restrict, locale_t, const char * __restrict, ...)
	    __scanflike(3, 4);
int	 printf_l(locale_t, const char * __restrict, ...) __printflike(2, 3);
int	 scanf_l(locale_t, const char * __restrict, ...) __scanflike(2, 3);
int	 snprintf_l(char * __restrict, size_t, locale_t,
	    const char * __restrict, ...) __printflike(4, 5);
int	 sprintf_l(char * __restrict, locale_t, const char * __restrict, ...)
	    __printflike(3, 4);
int	 sscanf_l(const char * __restrict, locale_t, const char * __restrict,
	    ...) __scanflike(3, 4);
int	 vfprintf_l(FILE * __restrict, locale_t, const char * __restrict,
	    __va_list) __printflike(3, 0);
int	 vprintf_l(locale_t, const char * __restrict, __va_list)
	    __printflike(2, 0);
int	 vsprintf_l(char * __restrict, locale_t, const char * __restrict,
	    __va_list) __printflike(3, 0);
int	 vfscanf_l(FILE * __restrict, locale_t, const char * __restrict,
	    __va_list) __scanflike(3, 0);
int	 vscanf_l(locale_t, const char * __restrict, __va_list)
	    __scanflike(2, 0);
int	 vsnprintf_l(char * __restrict, size_t, locale_t,
	    const char * __restrict, __va_list) __printflike(4, 0);
int	 vsscanf_l(const char * __restrict, locale_t, const char * __restrict,
	    __va_list) __scanflike(3, 0);
int	 vdprintf_l(int, locale_t, const char * __restrict, __va_list)
	    __printflike(3, 0);
int	 vasprintf_l(char **, locale_t, const char *, __va_list)
	    __printflike(3, 0);
# 74 "/usr/include/xlocale.h" 2 3 4
#endif
# 75 "/usr/include/xlocale.h" 3 4

#ifdef _WCHAR_H_
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_wchar.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/xlocale/_wchar.h" 1 3 4
/*-
 * Copyright (c) 2011, 2012 The FreeBSD Foundation
 * All rights reserved.
 *
 * This software was developed by David Chisnall under sponsorship from
 * the FreeBSD Foundation.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/include/xlocale/_wchar.h 231673 2012-02-14 12:03:23Z theraven $
 */

#ifndef _LOCALE_T_DEFINED
#define _LOCALE_T_DEFINED
typedef struct	_xlocale *locale_t;
#endif
# 36 "/usr/include/xlocale/_wchar.h" 3 4

#ifndef _XLOCALE_WCHAR1_H
#define _XLOCALE_WCHAR1_H
int			 wcscasecmp_l(const wchar_t *, const wchar_t *,
			   locale_t);
int			 wcsncasecmp_l(const wchar_t *, const wchar_t *, size_t,
			   locale_t);
int			 wcscoll_l(const wchar_t *, const wchar_t *, locale_t);
size_t			 wcsxfrm_l(wchar_t * __restrict,
			   const wchar_t * __restrict, size_t, locale_t);

#endif /* _XLOCALE_WCHAR1_H */
# 48 "/usr/include/xlocale/_wchar.h" 3 4

/*
 * Only declare the non-POSIX functions if we're included from xlocale.h.
 */

#ifdef _XLOCALE_H_
#ifndef _XLOCALE_WCHAR2_H
#define _XLOCALE_WCHAR2_H

wint_t			 btowc_l(int, locale_t);
wint_t			 fgetwc_l(FILE *, locale_t);
wchar_t			*fgetws_l(wchar_t * __restrict, int, FILE * __restrict,
			    locale_t);
wint_t			 fputwc_l(wchar_t, FILE *, locale_t);
int			 fputws_l(const wchar_t * __restrict, FILE * __restrict,
			   locale_t);
int			 fwprintf_l(FILE * __restrict, locale_t,
			    const wchar_t * __restrict, ...);
int			 fwscanf_l(FILE * __restrict, locale_t,
			    const wchar_t * __restrict, ...);
wint_t			 getwc_l(FILE *, locale_t);
wint_t			 getwchar_l(locale_t);
size_t			 mbrlen_l(const char * __restrict, size_t,
			   mbstate_t * __restrict, locale_t);
size_t			 mbrtowc_l(wchar_t * __restrict,
			    const char * __restrict, size_t,
			    mbstate_t * __restrict, locale_t);
int			 mbsinit_l(const mbstate_t *, locale_t);
size_t			 mbsrtowcs_l(wchar_t * __restrict,
			    const char ** __restrict, size_t,
			    mbstate_t * __restrict, locale_t);
wint_t			 putwc_l(wchar_t, FILE *, locale_t);
wint_t			 putwchar_l(wchar_t, locale_t);
int			 swprintf_l(wchar_t * __restrict, size_t n, locale_t,
			    const wchar_t * __restrict, ...);
int			 swscanf_l(const wchar_t * __restrict, locale_t,
			   const wchar_t * __restrict, ...);
wint_t			 ungetwc_l(wint_t, FILE *, locale_t);
int			 vfwprintf_l(FILE * __restrict, locale_t,
			    const wchar_t * __restrict, __va_list);
int			 vswprintf_l(wchar_t * __restrict, size_t n, locale_t,
			    const wchar_t * __restrict, __va_list);
int			 vwprintf_l(locale_t, const wchar_t * __restrict,
			    __va_list);
size_t			 wcrtomb_l(char * __restrict, wchar_t,
			    mbstate_t * __restrict, locale_t);
size_t			 wcsftime_l(wchar_t * __restrict, size_t,
			    const wchar_t * __restrict,
			    const struct tm * __restrict, locale_t);
size_t			 wcsrtombs_l(char * __restrict,
			    const wchar_t ** __restrict, size_t,
			    mbstate_t * __restrict, locale_t);
double			 wcstod_l(const wchar_t * __restrict,
			    wchar_t ** __restrict, locale_t);
long			 wcstol_l(const wchar_t * __restrict,
			    wchar_t ** __restrict, int, locale_t);
unsigned long		 wcstoul_l(const wchar_t * __restrict,
			    wchar_t ** __restrict, int, locale_t);
int			 wcswidth_l(const wchar_t *, size_t, locale_t);
int			 wctob_l(wint_t, locale_t);
int			 wcwidth_l(wchar_t, locale_t);
int			 wprintf_l(locale_t, const wchar_t * __restrict, ...);
int			 wscanf_l(locale_t, const wchar_t * __restrict, ...);
int			 vfwscanf_l(FILE * __restrict, locale_t,
			    const wchar_t * __restrict, __va_list);
int			 vswscanf_l(const wchar_t * __restrict, locale_t,
			    const wchar_t *__restrict, __va_list);
int			 vwscanf_l(locale_t, const wchar_t * __restrict,
			    __va_list);
float			 wcstof_l(const wchar_t * __restrict,
			    wchar_t ** __restrict, locale_t);
long double		 wcstold_l(const wchar_t * __restrict,
			    wchar_t ** __restrict, locale_t);
long long		 wcstoll_l(const wchar_t * __restrict,
			    wchar_t ** __restrict, int, locale_t);
unsigned long long	 wcstoull_l(const wchar_t * __restrict,
			    wchar_t ** __restrict, int, locale_t);
size_t			 mbsnrtowcs_l(wchar_t * __restrict,
			    const char ** __restrict, size_t, size_t,
			    mbstate_t * __restrict, locale_t);
size_t			 wcsnrtombs_l(char * __restrict,
			    const wchar_t ** __restrict, size_t, size_t,
			    mbstate_t * __restrict, locale_t);

#endif /* _XLOCALE_WCHAR_H */
# 133 "/usr/include/xlocale/_wchar.h" 3 4
#endif /* _XLOCALE_H_ */
# 134 "/usr/include/xlocale/_wchar.h" 3 4
# 78 "/usr/include/xlocale.h" 2 3 4
#endif
# 79 "/usr/include/xlocale.h" 3 4



struct lconv	*localeconv_l(locale_t);
__END_DECLS

#endif
# 86 "/usr/include/xlocale.h" 3 4
# 28 "/usr/include/c++/v1/__locale" 2 3
#endif  // _WIN32 || __GLIBC__ || __APPLE__ || __FreeBSD__ || __sun__ || __EMSCRIPTEN__ || __IBMCPP__
# 29 "/usr/include/c++/v1/__locale" 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 32 "/usr/include/c++/v1/__locale" 3
#endif
# 33 "/usr/include/c++/v1/__locale" 3

_LIBCPP_BEGIN_NAMESPACE_STD

class _LIBCPP_TYPE_VIS locale;

template <class _Facet>
_LIBCPP_INLINE_VISIBILITY
bool
has_facet(const locale&) _NOEXCEPT;

template <class _Facet>
_LIBCPP_INLINE_VISIBILITY
const _Facet&
use_facet(const locale&);

class _LIBCPP_TYPE_VIS locale
{
public:
    // types:
    class _LIBCPP_TYPE_VIS facet;
    class _LIBCPP_TYPE_VIS id;

    typedef int category;
    static const category // values assigned here are for exposition only
        none     = 0,
        collate  = LC_COLLATE_MASK,
        ctype    = LC_CTYPE_MASK,
        monetary = LC_MONETARY_MASK,
        numeric  = LC_NUMERIC_MASK,
        time     = LC_TIME_MASK,
        messages = LC_MESSAGES_MASK,
        all = collate | ctype | monetary | numeric | time | messages;

    // construct/copy/destroy:
    locale()  _NOEXCEPT;
    locale(const locale&)  _NOEXCEPT;
    explicit locale(const char*);
    explicit locale(const string&);
    locale(const locale&, const char*, category);
    locale(const locale&, const string&, category);
    template <class _Facet>
        _LIBCPP_INLINE_VISIBILITY locale(const locale&, _Facet*);
    locale(const locale&, const locale&, category);

    ~locale();

    const locale& operator=(const locale&)  _NOEXCEPT;

    template <class _Facet> locale combine(const locale&) const;

    // locale operations:
    string name() const;
    bool operator==(const locale&) const;
    bool operator!=(const locale& __y) const {return !(*this == __y);}
    template <class _CharT, class _Traits, class _Allocator>
      bool operator()(const basic_string<_CharT, _Traits, _Allocator>&,
                      const basic_string<_CharT, _Traits, _Allocator>&) const;

    // global locale objects:
    static locale global(const locale&);
    static const locale& classic();

private:
    class __imp;
    __imp* __locale_;

    void __install_ctor(const locale&, facet*, long);
    static locale& __global();
    bool has_facet(id&) const;
    const facet* use_facet(id&) const;

    template <class _Facet> friend bool has_facet(const locale&)  _NOEXCEPT;
    template <class _Facet> friend const _Facet& use_facet(const locale&);
};

class _LIBCPP_TYPE_VIS locale::facet
    : public __shared_count
{
protected:
    _LIBCPP_INLINE_VISIBILITY
    explicit facet(size_t __refs = 0)
        : __shared_count(static_cast<long>(__refs)-1) {}

    virtual ~facet();

//    facet(const facet&) = delete;     // effectively done in __shared_count
//    void operator=(const facet&) = delete;
private:
    virtual void __on_zero_shared() _NOEXCEPT;
};

class _LIBCPP_TYPE_VIS locale::id
{
    once_flag      __flag_;
    int32_t        __id_;

    static int32_t __next_id;
public:
    _LIBCPP_INLINE_VISIBILITY _LIBCPP_CONSTEXPR id() :__id_(0) {}
private:
    void __init();
    void operator=(const id&); // = delete;
    id(const id&); // = delete;
public:  // only needed for tests
    long __get();

    friend class locale;
    friend class locale::__imp;
};

template <class _Facet>
inline _LIBCPP_INLINE_VISIBILITY
locale::locale(const locale& __other, _Facet* __f)
{
    __install_ctor(__other, __f, __f ? __f->id.__get() : 0);
}

template <class _Facet>
locale
locale::combine(const locale& __other) const
{
#ifndef _LIBCPP_NO_EXCEPTIONS
    if (!_VSTD::has_facet<_Facet>(__other))
        throw runtime_error("locale::combine: locale missing facet");
#endif  // _LIBCPP_NO_EXCEPTIONS
# 158 "/usr/include/c++/v1/__locale" 3
    return locale(*this, &const_cast<_Facet&>(_VSTD::use_facet<_Facet>(__other)));
}

template <class _Facet>
inline _LIBCPP_INLINE_VISIBILITY
bool
has_facet(const locale& __l)  _NOEXCEPT
{
    return __l.has_facet(_Facet::id);
}

template <class _Facet>
inline _LIBCPP_INLINE_VISIBILITY
const _Facet&
use_facet(const locale& __l)
{
    return static_cast<const _Facet&>(*__l.use_facet(_Facet::id));
}

// template <class _CharT> class collate;

template <class _CharT>
class _LIBCPP_TYPE_VIS_ONLY collate
    : public locale::facet
{
public:
    typedef _CharT char_type;
    typedef basic_string<char_type> string_type;

    _LIBCPP_INLINE_VISIBILITY
    explicit collate(size_t __refs = 0)
        : locale::facet(__refs) {}

    _LIBCPP_INLINE_VISIBILITY
    int compare(const char_type* __lo1, const char_type* __hi1,
                const char_type* __lo2, const char_type* __hi2) const
    {
        return do_compare(__lo1, __hi1, __lo2, __hi2);
    }

    _LIBCPP_INLINE_VISIBILITY
    string_type transform(const char_type* __lo, const char_type* __hi) const
    {
        return do_transform(__lo, __hi);
    }

    _LIBCPP_INLINE_VISIBILITY
    long hash(const char_type* __lo, const char_type* __hi) const
    {
        return do_hash(__lo, __hi);
    }

    static locale::id id;

protected:
    ~collate();
    virtual int do_compare(const char_type* __lo1, const char_type* __hi1,
                           const char_type* __lo2, const char_type* __hi2) const;
    virtual string_type do_transform(const char_type* __lo, const char_type* __hi) const
        {return string_type(__lo, __hi);}
    virtual long do_hash(const char_type* __lo, const char_type* __hi) const;
};

template <class _CharT> locale::id collate<_CharT>::id;

template <class _CharT>
collate<_CharT>::~collate()
{
}

template <class _CharT>
int
collate<_CharT>::do_compare(const char_type* __lo1, const char_type* __hi1,
                            const char_type* __lo2, const char_type* __hi2) const
{
    for (; __lo2 != __hi2; ++__lo1, ++__lo2)
    {
        if (__lo1 == __hi1 || *__lo1 < *__lo2)
            return -1;
        if (*__lo2 < *__lo1)
            return 1;
    }
    return __lo1 != __hi1;
}

template <class _CharT>
long
collate<_CharT>::do_hash(const char_type* __lo, const char_type* __hi) const
{
    size_t __h = 0;
    const size_t __sr = __CHAR_BIT__ * sizeof(size_t) - 8;
    const size_t __mask = size_t(0xF) << (__sr + 4);
    for(const char_type* __p = __lo; __p != __hi; ++__p)
    {
        __h = (__h << 4) + static_cast<size_t>(*__p);
        size_t __g = __h & __mask;
        __h ^= __g | (__g >> __sr);
    }
    return static_cast<long>(__h);
}

_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS collate<char>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS collate<wchar_t>)

// template <class CharT> class collate_byname;

template <class _CharT> class _LIBCPP_TYPE_VIS_ONLY collate_byname;

template <>
class _LIBCPP_TYPE_VIS collate_byname<char>
    : public collate<char>
{
    locale_t __l;
public:
    typedef char char_type;
    typedef basic_string<char_type> string_type;

    explicit collate_byname(const char* __n, size_t __refs = 0);
    explicit collate_byname(const string& __n, size_t __refs = 0);

protected:
    ~collate_byname();
    virtual int do_compare(const char_type* __lo1, const char_type* __hi1,
                           const char_type* __lo2, const char_type* __hi2) const;
    virtual string_type do_transform(const char_type* __lo, const char_type* __hi) const;
};

template <>
class _LIBCPP_TYPE_VIS collate_byname<wchar_t>
    : public collate<wchar_t>
{
    locale_t __l;
public:
    typedef wchar_t char_type;
    typedef basic_string<char_type> string_type;

    explicit collate_byname(const char* __n, size_t __refs = 0);
    explicit collate_byname(const string& __n, size_t __refs = 0);

protected:
    ~collate_byname();

    virtual int do_compare(const char_type* __lo1, const char_type* __hi1,
                           const char_type* __lo2, const char_type* __hi2) const;
    virtual string_type do_transform(const char_type* __lo, const char_type* __hi) const;
};

template <class _CharT, class _Traits, class _Allocator>
bool
locale::operator()(const basic_string<_CharT, _Traits, _Allocator>& __x,
                   const basic_string<_CharT, _Traits, _Allocator>& __y) const
{
    return _VSTD::use_facet<_VSTD::collate<_CharT> >(*this).compare(
                                       __x.data(), __x.data() + __x.size(),
                                       __y.data(), __y.data() + __y.size()) < 0;
}

// template <class charT> class ctype

class _LIBCPP_TYPE_VIS ctype_base
{
public:
#ifdef __GLIBC__
    typedef unsigned short mask;
    static const mask space  = _ISspace;
    static const mask print  = _ISprint;
    static const mask cntrl  = _IScntrl;
    static const mask upper  = _ISupper;
    static const mask lower  = _ISlower;
    static const mask alpha  = _ISalpha;
    static const mask digit  = _ISdigit;
    static const mask punct  = _ISpunct;
    static const mask xdigit = _ISxdigit;
    static const mask blank  = _ISblank;
#elif defined(_WIN32)
# 333 "/usr/include/c++/v1/__locale" 3
    typedef unsigned short mask;
    static const mask space  = _SPACE;
    static const mask print  = _BLANK|_PUNCT|_ALPHA|_DIGIT;
    static const mask cntrl  = _CONTROL;
    static const mask upper  = _UPPER;
    static const mask lower  = _LOWER;
    static const mask alpha  = _ALPHA;
    static const mask digit  = _DIGIT;
    static const mask punct  = _PUNCT;
    static const mask xdigit = _HEX;
    static const mask blank  = _BLANK;
#elif defined(__APPLE__) || defined(__FreeBSD__) || defined(__EMSCRIPTEN__) || defined(__NetBSD__)
# 345 "/usr/include/c++/v1/__locale" 3
#ifdef __APPLE__
    typedef __uint32_t mask;
#elif defined(__FreeBSD__)
# 348 "/usr/include/c++/v1/__locale" 3
    typedef unsigned long mask;
#elif defined(__EMSCRIPTEN__) ||  defined(__NetBSD__)
# 350 "/usr/include/c++/v1/__locale" 3
    typedef unsigned short mask;
#endif
# 352 "/usr/include/c++/v1/__locale" 3
    static const mask space  = _CTYPE_S;
    static const mask print  = _CTYPE_R;
    static const mask cntrl  = _CTYPE_C;
    static const mask upper  = _CTYPE_U;
    static const mask lower  = _CTYPE_L;
    static const mask alpha  = _CTYPE_A;
    static const mask digit  = _CTYPE_D;
    static const mask punct  = _CTYPE_P;
    static const mask xdigit = _CTYPE_X;
# if defined(__NetBSD__)
    static const mask blank  = _CTYPE_BL;
# else
# 364 "/usr/include/c++/v1/__locale" 3
    static const mask blank  = _CTYPE_B;
# endif
# 366 "/usr/include/c++/v1/__locale" 3
#elif defined(__sun__) || defined(_AIX)
# 367 "/usr/include/c++/v1/__locale" 3
    typedef unsigned int mask;
    static const mask space  = _ISSPACE;
    static const mask print  = _ISPRINT;
    static const mask cntrl  = _ISCNTRL;
    static const mask upper  = _ISUPPER;
    static const mask lower  = _ISLOWER;
    static const mask alpha  = _ISALPHA;
    static const mask digit  = _ISDIGIT;
    static const mask punct  = _ISPUNCT;
    static const mask xdigit = _ISXDIGIT;
    static const mask blank  = _ISBLANK;
#else  // __GLIBC__ || _WIN32 || __APPLE__ || __FreeBSD__ || __EMSCRIPTEN__ || __sun__
# 379 "/usr/include/c++/v1/__locale" 3
    typedef unsigned long mask;
    static const mask space  = 1<<0;
    static const mask print  = 1<<1;
    static const mask cntrl  = 1<<2;
    static const mask upper  = 1<<3;
    static const mask lower  = 1<<4;
    static const mask alpha  = 1<<5;
    static const mask digit  = 1<<6;
    static const mask punct  = 1<<7;
    static const mask xdigit = 1<<8;
    static const mask blank  = 1<<9;
#endif  // __GLIBC__ || _WIN32 || __APPLE__ || __FreeBSD__
# 391 "/usr/include/c++/v1/__locale" 3
    static const mask alnum  = alpha | digit;
    static const mask graph  = alnum | punct;

    _LIBCPP_ALWAYS_INLINE ctype_base() {}
};

template <class _CharT> class _LIBCPP_TYPE_VIS_ONLY ctype;

template <>
class _LIBCPP_TYPE_VIS ctype<wchar_t>
    : public locale::facet,
      public ctype_base
{
public:
    typedef wchar_t char_type;

    _LIBCPP_ALWAYS_INLINE
    explicit ctype(size_t __refs = 0)
        : locale::facet(__refs) {}

    _LIBCPP_ALWAYS_INLINE
    bool is(mask __m, char_type __c) const
    {
        return do_is(__m, __c);
    }

    _LIBCPP_ALWAYS_INLINE
    const char_type* is(const char_type* __low, const char_type* __high, mask* __vec) const
    {
        return do_is(__low, __high, __vec);
    }

    _LIBCPP_ALWAYS_INLINE
    const char_type* scan_is(mask __m, const char_type* __low, const char_type* __high) const
    {
        return do_scan_is(__m, __low, __high);
    }

    _LIBCPP_ALWAYS_INLINE
    const char_type* scan_not(mask __m, const char_type* __low, const char_type* __high) const
    {
        return do_scan_not(__m, __low, __high);
    }

    _LIBCPP_ALWAYS_INLINE
    char_type toupper(char_type __c) const
    {
        return do_toupper(__c);
    }

    _LIBCPP_ALWAYS_INLINE
    const char_type* toupper(char_type* __low, const char_type* __high) const
    {
        return do_toupper(__low, __high);
    }

    _LIBCPP_ALWAYS_INLINE
    char_type tolower(char_type __c) const
    {
        return do_tolower(__c);
    }

    _LIBCPP_ALWAYS_INLINE
    const char_type* tolower(char_type* __low, const char_type* __high) const
    {
        return do_tolower(__low, __high);
    }

    _LIBCPP_ALWAYS_INLINE
    char_type widen(char __c) const
    {
        return do_widen(__c);
    }

    _LIBCPP_ALWAYS_INLINE
    const char* widen(const char* __low, const char* __high, char_type* __to) const
    {
        return do_widen(__low, __high, __to);
    }

    _LIBCPP_ALWAYS_INLINE
    char narrow(char_type __c, char __dfault) const
    {
        return do_narrow(__c, __dfault);
    }

    _LIBCPP_ALWAYS_INLINE
    const char_type* narrow(const char_type* __low, const char_type* __high, char __dfault, char* __to) const
    {
        return do_narrow(__low, __high, __dfault, __to);
    }

    static locale::id id;

protected:
    ~ctype();
    virtual bool do_is(mask __m, char_type __c) const;
    virtual const char_type* do_is(const char_type* __low, const char_type* __high, mask* __vec) const;
    virtual const char_type* do_scan_is(mask __m, const char_type* __low, const char_type* __high) const;
    virtual const char_type* do_scan_not(mask __m, const char_type* __low, const char_type* __high) const;
    virtual char_type do_toupper(char_type) const;
    virtual const char_type* do_toupper(char_type* __low, const char_type* __high) const;
    virtual char_type do_tolower(char_type) const;
    virtual const char_type* do_tolower(char_type* __low, const char_type* __high) const;
    virtual char_type do_widen(char) const;
    virtual const char* do_widen(const char* __low, const char* __high, char_type* __dest) const;
    virtual char do_narrow(char_type, char __dfault) const;
    virtual const char_type* do_narrow(const char_type* __low, const char_type* __high, char __dfault, char* __dest) const;
};

template <>
class _LIBCPP_TYPE_VIS ctype<char>
    : public locale::facet, public ctype_base
{
    const mask* __tab_;
    bool        __del_;
public:
    typedef char char_type;

    explicit ctype(const mask* __tab = 0, bool __del = false, size_t __refs = 0);

    _LIBCPP_ALWAYS_INLINE
    bool is(mask __m, char_type __c) const
    {
        return isascii(__c) ? (__tab_[static_cast<int>(__c)] & __m) !=0 : false;
    }

    _LIBCPP_ALWAYS_INLINE
    const char_type* is(const char_type* __low, const char_type* __high, mask* __vec) const
    {
        for (; __low != __high; ++__low, ++__vec)
            *__vec = isascii(*__low) ? __tab_[static_cast<int>(*__low)] : 0;
        return __low;
    }

    _LIBCPP_ALWAYS_INLINE
    const char_type* scan_is (mask __m, const char_type* __low, const char_type* __high) const
    {
        for (; __low != __high; ++__low)
            if (isascii(*__low) && (__tab_[static_cast<int>(*__low)] & __m))
                break;
        return __low;
    }

    _LIBCPP_ALWAYS_INLINE
    const char_type* scan_not(mask __m, const char_type* __low, const char_type* __high) const
    {
        for (; __low != __high; ++__low)
            if (!(isascii(*__low) && (__tab_[static_cast<int>(*__low)] & __m)))
                break;
        return __low;
    }

    _LIBCPP_ALWAYS_INLINE
    char_type toupper(char_type __c) const
    {
        return do_toupper(__c);
    }

    _LIBCPP_ALWAYS_INLINE
    const char_type* toupper(char_type* __low, const char_type* __high) const
    {
        return do_toupper(__low, __high);
    }

    _LIBCPP_ALWAYS_INLINE
    char_type tolower(char_type __c) const
    {
        return do_tolower(__c);
    }

    _LIBCPP_ALWAYS_INLINE
    const char_type* tolower(char_type* __low, const char_type* __high) const
    {
        return do_tolower(__low, __high);
    }

    _LIBCPP_ALWAYS_INLINE
    char_type widen(char __c) const
    {
        return do_widen(__c);
    }

    _LIBCPP_ALWAYS_INLINE
    const char* widen(const char* __low, const char* __high, char_type* __to) const
    {
        return do_widen(__low, __high, __to);
    }

    _LIBCPP_ALWAYS_INLINE
    char narrow(char_type __c, char __dfault) const
    {
        return do_narrow(__c, __dfault);
    }

    _LIBCPP_ALWAYS_INLINE
    const char* narrow(const char_type* __low, const char_type* __high, char __dfault, char* __to) const
    {
        return do_narrow(__low, __high, __dfault, __to);
    }

    static locale::id id;

#ifdef _CACHED_RUNES
    static const size_t table_size = _CACHED_RUNES;
#else
# 597 "/usr/include/c++/v1/__locale" 3
    static const size_t table_size = 256;  // FIXME: Don't hardcode this.
#endif
# 599 "/usr/include/c++/v1/__locale" 3
    _LIBCPP_ALWAYS_INLINE const mask* table() const  _NOEXCEPT {return __tab_;}
    static const mask* classic_table()  _NOEXCEPT;
#if defined(__GLIBC__) || defined(__EMSCRIPTEN__)
    static const int* __classic_upper_table() _NOEXCEPT;
    static const int* __classic_lower_table() _NOEXCEPT;
#endif
# 605 "/usr/include/c++/v1/__locale" 3
#if defined(__NetBSD__)
    static const short* __classic_upper_table() _NOEXCEPT;
    static const short* __classic_lower_table() _NOEXCEPT;
#endif
# 609 "/usr/include/c++/v1/__locale" 3

protected:
    ~ctype();
    virtual char_type do_toupper(char_type __c) const;
    virtual const char_type* do_toupper(char_type* __low, const char_type* __high) const;
    virtual char_type do_tolower(char_type __c) const;
    virtual const char_type* do_tolower(char_type* __low, const char_type* __high) const;
    virtual char_type do_widen(char __c) const;
    virtual const char* do_widen(const char* __low, const char* __high, char_type* __to) const;
    virtual char do_narrow(char_type __c, char __dfault) const;
    virtual const char* do_narrow(const char_type* __low, const char_type* __high, char __dfault, char* __to) const;
};

// template <class CharT> class ctype_byname;

template <class _CharT> class _LIBCPP_TYPE_VIS_ONLY ctype_byname;

template <>
class _LIBCPP_TYPE_VIS ctype_byname<char>
    : public ctype<char>
{
    locale_t __l;

public:
    explicit ctype_byname(const char*, size_t = 0);
    explicit ctype_byname(const string&, size_t = 0);

protected:
    ~ctype_byname();
    virtual char_type do_toupper(char_type) const;
    virtual const char_type* do_toupper(char_type* __low, const char_type* __high) const;
    virtual char_type do_tolower(char_type) const;
    virtual const char_type* do_tolower(char_type* __low, const char_type* __high) const;
};

template <>
class _LIBCPP_TYPE_VIS ctype_byname<wchar_t>
    : public ctype<wchar_t>
{
    locale_t __l;

public:
    explicit ctype_byname(const char*, size_t = 0);
    explicit ctype_byname(const string&, size_t = 0);

protected:
    ~ctype_byname();
    virtual bool do_is(mask __m, char_type __c) const;
    virtual const char_type* do_is(const char_type* __low, const char_type* __high, mask* __vec) const;
    virtual const char_type* do_scan_is(mask __m, const char_type* __low, const char_type* __high) const;
    virtual const char_type* do_scan_not(mask __m, const char_type* __low, const char_type* __high) const;
    virtual char_type do_toupper(char_type) const;
    virtual const char_type* do_toupper(char_type* __low, const char_type* __high) const;
    virtual char_type do_tolower(char_type) const;
    virtual const char_type* do_tolower(char_type* __low, const char_type* __high) const;
    virtual char_type do_widen(char) const;
    virtual const char* do_widen(const char* __low, const char* __high, char_type* __dest) const;
    virtual char do_narrow(char_type, char __dfault) const;
    virtual const char_type* do_narrow(const char_type* __low, const char_type* __high, char __dfault, char* __dest) const;
};

template <class _CharT>
inline _LIBCPP_INLINE_VISIBILITY
bool
isspace(_CharT __c, const locale& __loc)
{
    return use_facet<ctype<_CharT> >(__loc).is(ctype_base::space, __c);
}

template <class _CharT>
inline _LIBCPP_INLINE_VISIBILITY
bool
isprint(_CharT __c, const locale& __loc)
{
    return use_facet<ctype<_CharT> >(__loc).is(ctype_base::print, __c);
}

template <class _CharT>
inline _LIBCPP_INLINE_VISIBILITY
bool
iscntrl(_CharT __c, const locale& __loc)
{
    return use_facet<ctype<_CharT> >(__loc).is(ctype_base::cntrl, __c);
}

template <class _CharT>
inline _LIBCPP_INLINE_VISIBILITY
bool
isupper(_CharT __c, const locale& __loc)
{
    return use_facet<ctype<_CharT> >(__loc).is(ctype_base::upper, __c);
}

template <class _CharT>
inline _LIBCPP_INLINE_VISIBILITY
bool
islower(_CharT __c, const locale& __loc)
{
    return use_facet<ctype<_CharT> >(__loc).is(ctype_base::lower, __c);
}

template <class _CharT>
inline _LIBCPP_INLINE_VISIBILITY
bool
isalpha(_CharT __c, const locale& __loc)
{
    return use_facet<ctype<_CharT> >(__loc).is(ctype_base::alpha, __c);
}

template <class _CharT>
inline _LIBCPP_INLINE_VISIBILITY
bool
isdigit(_CharT __c, const locale& __loc)
{
    return use_facet<ctype<_CharT> >(__loc).is(ctype_base::digit, __c);
}

template <class _CharT>
inline _LIBCPP_INLINE_VISIBILITY
bool
ispunct(_CharT __c, const locale& __loc)
{
    return use_facet<ctype<_CharT> >(__loc).is(ctype_base::punct, __c);
}

template <class _CharT>
inline _LIBCPP_INLINE_VISIBILITY
bool
isxdigit(_CharT __c, const locale& __loc)
{
    return use_facet<ctype<_CharT> >(__loc).is(ctype_base::xdigit, __c);
}

template <class _CharT>
inline _LIBCPP_INLINE_VISIBILITY
bool
isalnum(_CharT __c, const locale& __loc)
{
    return use_facet<ctype<_CharT> >(__loc).is(ctype_base::alnum, __c);
}

template <class _CharT>
inline _LIBCPP_INLINE_VISIBILITY
bool
isgraph(_CharT __c, const locale& __loc)
{
    return use_facet<ctype<_CharT> >(__loc).is(ctype_base::graph, __c);
}

template <class _CharT>
inline _LIBCPP_INLINE_VISIBILITY
_CharT
toupper(_CharT __c, const locale& __loc)
{
    return use_facet<ctype<_CharT> >(__loc).toupper(__c);
}

template <class _CharT>
inline _LIBCPP_INLINE_VISIBILITY
_CharT
tolower(_CharT __c, const locale& __loc)
{
    return use_facet<ctype<_CharT> >(__loc).tolower(__c);
}

// codecvt_base

class _LIBCPP_TYPE_VIS codecvt_base
{
public:
    _LIBCPP_ALWAYS_INLINE codecvt_base() {}
    enum result {ok, partial, error, noconv};
};

// template <class internT, class externT, class stateT> class codecvt;

template <class _InternT, class _ExternT, class _StateT> class _LIBCPP_TYPE_VIS_ONLY codecvt;

// template <> class codecvt<char, char, mbstate_t>

template <>
class _LIBCPP_TYPE_VIS codecvt<char, char, mbstate_t>
    : public locale::facet,
      public codecvt_base
{
public:
    typedef char      intern_type;
    typedef char      extern_type;
    typedef mbstate_t state_type;

    _LIBCPP_ALWAYS_INLINE
    explicit codecvt(size_t __refs = 0)
        : locale::facet(__refs) {}

    _LIBCPP_ALWAYS_INLINE
    result out(state_type& __st,
               const intern_type* __frm, const intern_type* __frm_end, const intern_type*& __frm_nxt,
               extern_type* __to, extern_type* __to_end, extern_type*& __to_nxt) const
    {
        return do_out(__st, __frm, __frm_end, __frm_nxt, __to, __to_end, __to_nxt);
    }

    _LIBCPP_ALWAYS_INLINE
    result unshift(state_type& __st,
                   extern_type* __to, extern_type* __to_end, extern_type*& __to_nxt) const
    {
        return do_unshift(__st, __to, __to_end, __to_nxt);
    }

    _LIBCPP_ALWAYS_INLINE
    result in(state_type& __st,
              const extern_type* __frm, const extern_type* __frm_end, const extern_type*& __frm_nxt,
              intern_type* __to, intern_type* __to_end, intern_type*& __to_nxt) const
    {
        return do_in(__st, __frm, __frm_end, __frm_nxt, __to, __to_end, __to_nxt);
    }

    _LIBCPP_ALWAYS_INLINE
    int encoding() const  _NOEXCEPT
    {
        return do_encoding();
    }

    _LIBCPP_ALWAYS_INLINE
    bool always_noconv() const  _NOEXCEPT
    {
        return do_always_noconv();
    }

    _LIBCPP_ALWAYS_INLINE
    int length(state_type& __st, const extern_type* __frm, const extern_type* __end, size_t __mx) const
    {
        return do_length(__st, __frm, __end, __mx);
    }

    _LIBCPP_ALWAYS_INLINE
    int max_length() const  _NOEXCEPT
    {
        return do_max_length();
    }

    static locale::id id;

protected:
    _LIBCPP_ALWAYS_INLINE
    explicit codecvt(const char*, size_t __refs = 0)
        : locale::facet(__refs) {}

    ~codecvt();

    virtual result do_out(state_type& __st,
                          const intern_type* __frm, const intern_type* __frm_end, const intern_type*& __frm_nxt,
                          extern_type* __to, extern_type* __to_end, extern_type*& __to_nxt) const;
    virtual result do_in(state_type& __st,
                         const extern_type* __frm, const extern_type* __frm_end, const extern_type*& __frm_nxt,
                         intern_type* __to, intern_type* __to_end, intern_type*& __to_nxt) const;
    virtual result do_unshift(state_type& __st,
                              extern_type* __to, extern_type* __to_end, extern_type*& __to_nxt) const;
    virtual int do_encoding() const  _NOEXCEPT;
    virtual bool do_always_noconv() const  _NOEXCEPT;
    virtual int do_length(state_type& __st, const extern_type* __frm, const extern_type* __end, size_t __mx) const;
    virtual int do_max_length() const  _NOEXCEPT;
};

// template <> class codecvt<wchar_t, char, mbstate_t>

template <>
class _LIBCPP_TYPE_VIS codecvt<wchar_t, char, mbstate_t>
    : public locale::facet,
      public codecvt_base
{
    locale_t __l;
public:
    typedef wchar_t   intern_type;
    typedef char      extern_type;
    typedef mbstate_t state_type;

    explicit codecvt(size_t __refs = 0);

    _LIBCPP_ALWAYS_INLINE
    result out(state_type& __st,
               const intern_type* __frm, const intern_type* __frm_end, const intern_type*& __frm_nxt,
               extern_type* __to, extern_type* __to_end, extern_type*& __to_nxt) const
    {
        return do_out(__st, __frm, __frm_end, __frm_nxt, __to, __to_end, __to_nxt);
    }

    _LIBCPP_ALWAYS_INLINE
    result unshift(state_type& __st,
                   extern_type* __to, extern_type* __to_end, extern_type*& __to_nxt) const
    {
        return do_unshift(__st, __to, __to_end, __to_nxt);
    }

    _LIBCPP_ALWAYS_INLINE
    result in(state_type& __st,
              const extern_type* __frm, const extern_type* __frm_end, const extern_type*& __frm_nxt,
              intern_type* __to, intern_type* __to_end, intern_type*& __to_nxt) const
    {
        return do_in(__st, __frm, __frm_end, __frm_nxt, __to, __to_end, __to_nxt);
    }

    _LIBCPP_ALWAYS_INLINE
    int encoding() const  _NOEXCEPT
    {
        return do_encoding();
    }

    _LIBCPP_ALWAYS_INLINE
    bool always_noconv() const  _NOEXCEPT
    {
        return do_always_noconv();
    }

    _LIBCPP_ALWAYS_INLINE
    int length(state_type& __st, const extern_type* __frm, const extern_type* __end, size_t __mx) const
    {
        return do_length(__st, __frm, __end, __mx);
    }

    _LIBCPP_ALWAYS_INLINE
    int max_length() const  _NOEXCEPT
    {
        return do_max_length();
    }

    static locale::id id;

protected:
    explicit codecvt(const char*, size_t __refs = 0);

    ~codecvt();

    virtual result do_out(state_type& __st,
                          const intern_type* __frm, const intern_type* __frm_end, const intern_type*& __frm_nxt,
                          extern_type* __to, extern_type* __to_end, extern_type*& __to_nxt) const;
    virtual result do_in(state_type& __st,
                         const extern_type* __frm, const extern_type* __frm_end, const extern_type*& __frm_nxt,
                         intern_type* __to, intern_type* __to_end, intern_type*& __to_nxt) const;
    virtual result do_unshift(state_type& __st,
                              extern_type* __to, extern_type* __to_end, extern_type*& __to_nxt) const;
    virtual int do_encoding() const  _NOEXCEPT;
    virtual bool do_always_noconv() const  _NOEXCEPT;
    virtual int do_length(state_type&, const extern_type* __frm, const extern_type* __end, size_t __mx) const;
    virtual int do_max_length() const  _NOEXCEPT;
};

// template <> class codecvt<char16_t, char, mbstate_t>

template <>
class _LIBCPP_TYPE_VIS codecvt<char16_t, char, mbstate_t>
    : public locale::facet,
      public codecvt_base
{
public:
    typedef char16_t  intern_type;
    typedef char      extern_type;
    typedef mbstate_t state_type;

    _LIBCPP_ALWAYS_INLINE
    explicit codecvt(size_t __refs = 0)
        : locale::facet(__refs) {}

    _LIBCPP_ALWAYS_INLINE
    result out(state_type& __st,
               const intern_type* __frm, const intern_type* __frm_end, const intern_type*& __frm_nxt,
               extern_type* __to, extern_type* __to_end, extern_type*& __to_nxt) const
    {
        return do_out(__st, __frm, __frm_end, __frm_nxt, __to, __to_end, __to_nxt);
    }

    _LIBCPP_ALWAYS_INLINE
    result unshift(state_type& __st,
                   extern_type* __to, extern_type* __to_end, extern_type*& __to_nxt) const
    {
        return do_unshift(__st, __to, __to_end, __to_nxt);
    }

    _LIBCPP_ALWAYS_INLINE
    result in(state_type& __st,
              const extern_type* __frm, const extern_type* __frm_end, const extern_type*& __frm_nxt,
              intern_type* __to, intern_type* __to_end, intern_type*& __to_nxt) const
    {
        return do_in(__st, __frm, __frm_end, __frm_nxt, __to, __to_end, __to_nxt);
    }

    _LIBCPP_ALWAYS_INLINE
    int encoding() const  _NOEXCEPT
    {
        return do_encoding();
    }

    _LIBCPP_ALWAYS_INLINE
    bool always_noconv() const  _NOEXCEPT
    {
        return do_always_noconv();
    }

    _LIBCPP_ALWAYS_INLINE
    int length(state_type& __st, const extern_type* __frm, const extern_type* __end, size_t __mx) const
    {
        return do_length(__st, __frm, __end, __mx);
    }

    _LIBCPP_ALWAYS_INLINE
    int max_length() const  _NOEXCEPT
    {
        return do_max_length();
    }

    static locale::id id;

protected:
    _LIBCPP_ALWAYS_INLINE
    explicit codecvt(const char*, size_t __refs = 0)
        : locale::facet(__refs) {}

    ~codecvt();

    virtual result do_out(state_type& __st,
                          const intern_type* __frm, const intern_type* __frm_end, const intern_type*& __frm_nxt,
                          extern_type* __to, extern_type* __to_end, extern_type*& __to_nxt) const;
    virtual result do_in(state_type& __st,
                         const extern_type* __frm, const extern_type* __frm_end, const extern_type*& __frm_nxt,
                         intern_type* __to, intern_type* __to_end, intern_type*& __to_nxt) const;
    virtual result do_unshift(state_type& __st,
                              extern_type* __to, extern_type* __to_end, extern_type*& __to_nxt) const;
    virtual int do_encoding() const  _NOEXCEPT;
    virtual bool do_always_noconv() const  _NOEXCEPT;
    virtual int do_length(state_type&, const extern_type* __frm, const extern_type* __end, size_t __mx) const;
    virtual int do_max_length() const  _NOEXCEPT;
};

// template <> class codecvt<char32_t, char, mbstate_t>

template <>
class _LIBCPP_TYPE_VIS codecvt<char32_t, char, mbstate_t>
    : public locale::facet,
      public codecvt_base
{
public:
    typedef char32_t  intern_type;
    typedef char      extern_type;
    typedef mbstate_t state_type;

    _LIBCPP_ALWAYS_INLINE
    explicit codecvt(size_t __refs = 0)
        : locale::facet(__refs) {}

    _LIBCPP_ALWAYS_INLINE
    result out(state_type& __st,
               const intern_type* __frm, const intern_type* __frm_end, const intern_type*& __frm_nxt,
               extern_type* __to, extern_type* __to_end, extern_type*& __to_nxt) const
    {
        return do_out(__st, __frm, __frm_end, __frm_nxt, __to, __to_end, __to_nxt);
    }

    _LIBCPP_ALWAYS_INLINE
    result unshift(state_type& __st,
                   extern_type* __to, extern_type* __to_end, extern_type*& __to_nxt) const
    {
        return do_unshift(__st, __to, __to_end, __to_nxt);
    }

    _LIBCPP_ALWAYS_INLINE
    result in(state_type& __st,
              const extern_type* __frm, const extern_type* __frm_end, const extern_type*& __frm_nxt,
              intern_type* __to, intern_type* __to_end, intern_type*& __to_nxt) const
    {
        return do_in(__st, __frm, __frm_end, __frm_nxt, __to, __to_end, __to_nxt);
    }

    _LIBCPP_ALWAYS_INLINE
    int encoding() const  _NOEXCEPT
    {
        return do_encoding();
    }

    _LIBCPP_ALWAYS_INLINE
    bool always_noconv() const  _NOEXCEPT
    {
        return do_always_noconv();
    }

    _LIBCPP_ALWAYS_INLINE
    int length(state_type& __st, const extern_type* __frm, const extern_type* __end, size_t __mx) const
    {
        return do_length(__st, __frm, __end, __mx);
    }

    _LIBCPP_ALWAYS_INLINE
    int max_length() const  _NOEXCEPT
    {
        return do_max_length();
    }

    static locale::id id;

protected:
    _LIBCPP_ALWAYS_INLINE
    explicit codecvt(const char*, size_t __refs = 0)
        : locale::facet(__refs) {}

    ~codecvt();

    virtual result do_out(state_type& __st,
                          const intern_type* __frm, const intern_type* __frm_end, const intern_type*& __frm_nxt,
                          extern_type* __to, extern_type* __to_end, extern_type*& __to_nxt) const;
    virtual result do_in(state_type& __st,
                         const extern_type* __frm, const extern_type* __frm_end, const extern_type*& __frm_nxt,
                         intern_type* __to, intern_type* __to_end, intern_type*& __to_nxt) const;
    virtual result do_unshift(state_type& __st,
                              extern_type* __to, extern_type* __to_end, extern_type*& __to_nxt) const;
    virtual int do_encoding() const  _NOEXCEPT;
    virtual bool do_always_noconv() const  _NOEXCEPT;
    virtual int do_length(state_type&, const extern_type* __frm, const extern_type* __end, size_t __mx) const;
    virtual int do_max_length() const  _NOEXCEPT;
};

// template <class _InternT, class _ExternT, class _StateT> class codecvt_byname

template <class _InternT, class _ExternT, class _StateT>
class _LIBCPP_TYPE_VIS_ONLY codecvt_byname
    : public codecvt<_InternT, _ExternT, _StateT>
{
public:
    _LIBCPP_ALWAYS_INLINE
    explicit codecvt_byname(const char* __nm, size_t __refs = 0)
        : codecvt<_InternT, _ExternT, _StateT>(__nm, __refs) {}
    _LIBCPP_ALWAYS_INLINE
    explicit codecvt_byname(const string& __nm, size_t __refs = 0)
        : codecvt<_InternT, _ExternT, _StateT>(__nm.c_str(), __refs) {}
protected:
    ~codecvt_byname();
};

template <class _InternT, class _ExternT, class _StateT>
codecvt_byname<_InternT, _ExternT, _StateT>::~codecvt_byname()
{
}

_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS codecvt_byname<char, char, mbstate_t>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS codecvt_byname<wchar_t, char, mbstate_t>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS codecvt_byname<char16_t, char, mbstate_t>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS codecvt_byname<char32_t, char, mbstate_t>)

_LIBCPP_FUNC_VIS void __throw_runtime_error(const char*);

template <size_t _Np>
struct __narrow_to_utf8
{
    template <class _OutputIterator, class _CharT>
    _OutputIterator
    operator()(_OutputIterator __s, const _CharT* __wb, const _CharT* __we) const;
};

template <>
struct __narrow_to_utf8<8>
{
    template <class _OutputIterator, class _CharT>
    _LIBCPP_ALWAYS_INLINE
    _OutputIterator
    operator()(_OutputIterator __s, const _CharT* __wb, const _CharT* __we) const
    {
        for (; __wb < __we; ++__wb, ++__s)
            *__s = *__wb;
        return __s;
    }
};

template <>
struct __narrow_to_utf8<16>
    : public codecvt<char16_t, char, mbstate_t>
{
    _LIBCPP_ALWAYS_INLINE
    __narrow_to_utf8() : codecvt<char16_t, char, mbstate_t>(1) {}

    ~__narrow_to_utf8();

    template <class _OutputIterator, class _CharT>
    _LIBCPP_ALWAYS_INLINE
    _OutputIterator
    operator()(_OutputIterator __s, const _CharT* __wb, const _CharT* __we) const
    {
        result __r = ok;
        mbstate_t __mb;
        while (__wb < __we && __r != error)
        {
            const int __sz = 32;
            char __buf[__sz];
            char* __bn;
            const char16_t* __wn = (const char16_t*)__wb;
            __r = do_out(__mb, (const char16_t*)__wb, (const char16_t*)__we, __wn,
                         __buf, __buf+__sz, __bn);
            if (__r == codecvt_base::error || __wn == (const char16_t*)__wb)
                __throw_runtime_error("locale not supported");
            for (const char* __p = __buf; __p < __bn; ++__p, ++__s)
                *__s = *__p;
            __wb = (const _CharT*)__wn;
        }
        return __s;
    }
};

template <>
struct __narrow_to_utf8<32>
    : public codecvt<char32_t, char, mbstate_t>
{
    _LIBCPP_ALWAYS_INLINE
    __narrow_to_utf8() : codecvt<char32_t, char, mbstate_t>(1) {}

    ~__narrow_to_utf8();

    template <class _OutputIterator, class _CharT>
    _LIBCPP_ALWAYS_INLINE
    _OutputIterator
    operator()(_OutputIterator __s, const _CharT* __wb, const _CharT* __we) const
    {
        result __r = ok;
        mbstate_t __mb;
        while (__wb < __we && __r != error)
        {
            const int __sz = 32;
            char __buf[__sz];
            char* __bn;
            const char32_t* __wn = (const char32_t*)__wb;
            __r = do_out(__mb, (const char32_t*)__wb, (const char32_t*)__we, __wn,
                         __buf, __buf+__sz, __bn);
            if (__r == codecvt_base::error || __wn == (const char32_t*)__wb)
                __throw_runtime_error("locale not supported");
            for (const char* __p = __buf; __p < __bn; ++__p, ++__s)
                *__s = *__p;
            __wb = (const _CharT*)__wn;
        }
        return __s;
    }
};

template <size_t _Np>
struct __widen_from_utf8
{
    template <class _OutputIterator>
    _OutputIterator
    operator()(_OutputIterator __s, const char* __nb, const char* __ne) const;
};

template <>
struct __widen_from_utf8<8>
{
    template <class _OutputIterator>
    _LIBCPP_ALWAYS_INLINE
    _OutputIterator
    operator()(_OutputIterator __s, const char* __nb, const char* __ne) const
    {
        for (; __nb < __ne; ++__nb, ++__s)
            *__s = *__nb;
        return __s;
    }
};

template <>
struct __widen_from_utf8<16>
    : public codecvt<char16_t, char, mbstate_t>
{
    _LIBCPP_ALWAYS_INLINE
    __widen_from_utf8() : codecvt<char16_t, char, mbstate_t>(1) {}

    ~__widen_from_utf8();

    template <class _OutputIterator>
    _LIBCPP_ALWAYS_INLINE
    _OutputIterator
    operator()(_OutputIterator __s, const char* __nb, const char* __ne) const
    {
        result __r = ok;
        mbstate_t __mb;
        while (__nb < __ne && __r != error)
        {
            const int __sz = 32;
            char16_t __buf[__sz];
            char16_t* __bn;
            const char* __nn = __nb;
            __r = do_in(__mb, __nb, __ne - __nb > __sz ? __nb+__sz : __ne, __nn,
                        __buf, __buf+__sz, __bn);
            if (__r == codecvt_base::error || __nn == __nb)
                __throw_runtime_error("locale not supported");
            for (const char16_t* __p = __buf; __p < __bn; ++__p, ++__s)
                *__s = (wchar_t)*__p;
            __nb = __nn;
        }
        return __s;
    }
};

template <>
struct __widen_from_utf8<32>
    : public codecvt<char32_t, char, mbstate_t>
{
    _LIBCPP_ALWAYS_INLINE
    __widen_from_utf8() : codecvt<char32_t, char, mbstate_t>(1) {}

    ~__widen_from_utf8();

    template <class _OutputIterator>
    _LIBCPP_ALWAYS_INLINE
    _OutputIterator
    operator()(_OutputIterator __s, const char* __nb, const char* __ne) const
    {
        result __r = ok;
        mbstate_t __mb;
        while (__nb < __ne && __r != error)
        {
            const int __sz = 32;
            char32_t __buf[__sz];
            char32_t* __bn;
            const char* __nn = __nb;
            __r = do_in(__mb, __nb, __ne - __nb > __sz ? __nb+__sz : __ne, __nn,
                        __buf, __buf+__sz, __bn);
            if (__r == codecvt_base::error || __nn == __nb)
                __throw_runtime_error("locale not supported");
            for (const char32_t* __p = __buf; __p < __bn; ++__p, ++__s)
                *__s = (wchar_t)*__p;
            __nb = __nn;
        }
        return __s;
    }
};

// template <class charT> class numpunct

template <class _CharT> class _LIBCPP_TYPE_VIS_ONLY numpunct;

template <>
class _LIBCPP_TYPE_VIS numpunct<char>
    : public locale::facet
{
public:
    typedef char char_type;
    typedef basic_string<char_type> string_type;

    explicit numpunct(size_t __refs = 0);

    _LIBCPP_ALWAYS_INLINE char_type decimal_point() const {return do_decimal_point();}
    _LIBCPP_ALWAYS_INLINE char_type thousands_sep() const {return do_thousands_sep();}
    _LIBCPP_ALWAYS_INLINE string grouping() const         {return do_grouping();}
    _LIBCPP_ALWAYS_INLINE string_type truename() const    {return do_truename();}
    _LIBCPP_ALWAYS_INLINE string_type falsename() const   {return do_falsename();}

    static locale::id id;

protected:
    ~numpunct();
    virtual char_type do_decimal_point() const;
    virtual char_type do_thousands_sep() const;
    virtual string do_grouping() const;
    virtual string_type do_truename() const;
    virtual string_type do_falsename() const;

    char_type __decimal_point_;
    char_type __thousands_sep_;
    string __grouping_;
};

template <>
class _LIBCPP_TYPE_VIS numpunct<wchar_t>
    : public locale::facet
{
public:
    typedef wchar_t char_type;
    typedef basic_string<char_type> string_type;

    explicit numpunct(size_t __refs = 0);

    _LIBCPP_ALWAYS_INLINE char_type decimal_point() const {return do_decimal_point();}
    _LIBCPP_ALWAYS_INLINE char_type thousands_sep() const {return do_thousands_sep();}
    _LIBCPP_ALWAYS_INLINE string grouping() const         {return do_grouping();}
    _LIBCPP_ALWAYS_INLINE string_type truename() const    {return do_truename();}
    _LIBCPP_ALWAYS_INLINE string_type falsename() const   {return do_falsename();}

    static locale::id id;

protected:
    ~numpunct();
    virtual char_type do_decimal_point() const;
    virtual char_type do_thousands_sep() const;
    virtual string do_grouping() const;
    virtual string_type do_truename() const;
    virtual string_type do_falsename() const;

    char_type __decimal_point_;
    char_type __thousands_sep_;
    string __grouping_;
};

// template <class charT> class numpunct_byname

template <class charT> class _LIBCPP_TYPE_VIS_ONLY numpunct_byname;

template <>
class _LIBCPP_TYPE_VIS numpunct_byname<char>
: public numpunct<char>
{
public:
    typedef char char_type;
    typedef basic_string<char_type> string_type;

    explicit numpunct_byname(const char* __nm, size_t __refs = 0);
    explicit numpunct_byname(const string& __nm, size_t __refs = 0);

protected:
    ~numpunct_byname();

private:
    void __init(const char*);
};

template <>
class _LIBCPP_TYPE_VIS numpunct_byname<wchar_t>
: public numpunct<wchar_t>
{
public:
    typedef wchar_t char_type;
    typedef basic_string<char_type> string_type;

    explicit numpunct_byname(const char* __nm, size_t __refs = 0);
    explicit numpunct_byname(const string& __nm, size_t __refs = 0);

protected:
    ~numpunct_byname();

private:
    void __init(const char*);
};

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP___LOCALE
# 1446 "/usr/include/c++/v1/__locale" 3
# 183 "/usr/include/c++/v1/locale" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <algorithm>
#endif /* expanded by -frewrite-includes */
# 184 "/usr/include/c++/v1/locale" 3
#if 0 /* expanded by -frewrite-includes */
#include <memory>
#endif /* expanded by -frewrite-includes */
# 185 "/usr/include/c++/v1/locale" 3
#if 0 /* expanded by -frewrite-includes */
#include <ios>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/ios" 1 3
// -*- C++ -*-
//===---------------------------- ios -------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_IOS
#define _LIBCPP_IOS

/*
    ios synopsis

#include <iosfwd>

namespace std
{

typedef OFF_T streamoff;
typedef SZ_T streamsize;
template <class stateT> class fpos;

class ios_base
{
public:
    class failure;

    typedef T1 fmtflags;
    static constexpr fmtflags boolalpha;
    static constexpr fmtflags dec;
    static constexpr fmtflags fixed;
    static constexpr fmtflags hex;
    static constexpr fmtflags internal;
    static constexpr fmtflags left;
    static constexpr fmtflags oct;
    static constexpr fmtflags right;
    static constexpr fmtflags scientific;
    static constexpr fmtflags showbase;
    static constexpr fmtflags showpoint;
    static constexpr fmtflags showpos;
    static constexpr fmtflags skipws;
    static constexpr fmtflags unitbuf;
    static constexpr fmtflags uppercase;
    static constexpr fmtflags adjustfield;
    static constexpr fmtflags basefield;
    static constexpr fmtflags floatfield;

    typedef T2 iostate;
    static constexpr iostate badbit;
    static constexpr iostate eofbit;
    static constexpr iostate failbit;
    static constexpr iostate goodbit;

    typedef T3 openmode;
    static constexpr openmode app;
    static constexpr openmode ate;
    static constexpr openmode binary;
    static constexpr openmode in;
    static constexpr openmode out;
    static constexpr openmode trunc;

    typedef T4 seekdir;
    static constexpr seekdir beg;
    static constexpr seekdir cur;
    static constexpr seekdir end;

    class Init;

    // 27.5.2.2 fmtflags state:
    fmtflags flags() const;
    fmtflags flags(fmtflags fmtfl);
    fmtflags setf(fmtflags fmtfl);
    fmtflags setf(fmtflags fmtfl, fmtflags mask);
    void unsetf(fmtflags mask);

    streamsize precision() const;
    streamsize precision(streamsize prec);
    streamsize width() const;
    streamsize width(streamsize wide);

    // 27.5.2.3 locales:
    locale imbue(const locale& loc);
    locale getloc() const;

    // 27.5.2.5 storage:
    static int xalloc();
    long& iword(int index);
    void*& pword(int index);

    // destructor
    virtual ~ios_base();

    // 27.5.2.6 callbacks;
    enum event { erase_event, imbue_event, copyfmt_event };
    typedef void (*event_callback)(event, ios_base&, int index);
    void register_callback(event_callback fn, int index);

    ios_base(const ios_base&) = delete;
    ios_base& operator=(const ios_base&) = delete;

    static bool sync_with_stdio(bool sync = true);

protected:
    ios_base();
};

template <class charT, class traits = char_traits<charT> >
class basic_ios
    : public ios_base
{
public:
    // types:
    typedef charT char_type;
    typedef typename traits::int_type int_type;
    typedef typename traits::pos_type pos_type;
    typedef typename traits::off_type off_type;
    typedef traits traits_type;

    operator unspecified-bool-type() const;
    bool operator!() const;
    iostate rdstate() const;
    void clear(iostate state = goodbit);
    void setstate(iostate state);
    bool good() const;
    bool eof() const;
    bool fail() const;
    bool bad() const;

    iostate exceptions() const;
    void exceptions(iostate except);

    // 27.5.4.1 Constructor/destructor:
    explicit basic_ios(basic_streambuf<charT,traits>* sb);
    virtual ~basic_ios();

    // 27.5.4.2 Members:
    basic_ostream<charT,traits>* tie() const;
    basic_ostream<charT,traits>* tie(basic_ostream<charT,traits>* tiestr);

    basic_streambuf<charT,traits>* rdbuf() const;
    basic_streambuf<charT,traits>* rdbuf(basic_streambuf<charT,traits>* sb);

    basic_ios& copyfmt(const basic_ios& rhs);

    char_type fill() const;
    char_type fill(char_type ch);

    locale imbue(const locale& loc);

    char narrow(char_type c, char dfault) const;
    char_type widen(char c) const;

    basic_ios(const basic_ios& ) = delete;
    basic_ios& operator=(const basic_ios&) = delete;

protected:
    basic_ios();
    void init(basic_streambuf<charT,traits>* sb);
    void move(basic_ios& rhs);
    void swap(basic_ios& rhs) noexcept;
    void set_rdbuf(basic_streambuf<charT, traits>* sb);
};

// 27.5.5, manipulators:
ios_base& boolalpha (ios_base& str);
ios_base& noboolalpha(ios_base& str);
ios_base& showbase (ios_base& str);
ios_base& noshowbase (ios_base& str);
ios_base& showpoint (ios_base& str);
ios_base& noshowpoint(ios_base& str);
ios_base& showpos (ios_base& str);
ios_base& noshowpos (ios_base& str);
ios_base& skipws (ios_base& str);
ios_base& noskipws (ios_base& str);
ios_base& uppercase (ios_base& str);
ios_base& nouppercase(ios_base& str);
ios_base& unitbuf (ios_base& str);
ios_base& nounitbuf (ios_base& str);

// 27.5.5.2 adjustfield:
ios_base& internal (ios_base& str);
ios_base& left (ios_base& str);
ios_base& right (ios_base& str);

// 27.5.5.3 basefield:
ios_base& dec (ios_base& str);
ios_base& hex (ios_base& str);
ios_base& oct (ios_base& str);

// 27.5.5.4 floatfield:
ios_base& fixed (ios_base& str);
ios_base& scientific (ios_base& str);
ios_base& hexfloat (ios_base& str);
ios_base& defaultfloat(ios_base& str);

// 27.5.5.5 error reporting:
enum class io_errc
{
    stream = 1
};

concept_map ErrorCodeEnum<io_errc> { };
error_code make_error_code(io_errc e) noexcept; 
error_condition make_error_condition(io_errc e) noexcept; 
storage-class-specifier const error_category& iostream_category() noexcept;

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 215 "/usr/include/c++/v1/ios" 3
#if 0 /* expanded by -frewrite-includes */
#include <iosfwd>
#endif /* expanded by -frewrite-includes */
# 216 "/usr/include/c++/v1/ios" 3
#if 0 /* expanded by -frewrite-includes */
#include <__locale>
#endif /* expanded by -frewrite-includes */
# 217 "/usr/include/c++/v1/ios" 3
#if 0 /* expanded by -frewrite-includes */
#include <system_error>
#endif /* expanded by -frewrite-includes */
# 218 "/usr/include/c++/v1/ios" 3

#if __has_feature(cxx_atomic)
#if 0 /* expanded by -frewrite-includes */
#include <atomic>     // for __xindex_
#endif /* expanded by -frewrite-includes */
# 221 "/usr/include/c++/v1/ios" 3
#endif
# 222 "/usr/include/c++/v1/ios" 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 225 "/usr/include/c++/v1/ios" 3
#endif
# 226 "/usr/include/c++/v1/ios" 3

_LIBCPP_BEGIN_NAMESPACE_STD

typedef ptrdiff_t streamsize;

class _LIBCPP_TYPE_VIS ios_base
{
public:
    class _LIBCPP_TYPE_VIS failure;

    typedef unsigned int fmtflags;
    static const fmtflags boolalpha   = 0x0001;
    static const fmtflags dec         = 0x0002;
    static const fmtflags fixed       = 0x0004;
    static const fmtflags hex         = 0x0008;
    static const fmtflags internal    = 0x0010;
    static const fmtflags left        = 0x0020;
    static const fmtflags oct         = 0x0040;
    static const fmtflags right       = 0x0080;
    static const fmtflags scientific  = 0x0100;
    static const fmtflags showbase    = 0x0200;
    static const fmtflags showpoint   = 0x0400;
    static const fmtflags showpos     = 0x0800;
    static const fmtflags skipws      = 0x1000;
    static const fmtflags unitbuf     = 0x2000;
    static const fmtflags uppercase   = 0x4000;
    static const fmtflags adjustfield = left | right | internal;
    static const fmtflags basefield   = dec | oct | hex;
    static const fmtflags floatfield  = scientific | fixed;

    typedef unsigned int iostate;
    typedef iostate      io_state;
    static const iostate badbit  = 0x1;
    static const iostate eofbit  = 0x2;
    static const iostate failbit = 0x4;
    static const iostate goodbit = 0x0;

    typedef unsigned int openmode;
    typedef openmode     open_mode;
    static const openmode app    = 0x01;
    static const openmode ate    = 0x02;
    static const openmode binary = 0x04;
    static const openmode in     = 0x08;
    static const openmode out    = 0x10;
    static const openmode trunc  = 0x20;

    enum seekdir {beg, cur, end};
    typedef seekdir seek_dir;

    typedef _VSTD::streamoff streamoff;
    typedef _VSTD::streampos streampos;

    class _LIBCPP_TYPE_VIS Init;

    // 27.5.2.2 fmtflags state:
    _LIBCPP_INLINE_VISIBILITY fmtflags flags() const;
    _LIBCPP_INLINE_VISIBILITY fmtflags flags(fmtflags __fmtfl);
    _LIBCPP_INLINE_VISIBILITY fmtflags setf(fmtflags __fmtfl);
    _LIBCPP_INLINE_VISIBILITY fmtflags setf(fmtflags __fmtfl, fmtflags __mask);
    _LIBCPP_INLINE_VISIBILITY void unsetf(fmtflags __mask);

    _LIBCPP_INLINE_VISIBILITY streamsize precision() const;
    _LIBCPP_INLINE_VISIBILITY streamsize precision(streamsize __prec);
    _LIBCPP_INLINE_VISIBILITY streamsize width() const;
    _LIBCPP_INLINE_VISIBILITY streamsize width(streamsize __wide);

    // 27.5.2.3 locales:
    locale imbue(const locale& __loc);
    locale getloc() const;

    // 27.5.2.5 storage:
    static int xalloc();
    long& iword(int __index);
    void*& pword(int __index);

    // destructor
    virtual ~ios_base();

    // 27.5.2.6 callbacks;
    enum event { erase_event, imbue_event, copyfmt_event };
    typedef void (*event_callback)(event, ios_base&, int __index);
    void register_callback(event_callback __fn, int __index);

private:
    ios_base(const ios_base&); // = delete;
    ios_base& operator=(const ios_base&); // = delete;

public:
    static bool sync_with_stdio(bool __sync = true);

    _LIBCPP_INLINE_VISIBILITY iostate rdstate() const;
    void clear(iostate __state = goodbit);
    _LIBCPP_INLINE_VISIBILITY void setstate(iostate __state);

    _LIBCPP_INLINE_VISIBILITY bool good() const;
    _LIBCPP_INLINE_VISIBILITY bool eof() const;
    _LIBCPP_INLINE_VISIBILITY bool fail() const;
    _LIBCPP_INLINE_VISIBILITY bool bad() const;

    _LIBCPP_INLINE_VISIBILITY iostate exceptions() const;
    _LIBCPP_INLINE_VISIBILITY void exceptions(iostate __iostate);

    void __set_badbit_and_consider_rethrow();
    void __set_failbit_and_consider_rethrow();

protected:
    _LIBCPP_INLINE_VISIBILITY
    ios_base() {// purposefully does no initialization
               }

    void init(void* __sb);
    _LIBCPP_ALWAYS_INLINE void* rdbuf() const {return __rdbuf_;}

    _LIBCPP_ALWAYS_INLINE
    void rdbuf(void* __sb)
    {
        __rdbuf_ = __sb;
        clear();
    }

    void __call_callbacks(event);
    void copyfmt(const ios_base&);
    void move(ios_base&);
    void swap(ios_base&) _NOEXCEPT;

    _LIBCPP_ALWAYS_INLINE
    void set_rdbuf(void* __sb)
    {
        __rdbuf_ = __sb;
    }

private:
    // All data members must be scalars
    fmtflags        __fmtflags_;
    streamsize      __precision_;
    streamsize      __width_;
    iostate         __rdstate_;
    iostate         __exceptions_;
    void*           __rdbuf_;
    void*           __loc_;
    event_callback* __fn_;
    int*            __index_;
    size_t          __event_size_;
    size_t          __event_cap_;
#if __has_feature(cxx_atomic)
    static atomic<int> __xindex_;
#else
# 373 "/usr/include/c++/v1/ios" 3
    static int      __xindex_;
#endif
# 375 "/usr/include/c++/v1/ios" 3
    long*           __iarray_;
    size_t          __iarray_size_;
    size_t          __iarray_cap_;
    void**          __parray_;
    size_t          __parray_size_;
    size_t          __parray_cap_;
};

//enum class io_errc
_LIBCPP_DECLARE_STRONG_ENUM(io_errc)
{
    stream = 1
};
_LIBCPP_DECLARE_STRONG_ENUM_EPILOG(io_errc)

template <>
struct _LIBCPP_TYPE_VIS_ONLY is_error_code_enum<io_errc> : public true_type { };

#ifdef _LIBCPP_HAS_NO_STRONG_ENUMS
template <>
struct _LIBCPP_TYPE_VIS_ONLY is_error_code_enum<io_errc::__lx> : public true_type { };
#endif
# 397 "/usr/include/c++/v1/ios" 3

_LIBCPP_FUNC_VIS
const error_category& iostream_category() _NOEXCEPT;

inline _LIBCPP_INLINE_VISIBILITY
error_code
make_error_code(io_errc __e) _NOEXCEPT
{
    return error_code(static_cast<int>(__e), iostream_category());
}

inline _LIBCPP_INLINE_VISIBILITY
error_condition
make_error_condition(io_errc __e) _NOEXCEPT
{
    return error_condition(static_cast<int>(__e), iostream_category());
}

class _LIBCPP_EXCEPTION_ABI ios_base::failure
    : public system_error
{
public:
    explicit failure(const string& __msg, const error_code& __ec = io_errc::stream);
    explicit failure(const char* __msg, const error_code& __ec = io_errc::stream);
    virtual ~failure() throw();
};

class _LIBCPP_TYPE_VIS ios_base::Init
{
public:
    Init();
    ~Init();
};

// fmtflags

inline _LIBCPP_INLINE_VISIBILITY
ios_base::fmtflags
ios_base::flags() const
{
    return __fmtflags_;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base::fmtflags
ios_base::flags(fmtflags __fmtfl)
{
    fmtflags __r = __fmtflags_;
    __fmtflags_ = __fmtfl;
    return __r;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base::fmtflags
ios_base::setf(fmtflags __fmtfl)
{
    fmtflags __r = __fmtflags_;
    __fmtflags_ |= __fmtfl;
    return __r;
}

inline _LIBCPP_INLINE_VISIBILITY
void
ios_base::unsetf(fmtflags __mask)
{
    __fmtflags_ &= ~__mask;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base::fmtflags
ios_base::setf(fmtflags __fmtfl, fmtflags __mask)
{
    fmtflags __r = __fmtflags_;
    unsetf(__mask);
    __fmtflags_ |= __fmtfl & __mask;
    return __r;
}

// precision

inline _LIBCPP_INLINE_VISIBILITY
streamsize
ios_base::precision() const
{
    return __precision_;
}

inline _LIBCPP_INLINE_VISIBILITY
streamsize
ios_base::precision(streamsize __prec)
{
    streamsize __r = __precision_;
    __precision_ = __prec;
    return __r;
}

// width

inline _LIBCPP_INLINE_VISIBILITY
streamsize
ios_base::width() const
{
    return __width_;
}

inline _LIBCPP_INLINE_VISIBILITY
streamsize
ios_base::width(streamsize __wide)
{
    streamsize __r = __width_;
    __width_ = __wide;
    return __r;
}

// iostate

inline _LIBCPP_INLINE_VISIBILITY
ios_base::iostate
ios_base::rdstate() const
{
    return __rdstate_;
}

inline _LIBCPP_INLINE_VISIBILITY
void
ios_base::setstate(iostate __state)
{
    clear(__rdstate_ | __state);
}

inline _LIBCPP_INLINE_VISIBILITY
bool
ios_base::good() const
{
    return __rdstate_ == 0;
}

inline _LIBCPP_INLINE_VISIBILITY
bool
ios_base::eof() const
{
    return (__rdstate_ & eofbit) != 0;
}

inline _LIBCPP_INLINE_VISIBILITY
bool
ios_base::fail() const
{
    return (__rdstate_ & (failbit | badbit)) != 0;
}

inline _LIBCPP_INLINE_VISIBILITY
bool
ios_base::bad() const
{
    return (__rdstate_ & badbit) != 0;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base::iostate
ios_base::exceptions() const
{
    return __exceptions_;
}

inline _LIBCPP_INLINE_VISIBILITY
void
ios_base::exceptions(iostate __iostate)
{
    __exceptions_ = __iostate;
    clear(__rdstate_);
}

template <class _CharT, class _Traits>
class _LIBCPP_TYPE_VIS_ONLY basic_ios
    : public ios_base
{
public:
    // types:
    typedef _CharT char_type;
    typedef _Traits traits_type;

    typedef typename traits_type::int_type int_type;
    typedef typename traits_type::pos_type pos_type;
    typedef typename traits_type::off_type off_type;

    _LIBCPP_ALWAYS_INLINE
        _LIBCPP_EXPLICIT
        operator bool() const {return !fail();}
    _LIBCPP_ALWAYS_INLINE bool operator!() const    {return  fail();}
    _LIBCPP_ALWAYS_INLINE iostate rdstate() const   {return ios_base::rdstate();}
    _LIBCPP_ALWAYS_INLINE void clear(iostate __state = goodbit) {ios_base::clear(__state);}
    _LIBCPP_ALWAYS_INLINE void setstate(iostate __state) {ios_base::setstate(__state);}
    _LIBCPP_ALWAYS_INLINE bool good() const {return ios_base::good();}
    _LIBCPP_ALWAYS_INLINE bool eof() const  {return ios_base::eof();}
    _LIBCPP_ALWAYS_INLINE bool fail() const {return ios_base::fail();}
    _LIBCPP_ALWAYS_INLINE bool bad() const  {return ios_base::bad();}

    _LIBCPP_ALWAYS_INLINE iostate exceptions() const {return ios_base::exceptions();}
    _LIBCPP_ALWAYS_INLINE void exceptions(iostate __iostate) {ios_base::exceptions(__iostate);}

    // 27.5.4.1 Constructor/destructor:
    _LIBCPP_INLINE_VISIBILITY
    explicit basic_ios(basic_streambuf<char_type,traits_type>* __sb);
    virtual ~basic_ios();

    // 27.5.4.2 Members:
    _LIBCPP_INLINE_VISIBILITY 
    basic_ostream<char_type, traits_type>* tie() const;
    _LIBCPP_INLINE_VISIBILITY 
    basic_ostream<char_type, traits_type>* tie(basic_ostream<char_type, traits_type>* __tiestr);

    _LIBCPP_INLINE_VISIBILITY 
    basic_streambuf<char_type, traits_type>* rdbuf() const;
    _LIBCPP_INLINE_VISIBILITY 
    basic_streambuf<char_type, traits_type>* rdbuf(basic_streambuf<char_type, traits_type>* __sb);

    basic_ios& copyfmt(const basic_ios& __rhs);

    _LIBCPP_INLINE_VISIBILITY 
    char_type fill() const;
    _LIBCPP_INLINE_VISIBILITY 
    char_type fill(char_type __ch);

    _LIBCPP_INLINE_VISIBILITY 
    locale imbue(const locale& __loc);

    _LIBCPP_INLINE_VISIBILITY 
    char narrow(char_type __c, char __dfault) const;
    _LIBCPP_INLINE_VISIBILITY 
    char_type widen(char __c) const;

protected:
    _LIBCPP_ALWAYS_INLINE
    basic_ios() {// purposefully does no initialization
                }
    _LIBCPP_INLINE_VISIBILITY 
    void init(basic_streambuf<char_type, traits_type>* __sb);

    _LIBCPP_INLINE_VISIBILITY 
    void move(basic_ios& __rhs);
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    _LIBCPP_ALWAYS_INLINE
    void move(basic_ios&& __rhs) {move(__rhs);}
#endif
# 642 "/usr/include/c++/v1/ios" 3
    _LIBCPP_INLINE_VISIBILITY 
    void swap(basic_ios& __rhs) _NOEXCEPT;
    _LIBCPP_INLINE_VISIBILITY 
    void set_rdbuf(basic_streambuf<char_type, traits_type>* __sb);
private:
    basic_ostream<char_type, traits_type>* __tie_;
     mutable int_type __fill_;
};

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
basic_ios<_CharT, _Traits>::basic_ios(basic_streambuf<char_type,traits_type>* __sb)
{
    init(__sb);
}

template <class _CharT, class _Traits>
basic_ios<_CharT, _Traits>::~basic_ios()
{
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
void
basic_ios<_CharT, _Traits>::init(basic_streambuf<char_type, traits_type>* __sb)
{
    ios_base::init(__sb);
    __tie_ = 0;
    __fill_ = traits_type::eof();
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
basic_ostream<_CharT, _Traits>*
basic_ios<_CharT, _Traits>::tie() const
{
    return __tie_;
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
basic_ostream<_CharT, _Traits>*
basic_ios<_CharT, _Traits>::tie(basic_ostream<char_type, traits_type>* __tiestr)
{
    basic_ostream<char_type, traits_type>* __r = __tie_;
    __tie_ = __tiestr;
    return __r;
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
basic_streambuf<_CharT, _Traits>*
basic_ios<_CharT, _Traits>::rdbuf() const
{
    return static_cast<basic_streambuf<char_type, traits_type>*>(ios_base::rdbuf());
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
basic_streambuf<_CharT, _Traits>*
basic_ios<_CharT, _Traits>::rdbuf(basic_streambuf<char_type, traits_type>* __sb)
{
    basic_streambuf<char_type, traits_type>* __r = rdbuf();
    ios_base::rdbuf(__sb);
    return __r;
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
locale
basic_ios<_CharT, _Traits>::imbue(const locale& __loc)
{
    locale __r = getloc();
    ios_base::imbue(__loc);
    if (rdbuf())
        rdbuf()->pubimbue(__loc);
    return __r;
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
char
basic_ios<_CharT, _Traits>::narrow(char_type __c, char __dfault) const
{
    return use_facet<ctype<char_type> >(getloc()).narrow(__c, __dfault);
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
_CharT
basic_ios<_CharT, _Traits>::widen(char __c) const
{
    return use_facet<ctype<char_type> >(getloc()).widen(__c);
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
_CharT
basic_ios<_CharT, _Traits>::fill() const
{
    if (traits_type::eq_int_type(traits_type::eof(), __fill_))
        __fill_ = widen(' ');
    return __fill_;
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
_CharT
basic_ios<_CharT, _Traits>::fill(char_type __ch)
{
    char_type __r = __fill_;
    __fill_ = __ch;
    return __r;
}

template <class _CharT, class _Traits>
basic_ios<_CharT, _Traits>&
basic_ios<_CharT, _Traits>::copyfmt(const basic_ios& __rhs)
{
    if (this != &__rhs)
    {
        __call_callbacks(erase_event);
        ios_base::copyfmt(__rhs);
        __tie_ = __rhs.__tie_;
        __fill_ = __rhs.__fill_;
        __call_callbacks(copyfmt_event);
        exceptions(__rhs.exceptions());
    }
    return *this;
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
void
basic_ios<_CharT, _Traits>::move(basic_ios& __rhs)
{
    ios_base::move(__rhs);
    __tie_ = __rhs.__tie_;
    __rhs.__tie_ = 0;
    __fill_ = __rhs.__fill_;
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
void
basic_ios<_CharT, _Traits>::swap(basic_ios& __rhs) _NOEXCEPT
{
    ios_base::swap(__rhs);
    _VSTD::swap(__tie_, __rhs.__tie_);
    _VSTD::swap(__fill_, __rhs.__fill_);
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
void
basic_ios<_CharT, _Traits>::set_rdbuf(basic_streambuf<char_type, traits_type>* __sb)
{
    ios_base::set_rdbuf(__sb);
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
boolalpha(ios_base& __str)
{
    __str.setf(ios_base::boolalpha);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
noboolalpha(ios_base& __str)
{
    __str.unsetf(ios_base::boolalpha);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
showbase(ios_base& __str)
{
    __str.setf(ios_base::showbase);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
noshowbase(ios_base& __str)
{
    __str.unsetf(ios_base::showbase);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
showpoint(ios_base& __str)
{
    __str.setf(ios_base::showpoint);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
noshowpoint(ios_base& __str)
{
    __str.unsetf(ios_base::showpoint);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
showpos(ios_base& __str)
{
    __str.setf(ios_base::showpos);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
noshowpos(ios_base& __str)
{
    __str.unsetf(ios_base::showpos);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
skipws(ios_base& __str)
{
    __str.setf(ios_base::skipws);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
noskipws(ios_base& __str)
{
    __str.unsetf(ios_base::skipws);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
uppercase(ios_base& __str)
{
    __str.setf(ios_base::uppercase);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
nouppercase(ios_base& __str)
{
    __str.unsetf(ios_base::uppercase);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
unitbuf(ios_base& __str)
{
    __str.setf(ios_base::unitbuf);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
nounitbuf(ios_base& __str)
{
    __str.unsetf(ios_base::unitbuf);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
internal(ios_base& __str)
{
    __str.setf(ios_base::internal, ios_base::adjustfield);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
left(ios_base& __str)
{
    __str.setf(ios_base::left, ios_base::adjustfield);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
right(ios_base& __str)
{
    __str.setf(ios_base::right, ios_base::adjustfield);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
dec(ios_base& __str)
{
    __str.setf(ios_base::dec, ios_base::basefield);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
hex(ios_base& __str)
{
    __str.setf(ios_base::hex, ios_base::basefield);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
oct(ios_base& __str)
{
    __str.setf(ios_base::oct, ios_base::basefield);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
fixed(ios_base& __str)
{
    __str.setf(ios_base::fixed, ios_base::floatfield);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
scientific(ios_base& __str)
{
    __str.setf(ios_base::scientific, ios_base::floatfield);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
hexfloat(ios_base& __str)
{
    __str.setf(ios_base::fixed | ios_base::scientific, ios_base::floatfield);
    return __str;
}

inline _LIBCPP_INLINE_VISIBILITY
ios_base&
defaultfloat(ios_base& __str)
{
    __str.unsetf(ios_base::floatfield);
    return __str;
}

template <class _CharT, class _Traits>
class __save_flags
{
    typedef basic_ios<_CharT, _Traits> __stream_type;
    typedef typename __stream_type::fmtflags fmtflags;

    __stream_type& __stream_;
    fmtflags       __fmtflags_;
    _CharT         __fill_;

    __save_flags(const __save_flags&);
    __save_flags& operator=(const __save_flags&);
public:
    _LIBCPP_INLINE_VISIBILITY
    explicit __save_flags(__stream_type& __stream)
        : __stream_(__stream),
          __fmtflags_(__stream.flags()),
          __fill_(__stream.fill())
        {}
    _LIBCPP_INLINE_VISIBILITY
    ~__save_flags()
    {
        __stream_.flags(__fmtflags_);
        __stream_.fill(__fill_);
    }
};

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_IOS
# 1024 "/usr/include/c++/v1/ios" 3
# 186 "/usr/include/c++/v1/locale" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <streambuf>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/streambuf" 1 3
// -*- C++ -*-
//===------------------------- streambuf ----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_STEAMBUF
#define _LIBCPP_STEAMBUF

/*
    streambuf synopsis

namespace std
{

template <class charT, class traits = char_traits<charT> >
class basic_streambuf
{
public:
    // types:
    typedef charT char_type;
    typedef traits traits_type;
    typedef typename traits_type::int_type int_type;
    typedef typename traits_type::pos_type pos_type;
    typedef typename traits_type::off_type off_type;

    virtual ~basic_streambuf();

    // 27.6.2.2.1 locales:
    locale pubimbue(const locale& loc);
    locale getloc() const;

    // 27.6.2.2.2 buffer and positioning:
    basic_streambuf* pubsetbuf(char_type* s, streamsize n);
    pos_type pubseekoff(off_type off, ios_base::seekdir way,
                        ios_base::openmode which = ios_base::in | ios_base::out);
    pos_type pubseekpos(pos_type sp,
                        ios_base::openmode which = ios_base::in | ios_base::out);
    int pubsync();

    // Get and put areas:
    // 27.6.2.2.3 Get area:
    streamsize in_avail();
    int_type snextc();
    int_type sbumpc();
    int_type sgetc();
    streamsize sgetn(char_type* s, streamsize n);

    // 27.6.2.2.4 Putback:
    int_type sputbackc(char_type c);
    int_type sungetc();

    // 27.6.2.2.5 Put area:
    int_type sputc(char_type c);
    streamsize sputn(const char_type* s, streamsize n);

protected:
    basic_streambuf();
    basic_streambuf(const basic_streambuf& rhs);
    basic_streambuf& operator=(const basic_streambuf& rhs);
    void swap(basic_streambuf& rhs);

    // 27.6.2.3.2 Get area:
    char_type* eback() const;
    char_type* gptr() const;
    char_type* egptr() const;
    void gbump(int n);
    void setg(char_type* gbeg, char_type* gnext, char_type* gend);

    // 27.6.2.3.3 Put area:
    char_type* pbase() const;
    char_type* pptr() const;
    char_type* epptr() const;
    void pbump(int n);
    void setp(char_type* pbeg, char_type* pend);

    // 27.6.2.4 virtual functions:
    // 27.6.2.4.1 Locales:
    virtual void imbue(const locale& loc);

    // 27.6.2.4.2 Buffer management and positioning:
    virtual basic_streambuf* setbuf(char_type* s, streamsize n);
    virtual pos_type seekoff(off_type off, ios_base::seekdir way,
                             ios_base::openmode which = ios_base::in | ios_base::out);
    virtual pos_type seekpos(pos_type sp,
                             ios_base::openmode which = ios_base::in | ios_base::out);
    virtual int sync();

    // 27.6.2.4.3 Get area:
    virtual streamsize showmanyc();
    virtual streamsize xsgetn(char_type* s, streamsize n);
    virtual int_type underflow();
    virtual int_type uflow();

    // 27.6.2.4.4 Putback:
    virtual int_type pbackfail(int_type c = traits_type::eof());

    // 27.6.2.4.5 Put area:
    virtual streamsize xsputn(const char_type* s, streamsize n);
    virtual int_type overflow (int_type c = traits_type::eof());
};

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 112 "/usr/include/c++/v1/streambuf" 3
#if 0 /* expanded by -frewrite-includes */
#include <iosfwd>
#endif /* expanded by -frewrite-includes */
# 113 "/usr/include/c++/v1/streambuf" 3
#if 0 /* expanded by -frewrite-includes */
#include <ios>
#endif /* expanded by -frewrite-includes */
# 114 "/usr/include/c++/v1/streambuf" 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 117 "/usr/include/c++/v1/streambuf" 3
#endif
# 118 "/usr/include/c++/v1/streambuf" 3

_LIBCPP_BEGIN_NAMESPACE_STD

template <class _CharT, class _Traits>
class _LIBCPP_TYPE_VIS_ONLY basic_streambuf
{
public:
    // types:
    typedef _CharT                         char_type;
    typedef _Traits                        traits_type;
    typedef typename traits_type::int_type int_type;
    typedef typename traits_type::pos_type pos_type;
    typedef typename traits_type::off_type off_type;

    virtual ~basic_streambuf();

    // 27.6.2.2.1 locales:
    locale pubimbue(const locale& __loc);
    locale getloc() const;

    // 27.6.2.2.2 buffer and positioning:
    basic_streambuf* pubsetbuf(char_type* __s, streamsize __n);
    pos_type pubseekoff(off_type __off, ios_base::seekdir __way,
                        ios_base::openmode __which = ios_base::in | ios_base::out);
    pos_type pubseekpos(pos_type __sp,
                        ios_base::openmode __which = ios_base::in | ios_base::out);
    int pubsync();

    // Get and put areas:
    // 27.6.2.2.3 Get area:
    streamsize in_avail();
    int_type snextc();
    int_type sbumpc();
    int_type sgetc();
    streamsize sgetn(char_type* __s, streamsize __n);

    // 27.6.2.2.4 Putback:
    int_type sputbackc(char_type __c);
    int_type sungetc();

    // 27.6.2.2.5 Put area:
    int_type sputc(char_type __c);
    streamsize sputn(const char_type* __s, streamsize __n);

protected:
    basic_streambuf();
    basic_streambuf(const basic_streambuf& __rhs);
    basic_streambuf& operator=(const basic_streambuf& __rhs);
    void swap(basic_streambuf& __rhs);

    // 27.6.2.3.2 Get area:
    _LIBCPP_ALWAYS_INLINE char_type* eback() const {return __binp_;}
    _LIBCPP_ALWAYS_INLINE char_type* gptr()  const {return __ninp_;}
    _LIBCPP_ALWAYS_INLINE char_type* egptr() const {return __einp_;}
    void gbump(int __n);
    void setg(char_type* __gbeg, char_type* __gnext, char_type* __gend);

    // 27.6.2.3.3 Put area:
    _LIBCPP_ALWAYS_INLINE char_type* pbase() const {return __bout_;}
    _LIBCPP_ALWAYS_INLINE char_type* pptr()  const {return __nout_;}
    _LIBCPP_ALWAYS_INLINE char_type* epptr() const {return __eout_;}
    void pbump(int __n);
    void setp(char_type* __pbeg, char_type* __pend);

    // 27.6.2.4 virtual functions:
    // 27.6.2.4.1 Locales:
    virtual void imbue(const locale& __loc);

    // 27.6.2.4.2 Buffer management and positioning:
    virtual basic_streambuf* setbuf(char_type* __s, streamsize __n);
    virtual pos_type seekoff(off_type __off, ios_base::seekdir __way,
                             ios_base::openmode __which = ios_base::in | ios_base::out);
    virtual pos_type seekpos(pos_type __sp,
                             ios_base::openmode __which = ios_base::in | ios_base::out);
    virtual int sync();

    // 27.6.2.4.3 Get area:
    virtual streamsize showmanyc();
    virtual streamsize xsgetn(char_type* __s, streamsize __n);
    virtual int_type underflow();
    virtual int_type uflow();

    // 27.6.2.4.4 Putback:
    virtual int_type pbackfail(int_type __c = traits_type::eof());

    // 27.6.2.4.5 Put area:
    virtual streamsize xsputn(const char_type* __s, streamsize __n);
    virtual int_type overflow(int_type __c = traits_type::eof());

private:
    locale __loc_;
    char_type* __binp_;
    char_type* __ninp_;
    char_type* __einp_;
    char_type* __bout_;
    char_type* __nout_;
    char_type* __eout_;
};

template <class _CharT, class _Traits>
basic_streambuf<_CharT, _Traits>::~basic_streambuf()
{
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
locale
basic_streambuf<_CharT, _Traits>::pubimbue(const locale& __loc)
{
    imbue(__loc);
    locale __r = __loc_;
    __loc_ = __loc;
    return __r;
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
locale
basic_streambuf<_CharT, _Traits>::getloc() const
{
    return __loc_;
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
basic_streambuf<_CharT, _Traits>*
basic_streambuf<_CharT, _Traits>::pubsetbuf(char_type* __s, streamsize __n)
{
    return setbuf(__s, __n);
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_streambuf<_CharT, _Traits>::pos_type
basic_streambuf<_CharT, _Traits>::pubseekoff(off_type __off,
                                             ios_base::seekdir __way,
                                             ios_base::openmode __which)
{
    return seekoff(__off, __way, __which);
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_streambuf<_CharT, _Traits>::pos_type
basic_streambuf<_CharT, _Traits>::pubseekpos(pos_type __sp,
                                             ios_base::openmode __which)
{
    return seekpos(__sp, __which);
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
int
basic_streambuf<_CharT, _Traits>::pubsync()
{
    return sync();
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
streamsize
basic_streambuf<_CharT, _Traits>::in_avail()
{
    if (__ninp_ < __einp_)
        return static_cast<streamsize>(__einp_ - __ninp_);
    return showmanyc();
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_streambuf<_CharT, _Traits>::int_type
basic_streambuf<_CharT, _Traits>::snextc()
{
    if (sbumpc() == traits_type::eof())
        return traits_type::eof();
    return sgetc();
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_streambuf<_CharT, _Traits>::int_type
basic_streambuf<_CharT, _Traits>::sbumpc()
{
    if (__ninp_ == __einp_)
        return uflow();
    return traits_type::to_int_type(*__ninp_++);
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_streambuf<_CharT, _Traits>::int_type
basic_streambuf<_CharT, _Traits>::sgetc()
{
    if (__ninp_ == __einp_)
        return underflow();
    return traits_type::to_int_type(*__ninp_);
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
streamsize
basic_streambuf<_CharT, _Traits>::sgetn(char_type* __s, streamsize __n)
{
    return xsgetn(__s, __n);
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_streambuf<_CharT, _Traits>::int_type
basic_streambuf<_CharT, _Traits>::sputbackc(char_type __c)
{
    if (__binp_ == __ninp_ || !traits_type::eq(__c, __ninp_[-1]))
        return pbackfail(traits_type::to_int_type(__c));
    return traits_type::to_int_type(*--__ninp_);
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_streambuf<_CharT, _Traits>::int_type
basic_streambuf<_CharT, _Traits>::sungetc()
{
    if (__binp_ == __ninp_)
        return pbackfail();
    return traits_type::to_int_type(*--__ninp_);
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
typename basic_streambuf<_CharT, _Traits>::int_type
basic_streambuf<_CharT, _Traits>::sputc(char_type __c)
{
    if (__nout_ == __eout_)
        return overflow(traits_type::to_int_type(__c));
    *__nout_++ = __c;
    return traits_type::to_int_type(__c);
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
streamsize
basic_streambuf<_CharT, _Traits>::sputn(const char_type* __s, streamsize __n)
{
    return xsputn(__s, __n);
}

template <class _CharT, class _Traits>
basic_streambuf<_CharT, _Traits>::basic_streambuf()
    : __binp_(0),
      __ninp_(0),
      __einp_(0),
      __bout_(0),
      __nout_(0),
      __eout_(0)
{
}

template <class _CharT, class _Traits>
basic_streambuf<_CharT, _Traits>::basic_streambuf(const basic_streambuf& __sb)
    : __loc_(__sb.__loc_),
      __binp_(__sb.__binp_),
      __ninp_(__sb.__ninp_),
      __einp_(__sb.__einp_),
      __bout_(__sb.__bout_),
      __nout_(__sb.__nout_),
      __eout_(__sb.__eout_)
{
}

template <class _CharT, class _Traits>
basic_streambuf<_CharT, _Traits>&
basic_streambuf<_CharT, _Traits>::operator=(const basic_streambuf& __sb)
{
    __loc_ = __sb.__loc_;
    __binp_ = __sb.__binp_;
    __ninp_ = __sb.__ninp_;
    __einp_ = __sb.__einp_;
    __bout_ = __sb.__bout_;
    __nout_ = __sb.__nout_;
    __eout_ = __sb.__eout_;
    return *this;
}

template <class _CharT, class _Traits>
void
basic_streambuf<_CharT, _Traits>::swap(basic_streambuf& __sb)
{
    _VSTD::swap(__loc_, __sb.__loc_);
    _VSTD::swap(__binp_, __sb.__binp_);
    _VSTD::swap(__ninp_, __sb.__ninp_);
    _VSTD::swap(__einp_, __sb.__einp_);
    _VSTD::swap(__bout_, __sb.__bout_);
    _VSTD::swap(__nout_, __sb.__nout_);
    _VSTD::swap(__eout_, __sb.__eout_);
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
void
basic_streambuf<_CharT, _Traits>::gbump(int __n)
{
    __ninp_ += __n;
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
void
basic_streambuf<_CharT, _Traits>::setg(char_type* __gbeg, char_type* __gnext,
                                                          char_type* __gend)
{
    __binp_ = __gbeg;
    __ninp_ = __gnext;
    __einp_ = __gend;
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
void
basic_streambuf<_CharT, _Traits>::pbump(int __n)
{
    __nout_ += __n;
}

template <class _CharT, class _Traits>
inline _LIBCPP_INLINE_VISIBILITY
void
basic_streambuf<_CharT, _Traits>::setp(char_type* __pbeg, char_type* __pend)
{
    __bout_ = __nout_ = __pbeg;
    __eout_ = __pend;
}

template <class _CharT, class _Traits>
void
basic_streambuf<_CharT, _Traits>::imbue(const locale&)
{
}

template <class _CharT, class _Traits>
basic_streambuf<_CharT, _Traits>*
basic_streambuf<_CharT, _Traits>::setbuf(char_type*, streamsize)
{
    return this;
}

template <class _CharT, class _Traits>
typename basic_streambuf<_CharT, _Traits>::pos_type
basic_streambuf<_CharT, _Traits>::seekoff(off_type, ios_base::seekdir,
                                          ios_base::openmode)
{
    return pos_type(off_type(-1));
}

template <class _CharT, class _Traits>
typename basic_streambuf<_CharT, _Traits>::pos_type
basic_streambuf<_CharT, _Traits>::seekpos(pos_type, ios_base::openmode)
{
    return pos_type(off_type(-1));
}

template <class _CharT, class _Traits>
int
basic_streambuf<_CharT, _Traits>::sync()
{
    return 0;
}

template <class _CharT, class _Traits>
streamsize
basic_streambuf<_CharT, _Traits>::showmanyc()
{
    return 0;
}

template <class _CharT, class _Traits>
streamsize
basic_streambuf<_CharT, _Traits>::xsgetn(char_type* __s, streamsize __n)
{
    const int_type __eof = traits_type::eof();
    int_type __c;
    streamsize __i = 0;
    for (;__i < __n; ++__i, ++__s)
    {
        if (__ninp_ < __einp_)
            *__s = *__ninp_++;
        else if ((__c = uflow()) != __eof)
            *__s = traits_type::to_char_type(__c);
        else
            break;
    }
    return __i;
}

template <class _CharT, class _Traits>
typename basic_streambuf<_CharT, _Traits>::int_type
basic_streambuf<_CharT, _Traits>::underflow()
{
    return traits_type::eof();
}

template <class _CharT, class _Traits>
typename basic_streambuf<_CharT, _Traits>::int_type
basic_streambuf<_CharT, _Traits>::uflow()
{
    if (underflow() == traits_type::eof())
        return traits_type::eof();
    return traits_type::to_int_type(*__ninp_++);
}

template <class _CharT, class _Traits>
typename basic_streambuf<_CharT, _Traits>::int_type
basic_streambuf<_CharT, _Traits>::pbackfail(int_type)
{
    return traits_type::eof();
}

template <class _CharT, class _Traits>
streamsize
basic_streambuf<_CharT, _Traits>::xsputn(const char_type* __s, streamsize __n)
{
    streamsize __i = 0;
    int_type __eof = traits_type::eof();
    for (; __i < __n; ++__s, ++__i)
    {
        if (__nout_ < __eout_)
            *__nout_++ = *__s;
        else if (overflow(traits_type::to_int_type(*__s)) == __eof)
            break;
    }
    return __i;
}

template <class _CharT, class _Traits>
typename basic_streambuf<_CharT, _Traits>::int_type
basic_streambuf<_CharT, _Traits>::overflow(int_type)
{
    return traits_type::eof();
}

_LIBCPP_EXTERN_TEMPLATE(class _LIBCPP_TYPE_VIS basic_streambuf<char>)
_LIBCPP_EXTERN_TEMPLATE(class _LIBCPP_TYPE_VIS basic_streambuf<wchar_t>)

_LIBCPP_EXTERN_TEMPLATE(class _LIBCPP_TYPE_VIS basic_ios<char>)
_LIBCPP_EXTERN_TEMPLATE(class _LIBCPP_TYPE_VIS basic_ios<wchar_t>)

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_STEAMBUF
# 565 "/usr/include/c++/v1/streambuf" 3
# 187 "/usr/include/c++/v1/locale" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <iterator>
#endif /* expanded by -frewrite-includes */
# 188 "/usr/include/c++/v1/locale" 3
#if 0 /* expanded by -frewrite-includes */
#include <limits>
#endif /* expanded by -frewrite-includes */
# 189 "/usr/include/c++/v1/locale" 3
#ifndef __APPLE__
#if 0 /* expanded by -frewrite-includes */
#include <cstdarg>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/cstdarg" 1 3
// -*- C++ -*-
//===--------------------------- cstdarg ----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CSTDARG
#define _LIBCPP_CSTDARG

/*
    cstdarg synopsis

Macros:

    type va_arg(va_list ap, type);
    void va_copy(va_list dest, va_list src);  // C99
    void va_end(va_list ap);
    void va_start(va_list ap, parmN);

namespace std
{

Types:

    va_list

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 36 "/usr/include/c++/v1/cstdarg" 3
#if 0 /* expanded by -frewrite-includes */
#include <stdarg.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/stdarg.h" 1 3 4
/*-
 * This file is in the public domain.
 */
/* $FreeBSD: head/sys/amd64/include/stdarg.h 232276 2012-02-28 22:30:58Z tijl $ */

#if 0 /* expanded by -frewrite-includes */
#include <x86/stdarg.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/x86/stdarg.h" 1 3 4
/*-
 * Copyright (c) 2002 David E. O'Brien.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/sys/x86/include/stdarg.h 256105 2013-10-07 10:01:23Z phk $
 */

#ifndef _MACHINE_STDARG_H_
#define	_MACHINE_STDARG_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 35 "/usr/include/x86/stdarg.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 36 "/usr/include/x86/stdarg.h" 3 4

#ifndef _VA_LIST_DECLARED
#define	_VA_LIST_DECLARED
typedef	__va_list	va_list;
#endif
# 41 "/usr/include/x86/stdarg.h" 3 4

#ifdef __GNUCLIKE_BUILTIN_STDARG

#define	va_start(ap, last) \
	__builtin_va_start((ap), (last))

#define	va_arg(ap, type) \
	__builtin_va_arg((ap), type)

#define	__va_copy(dest, src) \
	__builtin_va_copy((dest), (src))

#if __ISO_C_VISIBLE >= 1999
#define	va_copy(dest, src) \
	__va_copy(dest, src)
#endif
# 57 "/usr/include/x86/stdarg.h" 3 4

#define	va_end(ap) \
	__builtin_va_end(ap)

#elif defined(lint)
# 62 "/usr/include/x86/stdarg.h" 3 4
/* Provide a fake implementation for lint's benefit */
#define	__va_size(type) \
	(((sizeof(type) + sizeof(long) - 1) / sizeof(long)) * sizeof(long))
#define	va_start(ap, last) \
	((ap) = (va_list)&(last) + __va_size(last))
#define va_copy(dst, src) \
	((dst) = (src))
#define	va_arg(ap, type) \
	(*(type *)((ap) += __va_size(type), (ap) - __va_size(type)))
#define	va_end(ap)

#else
# 74 "/usr/include/x86/stdarg.h" 3 4
#error this file needs to be ported to your compiler
#endif
# 76 "/usr/include/x86/stdarg.h" 3 4

#endif /* !_MACHINE_STDARG_H_ */
# 78 "/usr/include/x86/stdarg.h" 3 4
# 7 "/usr/include/stdarg.h" 2 3 4
# 37 "/usr/include/c++/v1/cstdarg" 2 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 40 "/usr/include/c++/v1/cstdarg" 3
#endif
# 41 "/usr/include/c++/v1/cstdarg" 3

_LIBCPP_BEGIN_NAMESPACE_STD

using ::va_list;

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_CSTDARG
# 49 "/usr/include/c++/v1/cstdarg" 3
# 191 "/usr/include/c++/v1/locale" 2 3
#endif
# 192 "/usr/include/c++/v1/locale" 3
#if 0 /* expanded by -frewrite-includes */
#include <cstdlib>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/cstdlib" 1 3
// -*- C++ -*-
//===--------------------------- cstdlib ----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CSTDLIB
#define _LIBCPP_CSTDLIB

/*
    cstdlib synopsis

Macros:

    EXIT_FAILURE
    EXIT_SUCCESS
    MB_CUR_MAX
    NULL
    RAND_MAX

namespace std
{

Types:

    size_t
    div_t
    ldiv_t
    lldiv_t                                                               // C99

double    atof (const char* nptr);
int       atoi (const char* nptr);
long      atol (const char* nptr);
long long atoll(const char* nptr);                                        // C99
double             strtod  (const char* restrict nptr, char** restrict endptr);
float              strtof  (const char* restrict nptr, char** restrict endptr); // C99
long double        strtold (const char* restrict nptr, char** restrict endptr); // C99
long               strtol  (const char* restrict nptr, char** restrict endptr, int base);
long long          strtoll (const char* restrict nptr, char** restrict endptr, int base); // C99
unsigned long      strtoul (const char* restrict nptr, char** restrict endptr, int base);
unsigned long long strtoull(const char* restrict nptr, char** restrict endptr, int base); // C99
int rand(void);
void srand(unsigned int seed);
void* calloc(size_t nmemb, size_t size);
void free(void* ptr);
void* malloc(size_t size);
void* realloc(void* ptr, size_t size);
void abort(void);
int atexit(void (*func)(void));
void exit(int status);
void _Exit(int status);
char* getenv(const char* name);
int system(const char* string);
void* bsearch(const void* key, const void* base, size_t nmemb, size_t size,
              int (*compar)(const void *, const void *));
void qsort(void* base, size_t nmemb, size_t size,
           int (*compar)(const void *, const void *));
int         abs(      int j);
long        abs(     long j);
long long   abs(long long j);                                             // C++0X
long       labs(     long j);
long long llabs(long long j);                                             // C99
div_t     div(      int numer,       int denom);
ldiv_t    div(     long numer,      long denom);
lldiv_t   div(long long numer, long long denom);                          // C++0X
ldiv_t   ldiv(     long numer,      long denom);
lldiv_t lldiv(long long numer, long long denom);                          // C99
int mblen(const char* s, size_t n);
int mbtowc(wchar_t* restrict pwc, const char* restrict s, size_t n);
int wctomb(char* s, wchar_t wchar);
size_t mbstowcs(wchar_t* restrict pwcs, const char* restrict s, size_t n);
size_t wcstombs(char* restrict s, const wchar_t* restrict pwcs, size_t n);
int at_quick_exit(void (*func)(void))                                     // C++11
void quick_exit(int status);                                              // C++11
void *aligned_alloc(size_t alignment, size_t size);                       // C11

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 86 "/usr/include/c++/v1/cstdlib" 3
#if 0 /* expanded by -frewrite-includes */
#include <stdlib.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/stdlib.h" 1 3 4
/*-
 * Copyright (c) 1990, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)stdlib.h	8.5 (Berkeley) 5/19/95
 * $FreeBSD: head/include/stdlib.h 270952 2014-09-01 22:25:42Z pfg $
 */

#ifndef _STDLIB_H_
#define	_STDLIB_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 37 "/usr/include/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_null.h>
#endif /* expanded by -frewrite-includes */
# 38 "/usr/include/stdlib.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 39 "/usr/include/stdlib.h" 3 4

#if __BSD_VISIBLE
#ifndef _RUNE_T_DECLARED
typedef	__rune_t	rune_t;
#define	_RUNE_T_DECLARED
#endif
# 45 "/usr/include/stdlib.h" 3 4
#endif
# 46 "/usr/include/stdlib.h" 3 4

#ifndef _SIZE_T_DECLARED
typedef	__size_t	size_t;
#define	_SIZE_T_DECLARED
#endif
# 51 "/usr/include/stdlib.h" 3 4

#ifndef	__cplusplus
#ifndef _WCHAR_T_DECLARED
typedef	___wchar_t	wchar_t;
#define	_WCHAR_T_DECLARED
#endif
# 57 "/usr/include/stdlib.h" 3 4
#endif
# 58 "/usr/include/stdlib.h" 3 4

typedef struct {
	int	quot;		/* quotient */
	int	rem;		/* remainder */
} div_t;

typedef struct {
	long	quot;
	long	rem;
} ldiv_t;

#define	EXIT_FAILURE	1
#define	EXIT_SUCCESS	0

#define	RAND_MAX	0x7ffffffd

__BEGIN_DECLS
#ifdef _XLOCALE_H_
#if 0 /* expanded by -frewrite-includes */
#include <xlocale/_stdlib.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/xlocale/_stdlib.h" 1 3 4
/*-
 * Copyright (c) 2011, 2012 The FreeBSD Foundation
 * All rights reserved.
 *
 * This software was developed by David Chisnall under sponsorship from
 * the FreeBSD Foundation.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/include/xlocale/_stdlib.h 231673 2012-02-14 12:03:23Z theraven $
 */

/*
 * Extended locale versions of the locale-aware functions from stdlib.h.
 *
 * Include <stdlib.h> before <xlocale.h> to expose these.
 */
double			 atof_l(const char *, locale_t);
int			 atoi_l(const char *, locale_t);
long			 atol_l(const char *, locale_t);
long long		 atoll_l(const char *, locale_t);
int			 mblen_l(const char *, size_t, locale_t);
size_t			 mbstowcs_l(wchar_t * __restrict,
			    const char * __restrict, size_t, locale_t);
int			 mbtowc_l(wchar_t * __restrict,
			    const char * __restrict, size_t, locale_t);
double			 strtod_l(const char *, char **, locale_t);
float			 strtof_l(const char *, char **, locale_t);
long			 strtol_l(const char *, char **, int, locale_t);
long double		 strtold_l(const char *, char **, locale_t);
long long		 strtoll_l(const char *, char **, int, locale_t);
unsigned long		 strtoul_l(const char *, char **, int, locale_t);
unsigned long long	 strtoull_l(const char *, char **, int, locale_t);
size_t			 wcstombs_l(char * __restrict,
			    const wchar_t * __restrict, size_t, locale_t);
int			 wctomb_l(char *, wchar_t, locale_t);

int			 ___mb_cur_max_l(locale_t);
#define MB_CUR_MAX_L(x) (___mb_cur_max_l(x))

# 77 "/usr/include/stdlib.h" 2 3 4
#endif
# 78 "/usr/include/stdlib.h" 3 4
extern int __mb_cur_max;
extern int ___mb_cur_max(void);
#define	MB_CUR_MAX	(___mb_cur_max())

_Noreturn void	 abort(void);
int	 abs(int) __pure2;
int	 atexit(void (*)(void));
double	 atof(const char *);
int	 atoi(const char *);
long	 atol(const char *);
void	*bsearch(const void *, const void *, size_t,
	    size_t, int (*)(const void *, const void *));
void	*calloc(size_t, size_t) __malloc_like;
div_t	 div(int, int) __pure2;
_Noreturn void	 exit(int);
void	 free(void *);
char	*getenv(const char *);
long	 labs(long) __pure2;
ldiv_t	 ldiv(long, long) __pure2;
void	*malloc(size_t) __malloc_like;
int	 mblen(const char *, size_t);
size_t	 mbstowcs(wchar_t * __restrict , const char * __restrict, size_t);
int	 mbtowc(wchar_t * __restrict, const char * __restrict, size_t);
void	 qsort(void *, size_t, size_t,
	    int (*)(const void *, const void *));
int	 rand(void);
void	*realloc(void *, size_t);
void	 srand(unsigned);
double	 strtod(const char * __restrict, char ** __restrict);
float	 strtof(const char * __restrict, char ** __restrict);
long	 strtol(const char * __restrict, char ** __restrict, int);
long double
	 strtold(const char * __restrict, char ** __restrict);
unsigned long
	 strtoul(const char * __restrict, char ** __restrict, int);
int	 system(const char *);
int	 wctomb(char *, wchar_t);
size_t	 wcstombs(char * __restrict, const wchar_t * __restrict, size_t);

/*
 * Functions added in C99 which we make conditionally available in the
 * BSD^C89 namespace if the compiler supports `long long'.
 * The #if test is more complicated than it ought to be because
 * __BSD_VISIBLE implies __ISO_C_VISIBLE == 1999 *even if* `long long'
 * is not supported in the compilation environment (which therefore means
 * that it can't really be ISO C99).
 *
 * (The only other extension made by C99 in thie header is _Exit().)
 */
#if __ISO_C_VISIBLE >= 1999
#ifdef __LONG_LONG_SUPPORTED
/* LONGLONG */
typedef struct {
	long long quot;
	long long rem;
} lldiv_t;

/* LONGLONG */
long long
	 atoll(const char *);
/* LONGLONG */
long long
	 llabs(long long) __pure2;
/* LONGLONG */
lldiv_t	 lldiv(long long, long long) __pure2;
/* LONGLONG */
long long
	 strtoll(const char * __restrict, char ** __restrict, int);
/* LONGLONG */
unsigned long long
	 strtoull(const char * __restrict, char ** __restrict, int);
#endif /* __LONG_LONG_SUPPORTED */
# 150 "/usr/include/stdlib.h" 3 4

_Noreturn void	 _Exit(int);
#endif /* __ISO_C_VISIBLE >= 1999 */
# 153 "/usr/include/stdlib.h" 3 4

/*
 * If we're in a mode greater than C99, expose C11 functions.
 */
#if __ISO_C_VISIBLE >= 2011 || __cplusplus >= 201103L
void *	aligned_alloc(size_t, size_t) __malloc_like;
int	at_quick_exit(void (*)(void));
_Noreturn void
	quick_exit(int);
#endif /* __ISO_C_VISIBLE >= 2011 */
# 163 "/usr/include/stdlib.h" 3 4
/*
 * Extensions made by POSIX relative to C.
 */
#if __POSIX_VISIBLE >= 199506 || __XSI_VISIBLE
char	*realpath(const char * __restrict, char * __restrict);
#endif
# 169 "/usr/include/stdlib.h" 3 4
#if __POSIX_VISIBLE >= 199506
int	 rand_r(unsigned *);			/* (TSF) */
#endif
# 172 "/usr/include/stdlib.h" 3 4
#if __POSIX_VISIBLE >= 200112
int	 posix_memalign(void **, size_t, size_t); /* (ADV) */
int	 setenv(const char *, const char *, int);
int	 unsetenv(const char *);
#endif
# 177 "/usr/include/stdlib.h" 3 4

#if __POSIX_VISIBLE >= 200809 || __XSI_VISIBLE
int	 getsubopt(char **, char *const *, char **);
#ifndef _MKDTEMP_DECLARED
char	*mkdtemp(char *);
#define	_MKDTEMP_DECLARED
#endif
# 184 "/usr/include/stdlib.h" 3 4
#ifndef _MKSTEMP_DECLARED
int	 mkstemp(char *);
#define	_MKSTEMP_DECLARED
#endif
# 188 "/usr/include/stdlib.h" 3 4
#endif /* __POSIX_VISIBLE >= 200809 || __XSI_VISIBLE */
# 189 "/usr/include/stdlib.h" 3 4

/*
 * The only changes to the XSI namespace in revision 6 were the deletion
 * of the ttyslot() and valloc() functions, which FreeBSD never declared
 * in this header.  For revision 7, ecvt(), fcvt(), and gcvt(), which
 * FreeBSD also does not have, and mktemp(), are to be deleted.
 */
#if __XSI_VISIBLE
/* XXX XSI requires pollution from <sys/wait.h> here.  We'd rather not. */
long	 a64l(const char *);
double	 drand48(void);
/* char	*ecvt(double, int, int * __restrict, int * __restrict); */
double	 erand48(unsigned short[3]);
/* char	*fcvt(double, int, int * __restrict, int * __restrict); */
/* char	*gcvt(double, int, int * __restrict, int * __restrict); */
int	 grantpt(int);
char	*initstate(unsigned long /* XSI requires u_int */, char *, long);
long	 jrand48(unsigned short[3]);
char	*l64a(long);
void	 lcong48(unsigned short[7]);
long	 lrand48(void);
#if !defined(_MKTEMP_DECLARED) && (__BSD_VISIBLE || __XSI_VISIBLE <= 600)
char	*mktemp(char *);
#define	_MKTEMP_DECLARED
#endif
# 214 "/usr/include/stdlib.h" 3 4
long	 mrand48(void);
long	 nrand48(unsigned short[3]);
int	 posix_openpt(int);
char	*ptsname(int);
int	 putenv(char *);
long	 random(void);
unsigned short
	*seed48(unsigned short[3]);
#ifndef _SETKEY_DECLARED
int	 setkey(const char *);
#define	_SETKEY_DECLARED
#endif
# 226 "/usr/include/stdlib.h" 3 4
char	*setstate(/* const */ char *);
void	 srand48(long);
void	 srandom(unsigned long);
int	 unlockpt(int);
#endif /* __XSI_VISIBLE */
# 231 "/usr/include/stdlib.h" 3 4

#if __BSD_VISIBLE
extern const char *malloc_conf;
extern void (*malloc_message)(void *, const char *);

/*
 * The alloca() function can't be implemented in C, and on some
 * platforms it can't be implemented at all as a callable function.
 * The GNU C compiler provides a built-in alloca() which we can use;
 * in all other cases, provide a prototype, mainly to pacify various
 * incarnations of lint.  On platforms where alloca() is not in libc,
 * programs which use it will fail to link when compiled with non-GNU
 * compilers.
 */
#if __GNUC__ >= 2 || defined(__INTEL_COMPILER)
#undef  alloca	/* some GNU bits try to get cute and define this on their own */
#define alloca(sz) __builtin_alloca(sz)
#elif defined(lint)
# 249 "/usr/include/stdlib.h" 3 4
void	*alloca(size_t);
#endif
# 251 "/usr/include/stdlib.h" 3 4

void	 abort2(const char *, int, void **) __dead2;
__uint32_t
	 arc4random(void);
void	 arc4random_addrandom(unsigned char *, int);
void	 arc4random_buf(void *, size_t);
void	 arc4random_stir(void);
__uint32_t 
	 arc4random_uniform(__uint32_t);
#ifdef __BLOCKS__
int	 atexit_b(void (^)(void));
void	*bsearch_b(const void *, const void *, size_t,
	    size_t, int (^)(const void *, const void *));
#endif
# 265 "/usr/include/stdlib.h" 3 4
char	*getbsize(int *, long *);
					/* getcap(3) functions */
char	*cgetcap(char *, const char *, int);
int	 cgetclose(void);
int	 cgetent(char **, char **, const char *);
int	 cgetfirst(char **, char **);
int	 cgetmatch(const char *, const char *);
int	 cgetnext(char **, char **);
int	 cgetnum(char *, const char *, long *);
int	 cgetset(const char *);
int	 cgetstr(char *, const char *, char **);
int	 cgetustr(char *, const char *, char **);

int	 daemon(int, int);
char	*devname(__dev_t, __mode_t);
char 	*devname_r(__dev_t, __mode_t, char *, int);
char	*fdevname(int);
char 	*fdevname_r(int, char *, int);
int	 getloadavg(double [], int);
const char *
	 getprogname(void);

int	 heapsort(void *, size_t, size_t, int (*)(const void *, const void *));
#ifdef __BLOCKS__
int	 heapsort_b(void *, size_t, size_t, int (^)(const void *, const void *));
void	 qsort_b(void *, size_t, size_t,
	    int (^)(const void *, const void *));
#endif
# 293 "/usr/include/stdlib.h" 3 4
int	 l64a_r(long, char *, int);
int	 mergesort(void *, size_t, size_t, int (*)(const void *, const void *));
#ifdef __BLOCKS__
int	 mergesort_b(void *, size_t, size_t, int (^)(const void *, const void *));
#endif
# 298 "/usr/include/stdlib.h" 3 4
int	 mkostemp(char *, int);
int	 mkostemps(char *, int, int);
void	 qsort_r(void *, size_t, size_t, void *,
	    int (*)(void *, const void *, const void *));
int	 radixsort(const unsigned char **, int, const unsigned char *,
	    unsigned);
void    *reallocf(void *, size_t);
int	 rpmatch(const char *);
void	 setprogname(const char *);
int	 sradixsort(const unsigned char **, int, const unsigned char *,
	    unsigned);
void	 sranddev(void);
void	 srandomdev(void);
long long
	strtonum(const char *, long long, long long, const char **);

/* Deprecated interfaces, to be removed in FreeBSD 6.0. */
__int64_t
	 strtoq(const char *, char **, int);
__uint64_t
	 strtouq(const char *, char **, int);

extern char *suboptarg;			/* getsubopt(3) external variable */
#endif /* __BSD_VISIBLE */
# 322 "/usr/include/stdlib.h" 3 4
__END_DECLS

#endif /* !_STDLIB_H_ */
# 325 "/usr/include/stdlib.h" 3 4
# 87 "/usr/include/c++/v1/cstdlib" 2 3
#ifdef _LIBCPP_MSVCRT
#if 0 /* expanded by -frewrite-includes */
#include "support/win32/locale_win32.h"
#endif /* expanded by -frewrite-includes */
# 89 "/usr/include/c++/v1/cstdlib" 3
#endif // _LIBCPP_MSVCRT
# 90 "/usr/include/c++/v1/cstdlib" 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 93 "/usr/include/c++/v1/cstdlib" 3
#endif
# 94 "/usr/include/c++/v1/cstdlib" 3

_LIBCPP_BEGIN_NAMESPACE_STD

using ::size_t;
using ::div_t;
using ::ldiv_t;
#ifndef _LIBCPP_HAS_NO_LONG_LONG
using ::lldiv_t;
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 103 "/usr/include/c++/v1/cstdlib" 3
using ::atof;
using ::atoi;
using ::atol;
#ifndef _LIBCPP_HAS_NO_LONG_LONG
using ::atoll;
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 109 "/usr/include/c++/v1/cstdlib" 3
using ::strtod;
using ::strtof;
using ::strtold;
using ::strtol;
#ifndef _LIBCPP_HAS_NO_LONG_LONG
using ::strtoll;
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 116 "/usr/include/c++/v1/cstdlib" 3
using ::strtoul;
#ifndef _LIBCPP_HAS_NO_LONG_LONG
using ::strtoull;
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 120 "/usr/include/c++/v1/cstdlib" 3
using ::rand;
using ::srand;
using ::calloc;
using ::free;
using ::malloc;
using ::realloc;
using ::abort;
using ::atexit;
using ::exit;
using ::_Exit;
using ::getenv;
using ::system;
using ::bsearch;
using ::qsort;
using ::abs;
using ::labs;
#ifndef _LIBCPP_HAS_NO_LONG_LONG
using ::llabs;
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 139 "/usr/include/c++/v1/cstdlib" 3
using ::div;
using ::ldiv;
#ifndef _LIBCPP_HAS_NO_LONG_LONG
using ::lldiv;
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 144 "/usr/include/c++/v1/cstdlib" 3
using ::mblen;
using ::mbtowc;
using ::wctomb;
using ::mbstowcs;
using ::wcstombs;
#ifdef _LIBCPP_HAS_QUICK_EXIT
using ::at_quick_exit;
using ::quick_exit;
#endif
# 153 "/usr/include/c++/v1/cstdlib" 3
#ifdef _LIBCPP_HAS_C11_FEATURES
using ::aligned_alloc;
#endif
# 156 "/usr/include/c++/v1/cstdlib" 3

// MSVCRT already has the correct prototype in <stdlib.h> #ifdef __cplusplus
#if !defined(_LIBCPP_MSVCRT) && !defined(__sun__) && !defined(_AIX)
inline _LIBCPP_INLINE_VISIBILITY long      abs(     long __x) _NOEXCEPT {return  labs(__x);}
#ifndef _LIBCPP_HAS_NO_LONG_LONG
inline _LIBCPP_INLINE_VISIBILITY long long abs(long long __x) _NOEXCEPT {return llabs(__x);}
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 163 "/usr/include/c++/v1/cstdlib" 3

inline _LIBCPP_INLINE_VISIBILITY  ldiv_t div(     long __x,      long __y) _NOEXCEPT {return  ldiv(__x, __y);}
#ifndef _LIBCPP_HAS_NO_LONG_LONG
inline _LIBCPP_INLINE_VISIBILITY lldiv_t div(long long __x, long long __y) _NOEXCEPT {return lldiv(__x, __y);}
#endif // _LIBCPP_HAS_NO_LONG_LONG
# 168 "/usr/include/c++/v1/cstdlib" 3
#endif // _LIBCPP_MSVCRT
# 169 "/usr/include/c++/v1/cstdlib" 3

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_CSTDLIB
# 173 "/usr/include/c++/v1/cstdlib" 3
# 193 "/usr/include/c++/v1/locale" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <ctime>
#endif /* expanded by -frewrite-includes */
# 194 "/usr/include/c++/v1/locale" 3
#if defined(_LIBCPP_MSVCRT) || defined(__MINGW32__)
#if 0 /* expanded by -frewrite-includes */
#include <support/win32/locale_win32.h>
#endif /* expanded by -frewrite-includes */
# 196 "/usr/include/c++/v1/locale" 3
#else // _LIBCPP_MSVCRT
# 197 "/usr/include/c++/v1/locale" 3
#if 0 /* expanded by -frewrite-includes */
#include <nl_types.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/nl_types.h" 1 3 4
/*	$NetBSD: nl_types.h,v 1.9 2000/10/03 19:53:32 sommerfeld Exp $	*/

/*-
 * Copyright (c) 1996 The NetBSD Foundation, Inc.
 * All rights reserved.
 *
 * This code is derived from software contributed to The NetBSD Foundation
 * by J.T. Conklin.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * $FreeBSD: head/include/nl_types.h 203963 2010-02-16 19:28:10Z imp $
 */

#ifndef _NL_TYPES_H_
#define _NL_TYPES_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 38 "/usr/include/nl_types.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/types.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/sys/types.h" 1 3 4
/*-
 * Copyright (c) 1982, 1986, 1991, 1993, 1994
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)types.h	8.6 (Berkeley) 2/19/95
 * $FreeBSD: head/sys/sys/types.h 255219 2013-09-05 00:09:56Z pjd $
 */

#ifndef _SYS_TYPES_H_
#define	_SYS_TYPES_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 42 "/usr/include/sys/types.h" 3 4

/* Machine type dependent parameters. */
#if 0 /* expanded by -frewrite-includes */
#include <machine/endian.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/machine/endian.h" 1 3 4
/*-
 * This file is in the public domain.
 */
/* $FreeBSD: head/sys/amd64/include/endian.h 232266 2012-02-28 19:39:54Z tijl $ */

#if 0 /* expanded by -frewrite-includes */
#include <x86/endian.h>
#endif /* expanded by -frewrite-includes */
# 7 "/usr/include/machine/endian.h" 3 4
# 45 "/usr/include/sys/types.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 46 "/usr/include/sys/types.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/_pthreadtypes.h>
#endif /* expanded by -frewrite-includes */
# 48 "/usr/include/sys/types.h" 3 4

#if __BSD_VISIBLE
typedef	unsigned char	u_char;
typedef	unsigned short	u_short;
typedef	unsigned int	u_int;
typedef	unsigned long	u_long;
#ifndef _KERNEL
typedef	unsigned short	ushort;		/* Sys V compatibility */
typedef	unsigned int	uint;		/* Sys V compatibility */
#endif
# 58 "/usr/include/sys/types.h" 3 4
#endif
# 59 "/usr/include/sys/types.h" 3 4

/*
 * XXX POSIX sized integrals that should appear only in <sys/stdint.h>.
 */
#if 0 /* expanded by -frewrite-includes */
#include <sys/_stdint.h>
#endif /* expanded by -frewrite-includes */
# 64 "/usr/include/sys/types.h" 3 4

typedef __uint8_t	u_int8_t;	/* unsigned integrals (deprecated) */
typedef __uint16_t	u_int16_t;
typedef __uint32_t	u_int32_t;
typedef __uint64_t	u_int64_t;

typedef	__uint64_t	u_quad_t;	/* quads (deprecated) */
typedef	__int64_t	quad_t;
typedef	quad_t *	qaddr_t;

typedef	char *		caddr_t;	/* core address */
typedef	const char *	c_caddr_t;	/* core address, pointer to const */

#ifndef _BLKSIZE_T_DECLARED
typedef	__blksize_t	blksize_t;
#define	_BLKSIZE_T_DECLARED
#endif
# 81 "/usr/include/sys/types.h" 3 4

typedef	__cpuwhich_t	cpuwhich_t;
typedef	__cpulevel_t	cpulevel_t;
typedef	__cpusetid_t	cpusetid_t;

#ifndef _BLKCNT_T_DECLARED
typedef	__blkcnt_t	blkcnt_t;
#define	_BLKCNT_T_DECLARED
#endif
# 90 "/usr/include/sys/types.h" 3 4

#ifndef _CLOCK_T_DECLARED
typedef	__clock_t	clock_t;
#define	_CLOCK_T_DECLARED
#endif
# 95 "/usr/include/sys/types.h" 3 4

#ifndef _CLOCKID_T_DECLARED
typedef	__clockid_t	clockid_t;
#define	_CLOCKID_T_DECLARED
#endif
# 100 "/usr/include/sys/types.h" 3 4

typedef	__critical_t	critical_t;	/* Critical section value */
typedef	__int64_t	daddr_t;	/* disk address */

#ifndef _DEV_T_DECLARED
typedef	__dev_t		dev_t;		/* device number or struct cdev */
#define	_DEV_T_DECLARED
#endif
# 108 "/usr/include/sys/types.h" 3 4

#ifndef _FFLAGS_T_DECLARED
typedef	__fflags_t	fflags_t;	/* file flags */
#define	_FFLAGS_T_DECLARED
#endif
# 113 "/usr/include/sys/types.h" 3 4

typedef	__fixpt_t	fixpt_t;	/* fixed point number */

#ifndef _FSBLKCNT_T_DECLARED		/* for statvfs() */
typedef	__fsblkcnt_t	fsblkcnt_t;
typedef	__fsfilcnt_t	fsfilcnt_t;
#define	_FSBLKCNT_T_DECLARED
#endif
# 121 "/usr/include/sys/types.h" 3 4

#ifndef _GID_T_DECLARED
typedef	__gid_t		gid_t;		/* group id */
#define	_GID_T_DECLARED
#endif
# 126 "/usr/include/sys/types.h" 3 4

#ifndef _IN_ADDR_T_DECLARED
typedef	__uint32_t	in_addr_t;	/* base type for internet address */
#define	_IN_ADDR_T_DECLARED
#endif
# 131 "/usr/include/sys/types.h" 3 4

#ifndef _IN_PORT_T_DECLARED
typedef	__uint16_t	in_port_t;
#define	_IN_PORT_T_DECLARED
#endif
# 136 "/usr/include/sys/types.h" 3 4

#ifndef _ID_T_DECLARED
typedef	__id_t		id_t;		/* can hold a uid_t or pid_t */
#define	_ID_T_DECLARED
#endif
# 141 "/usr/include/sys/types.h" 3 4

#ifndef _INO_T_DECLARED
typedef	__ino_t		ino_t;		/* inode number */
#define	_INO_T_DECLARED
#endif
# 146 "/usr/include/sys/types.h" 3 4

#ifndef _KEY_T_DECLARED
typedef	__key_t		key_t;		/* IPC key (for Sys V IPC) */
#define	_KEY_T_DECLARED
#endif
# 151 "/usr/include/sys/types.h" 3 4

#ifndef _LWPID_T_DECLARED
typedef	__lwpid_t	lwpid_t;	/* Thread ID (a.k.a. LWP) */
#define	_LWPID_T_DECLARED
#endif
# 156 "/usr/include/sys/types.h" 3 4

#ifndef _MODE_T_DECLARED
typedef	__mode_t	mode_t;		/* permissions */
#define	_MODE_T_DECLARED
#endif
# 161 "/usr/include/sys/types.h" 3 4

#ifndef _ACCMODE_T_DECLARED
typedef	__accmode_t	accmode_t;	/* access permissions */
#define	_ACCMODE_T_DECLARED
#endif
# 166 "/usr/include/sys/types.h" 3 4

#ifndef _NLINK_T_DECLARED
typedef	__nlink_t	nlink_t;	/* link count */
#define	_NLINK_T_DECLARED
#endif
# 171 "/usr/include/sys/types.h" 3 4

#ifndef _OFF_T_DECLARED
typedef	__off_t		off_t;		/* file offset */
#define	_OFF_T_DECLARED
#endif
# 176 "/usr/include/sys/types.h" 3 4

#ifndef _PID_T_DECLARED
typedef	__pid_t		pid_t;		/* process id */
#define	_PID_T_DECLARED
#endif
# 181 "/usr/include/sys/types.h" 3 4

typedef	__register_t	register_t;

#ifndef _RLIM_T_DECLARED
typedef	__rlim_t	rlim_t;		/* resource limit */
#define	_RLIM_T_DECLARED
#endif
# 188 "/usr/include/sys/types.h" 3 4

typedef	__int64_t	sbintime_t;

typedef	__segsz_t	segsz_t;	/* segment size (in pages) */

#ifndef _SIZE_T_DECLARED
typedef	__size_t	size_t;
#define	_SIZE_T_DECLARED
#endif
# 197 "/usr/include/sys/types.h" 3 4

#ifndef _SSIZE_T_DECLARED
typedef	__ssize_t	ssize_t;
#define	_SSIZE_T_DECLARED
#endif
# 202 "/usr/include/sys/types.h" 3 4

#ifndef _SUSECONDS_T_DECLARED
typedef	__suseconds_t	suseconds_t;	/* microseconds (signed) */
#define	_SUSECONDS_T_DECLARED
#endif
# 207 "/usr/include/sys/types.h" 3 4

#ifndef _TIME_T_DECLARED
typedef	__time_t	time_t;
#define	_TIME_T_DECLARED
#endif
# 212 "/usr/include/sys/types.h" 3 4

#ifndef _TIMER_T_DECLARED
typedef	__timer_t	timer_t;
#define	_TIMER_T_DECLARED
#endif
# 217 "/usr/include/sys/types.h" 3 4

#ifndef _MQD_T_DECLARED
typedef	__mqd_t	mqd_t;
#define	_MQD_T_DECLARED
#endif
# 222 "/usr/include/sys/types.h" 3 4

typedef	__u_register_t	u_register_t;

#ifndef _UID_T_DECLARED
typedef	__uid_t		uid_t;		/* user id */
#define	_UID_T_DECLARED
#endif
# 229 "/usr/include/sys/types.h" 3 4

#ifndef _USECONDS_T_DECLARED
typedef	__useconds_t	useconds_t;	/* microseconds (unsigned) */
#define	_USECONDS_T_DECLARED
#endif
# 234 "/usr/include/sys/types.h" 3 4

#ifndef _CAP_RIGHTS_T_DECLARED
#define	_CAP_RIGHTS_T_DECLARED
struct cap_rights;

typedef	struct cap_rights	cap_rights_t;
#endif
# 241 "/usr/include/sys/types.h" 3 4

typedef	__vm_offset_t	vm_offset_t;
typedef	__vm_ooffset_t	vm_ooffset_t;
typedef	__vm_paddr_t	vm_paddr_t;
typedef	__vm_pindex_t	vm_pindex_t;
typedef	__vm_size_t	vm_size_t;

#ifdef _KERNEL
typedef	int		boolean_t;
typedef	struct device	*device_t;
typedef	__intfptr_t	intfptr_t;

/*
 * XXX this is fixed width for historical reasons.  It should have had type
 * __int_fast32_t.  Fixed-width types should not be used unless binary
 * compatibility is essential.  Least-width types should be used even less
 * since they provide smaller benefits.
 *
 * XXX should be MD.
 *
 * XXX this is bogus in -current, but still used for spl*().
 */
typedef	__uint32_t	intrmask_t;	/* Interrupt mask (spl, xxx_imask...) */

typedef	__uintfptr_t	uintfptr_t;
typedef	__uint64_t	uoff_t;
typedef	char		vm_memattr_t;	/* memory attribute codes */
typedef	struct vm_page	*vm_page_t;

#if !defined(__bool_true_false_are_defined) && !defined(__cplusplus)
#define	__bool_true_false_are_defined	1
#define	false	0
#define	true	1
#if __STDC_VERSION__ < 199901L && __GNUC__ < 3 && !defined(__INTEL_COMPILER)
typedef	int	_Bool;
#endif
# 277 "/usr/include/sys/types.h" 3 4
typedef	_Bool	bool;
#endif /* !__bool_true_false_are_defined && !__cplusplus */
# 279 "/usr/include/sys/types.h" 3 4

#define offsetof(type, field) __offsetof(type, field)

#endif /* !_KERNEL */
# 283 "/usr/include/sys/types.h" 3 4

/*
 * The following are all things that really shouldn't exist in this header,
 * since its purpose is to provide typedefs, not miscellaneous doodads.
 */
#if __BSD_VISIBLE

#if 0 /* expanded by -frewrite-includes */
#include <sys/select.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/sys/select.h" 1 3 4
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/sys/sys/select.h 265051 2014-04-28 13:42:41Z emaste $
 */

#ifndef _SYS_SELECT_H_
#define	_SYS_SELECT_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 36 "/usr/include/sys/select.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 37 "/usr/include/sys/select.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/_sigset.h>
#endif /* expanded by -frewrite-includes */
# 39 "/usr/include/sys/select.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_timeval.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/sys/_timeval.h" 1 3 4
/*-
 * Copyright (c) 2002 Mike Barcroft <mike@FreeBSD.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD: head/sys/sys/_timeval.h 158471 2006-05-12 05:04:46Z jhb $
 */

#ifndef _SYS__TIMEVAL_H_
#define _SYS__TIMEVAL_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 33 "/usr/include/sys/_timeval.h" 3 4

#ifndef _SUSECONDS_T_DECLARED
typedef	__suseconds_t	suseconds_t;
#define	_SUSECONDS_T_DECLARED
#endif
# 38 "/usr/include/sys/_timeval.h" 3 4

#ifndef _TIME_T_DECLARED
typedef	__time_t	time_t;
#define	_TIME_T_DECLARED
#endif
# 43 "/usr/include/sys/_timeval.h" 3 4

/*
 * Structure returned by gettimeofday(2) system call, and used in other calls.
 */
struct timeval {
	time_t		tv_sec;		/* seconds */
	suseconds_t	tv_usec;	/* and microseconds */
};

#endif /* !_SYS__TIMEVAL_H_ */
# 53 "/usr/include/sys/_timeval.h" 3 4
# 40 "/usr/include/sys/select.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/timespec.h>
#endif /* expanded by -frewrite-includes */
# 41 "/usr/include/sys/select.h" 3 4

typedef	unsigned long	__fd_mask;
#if __BSD_VISIBLE
typedef	__fd_mask	fd_mask;
#endif
# 46 "/usr/include/sys/select.h" 3 4

#ifndef _SIGSET_T_DECLARED
#define	_SIGSET_T_DECLARED
typedef	__sigset_t	sigset_t;
#endif
# 51 "/usr/include/sys/select.h" 3 4

/*
 * Select uses bit masks of file descriptors in longs.  These macros
 * manipulate such bit fields (the filesystem macros use chars).
 * FD_SETSIZE may be defined by the user, but the default here should
 * be enough for most uses.
 */
#ifndef	FD_SETSIZE
#define	FD_SETSIZE	1024
#endif
# 61 "/usr/include/sys/select.h" 3 4

#define	_NFDBITS	(sizeof(__fd_mask) * 8)	/* bits per mask */
#if __BSD_VISIBLE
#define	NFDBITS		_NFDBITS
#endif
# 66 "/usr/include/sys/select.h" 3 4

#ifndef _howmany
#define	_howmany(x, y)	(((x) + ((y) - 1)) / (y))
#endif
# 70 "/usr/include/sys/select.h" 3 4

typedef	struct fd_set {
	__fd_mask	__fds_bits[_howmany(FD_SETSIZE, _NFDBITS)];
} fd_set;
#if __BSD_VISIBLE
#define	fds_bits	__fds_bits
#endif
# 77 "/usr/include/sys/select.h" 3 4

#define	__fdset_mask(n)	((__fd_mask)1 << ((n) % _NFDBITS))
#define	FD_CLR(n, p)	((p)->__fds_bits[(n)/_NFDBITS] &= ~__fdset_mask(n))
#if __BSD_VISIBLE
#define	FD_COPY(f, t)	(void)(*(t) = *(f))
#endif
# 83 "/usr/include/sys/select.h" 3 4
#define	FD_ISSET(n, p)	(((p)->__fds_bits[(n)/_NFDBITS] & __fdset_mask(n)) != 0)
#define	FD_SET(n, p)	((p)->__fds_bits[(n)/_NFDBITS] |= __fdset_mask(n))
#define	FD_ZERO(p) do {					\
	fd_set *_p;					\
	__size_t _n;					\
							\
	_p = (p);					\
	_n = _howmany(FD_SETSIZE, _NFDBITS);		\
	while (_n > 0)					\
		_p->__fds_bits[--_n] = 0;		\
} while (0)

#ifndef _KERNEL

__BEGIN_DECLS
int pselect(int, fd_set *__restrict, fd_set *__restrict, fd_set *__restrict,
	const struct timespec *__restrict, const sigset_t *__restrict);
#ifndef _SELECT_DECLARED
#define	_SELECT_DECLARED
/* XXX missing restrict type-qualifier */
int	select(int, fd_set *, fd_set *, fd_set *, struct timeval *);
#endif
# 105 "/usr/include/sys/select.h" 3 4
__END_DECLS
#endif /* !_KERNEL */
# 107 "/usr/include/sys/select.h" 3 4

#endif /* _SYS_SELECT_H_ */
# 109 "/usr/include/sys/select.h" 3 4
# 291 "/usr/include/sys/types.h" 2 3 4

/*
 * minor() gives a cookie instead of an index since we don't want to
 * change the meanings of bits 0-15 or waste time and space shifting
 * bits 16-31 for devices that don't use them.
 */
#define	major(x)	((int)(((u_int)(x) >> 8)&0xff))	/* major number */
#define	minor(x)	((int)((x)&0xffff00ff))		/* minor number */
#define	makedev(x,y)	((dev_t)(((x) << 8) | (y)))	/* create dev_t */

/*
 * These declarations belong elsewhere, but are repeated here and in
 * <stdio.h> to give broken programs a better chance of working with
 * 64-bit off_t's.
 */
#ifndef _KERNEL
__BEGIN_DECLS
#ifndef _FTRUNCATE_DECLARED
#define	_FTRUNCATE_DECLARED
int	 ftruncate(int, off_t);
#endif
# 312 "/usr/include/sys/types.h" 3 4
#ifndef _LSEEK_DECLARED
#define	_LSEEK_DECLARED
off_t	 lseek(int, off_t, int);
#endif
# 316 "/usr/include/sys/types.h" 3 4
#ifndef _MMAP_DECLARED
#define	_MMAP_DECLARED
void *	 mmap(void *, size_t, int, int, int, off_t);
#endif
# 320 "/usr/include/sys/types.h" 3 4
#ifndef _TRUNCATE_DECLARED
#define	_TRUNCATE_DECLARED
int	 truncate(const char *, off_t);
#endif
# 324 "/usr/include/sys/types.h" 3 4
__END_DECLS
#endif /* !_KERNEL */
# 326 "/usr/include/sys/types.h" 3 4

#endif /* __BSD_VISIBLE */
# 328 "/usr/include/sys/types.h" 3 4

#endif /* !_SYS_TYPES_H_ */
# 330 "/usr/include/sys/types.h" 3 4
# 39 "/usr/include/nl_types.h" 2 3 4

#ifdef _NLS_PRIVATE
/*
 * MESSAGE CATALOG FILE FORMAT.
 *
 * The NetBSD/FreeBSD message catalog format is similar to the format used by
 * Svr4 systems.  The differences are:
 *   * fixed byte order (big endian)
 *   * fixed data field sizes
 *
 * A message catalog contains four data types: a catalog header, one
 * or more set headers, one or more message headers, and one or more
 * text strings.
 */

#define _NLS_MAGIC	0xff88ff89

struct _nls_cat_hdr {
	int32_t __magic;
	int32_t __nsets;
	int32_t __mem;
	int32_t __msg_hdr_offset;
	int32_t __msg_txt_offset;
} ;

struct _nls_set_hdr {
	int32_t __setno;	/* set number: 0 < x <= NL_SETMAX */
	int32_t __nmsgs;	/* number of messages in the set  */
	int32_t __index;	/* index of first msg_hdr in msg_hdr table */
} ;

struct _nls_msg_hdr {
	int32_t __msgno;	/* msg number: 0 < x <= NL_MSGMAX */
	int32_t __msglen;
	int32_t __offset;
} ;

#endif	/* _NLS_PRIVATE */
# 77 "/usr/include/nl_types.h" 3 4

#define	NL_SETD		0
#define	NL_CAT_LOCALE	1

typedef struct __nl_cat_d {
	void	*__data;
	int	__size;
} *nl_catd;

#ifndef _NL_ITEM_DECLARED
typedef	__nl_item	nl_item;
#define	_NL_ITEM_DECLARED
#endif
# 90 "/usr/include/nl_types.h" 3 4

__BEGIN_DECLS
nl_catd  catopen(const char *, int);
char    *catgets(nl_catd, int, int, const char *) __format_arg(4);
int	 catclose(nl_catd);
__END_DECLS

#endif	/* _NL_TYPES_H_ */
# 98 "/usr/include/nl_types.h" 3 4
# 198 "/usr/include/c++/v1/locale" 2 3
#endif  // !_LIBCPP_MSVCRT
# 199 "/usr/include/c++/v1/locale" 3

#ifdef __APPLE__
#if 0 /* expanded by -frewrite-includes */
#include <Availability.h>
#endif /* expanded by -frewrite-includes */
# 202 "/usr/include/c++/v1/locale" 3
#endif
# 203 "/usr/include/c++/v1/locale" 3

#if 0 /* expanded by -frewrite-includes */
#include <__undef_min_max>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/__undef_min_max" 1 3
// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifdef min
#if defined(_MSC_VER) && ! defined(__clang__)
_LIBCPP_WARNING("macro min is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing min")
#else
# 16 "/usr/include/c++/v1/__undef_min_max" 3
#warning: macro min is incompatible with C++.  #undefing min
#endif
# 18 "/usr/include/c++/v1/__undef_min_max" 3
#undef min
#endif
# 20 "/usr/include/c++/v1/__undef_min_max" 3

#ifdef max
#if defined(_MSC_VER) && ! defined(__clang__)
_LIBCPP_WARNING("macro max is incompatible with C++.  Try #define NOMINMAX "
                "before any Windows header. #undefing max")
#else
# 26 "/usr/include/c++/v1/__undef_min_max" 3
#warning: macro max is incompatible with C++.  #undefing max
#endif
# 28 "/usr/include/c++/v1/__undef_min_max" 3
#undef max
#endif
# 30 "/usr/include/c++/v1/__undef_min_max" 3
# 205 "/usr/include/c++/v1/locale" 2 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 208 "/usr/include/c++/v1/locale" 3
#endif
# 209 "/usr/include/c++/v1/locale" 3

_LIBCPP_BEGIN_NAMESPACE_STD

#if defined(__APPLE__) || defined(__FreeBSD__)
#  define _LIBCPP_GET_C_LOCALE 0
#elif defined(__NetBSD__)
# 215 "/usr/include/c++/v1/locale" 3
#  define _LIBCPP_GET_C_LOCALE LC_C_LOCALE
#else
# 217 "/usr/include/c++/v1/locale" 3
#  define _LIBCPP_GET_C_LOCALE __cloc()
   // Get the C locale object
   _LIBCPP_FUNC_VIS locale_t __cloc();
#define __cloc_defined
#endif
# 222 "/usr/include/c++/v1/locale" 3

typedef _VSTD::remove_pointer<locale_t>::type __locale_struct;
typedef _VSTD::unique_ptr<__locale_struct, decltype(&freelocale)> __locale_unique_ptr;
#ifndef _LIBCPP_LOCALE__L_EXTENSIONS
typedef _VSTD::unique_ptr<__locale_struct, decltype(&uselocale)> __locale_raii;
#endif
# 228 "/usr/include/c++/v1/locale" 3

// OSX has nice foo_l() functions that let you turn off use of the global
// locale.  Linux, not so much.  The following functions avoid the locale when
// that's possible and otherwise do the wrong thing.  FIXME.
#if defined(__linux__) || defined(__EMSCRIPTEN__) || defined(_AIX)

#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
decltype(MB_CUR_MAX_L(_VSTD::declval<locale_t>()))
inline _LIBCPP_INLINE_VISIBILITY
__mb_cur_max_l(locale_t __l)
{
  return MB_CUR_MAX_L(__l);
}
#else  // _LIBCPP_LOCALE__L_EXTENSIONS
# 242 "/usr/include/c++/v1/locale" 3
inline _LIBCPP_ALWAYS_INLINE
decltype(MB_CUR_MAX) __mb_cur_max_l(locale_t __l)
{
  __locale_raii __current(uselocale(__l), uselocale);
  return MB_CUR_MAX;
}
#endif // _LIBCPP_LOCALE__L_EXTENSIONS
# 249 "/usr/include/c++/v1/locale" 3

inline _LIBCPP_ALWAYS_INLINE
wint_t __btowc_l(int __c, locale_t __l)
{
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
  return btowc_l(__c, __l);
#else
# 256 "/usr/include/c++/v1/locale" 3
  __locale_raii __current(uselocale(__l), uselocale);
  return btowc(__c);
#endif
# 259 "/usr/include/c++/v1/locale" 3
}

inline _LIBCPP_ALWAYS_INLINE
int __wctob_l(wint_t __c, locale_t __l)
{
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
  return wctob_l(__c, __l);
#else
# 267 "/usr/include/c++/v1/locale" 3
  __locale_raii __current(uselocale(__l), uselocale);
  return wctob(__c);
#endif
# 270 "/usr/include/c++/v1/locale" 3
}

inline _LIBCPP_ALWAYS_INLINE
size_t __wcsnrtombs_l(char *__dest, const wchar_t **__src, size_t __nwc,
                      size_t __len, mbstate_t *__ps, locale_t __l)
{
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
  return wcsnrtombs_l(__dest, __src, __nwc, __len, __ps, __l);
#else
# 279 "/usr/include/c++/v1/locale" 3
  __locale_raii __current(uselocale(__l), uselocale);
  return wcsnrtombs(__dest, __src, __nwc, __len, __ps);
#endif
# 282 "/usr/include/c++/v1/locale" 3
}

inline _LIBCPP_ALWAYS_INLINE
size_t __wcrtomb_l(char *__s, wchar_t __wc, mbstate_t *__ps, locale_t __l)
{
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
  return wcrtomb_l(__s, __wc, __ps, __l);
#else
# 290 "/usr/include/c++/v1/locale" 3
  __locale_raii __current(uselocale(__l), uselocale);
  return wcrtomb(__s, __wc, __ps);
#endif
# 293 "/usr/include/c++/v1/locale" 3
}

inline _LIBCPP_ALWAYS_INLINE
size_t __mbsnrtowcs_l(wchar_t * __dest, const char **__src, size_t __nms,
                      size_t __len, mbstate_t *__ps, locale_t __l)
{
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
  return mbsnrtowcs_l(__dest, __src, __nms, __len, __ps, __l);
#else
# 302 "/usr/include/c++/v1/locale" 3
  __locale_raii __current(uselocale(__l), uselocale);
  return mbsnrtowcs(__dest, __src, __nms, __len, __ps);
#endif
# 305 "/usr/include/c++/v1/locale" 3
}

inline _LIBCPP_ALWAYS_INLINE
size_t __mbrtowc_l(wchar_t *__pwc, const char *__s, size_t __n,
                   mbstate_t *__ps, locale_t __l)
{
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
  return mbrtowc_l(__pwc, __s, __n, __ps, __l);
#else
# 314 "/usr/include/c++/v1/locale" 3
  __locale_raii __current(uselocale(__l), uselocale);
  return mbrtowc(__pwc, __s, __n, __ps);
#endif
# 317 "/usr/include/c++/v1/locale" 3
}

inline _LIBCPP_ALWAYS_INLINE
int __mbtowc_l(wchar_t *__pwc, const char *__pmb, size_t __max, locale_t __l)
{
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
  return mbtowc_l(__pwc, __pmb, __max, __l);
#else
# 325 "/usr/include/c++/v1/locale" 3
  __locale_raii __current(uselocale(__l), uselocale);
  return mbtowc(__pwc, __pmb, __max);
#endif
# 328 "/usr/include/c++/v1/locale" 3
}

inline _LIBCPP_ALWAYS_INLINE
size_t __mbrlen_l(const char *__s, size_t __n, mbstate_t *__ps, locale_t __l)
{
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
  return mbrlen_l(__s, __n, __ps, __l);
#else
# 336 "/usr/include/c++/v1/locale" 3
  __locale_raii __current(uselocale(__l), uselocale);
  return mbrlen(__s, __n, __ps);
#endif
# 339 "/usr/include/c++/v1/locale" 3
}

inline _LIBCPP_ALWAYS_INLINE
lconv *__localeconv_l(locale_t __l)
{
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
  return localeconv_l(__l);
#else
# 347 "/usr/include/c++/v1/locale" 3
  __locale_raii __current(uselocale(__l), uselocale);
  return localeconv();
#endif
# 350 "/usr/include/c++/v1/locale" 3
}

inline _LIBCPP_ALWAYS_INLINE
size_t __mbsrtowcs_l(wchar_t *__dest, const char **__src, size_t __len,
                     mbstate_t *__ps, locale_t __l)
{
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
  return mbsrtowcs_l(__dest, __src, __len, __ps, __l);
#else
# 359 "/usr/include/c++/v1/locale" 3
  __locale_raii __current(uselocale(__l), uselocale);
  return mbsrtowcs(__dest, __src, __len, __ps);
#endif
# 362 "/usr/include/c++/v1/locale" 3
}

inline
int __snprintf_l(char *__s, size_t __n, locale_t __l, const char *__format, ...) {
  va_list __va;
  va_start(__va, __format);
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
  int __res = vsnprintf_l(__s, __n, __l, __format, __va);
#else
# 371 "/usr/include/c++/v1/locale" 3
  __locale_raii __current(uselocale(__l), uselocale);
  int __res = vsnprintf(__s, __n, __format, __va);
#endif
# 374 "/usr/include/c++/v1/locale" 3
  va_end(__va);
  return __res;
}

inline
int __asprintf_l(char **__s, locale_t __l, const char *__format, ...) {
  va_list __va;
  va_start(__va, __format);
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
  int __res = vasprintf_l(__s, __l, __format, __va);
#else
# 385 "/usr/include/c++/v1/locale" 3
  __locale_raii __current(uselocale(__l), uselocale);
  int __res = vasprintf(__s, __format, __va);
#endif
# 388 "/usr/include/c++/v1/locale" 3
  va_end(__va);
  return __res;
}

inline
int __sscanf_l(const char *__s, locale_t __l, const char *__format, ...) {
  va_list __va;
  va_start(__va, __format);
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
  int __res = vsscanf_l(__s, __l, __format, __va);
#else
# 399 "/usr/include/c++/v1/locale" 3
  __locale_raii __current(uselocale(__l), uselocale);
  int __res = vsscanf(__s, __format, __va);
#endif
# 402 "/usr/include/c++/v1/locale" 3
  va_end(__va);
  return __res;
}

#endif  // __linux__
# 407 "/usr/include/c++/v1/locale" 3

// __scan_keyword
// Scans [__b, __e) until a match is found in the basic_strings range
//  [__kb, __ke) or until it can be shown that there is no match in [__kb, __ke).
//  __b will be incremented (visibly), consuming CharT until a match is found
//  or proved to not exist.  A keyword may be "", in which will match anything.
//  If one keyword is a prefix of another, and the next CharT in the input
//  might match another keyword, the algorithm will attempt to find the longest
//  matching keyword.  If the longer matching keyword ends up not matching, then
//  no keyword match is found.  If no keyword match is found, __ke is returned
//  and failbit is set in __err.
//  Else an iterator pointing to the matching keyword is found.  If more than
//  one keyword matches, an iterator to the first matching keyword is returned.
//  If on exit __b == __e, eofbit is set in __err.  If __case_senstive is false,
//  __ct is used to force to lower case before comparing characters.
//  Examples:
//  Keywords:  "a", "abb"
//  If the input is "a", the first keyword matches and eofbit is set.
//  If the input is "abc", no match is found and "ab" are consumed.
template <class _InputIterator, class _ForwardIterator, class _Ctype>
_LIBCPP_HIDDEN
_ForwardIterator
__scan_keyword(_InputIterator& __b, _InputIterator __e,
               _ForwardIterator __kb, _ForwardIterator __ke,
               const _Ctype& __ct, ios_base::iostate& __err,
               bool __case_sensitive = true)
{
    typedef typename iterator_traits<_InputIterator>::value_type _CharT;
    size_t __nkw = static_cast<size_t>(_VSTD::distance(__kb, __ke));
    const unsigned char __doesnt_match = '\0';
    const unsigned char __might_match = '\1';
    const unsigned char __does_match = '\2';
    unsigned char __statbuf[100];
    unsigned char* __status = __statbuf;
    unique_ptr<unsigned char, void(*)(void*)> __stat_hold(0, free);
    if (__nkw > sizeof(__statbuf))
    {
        __status = (unsigned char*)malloc(__nkw);
        if (__status == 0)
            __throw_bad_alloc();
        __stat_hold.reset(__status);
    }
    size_t __n_might_match = __nkw;  // At this point, any keyword might match
    size_t __n_does_match = 0;       // but none of them definitely do
    // Initialize all statuses to __might_match, except for "" keywords are __does_match
    unsigned char* __st = __status;
    for (_ForwardIterator __ky = __kb; __ky != __ke; ++__ky, ++__st)
    {
        if (!__ky->empty())
            *__st = __might_match;
        else
        {
            *__st = __does_match;
            --__n_might_match;
            ++__n_does_match;
        }
    }
    // While there might be a match, test keywords against the next CharT
    for (size_t __indx = 0; __b != __e && __n_might_match > 0; ++__indx)
    {
        // Peek at the next CharT but don't consume it
        _CharT __c = *__b;
        if (!__case_sensitive)
            __c = __ct.toupper(__c);
        bool __consume = false;
        // For each keyword which might match, see if the __indx character is __c
        // If a match if found, consume __c
        // If a match is found, and that is the last character in the keyword,
        //    then that keyword matches.
        // If the keyword doesn't match this character, then change the keyword
        //    to doesn't match
        __st = __status;
        for (_ForwardIterator __ky = __kb; __ky != __ke; ++__ky, ++__st)
        {
            if (*__st == __might_match)
            {
                _CharT __kc = (*__ky)[__indx];
                if (!__case_sensitive)
                    __kc = __ct.toupper(__kc);
                if (__c == __kc)
                {
                    __consume = true;
                    if (__ky->size() == __indx+1)
                    {
                        *__st = __does_match;
                        --__n_might_match;
                        ++__n_does_match;
                    }
                }
                else
                {
                    *__st = __doesnt_match;
                    --__n_might_match;
                }
            }
        }
        // consume if we matched a character
        if (__consume)
        {
            ++__b;
            // If we consumed a character and there might be a matched keyword that
            //   was marked matched on a previous iteration, then such keywords
            //   which are now marked as not matching.
            if (__n_might_match + __n_does_match > 1)
            {
                __st = __status;
                for (_ForwardIterator __ky = __kb; __ky != __ke; ++__ky, ++__st)
                {
                    if (*__st == __does_match && __ky->size() != __indx+1)
                    {
                        *__st = __doesnt_match;
                        --__n_does_match;
                    }
                }
            }
        }
    }
    // We've exited the loop because we hit eof and/or we have no more "might matches".
    if (__b == __e)
        __err |= ios_base::eofbit;
    // Return the first matching result
    for (__st = __status; __kb != __ke; ++__kb, ++__st)
        if (*__st == __does_match)
            break;
    if (__kb == __ke)
        __err |= ios_base::failbit;
    return __kb;
}

struct _LIBCPP_TYPE_VIS __num_get_base
{
    static const int __num_get_buf_sz = 40;

    static int __get_base(ios_base&);
    static const char __src[33];
};

_LIBCPP_FUNC_VIS
void __check_grouping(const string& __grouping, unsigned* __g, unsigned* __g_end,
                      ios_base::iostate& __err);

template <class _CharT>
struct __num_get
    : protected __num_get_base
{
    static string __stage2_int_prep(ios_base& __iob, _CharT* __atoms, _CharT& __thousands_sep);
    static string __stage2_float_prep(ios_base& __iob, _CharT* __atoms, _CharT& __decimal_point,
                                      _CharT& __thousands_sep);
    static int __stage2_int_loop(_CharT __ct, int __base, char* __a, char*& __a_end,
                  unsigned& __dc, _CharT __thousands_sep, const string& __grouping,
                  unsigned* __g, unsigned*& __g_end, _CharT* __atoms);
    static int __stage2_float_loop(_CharT __ct, bool& __in_units, char& __exp,
                                   char* __a, char*& __a_end,
                                   _CharT __decimal_point, _CharT __thousands_sep,
                                   const string& __grouping, unsigned* __g,
                                   unsigned*& __g_end, unsigned& __dc, _CharT* __atoms);
};

template <class _CharT>
string
__num_get<_CharT>::__stage2_int_prep(ios_base& __iob, _CharT* __atoms, _CharT& __thousands_sep)
{
    locale __loc = __iob.getloc();
    use_facet<ctype<_CharT> >(__loc).widen(__src, __src + 26, __atoms);
    const numpunct<_CharT>& __np = use_facet<numpunct<_CharT> >(__loc);
    __thousands_sep = __np.thousands_sep();
    return __np.grouping();
}

template <class _CharT>
string
__num_get<_CharT>::__stage2_float_prep(ios_base& __iob, _CharT* __atoms, _CharT& __decimal_point,
                    _CharT& __thousands_sep)
{
    locale __loc = __iob.getloc();
    use_facet<ctype<_CharT> >(__loc).widen(__src, __src + 32, __atoms);
    const numpunct<_CharT>& __np = use_facet<numpunct<_CharT> >(__loc);
    __decimal_point = __np.decimal_point();
    __thousands_sep = __np.thousands_sep();
    return __np.grouping();
}

template <class _CharT>
int
__num_get<_CharT>::__stage2_int_loop(_CharT __ct, int __base, char* __a, char*& __a_end,
                  unsigned& __dc, _CharT __thousands_sep, const string& __grouping,
                  unsigned* __g, unsigned*& __g_end, _CharT* __atoms)
{
    if (__a_end == __a && (__ct == __atoms[24] || __ct == __atoms[25]))
    {
        *__a_end++ = __ct == __atoms[24] ? '+' : '-';
        __dc = 0;
        return 0;
    }
    if (__grouping.size() != 0 && __ct == __thousands_sep)
    {
        if (__g_end-__g < __num_get_buf_sz)
        {
            *__g_end++ = __dc;
            __dc = 0;
        }
        return 0;
    }
    ptrdiff_t __f = find(__atoms, __atoms + 26, __ct) - __atoms;
    if (__f >= 24)
        return -1;
    switch (__base)
    {
    case 8:
    case 10:
        if (__f >= __base)
            return -1;
        break;
    case 16:
        if (__f < 22)
            break;
        if (__a_end != __a && __a_end - __a <= 2 && __a_end[-1] == '0')
        {
            __dc = 0;
            *__a_end++ = __src[__f];
            return 0;
        }
        return -1;
    }
    *__a_end++ = __src[__f];
    ++__dc;
    return 0;
}

template <class _CharT>
int
__num_get<_CharT>::__stage2_float_loop(_CharT __ct, bool& __in_units, char& __exp, char* __a, char*& __a_end,
                    _CharT __decimal_point, _CharT __thousands_sep, const string& __grouping,
                    unsigned* __g, unsigned*& __g_end, unsigned& __dc, _CharT* __atoms)
{
    if (__ct == __decimal_point)
    {
        if (!__in_units)
            return -1;
        __in_units = false;
        *__a_end++ = '.';
        if (__grouping.size() != 0 && __g_end-__g < __num_get_buf_sz)
            *__g_end++ = __dc;
        return 0;
    }
    if (__ct == __thousands_sep && __grouping.size() != 0)
    {
        if (!__in_units)
            return -1;
        if (__g_end-__g < __num_get_buf_sz)
        {
            *__g_end++ = __dc;
            __dc = 0;
        }
        return 0;
    }
    ptrdiff_t __f = find(__atoms, __atoms + 32, __ct) - __atoms;
    if (__f >= 32)
        return -1;
    char __x = __src[__f];
    if (__x == '-' || __x == '+')
    {
        if (__a_end == __a || (__a_end[-1] & 0x5F) == (__exp & 0x7F))
        {
            *__a_end++ = __x;
            return 0;
        }
        return -1;
    }
    if (__x == 'x' || __x == 'X')
        __exp = 'P';
    else if ((__x & 0x5F) == __exp)
    {
        __exp |= 0x80;
        if (__in_units)
        {
            __in_units = false;
            if (__grouping.size() != 0 && __g_end-__g < __num_get_buf_sz)
                *__g_end++ = __dc;
        }
    }
    *__a_end++ = __x;
    if (__f >= 22)
        return 0;
    ++__dc;
    return 0;
}

_LIBCPP_EXTERN_TEMPLATE2(struct _LIBCPP_TYPE_VIS __num_get<char>)
_LIBCPP_EXTERN_TEMPLATE2(struct _LIBCPP_TYPE_VIS __num_get<wchar_t>)

template <class _CharT, class _InputIterator = istreambuf_iterator<_CharT> >
class _LIBCPP_TYPE_VIS_ONLY num_get
    : public locale::facet,
      private __num_get<_CharT>
{
public:
    typedef _CharT char_type;
    typedef _InputIterator iter_type;

    _LIBCPP_ALWAYS_INLINE
    explicit num_get(size_t __refs = 0)
        : locale::facet(__refs) {}

    _LIBCPP_ALWAYS_INLINE
    iter_type get(iter_type __b, iter_type __e, ios_base& __iob,
                  ios_base::iostate& __err, bool& __v) const
    {
        return do_get(__b, __e, __iob, __err, __v);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type get(iter_type __b, iter_type __e, ios_base& __iob,
                  ios_base::iostate& __err, long& __v) const
    {
        return do_get(__b, __e, __iob, __err, __v);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type get(iter_type __b, iter_type __e, ios_base& __iob,
                  ios_base::iostate& __err, long long& __v) const
    {
        return do_get(__b, __e, __iob, __err, __v);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type get(iter_type __b, iter_type __e, ios_base& __iob,
                  ios_base::iostate& __err, unsigned short& __v) const
    {
        return do_get(__b, __e, __iob, __err, __v);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type get(iter_type __b, iter_type __e, ios_base& __iob,
                  ios_base::iostate& __err, unsigned int& __v) const
    {
        return do_get(__b, __e, __iob, __err, __v);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type get(iter_type __b, iter_type __e, ios_base& __iob,
                  ios_base::iostate& __err, unsigned long& __v) const
    {
        return do_get(__b, __e, __iob, __err, __v);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type get(iter_type __b, iter_type __e, ios_base& __iob,
                  ios_base::iostate& __err, unsigned long long& __v) const
    {
        return do_get(__b, __e, __iob, __err, __v);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type get(iter_type __b, iter_type __e, ios_base& __iob,
                  ios_base::iostate& __err, float& __v) const
    {
        return do_get(__b, __e, __iob, __err, __v);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type get(iter_type __b, iter_type __e, ios_base& __iob,
                  ios_base::iostate& __err, double& __v) const
    {
        return do_get(__b, __e, __iob, __err, __v);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type get(iter_type __b, iter_type __e, ios_base& __iob,
                  ios_base::iostate& __err, long double& __v) const
    {
        return do_get(__b, __e, __iob, __err, __v);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type get(iter_type __b, iter_type __e, ios_base& __iob,
                  ios_base::iostate& __err, void*& __v) const
    {
        return do_get(__b, __e, __iob, __err, __v);
    }

    static locale::id id;

protected:
    _LIBCPP_ALWAYS_INLINE
    ~num_get() {}

    template <class _Fp>
    iter_type __do_get_floating_point
                            (iter_type __b, iter_type __e, ios_base& __iob,
                             ios_base::iostate& __err, _Fp& __v) const;

    template <class _Signed>
    iter_type __do_get_signed
                            (iter_type __b, iter_type __e, ios_base& __iob,
                             ios_base::iostate& __err, _Signed& __v) const;

    template <class _Unsigned>
    iter_type __do_get_unsigned
                            (iter_type __b, iter_type __e, ios_base& __iob,
                             ios_base::iostate& __err, _Unsigned& __v) const;


    virtual iter_type do_get(iter_type __b, iter_type __e, ios_base& __iob,
                             ios_base::iostate& __err, bool& __v) const;

    virtual iter_type do_get(iter_type __b, iter_type __e, ios_base& __iob,
                             ios_base::iostate& __err, long& __v) const
    { return this->__do_get_signed ( __b, __e, __iob, __err, __v ); }

    virtual iter_type do_get(iter_type __b, iter_type __e, ios_base& __iob,
                             ios_base::iostate& __err, long long& __v) const
    { return this->__do_get_signed ( __b, __e, __iob, __err, __v ); }

    virtual iter_type do_get(iter_type __b, iter_type __e, ios_base& __iob,
                             ios_base::iostate& __err, unsigned short& __v) const
    { return this->__do_get_unsigned ( __b, __e, __iob, __err, __v ); }

    virtual iter_type do_get(iter_type __b, iter_type __e, ios_base& __iob,
                             ios_base::iostate& __err, unsigned int& __v) const
    { return this->__do_get_unsigned ( __b, __e, __iob, __err, __v ); }

    virtual iter_type do_get(iter_type __b, iter_type __e, ios_base& __iob,
                             ios_base::iostate& __err, unsigned long& __v) const
    { return this->__do_get_unsigned ( __b, __e, __iob, __err, __v ); }

    virtual iter_type do_get(iter_type __b, iter_type __e, ios_base& __iob,
                             ios_base::iostate& __err, unsigned long long& __v) const
    { return this->__do_get_unsigned ( __b, __e, __iob, __err, __v ); }

    virtual iter_type do_get(iter_type __b, iter_type __e, ios_base& __iob,
                             ios_base::iostate& __err, float& __v) const
    { return this->__do_get_floating_point ( __b, __e, __iob, __err, __v ); }

    virtual iter_type do_get(iter_type __b, iter_type __e, ios_base& __iob,
                             ios_base::iostate& __err, double& __v) const
    { return this->__do_get_floating_point ( __b, __e, __iob, __err, __v ); }

    virtual iter_type do_get(iter_type __b, iter_type __e, ios_base& __iob,
                             ios_base::iostate& __err, long double& __v) const
    { return this->__do_get_floating_point ( __b, __e, __iob, __err, __v ); }

    virtual iter_type do_get(iter_type __b, iter_type __e, ios_base& __iob,
                             ios_base::iostate& __err, void*& __v) const;
};

template <class _CharT, class _InputIterator>
locale::id
num_get<_CharT, _InputIterator>::id;

template <class _Tp>
_Tp
__num_get_signed_integral(const char* __a, const char* __a_end,
                          ios_base::iostate& __err, int __base)
{
    if (__a != __a_end)
    {
        typename remove_reference<decltype(errno)>::type __save_errno = errno;
        errno = 0;
        char *__p2;
        long long __ll = strtoll_l(__a, &__p2, __base, _LIBCPP_GET_C_LOCALE);
        typename remove_reference<decltype(errno)>::type __current_errno = errno;
        if (__current_errno == 0)
            errno = __save_errno;
        if (__p2 != __a_end)
        {
            __err = ios_base::failbit;
            return 0;
        }
        else if (__current_errno == ERANGE         ||
                 __ll < numeric_limits<_Tp>::min() ||
                 numeric_limits<_Tp>::max() < __ll)
        {
            __err = ios_base::failbit;
            if (__ll > 0)
                return numeric_limits<_Tp>::max();
            else
                return numeric_limits<_Tp>::min();
        }
        return static_cast<_Tp>(__ll);
    }
    __err = ios_base::failbit;
    return 0;
}

template <class _Tp>
_Tp
__num_get_unsigned_integral(const char* __a, const char* __a_end,
                            ios_base::iostate& __err, int __base)
{
    if (__a != __a_end)
    {
        if (*__a == '-')
        {
            __err = ios_base::failbit;
            return 0;
        }
        typename remove_reference<decltype(errno)>::type __save_errno = errno;
        errno = 0;
        char *__p2;
        unsigned long long __ll = strtoull_l(__a, &__p2, __base, _LIBCPP_GET_C_LOCALE);
        typename remove_reference<decltype(errno)>::type __current_errno = errno;
        if (__current_errno == 0)
            errno = __save_errno;
        if (__p2 != __a_end)
        {
            __err = ios_base::failbit;
            return 0;
        }
        else if (__current_errno == ERANGE ||
                 numeric_limits<_Tp>::max() < __ll)
        {
            __err = ios_base::failbit;
            return numeric_limits<_Tp>::max();
        }
        return static_cast<_Tp>(__ll);
    }
    __err = ios_base::failbit;
    return 0;
}

template <class _Tp>
_Tp
__num_get_float(const char* __a, const char* __a_end, ios_base::iostate& __err)
{
    if (__a != __a_end)
    {
        typename remove_reference<decltype(errno)>::type __save_errno = errno;
        errno = 0;
        char *__p2;
        long double __ld = strtold_l(__a, &__p2, _LIBCPP_GET_C_LOCALE);
        typename remove_reference<decltype(errno)>::type __current_errno = errno;
        if (__current_errno == 0)
            errno = __save_errno;
        if (__p2 != __a_end)
        {
            __err = ios_base::failbit;
            return 0;
        }
        else if (__current_errno == ERANGE)
            __err = ios_base::failbit;
        return static_cast<_Tp>(__ld);
    }
    __err = ios_base::failbit;
    return 0;
}

template <class _CharT, class _InputIterator>
_InputIterator
num_get<_CharT, _InputIterator>::do_get(iter_type __b, iter_type __e,
                                        ios_base& __iob,
                                        ios_base::iostate& __err,
                                        bool& __v) const
{
    if ((__iob.flags() & ios_base::boolalpha) == 0)
    {
        long __lv = -1;
        __b = do_get(__b, __e, __iob, __err, __lv);
        switch (__lv)
        {
        case 0:
            __v = false;
            break;
        case 1:
            __v = true;
            break;
        default:
            __v = true;
            __err = ios_base::failbit;
            break;
        }
        return __b;
    }
    const ctype<_CharT>& __ct = use_facet<ctype<_CharT> >(__iob.getloc());
    const numpunct<_CharT>& __np = use_facet<numpunct<_CharT> >(__iob.getloc());
    typedef typename numpunct<_CharT>::string_type string_type;
    const string_type __names[2] = {__np.truename(), __np.falsename()};
    const string_type* __i = __scan_keyword(__b, __e, __names, __names+2,
                                            __ct, __err);
    __v = __i == __names;
    return __b;
}

// signed

template <class _CharT, class _InputIterator>
template <class _Signed>
_InputIterator
num_get<_CharT, _InputIterator>::__do_get_signed(iter_type __b, iter_type __e,
                                        ios_base& __iob,
                                        ios_base::iostate& __err,
                                        _Signed& __v) const
{
    // Stage 1
    int __base = this->__get_base(__iob);
    // Stage 2
    char_type __atoms[26];
    char_type __thousands_sep;
    string __grouping = this->__stage2_int_prep(__iob, __atoms, __thousands_sep);
    string __buf;
    __buf.resize(__buf.capacity());
    char* __a = &__buf[0];
    char* __a_end = __a;
    unsigned __g[__num_get_base::__num_get_buf_sz];
    unsigned* __g_end = __g;
    unsigned __dc = 0;
    for (; __b != __e; ++__b)
    {
        if (__a_end == __a + __buf.size())
        {
            size_t __tmp = __buf.size();
            __buf.resize(2*__buf.size());
            __buf.resize(__buf.capacity());
            __a = &__buf[0];
            __a_end = __a + __tmp;
        }
        if (this->__stage2_int_loop(*__b, __base, __a, __a_end, __dc,
                                    __thousands_sep, __grouping, __g, __g_end,
                                    __atoms))
            break;
    }
    if (__grouping.size() != 0 && __g_end-__g < __num_get_base::__num_get_buf_sz)
        *__g_end++ = __dc;
    // Stage 3
    __v = __num_get_signed_integral<_Signed>(__a, __a_end, __err, __base);
    // Digit grouping checked
    __check_grouping(__grouping, __g, __g_end, __err);
    // EOF checked
    if (__b == __e)
        __err |= ios_base::eofbit;
    return __b;
}

// unsigned

template <class _CharT, class _InputIterator>
template <class _Unsigned>
_InputIterator
num_get<_CharT, _InputIterator>::__do_get_unsigned(iter_type __b, iter_type __e,
                                        ios_base& __iob,
                                        ios_base::iostate& __err,
                                        _Unsigned& __v) const
{
    // Stage 1
    int __base = this->__get_base(__iob);
    // Stage 2
    char_type __atoms[26];
    char_type __thousands_sep;
    string __grouping = this->__stage2_int_prep(__iob, __atoms, __thousands_sep);
    string __buf;
    __buf.resize(__buf.capacity());
    char* __a = &__buf[0];
    char* __a_end = __a;
    unsigned __g[__num_get_base::__num_get_buf_sz];
    unsigned* __g_end = __g;
    unsigned __dc = 0;
    for (; __b != __e; ++__b)
    {
        if (__a_end == __a + __buf.size())
        {
            size_t __tmp = __buf.size();
            __buf.resize(2*__buf.size());
            __buf.resize(__buf.capacity());
            __a = &__buf[0];
            __a_end = __a + __tmp;
        }
        if (this->__stage2_int_loop(*__b, __base, __a, __a_end, __dc,
                                    __thousands_sep, __grouping, __g, __g_end,
                                    __atoms))
            break;
    }
    if (__grouping.size() != 0 && __g_end-__g < __num_get_base::__num_get_buf_sz)
        *__g_end++ = __dc;
    // Stage 3
    __v = __num_get_unsigned_integral<_Unsigned>(__a, __a_end, __err, __base);
    // Digit grouping checked
    __check_grouping(__grouping, __g, __g_end, __err);
    // EOF checked
    if (__b == __e)
        __err |= ios_base::eofbit;
    return __b;
}

// floating point

template <class _CharT, class _InputIterator>
template <class _Fp>
_InputIterator
num_get<_CharT, _InputIterator>::__do_get_floating_point(iter_type __b, iter_type __e,
                                        ios_base& __iob,
                                        ios_base::iostate& __err,
                                        _Fp& __v) const
{
    // Stage 1, nothing to do
    // Stage 2
    char_type __atoms[32];
    char_type __decimal_point;
    char_type __thousands_sep;
    string __grouping = this->__stage2_float_prep(__iob, __atoms,
                                                  __decimal_point,
                                                  __thousands_sep);
    string __buf;
    __buf.resize(__buf.capacity());
    char* __a = &__buf[0];
    char* __a_end = __a;
    unsigned __g[__num_get_base::__num_get_buf_sz];
    unsigned* __g_end = __g;
    unsigned __dc = 0;
    bool __in_units = true;
    char __exp = 'E';
    for (; __b != __e; ++__b)
    {
        if (__a_end == __a + __buf.size())
        {
            size_t __tmp = __buf.size();
            __buf.resize(2*__buf.size());
            __buf.resize(__buf.capacity());
            __a = &__buf[0];
            __a_end = __a + __tmp;
        }
        if (this->__stage2_float_loop(*__b, __in_units, __exp, __a, __a_end,
                                      __decimal_point, __thousands_sep,
                                      __grouping, __g, __g_end,
                                      __dc, __atoms))
            break;
    }
    if (__grouping.size() != 0 && __in_units && __g_end-__g < __num_get_base::__num_get_buf_sz)
        *__g_end++ = __dc;
    // Stage 3
    __v = __num_get_float<_Fp>(__a, __a_end, __err);
    // Digit grouping checked
    __check_grouping(__grouping, __g, __g_end, __err);
    // EOF checked
    if (__b == __e)
        __err |= ios_base::eofbit;
    return __b;
}

template <class _CharT, class _InputIterator>
_InputIterator
num_get<_CharT, _InputIterator>::do_get(iter_type __b, iter_type __e,
                                        ios_base& __iob,
                                        ios_base::iostate& __err,
                                        void*& __v) const
{
    // Stage 1
    int __base = 16;
    // Stage 2
    char_type __atoms[26];
    char_type __thousands_sep = 0;
    string __grouping;
    use_facet<ctype<_CharT> >(__iob.getloc()).widen(__num_get_base::__src,
                                                    __num_get_base::__src + 26, __atoms);
    string __buf;
    __buf.resize(__buf.capacity());
    char* __a = &__buf[0];
    char* __a_end = __a;
    unsigned __g[__num_get_base::__num_get_buf_sz];
    unsigned* __g_end = __g;
    unsigned __dc = 0;
    for (; __b != __e; ++__b)
    {
        if (__a_end == __a + __buf.size())
        {
            size_t __tmp = __buf.size();
            __buf.resize(2*__buf.size());
            __buf.resize(__buf.capacity());
            __a = &__buf[0];
            __a_end = __a + __tmp;
        }
        if (this->__stage2_int_loop(*__b, __base, __a, __a_end, __dc,
                                    __thousands_sep, __grouping,
                                    __g, __g_end, __atoms))
            break;
    }
    // Stage 3
    __a[sizeof(__a)-1] = 0;
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
    if (sscanf_l(__a, _LIBCPP_GET_C_LOCALE, "%p", &__v) != 1)
#else
# 1187 "/usr/include/c++/v1/locale" 3
    if (__sscanf_l(__a, __cloc(), "%p", &__v) != 1)
#endif
# 1189 "/usr/include/c++/v1/locale" 3
        __err = ios_base::failbit;
    // EOF checked
    if (__b == __e)
        __err |= ios_base::eofbit;
    return __b;
}

_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS num_get<char>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS num_get<wchar_t>)

struct _LIBCPP_TYPE_VIS __num_put_base
{
protected:
    static void __format_int(char* __fmt, const char* __len, bool __signd,
                             ios_base::fmtflags __flags);
    static bool __format_float(char* __fmt, const char* __len,
                               ios_base::fmtflags __flags);
    static char* __identify_padding(char* __nb, char* __ne,
                                    const ios_base& __iob);
};

template <class _CharT>
struct __num_put
    : protected __num_put_base
{
    static void __widen_and_group_int(char* __nb, char* __np, char* __ne,
                                      _CharT* __ob, _CharT*& __op, _CharT*& __oe,
                                      const locale& __loc);
    static void __widen_and_group_float(char* __nb, char* __np, char* __ne,
                                        _CharT* __ob, _CharT*& __op, _CharT*& __oe,
                                        const locale& __loc);
};

template <class _CharT>
void
__num_put<_CharT>::__widen_and_group_int(char* __nb, char* __np, char* __ne,
                                         _CharT* __ob, _CharT*& __op, _CharT*& __oe,
                                         const locale& __loc)
{
    const ctype<_CharT>&    __ct = use_facet<ctype<_CharT> >   (__loc);
    const numpunct<_CharT>& __npt = use_facet<numpunct<_CharT> >(__loc);
    string __grouping = __npt.grouping();
    if (__grouping.empty())
    {
        __ct.widen(__nb, __ne, __ob);
        __oe = __ob + (__ne - __nb);
    }
    else
    {
        __oe = __ob;
        char* __nf = __nb;
        if (*__nf == '-' || *__nf == '+')
            *__oe++ = __ct.widen(*__nf++);
        if (__ne - __nf >= 2 && __nf[0] == '0' && (__nf[1] == 'x' ||
                                                   __nf[1] == 'X'))
        {
            *__oe++ = __ct.widen(*__nf++);
            *__oe++ = __ct.widen(*__nf++);
        }
        reverse(__nf, __ne);
        _CharT __thousands_sep = __npt.thousands_sep();
        unsigned __dc = 0;
        unsigned __dg = 0;
        for (char* __p = __nf; __p < __ne; ++__p)
        {
            if (static_cast<unsigned>(__grouping[__dg]) > 0 &&
                __dc == static_cast<unsigned>(__grouping[__dg]))
            {
                *__oe++ = __thousands_sep;
                __dc = 0;
                if (__dg < __grouping.size()-1)
                    ++__dg;
            }
            *__oe++ = __ct.widen(*__p);
            ++__dc;
        }
        reverse(__ob + (__nf - __nb), __oe);
    }
    if (__np == __ne)
        __op = __oe;
    else
        __op = __ob + (__np - __nb);
}

template <class _CharT>
void
__num_put<_CharT>::__widen_and_group_float(char* __nb, char* __np, char* __ne,
                                           _CharT* __ob, _CharT*& __op, _CharT*& __oe,
                                           const locale& __loc)
{
    const ctype<_CharT>&    __ct = use_facet<ctype<_CharT> >   (__loc);
    const numpunct<_CharT>& __npt = use_facet<numpunct<_CharT> >(__loc);
    string __grouping = __npt.grouping();
    __oe = __ob;
    char* __nf = __nb;
    if (*__nf == '-' || *__nf == '+')
        *__oe++ = __ct.widen(*__nf++);
    char* __ns;
    if (__ne - __nf >= 2 && __nf[0] == '0' && (__nf[1] == 'x' ||
                                               __nf[1] == 'X'))
    {
        *__oe++ = __ct.widen(*__nf++);
        *__oe++ = __ct.widen(*__nf++);
        for (__ns = __nf; __ns < __ne; ++__ns)
            if (!isxdigit_l(*__ns, _LIBCPP_GET_C_LOCALE))
                break;
    }
    else
    {
        for (__ns = __nf; __ns < __ne; ++__ns)
            if (!isdigit_l(*__ns, _LIBCPP_GET_C_LOCALE))
                break;
    }
    if (__grouping.empty())
    {
        __ct.widen(__nf, __ns, __oe);
        __oe += __ns - __nf;
    }
    else
    {
        reverse(__nf, __ns);
        _CharT __thousands_sep = __npt.thousands_sep();
        unsigned __dc = 0;
        unsigned __dg = 0;
        for (char* __p = __nf; __p < __ns; ++__p)
        {
            if (__grouping[__dg] > 0 && __dc == static_cast<unsigned>(__grouping[__dg]))
            {
                *__oe++ = __thousands_sep;
                __dc = 0;
                if (__dg < __grouping.size()-1)
                    ++__dg;
            }
            *__oe++ = __ct.widen(*__p);
            ++__dc;
        }
        reverse(__ob + (__nf - __nb), __oe);
    }
    for (__nf = __ns; __nf < __ne; ++__nf)
    {
        if (*__nf == '.')
        {
            *__oe++ = __npt.decimal_point();
            ++__nf;
            break;
        }
        else
            *__oe++ = __ct.widen(*__nf);
    }
    __ct.widen(__nf, __ne, __oe);
    __oe += __ne - __nf;
    if (__np == __ne)
        __op = __oe;
    else
        __op = __ob + (__np - __nb);
}

_LIBCPP_EXTERN_TEMPLATE2(struct _LIBCPP_TYPE_VIS __num_put<char>)
_LIBCPP_EXTERN_TEMPLATE2(struct _LIBCPP_TYPE_VIS __num_put<wchar_t>)

template <class _CharT, class _OutputIterator = ostreambuf_iterator<_CharT> >
class _LIBCPP_TYPE_VIS_ONLY num_put
    : public locale::facet,
      private __num_put<_CharT>
{
public:
    typedef _CharT char_type;
    typedef _OutputIterator iter_type;

    _LIBCPP_ALWAYS_INLINE
    explicit num_put(size_t __refs = 0)
        : locale::facet(__refs) {}

    _LIBCPP_ALWAYS_INLINE
    iter_type put(iter_type __s, ios_base& __iob, char_type __fl,
                  bool __v) const
    {
        return do_put(__s, __iob, __fl, __v);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type put(iter_type __s, ios_base& __iob, char_type __fl,
                  long __v) const
    {
        return do_put(__s, __iob, __fl, __v);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type put(iter_type __s, ios_base& __iob, char_type __fl,
                  long long __v) const
    {
        return do_put(__s, __iob, __fl, __v);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type put(iter_type __s, ios_base& __iob, char_type __fl,
                  unsigned long __v) const
    {
        return do_put(__s, __iob, __fl, __v);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type put(iter_type __s, ios_base& __iob, char_type __fl,
                  unsigned long long __v) const
    {
        return do_put(__s, __iob, __fl, __v);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type put(iter_type __s, ios_base& __iob, char_type __fl,
                  double __v) const
    {
        return do_put(__s, __iob, __fl, __v);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type put(iter_type __s, ios_base& __iob, char_type __fl,
                  long double __v) const
    {
        return do_put(__s, __iob, __fl, __v);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type put(iter_type __s, ios_base& __iob, char_type __fl,
                  const void* __v) const
    {
        return do_put(__s, __iob, __fl, __v);
    }

    static locale::id id;

protected:
    _LIBCPP_ALWAYS_INLINE
    ~num_put() {}

    virtual iter_type do_put(iter_type __s, ios_base& __iob, char_type __fl,
                             bool __v) const;
    virtual iter_type do_put(iter_type __s, ios_base& __iob, char_type __fl,
                             long __v) const;
    virtual iter_type do_put(iter_type __s, ios_base& __iob, char_type __fl,
                             long long __v) const;
    virtual iter_type do_put(iter_type __s, ios_base& __iob, char_type __fl,
                             unsigned long) const;
    virtual iter_type do_put(iter_type __s, ios_base& __iob, char_type __fl,
                             unsigned long long) const;
    virtual iter_type do_put(iter_type __s, ios_base& __iob, char_type __fl,
                             double __v) const;
    virtual iter_type do_put(iter_type __s, ios_base& __iob, char_type __fl,
                             long double __v) const;
    virtual iter_type do_put(iter_type __s, ios_base& __iob, char_type __fl,
                             const void* __v) const;
};

template <class _CharT, class _OutputIterator>
locale::id
num_put<_CharT, _OutputIterator>::id;

template <class _CharT, class _OutputIterator>
_LIBCPP_HIDDEN
_OutputIterator
__pad_and_output(_OutputIterator __s,
                 const _CharT* __ob, const _CharT* __op, const _CharT* __oe,
                 ios_base& __iob, _CharT __fl)
{
    streamsize __sz = __oe - __ob;
    streamsize __ns = __iob.width();
    if (__ns > __sz)
        __ns -= __sz;
    else
        __ns = 0;
    for (;__ob < __op; ++__ob, ++__s)
        *__s = *__ob;
    for (; __ns; --__ns, ++__s)
        *__s = __fl;
    for (; __ob < __oe; ++__ob, ++__s)
        *__s = *__ob;
    __iob.width(0);
    return __s;
}

#if !defined(__APPLE__) || \
    (defined(__MAC_OS_X_VERSION_MIN_REQUIRED) && __MAC_OS_X_VERSION_MIN_REQUIRED > __MAC_10_8) || \
    (defined(__IPHONE_OS_VERSION_MIN_REQUIRED) && __IPHONE_OS_VERSION_MIN_REQUIRED > __IPHONE_6_0)

template <class _CharT, class _Traits>
_LIBCPP_HIDDEN
ostreambuf_iterator<_CharT, _Traits>
__pad_and_output(ostreambuf_iterator<_CharT, _Traits> __s,
                 const _CharT* __ob, const _CharT* __op, const _CharT* __oe,
                 ios_base& __iob, _CharT __fl)
{
    if (__s.__sbuf_ == nullptr)
        return __s;
    streamsize __sz = __oe - __ob;
    streamsize __ns = __iob.width();
    if (__ns > __sz)
        __ns -= __sz;
    else
        __ns = 0;
    streamsize __np = __op - __ob;
    if (__np > 0)
    {
        if (__s.__sbuf_->sputn(__ob, __np) != __np)
        {
            __s.__sbuf_ = nullptr;
            return __s;
        }
    }
    if (__ns > 0)
    {
        basic_string<_CharT, _Traits> __sp(__ns, __fl);
        if (__s.__sbuf_->sputn(__sp.data(), __ns) != __ns)
        {
            __s.__sbuf_ = nullptr;
            return __s;
        }
    }
    __np = __oe - __op;
    if (__np > 0)
    {
        if (__s.__sbuf_->sputn(__op, __np) != __np)
        {
            __s.__sbuf_ = nullptr;
            return __s;
        }
    }
    __iob.width(0);
    return __s;
}

#endif
# 1520 "/usr/include/c++/v1/locale" 3

template <class _CharT, class _OutputIterator>
_OutputIterator
num_put<_CharT, _OutputIterator>::do_put(iter_type __s, ios_base& __iob,
                                         char_type __fl, bool __v) const
{
    if ((__iob.flags() & ios_base::boolalpha) == 0)
        return do_put(__s, __iob, __fl, (unsigned long)__v);
    const numpunct<char_type>& __np = use_facet<numpunct<char_type> >(__iob.getloc());
    typedef typename numpunct<char_type>::string_type string_type;
#if _LIBCPP_DEBUG_LEVEL >= 2
    string_type __tmp(__v ? __np.truename() : __np.falsename());
    string_type __nm = _VSTD::move(__tmp);
#else
# 1534 "/usr/include/c++/v1/locale" 3
    string_type __nm = __v ? __np.truename() : __np.falsename();
#endif
# 1536 "/usr/include/c++/v1/locale" 3
    for (typename string_type::iterator __i = __nm.begin(); __i != __nm.end(); ++__i, ++__s)
        *__s = *__i;
    return __s;
}

template <class _CharT, class _OutputIterator>
_OutputIterator
num_put<_CharT, _OutputIterator>::do_put(iter_type __s, ios_base& __iob,
                                         char_type __fl, long __v) const
{
    // Stage 1 - Get number in narrow char
    char __fmt[6] = {'%', 0};
    const char* __len = "l";
    this->__format_int(__fmt+1, __len, true, __iob.flags());
    const unsigned __nbuf = (numeric_limits<long>::digits / 3)
                          + ((numeric_limits<long>::digits % 3) != 0)
                          + 1;
    char __nar[__nbuf];
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
    int __nc = snprintf_l(__nar, sizeof(__nar), _LIBCPP_GET_C_LOCALE, __fmt, __v);
#else
# 1557 "/usr/include/c++/v1/locale" 3
    int __nc = __snprintf_l(__nar, sizeof(__nar), __cloc(), __fmt, __v);
#endif
# 1559 "/usr/include/c++/v1/locale" 3
    char* __ne = __nar + __nc;
    char* __np = this->__identify_padding(__nar, __ne, __iob);
    // Stage 2 - Widen __nar while adding thousands separators
    char_type __o[2*(__nbuf-1) - 1];
    char_type* __op;  // pad here
    char_type* __oe;  // end of output
    this->__widen_and_group_int(__nar, __np, __ne, __o, __op, __oe, __iob.getloc());
    // [__o, __oe) contains thousands_sep'd wide number
    // Stage 3 & 4
    return __pad_and_output(__s, __o, __op, __oe, __iob, __fl);
}

template <class _CharT, class _OutputIterator>
_OutputIterator
num_put<_CharT, _OutputIterator>::do_put(iter_type __s, ios_base& __iob,
                                         char_type __fl, long long __v) const
{
    // Stage 1 - Get number in narrow char
    char __fmt[8] = {'%', 0};
    const char* __len = "ll";
    this->__format_int(__fmt+1, __len, true, __iob.flags());
    const unsigned __nbuf = (numeric_limits<long long>::digits / 3)
                          + ((numeric_limits<long long>::digits % 3) != 0)
                          + 1;
    char __nar[__nbuf];
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
    int __nc = snprintf_l(__nar, sizeof(__nar), _LIBCPP_GET_C_LOCALE, __fmt, __v);
#else
# 1587 "/usr/include/c++/v1/locale" 3
    int __nc = __snprintf_l(__nar, sizeof(__nar), __cloc(), __fmt, __v);
#endif
# 1589 "/usr/include/c++/v1/locale" 3
    char* __ne = __nar + __nc;
    char* __np = this->__identify_padding(__nar, __ne, __iob);
    // Stage 2 - Widen __nar while adding thousands separators
    char_type __o[2*(__nbuf-1) - 1];
    char_type* __op;  // pad here
    char_type* __oe;  // end of output
    this->__widen_and_group_int(__nar, __np, __ne, __o, __op, __oe, __iob.getloc());
    // [__o, __oe) contains thousands_sep'd wide number
    // Stage 3 & 4
    return __pad_and_output(__s, __o, __op, __oe, __iob, __fl);
}

template <class _CharT, class _OutputIterator>
_OutputIterator
num_put<_CharT, _OutputIterator>::do_put(iter_type __s, ios_base& __iob,
                                         char_type __fl, unsigned long __v) const
{
    // Stage 1 - Get number in narrow char
    char __fmt[6] = {'%', 0};
    const char* __len = "l";
    this->__format_int(__fmt+1, __len, false, __iob.flags());
    const unsigned __nbuf = (numeric_limits<unsigned long>::digits / 3)
                          + ((numeric_limits<unsigned long>::digits % 3) != 0)
                          + 1;
    char __nar[__nbuf];
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
    int __nc = snprintf_l(__nar, sizeof(__nar), _LIBCPP_GET_C_LOCALE, __fmt, __v);
#else
# 1617 "/usr/include/c++/v1/locale" 3
    int __nc = __snprintf_l(__nar, sizeof(__nar), __cloc(), __fmt, __v);
#endif
# 1619 "/usr/include/c++/v1/locale" 3
    char* __ne = __nar + __nc;
    char* __np = this->__identify_padding(__nar, __ne, __iob);
    // Stage 2 - Widen __nar while adding thousands separators
    char_type __o[2*(__nbuf-1) - 1];
    char_type* __op;  // pad here
    char_type* __oe;  // end of output
    this->__widen_and_group_int(__nar, __np, __ne, __o, __op, __oe, __iob.getloc());
    // [__o, __oe) contains thousands_sep'd wide number
    // Stage 3 & 4
    return __pad_and_output(__s, __o, __op, __oe, __iob, __fl);
}

template <class _CharT, class _OutputIterator>
_OutputIterator
num_put<_CharT, _OutputIterator>::do_put(iter_type __s, ios_base& __iob,
                                         char_type __fl, unsigned long long __v) const
{
    // Stage 1 - Get number in narrow char
    char __fmt[8] = {'%', 0};
    const char* __len = "ll";
    this->__format_int(__fmt+1, __len, false, __iob.flags());
    const unsigned __nbuf = (numeric_limits<unsigned long long>::digits / 3)
                          + ((numeric_limits<unsigned long long>::digits % 3) != 0)
                          + 1;
    char __nar[__nbuf];
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
    int __nc = snprintf_l(__nar, sizeof(__nar), _LIBCPP_GET_C_LOCALE, __fmt, __v);
#else
# 1647 "/usr/include/c++/v1/locale" 3
    int __nc = __snprintf_l(__nar, sizeof(__nar), __cloc(), __fmt, __v);
#endif
# 1649 "/usr/include/c++/v1/locale" 3
    char* __ne = __nar + __nc;
    char* __np = this->__identify_padding(__nar, __ne, __iob);
    // Stage 2 - Widen __nar while adding thousands separators
    char_type __o[2*(__nbuf-1) - 1];
    char_type* __op;  // pad here
    char_type* __oe;  // end of output
    this->__widen_and_group_int(__nar, __np, __ne, __o, __op, __oe, __iob.getloc());
    // [__o, __oe) contains thousands_sep'd wide number
    // Stage 3 & 4
    return __pad_and_output(__s, __o, __op, __oe, __iob, __fl);
}

template <class _CharT, class _OutputIterator>
_OutputIterator
num_put<_CharT, _OutputIterator>::do_put(iter_type __s, ios_base& __iob,
                                         char_type __fl, double __v) const
{
    // Stage 1 - Get number in narrow char
    char __fmt[8] = {'%', 0};
    const char* __len = "";
    bool __specify_precision = this->__format_float(__fmt+1, __len, __iob.flags());
    const unsigned __nbuf = 30;
    char __nar[__nbuf];
    char* __nb = __nar;
    int __nc;
    if (__specify_precision)
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
        __nc = snprintf_l(__nb, __nbuf, _LIBCPP_GET_C_LOCALE, __fmt,
                                   (int)__iob.precision(), __v);
#else
# 1679 "/usr/include/c++/v1/locale" 3
        __nc = __snprintf_l(__nb, __nbuf, __cloc(), __fmt,
                            (int)__iob.precision(), __v);
#endif
# 1682 "/usr/include/c++/v1/locale" 3
    else
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
        __nc = snprintf_l(__nb, __nbuf, _LIBCPP_GET_C_LOCALE, __fmt, __v);
#else
# 1686 "/usr/include/c++/v1/locale" 3
        __nc = __snprintf_l(__nb, __nbuf, __cloc(), __fmt, __v);
#endif
# 1688 "/usr/include/c++/v1/locale" 3
    unique_ptr<char, void(*)(void*)> __nbh(0, free);
    if (__nc > static_cast<int>(__nbuf-1))
    {
        if (__specify_precision)
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
            __nc = asprintf_l(&__nb, _LIBCPP_GET_C_LOCALE, __fmt, (int)__iob.precision(), __v);
#else
# 1695 "/usr/include/c++/v1/locale" 3
            __nc = __asprintf_l(&__nb, __cloc(), __fmt,
                              (int)__iob.precision(), __v);
#endif
# 1698 "/usr/include/c++/v1/locale" 3
        else
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
            __nc = asprintf_l(&__nb, _LIBCPP_GET_C_LOCALE, __fmt, __v);
#else
# 1702 "/usr/include/c++/v1/locale" 3
            __nc = __asprintf_l(&__nb, __cloc(), __fmt, (int)__iob.precision(), __v);
#endif
# 1704 "/usr/include/c++/v1/locale" 3
        if (__nb == 0)
            __throw_bad_alloc();
        __nbh.reset(__nb);
    }
    char* __ne = __nb + __nc;
    char* __np = this->__identify_padding(__nb, __ne, __iob);
    // Stage 2 - Widen __nar while adding thousands separators
    char_type __o[2*(__nbuf-1) - 1];
    char_type* __ob = __o;
    unique_ptr<char_type, void(*)(void*)> __obh(0, free);
    if (__nb != __nar)
    {
        __ob = (char_type*)malloc(2*static_cast<size_t>(__nc)*sizeof(char_type));
        if (__ob == 0)
            __throw_bad_alloc();
        __obh.reset(__ob);
    }
    char_type* __op;  // pad here
    char_type* __oe;  // end of output
    this->__widen_and_group_float(__nb, __np, __ne, __ob, __op, __oe, __iob.getloc());
    // [__o, __oe) contains thousands_sep'd wide number
    // Stage 3 & 4
    __s = __pad_and_output(__s, __ob, __op, __oe, __iob, __fl);
    return __s;
}

template <class _CharT, class _OutputIterator>
_OutputIterator
num_put<_CharT, _OutputIterator>::do_put(iter_type __s, ios_base& __iob,
                                         char_type __fl, long double __v) const
{
    // Stage 1 - Get number in narrow char
    char __fmt[8] = {'%', 0};
    const char* __len = "L";
    bool __specify_precision = this->__format_float(__fmt+1, __len, __iob.flags());
    const unsigned __nbuf = 30;
    char __nar[__nbuf];
    char* __nb = __nar;
    int __nc;
    if (__specify_precision)
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
        __nc = snprintf_l(__nb, __nbuf, _LIBCPP_GET_C_LOCALE, __fmt,
                                   (int)__iob.precision(), __v);
#else
# 1748 "/usr/include/c++/v1/locale" 3
        __nc = __snprintf_l(__nb, __nbuf, __cloc(), __fmt,
                            (int)__iob.precision(), __v);
#endif
# 1751 "/usr/include/c++/v1/locale" 3
    else
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
        __nc = snprintf_l(__nb, __nbuf, _LIBCPP_GET_C_LOCALE, __fmt, __v);
#else
# 1755 "/usr/include/c++/v1/locale" 3
        __nc = __snprintf_l(__nb, __nbuf, __cloc(), __fmt, __v);
#endif
# 1757 "/usr/include/c++/v1/locale" 3
    unique_ptr<char, void(*)(void*)> __nbh(0, free);
    if (__nc > static_cast<int>(__nbuf-1))
    {
        if (__specify_precision)
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
            __nc = asprintf_l(&__nb, _LIBCPP_GET_C_LOCALE, __fmt, (int)__iob.precision(), __v);
#else
# 1764 "/usr/include/c++/v1/locale" 3
            __nc = __asprintf_l(&__nb, __cloc(), __fmt,
                              (int)__iob.precision(), __v);
#endif
# 1767 "/usr/include/c++/v1/locale" 3
        else
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
            __nc = asprintf_l(&__nb, _LIBCPP_GET_C_LOCALE, __fmt, __v);
#else
# 1771 "/usr/include/c++/v1/locale" 3
            __nc = __asprintf_l(&__nb, __cloc(), __fmt, __v);
#endif
# 1773 "/usr/include/c++/v1/locale" 3
        if (__nb == 0)
            __throw_bad_alloc();
        __nbh.reset(__nb);
    }
    char* __ne = __nb + __nc;
    char* __np = this->__identify_padding(__nb, __ne, __iob);
    // Stage 2 - Widen __nar while adding thousands separators
    char_type __o[2*(__nbuf-1) - 1];
    char_type* __ob = __o;
    unique_ptr<char_type, void(*)(void*)> __obh(0, free);
    if (__nb != __nar)
    {
        __ob = (char_type*)malloc(2*static_cast<size_t>(__nc)*sizeof(char_type));
        if (__ob == 0)
            __throw_bad_alloc();
        __obh.reset(__ob);
    }
    char_type* __op;  // pad here
    char_type* __oe;  // end of output
    this->__widen_and_group_float(__nb, __np, __ne, __ob, __op, __oe, __iob.getloc());
    // [__o, __oe) contains thousands_sep'd wide number
    // Stage 3 & 4
    __s = __pad_and_output(__s, __ob, __op, __oe, __iob, __fl);
    return __s;
}

template <class _CharT, class _OutputIterator>
_OutputIterator
num_put<_CharT, _OutputIterator>::do_put(iter_type __s, ios_base& __iob,
                                         char_type __fl, const void* __v) const
{
    // Stage 1 - Get pointer in narrow char
    char __fmt[6] = "%p";
    const unsigned __nbuf = 20;
    char __nar[__nbuf];
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
    int __nc = snprintf_l(__nar, sizeof(__nar), _LIBCPP_GET_C_LOCALE, __fmt, __v);
#else
# 1811 "/usr/include/c++/v1/locale" 3
    int __nc = __snprintf_l(__nar, sizeof(__nar), __cloc(), __fmt, __v);
#endif
# 1813 "/usr/include/c++/v1/locale" 3
    char* __ne = __nar + __nc;
    char* __np = this->__identify_padding(__nar, __ne, __iob);
    // Stage 2 - Widen __nar
    char_type __o[2*(__nbuf-1) - 1];
    char_type* __op;  // pad here
    char_type* __oe;  // end of output
    const ctype<char_type>& __ct = use_facet<ctype<char_type> >(__iob.getloc());
    __ct.widen(__nar, __ne, __o);
    __oe = __o + (__ne - __nar);
    if (__np == __ne)
        __op = __oe;
    else
        __op = __o + (__np - __nar);
    // [__o, __oe) contains wide number
    // Stage 3 & 4
    return __pad_and_output(__s, __o, __op, __oe, __iob, __fl);
}

_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS num_put<char>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS num_put<wchar_t>)

template <class _CharT, class _InputIterator>
_LIBCPP_HIDDEN
int
__get_up_to_n_digits(_InputIterator& __b, _InputIterator __e,
                     ios_base::iostate& __err, const ctype<_CharT>& __ct, int __n)
{
    // Precondition:  __n >= 1
    if (__b == __e)
    {
        __err |= ios_base::eofbit | ios_base::failbit;
        return 0;
    }
    // get first digit
    _CharT __c = *__b;
    if (!__ct.is(ctype_base::digit, __c))
    {
        __err |= ios_base::failbit;
        return 0;
    }
    int __r = __ct.narrow(__c, 0) - '0';
    for (++__b, --__n; __b != __e && __n > 0; ++__b, --__n)
    {
        // get next digit
        __c = *__b;
        if (!__ct.is(ctype_base::digit, __c))
            return __r;
        __r = __r * 10 + __ct.narrow(__c, 0) - '0';
    }
    if (__b == __e)
        __err |= ios_base::eofbit;
    return __r;
}

class _LIBCPP_TYPE_VIS time_base
{
public:
    enum dateorder {no_order, dmy, mdy, ymd, ydm};
};

template <class _CharT>
class _LIBCPP_TYPE_VIS __time_get_c_storage
{
protected:
    typedef basic_string<_CharT> string_type;

    virtual const string_type* __weeks() const;
    virtual const string_type* __months() const;
    virtual const string_type* __am_pm() const;
    virtual const string_type& __c() const;
    virtual const string_type& __r() const;
    virtual const string_type& __x() const;
    virtual const string_type& __X() const;
};

template <class _CharT, class _InputIterator = istreambuf_iterator<_CharT> >
class _LIBCPP_TYPE_VIS_ONLY time_get
    : public locale::facet,
      public time_base,
      private __time_get_c_storage<_CharT>
{
public:
    typedef _CharT                  char_type;
    typedef _InputIterator          iter_type;
    typedef time_base::dateorder    dateorder;
    typedef basic_string<char_type> string_type;

    _LIBCPP_ALWAYS_INLINE
    explicit time_get(size_t __refs = 0)
        : locale::facet(__refs) {}

    _LIBCPP_ALWAYS_INLINE
    dateorder date_order() const
    {
        return this->do_date_order();
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type get_time(iter_type __b, iter_type __e, ios_base& __iob,
                       ios_base::iostate& __err, tm* __tm) const
    {
        return do_get_time(__b, __e, __iob, __err, __tm);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type get_date(iter_type __b, iter_type __e, ios_base& __iob,
                       ios_base::iostate& __err, tm* __tm) const
    {
        return do_get_date(__b, __e, __iob, __err, __tm);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type get_weekday(iter_type __b, iter_type __e, ios_base& __iob,
                          ios_base::iostate& __err, tm* __tm) const
    {
        return do_get_weekday(__b, __e, __iob, __err, __tm);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type get_monthname(iter_type __b, iter_type __e, ios_base& __iob,
                            ios_base::iostate& __err, tm* __tm) const
    {
        return do_get_monthname(__b, __e, __iob, __err, __tm);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type get_year(iter_type __b, iter_type __e, ios_base& __iob,
                       ios_base::iostate& __err, tm* __tm) const
    {
        return do_get_year(__b, __e, __iob, __err, __tm);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type get(iter_type __b, iter_type __e, ios_base& __iob,
                  ios_base::iostate& __err, tm *__tm,
                  char __fmt, char __mod = 0) const
    {
        return do_get(__b, __e, __iob, __err, __tm, __fmt, __mod);
    }

    iter_type get(iter_type __b, iter_type __e, ios_base& __iob,
                  ios_base::iostate& __err, tm* __tm,
                  const char_type* __fmtb, const char_type* __fmte) const;

    static locale::id id;

protected:
    _LIBCPP_ALWAYS_INLINE
    ~time_get() {}

    virtual dateorder do_date_order() const;
    virtual iter_type do_get_time(iter_type __b, iter_type __e, ios_base& __iob,
                                  ios_base::iostate& __err, tm* __tm) const;
    virtual iter_type do_get_date(iter_type __b, iter_type __e, ios_base& __iob,
                                  ios_base::iostate& __err, tm* __tm) const;
    virtual iter_type do_get_weekday(iter_type __b, iter_type __e, ios_base& __iob,
                                     ios_base::iostate& __err, tm* __tm) const;
    virtual iter_type do_get_monthname(iter_type __b, iter_type __e, ios_base& __iob,
                                       ios_base::iostate& __err, tm* __tm) const;
    virtual iter_type do_get_year(iter_type __b, iter_type __e, ios_base& __iob,
                                  ios_base::iostate& __err, tm* __tm) const;
    virtual iter_type do_get(iter_type __b, iter_type __e, ios_base& __iob,
                             ios_base::iostate& __err, tm* __tm,
                             char __fmt, char __mod) const;
private:
    void __get_white_space(iter_type& __b, iter_type __e,
                           ios_base::iostate& __err, const ctype<char_type>& __ct) const;
    void __get_percent(iter_type& __b, iter_type __e, ios_base::iostate& __err,
                       const ctype<char_type>& __ct) const;

    void __get_weekdayname(int& __m,
                           iter_type& __b, iter_type __e,
                           ios_base::iostate& __err,
                           const ctype<char_type>& __ct) const;
    void __get_monthname(int& __m,
                         iter_type& __b, iter_type __e,
                         ios_base::iostate& __err,
                         const ctype<char_type>& __ct) const;
    void __get_day(int& __d,
                   iter_type& __b, iter_type __e,
                   ios_base::iostate& __err,
                   const ctype<char_type>& __ct) const;
    void __get_month(int& __m,
                     iter_type& __b, iter_type __e,
                     ios_base::iostate& __err,
                     const ctype<char_type>& __ct) const;
    void __get_year(int& __y,
                   iter_type& __b, iter_type __e,
                   ios_base::iostate& __err,
                   const ctype<char_type>& __ct) const;
    void __get_year4(int& __y,
                    iter_type& __b, iter_type __e,
                    ios_base::iostate& __err,
                    const ctype<char_type>& __ct) const;
    void __get_hour(int& __d,
                    iter_type& __b, iter_type __e,
                    ios_base::iostate& __err,
                    const ctype<char_type>& __ct) const;
    void __get_12_hour(int& __h,
                       iter_type& __b, iter_type __e,
                       ios_base::iostate& __err,
                       const ctype<char_type>& __ct) const;
    void __get_am_pm(int& __h,
                     iter_type& __b, iter_type __e,
                     ios_base::iostate& __err,
                     const ctype<char_type>& __ct) const;
    void __get_minute(int& __m,
                      iter_type& __b, iter_type __e,
                      ios_base::iostate& __err,
                      const ctype<char_type>& __ct) const;
    void __get_second(int& __s,
                      iter_type& __b, iter_type __e,
                      ios_base::iostate& __err,
                      const ctype<char_type>& __ct) const;
    void __get_weekday(int& __w,
                       iter_type& __b, iter_type __e,
                       ios_base::iostate& __err,
                       const ctype<char_type>& __ct) const;
    void __get_day_year_num(int& __w,
                            iter_type& __b, iter_type __e,
                            ios_base::iostate& __err,
                            const ctype<char_type>& __ct) const;
};

template <class _CharT, class _InputIterator>
locale::id
time_get<_CharT, _InputIterator>::id;

// time_get primatives

template <class _CharT, class _InputIterator>
void
time_get<_CharT, _InputIterator>::__get_weekdayname(int& __w,
                                                    iter_type& __b, iter_type __e,
                                                    ios_base::iostate& __err,
                                                    const ctype<char_type>& __ct) const
{
    // Note:  ignoring case comes from the POSIX strptime spec
    const string_type* __wk = this->__weeks();
    ptrdiff_t __i = __scan_keyword(__b, __e, __wk, __wk+14, __ct, __err, false) - __wk;
    if (__i < 14)
        __w = __i % 7;
}

template <class _CharT, class _InputIterator>
void
time_get<_CharT, _InputIterator>::__get_monthname(int& __m,
                                                  iter_type& __b, iter_type __e,
                                                  ios_base::iostate& __err,
                                                  const ctype<char_type>& __ct) const
{
    // Note:  ignoring case comes from the POSIX strptime spec
    const string_type* __month = this->__months();
    ptrdiff_t __i = __scan_keyword(__b, __e, __month, __month+24, __ct, __err, false) - __month;
    if (__i < 24)
        __m = __i % 12;
}

template <class _CharT, class _InputIterator>
void
time_get<_CharT, _InputIterator>::__get_day(int& __d,
                                            iter_type& __b, iter_type __e,
                                            ios_base::iostate& __err,
                                            const ctype<char_type>& __ct) const
{
    int __t = __get_up_to_n_digits(__b, __e, __err, __ct, 2);
    if (!(__err & ios_base::failbit) && 1 <= __t && __t <= 31)
        __d = __t;
    else
        __err |= ios_base::failbit;
}

template <class _CharT, class _InputIterator>
void
time_get<_CharT, _InputIterator>::__get_month(int& __m,
                                              iter_type& __b, iter_type __e,
                                              ios_base::iostate& __err,
                                              const ctype<char_type>& __ct) const
{
    int __t = __get_up_to_n_digits(__b, __e, __err, __ct, 2) - 1;
    if (!(__err & ios_base::failbit) && __t <= 11)
        __m = __t;
    else
        __err |= ios_base::failbit;
}

template <class _CharT, class _InputIterator>
void
time_get<_CharT, _InputIterator>::__get_year(int& __y,
                                             iter_type& __b, iter_type __e,
                                             ios_base::iostate& __err,
                                             const ctype<char_type>& __ct) const
{
    int __t = __get_up_to_n_digits(__b, __e, __err, __ct, 4);
    if (!(__err & ios_base::failbit))
    {
        if (__t < 69)
            __t += 2000;
        else if (69 <= __t && __t <= 99)
            __t += 1900;
        __y = __t - 1900;
    }
}

template <class _CharT, class _InputIterator>
void
time_get<_CharT, _InputIterator>::__get_year4(int& __y,
                                              iter_type& __b, iter_type __e,
                                              ios_base::iostate& __err,
                                              const ctype<char_type>& __ct) const
{
    int __t = __get_up_to_n_digits(__b, __e, __err, __ct, 4);
    if (!(__err & ios_base::failbit))
        __y = __t - 1900;
}

template <class _CharT, class _InputIterator>
void
time_get<_CharT, _InputIterator>::__get_hour(int& __h,
                                             iter_type& __b, iter_type __e,
                                             ios_base::iostate& __err,
                                             const ctype<char_type>& __ct) const
{
    int __t = __get_up_to_n_digits(__b, __e, __err, __ct, 2);
    if (!(__err & ios_base::failbit) && __t <= 23)
        __h = __t;
    else
        __err |= ios_base::failbit;
}

template <class _CharT, class _InputIterator>
void
time_get<_CharT, _InputIterator>::__get_12_hour(int& __h,
                                                iter_type& __b, iter_type __e,
                                                ios_base::iostate& __err,
                                                const ctype<char_type>& __ct) const
{
    int __t = __get_up_to_n_digits(__b, __e, __err, __ct, 2);
    if (!(__err & ios_base::failbit) && 1 <= __t && __t <= 12)
        __h = __t;
    else
        __err |= ios_base::failbit;
}

template <class _CharT, class _InputIterator>
void
time_get<_CharT, _InputIterator>::__get_minute(int& __m,
                                               iter_type& __b, iter_type __e,
                                               ios_base::iostate& __err,
                                               const ctype<char_type>& __ct) const
{
    int __t = __get_up_to_n_digits(__b, __e, __err, __ct, 2);
    if (!(__err & ios_base::failbit) && __t <= 59)
        __m = __t;
    else
        __err |= ios_base::failbit;
}

template <class _CharT, class _InputIterator>
void
time_get<_CharT, _InputIterator>::__get_second(int& __s,
                                               iter_type& __b, iter_type __e,
                                               ios_base::iostate& __err,
                                               const ctype<char_type>& __ct) const
{
    int __t = __get_up_to_n_digits(__b, __e, __err, __ct, 2);
    if (!(__err & ios_base::failbit) && __t <= 60)
        __s = __t;
    else
        __err |= ios_base::failbit;
}

template <class _CharT, class _InputIterator>
void
time_get<_CharT, _InputIterator>::__get_weekday(int& __w,
                                                iter_type& __b, iter_type __e,
                                                ios_base::iostate& __err,
                                                const ctype<char_type>& __ct) const
{
    int __t = __get_up_to_n_digits(__b, __e, __err, __ct, 1);
    if (!(__err & ios_base::failbit) && __t <= 6)
        __w = __t;
    else
        __err |= ios_base::failbit;
}

template <class _CharT, class _InputIterator>
void
time_get<_CharT, _InputIterator>::__get_day_year_num(int& __d,
                                                     iter_type& __b, iter_type __e,
                                                     ios_base::iostate& __err,
                                                     const ctype<char_type>& __ct) const
{
    int __t = __get_up_to_n_digits(__b, __e, __err, __ct, 3);
    if (!(__err & ios_base::failbit) && __t <= 365)
        __d = __t;
    else
        __err |= ios_base::failbit;
}

template <class _CharT, class _InputIterator>
void
time_get<_CharT, _InputIterator>::__get_white_space(iter_type& __b, iter_type __e,
                                                    ios_base::iostate& __err,
                                                    const ctype<char_type>& __ct) const
{
    for (; __b != __e && __ct.is(ctype_base::space, *__b); ++__b)
        ;
    if (__b == __e)
        __err |= ios_base::eofbit;
}

template <class _CharT, class _InputIterator>
void
time_get<_CharT, _InputIterator>::__get_am_pm(int& __h,
                                              iter_type& __b, iter_type __e,
                                              ios_base::iostate& __err,
                                              const ctype<char_type>& __ct) const
{
    const string_type* __ap = this->__am_pm();
    if (__ap[0].size() + __ap[1].size() == 0)
    {
        __err |= ios_base::failbit;
        return;
    }
    ptrdiff_t __i = __scan_keyword(__b, __e, __ap, __ap+2, __ct, __err, false) - __ap;
    if (__i == 0 && __h == 12)
        __h = 0;
    else if (__i == 1 && __h < 12)
        __h += 12;
}

template <class _CharT, class _InputIterator>
void
time_get<_CharT, _InputIterator>::__get_percent(iter_type& __b, iter_type __e,
                                                ios_base::iostate& __err,
                                                const ctype<char_type>& __ct) const
{
    if (__b == __e)
    {
        __err |= ios_base::eofbit | ios_base::failbit;
        return;
    }
    if (__ct.narrow(*__b, 0) != '%')
        __err |= ios_base::failbit;
    else if(++__b == __e)
        __err |= ios_base::eofbit;
}

// time_get end primatives

template <class _CharT, class _InputIterator>
_InputIterator
time_get<_CharT, _InputIterator>::get(iter_type __b, iter_type __e,
                                      ios_base& __iob,
                                      ios_base::iostate& __err, tm* __tm,
                                      const char_type* __fmtb, const char_type* __fmte) const
{
    const ctype<char_type>& __ct = use_facet<ctype<char_type> >(__iob.getloc());
    __err = ios_base::goodbit;
    while (__fmtb != __fmte && __err == ios_base::goodbit)
    {
        if (__b == __e)
        {
            __err = ios_base::failbit;
            break;
        }
        if (__ct.narrow(*__fmtb, 0) == '%')
        {
            if (++__fmtb == __fmte)
            {
                __err = ios_base::failbit;
                break;
            }
            char __cmd = __ct.narrow(*__fmtb, 0);
            char __opt = '\0';
            if (__cmd == 'E' || __cmd == '0')
            {
                if (++__fmtb == __fmte)
                {
                    __err = ios_base::failbit;
                    break;
                }
                __opt = __cmd;
                __cmd = __ct.narrow(*__fmtb, 0);
            }
            __b = do_get(__b, __e, __iob, __err, __tm, __cmd, __opt);
            ++__fmtb;
        }
        else if (__ct.is(ctype_base::space, *__fmtb))
        {
            for (++__fmtb; __fmtb != __fmte && __ct.is(ctype_base::space, *__fmtb); ++__fmtb)
                ;
            for (        ;    __b != __e    && __ct.is(ctype_base::space, *__b);    ++__b)
                ;
        }
        else if (__ct.toupper(*__b) == __ct.toupper(*__fmtb))
        {
            ++__b;
            ++__fmtb;
        }
        else
            __err = ios_base::failbit;
    }
    if (__b == __e)
        __err |= ios_base::eofbit;
    return __b;
}

template <class _CharT, class _InputIterator>
typename time_get<_CharT, _InputIterator>::dateorder
time_get<_CharT, _InputIterator>::do_date_order() const
{
    return mdy;
}

template <class _CharT, class _InputIterator>
_InputIterator
time_get<_CharT, _InputIterator>::do_get_time(iter_type __b, iter_type __e,
                                              ios_base& __iob,
                                              ios_base::iostate& __err,
                                              tm* __tm) const
{
    const char_type __fmt[] = {'%', 'H', ':', '%', 'M', ':', '%', 'S'};
    return get(__b, __e, __iob, __err, __tm, __fmt, __fmt + sizeof(__fmt)/sizeof(__fmt[0]));
}

template <class _CharT, class _InputIterator>
_InputIterator
time_get<_CharT, _InputIterator>::do_get_date(iter_type __b, iter_type __e,
                                              ios_base& __iob,
                                              ios_base::iostate& __err,
                                              tm* __tm) const
{
    const string_type& __fmt = this->__x();
    return get(__b, __e, __iob, __err, __tm, __fmt.data(), __fmt.data() + __fmt.size());
}

template <class _CharT, class _InputIterator>
_InputIterator
time_get<_CharT, _InputIterator>::do_get_weekday(iter_type __b, iter_type __e,
                                                 ios_base& __iob,
                                                 ios_base::iostate& __err,
                                                 tm* __tm) const
{
    const ctype<char_type>& __ct = use_facet<ctype<char_type> >(__iob.getloc());
    __get_weekdayname(__tm->tm_wday, __b, __e, __err, __ct);
    return __b;
}

template <class _CharT, class _InputIterator>
_InputIterator
time_get<_CharT, _InputIterator>::do_get_monthname(iter_type __b, iter_type __e,
                                                   ios_base& __iob,
                                                   ios_base::iostate& __err,
                                                   tm* __tm) const
{
    const ctype<char_type>& __ct = use_facet<ctype<char_type> >(__iob.getloc());
    __get_monthname(__tm->tm_mon, __b, __e, __err, __ct);
    return __b;
}

template <class _CharT, class _InputIterator>
_InputIterator
time_get<_CharT, _InputIterator>::do_get_year(iter_type __b, iter_type __e,
                                              ios_base& __iob,
                                              ios_base::iostate& __err,
                                              tm* __tm) const
{
    const ctype<char_type>& __ct = use_facet<ctype<char_type> >(__iob.getloc());
    __get_year(__tm->tm_year, __b, __e, __err, __ct);
    return __b;
}

template <class _CharT, class _InputIterator>
_InputIterator
time_get<_CharT, _InputIterator>::do_get(iter_type __b, iter_type __e,
                                         ios_base& __iob,
                                         ios_base::iostate& __err, tm* __tm,
                                         char __fmt, char) const
{
    __err = ios_base::goodbit;
    const ctype<char_type>& __ct = use_facet<ctype<char_type> >(__iob.getloc());
    switch (__fmt)
    {
    case 'a':
    case 'A':
        __get_weekdayname(__tm->tm_wday, __b, __e, __err, __ct);
        break;
    case 'b':
    case 'B':
    case 'h':
        __get_monthname(__tm->tm_mon, __b, __e, __err, __ct);
        break;
    case 'c':
        {
        const string_type& __fm = this->__c();
        __b = get(__b, __e, __iob, __err, __tm, __fm.data(), __fm.data() + __fm.size());
        }
        break;
    case 'd':
    case 'e':
        __get_day(__tm->tm_mday, __b, __e, __err, __ct);
        break;
    case 'D':
        {
        const char_type __fm[] = {'%', 'm', '/', '%', 'd', '/', '%', 'y'};
        __b = get(__b, __e, __iob, __err, __tm, __fm, __fm + sizeof(__fm)/sizeof(__fm[0]));
        }
        break;
    case 'F':
        {
        const char_type __fm[] = {'%', 'Y', '-', '%', 'm', '-', '%', 'd'};
        __b = get(__b, __e, __iob, __err, __tm, __fm, __fm + sizeof(__fm)/sizeof(__fm[0]));
        }
        break;
    case 'H':
        __get_hour(__tm->tm_hour, __b, __e, __err, __ct);
        break;
    case 'I':
        __get_12_hour(__tm->tm_hour, __b, __e, __err, __ct);
        break;
    case 'j':
        __get_day_year_num(__tm->tm_yday, __b, __e, __err, __ct);
        break;
    case 'm':
        __get_month(__tm->tm_mon, __b, __e, __err, __ct);
        break;
    case 'M':
        __get_minute(__tm->tm_min, __b, __e, __err, __ct);
        break;
    case 'n':
    case 't':
        __get_white_space(__b, __e, __err, __ct);
        break;
    case 'p':
        __get_am_pm(__tm->tm_hour, __b, __e, __err, __ct);
        break;
    case 'r':
        {
        const char_type __fm[] = {'%', 'I', ':', '%', 'M', ':', '%', 'S', ' ', '%', 'p'};
        __b = get(__b, __e, __iob, __err, __tm, __fm, __fm + sizeof(__fm)/sizeof(__fm[0]));
        }
        break;
    case 'R':
        {
        const char_type __fm[] = {'%', 'H', ':', '%', 'M'};
        __b = get(__b, __e, __iob, __err, __tm, __fm, __fm + sizeof(__fm)/sizeof(__fm[0]));
        }
        break;
    case 'S':
        __get_second(__tm->tm_sec, __b, __e, __err, __ct);
        break;
    case 'T':
        {
        const char_type __fm[] = {'%', 'H', ':', '%', 'M', ':', '%', 'S'};
        __b = get(__b, __e, __iob, __err, __tm, __fm, __fm + sizeof(__fm)/sizeof(__fm[0]));
        }
        break;
    case 'w':
        __get_weekday(__tm->tm_wday, __b, __e, __err, __ct);
        break;
    case 'x':
        return do_get_date(__b, __e, __iob, __err, __tm);
    case 'X':
        {
        const string_type& __fm = this->__X();
        __b = get(__b, __e, __iob, __err, __tm, __fm.data(), __fm.data() + __fm.size());
        }
        break;
    case 'y':
        __get_year(__tm->tm_year, __b, __e, __err, __ct);
        break;
    case 'Y':
        __get_year4(__tm->tm_year, __b, __e, __err, __ct);
        break;
    case '%':
        __get_percent(__b, __e, __err, __ct);
        break;
    default:
        __err |= ios_base::failbit;
    }
    return __b;
}

_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS time_get<char>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS time_get<wchar_t>)

class _LIBCPP_TYPE_VIS __time_get
{
protected:
    locale_t __loc_;

    __time_get(const char* __nm);
    __time_get(const string& __nm);
    ~__time_get();
};

template <class _CharT>
class _LIBCPP_TYPE_VIS __time_get_storage
    : public __time_get
{
protected:
    typedef basic_string<_CharT> string_type;

    string_type __weeks_[14];
    string_type __months_[24];
    string_type __am_pm_[2];
    string_type __c_;
    string_type __r_;
    string_type __x_;
    string_type __X_;

    explicit __time_get_storage(const char* __nm);
    explicit __time_get_storage(const string& __nm);

    _LIBCPP_ALWAYS_INLINE ~__time_get_storage() {}

    time_base::dateorder __do_date_order() const;

private:
    void init(const ctype<_CharT>&);
    string_type __analyze(char __fmt, const ctype<_CharT>&);
};

template <class _CharT, class _InputIterator = istreambuf_iterator<_CharT> >
class _LIBCPP_TYPE_VIS_ONLY time_get_byname
    : public time_get<_CharT, _InputIterator>,
      private __time_get_storage<_CharT>
{
public:
    typedef time_base::dateorder    dateorder;
    typedef _InputIterator          iter_type;
    typedef _CharT                  char_type;
    typedef basic_string<char_type> string_type;

    _LIBCPP_INLINE_VISIBILITY
    explicit time_get_byname(const char* __nm, size_t __refs = 0)
        : time_get<_CharT, _InputIterator>(__refs),
          __time_get_storage<_CharT>(__nm) {}
    _LIBCPP_INLINE_VISIBILITY
    explicit time_get_byname(const string& __nm, size_t __refs = 0)
        : time_get<_CharT, _InputIterator>(__refs),
          __time_get_storage<_CharT>(__nm) {}

protected:
    _LIBCPP_INLINE_VISIBILITY
    ~time_get_byname() {}

    _LIBCPP_INLINE_VISIBILITY
    virtual dateorder do_date_order() const {return this->__do_date_order();}
private:
    _LIBCPP_INLINE_VISIBILITY
    virtual const string_type* __weeks() const  {return this->__weeks_;}
    _LIBCPP_INLINE_VISIBILITY
    virtual const string_type* __months() const {return this->__months_;}
    _LIBCPP_INLINE_VISIBILITY
    virtual const string_type* __am_pm() const  {return this->__am_pm_;}
    _LIBCPP_INLINE_VISIBILITY
    virtual const string_type& __c() const      {return this->__c_;}
    _LIBCPP_INLINE_VISIBILITY
    virtual const string_type& __r() const      {return this->__r_;}
    _LIBCPP_INLINE_VISIBILITY
    virtual const string_type& __x() const      {return this->__x_;}
    _LIBCPP_INLINE_VISIBILITY
    virtual const string_type& __X() const      {return this->__X_;}
};

_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS time_get_byname<char>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS time_get_byname<wchar_t>)

class _LIBCPP_TYPE_VIS __time_put
{
    locale_t __loc_;
protected:
    _LIBCPP_ALWAYS_INLINE __time_put() : __loc_(_LIBCPP_GET_C_LOCALE) {}
    __time_put(const char* __nm);
    __time_put(const string& __nm);
    ~__time_put();
    void __do_put(char* __nb, char*& __ne, const tm* __tm,
                  char __fmt, char __mod) const;
    void __do_put(wchar_t* __wb, wchar_t*& __we, const tm* __tm,
                  char __fmt, char __mod) const;
};

template <class _CharT, class _OutputIterator = ostreambuf_iterator<_CharT> >
class _LIBCPP_TYPE_VIS_ONLY time_put
    : public locale::facet,
      private __time_put
{
public:
    typedef _CharT char_type;
    typedef _OutputIterator iter_type;

    _LIBCPP_ALWAYS_INLINE
    explicit time_put(size_t __refs = 0)
        : locale::facet(__refs) {}

    iter_type put(iter_type __s, ios_base& __iob, char_type __fl, const tm* __tm,
                  const char_type* __pb, const char_type* __pe) const;

    _LIBCPP_ALWAYS_INLINE
    iter_type put(iter_type __s, ios_base& __iob, char_type __fl,
                  const tm* __tm, char __fmt, char __mod = 0) const
    {
        return do_put(__s, __iob, __fl, __tm, __fmt, __mod);
    }

    static locale::id id;

protected:
    _LIBCPP_ALWAYS_INLINE
    ~time_put() {}
    virtual iter_type do_put(iter_type __s, ios_base&, char_type, const tm* __tm,
                             char __fmt, char __mod) const;

    _LIBCPP_ALWAYS_INLINE
    explicit time_put(const char* __nm, size_t __refs)
        : locale::facet(__refs),
          __time_put(__nm) {}
    _LIBCPP_ALWAYS_INLINE
    explicit time_put(const string& __nm, size_t __refs)
        : locale::facet(__refs),
          __time_put(__nm) {}
};

template <class _CharT, class _OutputIterator>
locale::id
time_put<_CharT, _OutputIterator>::id;

template <class _CharT, class _OutputIterator>
_OutputIterator
time_put<_CharT, _OutputIterator>::put(iter_type __s, ios_base& __iob,
                                       char_type __fl, const tm* __tm,
                                       const char_type* __pb,
                                       const char_type* __pe) const
{
    const ctype<char_type>& __ct = use_facet<ctype<char_type> >(__iob.getloc());
    for (; __pb != __pe; ++__pb)
    {
        if (__ct.narrow(*__pb, 0) == '%')
        {
            if (++__pb == __pe)
            {
                *__s++ = __pb[-1];
                break;
            }
            char __mod = 0;
            char __fmt = __ct.narrow(*__pb, 0);
            if (__fmt == 'E' || __fmt == 'O')
            {
                if (++__pb == __pe)
                {
                    *__s++ = __pb[-2];
                    *__s++ = __pb[-1];
                    break;
                }
                __mod = __fmt;
                __fmt = __ct.narrow(*__pb, 0);
            }
            __s = do_put(__s, __iob, __fl, __tm, __fmt, __mod);
        }
        else
            *__s++ = *__pb;
    }
    return __s;
}

template <class _CharT, class _OutputIterator>
_OutputIterator
time_put<_CharT, _OutputIterator>::do_put(iter_type __s, ios_base&,
                                          char_type, const tm* __tm,
                                          char __fmt, char __mod) const
{
    char_type __nar[100];
    char_type* __nb = __nar;
    char_type* __ne = __nb + 100;
    __do_put(__nb, __ne, __tm, __fmt, __mod);
    return _VSTD::copy(__nb, __ne, __s);
}

_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS time_put<char>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS time_put<wchar_t>)

template <class _CharT, class _OutputIterator = ostreambuf_iterator<_CharT> >
class _LIBCPP_TYPE_VIS_ONLY time_put_byname
    : public time_put<_CharT, _OutputIterator>
{
public:
    _LIBCPP_ALWAYS_INLINE
    explicit time_put_byname(const char* __nm, size_t __refs = 0)
        : time_put<_CharT, _OutputIterator>(__nm, __refs) {}

    _LIBCPP_ALWAYS_INLINE
    explicit time_put_byname(const string& __nm, size_t __refs = 0)
        : time_put<_CharT, _OutputIterator>(__nm, __refs) {}

protected:
    _LIBCPP_ALWAYS_INLINE
    ~time_put_byname() {}
};

_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS time_put_byname<char>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS time_put_byname<wchar_t>)

// money_base

class _LIBCPP_TYPE_VIS money_base
{
public:
    enum part {none, space, symbol, sign, value};
    struct pattern {char field[4];};

    _LIBCPP_ALWAYS_INLINE money_base() {}
};

// moneypunct

template <class _CharT, bool _International = false>
class _LIBCPP_TYPE_VIS_ONLY moneypunct
    : public locale::facet,
      public money_base
{
public:
    typedef _CharT                  char_type;
    typedef basic_string<char_type> string_type;

    _LIBCPP_ALWAYS_INLINE
    explicit moneypunct(size_t __refs = 0)
        : locale::facet(__refs) {}

    _LIBCPP_ALWAYS_INLINE char_type   decimal_point() const {return do_decimal_point();}
    _LIBCPP_ALWAYS_INLINE char_type   thousands_sep() const {return do_thousands_sep();}
    _LIBCPP_ALWAYS_INLINE string      grouping()      const {return do_grouping();}
    _LIBCPP_ALWAYS_INLINE string_type curr_symbol()   const {return do_curr_symbol();}
    _LIBCPP_ALWAYS_INLINE string_type positive_sign() const {return do_positive_sign();}
    _LIBCPP_ALWAYS_INLINE string_type negative_sign() const {return do_negative_sign();}
    _LIBCPP_ALWAYS_INLINE int         frac_digits()   const {return do_frac_digits();}
    _LIBCPP_ALWAYS_INLINE pattern     pos_format()    const {return do_pos_format();}
    _LIBCPP_ALWAYS_INLINE pattern     neg_format()    const {return do_neg_format();}

    static locale::id id;
    static const bool intl = _International;

protected:
    _LIBCPP_ALWAYS_INLINE
    ~moneypunct() {}

    virtual char_type   do_decimal_point() const {return numeric_limits<char_type>::max();}
    virtual char_type   do_thousands_sep() const {return numeric_limits<char_type>::max();}
    virtual string      do_grouping()      const {return string();}
    virtual string_type do_curr_symbol()   const {return string_type();}
    virtual string_type do_positive_sign() const {return string_type();}
    virtual string_type do_negative_sign() const {return string_type(1, '-');}
    virtual int         do_frac_digits()   const {return 0;}
    virtual pattern     do_pos_format()    const
        {pattern __p = {{symbol, sign, none, value}}; return __p;}
    virtual pattern     do_neg_format()    const
        {pattern __p = {{symbol, sign, none, value}}; return __p;}
};

template <class _CharT, bool _International>
locale::id
moneypunct<_CharT, _International>::id;

template <class _CharT, bool _International>
const bool
moneypunct<_CharT, _International>::intl;

_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS moneypunct<char, false>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS moneypunct<char, true>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS moneypunct<wchar_t, false>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS moneypunct<wchar_t, true>)

// moneypunct_byname

template <class _CharT, bool _International = false>
class _LIBCPP_TYPE_VIS_ONLY moneypunct_byname
    : public moneypunct<_CharT, _International>
{
public:
    typedef money_base::pattern  pattern;
    typedef _CharT                  char_type;
    typedef basic_string<char_type> string_type;

    _LIBCPP_ALWAYS_INLINE
    explicit moneypunct_byname(const char* __nm, size_t __refs = 0)
        : moneypunct<_CharT, _International>(__refs) {init(__nm);}

    _LIBCPP_ALWAYS_INLINE
    explicit moneypunct_byname(const string& __nm, size_t __refs = 0)
        : moneypunct<_CharT, _International>(__refs) {init(__nm.c_str());}

protected:
    _LIBCPP_ALWAYS_INLINE
    ~moneypunct_byname() {}

    virtual char_type   do_decimal_point() const {return __decimal_point_;}
    virtual char_type   do_thousands_sep() const {return __thousands_sep_;}
    virtual string      do_grouping()      const {return __grouping_;}
    virtual string_type do_curr_symbol()   const {return __curr_symbol_;}
    virtual string_type do_positive_sign() const {return __positive_sign_;}
    virtual string_type do_negative_sign() const {return __negative_sign_;}
    virtual int         do_frac_digits()   const {return __frac_digits_;}
    virtual pattern     do_pos_format()    const {return __pos_format_;}
    virtual pattern     do_neg_format()    const {return __neg_format_;}

private:
    char_type   __decimal_point_;
    char_type   __thousands_sep_;
    string      __grouping_;
    string_type __curr_symbol_;
    string_type __positive_sign_;
    string_type __negative_sign_;
    int         __frac_digits_;
    pattern     __pos_format_;
    pattern     __neg_format_;

    void init(const char*);
};

template<> void moneypunct_byname<char, false>::init(const char*);
template<> void moneypunct_byname<char, true>::init(const char*);
template<> void moneypunct_byname<wchar_t, false>::init(const char*);
template<> void moneypunct_byname<wchar_t, true>::init(const char*);

_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS moneypunct_byname<char, false>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS moneypunct_byname<char, true>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS moneypunct_byname<wchar_t, false>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS moneypunct_byname<wchar_t, true>)

// money_get

template <class _CharT>
class __money_get
{
protected:
    typedef _CharT                  char_type;
    typedef basic_string<char_type> string_type;

    _LIBCPP_ALWAYS_INLINE __money_get() {}

    static void __gather_info(bool __intl, const locale& __loc,
                              money_base::pattern& __pat, char_type& __dp,
                              char_type& __ts, string& __grp,
                              string_type& __sym, string_type& __psn,
                              string_type& __nsn, int& __fd);
};

template <class _CharT>
void
__money_get<_CharT>::__gather_info(bool __intl, const locale& __loc,
                                   money_base::pattern& __pat, char_type& __dp,
                                   char_type& __ts, string& __grp,
                                   string_type& __sym, string_type& __psn,
                                   string_type& __nsn, int& __fd)
{
    if (__intl)
    {
        const moneypunct<char_type, true>& __mp =
            use_facet<moneypunct<char_type, true> >(__loc);
        __pat = __mp.neg_format();
        __nsn = __mp.negative_sign();
        __psn = __mp.positive_sign();
        __dp = __mp.decimal_point();
        __ts = __mp.thousands_sep();
        __grp = __mp.grouping();
        __sym = __mp.curr_symbol();
        __fd = __mp.frac_digits();
    }
    else
    {
        const moneypunct<char_type, false>& __mp =
            use_facet<moneypunct<char_type, false> >(__loc);
        __pat = __mp.neg_format();
        __nsn = __mp.negative_sign();
        __psn = __mp.positive_sign();
        __dp = __mp.decimal_point();
        __ts = __mp.thousands_sep();
        __grp = __mp.grouping();
        __sym = __mp.curr_symbol();
        __fd = __mp.frac_digits();
    }
}

_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS __money_get<char>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS __money_get<wchar_t>)

template <class _CharT, class _InputIterator = istreambuf_iterator<_CharT> >
class _LIBCPP_TYPE_VIS_ONLY money_get
    : public locale::facet,
      private __money_get<_CharT>
{
public:
    typedef _CharT                  char_type;
    typedef _InputIterator          iter_type;
    typedef basic_string<char_type> string_type;

    _LIBCPP_ALWAYS_INLINE
    explicit money_get(size_t __refs = 0)
        : locale::facet(__refs) {}

    _LIBCPP_ALWAYS_INLINE
    iter_type get(iter_type __b, iter_type __e, bool __intl, ios_base& __iob,
                  ios_base::iostate& __err, long double& __v) const
    {
        return do_get(__b, __e, __intl, __iob, __err, __v);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type get(iter_type __b, iter_type __e, bool __intl, ios_base& __iob,
                  ios_base::iostate& __err, string_type& __v) const
    {
        return do_get(__b, __e, __intl, __iob, __err, __v);
    }

    static locale::id id;

protected:

    _LIBCPP_ALWAYS_INLINE
    ~money_get() {}

    virtual iter_type do_get(iter_type __b, iter_type __e, bool __intl,
                             ios_base& __iob, ios_base::iostate& __err,
                             long double& __v) const;
    virtual iter_type do_get(iter_type __b, iter_type __e, bool __intl,
                             ios_base& __iob, ios_base::iostate& __err,
                             string_type& __v) const;

private:
    static bool __do_get(iter_type& __b, iter_type __e,
                         bool __intl, const locale& __loc,
                         ios_base::fmtflags __flags, ios_base::iostate& __err,
                         bool& __neg, const ctype<char_type>& __ct,
                         unique_ptr<char_type, void(*)(void*)>& __wb,
                         char_type*& __wn, char_type* __we);
};

template <class _CharT, class _InputIterator>
locale::id
money_get<_CharT, _InputIterator>::id;

_LIBCPP_FUNC_VIS void __do_nothing(void*);

template <class _Tp>
_LIBCPP_HIDDEN
void
__double_or_nothing(unique_ptr<_Tp, void(*)(void*)>& __b, _Tp*& __n, _Tp*& __e)
{
    bool __owns = __b.get_deleter() != __do_nothing;
    size_t __cur_cap = static_cast<size_t>(__e-__b.get()) * sizeof(_Tp);
    size_t __new_cap = __cur_cap < numeric_limits<size_t>::max() / 2 ?
                       2 * __cur_cap : numeric_limits<size_t>::max();
    size_t __n_off = static_cast<size_t>(__n - __b.get());
    _Tp* __t = (_Tp*)realloc(__owns ? __b.get() : 0, __new_cap);
    if (__t == 0)
        __throw_bad_alloc();
    if (__owns)
        __b.release();
    __b = unique_ptr<_Tp, void(*)(void*)>(__t, free);
    __new_cap /= sizeof(_Tp);
    __n = __b.get() + __n_off;
    __e = __b.get() + __new_cap;
}

// true == success
template <class _CharT, class _InputIterator>
bool
money_get<_CharT, _InputIterator>::__do_get(iter_type& __b, iter_type __e,
                                            bool __intl, const locale& __loc,
                                            ios_base::fmtflags __flags,
                                            ios_base::iostate& __err,
                                            bool& __neg,
                                            const ctype<char_type>& __ct,
                                            unique_ptr<char_type, void(*)(void*)>& __wb,
                                            char_type*& __wn, char_type* __we)
{
    const unsigned __bz = 100;
    unsigned __gbuf[__bz];
    unique_ptr<unsigned, void(*)(void*)> __gb(__gbuf, __do_nothing);
    unsigned* __gn = __gb.get();
    unsigned* __ge = __gn + __bz;
    money_base::pattern __pat;
    char_type __dp;
    char_type __ts;
    string __grp;
    string_type __sym;
    string_type __psn;
    string_type __nsn;
    // Capture the spaces read into money_base::{space,none} so they
    // can be compared to initial spaces in __sym.
    string_type __spaces;
    int __fd;
    __money_get<_CharT>::__gather_info(__intl, __loc, __pat, __dp, __ts, __grp,
                                       __sym, __psn, __nsn, __fd);
    const string_type* __trailing_sign = 0;
    __wn = __wb.get();
    for (unsigned __p = 0; __p < 4 && __b != __e; ++__p)
    {
        switch (__pat.field[__p])
        {
        case money_base::space:
            if (__p != 3)
            {
                if (__ct.is(ctype_base::space, *__b))
                    __spaces.push_back(*__b++);
                else
                {
                    __err |= ios_base::failbit;
                    return false;
                }
            }
            // drop through
        case money_base::none:
            if (__p != 3)
            {
                while (__b != __e && __ct.is(ctype_base::space, *__b))
                    __spaces.push_back(*__b++);
            }
            break;
        case money_base::sign:
            if (__psn.size() + __nsn.size() > 0)
            {
                if (__psn.size() == 0 || __nsn.size() == 0)
                {   // sign is optional
                    if (__psn.size() > 0)
                    {   // __nsn.size() == 0
                        if (*__b == __psn[0])
                        {
                            ++__b;
                            if (__psn.size() > 1)
                                __trailing_sign = &__psn;
                        }
                        else
                            __neg = true;
                    }
                    else if (*__b == __nsn[0])  // __nsn.size() > 0 &&  __psn.size() == 0
                    {
                        ++__b;
                        __neg = true;
                        if (__nsn.size() > 1)
                            __trailing_sign = &__nsn;
                    }
                }
                else  // sign is required
                {
                    if (*__b == __psn[0])
                    {
                        ++__b;
                        if (__psn.size() > 1)
                            __trailing_sign = &__psn;
                    }
                    else if (*__b == __nsn[0])
                    {
                        ++__b;
                        __neg = true;
                        if (__nsn.size() > 1)
                            __trailing_sign = &__nsn;
                    }
                    else
                    {
                        __err |= ios_base::failbit;
                        return false;
                    }
                }
            }
            break;
        case money_base::symbol:
            {
            bool __more_needed = __trailing_sign ||
                                 (__p < 2)       ||
                                 (__p == 2 && __pat.field[3] != static_cast<char>(money_base::none));
            bool __sb = (__flags & ios_base::showbase) != 0;
            if (__sb || __more_needed)
            {
                typename string_type::const_iterator __sym_space_end = __sym.begin();
                if (__p > 0 && (__pat.field[__p - 1] == money_base::none ||
                                __pat.field[__p - 1] == money_base::space)) {
                    // Match spaces we've already read against spaces at
                    // the beginning of __sym.
                    while (__sym_space_end != __sym.end() &&
                           __ct.is(ctype_base::space, *__sym_space_end))
                        ++__sym_space_end;
                    const size_t __num_spaces = __sym_space_end - __sym.begin();
                    if (__num_spaces > __spaces.size() ||
                        !equal(__spaces.end() - __num_spaces, __spaces.end(),
                               __sym.begin())) {
                        // No match. Put __sym_space_end back at the
                        // beginning of __sym, which will prevent a
                        // match in the next loop.
                        __sym_space_end = __sym.begin();
                    }
                }
                typename string_type::const_iterator __sym_curr_char = __sym_space_end;
                while (__sym_curr_char != __sym.end() && __b != __e &&
                       *__b == *__sym_curr_char) {
                    ++__b;
                    ++__sym_curr_char;
                }
                if (__sb && __sym_curr_char != __sym.end())
                {
                    __err |= ios_base::failbit;
                    return false;
                }
            }
            }
            break;
        case money_base::value:
            {
            unsigned __ng = 0;
            for (; __b != __e; ++__b)
            {
                char_type __c = *__b;
                if (__ct.is(ctype_base::digit, __c))
                {
                    if (__wn == __we)
                        __double_or_nothing(__wb, __wn, __we);
                    *__wn++ = __c;
                    ++__ng;
                }
                else if (__grp.size() > 0 && __ng > 0 && __c == __ts)
                {
                    if (__gn == __ge)
                        __double_or_nothing(__gb, __gn, __ge);
                    *__gn++ = __ng;
                    __ng = 0;
                }
                else
                    break;
            }
            if (__gb.get() != __gn && __ng > 0)
            {
                if (__gn == __ge)
                    __double_or_nothing(__gb, __gn, __ge);
                *__gn++ = __ng;
            }
            if (__fd > 0)
            {
                if (__b == __e || *__b != __dp)
                {
                    __err |= ios_base::failbit;
                    return false;
                }
                for (++__b; __fd > 0; --__fd, ++__b)
                {
                    if (__b == __e || !__ct.is(ctype_base::digit, *__b))
                    {
                        __err |= ios_base::failbit;
                        return false;
                    }
                    if (__wn == __we)
                        __double_or_nothing(__wb, __wn, __we);
                    *__wn++ = *__b;
                }
            }
            if (__wn == __wb.get())
            {
                __err |= ios_base::failbit;
                return false;
            }
            }
            break;
        }
    }
    if (__trailing_sign)
    {
        for (unsigned __i = 1; __i < __trailing_sign->size(); ++__i, ++__b)
        {
            if (__b == __e || *__b != (*__trailing_sign)[__i])
            {
                __err |= ios_base::failbit;
                return false;
            }
        }
    }
    if (__gb.get() != __gn)
    {
        ios_base::iostate __et = ios_base::goodbit;
        __check_grouping(__grp, __gb.get(), __gn, __et);
        if (__et)
        {
            __err |= ios_base::failbit;
            return false;
        }
    }
    return true;
}

template <class _CharT, class _InputIterator>
_InputIterator
money_get<_CharT, _InputIterator>::do_get(iter_type __b, iter_type __e,
                                          bool __intl, ios_base& __iob,
                                          ios_base::iostate& __err,
                                          long double& __v) const
{
    const int __bz = 100;
    char_type __wbuf[__bz];
    unique_ptr<char_type, void(*)(void*)> __wb(__wbuf, __do_nothing);
    char_type* __wn;
    char_type* __we = __wbuf + __bz;
    locale __loc = __iob.getloc();
    const ctype<char_type>& __ct = use_facet<ctype<char_type> >(__loc);
    bool __neg = false;
    if (__do_get(__b, __e, __intl, __loc, __iob.flags(), __err, __neg, __ct,
                 __wb, __wn, __we))
    {
        const char __src[] = "0123456789";
        char_type __atoms[sizeof(__src)-1];
        __ct.widen(__src, __src + (sizeof(__src)-1), __atoms);
        char __nbuf[__bz];
        char* __nc = __nbuf;
        unique_ptr<char, void(*)(void*)> __h(0, free);
        if (__wn - __wb.get() > __bz-2)
        {
            __h.reset((char*)malloc(static_cast<size_t>(__wn - __wb.get() + 2)));
            if (__h.get() == 0)
                __throw_bad_alloc();
            __nc = __h.get();
        }
        if (__neg)
            *__nc++ = '-';
        for (const char_type* __w = __wb.get(); __w < __wn; ++__w, ++__nc)
            *__nc = __src[find(__atoms, _VSTD::end(__atoms), *__w) - __atoms];
        *__nc = char();
        if (sscanf(__nbuf, "%Lf", &__v) != 1)
            __throw_runtime_error("money_get error");
    }
    if (__b == __e)
        __err |= ios_base::eofbit;
    return __b;
}

template <class _CharT, class _InputIterator>
_InputIterator
money_get<_CharT, _InputIterator>::do_get(iter_type __b, iter_type __e,
                                          bool __intl, ios_base& __iob,
                                          ios_base::iostate& __err,
                                          string_type& __v) const
{
    const int __bz = 100;
    char_type __wbuf[__bz];
    unique_ptr<char_type, void(*)(void*)> __wb(__wbuf, __do_nothing);
    char_type* __wn;
    char_type* __we = __wbuf + __bz;
    locale __loc = __iob.getloc();
    const ctype<char_type>& __ct = use_facet<ctype<char_type> >(__loc);
    bool __neg = false;
    if (__do_get(__b, __e, __intl, __loc, __iob.flags(), __err, __neg, __ct,
                 __wb, __wn, __we))
    {
        __v.clear();
        if (__neg)
            __v.push_back(__ct.widen('-'));
        char_type __z = __ct.widen('0');
        char_type* __w;
        for (__w = __wb.get(); __w < __wn-1; ++__w)
            if (*__w != __z)
                break;
        __v.append(__w, __wn);
    }
    if (__b == __e)
        __err |= ios_base::eofbit;
    return __b;
}

_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS money_get<char>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS money_get<wchar_t>)

// money_put

template <class _CharT>
class __money_put
{
protected:
    typedef _CharT                  char_type;
    typedef basic_string<char_type> string_type;

    _LIBCPP_ALWAYS_INLINE __money_put() {}

    static void __gather_info(bool __intl, bool __neg, const locale& __loc,
                              money_base::pattern& __pat, char_type& __dp,
                              char_type& __ts, string& __grp,
                              string_type& __sym, string_type& __sn,
                              int& __fd);
    static void __format(char_type* __mb, char_type*& __mi, char_type*& __me,
                         ios_base::fmtflags __flags,
                         const char_type* __db, const char_type* __de,
                         const ctype<char_type>& __ct, bool __neg,
                         const money_base::pattern& __pat, char_type __dp,
                         char_type __ts, const string& __grp,
                         const string_type& __sym, const string_type& __sn,
                         int __fd);
};

template <class _CharT>
void
__money_put<_CharT>::__gather_info(bool __intl, bool __neg, const locale& __loc,
                                   money_base::pattern& __pat, char_type& __dp,
                                   char_type& __ts, string& __grp,
                                   string_type& __sym, string_type& __sn,
                                   int& __fd)
{
    if (__intl)
    {
        const moneypunct<char_type, true>& __mp =
            use_facet<moneypunct<char_type, true> >(__loc);
        if (__neg)
        {
            __pat = __mp.neg_format();
            __sn = __mp.negative_sign();
        }
        else
        {
            __pat = __mp.pos_format();
            __sn = __mp.positive_sign();
        }
        __dp = __mp.decimal_point();
        __ts = __mp.thousands_sep();
        __grp = __mp.grouping();
        __sym = __mp.curr_symbol();
        __fd = __mp.frac_digits();
    }
    else
    {
        const moneypunct<char_type, false>& __mp =
            use_facet<moneypunct<char_type, false> >(__loc);
        if (__neg)
        {
            __pat = __mp.neg_format();
            __sn = __mp.negative_sign();
        }
        else
        {
            __pat = __mp.pos_format();
            __sn = __mp.positive_sign();
        }
        __dp = __mp.decimal_point();
        __ts = __mp.thousands_sep();
        __grp = __mp.grouping();
        __sym = __mp.curr_symbol();
        __fd = __mp.frac_digits();
    }
}

template <class _CharT>
void
__money_put<_CharT>::__format(char_type* __mb, char_type*& __mi, char_type*& __me,
                              ios_base::fmtflags __flags,
                              const char_type* __db, const char_type* __de,
                              const ctype<char_type>& __ct, bool __neg,
                              const money_base::pattern& __pat, char_type __dp,
                              char_type __ts, const string& __grp,
                              const string_type& __sym, const string_type& __sn,
                              int __fd)
{
    __me = __mb;
    for (unsigned __p = 0; __p < 4; ++__p)
    {
        switch (__pat.field[__p])
        {
        case money_base::none:
            __mi = __me;
            break;
        case money_base::space:
            __mi = __me;
            *__me++ = __ct.widen(' ');
            break;
        case money_base::sign:
            if (!__sn.empty())
                *__me++ = __sn[0];
            break;
        case money_base::symbol:
            if (!__sym.empty() && (__flags & ios_base::showbase))
                __me = _VSTD::copy(__sym.begin(), __sym.end(), __me);
            break;
        case money_base::value:
            {
            // remember start of value so we can reverse it
            char_type* __t = __me;
            // find beginning of digits
            if (__neg)
                ++__db;
            // find end of digits
            const char_type* __d;
            for (__d = __db; __d < __de; ++__d)
                if (!__ct.is(ctype_base::digit, *__d))
                    break;
            // print fractional part
            if (__fd > 0)
            {
                int __f;
                for (__f = __fd; __d > __db && __f > 0; --__f)
                    *__me++ = *--__d;
                char_type __z = __f > 0 ? __ct.widen('0') : char_type();
                for (; __f > 0; --__f)
                    *__me++ = __z;
                *__me++ = __dp;
            }
            // print units part
            if (__d == __db)
            {
                *__me++ = __ct.widen('0');
            }
            else
            {
                unsigned __ng = 0;
                unsigned __ig = 0;
                unsigned __gl = __grp.empty() ? numeric_limits<unsigned>::max()
                                              : static_cast<unsigned>(__grp[__ig]);
                while (__d != __db)
                {
                    if (__ng == __gl)
                    {
                        *__me++ = __ts;
                        __ng = 0;
                        if (++__ig < __grp.size())
                            __gl = __grp[__ig] == numeric_limits<char>::max() ?
                                        numeric_limits<unsigned>::max() :
                                        static_cast<unsigned>(__grp[__ig]);
                    }
                    *__me++ = *--__d;
                    ++__ng;
                }
            }
            // reverse it
            reverse(__t, __me);
            }
            break;
        }
    }
    // print rest of sign, if any
    if (__sn.size() > 1)
        __me = _VSTD::copy(__sn.begin()+1, __sn.end(), __me);
    // set alignment
    if ((__flags & ios_base::adjustfield) == ios_base::left)
        __mi = __me;
    else if ((__flags & ios_base::adjustfield) != ios_base::internal)
        __mi = __mb;
}

_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS __money_put<char>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS __money_put<wchar_t>)

template <class _CharT, class _OutputIterator = ostreambuf_iterator<_CharT> >
class _LIBCPP_TYPE_VIS_ONLY money_put
    : public locale::facet,
      private __money_put<_CharT>
{
public:
    typedef _CharT                  char_type;
    typedef _OutputIterator         iter_type;
    typedef basic_string<char_type> string_type;

    _LIBCPP_ALWAYS_INLINE
    explicit money_put(size_t __refs = 0)
        : locale::facet(__refs) {}

    _LIBCPP_ALWAYS_INLINE
    iter_type put(iter_type __s, bool __intl, ios_base& __iob, char_type __fl,
                  long double __units) const
    {
        return do_put(__s, __intl, __iob, __fl, __units);
    }

    _LIBCPP_ALWAYS_INLINE
    iter_type put(iter_type __s, bool __intl, ios_base& __iob, char_type __fl,
                  const string_type& __digits) const
    {
        return do_put(__s, __intl, __iob, __fl, __digits);
    }

    static locale::id id;

protected:
    _LIBCPP_ALWAYS_INLINE
    ~money_put() {}

    virtual iter_type do_put(iter_type __s, bool __intl, ios_base& __iob,
                             char_type __fl, long double __units) const;
    virtual iter_type do_put(iter_type __s, bool __intl, ios_base& __iob,
                             char_type __fl, const string_type& __digits) const;
};

template <class _CharT, class _OutputIterator>
locale::id
money_put<_CharT, _OutputIterator>::id;

template <class _CharT, class _OutputIterator>
_OutputIterator
money_put<_CharT, _OutputIterator>::do_put(iter_type __s, bool __intl,
                                           ios_base& __iob, char_type __fl,
                                           long double __units) const
{
    // convert to char
    const size_t __bs = 100;
    char __buf[__bs];
    char* __bb = __buf;
    char_type __digits[__bs];
    char_type* __db = __digits;
    size_t __n = static_cast<size_t>(snprintf(__bb, __bs, "%.0Lf", __units));
    unique_ptr<char, void(*)(void*)> __hn(0, free);
    unique_ptr<char_type, void(*)(void*)> __hd(0, free);
    // secure memory for digit storage
    if (__n > __bs-1)
    {
#ifdef _LIBCPP_LOCALE__L_EXTENSIONS
        __n = static_cast<size_t>(asprintf_l(&__bb, _LIBCPP_GET_C_LOCALE, "%.0Lf", __units));
#else
# 3522 "/usr/include/c++/v1/locale" 3
        __n = __asprintf_l(&__bb, __cloc(), "%.0Lf", __units);
#endif
# 3524 "/usr/include/c++/v1/locale" 3
        if (__bb == 0)
            __throw_bad_alloc();
        __hn.reset(__bb);
        __hd.reset((char_type*)malloc(__n * sizeof(char_type)));
        if (__hd == nullptr)
            __throw_bad_alloc();
        __db = __hd.get();
    }
    // gather info
    locale __loc = __iob.getloc();
    const ctype<char_type>& __ct = use_facet<ctype<char_type> >(__loc);
    __ct.widen(__bb, __bb + __n, __db);
    bool __neg = __n > 0 && __bb[0] == '-';
    money_base::pattern __pat;
    char_type __dp;
    char_type __ts;
    string __grp;
    string_type __sym;
    string_type __sn;
    int __fd;
    this->__gather_info(__intl, __neg, __loc, __pat, __dp, __ts, __grp, __sym, __sn, __fd);
    // secure memory for formatting
    char_type __mbuf[__bs];
    char_type* __mb = __mbuf;
    unique_ptr<char_type, void(*)(void*)> __hw(0, free);
    size_t __exn = static_cast<int>(__n) > __fd ?
                   (__n - static_cast<size_t>(__fd)) * 2 + __sn.size() +
                    __sym.size() + static_cast<size_t>(__fd) + 1
                 : __sn.size() + __sym.size() + static_cast<size_t>(__fd) + 2;
    if (__exn > __bs)
    {
        __hw.reset((char_type*)malloc(__exn * sizeof(char_type)));
        __mb = __hw.get();
        if (__mb == 0)
            __throw_bad_alloc();
    }
    // format
    char_type* __mi;
    char_type* __me;
    this->__format(__mb, __mi, __me, __iob.flags(),
                   __db, __db + __n, __ct,
                   __neg, __pat, __dp, __ts, __grp, __sym, __sn, __fd);
    return __pad_and_output(__s, __mb, __mi, __me, __iob, __fl);
}

template <class _CharT, class _OutputIterator>
_OutputIterator
money_put<_CharT, _OutputIterator>::do_put(iter_type __s, bool __intl,
                                           ios_base& __iob, char_type __fl,
                                           const string_type& __digits) const
{
    // gather info
    locale __loc = __iob.getloc();
    const ctype<char_type>& __ct = use_facet<ctype<char_type> >(__loc);
    bool __neg = __digits.size() > 0 && __digits[0] == __ct.widen('-');
    money_base::pattern __pat;
    char_type __dp;
    char_type __ts;
    string __grp;
    string_type __sym;
    string_type __sn;
    int __fd;
    this->__gather_info(__intl, __neg, __loc, __pat, __dp, __ts, __grp, __sym, __sn, __fd);
    // secure memory for formatting
    char_type __mbuf[100];
    char_type* __mb = __mbuf;
    unique_ptr<char_type, void(*)(void*)> __h(0, free);
    size_t __exn = static_cast<int>(__digits.size()) > __fd ?
                   (__digits.size() - static_cast<size_t>(__fd)) * 2 +
                    __sn.size() + __sym.size() + static_cast<size_t>(__fd) + 1
                 : __sn.size() + __sym.size() + static_cast<size_t>(__fd) + 2;
    if (__exn > 100)
    {
        __h.reset((char_type*)malloc(__exn * sizeof(char_type)));
        __mb = __h.get();
        if (__mb == 0)
            __throw_bad_alloc();
    }
    // format
    char_type* __mi;
    char_type* __me;
    this->__format(__mb, __mi, __me, __iob.flags(),
                   __digits.data(), __digits.data() + __digits.size(), __ct,
                   __neg, __pat, __dp, __ts, __grp, __sym, __sn, __fd);
    return __pad_and_output(__s, __mb, __mi, __me, __iob, __fl);
}

_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS money_put<char>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS money_put<wchar_t>)

// messages

class _LIBCPP_TYPE_VIS messages_base
{
public:
    typedef ptrdiff_t catalog;

    _LIBCPP_ALWAYS_INLINE messages_base() {}
};

template <class _CharT>
class _LIBCPP_TYPE_VIS_ONLY messages
    : public locale::facet,
      public messages_base
{
public:
    typedef _CharT               char_type;
    typedef basic_string<_CharT> string_type;

    _LIBCPP_ALWAYS_INLINE
    explicit messages(size_t __refs = 0)
        : locale::facet(__refs) {}

    _LIBCPP_ALWAYS_INLINE
    catalog open(const basic_string<char>& __nm, const locale& __loc) const
    {
        return do_open(__nm, __loc);
    }

    _LIBCPP_ALWAYS_INLINE
    string_type get(catalog __c, int __set, int __msgid,
                    const string_type& __dflt) const
    {
        return do_get(__c, __set, __msgid, __dflt);
    }

    _LIBCPP_ALWAYS_INLINE
    void close(catalog __c) const
    {
        do_close(__c);
    }

    static locale::id id;

protected:
    _LIBCPP_ALWAYS_INLINE
    ~messages() {}

    virtual catalog do_open(const basic_string<char>&, const locale&) const;
    virtual string_type do_get(catalog, int __set, int __msgid,
                               const string_type& __dflt) const;
    virtual void do_close(catalog) const;
};

template <class _CharT>
locale::id
messages<_CharT>::id;

template <class _CharT>
typename messages<_CharT>::catalog
messages<_CharT>::do_open(const basic_string<char>& __nm, const locale&) const
{
#ifdef _WIN32
    return -1;
#else // _WIN32
# 3679 "/usr/include/c++/v1/locale" 3
    catalog __cat = (catalog)catopen(__nm.c_str(), NL_CAT_LOCALE);
    if (__cat != -1)
        __cat = static_cast<catalog>((static_cast<size_t>(__cat) >> 1));
    return __cat;
#endif // _WIN32
# 3684 "/usr/include/c++/v1/locale" 3
}

template <class _CharT>
typename messages<_CharT>::string_type
messages<_CharT>::do_get(catalog __c, int __set, int __msgid,
                         const string_type& __dflt) const
{
#ifdef _WIN32
    return __dflt;
#else // _WIN32
# 3694 "/usr/include/c++/v1/locale" 3
    string __ndflt;
    __narrow_to_utf8<sizeof(char_type)*__CHAR_BIT__>()(back_inserter(__ndflt),
                                                       __dflt.c_str(),
                                                       __dflt.c_str() + __dflt.size());
    if (__c != -1)
        __c <<= 1;
    nl_catd __cat = (nl_catd)__c;
    char* __n = catgets(__cat, __set, __msgid, __ndflt.c_str());
    string_type __w;
    __widen_from_utf8<sizeof(char_type)*__CHAR_BIT__>()(back_inserter(__w),
                                                        __n, __n + strlen(__n));
    return __w;
#endif // _WIN32
# 3707 "/usr/include/c++/v1/locale" 3
}

template <class _CharT>
void
messages<_CharT>::do_close(catalog __c) const
{
#if !defined(_WIN32)
    if (__c != -1)
        __c <<= 1;
    nl_catd __cat = (nl_catd)__c;
    catclose(__cat);
#endif // !_WIN32
# 3719 "/usr/include/c++/v1/locale" 3
}

_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS messages<char>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS messages<wchar_t>)

template <class _CharT>
class _LIBCPP_TYPE_VIS_ONLY messages_byname
    : public messages<_CharT>
{
public:
    typedef messages_base::catalog catalog;
    typedef basic_string<_CharT> string_type;

    _LIBCPP_ALWAYS_INLINE
    explicit messages_byname(const char*, size_t __refs = 0)
        : messages<_CharT>(__refs) {}

    _LIBCPP_ALWAYS_INLINE
    explicit messages_byname(const string&, size_t __refs = 0)
        : messages<_CharT>(__refs) {}

protected:
    _LIBCPP_ALWAYS_INLINE
    ~messages_byname() {}
};

_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS messages_byname<char>)
_LIBCPP_EXTERN_TEMPLATE2(class _LIBCPP_TYPE_VIS messages_byname<wchar_t>)

template<class _Codecvt, class _Elem = wchar_t,
         class _Wide_alloc = allocator<_Elem>,
         class _Byte_alloc = allocator<char> >
class _LIBCPP_TYPE_VIS_ONLY wstring_convert
{
public:
    typedef basic_string<char, char_traits<char>, _Byte_alloc>   byte_string;
    typedef basic_string<_Elem, char_traits<_Elem>, _Wide_alloc> wide_string;
    typedef typename _Codecvt::state_type                        state_type;
    typedef typename wide_string::traits_type::int_type          int_type;

private:
    byte_string __byte_err_string_;
    wide_string __wide_err_string_;
    _Codecvt* __cvtptr_;
    state_type __cvtstate_;
    size_t __cvtcount_;

    wstring_convert(const wstring_convert& __wc);
    wstring_convert& operator=(const wstring_convert& __wc);
public:
    _LIBCPP_EXPLICIT_AFTER_CXX11 wstring_convert(_Codecvt* __pcvt = new _Codecvt);
    wstring_convert(_Codecvt* __pcvt, state_type __state);
    _LIBCPP_EXPLICIT_AFTER_CXX11 wstring_convert(const byte_string& __byte_err,
                    const wide_string& __wide_err = wide_string());
#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES
    wstring_convert(wstring_convert&& __wc);
#endif
# 3776 "/usr/include/c++/v1/locale" 3
    ~wstring_convert();

    _LIBCPP_ALWAYS_INLINE
    wide_string from_bytes(char __byte)
        {return from_bytes(&__byte, &__byte+1);}
    _LIBCPP_ALWAYS_INLINE
    wide_string from_bytes(const char* __ptr)
        {return from_bytes(__ptr, __ptr + char_traits<char>::length(__ptr));}
    _LIBCPP_ALWAYS_INLINE
    wide_string from_bytes(const byte_string& __str)
        {return from_bytes(__str.data(), __str.data() + __str.size());}
    wide_string from_bytes(const char* __first, const char* __last);

    _LIBCPP_ALWAYS_INLINE
    byte_string to_bytes(_Elem __wchar)
        {return to_bytes(&__wchar, &__wchar+1);}
    _LIBCPP_ALWAYS_INLINE
    byte_string to_bytes(const _Elem* __wptr)
        {return to_bytes(__wptr, __wptr + char_traits<_Elem>::length(__wptr));}
    _LIBCPP_ALWAYS_INLINE
    byte_string to_bytes(const wide_string& __wstr)
        {return to_bytes(__wstr.data(), __wstr.data() + __wstr.size());}
    byte_string to_bytes(const _Elem* __first, const _Elem* __last);

    _LIBCPP_ALWAYS_INLINE
    size_t converted() const _NOEXCEPT {return __cvtcount_;}
    _LIBCPP_ALWAYS_INLINE
    state_type state() const {return __cvtstate_;}
};

template<class _Codecvt, class _Elem, class _Wide_alloc, class _Byte_alloc>
inline _LIBCPP_ALWAYS_INLINE
wstring_convert<_Codecvt, _Elem, _Wide_alloc, _Byte_alloc>::
    wstring_convert(_Codecvt* __pcvt)
        : __cvtptr_(__pcvt), __cvtstate_(), __cvtcount_(0)
{
}

template<class _Codecvt, class _Elem, class _Wide_alloc, class _Byte_alloc>
inline _LIBCPP_ALWAYS_INLINE
wstring_convert<_Codecvt, _Elem, _Wide_alloc, _Byte_alloc>::
    wstring_convert(_Codecvt* __pcvt, state_type __state)
        : __cvtptr_(__pcvt), __cvtstate_(__state), __cvtcount_(0)
{
}

template<class _Codecvt, class _Elem, class _Wide_alloc, class _Byte_alloc>
wstring_convert<_Codecvt, _Elem, _Wide_alloc, _Byte_alloc>::
    wstring_convert(const byte_string& __byte_err, const wide_string& __wide_err)
        : __byte_err_string_(__byte_err), __wide_err_string_(__wide_err),
          __cvtstate_(), __cvtcount_(0)
{
    __cvtptr_ = new _Codecvt;
}

#ifndef _LIBCPP_HAS_NO_RVALUE_REFERENCES

template<class _Codecvt, class _Elem, class _Wide_alloc, class _Byte_alloc>
inline _LIBCPP_ALWAYS_INLINE
wstring_convert<_Codecvt, _Elem, _Wide_alloc, _Byte_alloc>::
    wstring_convert(wstring_convert&& __wc)
        : __byte_err_string_(_VSTD::move(__wc.__byte_err_string_)),
          __wide_err_string_(_VSTD::move(__wc.__wide_err_string_)),
          __cvtptr_(__wc.__cvtptr_),
          __cvtstate_(__wc.__cvtstate_), __cvtcount_(__wc.__cvtstate_)
{
    __wc.__cvtptr_ = nullptr;
}

#endif  // _LIBCPP_HAS_NO_RVALUE_REFERENCES
# 3846 "/usr/include/c++/v1/locale" 3

template<class _Codecvt, class _Elem, class _Wide_alloc, class _Byte_alloc>
wstring_convert<_Codecvt, _Elem, _Wide_alloc, _Byte_alloc>::~wstring_convert()
{
    delete __cvtptr_;
}

template<class _Codecvt, class _Elem, class _Wide_alloc, class _Byte_alloc>
typename wstring_convert<_Codecvt, _Elem, _Wide_alloc, _Byte_alloc>::wide_string
wstring_convert<_Codecvt, _Elem, _Wide_alloc, _Byte_alloc>::
    from_bytes(const char* __frm, const char* __frm_end)
{
    __cvtcount_ = 0;
    if (__cvtptr_ != nullptr)
    {
        wide_string __ws(2*(__frm_end - __frm), _Elem());
        if (__frm != __frm_end)
            __ws.resize(__ws.capacity());
        codecvt_base::result __r = codecvt_base::ok;
        state_type __st = __cvtstate_;
        if (__frm != __frm_end)
        {
            _Elem* __to = &__ws[0];
            _Elem* __to_end = __to + __ws.size();
            const char* __frm_nxt;
            do
            {
                _Elem* __to_nxt;
                __r = __cvtptr_->in(__st, __frm, __frm_end, __frm_nxt,
                                          __to, __to_end, __to_nxt);
                __cvtcount_ += __frm_nxt - __frm;
                if (__frm_nxt == __frm)
                {
                    __r = codecvt_base::error;
                }
                else if (__r == codecvt_base::noconv)
                {
                    __ws.resize(__to - &__ws[0]);
                    // This only gets executed if _Elem is char
                    __ws.append((const _Elem*)__frm, (const _Elem*)__frm_end);
                    __frm = __frm_nxt;
                    __r = codecvt_base::ok;
                }
                else if (__r == codecvt_base::ok)
                {
                    __ws.resize(__to_nxt - &__ws[0]);
                    __frm = __frm_nxt;
                }
                else if (__r == codecvt_base::partial)
                {
                    ptrdiff_t __s = __to_nxt - &__ws[0];
                    __ws.resize(2 * __s);
                    __to = &__ws[0] + __s;
                    __to_end = &__ws[0] + __ws.size();
                    __frm = __frm_nxt;
                }
            } while (__r == codecvt_base::partial && __frm_nxt < __frm_end);
        }
        if (__r == codecvt_base::ok)
            return __ws;
    }
#ifndef _LIBCPP_NO_EXCEPTIONS
    if (__wide_err_string_.empty())
        throw range_error("wstring_convert: from_bytes error");
#endif  // _LIBCPP_NO_EXCEPTIONS
# 3911 "/usr/include/c++/v1/locale" 3
    return __wide_err_string_;
}

template<class _Codecvt, class _Elem, class _Wide_alloc, class _Byte_alloc>
typename wstring_convert<_Codecvt, _Elem, _Wide_alloc, _Byte_alloc>::byte_string
wstring_convert<_Codecvt, _Elem, _Wide_alloc, _Byte_alloc>::
    to_bytes(const _Elem* __frm, const _Elem* __frm_end)
{
    __cvtcount_ = 0;
    if (__cvtptr_ != nullptr)
    {
        byte_string __bs(2*(__frm_end - __frm), char());
        if (__frm != __frm_end)
            __bs.resize(__bs.capacity());
        codecvt_base::result __r = codecvt_base::ok;
        state_type __st = __cvtstate_;
        if (__frm != __frm_end)
        {
            char* __to = &__bs[0];
            char* __to_end = __to + __bs.size();
            const _Elem* __frm_nxt;
            do
            {
                char* __to_nxt;
                __r = __cvtptr_->out(__st, __frm, __frm_end, __frm_nxt,
                                           __to, __to_end, __to_nxt);
                __cvtcount_ += __frm_nxt - __frm;
                if (__frm_nxt == __frm)
                {
                    __r = codecvt_base::error;
                }
                else if (__r == codecvt_base::noconv)
                {
                    __bs.resize(__to - &__bs[0]);
                    // This only gets executed if _Elem is char
                    __bs.append((const char*)__frm, (const char*)__frm_end);
                    __frm = __frm_nxt;
                    __r = codecvt_base::ok;
                }
                else if (__r == codecvt_base::ok)
                {
                    __bs.resize(__to_nxt - &__bs[0]);
                    __frm = __frm_nxt;
                }
                else if (__r == codecvt_base::partial)
                {
                    ptrdiff_t __s = __to_nxt - &__bs[0];
                    __bs.resize(2 * __s);
                    __to = &__bs[0] + __s;
                    __to_end = &__bs[0] + __bs.size();
                    __frm = __frm_nxt;
                }
            } while (__r == codecvt_base::partial && __frm_nxt < __frm_end);
        }
        if (__r == codecvt_base::ok)
        {
            size_t __s = __bs.size();
            __bs.resize(__bs.capacity());
            char* __to = &__bs[0] + __s;
            char* __to_end = __to + __bs.size();
            do
            {
                char* __to_nxt;
                __r = __cvtptr_->unshift(__st, __to, __to_end, __to_nxt);
                if (__r == codecvt_base::noconv)
                {
                    __bs.resize(__to - &__bs[0]);
                    __r = codecvt_base::ok;
                }
                else if (__r == codecvt_base::ok)
                {
                    __bs.resize(__to_nxt - &__bs[0]);
                }
                else if (__r == codecvt_base::partial)
                {
                    ptrdiff_t __sp = __to_nxt - &__bs[0];
                    __bs.resize(2 * __sp);
                    __to = &__bs[0] + __sp;
                    __to_end = &__bs[0] + __bs.size();
                }
            } while (__r == codecvt_base::partial);
            if (__r == codecvt_base::ok)
                return __bs;
        }
    }
#ifndef _LIBCPP_NO_EXCEPTIONS
    if (__byte_err_string_.empty())
        throw range_error("wstring_convert: to_bytes error");
#endif  // _LIBCPP_NO_EXCEPTIONS
# 4000 "/usr/include/c++/v1/locale" 3
    return __byte_err_string_;
}

template <class _Codecvt, class _Elem = wchar_t, class _Tr = char_traits<_Elem> >
class _LIBCPP_TYPE_VIS_ONLY wbuffer_convert
    : public basic_streambuf<_Elem, _Tr>
{
public:
    // types:
    typedef _Elem                          char_type;
    typedef _Tr                            traits_type;
    typedef typename traits_type::int_type int_type;
    typedef typename traits_type::pos_type pos_type;
    typedef typename traits_type::off_type off_type;
    typedef typename _Codecvt::state_type  state_type;

private:
    char*       __extbuf_;
    const char* __extbufnext_;
    const char* __extbufend_;
    char __extbuf_min_[8];
    size_t __ebs_;
    char_type* __intbuf_;
    size_t __ibs_;
    streambuf* __bufptr_;
    _Codecvt* __cv_;
    state_type __st_;
    ios_base::openmode __cm_;
    bool __owns_eb_;
    bool __owns_ib_;
    bool __always_noconv_;

    wbuffer_convert(const wbuffer_convert&);
    wbuffer_convert& operator=(const wbuffer_convert&);
public:
    _LIBCPP_EXPLICIT_AFTER_CXX11 wbuffer_convert(streambuf* __bytebuf = 0, 
            _Codecvt* __pcvt = new _Codecvt, state_type __state = state_type());
    ~wbuffer_convert();

    _LIBCPP_INLINE_VISIBILITY
    streambuf* rdbuf() const {return __bufptr_;}
    _LIBCPP_INLINE_VISIBILITY
    streambuf* rdbuf(streambuf* __bytebuf)
    {
        streambuf* __r = __bufptr_;
        __bufptr_ = __bytebuf;
        return __r;
    }

    _LIBCPP_INLINE_VISIBILITY
    state_type state() const {return __st_;}

protected:
    virtual int_type underflow();
    virtual int_type pbackfail(int_type __c = traits_type::eof());
    virtual int_type overflow (int_type __c = traits_type::eof());
    virtual basic_streambuf<char_type, traits_type>* setbuf(char_type* __s,
                                                            streamsize __n);
    virtual pos_type seekoff(off_type __off, ios_base::seekdir __way,
                             ios_base::openmode __wch = ios_base::in | ios_base::out);
    virtual pos_type seekpos(pos_type __sp,
                             ios_base::openmode __wch = ios_base::in | ios_base::out);
    virtual int sync();

private:
    bool __read_mode();
    void __write_mode();
    wbuffer_convert* __close();
};

template <class _Codecvt, class _Elem, class _Tr>
wbuffer_convert<_Codecvt, _Elem, _Tr>::
    wbuffer_convert(streambuf* __bytebuf, _Codecvt* __pcvt, state_type __state)
    : __extbuf_(0),
      __extbufnext_(0),
      __extbufend_(0),
      __ebs_(0),
      __intbuf_(0),
      __ibs_(0),
      __bufptr_(__bytebuf),
      __cv_(__pcvt),
      __st_(__state),
      __cm_(0),
      __owns_eb_(false),
      __owns_ib_(false),
      __always_noconv_(__cv_ ? __cv_->always_noconv() : false)
{
    setbuf(0, 4096);
}

template <class _Codecvt, class _Elem, class _Tr>
wbuffer_convert<_Codecvt, _Elem, _Tr>::~wbuffer_convert()
{
    __close();
    delete __cv_;
    if (__owns_eb_)
        delete [] __extbuf_;
    if (__owns_ib_)
        delete [] __intbuf_;
}

template <class _Codecvt, class _Elem, class _Tr>
typename wbuffer_convert<_Codecvt, _Elem, _Tr>::int_type
wbuffer_convert<_Codecvt, _Elem, _Tr>::underflow()
{
    if (__cv_ == 0 || __bufptr_ == 0)
        return traits_type::eof();
    bool __initial = __read_mode();
    char_type __1buf;
    if (this->gptr() == 0)
        this->setg(&__1buf, &__1buf+1, &__1buf+1);
    const size_t __unget_sz = __initial ? 0 : min<size_t>((this->egptr() - this->eback()) / 2, 4);
    int_type __c = traits_type::eof();
    if (this->gptr() == this->egptr())
    {
        memmove(this->eback(), this->egptr() - __unget_sz, __unget_sz * sizeof(char_type));
        if (__always_noconv_)
        {
            streamsize __nmemb = static_cast<streamsize>(this->egptr() - this->eback() - __unget_sz);
            __nmemb = __bufptr_->sgetn((char*)this->eback() + __unget_sz, __nmemb);
            if (__nmemb != 0)
            {
                this->setg(this->eback(),
                           this->eback() + __unget_sz,
                           this->eback() + __unget_sz + __nmemb);
                __c = *this->gptr();
            }
        }
        else
        {
            memmove(__extbuf_, __extbufnext_, __extbufend_ - __extbufnext_);
            __extbufnext_ = __extbuf_ + (__extbufend_ - __extbufnext_);
            __extbufend_ = __extbuf_ + (__extbuf_ == __extbuf_min_ ? sizeof(__extbuf_min_) : __ebs_);
            streamsize __nmemb = _VSTD::min(static_cast<streamsize>(this->egptr() - this->eback() - __unget_sz),
                                 static_cast<streamsize>(__extbufend_ - __extbufnext_));
            codecvt_base::result __r;
            state_type __svs = __st_;
            streamsize __nr = __bufptr_->sgetn(const_cast<char*>(__extbufnext_), __nmemb);
            if (__nr != 0)
            {
                __extbufend_ = __extbufnext_ + __nr;
                char_type*  __inext;
                __r = __cv_->in(__st_, __extbuf_, __extbufend_, __extbufnext_,
                                       this->eback() + __unget_sz,
                                       this->egptr(), __inext);
                if (__r == codecvt_base::noconv)
                {
                    this->setg((char_type*)__extbuf_, (char_type*)__extbuf_, (char_type*)__extbufend_);
                    __c = *this->gptr();
                }
                else if (__inext != this->eback() + __unget_sz)
                {
                    this->setg(this->eback(), this->eback() + __unget_sz, __inext);
                    __c = *this->gptr();
                }
            }
        }
    }
    else
        __c = *this->gptr();
    if (this->eback() == &__1buf)
        this->setg(0, 0, 0);
    return __c;
}

template <class _Codecvt, class _Elem, class _Tr>
typename wbuffer_convert<_Codecvt, _Elem, _Tr>::int_type
wbuffer_convert<_Codecvt, _Elem, _Tr>::pbackfail(int_type __c)
{
    if (__cv_ != 0 && __bufptr_ != 0 && this->eback() < this->gptr())
    {
        if (traits_type::eq_int_type(__c, traits_type::eof()))
        {
            this->gbump(-1);
            return traits_type::not_eof(__c);
        }
        if (traits_type::eq(traits_type::to_char_type(__c), this->gptr()[-1]))
        {
            this->gbump(-1);
            *this->gptr() = traits_type::to_char_type(__c);
            return __c;
        }
    }
    return traits_type::eof();
}

template <class _Codecvt, class _Elem, class _Tr>
typename wbuffer_convert<_Codecvt, _Elem, _Tr>::int_type
wbuffer_convert<_Codecvt, _Elem, _Tr>::overflow(int_type __c)
{
    if (__cv_ == 0 || __bufptr_ == 0)
        return traits_type::eof();
    __write_mode();
    char_type __1buf;
    char_type* __pb_save = this->pbase();
    char_type* __epb_save = this->epptr();
    if (!traits_type::eq_int_type(__c, traits_type::eof()))
    {
        if (this->pptr() == 0)
            this->setp(&__1buf, &__1buf+1);
        *this->pptr() = traits_type::to_char_type(__c);
        this->pbump(1);
    }
    if (this->pptr() != this->pbase())
    {
        if (__always_noconv_)
        {
            streamsize __nmemb = static_cast<streamsize>(this->pptr() - this->pbase());
            if (__bufptr_->sputn((const char*)this->pbase(), __nmemb) != __nmemb)
                return traits_type::eof();
        }
        else
        {
            char* __extbe = __extbuf_;
            codecvt_base::result __r;
            do
            {
                const char_type* __e;
                __r = __cv_->out(__st_, this->pbase(), this->pptr(), __e,
                                        __extbuf_, __extbuf_ + __ebs_, __extbe);
                if (__e == this->pbase())
                    return traits_type::eof();
                if (__r == codecvt_base::noconv)
                {
                    streamsize __nmemb = static_cast<size_t>(this->pptr() - this->pbase());
                    if (__bufptr_->sputn((const char*)this->pbase(), __nmemb) != __nmemb)
                        return traits_type::eof();
                }
                else if (__r == codecvt_base::ok || __r == codecvt_base::partial)
                {
                    streamsize __nmemb = static_cast<size_t>(__extbe - __extbuf_);
                    if (__bufptr_->sputn(__extbuf_, __nmemb) != __nmemb)
                        return traits_type::eof();
                    if (__r == codecvt_base::partial)
                    {
                        this->setp((char_type*)__e, this->pptr());
                        this->pbump(this->epptr() - this->pbase());
                    }
                }
                else
                    return traits_type::eof();
            } while (__r == codecvt_base::partial);
        }
        this->setp(__pb_save, __epb_save);
    }
    return traits_type::not_eof(__c);
}

template <class _Codecvt, class _Elem, class _Tr>
basic_streambuf<_Elem, _Tr>*
wbuffer_convert<_Codecvt, _Elem, _Tr>::setbuf(char_type* __s, streamsize __n)
{
    this->setg(0, 0, 0);
    this->setp(0, 0);
    if (__owns_eb_)
        delete [] __extbuf_;
    if (__owns_ib_)
        delete [] __intbuf_;
    __ebs_ = __n;
    if (__ebs_ > sizeof(__extbuf_min_))
    {
        if (__always_noconv_ && __s)
        {
            __extbuf_ = (char*)__s;
            __owns_eb_ = false;
        }
        else
        {
            __extbuf_ = new char[__ebs_];
            __owns_eb_ = true;
        }
    }
    else
    {
        __extbuf_ = __extbuf_min_;
        __ebs_ = sizeof(__extbuf_min_);
        __owns_eb_ = false;
    }
    if (!__always_noconv_)
    {
        __ibs_ = max<streamsize>(__n, sizeof(__extbuf_min_));
        if (__s && __ibs_ >= sizeof(__extbuf_min_))
        {
            __intbuf_ = __s;
            __owns_ib_ = false;
        }
        else
        {
            __intbuf_ = new char_type[__ibs_];
            __owns_ib_ = true;
        }
    }
    else
    {
        __ibs_ = 0;
        __intbuf_ = 0;
        __owns_ib_ = false;
    }
    return this;
}

template <class _Codecvt, class _Elem, class _Tr>
typename wbuffer_convert<_Codecvt, _Elem, _Tr>::pos_type
wbuffer_convert<_Codecvt, _Elem, _Tr>::seekoff(off_type __off, ios_base::seekdir __way,
                                        ios_base::openmode __om)
{
    int __width = __cv_->encoding();
    if (__cv_ == 0 || __bufptr_ == 0 || (__width <= 0 && __off != 0) || sync())
        return pos_type(off_type(-1));
    // __width > 0 || __off == 0
    switch (__way)
    {
    case ios_base::beg:
        break;
    case ios_base::cur:
        break;
    case ios_base::end:
        break;
    default:
        return pos_type(off_type(-1));
    }
    pos_type __r = __bufptr_->pubseekoff(__width * __off, __way, __om);
    __r.state(__st_);
    return __r;
}

template <class _Codecvt, class _Elem, class _Tr>
typename wbuffer_convert<_Codecvt, _Elem, _Tr>::pos_type
wbuffer_convert<_Codecvt, _Elem, _Tr>::seekpos(pos_type __sp, ios_base::openmode __wch)
{
    if (__cv_ == 0 || __bufptr_ == 0 || sync())
        return pos_type(off_type(-1));
    if (__bufptr_->pubseekpos(__sp, __wch) == pos_type(off_type(-1)))
        return pos_type(off_type(-1));
    return __sp;
}

template <class _Codecvt, class _Elem, class _Tr>
int
wbuffer_convert<_Codecvt, _Elem, _Tr>::sync()
{
    if (__cv_ == 0 || __bufptr_ == 0)
        return 0;
    if (__cm_ & ios_base::out)
    {
        if (this->pptr() != this->pbase())
            if (overflow() == traits_type::eof())
                return -1;
        codecvt_base::result __r;
        do
        {
            char* __extbe;
            __r = __cv_->unshift(__st_, __extbuf_, __extbuf_ + __ebs_, __extbe);
            streamsize __nmemb = static_cast<streamsize>(__extbe - __extbuf_);
            if (__bufptr_->sputn(__extbuf_, __nmemb) != __nmemb)
                return -1;
        } while (__r == codecvt_base::partial);
        if (__r == codecvt_base::error)
            return -1;
        if (__bufptr_->pubsync())
            return -1;
    }
    else if (__cm_ & ios_base::in)
    {
        off_type __c;
        if (__always_noconv_)
            __c = this->egptr() - this->gptr();
        else
        {
            int __width = __cv_->encoding();
            __c = __extbufend_ - __extbufnext_;
            if (__width > 0)
                __c += __width * (this->egptr() - this->gptr());
            else
            {
                if (this->gptr() != this->egptr())
                {
                    reverse(this->gptr(), this->egptr());
                    codecvt_base::result __r;
                    const char_type* __e = this->gptr();
                    char* __extbe;
                    do
                    {
                        __r = __cv_->out(__st_, __e, this->egptr(), __e,
                                         __extbuf_, __extbuf_ + __ebs_, __extbe);
                        switch (__r)
                        {
                        case codecvt_base::noconv:
                            __c += this->egptr() - this->gptr();
                            break;
                        case codecvt_base::ok:
                        case codecvt_base::partial:
                            __c += __extbe - __extbuf_;
                            break;
                        default:
                            return -1;
                        }
                    } while (__r == codecvt_base::partial);
                }
            }
        }
        if (__bufptr_->pubseekoff(-__c, ios_base::cur, __cm_) == pos_type(off_type(-1)))
            return -1;
        this->setg(0, 0, 0);
        __cm_ = 0;
    }
    return 0;
}

template <class _Codecvt, class _Elem, class _Tr>
bool
wbuffer_convert<_Codecvt, _Elem, _Tr>::__read_mode()
{
    if (!(__cm_ & ios_base::in))
    {
        this->setp(0, 0);
        if (__always_noconv_)
            this->setg((char_type*)__extbuf_,
                       (char_type*)__extbuf_ + __ebs_,
                       (char_type*)__extbuf_ + __ebs_);
        else
            this->setg(__intbuf_, __intbuf_ + __ibs_, __intbuf_ + __ibs_);
        __cm_ = ios_base::in;
        return true;
    }
    return false;
}

template <class _Codecvt, class _Elem, class _Tr>
void
wbuffer_convert<_Codecvt, _Elem, _Tr>::__write_mode()
{
    if (!(__cm_ & ios_base::out))
    {
        this->setg(0, 0, 0);
        if (__ebs_ > sizeof(__extbuf_min_))
        {
            if (__always_noconv_)
                this->setp((char_type*)__extbuf_,
                           (char_type*)__extbuf_ + (__ebs_ - 1));
            else
                this->setp(__intbuf_, __intbuf_ + (__ibs_ - 1));
        }
        else
            this->setp(0, 0);
        __cm_ = ios_base::out;
    }
}

template <class _Codecvt, class _Elem, class _Tr>
wbuffer_convert<_Codecvt, _Elem, _Tr>*
wbuffer_convert<_Codecvt, _Elem, _Tr>::__close()
{
    wbuffer_convert* __rt = 0;
    if (__cv_ != 0 && __bufptr_ != 0)
    {
        __rt = this;
        if ((__cm_ & ios_base::out) && sync())
            __rt = 0;
    }
    return __rt;
}

_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_LOCALE
# 4466 "/usr/include/c++/v1/locale" 3
# 48 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.h" 2
#ifndef gmic_version
#define gmic_version 1584

// Define environment variables.
#ifndef gmic_split_compilation
#define gmic_float
#endif // #ifndef gmic_split_compilation
# 55 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.h"
#ifndef gmic_is_beta
#define gmic_is_beta 0
#endif // #ifndef gmic_is_beta
# 58 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.h"
#ifndef cimg_verbosity
#define cimg_verbosity 1
#endif // #ifndef cimg_verbosity
# 61 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.h"
#if defined(cimg_build)
#define cimg_plugin "examples/gmic.cpp"
#define cimg_include_file "../CImg.h"
#elif defined(gmic_build) // #if defined(cimg_build)
# 65 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.h"
#define cimg_plugin "gmic.cpp"
#define cimg_include_file "./CImg.h"
#endif // #if defined(cimg_build)
# 68 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.h"

#ifdef cimg_include_file
#if 0 /* expanded by -frewrite-includes */
#include cimg_include_file
#endif /* expanded by -frewrite-includes */
# 1 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h" 1
/*
 #
 #  File            : CImg.h
 #                    ( C++ header file )
 #
 #  Description     : The C++ Template Image Processing Toolkit.
 #                    This file is the main component of the CImg Library project.
 #                    ( http://cimg.sourceforge.net )
 #
 #  Project manager : David Tschumperle.
 #                    ( http://tschumperle.users.greyc.fr/ )
 #
 #                    A complete list of contributors is available in file 'README.txt'
 #                    distributed within the CImg package.
 #
 #  Licenses        : This file is 'dual-licensed', you have to choose one
 #                    of the two licenses below to apply.
 #
 #                    CeCILL-C
 #                    The CeCILL-C license is close to the GNU LGPL.
 #                    ( http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html )
 #
 #                or  CeCILL v2.0
 #                    The CeCILL license is compatible with the GNU GPL.
 #                    ( http://www.cecill.info/licences/Licence_CeCILL_V2-en.html )
 #
 #  This software is governed either by the CeCILL or the CeCILL-C license
 #  under French law and abiding by the rules of distribution of free software.
 #  You can  use, modify and or redistribute the software under the terms of
 #  the CeCILL or CeCILL-C licenses as circulated by CEA, CNRS and INRIA
 #  at the following URL: "http://www.cecill.info".
 #
 #  As a counterpart to the access to the source code and  rights to copy,
 #  modify and redistribute granted by the license, users are provided only
 #  with a limited warranty  and the software's author,  the holder of the
 #  economic rights,  and the successive licensors  have only  limited
 #  liability.
 #
 #  In this respect, the user's attention is drawn to the risks associated
 #  with loading,  using,  modifying and/or developing or reproducing the
 #  software by the user in light of its specific status of free software,
 #  that may mean  that it is complicated to manipulate,  and  that  also
 #  therefore means  that it is reserved for developers  and  experienced
 #  professionals having in-depth computer knowledge. Users are therefore
 #  encouraged to load and test the software's suitability as regards their
 #  requirements in conditions enabling the security of their systems and/or
 #  data to be ensured and,  more generally, to use and operate it in the
 #  same conditions as regards security.
 #
 #  The fact that you are presently reading this means that you have had
 #  knowledge of the CeCILL and CeCILL-C licenses and that you accept its terms.
 #
*/

// Set version number of the library.
#ifndef cimg_version
#define cimg_version 158

/*-----------------------------------------------------------
 #
 # Test and possibly auto-set CImg configuration variables
 # and include required headers.
 #
 # If you find that the default configuration variables are
 # not adapted to your system, you can override their values
 # before including the header file "CImg.h"
 # (use the #define directive).
 #
 ------------------------------------------------------------*/

// Include standard C++ headers.
// This is the minimal set of required headers to make CImg-based codes compile.
#if 0 /* expanded by -frewrite-includes */
#include <cstdio>
#endif /* expanded by -frewrite-includes */
# 74 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdlib>
#endif /* expanded by -frewrite-includes */
# 75 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdarg>
#endif /* expanded by -frewrite-includes */
# 76 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstring>
#endif /* expanded by -frewrite-includes */
# 77 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include <cmath>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/c++/v1/cmath" 1 3
// -*- C++ -*-
//===---------------------------- cmath -----------------------------------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is dual licensed under the MIT and the University of Illinois Open
// Source Licenses. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCPP_CMATH
#define _LIBCPP_CMATH

/*
    cmath synopsis

Macros:

    HUGE_VAL
    HUGE_VALF               // C99
    HUGE_VALL               // C99
    INFINITY                // C99
    NAN                     // C99
    FP_INFINITE             // C99
    FP_NAN                  // C99
    FP_NORMAL               // C99
    FP_SUBNORMAL            // C99
    FP_ZERO                 // C99
    FP_FAST_FMA             // C99
    FP_FAST_FMAF            // C99
    FP_FAST_FMAL            // C99
    FP_ILOGB0               // C99
    FP_ILOGBNAN             // C99
    MATH_ERRNO              // C99
    MATH_ERREXCEPT          // C99
    math_errhandling        // C99

namespace std
{

Types:

    float_t                 // C99
    double_t                // C99

// C90

floating_point abs(floating_point x);

floating_point acos (arithmetic x);
float          acosf(float x);
long double    acosl(long double x);

floating_point asin (arithmetic x);
float          asinf(float x);
long double    asinl(long double x);

floating_point atan (arithmetic x);
float          atanf(float x);
long double    atanl(long double x);

floating_point atan2 (arithmetic y, arithmetic x);
float          atan2f(float y, float x);
long double    atan2l(long double y, long double x);

floating_point ceil (arithmetic x);
float          ceilf(float x);
long double    ceill(long double x);

floating_point cos (arithmetic x);
float          cosf(float x);
long double    cosl(long double x);

floating_point cosh (arithmetic x);
float          coshf(float x);
long double    coshl(long double x);

floating_point exp (arithmetic x);
float          expf(float x);
long double    expl(long double x);

floating_point fabs (arithmetic x);
float          fabsf(float x);
long double    fabsl(long double x);

floating_point floor (arithmetic x);
float          floorf(float x);
long double    floorl(long double x);

floating_point fmod (arithmetic x, arithmetic y);
float          fmodf(float x, float y);
long double    fmodl(long double x, long double y);

floating_point frexp (arithmetic value, int* exp);
float          frexpf(float value, int* exp);
long double    frexpl(long double value, int* exp);

floating_point ldexp (arithmetic value, int exp);
float          ldexpf(float value, int exp);
long double    ldexpl(long double value, int exp);

floating_point log (arithmetic x);
float          logf(float x);
long double    logl(long double x);

floating_point log10 (arithmetic x);
float          log10f(float x);
long double    log10l(long double x);

floating_point modf (floating_point value, floating_point* iptr);
float          modff(float value, float* iptr);
long double    modfl(long double value, long double* iptr);

floating_point pow (arithmetic x, arithmetic y);
float          powf(float x, float y);
long double    powl(long double x, long double y);

floating_point sin (arithmetic x);
float          sinf(float x);
long double    sinl(long double x);

floating_point sinh (arithmetic x);
float          sinhf(float x);
long double    sinhl(long double x);

floating_point sqrt (arithmetic x);
float          sqrtf(float x);
long double    sqrtl(long double x);

floating_point tan (arithmetic x);
float          tanf(float x);
long double    tanl(long double x);

floating_point tanh (arithmetic x);
float          tanhf(float x);
long double    tanhl(long double x);

//  C99

bool signbit(arithmetic x);

int fpclassify(arithmetic x);

bool isfinite(arithmetic x);
bool isinf(arithmetic x);
bool isnan(arithmetic x);
bool isnormal(arithmetic x);

bool isgreater(arithmetic x, arithmetic y);
bool isgreaterequal(arithmetic x, arithmetic y);
bool isless(arithmetic x, arithmetic y);
bool islessequal(arithmetic x, arithmetic y);
bool islessgreater(arithmetic x, arithmetic y);
bool isunordered(arithmetic x, arithmetic y);

floating_point acosh (arithmetic x);
float          acoshf(float x);
long double    acoshl(long double x);

floating_point asinh (arithmetic x);
float          asinhf(float x);
long double    asinhl(long double x);

floating_point atanh (arithmetic x);
float          atanhf(float x);
long double    atanhl(long double x);

floating_point cbrt (arithmetic x);
float          cbrtf(float x);
long double    cbrtl(long double x);

floating_point copysign (arithmetic x, arithmetic y);
float          copysignf(float x, float y);
long double    copysignl(long double x, long double y);

floating_point erf (arithmetic x);
float          erff(float x);
long double    erfl(long double x);

floating_point erfc (arithmetic x);
float          erfcf(float x);
long double    erfcl(long double x);

floating_point exp2 (arithmetic x);
float          exp2f(float x);
long double    exp2l(long double x);

floating_point expm1 (arithmetic x);
float          expm1f(float x);
long double    expm1l(long double x);

floating_point fdim (arithmetic x, arithmetic y);
float          fdimf(float x, float y);
long double    fdiml(long double x, long double y);

floating_point fma (arithmetic x, arithmetic y, arithmetic z);
float          fmaf(float x, float y, float z);
long double    fmal(long double x, long double y, long double z);

floating_point fmax (arithmetic x, arithmetic y);
float          fmaxf(float x, float y);
long double    fmaxl(long double x, long double y);

floating_point fmin (arithmetic x, arithmetic y);
float          fminf(float x, float y);
long double    fminl(long double x, long double y);

floating_point hypot (arithmetic x, arithmetic y);
float          hypotf(float x, float y);
long double    hypotl(long double x, long double y);

int ilogb (arithmetic x);
int ilogbf(float x);
int ilogbl(long double x);

floating_point lgamma (arithmetic x);
float          lgammaf(float x);
long double    lgammal(long double x);

long long llrint (arithmetic x);
long long llrintf(float x);
long long llrintl(long double x);

long long llround (arithmetic x);
long long llroundf(float x);
long long llroundl(long double x);

floating_point log1p (arithmetic x);
float          log1pf(float x);
long double    log1pl(long double x);

floating_point log2 (arithmetic x);
float          log2f(float x);
long double    log2l(long double x);

floating_point logb (arithmetic x);
float          logbf(float x);
long double    logbl(long double x);

long lrint (arithmetic x);
long lrintf(float x);
long lrintl(long double x);

long lround (arithmetic x);
long lroundf(float x);
long lroundl(long double x);

double      nan (const char* str);
float       nanf(const char* str);
long double nanl(const char* str);

floating_point nearbyint (arithmetic x);
float          nearbyintf(float x);
long double    nearbyintl(long double x);

floating_point nextafter (arithmetic x, arithmetic y);
float          nextafterf(float x, float y);
long double    nextafterl(long double x, long double y);

floating_point nexttoward (arithmetic x, long double y);
float          nexttowardf(float x, long double y);
long double    nexttowardl(long double x, long double y);

floating_point remainder (arithmetic x, arithmetic y);
float          remainderf(float x, float y);
long double    remainderl(long double x, long double y);

floating_point remquo (arithmetic x, arithmetic y, int* pquo);
float          remquof(float x, float y, int* pquo);
long double    remquol(long double x, long double y, int* pquo);

floating_point rint (arithmetic x);
float          rintf(float x);
long double    rintl(long double x);

floating_point round (arithmetic x);
float          roundf(float x);
long double    roundl(long double x);

floating_point scalbln (arithmetic x, long ex);
float          scalblnf(float x, long ex);
long double    scalblnl(long double x, long ex);

floating_point scalbn (arithmetic x, int ex);
float          scalbnf(float x, int ex);
long double    scalbnl(long double x, int ex);

floating_point tgamma (arithmetic x);
float          tgammaf(float x);
long double    tgammal(long double x);

floating_point trunc (arithmetic x);
float          truncf(float x);
long double    truncl(long double x);

}  // std

*/

#if 0 /* expanded by -frewrite-includes */
#include <__config>
#endif /* expanded by -frewrite-includes */
# 301 "/usr/include/c++/v1/cmath" 3
#if 0 /* expanded by -frewrite-includes */
#include <math.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/math.h" 1 3 4
/*
 * ====================================================
 * Copyright (C) 1993 by Sun Microsystems, Inc. All rights reserved.
 *
 * Developed at SunPro, a Sun Microsystems, Inc. business.
 * Permission to use, copy, modify, and distribute this
 * software is freely granted, provided that this notice
 * is preserved.
 * ====================================================
 */

/*
 * from: @(#)fdlibm.h 5.1 93/09/24
 * $FreeBSD: head/lib/msun/src/math.h 271651 2014-09-15 23:21:57Z kargl $
 */

#ifndef _MATH_H_
#define	_MATH_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 21 "/usr/include/math.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 22 "/usr/include/math.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <machine/_limits.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/machine/_limits.h" 1 3 4
/*-
 * This file is in the public domain.
 */
/* $FreeBSD: head/sys/amd64/include/_limits.h 232262 2012-02-28 18:24:28Z tijl $ */

#if 0 /* expanded by -frewrite-includes */
#include <x86/_limits.h>
#endif /* expanded by -frewrite-includes */
# 7 "/usr/include/machine/_limits.h" 3 4
# 23 "/usr/include/math.h" 2 3 4

/*
 * ANSI/POSIX
 */
extern const union __infinity_un {
	unsigned char	__uc[8];
	double		__ud;
} __infinity;

extern const union __nan_un {
	unsigned char	__uc[sizeof(float)];
	float		__uf;
} __nan;

#if __GNUC_PREREQ__(3, 3) || (defined(__INTEL_COMPILER) && __INTEL_COMPILER >= 800)
#define	__MATH_BUILTIN_CONSTANTS
#endif
# 40 "/usr/include/math.h" 3 4

#if __GNUC_PREREQ__(3, 0) && !defined(__INTEL_COMPILER)
#define	__MATH_BUILTIN_RELOPS
#endif
# 44 "/usr/include/math.h" 3 4

#ifdef __MATH_BUILTIN_CONSTANTS
#define	HUGE_VAL	__builtin_huge_val()
#else
# 48 "/usr/include/math.h" 3 4
#define	HUGE_VAL	(__infinity.__ud)
#endif
# 50 "/usr/include/math.h" 3 4

#if __ISO_C_VISIBLE >= 1999
#define	FP_ILOGB0	(-__INT_MAX)
#define	FP_ILOGBNAN	__INT_MAX

#ifdef __MATH_BUILTIN_CONSTANTS
#define	HUGE_VALF	__builtin_huge_valf()
#define	HUGE_VALL	__builtin_huge_vall()
#define	INFINITY	__builtin_inff()
#define	NAN		__builtin_nanf("")
#else
# 61 "/usr/include/math.h" 3 4
#define	HUGE_VALF	(float)HUGE_VAL
#define	HUGE_VALL	(long double)HUGE_VAL
#define	INFINITY	HUGE_VALF
#define	NAN		(__nan.__uf)
#endif /* __MATH_BUILTIN_CONSTANTS */
# 66 "/usr/include/math.h" 3 4

#define	MATH_ERRNO	1
#define	MATH_ERREXCEPT	2
#define	math_errhandling	MATH_ERREXCEPT

#define	FP_FAST_FMAF	1

/* Symbolic constants to classify floating point numbers. */
#define	FP_INFINITE	0x01
#define	FP_NAN		0x02
#define	FP_NORMAL	0x04
#define	FP_SUBNORMAL	0x08
#define	FP_ZERO		0x10

#if (__STDC_VERSION__ >= 201112L && defined(__clang__)) || \
    __has_extension(c_generic_selections)
#define	__fp_type_select(x, f, d, ld) _Generic((x),			\
    float: f(x),							\
    double: d(x),							\
    long double: ld(x),							\
    volatile float: f(x),						\
    volatile double: d(x),						\
    volatile long double: ld(x),					\
    volatile const float: f(x),						\
    volatile const double: d(x),					\
    volatile const long double: ld(x),					\
    const float: f(x),							\
    const double: d(x),							\
    const long double: ld(x))
#elif __GNUC_PREREQ__(3, 1) && !defined(__cplusplus)
# 96 "/usr/include/math.h" 3 4
#define	__fp_type_select(x, f, d, ld) __builtin_choose_expr(		\
    __builtin_types_compatible_p(__typeof(x), long double), ld(x),	\
    __builtin_choose_expr(						\
    __builtin_types_compatible_p(__typeof(x), double), d(x),		\
    __builtin_choose_expr(						\
    __builtin_types_compatible_p(__typeof(x), float), f(x), (void)0)))
#else
# 103 "/usr/include/math.h" 3 4
#define	 __fp_type_select(x, f, d, ld)					\
    ((sizeof(x) == sizeof(float)) ? f(x)				\
    : (sizeof(x) == sizeof(double)) ? d(x)				\
    : ld(x))
#endif
# 108 "/usr/include/math.h" 3 4

#define	fpclassify(x) \
	__fp_type_select(x, __fpclassifyf, __fpclassifyd, __fpclassifyl)
#define	isfinite(x) __fp_type_select(x, __isfinitef, __isfinite, __isfinitel)
#define	isinf(x) __fp_type_select(x, __isinff, __isinf, __isinfl)
#define	isnan(x) \
	__fp_type_select(x, __inline_isnanf, __inline_isnan, __inline_isnanl)
#define	isnormal(x) __fp_type_select(x, __isnormalf, __isnormal, __isnormall)

#ifdef __MATH_BUILTIN_RELOPS
#define	isgreater(x, y)		__builtin_isgreater((x), (y))
#define	isgreaterequal(x, y)	__builtin_isgreaterequal((x), (y))
#define	isless(x, y)		__builtin_isless((x), (y))
#define	islessequal(x, y)	__builtin_islessequal((x), (y))
#define	islessgreater(x, y)	__builtin_islessgreater((x), (y))
#define	isunordered(x, y)	__builtin_isunordered((x), (y))
#else
# 125 "/usr/include/math.h" 3 4
#define	isgreater(x, y)		(!isunordered((x), (y)) && (x) > (y))
#define	isgreaterequal(x, y)	(!isunordered((x), (y)) && (x) >= (y))
#define	isless(x, y)		(!isunordered((x), (y)) && (x) < (y))
#define	islessequal(x, y)	(!isunordered((x), (y)) && (x) <= (y))
#define	islessgreater(x, y)	(!isunordered((x), (y)) && \
					((x) > (y) || (y) > (x)))
#define	isunordered(x, y)	(isnan(x) || isnan(y))
#endif /* __MATH_BUILTIN_RELOPS */
# 133 "/usr/include/math.h" 3 4

#define	signbit(x) __fp_type_select(x, __signbitf, __signbit, __signbitl)

typedef	__double_t	double_t;
typedef	__float_t	float_t;
#endif /* __ISO_C_VISIBLE >= 1999 */
# 139 "/usr/include/math.h" 3 4

/*
 * XOPEN/SVID
 */
#if __BSD_VISIBLE || __XSI_VISIBLE
#define	M_E		2.7182818284590452354	/* e */
#define	M_LOG2E		1.4426950408889634074	/* log 2e */
#define	M_LOG10E	0.43429448190325182765	/* log 10e */
#define	M_LN2		0.69314718055994530942	/* log e2 */
#define	M_LN10		2.30258509299404568402	/* log e10 */
#define	M_PI		3.14159265358979323846	/* pi */
#define	M_PI_2		1.57079632679489661923	/* pi/2 */
#define	M_PI_4		0.78539816339744830962	/* pi/4 */
#define	M_1_PI		0.31830988618379067154	/* 1/pi */
#define	M_2_PI		0.63661977236758134308	/* 2/pi */
#define	M_2_SQRTPI	1.12837916709551257390	/* 2/sqrt(pi) */
#define	M_SQRT2		1.41421356237309504880	/* sqrt(2) */
#define	M_SQRT1_2	0.70710678118654752440	/* 1/sqrt(2) */

#define	MAXFLOAT	((float)3.40282346638528860e+38)
extern int signgam;
#endif /* __BSD_VISIBLE || __XSI_VISIBLE */
# 161 "/usr/include/math.h" 3 4

#if __BSD_VISIBLE
#if 0
/* Old value from 4.4BSD-Lite math.h; this is probably better. */
#define	HUGE		HUGE_VAL
#else
# 167 "/usr/include/math.h" 3 4
#define	HUGE		MAXFLOAT
#endif
# 169 "/usr/include/math.h" 3 4
#endif /* __BSD_VISIBLE */
# 170 "/usr/include/math.h" 3 4

/*
 * Most of these functions depend on the rounding mode and have the side
 * effect of raising floating-point exceptions, so they are not declared
 * as __pure2.  In C99, FENV_ACCESS affects the purity of these functions.
 */
__BEGIN_DECLS
/*
 * ANSI/POSIX
 */
int	__fpclassifyd(double) __pure2;
int	__fpclassifyf(float) __pure2;
int	__fpclassifyl(long double) __pure2;
int	__isfinitef(float) __pure2;
int	__isfinite(double) __pure2;
int	__isfinitel(long double) __pure2;
int	__isinff(float) __pure2;
int	__isinf(double) __pure2;
int	__isinfl(long double) __pure2;
int	__isnormalf(float) __pure2;
int	__isnormal(double) __pure2;
int	__isnormall(long double) __pure2;
int	__signbit(double) __pure2;
int	__signbitf(float) __pure2;
int	__signbitl(long double) __pure2;

static __inline int
__inline_isnan(__const double __x)
{

	return (__x != __x);
}

static __inline int
__inline_isnanf(__const float __x)
{

	return (__x != __x);
}

static __inline int
__inline_isnanl(__const long double __x)
{

	return (__x != __x);
}

/*
 * Version 2 of the Single UNIX Specification (UNIX98) defined isnan() and
 * isinf() as functions taking double.  C99, and the subsequent POSIX revisions
 * (SUSv3, POSIX.1-2001, define it as a macro that accepts any real floating
 * point type.  If we are targeting SUSv2 and C99 or C11 (or C++11) then we
 * expose the newer definition, assuming that the language spec takes
 * precedence over the operating system interface spec.
 */
#if	__XSI_VISIBLE > 0 && __XSI_VISIBLE < 600 && __ISO_C_VISIBLE < 1999
#undef isinf
#undef isnan
int	isinf(double);
int	isnan(double);
#endif
# 231 "/usr/include/math.h" 3 4

double	acos(double);
double	asin(double);
double	atan(double);
double	atan2(double, double);
double	cos(double);
double	sin(double);
double	tan(double);

double	cosh(double);
double	sinh(double);
double	tanh(double);

double	exp(double);
double	frexp(double, int *);	/* fundamentally !__pure2 */
double	ldexp(double, int);
double	log(double);
double	log10(double);
double	modf(double, double *);	/* fundamentally !__pure2 */

double	pow(double, double);
double	sqrt(double);

double	ceil(double);
double	fabs(double) __pure2;
double	floor(double);
double	fmod(double, double);

/*
 * These functions are not in C90.
 */
#if __BSD_VISIBLE || __ISO_C_VISIBLE >= 1999 || __XSI_VISIBLE
double	acosh(double);
double	asinh(double);
double	atanh(double);
double	cbrt(double);
double	erf(double);
double	erfc(double);
double	exp2(double);
double	expm1(double);
double	fma(double, double, double);
double	hypot(double, double);
int	ilogb(double) __pure2;
double	lgamma(double);
long long llrint(double);
long long llround(double);
double	log1p(double);
double	log2(double);
double	logb(double);
long	lrint(double);
long	lround(double);
double	nan(const char *) __pure2;
double	nextafter(double, double);
double	remainder(double, double);
double	remquo(double, double, int *);
double	rint(double);
#endif /* __BSD_VISIBLE || __ISO_C_VISIBLE >= 1999 || __XSI_VISIBLE */
# 288 "/usr/include/math.h" 3 4

#if __BSD_VISIBLE || __XSI_VISIBLE
double	j0(double);
double	j1(double);
double	jn(int, double);
double	y0(double);
double	y1(double);
double	yn(int, double);

#if __XSI_VISIBLE <= 500 || __BSD_VISIBLE
double	gamma(double);
#endif
# 300 "/usr/include/math.h" 3 4

#if __XSI_VISIBLE <= 600 || __BSD_VISIBLE
double	scalb(double, double);
#endif
# 304 "/usr/include/math.h" 3 4
#endif /* __BSD_VISIBLE || __XSI_VISIBLE */
# 305 "/usr/include/math.h" 3 4

#if __BSD_VISIBLE || __ISO_C_VISIBLE >= 1999
double	copysign(double, double) __pure2;
double	fdim(double, double);
double	fmax(double, double) __pure2;
double	fmin(double, double) __pure2;
double	nearbyint(double);
double	round(double);
double	scalbln(double, long);
double	scalbn(double, int);
double	tgamma(double);
double	trunc(double);
#endif
# 318 "/usr/include/math.h" 3 4

/*
 * BSD math library entry points
 */
#if __BSD_VISIBLE
double	drem(double, double);
int	finite(double) __pure2;
int	isnanf(float) __pure2;

/*
 * Reentrant version of gamma & lgamma; passes signgam back by reference
 * as the second argument; user must allocate space for signgam.
 */
double	gamma_r(double, int *);
double	lgamma_r(double, int *);

/*
 * IEEE Test Vector
 */
double	significand(double);
#endif /* __BSD_VISIBLE */
# 339 "/usr/include/math.h" 3 4

/* float versions of ANSI/POSIX functions */
#if __ISO_C_VISIBLE >= 1999
float	acosf(float);
float	asinf(float);
float	atanf(float);
float	atan2f(float, float);
float	cosf(float);
float	sinf(float);
float	tanf(float);

float	coshf(float);
float	sinhf(float);
float	tanhf(float);

float	exp2f(float);
float	expf(float);
float	expm1f(float);
float	frexpf(float, int *);	/* fundamentally !__pure2 */
int	ilogbf(float) __pure2;
float	ldexpf(float, int);
float	log10f(float);
float	log1pf(float);
float	log2f(float);
float	logf(float);
float	modff(float, float *);	/* fundamentally !__pure2 */

float	powf(float, float);
float	sqrtf(float);

float	ceilf(float);
float	fabsf(float) __pure2;
float	floorf(float);
float	fmodf(float, float);
float	roundf(float);

float	erff(float);
float	erfcf(float);
float	hypotf(float, float);
float	lgammaf(float);
float	tgammaf(float);

float	acoshf(float);
float	asinhf(float);
float	atanhf(float);
float	cbrtf(float);
float	logbf(float);
float	copysignf(float, float) __pure2;
long long llrintf(float);
long long llroundf(float);
long	lrintf(float);
long	lroundf(float);
float	nanf(const char *) __pure2;
float	nearbyintf(float);
float	nextafterf(float, float);
float	remainderf(float, float);
float	remquof(float, float, int *);
float	rintf(float);
float	scalblnf(float, long);
float	scalbnf(float, int);
float	truncf(float);

float	fdimf(float, float);
float	fmaf(float, float, float);
float	fmaxf(float, float) __pure2;
float	fminf(float, float) __pure2;
#endif
# 406 "/usr/include/math.h" 3 4

/*
 * float versions of BSD math library entry points
 */
#if __BSD_VISIBLE
float	dremf(float, float);
int	finitef(float) __pure2;
float	gammaf(float);
float	j0f(float);
float	j1f(float);
float	jnf(int, float);
float	scalbf(float, float);
float	y0f(float);
float	y1f(float);
float	ynf(int, float);

/*
 * Float versions of reentrant version of gamma & lgamma; passes
 * signgam back by reference as the second argument; user must
 * allocate space for signgam.
 */
float	gammaf_r(float, int *);
float	lgammaf_r(float, int *);

/*
 * float version of IEEE Test Vector
 */
float	significandf(float);
#endif	/* __BSD_VISIBLE */
# 435 "/usr/include/math.h" 3 4

/*
 * long double versions of ISO/POSIX math functions
 */
#if __ISO_C_VISIBLE >= 1999
long double	acoshl(long double);
long double	acosl(long double);
long double	asinhl(long double);
long double	asinl(long double);
long double	atan2l(long double, long double);
long double	atanhl(long double);
long double	atanl(long double);
long double	cbrtl(long double);
long double	ceill(long double);
long double	copysignl(long double, long double) __pure2;
long double	coshl(long double);
long double	cosl(long double);
long double	erfcl(long double);
long double	erfl(long double);
long double	exp2l(long double);
long double	expl(long double);
long double	expm1l(long double);
long double	fabsl(long double) __pure2;
long double	fdiml(long double, long double);
long double	floorl(long double);
long double	fmal(long double, long double, long double);
long double	fmaxl(long double, long double) __pure2;
long double	fminl(long double, long double) __pure2;
long double	fmodl(long double, long double);
long double	frexpl(long double value, int *); /* fundamentally !__pure2 */
long double	hypotl(long double, long double);
int		ilogbl(long double) __pure2;
long double	ldexpl(long double, int);
long double	lgammal(long double);
long long	llrintl(long double);
long long	llroundl(long double);
long double	log10l(long double);
long double	log1pl(long double);
long double	log2l(long double);
long double	logbl(long double);
long double	logl(long double);
long		lrintl(long double);
long		lroundl(long double);
long double	modfl(long double, long double *); /* fundamentally !__pure2 */
long double	nanl(const char *) __pure2;
long double	nearbyintl(long double);
long double	nextafterl(long double, long double);
double		nexttoward(double, long double);
float		nexttowardf(float, long double);
long double	nexttowardl(long double, long double);
long double	powl(long double, long double);
long double	remainderl(long double, long double);
long double	remquol(long double, long double, int *);
long double	rintl(long double);
long double	roundl(long double);
long double	scalblnl(long double, long);
long double	scalbnl(long double, int);
long double	sinhl(long double);
long double	sinl(long double);
long double	sqrtl(long double);
long double	tanhl(long double);
long double	tanl(long double);
long double	tgammal(long double);
long double	truncl(long double);
#endif /* __ISO_C_VISIBLE >= 1999 */
# 500 "/usr/include/math.h" 3 4

#if __BSD_VISIBLE
long double	lgammal_r(long double, int *);
#endif
# 504 "/usr/include/math.h" 3 4

__END_DECLS

#endif /* !_MATH_H_ */
# 508 "/usr/include/math.h" 3 4
# 302 "/usr/include/c++/v1/cmath" 2 3
#if 0 /* expanded by -frewrite-includes */
#include <type_traits>
#endif /* expanded by -frewrite-includes */
# 303 "/usr/include/c++/v1/cmath" 3

#ifdef _LIBCPP_MSVCRT
#if 0 /* expanded by -frewrite-includes */
#include "support/win32/math_win32.h"
#endif /* expanded by -frewrite-includes */
# 306 "/usr/include/c++/v1/cmath" 3
#endif
# 307 "/usr/include/c++/v1/cmath" 3

#if !defined(_LIBCPP_HAS_NO_PRAGMA_SYSTEM_HEADER)
#if 0 /* expanded by -frewrite-includes */
#pragma GCC system_header
#endif /* expanded by -frewrite-includes */
# 310 "/usr/include/c++/v1/cmath" 3
#endif
# 311 "/usr/include/c++/v1/cmath" 3

// signbit

#ifdef signbit

template <class _A1>
_LIBCPP_ALWAYS_INLINE
bool
__libcpp_signbit(_A1 __x) _NOEXCEPT
{
    return signbit(__x);
}

#undef signbit

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_arithmetic<_A1>::value, bool>::type
signbit(_A1 __x) _NOEXCEPT
{
    return __libcpp_signbit((typename std::__promote<_A1>::type)__x);
}

#endif  // signbit
# 335 "/usr/include/c++/v1/cmath" 3

// fpclassify

#ifdef fpclassify

template <class _A1>
_LIBCPP_ALWAYS_INLINE
int
__libcpp_fpclassify(_A1 __x) _NOEXCEPT
{
    return fpclassify(__x);
}

#undef fpclassify

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_arithmetic<_A1>::value, int>::type
fpclassify(_A1 __x) _NOEXCEPT
{
    return __libcpp_fpclassify((typename std::__promote<_A1>::type)__x);
}

#endif  // fpclassify
# 359 "/usr/include/c++/v1/cmath" 3

// isfinite

#ifdef isfinite

template <class _A1>
_LIBCPP_ALWAYS_INLINE
bool
__libcpp_isfinite(_A1 __x) _NOEXCEPT
{
    return isfinite(__x);
}

#undef isfinite

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_arithmetic<_A1>::value, bool>::type
isfinite(_A1 __x) _NOEXCEPT
{
    return __libcpp_isfinite((typename std::__promote<_A1>::type)__x);
}

#endif  // isfinite
# 383 "/usr/include/c++/v1/cmath" 3

// isinf

#ifdef isinf

template <class _A1>
_LIBCPP_ALWAYS_INLINE
bool
__libcpp_isinf(_A1 __x) _NOEXCEPT
{
    return isinf(__x);
}

#undef isinf

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_arithmetic<_A1>::value, bool>::type
isinf(_A1 __x) _NOEXCEPT
{
    return __libcpp_isinf((typename std::__promote<_A1>::type)__x);
}

#endif  // isinf
# 407 "/usr/include/c++/v1/cmath" 3

// isnan

#ifdef isnan

template <class _A1>
_LIBCPP_ALWAYS_INLINE
bool
__libcpp_isnan(_A1 __x) _NOEXCEPT
{
    return isnan(__x);
}

#undef isnan

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_arithmetic<_A1>::value, bool>::type
isnan(_A1 __x) _NOEXCEPT
{
    return __libcpp_isnan((typename std::__promote<_A1>::type)__x);
}

#endif  // isnan
# 431 "/usr/include/c++/v1/cmath" 3

// isnormal

#ifdef isnormal

template <class _A1>
_LIBCPP_ALWAYS_INLINE
bool
__libcpp_isnormal(_A1 __x) _NOEXCEPT
{
    return isnormal(__x);
}

#undef isnormal

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if<std::is_arithmetic<_A1>::value, bool>::type
isnormal(_A1 __x) _NOEXCEPT
{
    return __libcpp_isnormal((typename std::__promote<_A1>::type)__x);
}

#endif  // isnormal
# 455 "/usr/include/c++/v1/cmath" 3

// isgreater

#ifdef isgreater

template <class _A1, class _A2>
_LIBCPP_ALWAYS_INLINE
bool
__libcpp_isgreater(_A1 __x, _A2 __y) _NOEXCEPT
{
    return isgreater(__x, __y);
}

#undef isgreater

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    bool
>::type
isgreater(_A1 __x, _A2 __y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type type;
    return __libcpp_isgreater((type)__x, (type)__y);
}

#endif  // isgreater
# 485 "/usr/include/c++/v1/cmath" 3

// isgreaterequal

#ifdef isgreaterequal

template <class _A1, class _A2>
_LIBCPP_ALWAYS_INLINE
bool
__libcpp_isgreaterequal(_A1 __x, _A2 __y) _NOEXCEPT
{
    return isgreaterequal(__x, __y);
}

#undef isgreaterequal

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    bool
>::type
isgreaterequal(_A1 __x, _A2 __y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type type;
    return __libcpp_isgreaterequal((type)__x, (type)__y);
}

#endif  // isgreaterequal
# 515 "/usr/include/c++/v1/cmath" 3

// isless

#ifdef isless

template <class _A1, class _A2>
_LIBCPP_ALWAYS_INLINE
bool
__libcpp_isless(_A1 __x, _A2 __y) _NOEXCEPT
{
    return isless(__x, __y);
}

#undef isless

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    bool
>::type
isless(_A1 __x, _A2 __y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type type;
    return __libcpp_isless((type)__x, (type)__y);
}

#endif  // isless
# 545 "/usr/include/c++/v1/cmath" 3

// islessequal

#ifdef islessequal

template <class _A1, class _A2>
_LIBCPP_ALWAYS_INLINE
bool
__libcpp_islessequal(_A1 __x, _A2 __y) _NOEXCEPT
{
    return islessequal(__x, __y);
}

#undef islessequal

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    bool
>::type
islessequal(_A1 __x, _A2 __y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type type;
    return __libcpp_islessequal((type)__x, (type)__y);
}

#endif  // islessequal
# 575 "/usr/include/c++/v1/cmath" 3

// islessgreater

#ifdef islessgreater

template <class _A1, class _A2>
_LIBCPP_ALWAYS_INLINE
bool
__libcpp_islessgreater(_A1 __x, _A2 __y) _NOEXCEPT
{
    return islessgreater(__x, __y);
}

#undef islessgreater

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    bool
>::type
islessgreater(_A1 __x, _A2 __y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type type;
    return __libcpp_islessgreater((type)__x, (type)__y);
}

#endif  // islessgreater
# 605 "/usr/include/c++/v1/cmath" 3

// isunordered

#ifdef isunordered

template <class _A1, class _A2>
_LIBCPP_ALWAYS_INLINE
bool
__libcpp_isunordered(_A1 __x, _A2 __y) _NOEXCEPT
{
    return isunordered(__x, __y);
}

#undef isunordered

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename std::enable_if
<
    std::is_arithmetic<_A1>::value &&
    std::is_arithmetic<_A2>::value,
    bool
>::type
isunordered(_A1 __x, _A2 __y) _NOEXCEPT
{
    typedef typename std::__promote<_A1, _A2>::type type;
    return __libcpp_isunordered((type)__x, (type)__y);
}

#endif  // isunordered
# 635 "/usr/include/c++/v1/cmath" 3

_LIBCPP_BEGIN_NAMESPACE_STD

using ::signbit;
using ::fpclassify;
using ::isfinite;
using ::isinf;
using ::isnan;
using ::isnormal;
using ::isgreater;
using ::isgreaterequal;
using ::isless;
using ::islessequal;
using ::islessgreater;
using ::isunordered;
using ::isunordered;

using ::float_t;
using ::double_t;

// abs

#if !defined(_AIX)
inline _LIBCPP_INLINE_VISIBILITY
float
abs(float __x) _NOEXCEPT {return fabsf(__x);}

inline _LIBCPP_INLINE_VISIBILITY
double
abs(double __x) _NOEXCEPT {return fabs(__x);}

inline _LIBCPP_INLINE_VISIBILITY
long double
abs(long double __x) _NOEXCEPT {return fabsl(__x);}
#endif // !defined(_AIX)
# 670 "/usr/include/c++/v1/cmath" 3

#ifndef __sun__

// acos

using ::acos;
using ::acosf;

#if !(defined(_LIBCPP_MSVCRT) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       acos(float __x) _NOEXCEPT       {return acosf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double acos(long double __x) _NOEXCEPT {return acosl(__x);}
#endif
# 682 "/usr/include/c++/v1/cmath" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
acos(_A1 __x) _NOEXCEPT {return acos((double)__x);}

// asin

using ::asin;
using ::asinf;

#if !(defined(_LIBCPP_MSVCRT) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       asin(float __x) _NOEXCEPT       {return asinf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double asin(long double __x) _NOEXCEPT {return asinl(__x);}
#endif
# 697 "/usr/include/c++/v1/cmath" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
asin(_A1 __x) _NOEXCEPT {return asin((double)__x);}

// atan

using ::atan;
using ::atanf;

#if !(defined(_LIBCPP_MSVCRT) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       atan(float __x) _NOEXCEPT       {return atanf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double atan(long double __x) _NOEXCEPT {return atanl(__x);}
#endif
# 712 "/usr/include/c++/v1/cmath" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
atan(_A1 __x) _NOEXCEPT {return atan((double)__x);}

// atan2

using ::atan2;
using ::atan2f;

#if !(defined(_LIBCPP_MSVCRT) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       atan2(float __y, float __x) _NOEXCEPT             {return atan2f(__y, __x);}
inline _LIBCPP_INLINE_VISIBILITY long double atan2(long double __y, long double __x) _NOEXCEPT {return atan2l(__y, __x);}
#endif
# 727 "/usr/include/c++/v1/cmath" 3

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_arithmetic<_A1>::value &&
    is_arithmetic<_A2>::value,
    typename __promote<_A1, _A2>::type
>::type
atan2(_A1 __y, _A2 __x) _NOEXCEPT
{
    typedef typename __promote<_A1, _A2>::type __result_type;
    static_assert((!(is_same<_A1, __result_type>::value &&
                      is_same<_A2, __result_type>::value)), "");
    return atan2((__result_type)__y, (__result_type)__x);
}

// ceil

using ::ceil;
using ::ceilf;

#if !(defined(_LIBCPP_MSVCRT) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       ceil(float __x) _NOEXCEPT       {return ceilf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double ceil(long double __x) _NOEXCEPT {return ceill(__x);}
#endif
# 753 "/usr/include/c++/v1/cmath" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
ceil(_A1 __x) _NOEXCEPT {return ceil((double)__x);}

// cos

using ::cos;
using ::cosf;

#if !(defined(_LIBCPP_MSVCRT) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       cos(float __x) _NOEXCEPT       {return cosf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double cos(long double __x) _NOEXCEPT {return cosl(__x);}
#endif
# 768 "/usr/include/c++/v1/cmath" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
cos(_A1 __x) _NOEXCEPT {return cos((double)__x);}

// cosh

using ::cosh;
using ::coshf;

#if !(defined(_LIBCPP_MSVCRT) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       cosh(float __x) _NOEXCEPT       {return coshf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double cosh(long double __x) _NOEXCEPT {return coshl(__x);}
#endif
# 783 "/usr/include/c++/v1/cmath" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
cosh(_A1 __x) _NOEXCEPT {return cosh((double)__x);}

#endif // __sun__
# 790 "/usr/include/c++/v1/cmath" 3
// exp

using ::exp;
using ::expf;

#ifndef __sun__

#if !(defined(_LIBCPP_MSVCRT) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       exp(float __x) _NOEXCEPT       {return expf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double exp(long double __x) _NOEXCEPT {return expl(__x);}
#endif
# 801 "/usr/include/c++/v1/cmath" 3


template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
exp(_A1 __x) _NOEXCEPT {return exp((double)__x);}

// fabs

using ::fabs;
using ::fabsf;

#if !(defined(_LIBCPP_MSVCRT) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       fabs(float __x) _NOEXCEPT       {return fabsf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double fabs(long double __x) _NOEXCEPT {return fabsl(__x);}
#endif
# 817 "/usr/include/c++/v1/cmath" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
fabs(_A1 __x) _NOEXCEPT {return fabs((double)__x);}

// floor

using ::floor;
using ::floorf;

#if !(defined(_LIBCPP_MSVCRT) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       floor(float __x) _NOEXCEPT       {return floorf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double floor(long double __x) _NOEXCEPT {return floorl(__x);}
#endif
# 832 "/usr/include/c++/v1/cmath" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
floor(_A1 __x) _NOEXCEPT {return floor((double)__x);}

// fmod

#endif //__sun__
# 841 "/usr/include/c++/v1/cmath" 3
using ::fmod;
using ::fmodf;
#ifndef __sun__

#if !(defined(_LIBCPP_MSVCRT) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       fmod(float __x, float __y) _NOEXCEPT             {return fmodf(__x, __y);}
inline _LIBCPP_INLINE_VISIBILITY long double fmod(long double __x, long double __y) _NOEXCEPT {return fmodl(__x, __y);}
#endif
# 849 "/usr/include/c++/v1/cmath" 3

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_arithmetic<_A1>::value &&
    is_arithmetic<_A2>::value,
    typename __promote<_A1, _A2>::type
>::type
fmod(_A1 __x, _A2 __y) _NOEXCEPT
{
    typedef typename __promote<_A1, _A2>::type __result_type;
    static_assert((!(is_same<_A1, __result_type>::value &&
                      is_same<_A2, __result_type>::value)), "");
    return fmod((__result_type)__x, (__result_type)__y);
}


// frexp

using ::frexp;
using ::frexpf;

#if !(defined(_LIBCPP_MSVCRT) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       frexp(float __x, int* __e) _NOEXCEPT       {return frexpf(__x, __e);}
inline _LIBCPP_INLINE_VISIBILITY long double frexp(long double __x, int* __e) _NOEXCEPT {return frexpl(__x, __e);}
#endif
# 876 "/usr/include/c++/v1/cmath" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
frexp(_A1 __x, int* __e) _NOEXCEPT {return frexp((double)__x, __e);}

// ldexp

using ::ldexp;
using ::ldexpf;

#if !(defined(_LIBCPP_MSVCRT) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       ldexp(float __x, int __e) _NOEXCEPT       {return ldexpf(__x, __e);}
inline _LIBCPP_INLINE_VISIBILITY long double ldexp(long double __x, int __e) _NOEXCEPT {return ldexpl(__x, __e);}
#endif
# 891 "/usr/include/c++/v1/cmath" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
ldexp(_A1 __x, int __e) _NOEXCEPT {return ldexp((double)__x, __e);}

// log

#endif // __sun__
# 900 "/usr/include/c++/v1/cmath" 3
using ::log;
using ::logf;
#ifndef __sun__

#if !(defined(_LIBCPP_MSVCRT) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       log(float __x) _NOEXCEPT       {return logf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double log(long double __x) _NOEXCEPT {return logl(__x);}
#endif
# 908 "/usr/include/c++/v1/cmath" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
log(_A1 __x) _NOEXCEPT {return log((double)__x);}


// log10

using ::log10;
using ::log10f;

#if !(defined(_LIBCPP_MSVCRT) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       log10(float __x) _NOEXCEPT       {return log10f(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double log10(long double __x) _NOEXCEPT {return log10l(__x);}
#endif
# 924 "/usr/include/c++/v1/cmath" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
log10(_A1 __x) _NOEXCEPT {return log10((double)__x);}

// modf

using ::modf;
using ::modff;

#if !(defined(_LIBCPP_MSVCRT) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       modf(float __x, float* __y) _NOEXCEPT             {return modff(__x, __y);}
inline _LIBCPP_INLINE_VISIBILITY long double modf(long double __x, long double* __y) _NOEXCEPT {return modfl(__x, __y);}
#endif
# 939 "/usr/include/c++/v1/cmath" 3

// pow

#endif // __sun__ 
# 943 "/usr/include/c++/v1/cmath" 3
using ::pow;
using ::powf;

#ifndef __sun__

#if !(defined(_LIBCPP_MSVCRT) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       pow(float __x, float __y) _NOEXCEPT             {return powf(__x, __y);}
inline _LIBCPP_INLINE_VISIBILITY long double pow(long double __x, long double __y) _NOEXCEPT {return powl(__x, __y);}
#endif
# 952 "/usr/include/c++/v1/cmath" 3

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_arithmetic<_A1>::value &&
    is_arithmetic<_A2>::value,
    typename __promote<_A1, _A2>::type
>::type
pow(_A1 __x, _A2 __y) _NOEXCEPT
{
    typedef typename __promote<_A1, _A2>::type __result_type;
    static_assert((!(is_same<_A1, __result_type>::value &&
                      is_same<_A2, __result_type>::value)), "");
    return pow((__result_type)__x, (__result_type)__y);
}


// sin

using ::sin;
using ::sinf;

#if !(defined(_LIBCPP_MSVCRT) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       sin(float __x) _NOEXCEPT       {return sinf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double sin(long double __x) _NOEXCEPT {return sinl(__x);}
#endif
# 979 "/usr/include/c++/v1/cmath" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
sin(_A1 __x) _NOEXCEPT {return sin((double)__x);}

// sinh

using ::sinh;
using ::sinhf;

#if !(defined(_LIBCPP_MSVCRT) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       sinh(float __x) _NOEXCEPT       {return sinhf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double sinh(long double __x) _NOEXCEPT {return sinhl(__x);}
#endif
# 994 "/usr/include/c++/v1/cmath" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
sinh(_A1 __x) _NOEXCEPT {return sinh((double)__x);}

// sqrt

#endif // __sun__
# 1003 "/usr/include/c++/v1/cmath" 3
using ::sqrt;
using ::sqrtf;


#if !(defined(_LIBCPP_MSVCRT) || defined(__sun__) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       sqrt(float __x) _NOEXCEPT       {return sqrtf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double sqrt(long double __x) _NOEXCEPT {return sqrtl(__x);}
#endif
# 1011 "/usr/include/c++/v1/cmath" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
sqrt(_A1 __x) _NOEXCEPT {return sqrt((double)__x);}

// tan

using ::tan;
using ::tanf;
#ifndef __sun__

#if !(defined(_LIBCPP_MSVCRT) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       tan(float __x) _NOEXCEPT       {return tanf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double tan(long double __x) _NOEXCEPT {return tanl(__x);}
#endif
# 1027 "/usr/include/c++/v1/cmath" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
tan(_A1 __x) _NOEXCEPT {return tan((double)__x);}

// tanh

using ::tanh;
using ::tanhf;

#if !(defined(_LIBCPP_MSVCRT) || defined(_AIX))
inline _LIBCPP_INLINE_VISIBILITY float       tanh(float __x) _NOEXCEPT       {return tanhf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double tanh(long double __x) _NOEXCEPT {return tanhl(__x);}
#endif
# 1042 "/usr/include/c++/v1/cmath" 3

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
tanh(_A1 __x) _NOEXCEPT {return tanh((double)__x);}

// acosh

#ifndef _LIBCPP_MSVCRT
using ::acosh;
using ::acoshf;

inline _LIBCPP_INLINE_VISIBILITY float       acosh(float __x) _NOEXCEPT       {return acoshf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double acosh(long double __x) _NOEXCEPT {return acoshl(__x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
acosh(_A1 __x) _NOEXCEPT {return acosh((double)__x);}
#endif
# 1062 "/usr/include/c++/v1/cmath" 3

// asinh

#ifndef _LIBCPP_MSVCRT
using ::asinh;
using ::asinhf;

inline _LIBCPP_INLINE_VISIBILITY float       asinh(float __x) _NOEXCEPT       {return asinhf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double asinh(long double __x) _NOEXCEPT {return asinhl(__x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
asinh(_A1 __x) _NOEXCEPT {return asinh((double)__x);}
#endif
# 1077 "/usr/include/c++/v1/cmath" 3

// atanh

#ifndef _LIBCPP_MSVCRT
using ::atanh;
using ::atanhf;

inline _LIBCPP_INLINE_VISIBILITY float       atanh(float __x) _NOEXCEPT       {return atanhf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double atanh(long double __x) _NOEXCEPT {return atanhl(__x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
atanh(_A1 __x) _NOEXCEPT {return atanh((double)__x);}
#endif
# 1092 "/usr/include/c++/v1/cmath" 3

// cbrt

#ifndef _LIBCPP_MSVCRT
using ::cbrt;
using ::cbrtf;

inline _LIBCPP_INLINE_VISIBILITY float       cbrt(float __x) _NOEXCEPT       {return cbrtf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double cbrt(long double __x) _NOEXCEPT {return cbrtl(__x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
cbrt(_A1 __x) _NOEXCEPT {return cbrt((double)__x);}
#endif
# 1107 "/usr/include/c++/v1/cmath" 3

// copysign

using ::copysign;
using ::copysignf;

inline _LIBCPP_INLINE_VISIBILITY float       copysign(float __x, float __y) _NOEXCEPT             {return copysignf(__x, __y);}
inline _LIBCPP_INLINE_VISIBILITY long double copysign(long double __x, long double __y) _NOEXCEPT {return copysignl(__x, __y);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_arithmetic<_A1>::value &&
    is_arithmetic<_A2>::value,
    typename __promote<_A1, _A2>::type
>::type
copysign(_A1 __x, _A2 __y) _NOEXCEPT
{
    typedef typename __promote<_A1, _A2>::type __result_type;
    static_assert((!(is_same<_A1, __result_type>::value &&
                      is_same<_A2, __result_type>::value)), "");
    return copysign((__result_type)__x, (__result_type)__y);
}

#ifndef _LIBCPP_MSVCRT

// erf

using ::erf;
using ::erff;

inline _LIBCPP_INLINE_VISIBILITY float       erf(float __x) _NOEXCEPT       {return erff(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double erf(long double __x) _NOEXCEPT {return erfl(__x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
erf(_A1 __x) _NOEXCEPT {return erf((double)__x);}

// erfc

using ::erfc;
using ::erfcf;

inline _LIBCPP_INLINE_VISIBILITY float       erfc(float __x) _NOEXCEPT       {return erfcf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double erfc(long double __x) _NOEXCEPT {return erfcl(__x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
erfc(_A1 __x) _NOEXCEPT {return erfc((double)__x);}

// exp2

using ::exp2;
using ::exp2f;

inline _LIBCPP_INLINE_VISIBILITY float       exp2(float __x) _NOEXCEPT       {return exp2f(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double exp2(long double __x) _NOEXCEPT {return exp2l(__x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
exp2(_A1 __x) _NOEXCEPT {return exp2((double)__x);}

// expm1

using ::expm1;
using ::expm1f;

inline _LIBCPP_INLINE_VISIBILITY float       expm1(float __x) _NOEXCEPT       {return expm1f(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double expm1(long double __x) _NOEXCEPT {return expm1l(__x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
expm1(_A1 __x) _NOEXCEPT {return expm1((double)__x);}

// fdim

using ::fdim;
using ::fdimf;

inline _LIBCPP_INLINE_VISIBILITY float       fdim(float __x, float __y) _NOEXCEPT             {return fdimf(__x, __y);}
inline _LIBCPP_INLINE_VISIBILITY long double fdim(long double __x, long double __y) _NOEXCEPT {return fdiml(__x, __y);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_arithmetic<_A1>::value &&
    is_arithmetic<_A2>::value,
    typename __promote<_A1, _A2>::type
>::type
fdim(_A1 __x, _A2 __y) _NOEXCEPT
{
    typedef typename __promote<_A1, _A2>::type __result_type;
    static_assert((!(is_same<_A1, __result_type>::value &&
                      is_same<_A2, __result_type>::value)), "");
    return fdim((__result_type)__x, (__result_type)__y);
}

// fma

inline _LIBCPP_INLINE_VISIBILITY float fmaf(float __x, float __y, float __z) _NOEXCEPT {return (float)((double)__x*__y + __z);}
#ifndef FP_FAST_FMAF
#define FP_FAST_FMAF
#endif
# 1216 "/usr/include/c++/v1/cmath" 3

using ::fma;

inline _LIBCPP_INLINE_VISIBILITY float       fma(float __x, float __y, float __z) _NOEXCEPT                   {return fmaf(__x, __y, __z);}
inline _LIBCPP_INLINE_VISIBILITY long double fma(long double __x, long double __y, long double __z) _NOEXCEPT {return fmal(__x, __y, __z);}

template <class _A1, class _A2, class _A3>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_arithmetic<_A1>::value &&
    is_arithmetic<_A2>::value &&
    is_arithmetic<_A3>::value,
    typename __promote<_A1, _A2, _A3>::type
>::type
fma(_A1 __x, _A2 __y, _A3 __z) _NOEXCEPT
{
    typedef typename __promote<_A1, _A2, _A3>::type __result_type;
    static_assert((!(is_same<_A1, __result_type>::value &&
                      is_same<_A2, __result_type>::value &&
                      is_same<_A3, __result_type>::value)), "");
    return fma((__result_type)__x, (__result_type)__y, (__result_type)__z);
}

// fmax

using ::fmax;
using ::fmaxf;

inline _LIBCPP_INLINE_VISIBILITY float       fmax(float __x, float __y) _NOEXCEPT             {return fmaxf(__x, __y);}
inline _LIBCPP_INLINE_VISIBILITY long double fmax(long double __x, long double __y) _NOEXCEPT {return fmaxl(__x, __y);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_arithmetic<_A1>::value &&
    is_arithmetic<_A2>::value,
    typename __promote<_A1, _A2>::type
>::type
fmax(_A1 __x, _A2 __y) _NOEXCEPT
{
    typedef typename __promote<_A1, _A2>::type __result_type;
    static_assert((!(is_same<_A1, __result_type>::value &&
                      is_same<_A2, __result_type>::value)), "");
    return fmax((__result_type)__x, (__result_type)__y);
}

// fmin

using ::fmin;
using ::fminf;

inline _LIBCPP_INLINE_VISIBILITY float       fmin(float __x, float __y) _NOEXCEPT             {return fminf(__x, __y);}
inline _LIBCPP_INLINE_VISIBILITY long double fmin(long double __x, long double __y) _NOEXCEPT {return fminl(__x, __y);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_arithmetic<_A1>::value &&
    is_arithmetic<_A2>::value,
    typename __promote<_A1, _A2>::type
>::type
fmin(_A1 __x, _A2 __y) _NOEXCEPT
{
    typedef typename __promote<_A1, _A2>::type __result_type;
    static_assert((!(is_same<_A1, __result_type>::value &&
                      is_same<_A2, __result_type>::value)), "");
    return fmin((__result_type)__x, (__result_type)__y);
}

// hypot

using ::hypot;
using ::hypotf;

inline _LIBCPP_INLINE_VISIBILITY float       hypot(float __x, float __y) _NOEXCEPT             {return hypotf(__x, __y);}
inline _LIBCPP_INLINE_VISIBILITY long double hypot(long double __x, long double __y) _NOEXCEPT {return hypotl(__x, __y);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_arithmetic<_A1>::value &&
    is_arithmetic<_A2>::value,
    typename __promote<_A1, _A2>::type
>::type
hypot(_A1 __x, _A2 __y) _NOEXCEPT
{
    typedef typename __promote<_A1, _A2>::type __result_type;
    static_assert((!(is_same<_A1, __result_type>::value &&
                      is_same<_A2, __result_type>::value)), "");
    return hypot((__result_type)__x, (__result_type)__y);
}

// ilogb

using ::ilogb;
using ::ilogbf;

inline _LIBCPP_INLINE_VISIBILITY int ilogb(float __x) _NOEXCEPT       {return ilogbf(__x);}
inline _LIBCPP_INLINE_VISIBILITY int ilogb(long double __x) _NOEXCEPT {return ilogbl(__x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, int>::type
ilogb(_A1 __x) _NOEXCEPT {return ilogb((double)__x);}

// lgamma

using ::lgamma;
using ::lgammaf;

inline _LIBCPP_INLINE_VISIBILITY float       lgamma(float __x) _NOEXCEPT       {return lgammaf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double lgamma(long double __x) _NOEXCEPT {return lgammal(__x);}


template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
lgamma(_A1 __x) _NOEXCEPT {return lgamma((double)__x);}


// llrint

using ::llrint;
using ::llrintf;

inline _LIBCPP_INLINE_VISIBILITY long long llrint(float __x) _NOEXCEPT       {return llrintf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long long llrint(long double __x) _NOEXCEPT {return llrintl(__x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, long long>::type
llrint(_A1 __x) _NOEXCEPT {return llrint((double)__x);}

// llround

using ::llround;
using ::llroundf;

inline _LIBCPP_INLINE_VISIBILITY long long llround(float __x) _NOEXCEPT       {return llroundf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long long llround(long double __x) _NOEXCEPT {return llroundl(__x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, long long>::type
llround(_A1 __x) _NOEXCEPT {return llround((double)__x);}

// log1p

using ::log1p;
using ::log1pf;

inline _LIBCPP_INLINE_VISIBILITY float       log1p(float __x) _NOEXCEPT       {return log1pf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double log1p(long double __x) _NOEXCEPT {return log1pl(__x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
log1p(_A1 __x) _NOEXCEPT {return log1p((double)__x);}

// log2

using ::log2;
using ::log2f;

inline _LIBCPP_INLINE_VISIBILITY float       log2(float __x) _NOEXCEPT       {return log2f(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double log2(long double __x) _NOEXCEPT {return log2l(__x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
log2(_A1 __x) _NOEXCEPT {return log2((double)__x);}

// logb

using ::logb;
using ::logbf;

inline _LIBCPP_INLINE_VISIBILITY float       logb(float __x) _NOEXCEPT       {return logbf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double logb(long double __x) _NOEXCEPT {return logbl(__x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
logb(_A1 __x) _NOEXCEPT {return logb((double)__x);}

// lrint

using ::lrint;
using ::lrintf;

inline _LIBCPP_INLINE_VISIBILITY long lrint(float __x) _NOEXCEPT       {return lrintf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long lrint(long double __x) _NOEXCEPT {return lrintl(__x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, long>::type
lrint(_A1 __x) _NOEXCEPT {return lrint((double)__x);}

// lround

using ::lround;
using ::lroundf;

inline _LIBCPP_INLINE_VISIBILITY long lround(float __x) _NOEXCEPT       {return lroundf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long lround(long double __x) _NOEXCEPT {return lroundl(__x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, long>::type
lround(_A1 __x) _NOEXCEPT {return lround((double)__x);}

#endif // _LIBCPP_MSVCRT
# 1432 "/usr/include/c++/v1/cmath" 3
#endif // __sun__
# 1433 "/usr/include/c++/v1/cmath" 3

// nan

#ifndef _LIBCPP_MSVCRT
using ::nan;
using ::nanf;
#endif // _LIBCPP_MSVCRT
# 1440 "/usr/include/c++/v1/cmath" 3

#ifndef __sun__
#ifndef _LIBCPP_MSVCRT

// nearbyint

using ::nearbyint;
using ::nearbyintf;

inline _LIBCPP_INLINE_VISIBILITY float       nearbyint(float __x) _NOEXCEPT       {return nearbyintf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double nearbyint(long double __x) _NOEXCEPT {return nearbyintl(__x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
nearbyint(_A1 __x) _NOEXCEPT {return nearbyint((double)__x);}

// nextafter

using ::nextafter;
using ::nextafterf;

inline _LIBCPP_INLINE_VISIBILITY float       nextafter(float __x, float __y) _NOEXCEPT             {return nextafterf(__x, __y);}
inline _LIBCPP_INLINE_VISIBILITY long double nextafter(long double __x, long double __y) _NOEXCEPT {return nextafterl(__x, __y);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_arithmetic<_A1>::value &&
    is_arithmetic<_A2>::value,
    typename __promote<_A1, _A2>::type
>::type
nextafter(_A1 __x, _A2 __y) _NOEXCEPT
{
    typedef typename __promote<_A1, _A2>::type __result_type;
    static_assert((!(is_same<_A1, __result_type>::value &&
                      is_same<_A2, __result_type>::value)), "");
    return nextafter((__result_type)__x, (__result_type)__y);
}

// nexttoward

using ::nexttoward;
using ::nexttowardf;

inline _LIBCPP_INLINE_VISIBILITY float       nexttoward(float __x, long double __y) _NOEXCEPT       {return nexttowardf(__x, __y);}
inline _LIBCPP_INLINE_VISIBILITY long double nexttoward(long double __x, long double __y) _NOEXCEPT {return nexttowardl(__x, __y);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
nexttoward(_A1 __x, long double __y) _NOEXCEPT {return nexttoward((double)__x, __y);}

// remainder

using ::remainder;
using ::remainderf;

inline _LIBCPP_INLINE_VISIBILITY float       remainder(float __x, float __y) _NOEXCEPT             {return remainderf(__x, __y);}
inline _LIBCPP_INLINE_VISIBILITY long double remainder(long double __x, long double __y) _NOEXCEPT {return remainderl(__x, __y);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_arithmetic<_A1>::value &&
    is_arithmetic<_A2>::value,
    typename __promote<_A1, _A2>::type
>::type
remainder(_A1 __x, _A2 __y) _NOEXCEPT
{
    typedef typename __promote<_A1, _A2>::type __result_type;
    static_assert((!(is_same<_A1, __result_type>::value &&
                      is_same<_A2, __result_type>::value)), "");
    return remainder((__result_type)__x, (__result_type)__y);
}

// remquo

using ::remquo;
using ::remquof;

inline _LIBCPP_INLINE_VISIBILITY float       remquo(float __x, float __y, int* __z) _NOEXCEPT             {return remquof(__x, __y, __z);}
inline _LIBCPP_INLINE_VISIBILITY long double remquo(long double __x, long double __y, int* __z) _NOEXCEPT {return remquol(__x, __y, __z);}

template <class _A1, class _A2>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if
<
    is_arithmetic<_A1>::value &&
    is_arithmetic<_A2>::value,
    typename __promote<_A1, _A2>::type
>::type
remquo(_A1 __x, _A2 __y, int* __z) _NOEXCEPT
{
    typedef typename __promote<_A1, _A2>::type __result_type;
    static_assert((!(is_same<_A1, __result_type>::value &&
                      is_same<_A2, __result_type>::value)), "");
    return remquo((__result_type)__x, (__result_type)__y, __z);
}

// rint

using ::rint;
using ::rintf;

inline _LIBCPP_INLINE_VISIBILITY float       rint(float __x) _NOEXCEPT       {return rintf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double rint(long double __x) _NOEXCEPT {return rintl(__x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
rint(_A1 __x) _NOEXCEPT {return rint((double)__x);}

// round

using ::round;
using ::roundf;

inline _LIBCPP_INLINE_VISIBILITY float       round(float __x) _NOEXCEPT       {return roundf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double round(long double __x) _NOEXCEPT {return roundl(__x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
round(_A1 __x) _NOEXCEPT {return round((double)__x);}

// scalbln

using ::scalbln;
using ::scalblnf;

inline _LIBCPP_INLINE_VISIBILITY float       scalbln(float __x, long __y) _NOEXCEPT       {return scalblnf(__x, __y);}
inline _LIBCPP_INLINE_VISIBILITY long double scalbln(long double __x, long __y) _NOEXCEPT {return scalblnl(__x, __y);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
scalbln(_A1 __x, long __y) _NOEXCEPT {return scalbln((double)__x, __y);}

// scalbn

using ::scalbn;
using ::scalbnf;

inline _LIBCPP_INLINE_VISIBILITY float       scalbn(float __x, int __y) _NOEXCEPT       {return scalbnf(__x, __y);}
inline _LIBCPP_INLINE_VISIBILITY long double scalbn(long double __x, int __y) _NOEXCEPT {return scalbnl(__x, __y);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
scalbn(_A1 __x, int __y) _NOEXCEPT {return scalbn((double)__x, __y);}

// tgamma

using ::tgamma;
using ::tgammaf;

inline _LIBCPP_INLINE_VISIBILITY float       tgamma(float __x) _NOEXCEPT       {return tgammaf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double tgamma(long double __x) _NOEXCEPT {return tgammal(__x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
tgamma(_A1 __x) _NOEXCEPT {return tgamma((double)__x);}

// trunc

using ::trunc;
using ::truncf;

inline _LIBCPP_INLINE_VISIBILITY float       trunc(float __x) _NOEXCEPT       {return truncf(__x);}
inline _LIBCPP_INLINE_VISIBILITY long double trunc(long double __x) _NOEXCEPT {return truncl(__x);}

template <class _A1>
inline _LIBCPP_INLINE_VISIBILITY
typename enable_if<is_integral<_A1>::value, double>::type
trunc(_A1 __x) _NOEXCEPT {return trunc((double)__x);}

#endif // !_LIBCPP_MSVCRT
# 1621 "/usr/include/c++/v1/cmath" 3

using ::acosl;
using ::asinl;
using ::atanl;
using ::atan2l;
using ::ceill;
using ::cosl;
using ::coshl;
using ::expl;
using ::fabsl;
using ::floorl;
using ::fmodl;
using ::frexpl;
using ::ldexpl;
using ::logl;
using ::log10l;
using ::modfl;
using ::powl;
using ::sinl;
using ::sinhl;
using ::sqrtl;
using ::tanl;
#ifndef _LIBCPP_MSVCRT
using ::tanhl;
using ::acoshl;
using ::asinhl;
using ::atanhl;
using ::cbrtl;
#endif  // !_LIBCPP_MSVCRT
# 1650 "/usr/include/c++/v1/cmath" 3
using ::copysignl;
#ifndef _LIBCPP_MSVCRT
using ::erfl;
using ::erfcl;
using ::exp2l;
using ::expm1l;
using ::fdiml;
using ::fmal;
using ::fmaxl;
using ::fminl;
using ::hypotl;
using ::ilogbl;
using ::lgammal;
using ::llrintl;
using ::llroundl;
using ::log1pl;
using ::log2l;
using ::logbl;
using ::lrintl;
using ::lroundl;
using ::nanl;
using ::nearbyintl;
using ::nextafterl;
using ::nexttowardl;
using ::remainderl;
using ::remquol;
using ::rintl;
using ::roundl;
using ::scalblnl;
using ::scalbnl;
using ::tgammal;
using ::truncl;
#endif // !_LIBCPP_MSVCRT
# 1683 "/usr/include/c++/v1/cmath" 3

#else 
# 1685 "/usr/include/c++/v1/cmath" 3
using ::lgamma;
using ::lgammaf;
#endif // __sun__
# 1688 "/usr/include/c++/v1/cmath" 3
_LIBCPP_END_NAMESPACE_STD

#endif  // _LIBCPP_CMATH
# 1691 "/usr/include/c++/v1/cmath" 3
# 78 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <ctime>
#endif /* expanded by -frewrite-includes */
# 79 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include <exception>
#endif /* expanded by -frewrite-includes */
# 80 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Detect/configure OS variables.
//
// Define 'cimg_OS' to: '0' for an unknown OS (will try to minize library dependencies).
//                      '1' for a Unix-like OS (Linux, Solaris, BSD, MacOSX, Irix, ...).
//                      '2' for Microsoft Windows.
//                      (auto-detection is performed if 'cimg_OS' is not set by the user).
#ifndef cimg_OS
#if defined(unix)        || defined(__unix)      || defined(__unix__) \
 || defined(linux)       || defined(__linux)     || defined(__linux__) \
 || defined(sun)         || defined(__sun) \
 || defined(BSD)         || defined(__OpenBSD__) || defined(__NetBSD__) \
 || defined(__FreeBSD__) || defined (__DragonFly__) \
 || defined(sgi)         || defined(__sgi) \
 || defined(__MACOSX__)  || defined(__APPLE__) \
 || defined(__CYGWIN__)
#define cimg_OS 1
#elif defined(_MSC_VER) || defined(WIN32)  || defined(_WIN32) || defined(__WIN32__) \
   || defined(WIN64)    || defined(_WIN64) || defined(__WIN64__)
# 99 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#define cimg_OS 2
#else
# 101 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#define cimg_OS 0
#endif
# 103 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#elif !(cimg_OS==0 || cimg_OS==1 || cimg_OS==2)
# 104 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#error CImg Library: Invalid configuration variable 'cimg_OS'.
#error (correct values are '0 = unknown OS', '1 = Unix-like OS', '2 = Microsoft Windows').
#endif
# 107 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Disable silly warnings on some Microsoft VC++ compilers.
#ifdef _MSC_VER
#pragma warning(push)
#pragma warning(disable:4311)
#pragma warning(disable:4312)
#pragma warning(disable:4800)
#pragma warning(disable:4804)
#pragma warning(disable:4996)
#define _CRT_SECURE_NO_DEPRECATE 1
#define _CRT_NONSTDC_NO_DEPRECATE 1
#endif
# 119 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Include OS-specific headers.
#if cimg_OS==1
#if 0 /* expanded by -frewrite-includes */
#include <sys/types.h>
#endif /* expanded by -frewrite-includes */
# 123 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include <sys/time.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/sys/time.h" 1 3 4
/*-
 * Copyright (c) 1982, 1986, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)time.h	8.5 (Berkeley) 5/4/95
 * $FreeBSD: head/sys/sys/time.h 270261 2014-08-21 09:01:42Z davide $
 */

#ifndef _SYS_TIME_H_
#define	_SYS_TIME_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/_timeval.h>
#endif /* expanded by -frewrite-includes */
# 37 "/usr/include/sys/time.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/types.h>
#endif /* expanded by -frewrite-includes */
# 38 "/usr/include/sys/time.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/timespec.h>
#endif /* expanded by -frewrite-includes */
# 39 "/usr/include/sys/time.h" 3 4

struct timezone {
	int	tz_minuteswest;	/* minutes west of Greenwich */
	int	tz_dsttime;	/* type of dst correction */
};
#define	DST_NONE	0	/* not on dst */
#define	DST_USA		1	/* USA style dst */
#define	DST_AUST	2	/* Australian style dst */
#define	DST_WET		3	/* Western European dst */
#define	DST_MET		4	/* Middle European dst */
#define	DST_EET		5	/* Eastern European dst */
#define	DST_CAN		6	/* Canada */

#if __BSD_VISIBLE
struct bintime {
	time_t	sec;
	uint64_t frac;
};

static __inline void
bintime_addx(struct bintime *_bt, uint64_t _x)
{
	uint64_t _u;

	_u = _bt->frac;
	_bt->frac += _x;
	if (_u > _bt->frac)
		_bt->sec++;
}

static __inline void
bintime_add(struct bintime *_bt, const struct bintime *_bt2)
{
	uint64_t _u;

	_u = _bt->frac;
	_bt->frac += _bt2->frac;
	if (_u > _bt->frac)
		_bt->sec++;
	_bt->sec += _bt2->sec;
}

static __inline void
bintime_sub(struct bintime *_bt, const struct bintime *_bt2)
{
	uint64_t _u;

	_u = _bt->frac;
	_bt->frac -= _bt2->frac;
	if (_u < _bt->frac)
		_bt->sec--;
	_bt->sec -= _bt2->sec;
}

static __inline void
bintime_mul(struct bintime *_bt, u_int _x)
{
	uint64_t _p1, _p2;

	_p1 = (_bt->frac & 0xffffffffull) * _x;
	_p2 = (_bt->frac >> 32) * _x + (_p1 >> 32);
	_bt->sec *= _x;
	_bt->sec += (_p2 >> 32);
	_bt->frac = (_p2 << 32) | (_p1 & 0xffffffffull);
}

static __inline void
bintime_shift(struct bintime *_bt, int _exp)
{

	if (_exp > 0) {
		_bt->sec <<= _exp;
		_bt->sec |= _bt->frac >> (64 - _exp);
		_bt->frac <<= _exp;
	} else if (_exp < 0) {
		_bt->frac >>= -_exp;
		_bt->frac |= (uint64_t)_bt->sec << (64 + _exp);
		_bt->sec >>= -_exp;
	}
}

#define	bintime_clear(a)	((a)->sec = (a)->frac = 0)
#define	bintime_isset(a)	((a)->sec || (a)->frac)
#define	bintime_cmp(a, b, cmp)						\
	(((a)->sec == (b)->sec) ?					\
	    ((a)->frac cmp (b)->frac) :					\
	    ((a)->sec cmp (b)->sec))

#define	SBT_1S	((sbintime_t)1 << 32)
#define	SBT_1M	(SBT_1S * 60)
#define	SBT_1MS	(SBT_1S / 1000)
#define	SBT_1US	(SBT_1S / 1000000)
#define	SBT_1NS	(SBT_1S / 1000000000)
#define	SBT_MAX	0x7fffffffffffffffLL

static __inline int
sbintime_getsec(sbintime_t _sbt)
{

	return (_sbt >> 32);
}

static __inline sbintime_t
bttosbt(const struct bintime _bt)
{

	return (((sbintime_t)_bt.sec << 32) + (_bt.frac >> 32));
}

static __inline struct bintime
sbttobt(sbintime_t _sbt)
{
	struct bintime _bt;

	_bt.sec = _sbt >> 32;
	_bt.frac = _sbt << 32;
	return (_bt);
}

/*-
 * Background information:
 *
 * When converting between timestamps on parallel timescales of differing
 * resolutions it is historical and scientific practice to round down rather
 * than doing 4/5 rounding.
 *
 *   The date changes at midnight, not at noon.
 *
 *   Even at 15:59:59.999999999 it's not four'o'clock.
 *
 *   time_second ticks after N.999999999 not after N.4999999999
 */

static __inline void
bintime2timespec(const struct bintime *_bt, struct timespec *_ts)
{

	_ts->tv_sec = _bt->sec;
	_ts->tv_nsec = ((uint64_t)1000000000 *
	    (uint32_t)(_bt->frac >> 32)) >> 32;
}

static __inline void
timespec2bintime(const struct timespec *_ts, struct bintime *_bt)
{

	_bt->sec = _ts->tv_sec;
	/* 18446744073 = int(2^64 / 1000000000) */
	_bt->frac = _ts->tv_nsec * (uint64_t)18446744073LL;
}

static __inline void
bintime2timeval(const struct bintime *_bt, struct timeval *_tv)
{

	_tv->tv_sec = _bt->sec;
	_tv->tv_usec = ((uint64_t)1000000 * (uint32_t)(_bt->frac >> 32)) >> 32;
}

static __inline void
timeval2bintime(const struct timeval *_tv, struct bintime *_bt)
{

	_bt->sec = _tv->tv_sec;
	/* 18446744073709 = int(2^64 / 1000000) */
	_bt->frac = _tv->tv_usec * (uint64_t)18446744073709LL;
}

static __inline struct timespec
sbttots(sbintime_t _sbt)
{
	struct timespec _ts;

	_ts.tv_sec = _sbt >> 32;
	_ts.tv_nsec = ((uint64_t)1000000000 * (uint32_t)_sbt) >> 32;
	return (_ts);
}

static __inline sbintime_t
tstosbt(struct timespec _ts)
{

	return (((sbintime_t)_ts.tv_sec << 32) +
	    (_ts.tv_nsec * (((uint64_t)1 << 63) / 500000000) >> 32));
}

static __inline struct timeval
sbttotv(sbintime_t _sbt)
{
	struct timeval _tv;

	_tv.tv_sec = _sbt >> 32;
	_tv.tv_usec = ((uint64_t)1000000 * (uint32_t)_sbt) >> 32;
	return (_tv);
}

static __inline sbintime_t
tvtosbt(struct timeval _tv)
{

	return (((sbintime_t)_tv.tv_sec << 32) +
	    (_tv.tv_usec * (((uint64_t)1 << 63) / 500000) >> 32));
}
#endif /* __BSD_VISIBLE */
# 243 "/usr/include/sys/time.h" 3 4

#ifdef _KERNEL

/* Operations on timespecs */
#define	timespecclear(tvp)	((tvp)->tv_sec = (tvp)->tv_nsec = 0)
#define	timespecisset(tvp)	((tvp)->tv_sec || (tvp)->tv_nsec)
#define	timespeccmp(tvp, uvp, cmp)					\
	(((tvp)->tv_sec == (uvp)->tv_sec) ?				\
	    ((tvp)->tv_nsec cmp (uvp)->tv_nsec) :			\
	    ((tvp)->tv_sec cmp (uvp)->tv_sec))
#define	timespecadd(vvp, uvp)						\
	do {								\
		(vvp)->tv_sec += (uvp)->tv_sec;				\
		(vvp)->tv_nsec += (uvp)->tv_nsec;			\
		if ((vvp)->tv_nsec >= 1000000000) {			\
			(vvp)->tv_sec++;				\
			(vvp)->tv_nsec -= 1000000000;			\
		}							\
	} while (0)
#define	timespecsub(vvp, uvp)						\
	do {								\
		(vvp)->tv_sec -= (uvp)->tv_sec;				\
		(vvp)->tv_nsec -= (uvp)->tv_nsec;			\
		if ((vvp)->tv_nsec < 0) {				\
			(vvp)->tv_sec--;				\
			(vvp)->tv_nsec += 1000000000;			\
		}							\
	} while (0)

/* Operations on timevals. */

#define	timevalclear(tvp)		((tvp)->tv_sec = (tvp)->tv_usec = 0)
#define	timevalisset(tvp)		((tvp)->tv_sec || (tvp)->tv_usec)
#define	timevalcmp(tvp, uvp, cmp)					\
	(((tvp)->tv_sec == (uvp)->tv_sec) ?				\
	    ((tvp)->tv_usec cmp (uvp)->tv_usec) :			\
	    ((tvp)->tv_sec cmp (uvp)->tv_sec))

/* timevaladd and timevalsub are not inlined */

#endif /* _KERNEL */
# 284 "/usr/include/sys/time.h" 3 4

#ifndef _KERNEL			/* NetBSD/OpenBSD compatible interfaces */

#define	timerclear(tvp)		((tvp)->tv_sec = (tvp)->tv_usec = 0)
#define	timerisset(tvp)		((tvp)->tv_sec || (tvp)->tv_usec)
#define	timercmp(tvp, uvp, cmp)					\
	(((tvp)->tv_sec == (uvp)->tv_sec) ?				\
	    ((tvp)->tv_usec cmp (uvp)->tv_usec) :			\
	    ((tvp)->tv_sec cmp (uvp)->tv_sec))
#define	timeradd(tvp, uvp, vvp)						\
	do {								\
		(vvp)->tv_sec = (tvp)->tv_sec + (uvp)->tv_sec;		\
		(vvp)->tv_usec = (tvp)->tv_usec + (uvp)->tv_usec;	\
		if ((vvp)->tv_usec >= 1000000) {			\
			(vvp)->tv_sec++;				\
			(vvp)->tv_usec -= 1000000;			\
		}							\
	} while (0)
#define	timersub(tvp, uvp, vvp)						\
	do {								\
		(vvp)->tv_sec = (tvp)->tv_sec - (uvp)->tv_sec;		\
		(vvp)->tv_usec = (tvp)->tv_usec - (uvp)->tv_usec;	\
		if ((vvp)->tv_usec < 0) {				\
			(vvp)->tv_sec--;				\
			(vvp)->tv_usec += 1000000;			\
		}							\
	} while (0)
#endif
# 312 "/usr/include/sys/time.h" 3 4

/*
 * Names of the interval timers, and structure
 * defining a timer setting.
 */
#define	ITIMER_REAL	0
#define	ITIMER_VIRTUAL	1
#define	ITIMER_PROF	2

struct itimerval {
	struct	timeval it_interval;	/* timer interval */
	struct	timeval it_value;	/* current value */
};

/*
 * Getkerninfo clock information structure
 */
struct clockinfo {
	int	hz;		/* clock frequency */
	int	tick;		/* micro-seconds per hz tick */
	int	spare;
	int	stathz;		/* statistics clock frequency */
	int	profhz;		/* profiling clock frequency */
};

/* These macros are also in time.h. */
#ifndef CLOCK_REALTIME
#define	CLOCK_REALTIME	0
#define	CLOCK_VIRTUAL	1
#define	CLOCK_PROF	2
#define	CLOCK_MONOTONIC	4
#define	CLOCK_UPTIME	5		/* FreeBSD-specific. */
#define	CLOCK_UPTIME_PRECISE	7	/* FreeBSD-specific. */
#define	CLOCK_UPTIME_FAST	8	/* FreeBSD-specific. */
#define	CLOCK_REALTIME_PRECISE	9	/* FreeBSD-specific. */
#define	CLOCK_REALTIME_FAST	10	/* FreeBSD-specific. */
#define	CLOCK_MONOTONIC_PRECISE	11	/* FreeBSD-specific. */
#define	CLOCK_MONOTONIC_FAST	12	/* FreeBSD-specific. */
#define	CLOCK_SECOND	13		/* FreeBSD-specific. */
#define	CLOCK_THREAD_CPUTIME_ID	14
#define	CLOCK_PROCESS_CPUTIME_ID	15
#endif
# 354 "/usr/include/sys/time.h" 3 4

#ifndef TIMER_ABSTIME
#define	TIMER_RELTIME	0x0	/* relative timer */
#define	TIMER_ABSTIME	0x1	/* absolute timer */
#endif
# 359 "/usr/include/sys/time.h" 3 4

#if __BSD_VISIBLE
#define	CPUCLOCK_WHICH_PID	0
#define	CPUCLOCK_WHICH_TID	1
#endif
# 364 "/usr/include/sys/time.h" 3 4

#ifdef _KERNEL

/*
 * Kernel to clock driver interface.
 */
void	inittodr(time_t base);
void	resettodr(void);

extern volatile time_t	time_second;
extern volatile time_t	time_uptime;
extern struct bintime boottimebin;
extern struct timeval boottime;
extern struct bintime tc_tick_bt;
extern sbintime_t tc_tick_sbt;
extern struct bintime tick_bt;
extern sbintime_t tick_sbt;
extern int tc_precexp;
extern int tc_timepercentage;
extern struct bintime bt_timethreshold;
extern struct bintime bt_tickthreshold;
extern sbintime_t sbt_timethreshold;
extern sbintime_t sbt_tickthreshold;

/*
 * Functions for looking at our clock: [get]{bin,nano,micro}[up]time()
 *
 * Functions without the "get" prefix returns the best timestamp
 * we can produce in the given format.
 *
 * "bin"   == struct bintime  == seconds + 64 bit fraction of seconds.
 * "nano"  == struct timespec == seconds + nanoseconds.
 * "micro" == struct timeval  == seconds + microseconds.
 *
 * Functions containing "up" returns time relative to boot and
 * should be used for calculating time intervals.
 *
 * Functions without "up" returns GMT time.
 *
 * Functions with the "get" prefix returns a less precise result
 * much faster than the functions without "get" prefix and should
 * be used where a precision of 1/hz seconds is acceptable or where
 * performance is priority. (NB: "precision", _not_ "resolution" !)
 */

void	binuptime(struct bintime *bt);
void	nanouptime(struct timespec *tsp);
void	microuptime(struct timeval *tvp);

static __inline sbintime_t
sbinuptime(void)
{
	struct bintime _bt;

	binuptime(&_bt);
	return (bttosbt(_bt));
}

void	bintime(struct bintime *bt);
void	nanotime(struct timespec *tsp);
void	microtime(struct timeval *tvp);

void	getbinuptime(struct bintime *bt);
void	getnanouptime(struct timespec *tsp);
void	getmicrouptime(struct timeval *tvp);

static __inline sbintime_t
getsbinuptime(void)
{
	struct bintime _bt;

	getbinuptime(&_bt);
	return (bttosbt(_bt));
}

void	getbintime(struct bintime *bt);
void	getnanotime(struct timespec *tsp);
void	getmicrotime(struct timeval *tvp);

/* Other functions */
int	itimerdecr(struct itimerval *itp, int usec);
int	itimerfix(struct timeval *tv);
int	ppsratecheck(struct timeval *, int *, int);
int	ratecheck(struct timeval *, const struct timeval *);
void	timevaladd(struct timeval *t1, const struct timeval *t2);
void	timevalsub(struct timeval *t1, const struct timeval *t2);
int	tvtohz(struct timeval *tv);

#define	TC_DEFAULTPERC		5

#define	BT2FREQ(bt)                                                     \
	(((uint64_t)0x8000000000000000 + ((bt)->frac >> 2)) /           \
	    ((bt)->frac >> 1))

#define	SBT2FREQ(sbt)	((SBT_1S + ((sbt) >> 1)) / (sbt))

#define	FREQ2BT(freq, bt)                                               \
{									\
	(bt)->sec = 0;                                                  \
	(bt)->frac = ((uint64_t)0x8000000000000000  / (freq)) << 1;     \
}

#define	TIMESEL(sbt, sbt2)						\
	(((sbt2) >= sbt_timethreshold) ?				\
	    ((*(sbt) = getsbinuptime()), 1) : ((*(sbt) = sbinuptime()), 0))

#else /* !_KERNEL */
# 471 "/usr/include/sys/time.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <time.h>
#endif /* expanded by -frewrite-includes */
# 472 "/usr/include/sys/time.h" 3 4

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 474 "/usr/include/sys/time.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/select.h>
#endif /* expanded by -frewrite-includes */
# 475 "/usr/include/sys/time.h" 3 4

__BEGIN_DECLS
int	setitimer(int, const struct itimerval *, struct itimerval *);
int	utimes(const char *, const struct timeval *);

#if __BSD_VISIBLE
int	adjtime(const struct timeval *, struct timeval *);
int	clock_getcpuclockid2(id_t, int, clockid_t *);
int	futimes(int, const struct timeval *);
int	futimesat(int, const char *, const struct timeval [2]);
int	lutimes(const char *, const struct timeval *);
int	settimeofday(const struct timeval *, const struct timezone *);
#endif
# 488 "/usr/include/sys/time.h" 3 4

#if __XSI_VISIBLE
int	getitimer(int, struct itimerval *);
int	gettimeofday(struct timeval *, struct timezone *);
#endif
# 493 "/usr/include/sys/time.h" 3 4

__END_DECLS

#endif /* !_KERNEL */
# 497 "/usr/include/sys/time.h" 3 4

#endif /* !_SYS_TIME_H_ */
# 499 "/usr/include/sys/time.h" 3 4
# 124 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h" 2
#if 0 /* expanded by -frewrite-includes */
#include <unistd.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/unistd.h" 1 3 4
/*-
 * Copyright (c) 1991, 1993, 1994
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)unistd.h	8.12 (Berkeley) 4/27/95
 * $FreeBSD: head/include/unistd.h 271878 2014-09-19 18:13:56Z pfg $
 */

#ifndef _UNISTD_H_
#define	_UNISTD_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 37 "/usr/include/unistd.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/types.h>			/* XXX adds too much pollution. */
#endif /* expanded by -frewrite-includes */
# 38 "/usr/include/unistd.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/unistd.h>
#endif /* expanded by -frewrite-includes */
# 1 "/usr/include/sys/unistd.h" 1 3 4
/*-
 * Copyright (c) 1989, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)unistd.h	8.2 (Berkeley) 1/7/94
 * $FreeBSD: head/sys/sys/unistd.h 239347 2012-08-17 02:26:31Z davidxu $
 */

#ifndef _SYS_UNISTD_H_
#define	_SYS_UNISTD_H_

#if 0 /* expanded by -frewrite-includes */
#include <sys/cdefs.h>
#endif /* expanded by -frewrite-includes */
# 37 "/usr/include/sys/unistd.h" 3 4

/*
 * POSIX options and option groups we unconditionally do or don't
 * implement.  Those options which are implemented (or not) entirely
 * in user mode are defined in <unistd.h>.  Please keep this list in
 * alphabetical order.
 *
 * Anything which is defined as zero below **must** have an
 * implementation for the corresponding sysconf() which is able to
 * determine conclusively whether or not the feature is supported.
 * Anything which is defined as other than -1 below **must** have
 * complete headers, types, and function declarations as specified by
 * the POSIX standard; however, if the relevant sysconf() function
 * returns -1, the functions may be stubbed out.
 */
#define	_POSIX_ADVISORY_INFO		200112L
#define	_POSIX_ASYNCHRONOUS_IO		0
#define	_POSIX_CHOWN_RESTRICTED		1
#define	_POSIX_CLOCK_SELECTION		(-1)
#define	_POSIX_CPUTIME			200112L
#define	_POSIX_FSYNC			200112L
#define	_POSIX_IPV6			0
#define	_POSIX_JOB_CONTROL		1
#define	_POSIX_MAPPED_FILES		200112L
#define	_POSIX_MEMLOCK			(-1)
#define	_POSIX_MEMLOCK_RANGE		200112L
#define	_POSIX_MEMORY_PROTECTION	200112L
#define	_POSIX_MESSAGE_PASSING		200112L
#define	_POSIX_MONOTONIC_CLOCK		200112L
#define	_POSIX_NO_TRUNC			1
#define	_POSIX_PRIORITIZED_IO		(-1)
#define	_POSIX_PRIORITY_SCHEDULING	200112L
#define	_POSIX_RAW_SOCKETS		200112L
#define	_POSIX_REALTIME_SIGNALS		200112L
#define	_POSIX_SEMAPHORES		200112L
#define	_POSIX_SHARED_MEMORY_OBJECTS	200112L
#define	_POSIX_SPORADIC_SERVER		(-1)
#define	_POSIX_SYNCHRONIZED_IO		(-1)
#define	_POSIX_TIMEOUTS			200112L
#define	_POSIX_TIMERS			200112L
#define	_POSIX_TYPED_MEMORY_OBJECTS	(-1)
#define	_POSIX_VDISABLE			0xff

#if __XSI_VISIBLE
#define	_XOPEN_SHM			1
#define	_XOPEN_STREAMS			(-1)
#endif
# 84 "/usr/include/sys/unistd.h" 3 4

/*
 * Although we have saved user/group IDs, we do not use them in setuid
 * as described in POSIX 1003.1, because the feature does not work for
 * root.  We use the saved IDs in seteuid/setegid, which are not currently
 * part of the POSIX 1003.1 specification.  XXX revisit for 1003.1-2001
 * as this is now mandatory.
 */
#ifdef	_NOT_AVAILABLE
#define	_POSIX_SAVED_IDS	1 /* saved set-user-ID and set-group-ID */
#endif
# 95 "/usr/include/sys/unistd.h" 3 4

/* Define the POSIX.1 version we target for compliance. */
#define	_POSIX_VERSION		200112L

/* access function */
#define	F_OK		0	/* test for existence of file */
#define	X_OK		0x01	/* test for execute or search permission */
#define	W_OK		0x02	/* test for write permission */
#define	R_OK		0x04	/* test for read permission */

/* whence values for lseek(2) */
#ifndef SEEK_SET
#define	SEEK_SET	0	/* set file offset to offset */
#define	SEEK_CUR	1	/* set file offset to current plus offset */
#define	SEEK_END	2	/* set file offset to EOF plus offset */
#endif
# 111 "/usr/include/sys/unistd.h" 3 4
#if __BSD_VISIBLE
#define	SEEK_DATA	3	/* set file offset to next data past offset */
#define	SEEK_HOLE	4	/* set file offset to next hole past offset */
#endif
# 115 "/usr/include/sys/unistd.h" 3 4

#ifndef _POSIX_SOURCE
/* whence values for lseek(2); renamed by POSIX 1003.1 */
#define	L_SET		SEEK_SET
#define	L_INCR		SEEK_CUR
#define	L_XTND		SEEK_END
#endif
# 122 "/usr/include/sys/unistd.h" 3 4

/* configurable pathname variables */
#define	_PC_LINK_MAX		 1
#define	_PC_MAX_CANON		 2
#define	_PC_MAX_INPUT		 3
#define	_PC_NAME_MAX		 4
#define	_PC_PATH_MAX		 5
#define	_PC_PIPE_BUF		 6
#define	_PC_CHOWN_RESTRICTED	 7
#define	_PC_NO_TRUNC		 8
#define	_PC_VDISABLE		 9

#if __POSIX_VISIBLE >= 199309
#define	_PC_ASYNC_IO		53
#define	_PC_PRIO_IO		54
#define	_PC_SYNC_IO		55
#endif
# 139 "/usr/include/sys/unistd.h" 3 4

#if __POSIX_VISIBLE >= 200112
#define	_PC_ALLOC_SIZE_MIN	10
#define	_PC_FILESIZEBITS	12
#define	_PC_REC_INCR_XFER_SIZE	14
#define	_PC_REC_MAX_XFER_SIZE	15
#define	_PC_REC_MIN_XFER_SIZE	16
#define	_PC_REC_XFER_ALIGN	17
#define	_PC_SYMLINK_MAX		18
#endif
# 149 "/usr/include/sys/unistd.h" 3 4

#if __BSD_VISIBLE
#define	_PC_ACL_EXTENDED	59
#define	_PC_ACL_PATH_MAX	60
#define	_PC_CAP_PRESENT		61
#define	_PC_INF_PRESENT		62
#define	_PC_MAC_PRESENT		63
#define	_PC_ACL_NFS4		64
#endif
# 158 "/usr/include/sys/unistd.h" 3 4

/* From OpenSolaris, used by SEEK_DATA/SEEK_HOLE. */
#define	_PC_MIN_HOLE_SIZE	21

#if __BSD_VISIBLE
/*
 * rfork() options.
 *
 * XXX currently, some operations without RFPROC set are not supported.
 */
#define	RFNAMEG		(1<<0)	/* UNIMPL new plan9 `name space' */
#define	RFENVG		(1<<1)	/* UNIMPL copy plan9 `env space' */
#define	RFFDG		(1<<2)	/* copy fd table */
#define	RFNOTEG		(1<<3)	/* UNIMPL create new plan9 `note group' */
#define	RFPROC		(1<<4)	/* change child (else changes curproc) */
#define	RFMEM		(1<<5)	/* share `address space' */
#define	RFNOWAIT	(1<<6)	/* give child to init */
#define	RFCNAMEG	(1<<10)	/* UNIMPL zero plan9 `name space' */
#define	RFCENVG		(1<<11)	/* UNIMPL zero plan9 `env space' */
#define	RFCFDG		(1<<12)	/* close all fds, zero fd table */
#define	RFTHREAD	(1<<13)	/* enable kernel thread support */
#define	RFSIGSHARE	(1<<14)	/* share signal handlers */
#define	RFLINUXTHPN	(1<<16)	/* do linux clone exit parent notification */
#define	RFSTOPPED	(1<<17)	/* leave child in a stopped state */
#define	RFHIGHPID	(1<<18)	/* use a pid higher than 10 (idleproc) */
#define	RFTSIGZMB	(1<<19)	/* select signal for exit parent notification */
#define	RFTSIGSHIFT	20	/* selected signal number is in bits 20-27  */
#define	RFTSIGMASK	0xFF
#define	RFTSIGNUM(flags)	(((flags) >> RFTSIGSHIFT) & RFTSIGMASK)
#define	RFTSIGFLAGS(signum)	((signum) << RFTSIGSHIFT)
#define	RFPROCDESC	(1<<28)	/* return a process descriptor */
#define	RFPPWAIT	(1<<31)	/* parent sleeps until child exits (vfork) */
#define	RFFLAGS		(RFFDG | RFPROC | RFMEM | RFNOWAIT | RFCFDG | \
    RFTHREAD | RFSIGSHARE | RFLINUXTHPN | RFSTOPPED | RFHIGHPID | RFTSIGZMB | \
    RFPROCDESC | RFPPWAIT)
#define	RFKERNELONLY	(RFSTOPPED | RFHIGHPID | RFPPWAIT | RFPROCDESC)

#endif /* __BSD_VISIBLE */
# 196 "/usr/include/sys/unistd.h" 3 4

#endif /* !_SYS_UNISTD_H_ */
# 198 "/usr/include/sys/unistd.h" 3 4
# 39 "/usr/include/unistd.h" 2 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_null.h>
#endif /* expanded by -frewrite-includes */
# 40 "/usr/include/unistd.h" 3 4
#if 0 /* expanded by -frewrite-includes */
#include <sys/_types.h>
#endif /* expanded by -frewrite-includes */
# 41 "/usr/include/unistd.h" 3 4

#ifndef _GID_T_DECLARED
typedef	__gid_t		gid_t;
#define	_GID_T_DECLARED
#endif
# 46 "/usr/include/unistd.h" 3 4

#ifndef _OFF_T_DECLARED
typedef	__off_t		off_t;
#define	_OFF_T_DECLARED
#endif
# 51 "/usr/include/unistd.h" 3 4

#ifndef _PID_T_DECLARED
typedef	__pid_t		pid_t;
#define	_PID_T_DECLARED
#endif
# 56 "/usr/include/unistd.h" 3 4

#ifndef _SIZE_T_DECLARED
typedef	__size_t	size_t;
#define	_SIZE_T_DECLARED
#endif
# 61 "/usr/include/unistd.h" 3 4

#ifndef _SSIZE_T_DECLARED
typedef	__ssize_t	ssize_t;
#define	_SSIZE_T_DECLARED
#endif
# 66 "/usr/include/unistd.h" 3 4

#ifndef _UID_T_DECLARED
typedef	__uid_t		uid_t;
#define	_UID_T_DECLARED
#endif
# 71 "/usr/include/unistd.h" 3 4

#ifndef _USECONDS_T_DECLARED
typedef	__useconds_t	useconds_t;
#define	_USECONDS_T_DECLARED
#endif
# 76 "/usr/include/unistd.h" 3 4

#define	STDIN_FILENO	0	/* standard input file descriptor */
#define	STDOUT_FILENO	1	/* standard output file descriptor */
#define	STDERR_FILENO	2	/* standard error file descriptor */

#if __XSI_VISIBLE || __POSIX_VISIBLE >= 200112
#define	F_ULOCK		0	/* unlock locked section */
#define	F_LOCK		1	/* lock a section for exclusive use */
#define	F_TLOCK		2	/* test and lock a section for exclusive use */
#define	F_TEST		3	/* test a section for locks by other procs */
#endif
# 87 "/usr/include/unistd.h" 3 4

/*
 * POSIX options and option groups we unconditionally do or don't
 * implement.  This list includes those options which are exclusively
 * implemented (or not) in user mode.  Please keep this list in
 * alphabetical order.
 *
 * Anything which is defined as zero below **must** have an
 * implementation for the corresponding sysconf() which is able to
 * determine conclusively whether or not the feature is supported.
 * Anything which is defined as other than -1 below **must** have
 * complete headers, types, and function declarations as specified by
 * the POSIX standard; however, if the relevant sysconf() function
 * returns -1, the functions may be stubbed out.
 */
#define	_POSIX_BARRIERS			200112L
#define	_POSIX_CPUTIME			200112L
#define	_POSIX_READER_WRITER_LOCKS	200112L
#define	_POSIX_REGEXP			1
#define	_POSIX_SHELL			1
#define	_POSIX_SPAWN			200112L
#define	_POSIX_SPIN_LOCKS		200112L
#define	_POSIX_THREAD_ATTR_STACKADDR	200112L
#define	_POSIX_THREAD_ATTR_STACKSIZE	200112L
#define	_POSIX_THREAD_CPUTIME		200112L
#define	_POSIX_THREAD_PRIO_INHERIT	200112L
#define	_POSIX_THREAD_PRIO_PROTECT	200112L
#define	_POSIX_THREAD_PRIORITY_SCHEDULING 200112L
#define	_POSIX_THREAD_PROCESS_SHARED	-1
#define	_POSIX_THREAD_SAFE_FUNCTIONS	-1
#define	_POSIX_THREAD_SPORADIC_SERVER	-1
#define	_POSIX_THREADS			200112L
#define	_POSIX_TRACE			-1
#define	_POSIX_TRACE_EVENT_FILTER	-1
#define	_POSIX_TRACE_INHERIT		-1
#define	_POSIX_TRACE_LOG		-1
#define	_POSIX2_C_BIND			200112L	/* mandatory */
#define	_POSIX2_C_DEV			-1 /* need c99 utility */
#define	_POSIX2_CHAR_TERM		1
#define	_POSIX2_FORT_DEV		-1 /* need fort77 utility */
#define	_POSIX2_FORT_RUN		200112L
#define	_POSIX2_LOCALEDEF		-1
#define	_POSIX2_PBS			-1
#define	_POSIX2_PBS_ACCOUNTING		-1
#define	_POSIX2_PBS_CHECKPOINT		-1
#define	_POSIX2_PBS_LOCATE		-1
#define	_POSIX2_PBS_MESSAGE		-1
#define	_POSIX2_PBS_TRACK		-1
#define	_POSIX2_SW_DEV			-1 /* XXX ??? */
#define	_POSIX2_UPE			200112L
#define	_V6_ILP32_OFF32			-1
#define	_V6_ILP32_OFFBIG		0
#define	_V6_LP64_OFF64			0
#define	_V6_LPBIG_OFFBIG		-1

#if __XSI_VISIBLE
#define	_XOPEN_CRYPT			-1 /* XXX ??? */
#define	_XOPEN_ENH_I18N			-1 /* mandatory in XSI */
#define	_XOPEN_LEGACY			-1
#define	_XOPEN_REALTIME			-1
#define	_XOPEN_REALTIME_THREADS		-1
#define	_XOPEN_UNIX			-1
#endif
# 150 "/usr/include/unistd.h" 3 4

/* Define the POSIX.2 version we target for compliance. */
#define	_POSIX2_VERSION		199212L

/*
 * POSIX-style system configuration variable accessors (for the
 * sysconf function).  The kernel does not directly implement the
 * sysconf() interface; rather, a C library stub translates references
 * to sysconf() into calls to sysctl() using a giant switch statement.
 * Those that are marked `user' are implemented entirely in the C
 * library and never query the kernel.  pathconf() is implemented
 * directly by the kernel so those are not defined here.
 */
#define	_SC_ARG_MAX		 1
#define	_SC_CHILD_MAX		 2
#define	_SC_CLK_TCK		 3
#define	_SC_NGROUPS_MAX		 4
#define	_SC_OPEN_MAX		 5
#define	_SC_JOB_CONTROL		 6
#define	_SC_SAVED_IDS		 7
#define	_SC_VERSION		 8
#define	_SC_BC_BASE_MAX		 9 /* user */
#define	_SC_BC_DIM_MAX		10 /* user */
#define	_SC_BC_SCALE_MAX	11 /* user */
#define	_SC_BC_STRING_MAX	12 /* user */
#define	_SC_COLL_WEIGHTS_MAX	13 /* user */
#define	_SC_EXPR_NEST_MAX	14 /* user */
#define	_SC_LINE_MAX		15 /* user */
#define	_SC_RE_DUP_MAX		16 /* user */
#define	_SC_2_VERSION		17 /* user */
#define	_SC_2_C_BIND		18 /* user */
#define	_SC_2_C_DEV		19 /* user */
#define	_SC_2_CHAR_TERM		20 /* user */
#define	_SC_2_FORT_DEV		21 /* user */
#define	_SC_2_FORT_RUN		22 /* user */
#define	_SC_2_LOCALEDEF		23 /* user */
#define	_SC_2_SW_DEV		24 /* user */
#define	_SC_2_UPE		25 /* user */
#define	_SC_STREAM_MAX		26 /* user */
#define	_SC_TZNAME_MAX		27 /* user */

#if __POSIX_VISIBLE >= 199309
#define	_SC_ASYNCHRONOUS_IO	28
#define	_SC_MAPPED_FILES	29
#define	_SC_MEMLOCK		30
#define	_SC_MEMLOCK_RANGE	31
#define	_SC_MEMORY_PROTECTION	32
#define	_SC_MESSAGE_PASSING	33
#define	_SC_PRIORITIZED_IO	34
#define	_SC_PRIORITY_SCHEDULING	35
#define	_SC_REALTIME_SIGNALS	36
#define	_SC_SEMAPHORES		37
#define	_SC_FSYNC		38
#define	_SC_SHARED_MEMORY_OBJECTS 39
#define	_SC_SYNCHRONIZED_IO	40
#define	_SC_TIMERS		41
#define	_SC_AIO_LISTIO_MAX	42
#define	_SC_AIO_MAX		43
#define	_SC_AIO_PRIO_DELTA_MAX	44
#define	_SC_DELAYTIMER_MAX	45
#define	_SC_MQ_OPEN_MAX		46
#define	_SC_PAGESIZE		47
#define	_SC_RTSIG_MAX		48
#define	_SC_SEM_NSEMS_MAX	49
#define	_SC_SEM_VALUE_MAX	50
#define	_SC_SIGQUEUE_MAX	51
#define	_SC_TIMER_MAX		52
#endif
# 218 "/usr/include/unistd.h" 3 4

#if __POSIX_VISIBLE >= 200112
#define	_SC_2_PBS		59 /* user */
#define	_SC_2_PBS_ACCOUNTING	60 /* user */
#define	_SC_2_PBS_CHECKPOINT	61 /* user */
#define	_SC_2_PBS_LOCATE	62 /* user */
#define	_SC_2_PBS_MESSAGE	63 /* user */
#define	_SC_2_PBS_TRACK		64 /* user */
#define	_SC_ADVISORY_INFO	65
#define	_SC_BARRIERS		66 /* user */
#define	_SC_CLOCK_SELECTION	67
#define	_SC_CPUTIME		68
#define	_SC_FILE_LOCKING	69
#define	_SC_GETGR_R_SIZE_MAX	70 /* user */
#define	_SC_GETPW_R_SIZE_MAX	71 /* user */
#define	_SC_HOST_NAME_MAX	72
#define	_SC_LOGIN_NAME_MAX	73
#define	_SC_MONOTONIC_CLOCK	74
#define	_SC_MQ_PRIO_MAX		75
#define	_SC_READER_WRITER_LOCKS	76 /* user */
#define	_SC_REGEXP		77 /* user */
#define	_SC_SHELL		78 /* user */
#define	_SC_SPAWN		79 /* user */
#define	_SC_SPIN_LOCKS		80 /* user */
#define	_SC_SPORADIC_SERVER	81
#define	_SC_THREAD_ATTR_STACKADDR 82 /* user */
#define	_SC_THREAD_ATTR_STACKSIZE 83 /* user */
#define	_SC_THREAD_CPUTIME	84 /* user */
#define	_SC_THREAD_DESTRUCTOR_ITERATIONS 85 /* user */
#define	_SC_THREAD_KEYS_MAX	86 /* user */
#define	_SC_THREAD_PRIO_INHERIT	87 /* user */
#define	_SC_THREAD_PRIO_PROTECT	88 /* user */
#define	_SC_THREAD_PRIORITY_SCHEDULING 89 /* user */
#define	_SC_THREAD_PROCESS_SHARED 90 /* user */
#define	_SC_THREAD_SAFE_FUNCTIONS 91 /* user */
#define	_SC_THREAD_SPORADIC_SERVER 92 /* user */
#define	_SC_THREAD_STACK_MIN	93 /* user */
#define	_SC_THREAD_THREADS_MAX	94 /* user */
#define	_SC_TIMEOUTS		95 /* user */
#define	_SC_THREADS		96 /* user */
#define	_SC_TRACE		97 /* user */
#define	_SC_TRACE_EVENT_FILTER	98 /* user */
#define	_SC_TRACE_INHERIT	99 /* user */
#define	_SC_TRACE_LOG		100 /* user */
#define	_SC_TTY_NAME_MAX	101 /* user */
#define	_SC_TYPED_MEMORY_OBJECTS 102
#define	_SC_V6_ILP32_OFF32	103 /* user */
#define	_SC_V6_ILP32_OFFBIG	104 /* user */
#define	_SC_V6_LP64_OFF64	105 /* user */
#define	_SC_V6_LPBIG_OFFBIG	106 /* user */
#define	_SC_IPV6		118
#define	_SC_RAW_SOCKETS		119
#define	_SC_SYMLOOP_MAX		120
#endif
# 272 "/usr/include/unistd.h" 3 4

#if __XSI_VISIBLE
#define	_SC_ATEXIT_MAX		107 /* user */
#define	_SC_IOV_MAX		56
#define	_SC_PAGE_SIZE		_SC_PAGESIZE
#define	_SC_XOPEN_CRYPT		108 /* user */
#define	_SC_XOPEN_ENH_I18N	109 /* user */
#define	_SC_XOPEN_LEGACY	110 /* user */
#define	_SC_XOPEN_REALTIME	111
#define	_SC_XOPEN_REALTIME_THREADS 112
#define	_SC_XOPEN_SHM		113
#define	_SC_XOPEN_STREAMS	114
#define	_SC_XOPEN_UNIX		115
#define	_SC_XOPEN_VERSION	116
#define	_SC_XOPEN_XCU_VERSION	117 /* user */
#endif
# 288 "/usr/include/unistd.h" 3 4

#if __BSD_VISIBLE
#define	_SC_NPROCESSORS_CONF	57
#define	_SC_NPROCESSORS_ONLN	58
#define	_SC_CPUSET_SIZE		122
#endif
# 294 "/usr/include/unistd.h" 3 4

/* Extensions found in Solaris and Linux. */
#define	_SC_PHYS_PAGES		121

/* Keys for the confstr(3) function. */
#if __POSIX_VISIBLE >= 199209
#define	_CS_PATH		1	/* default value of PATH */
#endif
# 302 "/usr/include/unistd.h" 3 4

#if __POSIX_VISIBLE >= 200112
#define	_CS_POSIX_V6_ILP32_OFF32_CFLAGS		2
#define	_CS_POSIX_V6_ILP32_OFF32_LDFLAGS	3
#define	_CS_POSIX_V6_ILP32_OFF32_LIBS		4
#define	_CS_POSIX_V6_ILP32_OFFBIG_CFLAGS	5
#define	_CS_POSIX_V6_ILP32_OFFBIG_LDFLAGS	6
#define	_CS_POSIX_V6_ILP32_OFFBIG_LIBS		7
#define	_CS_POSIX_V6_LP64_OFF64_CFLAGS		8
#define	_CS_POSIX_V6_LP64_OFF64_LDFLAGS		9
#define	_CS_POSIX_V6_LP64_OFF64_LIBS		10
#define	_CS_POSIX_V6_LPBIG_OFFBIG_CFLAGS	11
#define	_CS_POSIX_V6_LPBIG_OFFBIG_LDFLAGS	12
#define	_CS_POSIX_V6_LPBIG_OFFBIG_LIBS		13
#define	_CS_POSIX_V6_WIDTH_RESTRICTED_ENVS	14
#endif
# 318 "/usr/include/unistd.h" 3 4

__BEGIN_DECLS
/* 1003.1-1990 */
void	 _exit(int) __dead2;
int	 access(const char *, int);
unsigned int	 alarm(unsigned int);
int	 chdir(const char *);
int	 chown(const char *, uid_t, gid_t);
int	 close(int);
void	 closefrom(int);
int	 dup(int);
int	 dup2(int, int);
int	 execl(const char *, const char *, ...);
int	 execle(const char *, const char *, ...);
int	 execlp(const char *, const char *, ...);
int	 execv(const char *, char * const *);
int	 execve(const char *, char * const *, char * const *);
int	 execvp(const char *, char * const *);
pid_t	 fork(void);
long	 fpathconf(int, int);
char	*getcwd(char *, size_t);
gid_t	 getegid(void);
uid_t	 geteuid(void);
gid_t	 getgid(void);
int	 getgroups(int, gid_t []);
char	*getlogin(void);
pid_t	 getpgrp(void);
pid_t	 getpid(void);
pid_t	 getppid(void);
uid_t	 getuid(void);
int	 isatty(int);
int	 link(const char *, const char *);
#ifndef _LSEEK_DECLARED
#define	_LSEEK_DECLARED
off_t	 lseek(int, off_t, int);
#endif
# 354 "/usr/include/unistd.h" 3 4
long	 pathconf(const char *, int);
int	 pause(void);
int	 pipe(int *);
ssize_t	 read(int, void *, size_t);
int	 rmdir(const char *);
int	 setgid(gid_t);
int	 setpgid(pid_t, pid_t);
pid_t	 setsid(void);
int	 setuid(uid_t);
unsigned int	 sleep(unsigned int);
long	 sysconf(int);
pid_t	 tcgetpgrp(int);
int	 tcsetpgrp(int, pid_t);
char	*ttyname(int);
int	ttyname_r(int, char *, size_t);
int	 unlink(const char *);
ssize_t	 write(int, const void *, size_t);

/* 1003.2-1992 */
#if __POSIX_VISIBLE >= 199209 || __XSI_VISIBLE
size_t	 confstr(int, char *, size_t);
#ifndef _GETOPT_DECLARED
#define	_GETOPT_DECLARED
int	 getopt(int, char * const [], const char *);

extern char *optarg;			/* getopt(3) external variables */
extern int optind, opterr, optopt;
#endif /* _GETOPT_DECLARED */
# 382 "/usr/include/unistd.h" 3 4
#endif
# 383 "/usr/include/unistd.h" 3 4

/* ISO/IEC 9945-1: 1996 */
#if __POSIX_VISIBLE >= 199506 || __XSI_VISIBLE
int	 fsync(int);

/*
 * ftruncate() was in the POSIX Realtime Extension (it's used for shared
 * memory), but truncate() was not.
 */
#ifndef _FTRUNCATE_DECLARED
#define	_FTRUNCATE_DECLARED
int	 ftruncate(int, off_t);
#endif
# 396 "/usr/include/unistd.h" 3 4
#endif
# 397 "/usr/include/unistd.h" 3 4

#if __POSIX_VISIBLE >= 199506
int	 getlogin_r(char *, int);
#endif
# 401 "/usr/include/unistd.h" 3 4

/* 1003.1-2001 */
#if __POSIX_VISIBLE >= 200112 || __XSI_VISIBLE
int	 fchown(int, uid_t, gid_t);
ssize_t	 readlink(const char * __restrict, char * __restrict, size_t);
#endif
# 407 "/usr/include/unistd.h" 3 4
#if __POSIX_VISIBLE >= 200112
int	 gethostname(char *, size_t);
int	 setegid(gid_t);
int	 seteuid(uid_t);
#endif
# 412 "/usr/include/unistd.h" 3 4

/* 1003.1-2008 */
#if __POSIX_VISIBLE >= 200809 || __XSI_VISIBLE
int	 getsid(pid_t _pid);
int	 fchdir(int);
int	 getpgid(pid_t _pid);
int	 lchown(const char *, uid_t, gid_t);
ssize_t	 pread(int, void *, size_t, off_t);
ssize_t	 pwrite(int, const void *, size_t, off_t);

/* See comment at ftruncate() above. */
#ifndef _TRUNCATE_DECLARED
#define	_TRUNCATE_DECLARED
int	 truncate(const char *, off_t);
#endif
# 427 "/usr/include/unistd.h" 3 4
#endif /* __POSIX_VISIBLE >= 200809 || __XSI_VISIBLE */
# 428 "/usr/include/unistd.h" 3 4

#if __POSIX_VISIBLE >= 200809
int	faccessat(int, const char *, int, int);
int	fchownat(int, const char *, uid_t, gid_t, int);
int	fexecve(int, char *const [], char *const []);
int	linkat(int, const char *, int, const char *, int);
ssize_t	readlinkat(int, const char * __restrict, char * __restrict, size_t);
int	symlinkat(const char *, int, const char *);
int	unlinkat(int, const char *, int);
#endif /* __POSIX_VISIBLE >= 200809 */
# 438 "/usr/include/unistd.h" 3 4

/*
 * symlink() was originally in POSIX.1a, which was withdrawn after
 * being overtaken by events (1003.1-2001).  It was in XPG4.2, and of
 * course has been in BSD since 4.2.
 */
#if __POSIX_VISIBLE >= 200112 || __XSI_VISIBLE >= 402
int	 symlink(const char * __restrict, const char * __restrict);
#endif
# 447 "/usr/include/unistd.h" 3 4

/* X/Open System Interfaces */
#if __XSI_VISIBLE
char	*crypt(const char *, const char *);
/* char	*ctermid(char *); */		/* XXX ??? */
int	 encrypt(char *, int);
long	 gethostid(void);
int	 lockf(int, int, off_t);
int	 nice(int);
int	 setregid(gid_t, gid_t);
int	 setreuid(uid_t, uid_t);

#ifndef _SWAB_DECLARED
#define _SWAB_DECLARED
void	 swab(const void * __restrict, void * __restrict, ssize_t);
#endif /* _SWAB_DECLARED */
# 463 "/usr/include/unistd.h" 3 4

void	 sync(void);

#endif /* __XSI_VISIBLE */
# 467 "/usr/include/unistd.h" 3 4

#if (__XSI_VISIBLE && __XSI_VISIBLE <= 500) || __BSD_VISIBLE
int	 brk(const void *);
int	 chroot(const char *);
int	 getdtablesize(void);
int	 getpagesize(void) __pure2;
char	*getpass(const char *);
void	*sbrk(intptr_t);
#endif
# 476 "/usr/include/unistd.h" 3 4

#if (__XSI_VISIBLE && __XSI_VISIBLE <= 600) || __BSD_VISIBLE
char	*getwd(char *);			/* obsoleted by getcwd() */
useconds_t
	 ualarm(useconds_t, useconds_t);
int	 usleep(useconds_t);
pid_t	 vfork(void) __returns_twice;
#endif
# 484 "/usr/include/unistd.h" 3 4

#if __BSD_VISIBLE
struct timeval;				/* select(2) */
int	 acct(const char *);
int	 async_daemon(void);
int	 check_utility_compat(const char *);
const char *
	 crypt_get_format(void);
int	 crypt_set_format(const char *);
int	 des_cipher(const char *, char *, long, int);
int	 des_setkey(const char *key);
int	 dup3(int, int, int);
int	 eaccess(const char *, int);
void	 endusershell(void);
int	 exect(const char *, char * const *, char * const *);
int	 execvP(const char *, const char *, char * const *);
int	 feature_present(const char *);
char	*fflagstostr(u_long);
int	 getdomainname(char *, int);
int	 getgrouplist(const char *, gid_t, gid_t *, int *);
int	 getloginclass(char *, size_t);
mode_t	 getmode(const void *, mode_t);
int	 getosreldate(void);
int	 getpeereid(int, uid_t *, gid_t *);
int	 getresgid(gid_t *, gid_t *, gid_t *);
int	 getresuid(uid_t *, uid_t *, uid_t *);
char	*getusershell(void);
int	 initgroups(const char *, gid_t);
int	 iruserok(unsigned long, int, const char *, const char *);
int	 iruserok_sa(const void *, int, int, const char *, const char *);
int	 issetugid(void);
void	__FreeBSD_libc_enter_restricted_mode(void);
long	 lpathconf(const char *, int);
#ifndef _MKDTEMP_DECLARED
char	*mkdtemp(char *);
#define	_MKDTEMP_DECLARED
#endif
# 521 "/usr/include/unistd.h" 3 4
#ifndef	_MKNOD_DECLARED
int	 mknod(const char *, mode_t, dev_t);
#define	_MKNOD_DECLARED
#endif
# 525 "/usr/include/unistd.h" 3 4
#ifndef _MKSTEMP_DECLARED
int	 mkstemp(char *);
#define	_MKSTEMP_DECLARED
#endif
# 529 "/usr/include/unistd.h" 3 4
int	 mkstemps(char *, int);
#ifndef _MKTEMP_DECLARED
char	*mktemp(char *);
#define	_MKTEMP_DECLARED
#endif
# 534 "/usr/include/unistd.h" 3 4
int	 nfssvc(int, void *);
int	 nlm_syscall(int, int, int, char **);
int	 pipe2(int *, int);
int	 profil(char *, size_t, vm_offset_t, int);
int	 rcmd(char **, int, const char *, const char *, const char *, int *);
int	 rcmd_af(char **, int, const char *,
		const char *, const char *, int *, int);
int	 rcmdsh(char **, int, const char *,
		const char *, const char *, const char *);
char	*re_comp(const char *);
int	 re_exec(const char *);
int	 reboot(int);
int	 revoke(const char *);
pid_t	 rfork(int);
pid_t	 rfork_thread(int, void *, int (*)(void *), void *);
int	 rresvport(int *);
int	 rresvport_af(int *, int);
int	 ruserok(const char *, int, const char *, const char *);
#if __BSD_VISIBLE
#ifndef _SELECT_DECLARED
#define	_SELECT_DECLARED
int	 select(int, fd_set *, fd_set *, fd_set *, struct timeval *);
#endif
# 557 "/usr/include/unistd.h" 3 4
#endif
# 558 "/usr/include/unistd.h" 3 4
int	 setdomainname(const char *, int);
int	 setgroups(int, const gid_t *);
void	 sethostid(long);
int	 sethostname(const char *, int);
#ifndef _SETKEY_DECLARED
int	 setkey(const char *);
#define	_SETKEY_DECLARED
#endif
# 566 "/usr/include/unistd.h" 3 4
int	 setlogin(const char *);
int	 setloginclass(const char *);
void	*setmode(const char *);
int	 setpgrp(pid_t, pid_t);			/* obsoleted by setpgid() */
void	 setproctitle(const char *_fmt, ...) __printf0like(1, 2);
int	 setresgid(gid_t, gid_t, gid_t);
int	 setresuid(uid_t, uid_t, uid_t);
int	 setrgid(gid_t);
int	 setruid(uid_t);
void	 setusershell(void);
int	 strtofflags(char **, u_long *, u_long *);
int	 swapon(const char *);
int	 swapoff(const char *);
int	 syscall(int, ...);
off_t	 __syscall(quad_t, ...);
int	 undelete(const char *);
int	 unwhiteout(const char *);
void	*valloc(size_t);			/* obsoleted by malloc() */

#ifndef _OPTRESET_DECLARED
#define	_OPTRESET_DECLARED
extern int optreset;			/* getopt(3) external variable */
#endif
# 589 "/usr/include/unistd.h" 3 4
#endif /* __BSD_VISIBLE */
# 590 "/usr/include/unistd.h" 3 4
__END_DECLS

#endif /* !_UNISTD_H_ */
# 593 "/usr/include/unistd.h" 3 4
# 125 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h" 2
#elif cimg_OS==2
# 126 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifndef NOMINMAX
#define NOMINMAX
#endif
# 129 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include <windows.h>
#endif /* expanded by -frewrite-includes */
# 130 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifndef _WIN32_IE
#define _WIN32_IE 0x0400
#endif
# 133 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include <shlobj.h>
#endif /* expanded by -frewrite-includes */
# 134 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include <process.h>
#endif /* expanded by -frewrite-includes */
# 135 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include <io.h>
#endif /* expanded by -frewrite-includes */
# 136 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#define cimg_snprintf _snprintf
#define cimg_vsnprintf _vsnprintf
#endif
# 139 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifndef cimg_snprintf
#if 0 /* expanded by -frewrite-includes */
#include <stdio.h>
#endif /* expanded by -frewrite-includes */
# 141 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#define cimg_snprintf snprintf
#define cimg_vsnprintf vsnprintf
#endif
# 144 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Configure filename separator.
//
// Filename separator is set by default to '/', except for Windows where it is '\'.
#ifndef cimg_file_separator
#if cimg_OS==2
#define cimg_file_separator '\\'
#else
# 152 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#define cimg_file_separator '/'
#endif
# 154 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 155 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Configure verbosity of output messages.
//
// Define 'cimg_verbosity' to: '0' to hide library messages (quiet mode).
//                             '1' to output library messages on the console.
//                             '2' to output library messages on a basic dialog window (default behavior).
//                             '3' to do as '1' + add extra warnings (may slow down the code!).
//                             '4' to do as '2' + add extra warnings (may slow down the code!).
//
// Define 'cimg_strict_warnings' to replace warning messages by exception throwns.
//
// Define 'cimg_use_vt100' to allow output of color messages on VT100-compatible terminals.
#ifndef cimg_verbosity
#define cimg_verbosity 2
#elif !(cimg_verbosity==0 || cimg_verbosity==1 || cimg_verbosity==2 || cimg_verbosity==3 || cimg_verbosity==4)
# 170 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#error CImg Library: Configuration variable 'cimg_verbosity' is badly defined.
#error (should be { 0=quiet | 1=console | 2=dialog | 3=console+warnings | 4=dialog+warnings }).
#endif
# 173 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Configure display framework.
//
// Define 'cimg_display' to: '0' to disable display capabilities.
//                           '1' to use the X-Window framework (X11).
//                           '2' to use the Microsoft GDI32 framework.
#ifndef cimg_display
#if cimg_OS==0
#define cimg_display 0
#elif cimg_OS==1
# 183 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if defined(__MACOSX__) || defined(__APPLE__)
#define cimg_display 1
#else
# 186 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#define cimg_display 1
#endif
# 188 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#elif cimg_OS==2
# 189 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#define cimg_display 2
#endif
# 191 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#elif !(cimg_display==0 || cimg_display==1 || cimg_display==2)
# 192 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#error CImg Library: Configuration variable 'cimg_display' is badly defined.
#error (should be { 0=none | 1=X-Window (X11) | 2=Microsoft GDI32 }).
#endif
# 195 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Include display-specific headers.
#if cimg_display==1
#if 0 /* expanded by -frewrite-includes */
#include <X11/Xlib.h>
#endif /* expanded by -frewrite-includes */
# 199 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include <X11/Xutil.h>
#endif /* expanded by -frewrite-includes */
# 200 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include <X11/keysym.h>
#endif /* expanded by -frewrite-includes */
# 201 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include <pthread.h>
#endif /* expanded by -frewrite-includes */
# 202 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_use_xshm
#if 0 /* expanded by -frewrite-includes */
#include <sys/ipc.h>
#endif /* expanded by -frewrite-includes */
# 204 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include <sys/shm.h>
#endif /* expanded by -frewrite-includes */
# 205 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include <X11/extensions/XShm.h>
#endif /* expanded by -frewrite-includes */
# 206 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 207 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_use_xrandr
#if 0 /* expanded by -frewrite-includes */
#include <X11/extensions/Xrandr.h>
#endif /* expanded by -frewrite-includes */
# 209 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 210 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 211 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifndef cimg_appname
#define cimg_appname "CImg"
#endif
# 214 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Configure OpenMP support.
// (http://www.openmp.org)
//
// Define 'cimg_use_openmp' to enable OpenMP support.
//
// OpenMP directives may be used in a (very) few CImg functions to get
// advantages of multi-core CPUs.
#ifdef cimg_use_openmp
#if 0 /* expanded by -frewrite-includes */
#include "omp.h"
#endif /* expanded by -frewrite-includes */
# 224 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 225 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Configure OpenCV support.
// (http://opencv.willowgarage.com/wiki/)
//
// Define 'cimg_use_opencv' to enable OpenCV support.
//
// OpenCV library may be used to access images from cameras
// (see method 'CImg<T>::load_camera()').
#ifdef cimg_use_opencv
#ifdef True
#undef True
#define _cimg_redefine_True
#endif
# 238 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef False
#undef False
#define _cimg_redefine_False
#endif
# 242 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstddef>
#endif /* expanded by -frewrite-includes */
# 243 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include "cv.h"
#endif /* expanded by -frewrite-includes */
# 244 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include "highgui.h"
#endif /* expanded by -frewrite-includes */
# 245 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 246 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Configure LibPNG support.
// (http://www.libpng.org)
//
// Define 'cimg_use_png' to enable LibPNG support.
//
// PNG library may be used to get a native support of '.png' files.
// (see methods 'CImg<T>::{load,save}_png()'.
#ifdef cimg_use_png
extern "C" {
#if 0 /* expanded by -frewrite-includes */
#include "png.h"
#endif /* expanded by -frewrite-includes */
# 257 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
}
#endif
# 259 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Configure LibJPEG support.
// (http://en.wikipedia.org/wiki/Libjpeg)
//
// Define 'cimg_use_jpeg' to enable LibJPEG support.
//
// JPEG library may be used to get a native support of '.jpg' files.
// (see methods 'CImg<T>::{load,save}_jpeg()').
#ifdef cimg_use_jpeg
extern "C" {
#if 0 /* expanded by -frewrite-includes */
#include "jpeglib.h"
#endif /* expanded by -frewrite-includes */
# 270 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include "setjmp.h"
#endif /* expanded by -frewrite-includes */
# 271 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
}
#endif
# 273 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Configure LibTIFF support.
// (http://www.libtiff.org)
//
// Define 'cimg_use_tiff' to enable LibTIFF support.
//
// TIFF library may be used to get a native support of '.tif' files.
// (see methods 'CImg[List]<T>::{load,save}_tiff()').
#ifdef cimg_use_tiff
extern "C" {
#define uint64 uint64_hack_
#define int64 int64_hack_
#if 0 /* expanded by -frewrite-includes */
#include "tiffio.h"
#endif /* expanded by -frewrite-includes */
# 286 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#undef uint64
#undef int64
}
#endif
# 290 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Configure LibMINC2 support.
// (http://en.wikibooks.org/wiki/MINC/Reference/MINC2.0_File_Format_Reference)
//
// Define 'cimg_use_minc2' to enable LibMINC2 support.
//
// MINC2 library may be used to get a native support of '.mnc' files.
// (see methods 'CImg<T>::{load,save}_minc2()').
#ifdef cimg_use_minc2
#if 0 /* expanded by -frewrite-includes */
#include "minc_io_simple_volume.h"
#endif /* expanded by -frewrite-includes */
# 300 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include "minc_1_simple.h"
#endif /* expanded by -frewrite-includes */
# 301 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include "minc_1_simple_rw.h"
#endif /* expanded by -frewrite-includes */
# 302 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 303 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Configure FFMPEG support.
// (http://www.ffmpeg.org)
//
// Define 'cimg_use_ffmpeg' to enable FFMPEG lib support.
//
// Avcodec and Avformat libraries from FFMPEG may be used
// to get a native support of various video file formats.
// (see methods 'CImg[List]<T>::load_ffmpeg()').
#ifdef cimg_use_ffmpeg
#if (defined(_STDINT_H) || defined(_STDINT_H_)) && !defined(UINT64_C)
#warning "__STDC_CONSTANT_MACROS has to be defined before including <stdint.h>, this file will probably not compile."
#endif
# 316 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifndef __STDC_CONSTANT_MACROS
#define __STDC_CONSTANT_MACROS // ...or stdint.h wont' define UINT64_C, needed by libavutil
#endif
# 319 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
extern "C" {
#if 0 /* expanded by -frewrite-includes */
#include <libavformat/avformat.h>
#endif /* expanded by -frewrite-includes */
# 321 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include <libavcodec/avcodec.h>
#endif /* expanded by -frewrite-includes */
# 322 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include <libswscale/swscale.h>
#endif /* expanded by -frewrite-includes */
# 323 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
}
#endif
# 325 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Configure Zlib support.
// (http://www.zlib.net)
//
// Define 'cimg_use_zlib' to enable Zlib support.
//
// Zlib library may be used to allow compressed data in '.cimgz' files
// (see methods 'CImg[List]<T>::{load,save}_cimg()').
#ifdef cimg_use_zlib
extern "C" {
#if 0 /* expanded by -frewrite-includes */
#include "zlib.h"
#endif /* expanded by -frewrite-includes */
# 336 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
}
#endif
# 338 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Configure Magick++ support.
// (http://www.imagemagick.org/Magick++)
//
// Define 'cimg_use_magick' to enable Magick++ support.
//
// Magick++ library may be used to get a native support of various image file formats.
// (see methods 'CImg<T>::{load,save}()').
#ifdef cimg_use_magick
#if 0 /* expanded by -frewrite-includes */
#include "Magick++.h"
#endif /* expanded by -frewrite-includes */
# 348 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 349 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Configure FFTW3 support.
// (http://www.fftw.org)
//
// Define 'cimg_use_fftw3' to enable libFFTW3 support.
//
// FFTW3 library may be used to efficiently compute the Fast Fourier Transform
// of image data, without restriction on the image size.
// (see method 'CImg[List]<T>::FFT()').
#ifdef cimg_use_fftw3
extern "C" {
#if 0 /* expanded by -frewrite-includes */
#include "fftw3.h"
#endif /* expanded by -frewrite-includes */
# 1 "/usr/local/include/fftw3.h" 1
/*
 * Copyright (c) 2003, 2007-11 Matteo Frigo
 * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
 *
 * The following statement of license applies *only* to this header file,
 * and *not* to the other files distributed with FFTW or derived therefrom:
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/***************************** NOTE TO USERS *********************************
 *
 *                 THIS IS A HEADER FILE, NOT A MANUAL
 *
 *    If you want to know how to use FFTW, please read the manual,
 *    online at http://www.fftw.org/doc/ and also included with FFTW.
 *    For a quick start, see the manual's tutorial section.
 *
 *   (Reading header files to learn how to use a library is a habit
 *    stemming from code lacking a proper manual.  Arguably, it's a
 *    *bad* habit in most cases, because header files can contain
 *    interfaces that are not part of the public, stable API.)
 *
 ****************************************************************************/

#ifndef FFTW3_H
#define FFTW3_H

#if 0 /* expanded by -frewrite-includes */
#include <stdio.h>
#endif /* expanded by -frewrite-includes */
# 51 "/usr/local/include/fftw3.h"

#ifdef __cplusplus
extern "C"
{
#endif /* __cplusplus */
# 56 "/usr/local/include/fftw3.h"

/* If <complex.h> is included, use the C99 complex type.  Otherwise
   define a type bit-compatible with C99 complex */
#if !defined(FFTW_NO_Complex) && defined(_Complex_I) && defined(complex) && defined(I)
#  define FFTW_DEFINE_COMPLEX(R, C) typedef R _Complex C
#else
# 62 "/usr/local/include/fftw3.h"
#  define FFTW_DEFINE_COMPLEX(R, C) typedef R C[2]
#endif
# 64 "/usr/local/include/fftw3.h"

#define FFTW_CONCAT(prefix, name) prefix ## name
#define FFTW_MANGLE_DOUBLE(name) FFTW_CONCAT(fftw_, name)
#define FFTW_MANGLE_FLOAT(name) FFTW_CONCAT(fftwf_, name)
#define FFTW_MANGLE_LONG_DOUBLE(name) FFTW_CONCAT(fftwl_, name)
#define FFTW_MANGLE_QUAD(name) FFTW_CONCAT(fftwq_, name)

/* IMPORTANT: for Windows compilers, you should add a line
        #define FFTW_DLL
   here and in kernel/ifftw.h if you are compiling/using FFTW as a
   DLL, in order to do the proper importing/exporting, or
   alternatively compile with -DFFTW_DLL or the equivalent
   command-line flag.  This is not necessary under MinGW/Cygwin, where
   libtool does the imports/exports automatically. */
#if defined(FFTW_DLL) && (defined(_WIN32) || defined(__WIN32__))
   /* annoying Windows syntax for shared-library declarations */
#  if defined(COMPILING_FFTW) /* defined in api.h when compiling FFTW */
#    define FFTW_EXTERN extern __declspec(dllexport) 
#  else /* user is calling FFTW; import symbol */
# 83 "/usr/local/include/fftw3.h"
#    define FFTW_EXTERN extern __declspec(dllimport) 
#  endif
# 85 "/usr/local/include/fftw3.h"
#else
# 86 "/usr/local/include/fftw3.h"
#  define FFTW_EXTERN extern
#endif
# 88 "/usr/local/include/fftw3.h"

enum fftw_r2r_kind_do_not_use_me {
     FFTW_R2HC=0, FFTW_HC2R=1, FFTW_DHT=2,
     FFTW_REDFT00=3, FFTW_REDFT01=4, FFTW_REDFT10=5, FFTW_REDFT11=6,
     FFTW_RODFT00=7, FFTW_RODFT01=8, FFTW_RODFT10=9, FFTW_RODFT11=10
};

struct fftw_iodim_do_not_use_me {
     int n;                     /* dimension size */
     int is;			/* input stride */
     int os;			/* output stride */
};

#if 0 /* expanded by -frewrite-includes */
#include <stddef.h> /* for ptrdiff_t */
#endif /* expanded by -frewrite-includes */
# 102 "/usr/local/include/fftw3.h"
struct fftw_iodim64_do_not_use_me {
     ptrdiff_t n;                     /* dimension size */
     ptrdiff_t is;			/* input stride */
     ptrdiff_t os;			/* output stride */
};

typedef void (*fftw_write_char_func_do_not_use_me)(char c, void *);
typedef int (*fftw_read_char_func_do_not_use_me)(void *);

/*
  huge second-order macro that defines prototypes for all API
  functions.  We expand this macro for each supported precision
 
  X: name-mangling macro
  R: real data type
  C: complex data type
*/

#define FFTW_DEFINE_API(X, R, C)					   \
									   \
FFTW_DEFINE_COMPLEX(R, C);						   \
									   \
typedef struct X(plan_s) *X(plan);					   \
									   \
typedef struct fftw_iodim_do_not_use_me X(iodim);			   \
typedef struct fftw_iodim64_do_not_use_me X(iodim64);			   \
									   \
typedef enum fftw_r2r_kind_do_not_use_me X(r2r_kind);			   \
									   \
typedef fftw_write_char_func_do_not_use_me X(write_char_func);		   \
typedef fftw_read_char_func_do_not_use_me X(read_char_func);		   \
									   \
FFTW_EXTERN void X(execute)(const X(plan) p);				   \
									   \
FFTW_EXTERN X(plan) X(plan_dft)(int rank, const int *n,			   \
		    C *in, C *out, int sign, unsigned flags);		   \
									   \
FFTW_EXTERN X(plan) X(plan_dft_1d)(int n, C *in, C *out, int sign,	   \
		       unsigned flags);					   \
FFTW_EXTERN X(plan) X(plan_dft_2d)(int n0, int n1,			   \
		       C *in, C *out, int sign, unsigned flags);	   \
FFTW_EXTERN X(plan) X(plan_dft_3d)(int n0, int n1, int n2,		   \
		       C *in, C *out, int sign, unsigned flags);	   \
									   \
FFTW_EXTERN X(plan) X(plan_many_dft)(int rank, const int *n,		   \
                         int howmany,					   \
                         C *in, const int *inembed,			   \
                         int istride, int idist,			   \
                         C *out, const int *onembed,			   \
                         int ostride, int odist,			   \
                         int sign, unsigned flags);			   \
									   \
FFTW_EXTERN X(plan) X(plan_guru_dft)(int rank, const X(iodim) *dims,	   \
			 int howmany_rank,				   \
			 const X(iodim) *howmany_dims,			   \
			 C *in, C *out,					   \
			 int sign, unsigned flags);			   \
FFTW_EXTERN X(plan) X(plan_guru_split_dft)(int rank, const X(iodim) *dims, \
			 int howmany_rank,				   \
			 const X(iodim) *howmany_dims,			   \
			 R *ri, R *ii, R *ro, R *io,			   \
			 unsigned flags);				   \
									   \
FFTW_EXTERN X(plan) X(plan_guru64_dft)(int rank,			   \
                         const X(iodim64) *dims,			   \
			 int howmany_rank,				   \
			 const X(iodim64) *howmany_dims,		   \
			 C *in, C *out,					   \
			 int sign, unsigned flags);			   \
FFTW_EXTERN X(plan) X(plan_guru64_split_dft)(int rank,			   \
                         const X(iodim64) *dims,			   \
			 int howmany_rank,				   \
			 const X(iodim64) *howmany_dims,		   \
			 R *ri, R *ii, R *ro, R *io,			   \
			 unsigned flags);				   \
									   \
FFTW_EXTERN void X(execute_dft)(const X(plan) p, C *in, C *out);	   \
FFTW_EXTERN void X(execute_split_dft)(const X(plan) p, R *ri, R *ii,	   \
                                      R *ro, R *io);			   \
									   \
FFTW_EXTERN X(plan) X(plan_many_dft_r2c)(int rank, const int *n,	   \
                             int howmany,				   \
                             R *in, const int *inembed,			   \
                             int istride, int idist,			   \
                             C *out, const int *onembed,		   \
                             int ostride, int odist,			   \
                             unsigned flags);				   \
									   \
FFTW_EXTERN X(plan) X(plan_dft_r2c)(int rank, const int *n,		   \
                        R *in, C *out, unsigned flags);			   \
									   \
FFTW_EXTERN X(plan) X(plan_dft_r2c_1d)(int n,R *in,C *out,unsigned flags); \
FFTW_EXTERN X(plan) X(plan_dft_r2c_2d)(int n0, int n1,			   \
			   R *in, C *out, unsigned flags);		   \
FFTW_EXTERN X(plan) X(plan_dft_r2c_3d)(int n0, int n1,			   \
			   int n2,					   \
			   R *in, C *out, unsigned flags);		   \
									   \
									   \
FFTW_EXTERN X(plan) X(plan_many_dft_c2r)(int rank, const int *n,	   \
			     int howmany,				   \
			     C *in, const int *inembed,			   \
			     int istride, int idist,			   \
			     R *out, const int *onembed,		   \
			     int ostride, int odist,			   \
			     unsigned flags);				   \
									   \
FFTW_EXTERN X(plan) X(plan_dft_c2r)(int rank, const int *n,		   \
                        C *in, R *out, unsigned flags);			   \
									   \
FFTW_EXTERN X(plan) X(plan_dft_c2r_1d)(int n,C *in,R *out,unsigned flags); \
FFTW_EXTERN X(plan) X(plan_dft_c2r_2d)(int n0, int n1,			   \
			   C *in, R *out, unsigned flags);		   \
FFTW_EXTERN X(plan) X(plan_dft_c2r_3d)(int n0, int n1,			   \
			   int n2,					   \
			   C *in, R *out, unsigned flags);		   \
									   \
FFTW_EXTERN X(plan) X(plan_guru_dft_r2c)(int rank, const X(iodim) *dims,   \
			     int howmany_rank,				   \
			     const X(iodim) *howmany_dims,		   \
			     R *in, C *out,				   \
			     unsigned flags);				   \
FFTW_EXTERN X(plan) X(plan_guru_dft_c2r)(int rank, const X(iodim) *dims,   \
			     int howmany_rank,				   \
			     const X(iodim) *howmany_dims,		   \
			     C *in, R *out,				   \
			     unsigned flags);				   \
									   \
FFTW_EXTERN X(plan) X(plan_guru_split_dft_r2c)(				   \
                             int rank, const X(iodim) *dims,		   \
			     int howmany_rank,				   \
			     const X(iodim) *howmany_dims,		   \
			     R *in, R *ro, R *io,			   \
			     unsigned flags);				   \
FFTW_EXTERN X(plan) X(plan_guru_split_dft_c2r)(				   \
                             int rank, const X(iodim) *dims,		   \
			     int howmany_rank,				   \
			     const X(iodim) *howmany_dims,		   \
			     R *ri, R *ii, R *out,			   \
			     unsigned flags);				   \
									   \
FFTW_EXTERN X(plan) X(plan_guru64_dft_r2c)(int rank,			   \
                             const X(iodim64) *dims,			   \
			     int howmany_rank,				   \
			     const X(iodim64) *howmany_dims,		   \
			     R *in, C *out,				   \
			     unsigned flags);				   \
FFTW_EXTERN X(plan) X(plan_guru64_dft_c2r)(int rank,			   \
                             const X(iodim64) *dims,			   \
			     int howmany_rank,				   \
			     const X(iodim64) *howmany_dims,		   \
			     C *in, R *out,				   \
			     unsigned flags);				   \
									   \
FFTW_EXTERN X(plan) X(plan_guru64_split_dft_r2c)(			   \
                             int rank, const X(iodim64) *dims,		   \
			     int howmany_rank,				   \
			     const X(iodim64) *howmany_dims,		   \
			     R *in, R *ro, R *io,			   \
			     unsigned flags);				   \
FFTW_EXTERN X(plan) X(plan_guru64_split_dft_c2r)(			   \
                             int rank, const X(iodim64) *dims,		   \
			     int howmany_rank,				   \
			     const X(iodim64) *howmany_dims,		   \
			     R *ri, R *ii, R *out,			   \
			     unsigned flags);				   \
									   \
FFTW_EXTERN void X(execute_dft_r2c)(const X(plan) p, R *in, C *out);	   \
FFTW_EXTERN void X(execute_dft_c2r)(const X(plan) p, C *in, R *out);	   \
									   \
FFTW_EXTERN void X(execute_split_dft_r2c)(const X(plan) p,		   \
                                          R *in, R *ro, R *io);		   \
FFTW_EXTERN void X(execute_split_dft_c2r)(const X(plan) p,		   \
                                          R *ri, R *ii, R *out);	   \
									   \
FFTW_EXTERN X(plan) X(plan_many_r2r)(int rank, const int *n,		   \
                         int howmany,					   \
                         R *in, const int *inembed,			   \
                         int istride, int idist,			   \
                         R *out, const int *onembed,			   \
                         int ostride, int odist,			   \
                         const X(r2r_kind) *kind, unsigned flags);	   \
									   \
FFTW_EXTERN X(plan) X(plan_r2r)(int rank, const int *n, R *in, R *out,	   \
                    const X(r2r_kind) *kind, unsigned flags);		   \
									   \
FFTW_EXTERN X(plan) X(plan_r2r_1d)(int n, R *in, R *out,		   \
                       X(r2r_kind) kind, unsigned flags);		   \
FFTW_EXTERN X(plan) X(plan_r2r_2d)(int n0, int n1, R *in, R *out,	   \
                       X(r2r_kind) kind0, X(r2r_kind) kind1,		   \
                       unsigned flags);					   \
FFTW_EXTERN X(plan) X(plan_r2r_3d)(int n0, int n1, int n2,		   \
                       R *in, R *out, X(r2r_kind) kind0,		   \
                       X(r2r_kind) kind1, X(r2r_kind) kind2,		   \
                       unsigned flags);					   \
									   \
FFTW_EXTERN X(plan) X(plan_guru_r2r)(int rank, const X(iodim) *dims,	   \
                         int howmany_rank,				   \
                         const X(iodim) *howmany_dims,			   \
                         R *in, R *out,					   \
                         const X(r2r_kind) *kind, unsigned flags);	   \
									   \
FFTW_EXTERN X(plan) X(plan_guru64_r2r)(int rank, const X(iodim64) *dims,   \
                         int howmany_rank,				   \
                         const X(iodim64) *howmany_dims,		   \
                         R *in, R *out,					   \
                         const X(r2r_kind) *kind, unsigned flags);	   \
									   \
FFTW_EXTERN void X(execute_r2r)(const X(plan) p, R *in, R *out);	   \
									   \
FFTW_EXTERN void X(destroy_plan)(X(plan) p);				   \
FFTW_EXTERN void X(forget_wisdom)(void);				   \
FFTW_EXTERN void X(cleanup)(void);					   \
									   \
FFTW_EXTERN void X(set_timelimit)(double t);				   \
									   \
FFTW_EXTERN void X(plan_with_nthreads)(int nthreads);			   \
FFTW_EXTERN int X(init_threads)(void);					   \
FFTW_EXTERN void X(cleanup_threads)(void);				   \
									   \
FFTW_EXTERN int X(export_wisdom_to_filename)(const char *filename);	   \
FFTW_EXTERN void X(export_wisdom_to_file)(FILE *output_file);		   \
FFTW_EXTERN char *X(export_wisdom_to_string)(void);			   \
FFTW_EXTERN void X(export_wisdom)(X(write_char_func) write_char,   	   \
                                  void *data);				   \
FFTW_EXTERN int X(import_system_wisdom)(void);				   \
FFTW_EXTERN int X(import_wisdom_from_filename)(const char *filename);	   \
FFTW_EXTERN int X(import_wisdom_from_file)(FILE *input_file);		   \
FFTW_EXTERN int X(import_wisdom_from_string)(const char *input_string);	   \
FFTW_EXTERN int X(import_wisdom)(X(read_char_func) read_char, void *data); \
									   \
FFTW_EXTERN void X(fprint_plan)(const X(plan) p, FILE *output_file);	   \
FFTW_EXTERN void X(print_plan)(const X(plan) p);			   \
									   \
FFTW_EXTERN void *X(malloc)(size_t n);					   \
FFTW_EXTERN R *X(alloc_real)(size_t n);					   \
FFTW_EXTERN C *X(alloc_complex)(size_t n);				   \
FFTW_EXTERN void X(free)(void *p);					   \
									   \
FFTW_EXTERN void X(flops)(const X(plan) p,				   \
                          double *add, double *mul, double *fmas);	   \
FFTW_EXTERN double X(estimate_cost)(const X(plan) p);			   \
FFTW_EXTERN double X(cost)(const X(plan) p);				   \
									   \
FFTW_EXTERN const char X(version)[];					   \
FFTW_EXTERN const char X(cc)[];						   \
FFTW_EXTERN const char X(codelet_optim)[];


/* end of FFTW_DEFINE_API macro */

FFTW_DEFINE_API(FFTW_MANGLE_DOUBLE, double, fftw_complex)
FFTW_DEFINE_API(FFTW_MANGLE_FLOAT, float, fftwf_complex)
FFTW_DEFINE_API(FFTW_MANGLE_LONG_DOUBLE, long double, fftwl_complex)

/* __float128 (quad precision) is a gcc extension on i386, x86_64, and ia64
   for gcc >= 4.6 (compiled in FFTW with --enable-quad-precision) */
#if (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6)) \
 && !(defined(__ICC) || defined(__INTEL_COMPILER)) \
 && (defined(__i386__) || defined(__x86_64__) || defined(__ia64__))
#  if !defined(FFTW_NO_Complex) && defined(_Complex_I) && defined(complex) && defined(I)
/* note: __float128 is a typedef, which is not supported with the _Complex
         keyword in gcc, so instead we use this ugly __attribute__ version.
         However, we can't simply pass the __attribute__ version to
         FFTW_DEFINE_API because the __attribute__ confuses gcc in pointer
         types.  Hence redefining FFTW_DEFINE_COMPLEX.  Ugh. */
#    undef FFTW_DEFINE_COMPLEX
#    define FFTW_DEFINE_COMPLEX(R, C) typedef _Complex float __attribute__((mode(TC))) C
#  endif
# 371 "/usr/local/include/fftw3.h"
FFTW_DEFINE_API(FFTW_MANGLE_QUAD, __float128, fftwq_complex)
#endif
# 373 "/usr/local/include/fftw3.h"

#define FFTW_FORWARD (-1)
#define FFTW_BACKWARD (+1)

#define FFTW_NO_TIMELIMIT (-1.0)

/* documented flags */
#define FFTW_MEASURE (0U)
#define FFTW_DESTROY_INPUT (1U << 0)
#define FFTW_UNALIGNED (1U << 1)
#define FFTW_CONSERVE_MEMORY (1U << 2)
#define FFTW_EXHAUSTIVE (1U << 3) /* NO_EXHAUSTIVE is default */
#define FFTW_PRESERVE_INPUT (1U << 4) /* cancels FFTW_DESTROY_INPUT */
#define FFTW_PATIENT (1U << 5) /* IMPATIENT is default */
#define FFTW_ESTIMATE (1U << 6)
#define FFTW_WISDOM_ONLY (1U << 21)

/* undocumented beyond-guru flags */
#define FFTW_ESTIMATE_PATIENT (1U << 7)
#define FFTW_BELIEVE_PCOST (1U << 8)
#define FFTW_NO_DFT_R2HC (1U << 9)
#define FFTW_NO_NONTHREADED (1U << 10)
#define FFTW_NO_BUFFERING (1U << 11)
#define FFTW_NO_INDIRECT_OP (1U << 12)
#define FFTW_ALLOW_LARGE_GENERIC (1U << 13) /* NO_LARGE_GENERIC is default */
#define FFTW_NO_RANK_SPLITS (1U << 14)
#define FFTW_NO_VRANK_SPLITS (1U << 15)
#define FFTW_NO_VRECURSE (1U << 16)
#define FFTW_NO_SIMD (1U << 17)
#define FFTW_NO_SLOW (1U << 18)
#define FFTW_NO_FIXED_RADIX_LARGE_N (1U << 19)
#define FFTW_ALLOW_PRUNING (1U << 20)

#ifdef __cplusplus
}  /* extern "C" */
#endif /* __cplusplus */
# 409 "/usr/local/include/fftw3.h"

#endif /* FFTW3_H */
# 411 "/usr/local/include/fftw3.h"
# 361 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h" 2
}
#endif
# 363 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Configure LibBoard support.
// (http://libboard.sourceforge.net/)
//
// Define 'cimg_use_board' to enable Board support.
//
// Board library may be used to draw 3d objects in vector-graphics canvas
// that can be saved as '.ps' or '.svg' files afterwards.
// (see method 'CImg<T>::draw_object3d()').
#ifdef cimg_use_board
#ifdef None
#undef None
#define _cimg_redefine_None
#endif
# 377 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include "Board.h"
#endif /* expanded by -frewrite-includes */
# 378 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 379 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Configure OpenEXR support.
// (http://www.openexr.com/)
//
// Define 'cimg_use_openexr' to enable OpenEXR support.
//
// OpenEXR library may be used to get a native support of '.exr' files.
// (see methods 'CImg<T>::{load,save}_exr()').
#ifdef cimg_use_openexr
#if 0 /* expanded by -frewrite-includes */
#include "ImfRgbaFile.h"
#endif /* expanded by -frewrite-includes */
# 389 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include "ImfInputFile.h"
#endif /* expanded by -frewrite-includes */
# 390 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include "ImfChannelList.h"
#endif /* expanded by -frewrite-includes */
# 391 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include "ImfMatrixAttribute.h"
#endif /* expanded by -frewrite-includes */
# 392 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if 0 /* expanded by -frewrite-includes */
#include "ImfArray.h"
#endif /* expanded by -frewrite-includes */
# 393 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 394 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Lapack configuration.
// (http://www.netlib.org/lapack)
//
// Define 'cimg_use_lapack' to enable LAPACK support.
//
// Lapack library may be used in several CImg methods to speed up
// matrix computations (eigenvalues, inverse, ...).
#ifdef cimg_use_lapack
extern "C" {
  extern void sgetrf_(int*, int*, float*, int*, int*, int*);
  extern void sgetri_(int*, float*, int*, int*, float*, int*, int*);
  extern void sgetrs_(char*, int*, int*, float*, int*, int*, float*, int*, int*);
  extern void sgesvd_(char*, char*, int*, int*, float*, int*, float*, float*, int*, float*, int*, float*, int*, int*);
  extern void ssyev_(char*, char*, int*, float*, int*, float*, float*, int*, int*);
  extern void dgetrf_(int*, int*, double*, int*, int*, int*);
  extern void dgetri_(int*, double*, int*, int*, double*, int*, int*);
  extern void dgetrs_(char*, int*, int*, double*, int*, int*, double*, int*, int*);
  extern void dgesvd_(char*, char*, int*, int*, double*, int*, double*, double*, int*, double*, int*, double*, int*, int*);
  extern void dsyev_(char*, char*, int*, double*, int*, double*, double*, int*, int*);
  extern void dgels_(char*, int*,int*,int*,double*,int*,double*,int*,double*,int*,int*);
  extern void sgels_(char*, int*,int*,int*,float*,int*,float*,int*,float*,int*,int*);
}
#endif
# 418 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Check if min/max/PI macros are defined.
//
// CImg does not compile if macros 'min', 'max' or 'PI' are defined,
// because it redefines functions min(), max() and const variable PI in the cimg:: namespace.
// so it '#undef' these macros if necessary, and restore them to reasonable
// values at the end of this file.
#ifdef min
#undef min
#define _cimg_redefine_min
#endif
# 429 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef max
#undef max
#define _cimg_redefine_max
#endif
# 433 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef PI
#undef PI
#define _cimg_redefine_PI
#endif
# 437 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

// Define 'cimg_library' namespace suffix.
//
// You may want to add a suffix to the 'cimg_library' namespace, for instance if you need to work
// with several versions of the library at the same time.
#ifdef cimg_namespace_suffix
#define __cimg_library_suffixed(s) cimg_library_##s
#define _cimg_library_suffixed(s) __cimg_library_suffixed(s)
#define cimg_library_suffixed _cimg_library_suffixed(cimg_namespace_suffix)
#else
# 447 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#define cimg_library_suffixed cimg_library
#endif
# 449 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

/*------------------------------------------------------------------------------
  #
  # Define user-friendly macros.
  #
  # These CImg macros are prefixed by 'cimg_' and can be used safely in your own
  # code. They are useful to parse command line options, or to write image loops.
  #
  ------------------------------------------------------------------------------*/

// Macros to define program usage, and retrieve command line arguments.
#define cimg_usage(usage) cimg_library_suffixed::cimg::option((char*)0,argc,argv,(char*)0,usage,false)
#define cimg_help(str) cimg_library_suffixed::cimg::option((char*)0,argc,argv,str,(char*)0)
#define cimg_option(name,defaut,usage) cimg_library_suffixed::cimg::option(name,argc,argv,defaut,usage)
#define cimg_argument(pos) cimg_library_suffixed::cimg::argument(pos,argc,argv)
#define cimg_argument1(pos,s0) cimg_library_suffixed::cimg::argument(pos,argc,argv,1,s0)
#define cimg_argument2(pos,s0,s1) cimg_library_suffixed::cimg::argument(pos,argc,argv,2,s0,s1)
#define cimg_argument3(pos,s0,s1,s2) cimg_library_suffixed::cimg::argument(pos,argc,argv,3,s0,s1,s2)
#define cimg_argument4(pos,s0,s1,s2,s3) cimg_library_suffixed::cimg::argument(pos,argc,argv,4,s0,s1,s2,s3)
#define cimg_argument5(pos,s0,s1,s2,s3,s4) cimg_library_suffixed::cimg::argument(pos,argc,argv,5,s0,s1,s2,s3,s4)
#define cimg_argument6(pos,s0,s1,s2,s3,s4,s5) cimg_library_suffixed::cimg::argument(pos,argc,argv,6,s0,s1,s2,s3,s4,s5)
#define cimg_argument7(pos,s0,s1,s2,s3,s4,s5,s6) cimg_library_suffixed::cimg::argument(pos,argc,argv,7,s0,s1,s2,s3,s4,s5,s6)
#define cimg_argument8(pos,s0,s1,s2,s3,s4,s5,s6,s7) cimg_library_suffixed::cimg::argument(pos,argc,argv,8,s0,s1,s2,s3,s4,s5,s6,s7)
#define cimg_argument9(pos,s0,s1,s2,s3,s4,s5,s6,s7,s8) cimg_library_suffixed::cimg::argument(pos,argc,argv,9,s0,s1,s2,s3,s4,s5,s6,s7,s8)

// Macros to define and manipulate local neighborhoods.
#define CImg_2x2(I,T) T I[4]; \
                      T& I##cc = I[0]; T& I##nc = I[1]; \
                      T& I##cn = I[2]; T& I##nn = I[3]; \
                      I##cc = I##nc = \
                      I##cn = I##nn = 0

#define CImg_3x3(I,T) T I[9]; \
                      T& I##pp = I[0]; T& I##cp = I[1]; T& I##np = I[2]; \
                      T& I##pc = I[3]; T& I##cc = I[4]; T& I##nc = I[5]; \
                      T& I##pn = I[6]; T& I##cn = I[7]; T& I##nn = I[8]; \
                      I##pp = I##cp = I##np = \
                      I##pc = I##cc = I##nc = \
                      I##pn = I##cn = I##nn = 0

#define CImg_4x4(I,T) T I[16]; \
                      T& I##pp = I[0]; T& I##cp = I[1]; T& I##np = I[2]; T& I##ap = I[3]; \
                      T& I##pc = I[4]; T& I##cc = I[5]; T& I##nc = I[6]; T& I##ac = I[7]; \
                      T& I##pn = I[8]; T& I##cn = I[9]; T& I##nn = I[10]; T& I##an = I[11]; \
                      T& I##pa = I[12]; T& I##ca = I[13]; T& I##na = I[14]; T& I##aa = I[15]; \
                      I##pp = I##cp = I##np = I##ap = \
                      I##pc = I##cc = I##nc = I##ac = \
                      I##pn = I##cn = I##nn = I##an = \
                      I##pa = I##ca = I##na = I##aa = 0

#define CImg_5x5(I,T) T I[25]; \
                      T& I##bb = I[0]; T& I##pb = I[1]; T& I##cb = I[2]; T& I##nb = I[3]; T& I##ab = I[4]; \
                      T& I##bp = I[5]; T& I##pp = I[6]; T& I##cp = I[7]; T& I##np = I[8]; T& I##ap = I[9]; \
                      T& I##bc = I[10]; T& I##pc = I[11]; T& I##cc = I[12]; T& I##nc = I[13]; T& I##ac = I[14]; \
                      T& I##bn = I[15]; T& I##pn = I[16]; T& I##cn = I[17]; T& I##nn = I[18]; T& I##an = I[19]; \
                      T& I##ba = I[20]; T& I##pa = I[21]; T& I##ca = I[22]; T& I##na = I[23]; T& I##aa = I[24]; \
                      I##bb = I##pb = I##cb = I##nb = I##ab = \
                      I##bp = I##pp = I##cp = I##np = I##ap = \
                      I##bc = I##pc = I##cc = I##nc = I##ac = \
                      I##bn = I##pn = I##cn = I##nn = I##an = \
                      I##ba = I##pa = I##ca = I##na = I##aa = 0

#define CImg_2x2x2(I,T) T I[8]; \
                      T& I##ccc = I[0]; T& I##ncc = I[1]; \
                      T& I##cnc = I[2]; T& I##nnc = I[3]; \
                      T& I##ccn = I[4]; T& I##ncn = I[5]; \
                      T& I##cnn = I[6]; T& I##nnn = I[7]; \
                      I##ccc = I##ncc = \
                      I##cnc = I##nnc = \
                      I##ccn = I##ncn = \
                      I##cnn = I##nnn = 0

#define CImg_3x3x3(I,T) T I[27]; \
                      T& I##ppp = I[0]; T& I##cpp = I[1]; T& I##npp = I[2]; \
                      T& I##pcp = I[3]; T& I##ccp = I[4]; T& I##ncp = I[5]; \
                      T& I##pnp = I[6]; T& I##cnp = I[7]; T& I##nnp = I[8]; \
                      T& I##ppc = I[9]; T& I##cpc = I[10]; T& I##npc = I[11]; \
                      T& I##pcc = I[12]; T& I##ccc = I[13]; T& I##ncc = I[14]; \
                      T& I##pnc = I[15]; T& I##cnc = I[16]; T& I##nnc = I[17]; \
                      T& I##ppn = I[18]; T& I##cpn = I[19]; T& I##npn = I[20]; \
                      T& I##pcn = I[21]; T& I##ccn = I[22]; T& I##ncn = I[23]; \
                      T& I##pnn = I[24]; T& I##cnn = I[25]; T& I##nnn = I[26]; \
                      I##ppp = I##cpp = I##npp = \
                      I##pcp = I##ccp = I##ncp = \
                      I##pnp = I##cnp = I##nnp = \
                      I##ppc = I##cpc = I##npc = \
                      I##pcc = I##ccc = I##ncc = \
                      I##pnc = I##cnc = I##nnc = \
                      I##ppn = I##cpn = I##npn = \
                      I##pcn = I##ccn = I##ncn = \
                      I##pnn = I##cnn = I##nnn = 0

#define cimg_get2x2(img,x,y,z,c,I,T) \
  I[0] = (T)(img)(x,y,z,c), I[1] = (T)(img)(_n1##x,y,z,c), I[2] = (T)(img)(x,_n1##y,z,c), I[3] = (T)(img)(_n1##x,_n1##y,z,c)

#define cimg_get3x3(img,x,y,z,c,I,T) \
  I[0] = (T)(img)(_p1##x,_p1##y,z,c), I[1] = (T)(img)(x,_p1##y,z,c), I[2] = (T)(img)(_n1##x,_p1##y,z,c), I[3] = (T)(img)(_p1##x,y,z,c), \
  I[4] = (T)(img)(x,y,z,c), I[5] = (T)(img)(_n1##x,y,z,c), I[6] = (T)(img)(_p1##x,_n1##y,z,c), I[7] = (T)(img)(x,_n1##y,z,c), \
  I[8] = (T)(img)(_n1##x,_n1##y,z,c)

#define cimg_get4x4(img,x,y,z,c,I,T) \
  I[0] = (T)(img)(_p1##x,_p1##y,z,c), I[1] = (T)(img)(x,_p1##y,z,c), I[2] = (T)(img)(_n1##x,_p1##y,z,c), I[3] = (T)(img)(_n2##x,_p1##y,z,c), \
  I[4] = (T)(img)(_p1##x,y,z,c), I[5] = (T)(img)(x,y,z,c), I[6] = (T)(img)(_n1##x,y,z,c), I[7] = (T)(img)(_n2##x,y,z,c), \
  I[8] = (T)(img)(_p1##x,_n1##y,z,c), I[9] = (T)(img)(x,_n1##y,z,c), I[10] = (T)(img)(_n1##x,_n1##y,z,c), I[11] = (T)(img)(_n2##x,_n1##y,z,c), \
  I[12] = (T)(img)(_p1##x,_n2##y,z,c), I[13] = (T)(img)(x,_n2##y,z,c), I[14] = (T)(img)(_n1##x,_n2##y,z,c), I[15] = (T)(img)(_n2##x,_n2##y,z,c)

#define cimg_get5x5(img,x,y,z,c,I,T) \
  I[0] = (T)(img)(_p2##x,_p2##y,z,c), I[1] = (T)(img)(_p1##x,_p2##y,z,c), I[2] = (T)(img)(x,_p2##y,z,c), I[3] = (T)(img)(_n1##x,_p2##y,z,c), \
  I[4] = (T)(img)(_n2##x,_p2##y,z,c), I[5] = (T)(img)(_p2##x,_p1##y,z,c), I[6] = (T)(img)(_p1##x,_p1##y,z,c), I[7] = (T)(img)(x,_p1##y,z,c), \
  I[8] = (T)(img)(_n1##x,_p1##y,z,c), I[9] = (T)(img)(_n2##x,_p1##y,z,c), I[10] = (T)(img)(_p2##x,y,z,c), I[11] = (T)(img)(_p1##x,y,z,c), \
  I[12] = (T)(img)(x,y,z,c), I[13] = (T)(img)(_n1##x,y,z,c), I[14] = (T)(img)(_n2##x,y,z,c), I[15] = (T)(img)(_p2##x,_n1##y,z,c), \
  I[16] = (T)(img)(_p1##x,_n1##y,z,c), I[17] = (T)(img)(x,_n1##y,z,c), I[18] = (T)(img)(_n1##x,_n1##y,z,c), I[19] = (T)(img)(_n2##x,_n1##y,z,c), \
  I[20] = (T)(img)(_p2##x,_n2##y,z,c), I[21] = (T)(img)(_p1##x,_n2##y,z,c), I[22] = (T)(img)(x,_n2##y,z,c), I[23] = (T)(img)(_n1##x,_n2##y,z,c), \
  I[24] = (T)(img)(_n2##x,_n2##y,z,c)

#define cimg_get6x6(img,x,y,z,c,I,T) \
 I[0] = (T)(img)(_p2##x,_p2##y,z,c), I[1] = (T)(img)(_p1##x,_p2##y,z,c), I[2] = (T)(img)(x,_p2##y,z,c), I[3] = (T)(img)(_n1##x,_p2##y,z,c), \
 I[4] = (T)(img)(_n2##x,_p2##y,z,c), I[5] = (T)(img)(_n3##x,_p2##y,z,c), I[6] = (T)(img)(_p2##x,_p1##y,z,c), I[7] = (T)(img)(_p1##x,_p1##y,z,c), \
 I[8] = (T)(img)(x,_p1##y,z,c), I[9] = (T)(img)(_n1##x,_p1##y,z,c), I[10] = (T)(img)(_n2##x,_p1##y,z,c), I[11] = (T)(img)(_n3##x,_p1##y,z,c), \
 I[12] = (T)(img)(_p2##x,y,z,c), I[13] = (T)(img)(_p1##x,y,z,c), I[14] = (T)(img)(x,y,z,c), I[15] = (T)(img)(_n1##x,y,z,c), \
 I[16] = (T)(img)(_n2##x,y,z,c), I[17] = (T)(img)(_n3##x,y,z,c), I[18] = (T)(img)(_p2##x,_n1##y,z,c), I[19] = (T)(img)(_p1##x,_n1##y,z,c), \
 I[20] = (T)(img)(x,_n1##y,z,c), I[21] = (T)(img)(_n1##x,_n1##y,z,c), I[22] = (T)(img)(_n2##x,_n1##y,z,c), I[23] = (T)(img)(_n3##x,_n1##y,z,c), \
 I[24] = (T)(img)(_p2##x,_n2##y,z,c), I[25] = (T)(img)(_p1##x,_n2##y,z,c), I[26] = (T)(img)(x,_n2##y,z,c), I[27] = (T)(img)(_n1##x,_n2##y,z,c), \
 I[28] = (T)(img)(_n2##x,_n2##y,z,c), I[29] = (T)(img)(_n3##x,_n2##y,z,c), I[30] = (T)(img)(_p2##x,_n3##y,z,c), I[31] = (T)(img)(_p1##x,_n3##y,z,c), \
 I[32] = (T)(img)(x,_n3##y,z,c), I[33] = (T)(img)(_n1##x,_n3##y,z,c), I[34] = (T)(img)(_n2##x,_n3##y,z,c), I[35] = (T)(img)(_n3##x,_n3##y,z,c)

#define cimg_get7x7(img,x,y,z,c,I,T) \
 I[0] = (T)(img)(_p3##x,_p3##y,z,c), I[1] = (T)(img)(_p2##x,_p3##y,z,c), I[2] = (T)(img)(_p1##x,_p3##y,z,c), I[3] = (T)(img)(x,_p3##y,z,c), \
 I[4] = (T)(img)(_n1##x,_p3##y,z,c), I[5] = (T)(img)(_n2##x,_p3##y,z,c), I[6] = (T)(img)(_n3##x,_p3##y,z,c), I[7] = (T)(img)(_p3##x,_p2##y,z,c), \
 I[8] = (T)(img)(_p2##x,_p2##y,z,c), I[9] = (T)(img)(_p1##x,_p2##y,z,c), I[10] = (T)(img)(x,_p2##y,z,c), I[11] = (T)(img)(_n1##x,_p2##y,z,c), \
 I[12] = (T)(img)(_n2##x,_p2##y,z,c), I[13] = (T)(img)(_n3##x,_p2##y,z,c), I[14] = (T)(img)(_p3##x,_p1##y,z,c), I[15] = (T)(img)(_p2##x,_p1##y,z,c), \
 I[16] = (T)(img)(_p1##x,_p1##y,z,c), I[17] = (T)(img)(x,_p1##y,z,c), I[18] = (T)(img)(_n1##x,_p1##y,z,c), I[19] = (T)(img)(_n2##x,_p1##y,z,c), \
 I[20] = (T)(img)(_n3##x,_p1##y,z,c), I[21] = (T)(img)(_p3##x,y,z,c), I[22] = (T)(img)(_p2##x,y,z,c), I[23] = (T)(img)(_p1##x,y,z,c), \
 I[24] = (T)(img)(x,y,z,c), I[25] = (T)(img)(_n1##x,y,z,c), I[26] = (T)(img)(_n2##x,y,z,c), I[27] = (T)(img)(_n3##x,y,z,c), \
 I[28] = (T)(img)(_p3##x,_n1##y,z,c), I[29] = (T)(img)(_p2##x,_n1##y,z,c), I[30] = (T)(img)(_p1##x,_n1##y,z,c), I[31] = (T)(img)(x,_n1##y,z,c), \
 I[32] = (T)(img)(_n1##x,_n1##y,z,c), I[33] = (T)(img)(_n2##x,_n1##y,z,c), I[34] = (T)(img)(_n3##x,_n1##y,z,c), I[35] = (T)(img)(_p3##x,_n2##y,z,c), \
 I[36] = (T)(img)(_p2##x,_n2##y,z,c), I[37] = (T)(img)(_p1##x,_n2##y,z,c), I[38] = (T)(img)(x,_n2##y,z,c), I[39] = (T)(img)(_n1##x,_n2##y,z,c), \
 I[40] = (T)(img)(_n2##x,_n2##y,z,c), I[41] = (T)(img)(_n3##x,_n2##y,z,c), I[42] = (T)(img)(_p3##x,_n3##y,z,c), I[43] = (T)(img)(_p2##x,_n3##y,z,c), \
 I[44] = (T)(img)(_p1##x,_n3##y,z,c), I[45] = (T)(img)(x,_n3##y,z,c), I[46] = (T)(img)(_n1##x,_n3##y,z,c), I[47] = (T)(img)(_n2##x,_n3##y,z,c), \
 I[48] = (T)(img)(_n3##x,_n3##y,z,c)

#define cimg_get8x8(img,x,y,z,c,I,T) \
 I[0] = (T)(img)(_p3##x,_p3##y,z,c), I[1] = (T)(img)(_p2##x,_p3##y,z,c), I[2] = (T)(img)(_p1##x,_p3##y,z,c), I[3] = (T)(img)(x,_p3##y,z,c), \
 I[4] = (T)(img)(_n1##x,_p3##y,z,c), I[5] = (T)(img)(_n2##x,_p3##y,z,c), I[6] = (T)(img)(_n3##x,_p3##y,z,c), I[7] = (T)(img)(_n4##x,_p3##y,z,c), \
 I[8] = (T)(img)(_p3##x,_p2##y,z,c), I[9] = (T)(img)(_p2##x,_p2##y,z,c), I[10] = (T)(img)(_p1##x,_p2##y,z,c), I[11] = (T)(img)(x,_p2##y,z,c), \
 I[12] = (T)(img)(_n1##x,_p2##y,z,c), I[13] = (T)(img)(_n2##x,_p2##y,z,c), I[14] = (T)(img)(_n3##x,_p2##y,z,c), I[15] = (T)(img)(_n4##x,_p2##y,z,c), \
 I[16] = (T)(img)(_p3##x,_p1##y,z,c), I[17] = (T)(img)(_p2##x,_p1##y,z,c), I[18] = (T)(img)(_p1##x,_p1##y,z,c), I[19] = (T)(img)(x,_p1##y,z,c), \
 I[20] = (T)(img)(_n1##x,_p1##y,z,c), I[21] = (T)(img)(_n2##x,_p1##y,z,c), I[22] = (T)(img)(_n3##x,_p1##y,z,c), I[23] = (T)(img)(_n4##x,_p1##y,z,c), \
 I[24] = (T)(img)(_p3##x,y,z,c), I[25] = (T)(img)(_p2##x,y,z,c), I[26] = (T)(img)(_p1##x,y,z,c), I[27] = (T)(img)(x,y,z,c), \
 I[28] = (T)(img)(_n1##x,y,z,c), I[29] = (T)(img)(_n2##x,y,z,c), I[30] = (T)(img)(_n3##x,y,z,c), I[31] = (T)(img)(_n4##x,y,z,c), \
 I[32] = (T)(img)(_p3##x,_n1##y,z,c), I[33] = (T)(img)(_p2##x,_n1##y,z,c), I[34] = (T)(img)(_p1##x,_n1##y,z,c), I[35] = (T)(img)(x,_n1##y,z,c), \
 I[36] = (T)(img)(_n1##x,_n1##y,z,c), I[37] = (T)(img)(_n2##x,_n1##y,z,c), I[38] = (T)(img)(_n3##x,_n1##y,z,c), I[39] = (T)(img)(_n4##x,_n1##y,z,c), \
 I[40] = (T)(img)(_p3##x,_n2##y,z,c), I[41] = (T)(img)(_p2##x,_n2##y,z,c), I[42] = (T)(img)(_p1##x,_n2##y,z,c), I[43] = (T)(img)(x,_n2##y,z,c), \
 I[44] = (T)(img)(_n1##x,_n2##y,z,c), I[45] = (T)(img)(_n2##x,_n2##y,z,c), I[46] = (T)(img)(_n3##x,_n2##y,z,c), I[47] = (T)(img)(_n4##x,_n2##y,z,c), \
 I[48] = (T)(img)(_p3##x,_n3##y,z,c), I[49] = (T)(img)(_p2##x,_n3##y,z,c), I[50] = (T)(img)(_p1##x,_n3##y,z,c), I[51] = (T)(img)(x,_n3##y,z,c), \
 I[52] = (T)(img)(_n1##x,_n3##y,z,c), I[53] = (T)(img)(_n2##x,_n3##y,z,c), I[54] = (T)(img)(_n3##x,_n3##y,z,c), I[55] = (T)(img)(_n4##x,_n3##y,z,c), \
 I[56] = (T)(img)(_p3##x,_n4##y,z,c), I[57] = (T)(img)(_p2##x,_n4##y,z,c), I[58] = (T)(img)(_p1##x,_n4##y,z,c), I[59] = (T)(img)(x,_n4##y,z,c), \
 I[60] = (T)(img)(_n1##x,_n4##y,z,c), I[61] = (T)(img)(_n2##x,_n4##y,z,c), I[62] = (T)(img)(_n3##x,_n4##y,z,c), I[63] = (T)(img)(_n4##x,_n4##y,z,c);

#define cimg_get9x9(img,x,y,z,c,I,T) \
 I[0] = (T)(img)(_p4##x,_p4##y,z,c), I[1] = (T)(img)(_p3##x,_p4##y,z,c), I[2] = (T)(img)(_p2##x,_p4##y,z,c), I[3] = (T)(img)(_p1##x,_p4##y,z,c), \
 I[4] = (T)(img)(x,_p4##y,z,c), I[5] = (T)(img)(_n1##x,_p4##y,z,c), I[6] = (T)(img)(_n2##x,_p4##y,z,c), I[7] = (T)(img)(_n3##x,_p4##y,z,c), \
 I[8] = (T)(img)(_n4##x,_p4##y,z,c), I[9] = (T)(img)(_p4##x,_p3##y,z,c), I[10] = (T)(img)(_p3##x,_p3##y,z,c), I[11] = (T)(img)(_p2##x,_p3##y,z,c), \
 I[12] = (T)(img)(_p1##x,_p3##y,z,c), I[13] = (T)(img)(x,_p3##y,z,c), I[14] = (T)(img)(_n1##x,_p3##y,z,c), I[15] = (T)(img)(_n2##x,_p3##y,z,c), \
 I[16] = (T)(img)(_n3##x,_p3##y,z,c), I[17] = (T)(img)(_n4##x,_p3##y,z,c), I[18] = (T)(img)(_p4##x,_p2##y,z,c), I[19] = (T)(img)(_p3##x,_p2##y,z,c), \
 I[20] = (T)(img)(_p2##x,_p2##y,z,c), I[21] = (T)(img)(_p1##x,_p2##y,z,c), I[22] = (T)(img)(x,_p2##y,z,c), I[23] = (T)(img)(_n1##x,_p2##y,z,c), \
 I[24] = (T)(img)(_n2##x,_p2##y,z,c), I[25] = (T)(img)(_n3##x,_p2##y,z,c), I[26] = (T)(img)(_n4##x,_p2##y,z,c), I[27] = (T)(img)(_p4##x,_p1##y,z,c), \
 I[28] = (T)(img)(_p3##x,_p1##y,z,c), I[29] = (T)(img)(_p2##x,_p1##y,z,c), I[30] = (T)(img)(_p1##x,_p1##y,z,c), I[31] = (T)(img)(x,_p1##y,z,c), \
 I[32] = (T)(img)(_n1##x,_p1##y,z,c), I[33] = (T)(img)(_n2##x,_p1##y,z,c), I[34] = (T)(img)(_n3##x,_p1##y,z,c), I[35] = (T)(img)(_n4##x,_p1##y,z,c), \
 I[36] = (T)(img)(_p4##x,y,z,c), I[37] = (T)(img)(_p3##x,y,z,c), I[38] = (T)(img)(_p2##x,y,z,c), I[39] = (T)(img)(_p1##x,y,z,c), \
 I[40] = (T)(img)(x,y,z,c), I[41] = (T)(img)(_n1##x,y,z,c), I[42] = (T)(img)(_n2##x,y,z,c), I[43] = (T)(img)(_n3##x,y,z,c), \
 I[44] = (T)(img)(_n4##x,y,z,c), I[45] = (T)(img)(_p4##x,_n1##y,z,c), I[46] = (T)(img)(_p3##x,_n1##y,z,c), I[47] = (T)(img)(_p2##x,_n1##y,z,c), \
 I[48] = (T)(img)(_p1##x,_n1##y,z,c), I[49] = (T)(img)(x,_n1##y,z,c), I[50] = (T)(img)(_n1##x,_n1##y,z,c), I[51] = (T)(img)(_n2##x,_n1##y,z,c), \
 I[52] = (T)(img)(_n3##x,_n1##y,z,c), I[53] = (T)(img)(_n4##x,_n1##y,z,c), I[54] = (T)(img)(_p4##x,_n2##y,z,c), I[55] = (T)(img)(_p3##x,_n2##y,z,c), \
 I[56] = (T)(img)(_p2##x,_n2##y,z,c), I[57] = (T)(img)(_p1##x,_n2##y,z,c), I[58] = (T)(img)(x,_n2##y,z,c), I[59] = (T)(img)(_n1##x,_n2##y,z,c), \
 I[60] = (T)(img)(_n2##x,_n2##y,z,c), I[61] = (T)(img)(_n3##x,_n2##y,z,c), I[62] = (T)(img)(_n4##x,_n2##y,z,c), I[63] = (T)(img)(_p4##x,_n3##y,z,c), \
 I[64] = (T)(img)(_p3##x,_n3##y,z,c), I[65] = (T)(img)(_p2##x,_n3##y,z,c), I[66] = (T)(img)(_p1##x,_n3##y,z,c), I[67] = (T)(img)(x,_n3##y,z,c), \
 I[68] = (T)(img)(_n1##x,_n3##y,z,c), I[69] = (T)(img)(_n2##x,_n3##y,z,c), I[70] = (T)(img)(_n3##x,_n3##y,z,c), I[71] = (T)(img)(_n4##x,_n3##y,z,c), \
 I[72] = (T)(img)(_p4##x,_n4##y,z,c), I[73] = (T)(img)(_p3##x,_n4##y,z,c), I[74] = (T)(img)(_p2##x,_n4##y,z,c), I[75] = (T)(img)(_p1##x,_n4##y,z,c), \
 I[76] = (T)(img)(x,_n4##y,z,c), I[77] = (T)(img)(_n1##x,_n4##y,z,c), I[78] = (T)(img)(_n2##x,_n4##y,z,c), I[79] = (T)(img)(_n3##x,_n4##y,z,c), \
 I[80] = (T)(img)(_n4##x,_n4##y,z,c)

#define cimg_get2x2x2(img,x,y,z,c,I,T) \
  I[0] = (T)(img)(x,y,z,c), I[1] = (T)(img)(_n1##x,y,z,c), I[2] = (T)(img)(x,_n1##y,z,c), I[3] = (T)(img)(_n1##x,_n1##y,z,c), \
  I[4] = (T)(img)(x,y,_n1##z,c), I[5] = (T)(img)(_n1##x,y,_n1##z,c), I[6] = (T)(img)(x,_n1##y,_n1##z,c), I[7] = (T)(img)(_n1##x,_n1##y,_n1##z,c)

#define cimg_get3x3x3(img,x,y,z,c,I,T) \
  I[0] = (T)(img)(_p1##x,_p1##y,_p1##z,c), I[1] = (T)(img)(x,_p1##y,_p1##z,c), I[2] = (T)(img)(_n1##x,_p1##y,_p1##z,c), \
  I[3] = (T)(img)(_p1##x,y,_p1##z,c), I[4] = (T)(img)(x,y,_p1##z,c), I[5] = (T)(img)(_n1##x,y,_p1##z,c), \
  I[6] = (T)(img)(_p1##x,_n1##y,_p1##z,c), I[7] = (T)(img)(x,_n1##y,_p1##z,c), I[8] = (T)(img)(_n1##x,_n1##y,_p1##z,c), \
  I[9] = (T)(img)(_p1##x,_p1##y,z,c), I[10] = (T)(img)(x,_p1##y,z,c), I[11] = (T)(img)(_n1##x,_p1##y,z,c), \
  I[12] = (T)(img)(_p1##x,y,z,c), I[13] = (T)(img)(x,y,z,c), I[14] = (T)(img)(_n1##x,y,z,c), \
  I[15] = (T)(img)(_p1##x,_n1##y,z,c), I[16] = (T)(img)(x,_n1##y,z,c), I[17] = (T)(img)(_n1##x,_n1##y,z,c), \
  I[18] = (T)(img)(_p1##x,_p1##y,_n1##z,c), I[19] = (T)(img)(x,_p1##y,_n1##z,c), I[20] = (T)(img)(_n1##x,_p1##y,_n1##z,c), \
  I[21] = (T)(img)(_p1##x,y,_n1##z,c), I[22] = (T)(img)(x,y,_n1##z,c), I[23] = (T)(img)(_n1##x,y,_n1##z,c), \
  I[24] = (T)(img)(_p1##x,_n1##y,_n1##z,c), I[25] = (T)(img)(x,_n1##y,_n1##z,c), I[26] = (T)(img)(_n1##x,_n1##y,_n1##z,c)

// Macros to perform various image loops.
//
// These macros are simpler to use than loops with C++ iterators.
#define cimg_for(img,ptrs,T_ptrs) for (T_ptrs *ptrs = (img)._data, *_max##ptrs = (img)._data + (img).size(); ptrs<_max##ptrs; ++ptrs)
#define cimg_rof(img,ptrs,T_ptrs) for (T_ptrs *ptrs = (img)._data + (img).size(); (ptrs--)>(img)._data; )
#define cimg_foroff(img,off) for (unsigned long off = 0, _max##off = (img).size(); off<_max##off; ++off)

#define cimg_for1(bound,i) for (int i = 0; i<(int)(bound); ++i)
#define cimg_forX(img,x) cimg_for1((img)._width,x)
#define cimg_forY(img,y) cimg_for1((img)._height,y)
#define cimg_forZ(img,z) cimg_for1((img)._depth,z)
#define cimg_forC(img,c) cimg_for1((img)._spectrum,c)
#define cimg_forXY(img,x,y) cimg_forY(img,y) cimg_forX(img,x)
#define cimg_forXZ(img,x,z) cimg_forZ(img,z) cimg_forX(img,x)
#define cimg_forYZ(img,y,z) cimg_forZ(img,z) cimg_forY(img,y)
#define cimg_forXC(img,x,c) cimg_forC(img,c) cimg_forX(img,x)
#define cimg_forYC(img,y,c) cimg_forC(img,c) cimg_forY(img,y)
#define cimg_forZC(img,z,c) cimg_forC(img,c) cimg_forZ(img,z)
#define cimg_forXYZ(img,x,y,z) cimg_forZ(img,z) cimg_forXY(img,x,y)
#define cimg_forXYC(img,x,y,c) cimg_forC(img,c) cimg_forXY(img,x,y)
#define cimg_forXZC(img,x,z,c) cimg_forC(img,c) cimg_forXZ(img,x,z)
#define cimg_forYZC(img,y,z,c) cimg_forC(img,c) cimg_forYZ(img,y,z)
#define cimg_forXYZC(img,x,y,z,c) cimg_forC(img,c) cimg_forXYZ(img,x,y,z)

#define cimg_rof1(bound,i) for (int i = (int)(bound)-1; i>=0; --i)
#define cimg_rofX(img,x) cimg_rof1((img)._width,x)
#define cimg_rofY(img,y) cimg_rof1((img)._height,y)
#define cimg_rofZ(img,z) cimg_rof1((img)._depth,z)
#define cimg_rofC(img,c) cimg_rof1((img)._spectrum,c)
#define cimg_rofXY(img,x,y) cimg_rofY(img,y) cimg_rofX(img,x)
#define cimg_rofXZ(img,x,z) cimg_rofZ(img,z) cimg_rofX(img,x)
#define cimg_rofYZ(img,y,z) cimg_rofZ(img,z) cimg_rofY(img,y)
#define cimg_rofXC(img,x,c) cimg_rofC(img,c) cimg_rofX(img,x)
#define cimg_rofYC(img,y,c) cimg_rofC(img,c) cimg_rofY(img,y)
#define cimg_rofZC(img,z,c) cimg_rofC(img,c) cimg_rofZ(img,z)
#define cimg_rofXYZ(img,x,y,z) cimg_rofZ(img,z) cimg_rofXY(img,x,y)
#define cimg_rofXYC(img,x,y,c) cimg_rofC(img,c) cimg_rofXY(img,x,y)
#define cimg_rofXZC(img,x,z,c) cimg_rofC(img,c) cimg_rofXZ(img,x,z)
#define cimg_rofYZC(img,y,z,c) cimg_rofC(img,c) cimg_rofYZ(img,y,z)
#define cimg_rofXYZC(img,x,y,z,c) cimg_rofC(img,c) cimg_rofXYZ(img,x,y,z)

#define cimg_for_in1(bound,i0,i1,i) \
 for (int i = (int)(i0)<0?0:(int)(i0), _max##i = (int)(i1)<(int)(bound)?(int)(i1):(int)(bound)-1; i<=_max##i; ++i)
#define cimg_for_inX(img,x0,x1,x) cimg_for_in1((img)._width,x0,x1,x)
#define cimg_for_inY(img,y0,y1,y) cimg_for_in1((img)._height,y0,y1,y)
#define cimg_for_inZ(img,z0,z1,z) cimg_for_in1((img)._depth,z0,z1,z)
#define cimg_for_inC(img,c0,c1,c) cimg_for_in1((img)._spectrum,c0,c1,c)
#define cimg_for_inXY(img,x0,y0,x1,y1,x,y) cimg_for_inY(img,y0,y1,y) cimg_for_inX(img,x0,x1,x)
#define cimg_for_inXZ(img,x0,z0,x1,z1,x,z) cimg_for_inZ(img,z0,z1,z) cimg_for_inX(img,x0,x1,x)
#define cimg_for_inXC(img,x0,c0,x1,c1,x,c) cimg_for_inC(img,c0,c1,c) cimg_for_inX(img,x0,x1,x)
#define cimg_for_inYZ(img,y0,z0,y1,z1,y,z) cimg_for_inZ(img,x0,z1,z) cimg_for_inY(img,y0,y1,y)
#define cimg_for_inYC(img,y0,c0,y1,c1,y,c) cimg_for_inC(img,c0,c1,c) cimg_for_inY(img,y0,y1,y)
#define cimg_for_inZC(img,z0,c0,z1,c1,z,c) cimg_for_inC(img,c0,c1,c) cimg_for_inZ(img,z0,z1,z)
#define cimg_for_inXYZ(img,x0,y0,z0,x1,y1,z1,x,y,z) cimg_for_inZ(img,z0,z1,z) cimg_for_inXY(img,x0,y0,x1,y1,x,y)
#define cimg_for_inXYC(img,x0,y0,c0,x1,y1,c1,x,y,c) cimg_for_inC(img,c0,c1,c) cimg_for_inXY(img,x0,y0,x1,y1,x,y)
#define cimg_for_inXZC(img,x0,z0,c0,x1,z1,c1,x,z,c) cimg_for_inC(img,c0,c1,c) cimg_for_inXZ(img,x0,z0,x1,z1,x,z)
#define cimg_for_inYZC(img,y0,z0,c0,y1,z1,c1,y,z,c) cimg_for_inC(img,c0,c1,c) cimg_for_inYZ(img,y0,z0,y1,z1,y,z)
#define cimg_for_inXYZC(img,x0,y0,z0,c0,x1,y1,z1,c1,x,y,z,c) cimg_for_inC(img,c0,c1,c) cimg_for_inXYZ(img,x0,y0,z0,x1,y1,z1,x,y,z)
#define cimg_for_insideX(img,x,n) cimg_for_inX(img,n,(img)._width-1-(n),x)
#define cimg_for_insideY(img,y,n) cimg_for_inY(img,n,(img)._height-1-(n),y)
#define cimg_for_insideZ(img,z,n) cimg_for_inZ(img,n,(img)._depth-1-(n),z)
#define cimg_for_insideC(img,c,n) cimg_for_inC(img,n,(img)._spectrum-1-(n),c)
#define cimg_for_insideXY(img,x,y,n) cimg_for_inXY(img,n,n,(img)._width-1-(n),(img)._height-1-(n),x,y)
#define cimg_for_insideXYZ(img,x,y,z,n) cimg_for_inXYZ(img,n,n,n,(img)._width-1-(n),(img)._height-1-(n),(img)._depth-1-(n),x,y,z)
#define cimg_for_insideXYZC(img,x,y,z,c,n) cimg_for_inXYZ(img,n,n,n,(img)._width-1-(n),(img)._height-1-(n),(img)._depth-1-(n),x,y,z)

#define cimg_for_out1(boundi,i0,i1,i) \
 for (int i = (int)(i0)>0?0:(int)(i1)+1; i<(int)(boundi); ++i, i = i==(int)(i0)?(int)(i1)+1:i)
#define cimg_for_out2(boundi,boundj,i0,j0,i1,j1,i,j) \
 for (int j = 0; j<(int)(boundj); ++j) \
 for (int _n1j = (int)(j<(int)(j0) || j>(int)(j1)), i = _n1j?0:(int)(i0)>0?0:(int)(i1)+1; i<(int)(boundi); \
  ++i, i = _n1j?i:(i==(int)(i0)?(int)(i1)+1:i))
#define cimg_for_out3(boundi,boundj,boundk,i0,j0,k0,i1,j1,k1,i,j,k) \
 for (int k = 0; k<(int)(boundk); ++k) \
 for (int _n1k = (int)(k<(int)(k0) || k>(int)(k1)), j = 0; j<(int)(boundj); ++j) \
 for (int _n1j = (int)(j<(int)(j0) || j>(int)(j1)), i = _n1j || _n1k?0:(int)(i0)>0?0:(int)(i1)+1; i<(int)(boundi); \
  ++i, i = _n1j || _n1k?i:(i==(int)(i0)?(int)(i1)+1:i))
#define cimg_for_out4(boundi,boundj,boundk,boundl,i0,j0,k0,l0,i1,j1,k1,l1,i,j,k,l) \
 for (int l = 0; l<(int)(boundl); ++l) \
 for (int _n1l = (int)(l<(int)(l0) || l>(int)(l1)), k = 0; k<(int)(boundk); ++k) \
 for (int _n1k = (int)(k<(int)(k0) || k>(int)(k1)), j = 0; j<(int)(boundj); ++j) \
 for (int _n1j = (int)(j<(int)(j0) || j>(int)(j1)), i = _n1j || _n1k || _n1l?0:(int)(i0)>0?0:(int)(i1)+1; i<(int)(boundi); \
  ++i, i = _n1j || _n1k || _n1l?i:(i==(int)(i0)?(int)(i1)+1:i))
#define cimg_for_outX(img,x0,x1,x) cimg_for_out1((img)._width,x0,x1,x)
#define cimg_for_outY(img,y0,y1,y) cimg_for_out1((img)._height,y0,y1,y)
#define cimg_for_outZ(img,z0,z1,z) cimg_for_out1((img)._depth,z0,z1,z)
#define cimg_for_outC(img,c0,c1,c) cimg_for_out1((img)._spectrum,c0,c1,c)
#define cimg_for_outXY(img,x0,y0,x1,y1,x,y) cimg_for_out2((img)._width,(img)._height,x0,y0,x1,y1,x,y)
#define cimg_for_outXZ(img,x0,z0,x1,z1,x,z) cimg_for_out2((img)._width,(img)._depth,x0,z0,x1,z1,x,z)
#define cimg_for_outXC(img,x0,c0,x1,c1,x,c) cimg_for_out2((img)._width,(img)._spectrum,x0,c0,x1,c1,x,c)
#define cimg_for_outYZ(img,y0,z0,y1,z1,y,z) cimg_for_out2((img)._height,(img)._depth,y0,z0,y1,z1,y,z)
#define cimg_for_outYC(img,y0,c0,y1,c1,y,c) cimg_for_out2((img)._height,(img)._spectrum,y0,c0,y1,c1,y,c)
#define cimg_for_outZC(img,z0,c0,z1,c1,z,c) cimg_for_out2((img)._depth,(img)._spectrum,z0,c0,z1,c1,z,c)
#define cimg_for_outXYZ(img,x0,y0,z0,x1,y1,z1,x,y,z) cimg_for_out3((img)._width,(img)._height,(img)._depth,x0,y0,z0,x1,y1,z1,x,y,z)
#define cimg_for_outXYC(img,x0,y0,c0,x1,y1,c1,x,y,c) cimg_for_out3((img)._width,(img)._height,(img)._spectrum,x0,y0,c0,x1,y1,c1,x,y,c)
#define cimg_for_outXZC(img,x0,z0,c0,x1,z1,c1,x,z,c) cimg_for_out3((img)._width,(img)._depth,(img)._spectrum,x0,z0,c0,x1,z1,c1,x,z,c)
#define cimg_for_outYZC(img,y0,z0,c0,y1,z1,c1,y,z,c) cimg_for_out3((img)._height,(img)._depth,(img)._spectrum,y0,z0,c0,y1,z1,c1,y,z,c)
#define cimg_for_outXYZC(img,x0,y0,z0,c0,x1,y1,z1,c1,x,y,z,c) \
 cimg_for_out4((img)._width,(img)._height,(img)._depth,(img)._spectrum,x0,y0,z0,c0,x1,y1,z1,c1,x,y,z,c)
#define cimg_for_borderX(img,x,n) cimg_for_outX(img,n,(img)._width-1-(n),x)
#define cimg_for_borderY(img,y,n) cimg_for_outY(img,n,(img)._height-1-(n),y)
#define cimg_for_borderZ(img,z,n) cimg_for_outZ(img,n,(img)._depth-1-(n),z)
#define cimg_for_borderC(img,c,n) cimg_for_outC(img,n,(img)._spectrum-1-(n),c)
#define cimg_for_borderXY(img,x,y,n) cimg_for_outXY(img,n,n,(img)._width-1-(n),(img)._height-1-(n),x,y)
#define cimg_for_borderXYZ(img,x,y,z,n) cimg_for_outXYZ(img,n,n,n,(img)._width-1-(n),(img)._height-1-(n),(img)._depth-1-(n),x,y,z)
#define cimg_for_borderXYZC(img,x,y,z,c,n) \
 cimg_for_outXYZC(img,n,n,n,n,(img)._width-1-(n),(img)._height-1-(n),(img)._depth-1-(n),(img)._spectrum-1-(n),x,y,z,c)

#define cimg_for_spiralXY(img,x,y) \
 for (int x = 0, y = 0, _n1##x = 1, _n1##y = (img).width()*(img).height(); _n1##y; \
      --_n1##y, _n1##x+=(_n1##x>>2)-((!(_n1##x&3)?--y:((_n1##x&3)==1?(img)._width-1-++x:((_n1##x&3)==2?(img)._height-1-++y:--x))))?0:1)

#define cimg_for_lineXY(x,y,x0,y0,x1,y1) \
 for (int x = (int)(x0), y = (int)(y0), _sx = 1, _sy = 1, _steep = 0, \
      _dx=(x1)>(x0)?(int)(x1)-(int)(x0):(_sx=-1,(int)(x0)-(int)(x1)), \
      _dy=(y1)>(y0)?(int)(y1)-(int)(y0):(_sy=-1,(int)(y0)-(int)(y1)), \
      _counter = _dx, \
      _err = _dx>_dy?(_dy>>1):((_steep=1),(_counter=_dy),(_dx>>1)); \
      _counter>=0; \
      --_counter, x+=_steep? \
      (y+=_sy,(_err-=_dx)<0?_err+=_dy,_sx:0): \
      (y+=(_err-=_dy)<0?_err+=_dx,_sy:0,_sx))

#define cimg_for2(bound,i) \
 for (int i = 0, _n1##i = 1>=(bound)?(int)(bound)-1:1; \
      _n1##i<(int)(bound) || i==--_n1##i; \
      ++i, ++_n1##i)
#define cimg_for2X(img,x) cimg_for2((img)._width,x)
#define cimg_for2Y(img,y) cimg_for2((img)._height,y)
#define cimg_for2Z(img,z) cimg_for2((img)._depth,z)
#define cimg_for2C(img,c) cimg_for2((img)._spectrum,c)
#define cimg_for2XY(img,x,y) cimg_for2Y(img,y) cimg_for2X(img,x)
#define cimg_for2XZ(img,x,z) cimg_for2Z(img,z) cimg_for2X(img,x)
#define cimg_for2XC(img,x,c) cimg_for2C(img,c) cimg_for2X(img,x)
#define cimg_for2YZ(img,y,z) cimg_for2Z(img,z) cimg_for2Y(img,y)
#define cimg_for2YC(img,y,c) cimg_for2C(img,c) cimg_for2Y(img,y)
#define cimg_for2ZC(img,z,c) cimg_for2C(img,c) cimg_for2Z(img,z)
#define cimg_for2XYZ(img,x,y,z) cimg_for2Z(img,z) cimg_for2XY(img,x,y)
#define cimg_for2XZC(img,x,z,c) cimg_for2C(img,c) cimg_for2XZ(img,x,z)
#define cimg_for2YZC(img,y,z,c) cimg_for2C(img,c) cimg_for2YZ(img,y,z)
#define cimg_for2XYZC(img,x,y,z,c) cimg_for2C(img,c) cimg_for2XYZ(img,x,y,z)

#define cimg_for_in2(bound,i0,i1,i) \
 for (int i = (int)(i0)<0?0:(int)(i0), \
      _n1##i = i+1>=(int)(bound)?(int)(bound)-1:i+1; \
      i<=(int)(i1) && (_n1##i<(int)(bound) || i==--_n1##i); \
      ++i, ++_n1##i)
#define cimg_for_in2X(img,x0,x1,x) cimg_for_in2((img)._width,x0,x1,x)
#define cimg_for_in2Y(img,y0,y1,y) cimg_for_in2((img)._height,y0,y1,y)
#define cimg_for_in2Z(img,z0,z1,z) cimg_for_in2((img)._depth,z0,z1,z)
#define cimg_for_in2C(img,c0,c1,c) cimg_for_in2((img)._spectrum,c0,c1,c)
#define cimg_for_in2XY(img,x0,y0,x1,y1,x,y) cimg_for_in2Y(img,y0,y1,y) cimg_for_in2X(img,x0,x1,x)
#define cimg_for_in2XZ(img,x0,z0,x1,z1,x,z) cimg_for_in2Z(img,z0,z1,z) cimg_for_in2X(img,x0,x1,x)
#define cimg_for_in2XC(img,x0,c0,x1,c1,x,c) cimg_for_in2C(img,c0,c1,c) cimg_for_in2X(img,x0,x1,x)
#define cimg_for_in2YZ(img,y0,z0,y1,z1,y,z) cimg_for_in2Z(img,z0,z1,z) cimg_for_in2Y(img,y0,y1,y)
#define cimg_for_in2YC(img,y0,c0,y1,c1,y,c) cimg_for_in2C(img,c0,c1,c) cimg_for_in2Y(img,y0,y1,y)
#define cimg_for_in2ZC(img,z0,c0,z1,c1,z,c) cimg_for_in2C(img,c0,c1,c) cimg_for_in2Z(img,z0,z1,z)
#define cimg_for_in2XYZ(img,x0,y0,z0,x1,y1,z1,x,y,z) cimg_for_in2Z(img,z0,z1,z) cimg_for_in2XY(img,x0,y0,x1,y1,x,y)
#define cimg_for_in2XZC(img,x0,z0,c0,x1,y1,c1,x,z,c) cimg_for_in2C(img,c0,c1,c) cimg_for_in2XZ(img,x0,y0,x1,y1,x,z)
#define cimg_for_in2YZC(img,y0,z0,c0,y1,z1,c1,y,z,c) cimg_for_in2C(img,c0,c1,c) cimg_for_in2YZ(img,y0,z0,y1,z1,y,z)
#define cimg_for_in2XYZC(img,x0,y0,z0,c0,x1,y1,z1,c1,x,y,z,c) cimg_for_in2C(img,c0,c1,c) cimg_for_in2XYZ(img,x0,y0,z0,x1,y1,z1,x,y,z)

#define cimg_for3(bound,i) \
 for (int i = 0, _p1##i = 0, \
      _n1##i = 1>=(bound)?(int)(bound)-1:1; \
      _n1##i<(int)(bound) || i==--_n1##i; \
      _p1##i = i++, ++_n1##i)
#define cimg_for3X(img,x) cimg_for3((img)._width,x)
#define cimg_for3Y(img,y) cimg_for3((img)._height,y)
#define cimg_for3Z(img,z) cimg_for3((img)._depth,z)
#define cimg_for3C(img,c) cimg_for3((img)._spectrum,c)
#define cimg_for3XY(img,x,y) cimg_for3Y(img,y) cimg_for3X(img,x)
#define cimg_for3XZ(img,x,z) cimg_for3Z(img,z) cimg_for3X(img,x)
#define cimg_for3XC(img,x,c) cimg_for3C(img,c) cimg_for3X(img,x)
#define cimg_for3YZ(img,y,z) cimg_for3Z(img,z) cimg_for3Y(img,y)
#define cimg_for3YC(img,y,c) cimg_for3C(img,c) cimg_for3Y(img,y)
#define cimg_for3ZC(img,z,c) cimg_for3C(img,c) cimg_for3Z(img,z)
#define cimg_for3XYZ(img,x,y,z) cimg_for3Z(img,z) cimg_for3XY(img,x,y)
#define cimg_for3XZC(img,x,z,c) cimg_for3C(img,c) cimg_for3XZ(img,x,z)
#define cimg_for3YZC(img,y,z,c) cimg_for3C(img,c) cimg_for3YZ(img,y,z)
#define cimg_for3XYZC(img,x,y,z,c) cimg_for3C(img,c) cimg_for3XYZ(img,x,y,z)

#define cimg_for_in3(bound,i0,i1,i) \
 for (int i = (int)(i0)<0?0:(int)(i0), \
      _p1##i = i-1<0?0:i-1, \
      _n1##i = i+1>=(int)(bound)?(int)(bound)-1:i+1; \
      i<=(int)(i1) && (_n1##i<(int)(bound) || i==--_n1##i); \
      _p1##i = i++, ++_n1##i)
#define cimg_for_in3X(img,x0,x1,x) cimg_for_in3((img)._width,x0,x1,x)
#define cimg_for_in3Y(img,y0,y1,y) cimg_for_in3((img)._height,y0,y1,y)
#define cimg_for_in3Z(img,z0,z1,z) cimg_for_in3((img)._depth,z0,z1,z)
#define cimg_for_in3C(img,c0,c1,c) cimg_for_in3((img)._spectrum,c0,c1,c)
#define cimg_for_in3XY(img,x0,y0,x1,y1,x,y) cimg_for_in3Y(img,y0,y1,y) cimg_for_in3X(img,x0,x1,x)
#define cimg_for_in3XZ(img,x0,z0,x1,z1,x,z) cimg_for_in3Z(img,z0,z1,z) cimg_for_in3X(img,x0,x1,x)
#define cimg_for_in3XC(img,x0,c0,x1,c1,x,c) cimg_for_in3C(img,c0,c1,c) cimg_for_in3X(img,x0,x1,x)
#define cimg_for_in3YZ(img,y0,z0,y1,z1,y,z) cimg_for_in3Z(img,z0,z1,z) cimg_for_in3Y(img,y0,y1,y)
#define cimg_for_in3YC(img,y0,c0,y1,c1,y,c) cimg_for_in3C(img,c0,c1,c) cimg_for_in3Y(img,y0,y1,y)
#define cimg_for_in3ZC(img,z0,c0,z1,c1,z,c) cimg_for_in3C(img,c0,c1,c) cimg_for_in3Z(img,z0,z1,z)
#define cimg_for_in3XYZ(img,x0,y0,z0,x1,y1,z1,x,y,z) cimg_for_in3Z(img,z0,z1,z) cimg_for_in3XY(img,x0,y0,x1,y1,x,y)
#define cimg_for_in3XZC(img,x0,z0,c0,x1,y1,c1,x,z,c) cimg_for_in3C(img,c0,c1,c) cimg_for_in3XZ(img,x0,y0,x1,y1,x,z)
#define cimg_for_in3YZC(img,y0,z0,c0,y1,z1,c1,y,z,c) cimg_for_in3C(img,c0,c1,c) cimg_for_in3YZ(img,y0,z0,y1,z1,y,z)
#define cimg_for_in3XYZC(img,x0,y0,z0,c0,x1,y1,z1,c1,x,y,z,c) cimg_for_in3C(img,c0,c1,c) cimg_for_in3XYZ(img,x0,y0,z0,x1,y1,z1,x,y,z)

#define cimg_for4(bound,i) \
 for (int i = 0, _p1##i = 0, _n1##i = 1>=(bound)?(int)(bound)-1:1, \
      _n2##i = 2>=(bound)?(int)(bound)-1:2; \
      _n2##i<(int)(bound) || _n1##i==--_n2##i || i==(_n2##i = --_n1##i); \
      _p1##i = i++, ++_n1##i, ++_n2##i)
#define cimg_for4X(img,x) cimg_for4((img)._width,x)
#define cimg_for4Y(img,y) cimg_for4((img)._height,y)
#define cimg_for4Z(img,z) cimg_for4((img)._depth,z)
#define cimg_for4C(img,c) cimg_for4((img)._spectrum,c)
#define cimg_for4XY(img,x,y) cimg_for4Y(img,y) cimg_for4X(img,x)
#define cimg_for4XZ(img,x,z) cimg_for4Z(img,z) cimg_for4X(img,x)
#define cimg_for4XC(img,x,c) cimg_for4C(img,c) cimg_for4X(img,x)
#define cimg_for4YZ(img,y,z) cimg_for4Z(img,z) cimg_for4Y(img,y)
#define cimg_for4YC(img,y,c) cimg_for4C(img,c) cimg_for4Y(img,y)
#define cimg_for4ZC(img,z,c) cimg_for4C(img,c) cimg_for4Z(img,z)
#define cimg_for4XYZ(img,x,y,z) cimg_for4Z(img,z) cimg_for4XY(img,x,y)
#define cimg_for4XZC(img,x,z,c) cimg_for4C(img,c) cimg_for4XZ(img,x,z)
#define cimg_for4YZC(img,y,z,c) cimg_for4C(img,c) cimg_for4YZ(img,y,z)
#define cimg_for4XYZC(img,x,y,z,c) cimg_for4C(img,c) cimg_for4XYZ(img,x,y,z)

#define cimg_for_in4(bound,i0,i1,i) \
 for (int i = (int)(i0)<0?0:(int)(i0), \
      _p1##i = i-1<0?0:i-1, \
      _n1##i = i+1>=(int)(bound)?(int)(bound)-1:i+1, \
      _n2##i = i+2>=(int)(bound)?(int)(bound)-1:i+2; \
      i<=(int)(i1) && (_n2##i<(int)(bound) || _n1##i==--_n2##i || i==(_n2##i = --_n1##i)); \
      _p1##i = i++, ++_n1##i, ++_n2##i)
#define cimg_for_in4X(img,x0,x1,x) cimg_for_in4((img)._width,x0,x1,x)
#define cimg_for_in4Y(img,y0,y1,y) cimg_for_in4((img)._height,y0,y1,y)
#define cimg_for_in4Z(img,z0,z1,z) cimg_for_in4((img)._depth,z0,z1,z)
#define cimg_for_in4C(img,c0,c1,c) cimg_for_in4((img)._spectrum,c0,c1,c)
#define cimg_for_in4XY(img,x0,y0,x1,y1,x,y) cimg_for_in4Y(img,y0,y1,y) cimg_for_in4X(img,x0,x1,x)
#define cimg_for_in4XZ(img,x0,z0,x1,z1,x,z) cimg_for_in4Z(img,z0,z1,z) cimg_for_in4X(img,x0,x1,x)
#define cimg_for_in4XC(img,x0,c0,x1,c1,x,c) cimg_for_in4C(img,c0,c1,c) cimg_for_in4X(img,x0,x1,x)
#define cimg_for_in4YZ(img,y0,z0,y1,z1,y,z) cimg_for_in4Z(img,z0,z1,z) cimg_for_in4Y(img,y0,y1,y)
#define cimg_for_in4YC(img,y0,c0,y1,c1,y,c) cimg_for_in4C(img,c0,c1,c) cimg_for_in4Y(img,y0,y1,y)
#define cimg_for_in4ZC(img,z0,c0,z1,c1,z,c) cimg_for_in4C(img,c0,c1,c) cimg_for_in4Z(img,z0,z1,z)
#define cimg_for_in4XYZ(img,x0,y0,z0,x1,y1,z1,x,y,z) cimg_for_in4Z(img,z0,z1,z) cimg_for_in4XY(img,x0,y0,x1,y1,x,y)
#define cimg_for_in4XZC(img,x0,z0,c0,x1,y1,c1,x,z,c) cimg_for_in4C(img,c0,c1,c) cimg_for_in4XZ(img,x0,y0,x1,y1,x,z)
#define cimg_for_in4YZC(img,y0,z0,c0,y1,z1,c1,y,z,c) cimg_for_in4C(img,c0,c1,c) cimg_for_in4YZ(img,y0,z0,y1,z1,y,z)
#define cimg_for_in4XYZC(img,x0,y0,z0,c0,x1,y1,z1,c1,x,y,z,c) cimg_for_in4C(img,c0,c1,c) cimg_for_in4XYZ(img,x0,y0,z0,x1,y1,z1,x,y,z)

#define cimg_for5(bound,i) \
 for (int i = 0, _p2##i = 0, _p1##i = 0, \
      _n1##i = 1>=(bound)?(int)(bound)-1:1, \
      _n2##i = 2>=(bound)?(int)(bound)-1:2; \
      _n2##i<(int)(bound) || _n1##i==--_n2##i || i==(_n2##i = --_n1##i); \
      _p2##i = _p1##i, _p1##i = i++, ++_n1##i, ++_n2##i)
#define cimg_for5X(img,x) cimg_for5((img)._width,x)
#define cimg_for5Y(img,y) cimg_for5((img)._height,y)
#define cimg_for5Z(img,z) cimg_for5((img)._depth,z)
#define cimg_for5C(img,c) cimg_for5((img)._spectrum,c)
#define cimg_for5XY(img,x,y) cimg_for5Y(img,y) cimg_for5X(img,x)
#define cimg_for5XZ(img,x,z) cimg_for5Z(img,z) cimg_for5X(img,x)
#define cimg_for5XC(img,x,c) cimg_for5C(img,c) cimg_for5X(img,x)
#define cimg_for5YZ(img,y,z) cimg_for5Z(img,z) cimg_for5Y(img,y)
#define cimg_for5YC(img,y,c) cimg_for5C(img,c) cimg_for5Y(img,y)
#define cimg_for5ZC(img,z,c) cimg_for5C(img,c) cimg_for5Z(img,z)
#define cimg_for5XYZ(img,x,y,z) cimg_for5Z(img,z) cimg_for5XY(img,x,y)
#define cimg_for5XZC(img,x,z,c) cimg_for5C(img,c) cimg_for5XZ(img,x,z)
#define cimg_for5YZC(img,y,z,c) cimg_for5C(img,c) cimg_for5YZ(img,y,z)
#define cimg_for5XYZC(img,x,y,z,c) cimg_for5C(img,c) cimg_for5XYZ(img,x,y,z)

#define cimg_for_in5(bound,i0,i1,i) \
 for (int i = (int)(i0)<0?0:(int)(i0), \
      _p2##i = i-2<0?0:i-2, \
      _p1##i = i-1<0?0:i-1, \
      _n1##i = i+1>=(int)(bound)?(int)(bound)-1:i+1, \
      _n2##i = i+2>=(int)(bound)?(int)(bound)-1:i+2; \
      i<=(int)(i1) && (_n2##i<(int)(bound) || _n1##i==--_n2##i || i==(_n2##i = --_n1##i)); \
      _p2##i = _p1##i, _p1##i = i++, ++_n1##i, ++_n2##i)
#define cimg_for_in5X(img,x0,x1,x) cimg_for_in5((img)._width,x0,x1,x)
#define cimg_for_in5Y(img,y0,y1,y) cimg_for_in5((img)._height,y0,y1,y)
#define cimg_for_in5Z(img,z0,z1,z) cimg_for_in5((img)._depth,z0,z1,z)
#define cimg_for_in5C(img,c0,c1,c) cimg_for_in5((img)._spectrum,c0,c1,c)
#define cimg_for_in5XY(img,x0,y0,x1,y1,x,y) cimg_for_in5Y(img,y0,y1,y) cimg_for_in5X(img,x0,x1,x)
#define cimg_for_in5XZ(img,x0,z0,x1,z1,x,z) cimg_for_in5Z(img,z0,z1,z) cimg_for_in5X(img,x0,x1,x)
#define cimg_for_in5XC(img,x0,c0,x1,c1,x,c) cimg_for_in5C(img,c0,c1,c) cimg_for_in5X(img,x0,x1,x)
#define cimg_for_in5YZ(img,y0,z0,y1,z1,y,z) cimg_for_in5Z(img,z0,z1,z) cimg_for_in5Y(img,y0,y1,y)
#define cimg_for_in5YC(img,y0,c0,y1,c1,y,c) cimg_for_in5C(img,c0,c1,c) cimg_for_in5Y(img,y0,y1,y)
#define cimg_for_in5ZC(img,z0,c0,z1,c1,z,c) cimg_for_in5C(img,c0,c1,c) cimg_for_in5Z(img,z0,z1,z)
#define cimg_for_in5XYZ(img,x0,y0,z0,x1,y1,z1,x,y,z) cimg_for_in5Z(img,z0,z1,z) cimg_for_in5XY(img,x0,y0,x1,y1,x,y)
#define cimg_for_in5XZC(img,x0,z0,c0,x1,y1,c1,x,z,c) cimg_for_in5C(img,c0,c1,c) cimg_for_in5XZ(img,x0,y0,x1,y1,x,z)
#define cimg_for_in5YZC(img,y0,z0,c0,y1,z1,c1,y,z,c) cimg_for_in5C(img,c0,c1,c) cimg_for_in5YZ(img,y0,z0,y1,z1,y,z)
#define cimg_for_in5XYZC(img,x0,y0,z0,c0,x1,y1,z1,c1,x,y,z,c) cimg_for_in5C(img,c0,c1,c) cimg_for_in5XYZ(img,x0,y0,z0,x1,y1,z1,x,y,z)

#define cimg_for6(bound,i) \
 for (int i = 0, _p2##i = 0, _p1##i = 0, \
      _n1##i = 1>=(bound)?(int)(bound)-1:1, \
      _n2##i = 2>=(bound)?(int)(bound)-1:2, \
      _n3##i = 3>=(bound)?(int)(bound)-1:3; \
      _n3##i<(int)(bound) || _n2##i==--_n3##i || _n1##i==--_n2##i || i==(_n3##i = _n2##i = --_n1##i); \
      _p2##i = _p1##i, _p1##i = i++, ++_n1##i, ++_n2##i, ++_n3##i)
#define cimg_for6X(img,x) cimg_for6((img)._width,x)
#define cimg_for6Y(img,y) cimg_for6((img)._height,y)
#define cimg_for6Z(img,z) cimg_for6((img)._depth,z)
#define cimg_for6C(img,c) cimg_for6((img)._spectrum,c)
#define cimg_for6XY(img,x,y) cimg_for6Y(img,y) cimg_for6X(img,x)
#define cimg_for6XZ(img,x,z) cimg_for6Z(img,z) cimg_for6X(img,x)
#define cimg_for6XC(img,x,c) cimg_for6C(img,c) cimg_for6X(img,x)
#define cimg_for6YZ(img,y,z) cimg_for6Z(img,z) cimg_for6Y(img,y)
#define cimg_for6YC(img,y,c) cimg_for6C(img,c) cimg_for6Y(img,y)
#define cimg_for6ZC(img,z,c) cimg_for6C(img,c) cimg_for6Z(img,z)
#define cimg_for6XYZ(img,x,y,z) cimg_for6Z(img,z) cimg_for6XY(img,x,y)
#define cimg_for6XZC(img,x,z,c) cimg_for6C(img,c) cimg_for6XZ(img,x,z)
#define cimg_for6YZC(img,y,z,c) cimg_for6C(img,c) cimg_for6YZ(img,y,z)
#define cimg_for6XYZC(img,x,y,z,c) cimg_for6C(img,c) cimg_for6XYZ(img,x,y,z)

#define cimg_for_in6(bound,i0,i1,i) \
 for (int i = (int)(i0)<0?0:(int)(i0), \
      _p2##i = i-2<0?0:i-2, \
      _p1##i = i-1<0?0:i-1, \
      _n1##i = i+1>=(int)(bound)?(int)(bound)-1:i+1, \
      _n2##i = i+2>=(int)(bound)?(int)(bound)-1:i+2, \
      _n3##i = i+3>=(int)(bound)?(int)(bound)-1:i+3; \
      i<=(int)(i1) && (_n3##i<(int)(bound) || _n2##i==--_n3##i || _n1##i==--_n2##i || i==(_n3##i = _n2##i = --_n1##i)); \
      _p2##i = _p1##i, _p1##i = i++, ++_n1##i, ++_n2##i, ++_n3##i)
#define cimg_for_in6X(img,x0,x1,x) cimg_for_in6((img)._width,x0,x1,x)
#define cimg_for_in6Y(img,y0,y1,y) cimg_for_in6((img)._height,y0,y1,y)
#define cimg_for_in6Z(img,z0,z1,z) cimg_for_in6((img)._depth,z0,z1,z)
#define cimg_for_in6C(img,c0,c1,c) cimg_for_in6((img)._spectrum,c0,c1,c)
#define cimg_for_in6XY(img,x0,y0,x1,y1,x,y) cimg_for_in6Y(img,y0,y1,y) cimg_for_in6X(img,x0,x1,x)
#define cimg_for_in6XZ(img,x0,z0,x1,z1,x,z) cimg_for_in6Z(img,z0,z1,z) cimg_for_in6X(img,x0,x1,x)
#define cimg_for_in6XC(img,x0,c0,x1,c1,x,c) cimg_for_in6C(img,c0,c1,c) cimg_for_in6X(img,x0,x1,x)
#define cimg_for_in6YZ(img,y0,z0,y1,z1,y,z) cimg_for_in6Z(img,z0,z1,z) cimg_for_in6Y(img,y0,y1,y)
#define cimg_for_in6YC(img,y0,c0,y1,c1,y,c) cimg_for_in6C(img,c0,c1,c) cimg_for_in6Y(img,y0,y1,y)
#define cimg_for_in6ZC(img,z0,c0,z1,c1,z,c) cimg_for_in6C(img,c0,c1,c) cimg_for_in6Z(img,z0,z1,z)
#define cimg_for_in6XYZ(img,x0,y0,z0,x1,y1,z1,x,y,z) cimg_for_in6Z(img,z0,z1,z) cimg_for_in6XY(img,x0,y0,x1,y1,x,y)
#define cimg_for_in6XZC(img,x0,z0,c0,x1,y1,c1,x,z,c) cimg_for_in6C(img,c0,c1,c) cimg_for_in6XZ(img,x0,y0,x1,y1,x,z)
#define cimg_for_in6YZC(img,y0,z0,c0,y1,z1,c1,y,z,c) cimg_for_in6C(img,c0,c1,c) cimg_for_in6YZ(img,y0,z0,y1,z1,y,z)
#define cimg_for_in6XYZC(img,x0,y0,z0,c0,x1,y1,z1,c1,x,y,z,c) cimg_for_in6C(img,c0,c1,c) cimg_for_in6XYZ(img,x0,y0,z0,x1,y1,z1,x,y,z)

#define cimg_for7(bound,i) \
 for (int i = 0, _p3##i = 0, _p2##i = 0, _p1##i = 0, \
      _n1##i = 1>=(bound)?(int)(bound)-1:1, \
      _n2##i = 2>=(bound)?(int)(bound)-1:2, \
      _n3##i = 3>=(bound)?(int)(bound)-1:3; \
      _n3##i<(int)(bound) || _n2##i==--_n3##i || _n1##i==--_n2##i || i==(_n3##i = _n2##i = --_n1##i); \
      _p3##i = _p2##i, _p2##i = _p1##i, _p1##i = i++, ++_n1##i, ++_n2##i, ++_n3##i)
#define cimg_for7X(img,x) cimg_for7((img)._width,x)
#define cimg_for7Y(img,y) cimg_for7((img)._height,y)
#define cimg_for7Z(img,z) cimg_for7((img)._depth,z)
#define cimg_for7C(img,c) cimg_for7((img)._spectrum,c)
#define cimg_for7XY(img,x,y) cimg_for7Y(img,y) cimg_for7X(img,x)
#define cimg_for7XZ(img,x,z) cimg_for7Z(img,z) cimg_for7X(img,x)
#define cimg_for7XC(img,x,c) cimg_for7C(img,c) cimg_for7X(img,x)
#define cimg_for7YZ(img,y,z) cimg_for7Z(img,z) cimg_for7Y(img,y)
#define cimg_for7YC(img,y,c) cimg_for7C(img,c) cimg_for7Y(img,y)
#define cimg_for7ZC(img,z,c) cimg_for7C(img,c) cimg_for7Z(img,z)
#define cimg_for7XYZ(img,x,y,z) cimg_for7Z(img,z) cimg_for7XY(img,x,y)
#define cimg_for7XZC(img,x,z,c) cimg_for7C(img,c) cimg_for7XZ(img,x,z)
#define cimg_for7YZC(img,y,z,c) cimg_for7C(img,c) cimg_for7YZ(img,y,z)
#define cimg_for7XYZC(img,x,y,z,c) cimg_for7C(img,c) cimg_for7XYZ(img,x,y,z)

#define cimg_for_in7(bound,i0,i1,i) \
 for (int i = (int)(i0)<0?0:(int)(i0), \
      _p3##i = i-3<0?0:i-3, \
      _p2##i = i-2<0?0:i-2, \
      _p1##i = i-1<0?0:i-1, \
      _n1##i = i+1>=(int)(bound)?(int)(bound)-1:i+1, \
      _n2##i = i+2>=(int)(bound)?(int)(bound)-1:i+2, \
      _n3##i = i+3>=(int)(bound)?(int)(bound)-1:i+3; \
      i<=(int)(i1) && (_n3##i<(int)(bound) || _n2##i==--_n3##i || _n1##i==--_n2##i || i==(_n3##i = _n2##i = --_n1##i)); \
      _p3##i = _p2##i, _p2##i = _p1##i, _p1##i = i++, ++_n1##i, ++_n2##i, ++_n3##i)
#define cimg_for_in7X(img,x0,x1,x) cimg_for_in7((img)._width,x0,x1,x)
#define cimg_for_in7Y(img,y0,y1,y) cimg_for_in7((img)._height,y0,y1,y)
#define cimg_for_in7Z(img,z0,z1,z) cimg_for_in7((img)._depth,z0,z1,z)
#define cimg_for_in7C(img,c0,c1,c) cimg_for_in7((img)._spectrum,c0,c1,c)
#define cimg_for_in7XY(img,x0,y0,x1,y1,x,y) cimg_for_in7Y(img,y0,y1,y) cimg_for_in7X(img,x0,x1,x)
#define cimg_for_in7XZ(img,x0,z0,x1,z1,x,z) cimg_for_in7Z(img,z0,z1,z) cimg_for_in7X(img,x0,x1,x)
#define cimg_for_in7XC(img,x0,c0,x1,c1,x,c) cimg_for_in7C(img,c0,c1,c) cimg_for_in7X(img,x0,x1,x)
#define cimg_for_in7YZ(img,y0,z0,y1,z1,y,z) cimg_for_in7Z(img,z0,z1,z) cimg_for_in7Y(img,y0,y1,y)
#define cimg_for_in7YC(img,y0,c0,y1,c1,y,c) cimg_for_in7C(img,c0,c1,c) cimg_for_in7Y(img,y0,y1,y)
#define cimg_for_in7ZC(img,z0,c0,z1,c1,z,c) cimg_for_in7C(img,c0,c1,c) cimg_for_in7Z(img,z0,z1,z)
#define cimg_for_in7XYZ(img,x0,y0,z0,x1,y1,z1,x,y,z) cimg_for_in7Z(img,z0,z1,z) cimg_for_in7XY(img,x0,y0,x1,y1,x,y)
#define cimg_for_in7XZC(img,x0,z0,c0,x1,y1,c1,x,z,c) cimg_for_in7C(img,c0,c1,c) cimg_for_in7XZ(img,x0,y0,x1,y1,x,z)
#define cimg_for_in7YZC(img,y0,z0,c0,y1,z1,c1,y,z,c) cimg_for_in7C(img,c0,c1,c) cimg_for_in7YZ(img,y0,z0,y1,z1,y,z)
#define cimg_for_in7XYZC(img,x0,y0,z0,c0,x1,y1,z1,c1,x,y,z,c) cimg_for_in7C(img,c0,c1,c) cimg_for_in7XYZ(img,x0,y0,z0,x1,y1,z1,x,y,z)

#define cimg_for8(bound,i) \
 for (int i = 0, _p3##i = 0, _p2##i = 0, _p1##i = 0, \
      _n1##i = 1>=(bound)?(int)(bound)-1:1, \
      _n2##i = 2>=(bound)?(int)(bound)-1:2, \
      _n3##i = 3>=(bound)?(int)(bound)-1:3, \
      _n4##i = 4>=(bound)?(int)(bound)-1:4; \
      _n4##i<(int)(bound) || _n3##i==--_n4##i || _n2##i==--_n3##i || _n1##i==--_n2##i || \
      i==(_n4##i = _n3##i = _n2##i = --_n1##i); \
      _p3##i = _p2##i, _p2##i = _p1##i, _p1##i = i++, ++_n1##i, ++_n2##i, ++_n3##i, ++_n4##i)
#define cimg_for8X(img,x) cimg_for8((img)._width,x)
#define cimg_for8Y(img,y) cimg_for8((img)._height,y)
#define cimg_for8Z(img,z) cimg_for8((img)._depth,z)
#define cimg_for8C(img,c) cimg_for8((img)._spectrum,c)
#define cimg_for8XY(img,x,y) cimg_for8Y(img,y) cimg_for8X(img,x)
#define cimg_for8XZ(img,x,z) cimg_for8Z(img,z) cimg_for8X(img,x)
#define cimg_for8XC(img,x,c) cimg_for8C(img,c) cimg_for8X(img,x)
#define cimg_for8YZ(img,y,z) cimg_for8Z(img,z) cimg_for8Y(img,y)
#define cimg_for8YC(img,y,c) cimg_for8C(img,c) cimg_for8Y(img,y)
#define cimg_for8ZC(img,z,c) cimg_for8C(img,c) cimg_for8Z(img,z)
#define cimg_for8XYZ(img,x,y,z) cimg_for8Z(img,z) cimg_for8XY(img,x,y)
#define cimg_for8XZC(img,x,z,c) cimg_for8C(img,c) cimg_for8XZ(img,x,z)
#define cimg_for8YZC(img,y,z,c) cimg_for8C(img,c) cimg_for8YZ(img,y,z)
#define cimg_for8XYZC(img,x,y,z,c) cimg_for8C(img,c) cimg_for8XYZ(img,x,y,z)

#define cimg_for_in8(bound,i0,i1,i) \
 for (int i = (int)(i0)<0?0:(int)(i0), \
      _p3##i = i-3<0?0:i-3, \
      _p2##i = i-2<0?0:i-2, \
      _p1##i = i-1<0?0:i-1, \
      _n1##i = i+1>=(int)(bound)?(int)(bound)-1:i+1, \
      _n2##i = i+2>=(int)(bound)?(int)(bound)-1:i+2, \
      _n3##i = i+3>=(int)(bound)?(int)(bound)-1:i+3, \
      _n4##i = i+4>=(int)(bound)?(int)(bound)-1:i+4; \
      i<=(int)(i1) && (_n4##i<(int)(bound) || _n3##i==--_n4##i || _n2##i==--_n3##i || _n1##i==--_n2##i || \
      i==(_n4##i = _n3##i = _n2##i = --_n1##i)); \
      _p3##i = _p2##i, _p2##i = _p1##i, _p1##i = i++, ++_n1##i, ++_n2##i, ++_n3##i, ++_n4##i)
#define cimg_for_in8X(img,x0,x1,x) cimg_for_in8((img)._width,x0,x1,x)
#define cimg_for_in8Y(img,y0,y1,y) cimg_for_in8((img)._height,y0,y1,y)
#define cimg_for_in8Z(img,z0,z1,z) cimg_for_in8((img)._depth,z0,z1,z)
#define cimg_for_in8C(img,c0,c1,c) cimg_for_in8((img)._spectrum,c0,c1,c)
#define cimg_for_in8XY(img,x0,y0,x1,y1,x,y) cimg_for_in8Y(img,y0,y1,y) cimg_for_in8X(img,x0,x1,x)
#define cimg_for_in8XZ(img,x0,z0,x1,z1,x,z) cimg_for_in8Z(img,z0,z1,z) cimg_for_in8X(img,x0,x1,x)
#define cimg_for_in8XC(img,x0,c0,x1,c1,x,c) cimg_for_in8C(img,c0,c1,c) cimg_for_in8X(img,x0,x1,x)
#define cimg_for_in8YZ(img,y0,z0,y1,z1,y,z) cimg_for_in8Z(img,z0,z1,z) cimg_for_in8Y(img,y0,y1,y)
#define cimg_for_in8YC(img,y0,c0,y1,c1,y,c) cimg_for_in8C(img,c0,c1,c) cimg_for_in8Y(img,y0,y1,y)
#define cimg_for_in8ZC(img,z0,c0,z1,c1,z,c) cimg_for_in8C(img,c0,c1,c) cimg_for_in8Z(img,z0,z1,z)
#define cimg_for_in8XYZ(img,x0,y0,z0,x1,y1,z1,x,y,z) cimg_for_in8Z(img,z0,z1,z) cimg_for_in8XY(img,x0,y0,x1,y1,x,y)
#define cimg_for_in8XZC(img,x0,z0,c0,x1,y1,c1,x,z,c) cimg_for_in8C(img,c0,c1,c) cimg_for_in8XZ(img,x0,y0,x1,y1,x,z)
#define cimg_for_in8YZC(img,y0,z0,c0,y1,z1,c1,y,z,c) cimg_for_in8C(img,c0,c1,c) cimg_for_in8YZ(img,y0,z0,y1,z1,y,z)
#define cimg_for_in8XYZC(img,x0,y0,z0,c0,x1,y1,z1,c1,x,y,z,c) cimg_for_in8C(img,c0,c1,c) cimg_for_in8XYZ(img,x0,y0,z0,x1,y1,z1,x,y,z)

#define cimg_for9(bound,i) \
  for (int i = 0, _p4##i = 0, _p3##i = 0, _p2##i = 0, _p1##i = 0, \
       _n1##i = 1>=(int)(bound)?(int)(bound)-1:1, \
       _n2##i = 2>=(int)(bound)?(int)(bound)-1:2, \
       _n3##i = 3>=(int)(bound)?(int)(bound)-1:3, \
       _n4##i = 4>=(int)(bound)?(int)(bound)-1:4; \
       _n4##i<(int)(bound) || _n3##i==--_n4##i || _n2##i==--_n3##i || _n1##i==--_n2##i || \
       i==(_n4##i = _n3##i = _n2##i = --_n1##i); \
       _p4##i = _p3##i, _p3##i = _p2##i, _p2##i = _p1##i, _p1##i = i++, ++_n1##i, ++_n2##i, ++_n3##i, ++_n4##i)
#define cimg_for9X(img,x) cimg_for9((img)._width,x)
#define cimg_for9Y(img,y) cimg_for9((img)._height,y)
#define cimg_for9Z(img,z) cimg_for9((img)._depth,z)
#define cimg_for9C(img,c) cimg_for9((img)._spectrum,c)
#define cimg_for9XY(img,x,y) cimg_for9Y(img,y) cimg_for9X(img,x)
#define cimg_for9XZ(img,x,z) cimg_for9Z(img,z) cimg_for9X(img,x)
#define cimg_for9XC(img,x,c) cimg_for9C(img,c) cimg_for9X(img,x)
#define cimg_for9YZ(img,y,z) cimg_for9Z(img,z) cimg_for9Y(img,y)
#define cimg_for9YC(img,y,c) cimg_for9C(img,c) cimg_for9Y(img,y)
#define cimg_for9ZC(img,z,c) cimg_for9C(img,c) cimg_for9Z(img,z)
#define cimg_for9XYZ(img,x,y,z) cimg_for9Z(img,z) cimg_for9XY(img,x,y)
#define cimg_for9XZC(img,x,z,c) cimg_for9C(img,c) cimg_for9XZ(img,x,z)
#define cimg_for9YZC(img,y,z,c) cimg_for9C(img,c) cimg_for9YZ(img,y,z)
#define cimg_for9XYZC(img,x,y,z,c) cimg_for9C(img,c) cimg_for9XYZ(img,x,y,z)

#define cimg_for_in9(bound,i0,i1,i) \
  for (int i = (int)(i0)<0?0:(int)(i0), \
       _p4##i = i-4<0?0:i-4, \
       _p3##i = i-3<0?0:i-3, \
       _p2##i = i-2<0?0:i-2, \
       _p1##i = i-1<0?0:i-1, \
       _n1##i = i+1>=(int)(bound)?(int)(bound)-1:i+1, \
       _n2##i = i+2>=(int)(bound)?(int)(bound)-1:i+2, \
       _n3##i = i+3>=(int)(bound)?(int)(bound)-1:i+3, \
       _n4##i = i+4>=(int)(bound)?(int)(bound)-1:i+4; \
       i<=(int)(i1) && (_n4##i<(int)(bound) || _n3##i==--_n4##i || _n2##i==--_n3##i || _n1##i==--_n2##i || \
       i==(_n4##i = _n3##i = _n2##i = --_n1##i)); \
       _p4##i = _p3##i, _p3##i = _p2##i, _p2##i = _p1##i, _p1##i = i++, ++_n1##i, ++_n2##i, ++_n3##i, ++_n4##i)
#define cimg_for_in9X(img,x0,x1,x) cimg_for_in9((img)._width,x0,x1,x)
#define cimg_for_in9Y(img,y0,y1,y) cimg_for_in9((img)._height,y0,y1,y)
#define cimg_for_in9Z(img,z0,z1,z) cimg_for_in9((img)._depth,z0,z1,z)
#define cimg_for_in9C(img,c0,c1,c) cimg_for_in9((img)._spectrum,c0,c1,c)
#define cimg_for_in9XY(img,x0,y0,x1,y1,x,y) cimg_for_in9Y(img,y0,y1,y) cimg_for_in9X(img,x0,x1,x)
#define cimg_for_in9XZ(img,x0,z0,x1,z1,x,z) cimg_for_in9Z(img,z0,z1,z) cimg_for_in9X(img,x0,x1,x)
#define cimg_for_in9XC(img,x0,c0,x1,c1,x,c) cimg_for_in9C(img,c0,c1,c) cimg_for_in9X(img,x0,x1,x)
#define cimg_for_in9YZ(img,y0,z0,y1,z1,y,z) cimg_for_in9Z(img,z0,z1,z) cimg_for_in9Y(img,y0,y1,y)
#define cimg_for_in9YC(img,y0,c0,y1,c1,y,c) cimg_for_in9C(img,c0,c1,c) cimg_for_in9Y(img,y0,y1,y)
#define cimg_for_in9ZC(img,z0,c0,z1,c1,z,c) cimg_for_in9C(img,c0,c1,c) cimg_for_in9Z(img,z0,z1,z)
#define cimg_for_in9XYZ(img,x0,y0,z0,x1,y1,z1,x,y,z) cimg_for_in9Z(img,z0,z1,z) cimg_for_in9XY(img,x0,y0,x1,y1,x,y)
#define cimg_for_in9XZC(img,x0,z0,c0,x1,y1,c1,x,z,c) cimg_for_in9C(img,c0,c1,c) cimg_for_in9XZ(img,x0,y0,x1,y1,x,z)
#define cimg_for_in9YZC(img,y0,z0,c0,y1,z1,c1,y,z,c) cimg_for_in9C(img,c0,c1,c) cimg_for_in9YZ(img,y0,z0,y1,z1,y,z)
#define cimg_for_in9XYZC(img,x0,y0,z0,c0,x1,y1,z1,c1,x,y,z,c) cimg_for_in9C(img,c0,c1,c) cimg_for_in9XYZ(img,x0,y0,z0,x1,y1,z1,x,y,z)

#define cimg_for2x2(img,x,y,z,c,I,T) \
  cimg_for2((img)._height,y) for (int x = 0, \
   _n1##x = (int)( \
   (I[0] = (T)(img)(0,y,z,c)), \
   (I[2] = (T)(img)(0,_n1##y,z,c)), \
   1>=(img)._width?(img).width()-1:1);  \
   (_n1##x<(img).width() && ( \
   (I[1] = (T)(img)(_n1##x,y,z,c)), \
   (I[3] = (T)(img)(_n1##x,_n1##y,z,c)),1)) || \
   x==--_n1##x; \
   I[0] = I[1], \
   I[2] = I[3], \
   ++x, ++_n1##x)

#define cimg_for_in2x2(img,x0,y0,x1,y1,x,y,z,c,I,T) \
  cimg_for_in2((img)._height,y0,y1,y) for (int x = (int)(x0)<0?0:(int)(x0), \
   _n1##x = (int)( \
   (I[0] = (T)(img)(x,y,z,c)), \
   (I[2] = (T)(img)(x,_n1##y,z,c)), \
   x+1>=(int)(img)._width?(img).width()-1:x+1); \
   x<=(int)(x1) && ((_n1##x<(img).width() && (  \
   (I[1] = (T)(img)(_n1##x,y,z,c)), \
   (I[3] = (T)(img)(_n1##x,_n1##y,z,c)),1)) || \
   x==--_n1##x); \
   I[0] = I[1], \
   I[2] = I[3], \
   ++x, ++_n1##x)

#define cimg_for3x3(img,x,y,z,c,I,T) \
  cimg_for3((img)._height,y) for (int x = 0, \
   _p1##x = 0, \
   _n1##x = (int)( \
   (I[0] = I[1] = (T)(img)(_p1##x,_p1##y,z,c)), \
   (I[3] = I[4] = (T)(img)(0,y,z,c)), \
   (I[6] = I[7] = (T)(img)(0,_n1##y,z,c)),	\
   1>=(img)._width?(img).width()-1:1); \
   (_n1##x<(img).width() && ( \
   (I[2] = (T)(img)(_n1##x,_p1##y,z,c)), \
   (I[5] = (T)(img)(_n1##x,y,z,c)), \
   (I[8] = (T)(img)(_n1##x,_n1##y,z,c)),1)) || \
   x==--_n1##x; \
   I[0] = I[1], I[1] = I[2], \
   I[3] = I[4], I[4] = I[5], \
   I[6] = I[7], I[7] = I[8], \
   _p1##x = x++, ++_n1##x)

#define cimg_for_in3x3(img,x0,y0,x1,y1,x,y,z,c,I,T) \
  cimg_for_in3((img)._height,y0,y1,y) for (int x = (int)(x0)<0?0:(int)(x0), \
   _p1##x = x-1<0?0:x-1, \
   _n1##x = (int)( \
   (I[0] = (T)(img)(_p1##x,_p1##y,z,c)), \
   (I[3] = (T)(img)(_p1##x,y,z,c)), \
   (I[6] = (T)(img)(_p1##x,_n1##y,z,c)), \
   (I[1] = (T)(img)(x,_p1##y,z,c)), \
   (I[4] = (T)(img)(x,y,z,c)), \
   (I[7] = (T)(img)(x,_n1##y,z,c)), \
   x+1>=(int)(img)._width?(img).width()-1:x+1); \
   x<=(int)(x1) && ((_n1##x<(img).width() && ( \
   (I[2] = (T)(img)(_n1##x,_p1##y,z,c)), \
   (I[5] = (T)(img)(_n1##x,y,z,c)), \
   (I[8] = (T)(img)(_n1##x,_n1##y,z,c)),1)) || \
   x==--_n1##x);	    \
   I[0] = I[1], I[1] = I[2], \
   I[3] = I[4], I[4] = I[5], \
   I[6] = I[7], I[7] = I[8], \
   _p1##x = x++, ++_n1##x)

#define cimg_for4x4(img,x,y,z,c,I,T) \
  cimg_for4((img)._height,y) for (int x = 0, \
   _p1##x = 0, \
   _n1##x = 1>=(img)._width?(img).width()-1:1, \
   _n2##x = (int)( \
   (I[0] = I[1] = (T)(img)(_p1##x,_p1##y,z,c)), \
   (I[4] = I[5] = (T)(img)(0,y,z,c)), \
   (I[8] = I[9] = (T)(img)(0,_n1##y,z,c)), \
   (I[12] = I[13] = (T)(img)(0,_n2##y,z,c)), \
   (I[2] = (T)(img)(_n1##x,_p1##y,z,c)), \
   (I[6] = (T)(img)(_n1##x,y,z,c)), \
   (I[10] = (T)(img)(_n1##x,_n1##y,z,c)), \
   (I[14] = (T)(img)(_n1##x,_n2##y,z,c)), \
   2>=(img)._width?(img).width()-1:2); \
   (_n2##x<(img).width() && ( \
   (I[3] = (T)(img)(_n2##x,_p1##y,z,c)), \
   (I[7] = (T)(img)(_n2##x,y,z,c)), \
   (I[11] = (T)(img)(_n2##x,_n1##y,z,c)), \
   (I[15] = (T)(img)(_n2##x,_n2##y,z,c)),1)) || \
   _n1##x==--_n2##x || x==(_n2##x = --_n1##x); \
   I[0] = I[1], I[1] = I[2], I[2] = I[3], \
   I[4] = I[5], I[5] = I[6], I[6] = I[7], \
   I[8] = I[9], I[9] = I[10], I[10] = I[11], \
   I[12] = I[13], I[13] = I[14], I[14] = I[15], \
   _p1##x = x++, ++_n1##x, ++_n2##x)

#define cimg_for_in4x4(img,x0,y0,x1,y1,x,y,z,c,I,T) \
  cimg_for_in4((img)._height,y0,y1,y) for (int x = (int)(x0)<0?0:(int)(x0), \
   _p1##x = x-1<0?0:x-1, \
   _n1##x = x+1>=(int)(img)._width?(img).width()-1:x+1, \
   _n2##x = (int)( \
   (I[0] = (T)(img)(_p1##x,_p1##y,z,c)), \
   (I[4] = (T)(img)(_p1##x,y,z,c)), \
   (I[8] = (T)(img)(_p1##x,_n1##y,z,c)), \
   (I[12] = (T)(img)(_p1##x,_n2##y,z,c)), \
   (I[1] = (T)(img)(x,_p1##y,z,c)), \
   (I[5] = (T)(img)(x,y,z,c)), \
   (I[9] = (T)(img)(x,_n1##y,z,c)), \
   (I[13] = (T)(img)(x,_n2##y,z,c)), \
   (I[2] = (T)(img)(_n1##x,_p1##y,z,c)), \
   (I[6] = (T)(img)(_n1##x,y,z,c)), \
   (I[10] = (T)(img)(_n1##x,_n1##y,z,c)), \
   (I[14] = (T)(img)(_n1##x,_n2##y,z,c)), \
   x+2>=(int)(img)._width?(img).width()-1:x+2); \
   x<=(int)(x1) && ((_n2##x<(img).width() && ( \
   (I[3] = (T)(img)(_n2##x,_p1##y,z,c)), \
   (I[7] = (T)(img)(_n2##x,y,z,c)), \
   (I[11] = (T)(img)(_n2##x,_n1##y,z,c)), \
   (I[15] = (T)(img)(_n2##x,_n2##y,z,c)),1)) || \
   _n1##x==--_n2##x || x==(_n2##x = --_n1##x)); \
   I[0] = I[1], I[1] = I[2], I[2] = I[3], \
   I[4] = I[5], I[5] = I[6], I[6] = I[7], \
   I[8] = I[9], I[9] = I[10], I[10] = I[11], \
   I[12] = I[13], I[13] = I[14], I[14] = I[15], \
   _p1##x = x++, ++_n1##x, ++_n2##x)

#define cimg_for5x5(img,x,y,z,c,I,T) \
 cimg_for5((img)._height,y) for (int x = 0, \
   _p2##x = 0, _p1##x = 0, \
   _n1##x = 1>=(img)._width?(img).width()-1:1, \
   _n2##x = (int)( \
   (I[0] = I[1] = I[2] = (T)(img)(_p2##x,_p2##y,z,c)), \
   (I[5] = I[6] = I[7] = (T)(img)(0,_p1##y,z,c)), \
   (I[10] = I[11] = I[12] = (T)(img)(0,y,z,c)), \
   (I[15] = I[16] = I[17] = (T)(img)(0,_n1##y,z,c)), \
   (I[20] = I[21] = I[22] = (T)(img)(0,_n2##y,z,c)), \
   (I[3] = (T)(img)(_n1##x,_p2##y,z,c)), \
   (I[8] = (T)(img)(_n1##x,_p1##y,z,c)), \
   (I[13] = (T)(img)(_n1##x,y,z,c)), \
   (I[18] = (T)(img)(_n1##x,_n1##y,z,c)), \
   (I[23] = (T)(img)(_n1##x,_n2##y,z,c)),  \
   2>=(img)._width?(img).width()-1:2); \
   (_n2##x<(img).width() && ( \
   (I[4] = (T)(img)(_n2##x,_p2##y,z,c)), \
   (I[9] = (T)(img)(_n2##x,_p1##y,z,c)), \
   (I[14] = (T)(img)(_n2##x,y,z,c)), \
   (I[19] = (T)(img)(_n2##x,_n1##y,z,c)), \
   (I[24] = (T)(img)(_n2##x,_n2##y,z,c)),1)) || \
   _n1##x==--_n2##x || x==(_n2##x = --_n1##x); \
   I[0] = I[1], I[1] = I[2], I[2] = I[3], I[3] = I[4], \
   I[5] = I[6], I[6] = I[7], I[7] = I[8], I[8] = I[9], \
   I[10] = I[11], I[11] = I[12], I[12] = I[13], I[13] = I[14], \
   I[15] = I[16], I[16] = I[17], I[17] = I[18], I[18] = I[19], \
   I[20] = I[21], I[21] = I[22], I[22] = I[23], I[23] = I[24], \
   _p2##x = _p1##x, _p1##x = x++, ++_n1##x, ++_n2##x)

#define cimg_for_in5x5(img,x0,y0,x1,y1,x,y,z,c,I,T) \
 cimg_for_in5((img)._height,y0,y1,y) for (int x = (int)(x0)<0?0:(int)(x0), \
   _p2##x = x-2<0?0:x-2, \
   _p1##x = x-1<0?0:x-1, \
   _n1##x = x+1>=(int)(img)._width?(img).width()-1:x+1, \
   _n2##x = (int)( \
   (I[0] = (T)(img)(_p2##x,_p2##y,z,c)), \
   (I[5] = (T)(img)(_p2##x,_p1##y,z,c)), \
   (I[10] = (T)(img)(_p2##x,y,z,c)), \
   (I[15] = (T)(img)(_p2##x,_n1##y,z,c)), \
   (I[20] = (T)(img)(_p2##x,_n2##y,z,c)), \
   (I[1] = (T)(img)(_p1##x,_p2##y,z,c)), \
   (I[6] = (T)(img)(_p1##x,_p1##y,z,c)), \
   (I[11] = (T)(img)(_p1##x,y,z,c)), \
   (I[16] = (T)(img)(_p1##x,_n1##y,z,c)), \
   (I[21] = (T)(img)(_p1##x,_n2##y,z,c)), \
   (I[2] = (T)(img)(x,_p2##y,z,c)), \
   (I[7] = (T)(img)(x,_p1##y,z,c)), \
   (I[12] = (T)(img)(x,y,z,c)), \
   (I[17] = (T)(img)(x,_n1##y,z,c)), \
   (I[22] = (T)(img)(x,_n2##y,z,c)), \
   (I[3] = (T)(img)(_n1##x,_p2##y,z,c)), \
   (I[8] = (T)(img)(_n1##x,_p1##y,z,c)), \
   (I[13] = (T)(img)(_n1##x,y,z,c)), \
   (I[18] = (T)(img)(_n1##x,_n1##y,z,c)), \
   (I[23] = (T)(img)(_n1##x,_n2##y,z,c)), \
   x+2>=(int)(img)._width?(img).width()-1:x+2); \
   x<=(int)(x1) && ((_n2##x<(img).width() && ( \
   (I[4] = (T)(img)(_n2##x,_p2##y,z,c)), \
   (I[9] = (T)(img)(_n2##x,_p1##y,z,c)), \
   (I[14] = (T)(img)(_n2##x,y,z,c)), \
   (I[19] = (T)(img)(_n2##x,_n1##y,z,c)), \
   (I[24] = (T)(img)(_n2##x,_n2##y,z,c)),1)) || \
   _n1##x==--_n2##x || x==(_n2##x = --_n1##x)); \
   I[0] = I[1], I[1] = I[2], I[2] = I[3], I[3] = I[4], \
   I[5] = I[6], I[6] = I[7], I[7] = I[8], I[8] = I[9], \
   I[10] = I[11], I[11] = I[12], I[12] = I[13], I[13] = I[14], \
   I[15] = I[16], I[16] = I[17], I[17] = I[18], I[18] = I[19], \
   I[20] = I[21], I[21] = I[22], I[22] = I[23], I[23] = I[24], \
   _p2##x = _p1##x, _p1##x = x++, ++_n1##x, ++_n2##x)

#define cimg_for6x6(img,x,y,z,c,I,T) \
 cimg_for6((img)._height,y) for (int x = 0, \
   _p2##x = 0, _p1##x = 0, \
   _n1##x = 1>=(img)._width?(img).width()-1:1, \
   _n2##x = 2>=(img)._width?(img).width()-1:2, \
   _n3##x = (int)( \
   (I[0] = I[1] = I[2] = (T)(img)(_p2##x,_p2##y,z,c)), \
   (I[6] = I[7] = I[8] = (T)(img)(0,_p1##y,z,c)), \
   (I[12] = I[13] = I[14] = (T)(img)(0,y,z,c)), \
   (I[18] = I[19] = I[20] = (T)(img)(0,_n1##y,z,c)), \
   (I[24] = I[25] = I[26] = (T)(img)(0,_n2##y,z,c)), \
   (I[30] = I[31] = I[32] = (T)(img)(0,_n3##y,z,c)), \
   (I[3] = (T)(img)(_n1##x,_p2##y,z,c)), \
   (I[9] = (T)(img)(_n1##x,_p1##y,z,c)), \
   (I[15] = (T)(img)(_n1##x,y,z,c)), \
   (I[21] = (T)(img)(_n1##x,_n1##y,z,c)), \
   (I[27] = (T)(img)(_n1##x,_n2##y,z,c)), \
   (I[33] = (T)(img)(_n1##x,_n3##y,z,c)), \
   (I[4] = (T)(img)(_n2##x,_p2##y,z,c)), \
   (I[10] = (T)(img)(_n2##x,_p1##y,z,c)), \
   (I[16] = (T)(img)(_n2##x,y,z,c)), \
   (I[22] = (T)(img)(_n2##x,_n1##y,z,c)), \
   (I[28] = (T)(img)(_n2##x,_n2##y,z,c)), \
   (I[34] = (T)(img)(_n2##x,_n3##y,z,c)), \
   3>=(img)._width?(img).width()-1:3); \
   (_n3##x<(img).width() && ( \
   (I[5] = (T)(img)(_n3##x,_p2##y,z,c)), \
   (I[11] = (T)(img)(_n3##x,_p1##y,z,c)), \
   (I[17] = (T)(img)(_n3##x,y,z,c)), \
   (I[23] = (T)(img)(_n3##x,_n1##y,z,c)), \
   (I[29] = (T)(img)(_n3##x,_n2##y,z,c)), \
   (I[35] = (T)(img)(_n3##x,_n3##y,z,c)),1)) || \
   _n2##x==--_n3##x || _n1##x==--_n2##x || x==(_n3## x = _n2##x = --_n1##x); \
   I[0] = I[1], I[1] = I[2], I[2] = I[3], I[3] = I[4], I[4] = I[5], \
   I[6] = I[7], I[7] = I[8], I[8] = I[9], I[9] = I[10], I[10] = I[11], \
   I[12] = I[13], I[13] = I[14], I[14] = I[15], I[15] = I[16], I[16] = I[17], \
   I[18] = I[19], I[19] = I[20], I[20] = I[21], I[21] = I[22], I[22] = I[23], \
   I[24] = I[25], I[25] = I[26], I[26] = I[27], I[27] = I[28], I[28] = I[29], \
   I[30] = I[31], I[31] = I[32], I[32] = I[33], I[33] = I[34], I[34] = I[35], \
   _p2##x = _p1##x, _p1##x = x++, ++_n1##x, ++_n2##x, ++_n3##x)

#define cimg_for_in6x6(img,x0,y0,x1,y1,x,y,z,c,I,T) \
  cimg_for_in6((img)._height,y0,y1,y) for (int x = (int)(x0)<0?0:(int)x0, \
   _p2##x = x-2<0?0:x-2, \
   _p1##x = x-1<0?0:x-1, \
   _n1##x = x+1>=(int)(img)._width?(img).width()-1:x+1, \
   _n2##x = x+2>=(int)(img)._width?(img).width()-1:x+2, \
   _n3##x = (int)( \
   (I[0] = (T)(img)(_p2##x,_p2##y,z,c)), \
   (I[6] = (T)(img)(_p2##x,_p1##y,z,c)), \
   (I[12] = (T)(img)(_p2##x,y,z,c)), \
   (I[18] = (T)(img)(_p2##x,_n1##y,z,c)), \
   (I[24] = (T)(img)(_p2##x,_n2##y,z,c)), \
   (I[30] = (T)(img)(_p2##x,_n3##y,z,c)), \
   (I[1] = (T)(img)(_p1##x,_p2##y,z,c)), \
   (I[7] = (T)(img)(_p1##x,_p1##y,z,c)), \
   (I[13] = (T)(img)(_p1##x,y,z,c)), \
   (I[19] = (T)(img)(_p1##x,_n1##y,z,c)), \
   (I[25] = (T)(img)(_p1##x,_n2##y,z,c)), \
   (I[31] = (T)(img)(_p1##x,_n3##y,z,c)), \
   (I[2] = (T)(img)(x,_p2##y,z,c)), \
   (I[8] = (T)(img)(x,_p1##y,z,c)), \
   (I[14] = (T)(img)(x,y,z,c)), \
   (I[20] = (T)(img)(x,_n1##y,z,c)), \
   (I[26] = (T)(img)(x,_n2##y,z,c)), \
   (I[32] = (T)(img)(x,_n3##y,z,c)), \
   (I[3] = (T)(img)(_n1##x,_p2##y,z,c)), \
   (I[9] = (T)(img)(_n1##x,_p1##y,z,c)), \
   (I[15] = (T)(img)(_n1##x,y,z,c)), \
   (I[21] = (T)(img)(_n1##x,_n1##y,z,c)), \
   (I[27] = (T)(img)(_n1##x,_n2##y,z,c)), \
   (I[33] = (T)(img)(_n1##x,_n3##y,z,c)), \
   (I[4] = (T)(img)(_n2##x,_p2##y,z,c)), \
   (I[10] = (T)(img)(_n2##x,_p1##y,z,c)), \
   (I[16] = (T)(img)(_n2##x,y,z,c)), \
   (I[22] = (T)(img)(_n2##x,_n1##y,z,c)), \
   (I[28] = (T)(img)(_n2##x,_n2##y,z,c)), \
   (I[34] = (T)(img)(_n2##x,_n3##y,z,c)), \
   x+3>=(int)(img)._width?(img).width()-1:x+3); \
   x<=(int)(x1) && ((_n3##x<(img).width() && ( \
   (I[5] = (T)(img)(_n3##x,_p2##y,z,c)), \
   (I[11] = (T)(img)(_n3##x,_p1##y,z,c)), \
   (I[17] = (T)(img)(_n3##x,y,z,c)), \
   (I[23] = (T)(img)(_n3##x,_n1##y,z,c)), \
   (I[29] = (T)(img)(_n3##x,_n2##y,z,c)), \
   (I[35] = (T)(img)(_n3##x,_n3##y,z,c)),1)) || \
   _n2##x==--_n3##x || _n1##x==--_n2##x || x==(_n3## x = _n2##x = --_n1##x)); \
   I[0] = I[1], I[1] = I[2], I[2] = I[3], I[3] = I[4], I[4] = I[5], \
   I[6] = I[7], I[7] = I[8], I[8] = I[9], I[9] = I[10], I[10] = I[11], \
   I[12] = I[13], I[13] = I[14], I[14] = I[15], I[15] = I[16], I[16] = I[17], \
   I[18] = I[19], I[19] = I[20], I[20] = I[21], I[21] = I[22], I[22] = I[23], \
   I[24] = I[25], I[25] = I[26], I[26] = I[27], I[27] = I[28], I[28] = I[29], \
   I[30] = I[31], I[31] = I[32], I[32] = I[33], I[33] = I[34], I[34] = I[35], \
   _p2##x = _p1##x, _p1##x = x++, ++_n1##x, ++_n2##x, ++_n3##x)

#define cimg_for7x7(img,x,y,z,c,I,T) \
  cimg_for7((img)._height,y) for (int x = 0, \
   _p3##x = 0, _p2##x = 0, _p1##x = 0, \
   _n1##x = 1>=(img)._width?(img).width()-1:1, \
   _n2##x = 2>=(img)._width?(img).width()-1:2, \
   _n3##x = (int)( \
   (I[0] = I[1] = I[2] = I[3] = (T)(img)(_p3##x,_p3##y,z,c)), \
   (I[7] = I[8] = I[9] = I[10] = (T)(img)(0,_p2##y,z,c)), \
   (I[14] = I[15] = I[16] = I[17] = (T)(img)(0,_p1##y,z,c)), \
   (I[21] = I[22] = I[23] = I[24] = (T)(img)(0,y,z,c)), \
   (I[28] = I[29] = I[30] = I[31] = (T)(img)(0,_n1##y,z,c)), \
   (I[35] = I[36] = I[37] = I[38] = (T)(img)(0,_n2##y,z,c)), \
   (I[42] = I[43] = I[44] = I[45] = (T)(img)(0,_n3##y,z,c)), \
   (I[4] = (T)(img)(_n1##x,_p3##y,z,c)), \
   (I[11] = (T)(img)(_n1##x,_p2##y,z,c)), \
   (I[18] = (T)(img)(_n1##x,_p1##y,z,c)), \
   (I[25] = (T)(img)(_n1##x,y,z,c)), \
   (I[32] = (T)(img)(_n1##x,_n1##y,z,c)), \
   (I[39] = (T)(img)(_n1##x,_n2##y,z,c)), \
   (I[46] = (T)(img)(_n1##x,_n3##y,z,c)), \
   (I[5] = (T)(img)(_n2##x,_p3##y,z,c)), \
   (I[12] = (T)(img)(_n2##x,_p2##y,z,c)), \
   (I[19] = (T)(img)(_n2##x,_p1##y,z,c)), \
   (I[26] = (T)(img)(_n2##x,y,z,c)), \
   (I[33] = (T)(img)(_n2##x,_n1##y,z,c)), \
   (I[40] = (T)(img)(_n2##x,_n2##y,z,c)), \
   (I[47] = (T)(img)(_n2##x,_n3##y,z,c)), \
   3>=(img)._width?(img).width()-1:3); \
   (_n3##x<(img).width() && ( \
   (I[6] = (T)(img)(_n3##x,_p3##y,z,c)), \
   (I[13] = (T)(img)(_n3##x,_p2##y,z,c)), \
   (I[20] = (T)(img)(_n3##x,_p1##y,z,c)), \
   (I[27] = (T)(img)(_n3##x,y,z,c)), \
   (I[34] = (T)(img)(_n3##x,_n1##y,z,c)), \
   (I[41] = (T)(img)(_n3##x,_n2##y,z,c)), \
   (I[48] = (T)(img)(_n3##x,_n3##y,z,c)),1)) || \
   _n2##x==--_n3##x || _n1##x==--_n2##x || x==(_n3##x = _n2##x = --_n1##x); \
   I[0] = I[1], I[1] = I[2], I[2] = I[3], I[3] = I[4], I[4] = I[5], I[5] = I[6], \
   I[7] = I[8], I[8] = I[9], I[9] = I[10], I[10] = I[11], I[11] = I[12], I[12] = I[13], \
   I[14] = I[15], I[15] = I[16], I[16] = I[17], I[17] = I[18], I[18] = I[19], I[19] = I[20], \
   I[21] = I[22], I[22] = I[23], I[23] = I[24], I[24] = I[25], I[25] = I[26], I[26] = I[27], \
   I[28] = I[29], I[29] = I[30], I[30] = I[31], I[31] = I[32], I[32] = I[33], I[33] = I[34], \
   I[35] = I[36], I[36] = I[37], I[37] = I[38], I[38] = I[39], I[39] = I[40], I[40] = I[41], \
   I[42] = I[43], I[43] = I[44], I[44] = I[45], I[45] = I[46], I[46] = I[47], I[47] = I[48], \
   _p3##x = _p2##x, _p2##x = _p1##x, _p1##x = x++, ++_n1##x, ++_n2##x, ++_n3##x)

#define cimg_for_in7x7(img,x0,y0,x1,y1,x,y,z,c,I,T) \
  cimg_for_in7((img)._height,y0,y1,y) for (int x = (int)(x0)<0?0:(int)(x0), \
   _p3##x = x-3<0?0:x-3, \
   _p2##x = x-2<0?0:x-2, \
   _p1##x = x-1<0?0:x-1, \
   _n1##x = x+1>=(int)(img)._width?(img).width()-1:x+1, \
   _n2##x = x+2>=(int)(img)._width?(img).width()-1:x+2, \
   _n3##x = (int)( \
   (I[0] = (T)(img)(_p3##x,_p3##y,z,c)), \
   (I[7] = (T)(img)(_p3##x,_p2##y,z,c)), \
   (I[14] = (T)(img)(_p3##x,_p1##y,z,c)), \
   (I[21] = (T)(img)(_p3##x,y,z,c)), \
   (I[28] = (T)(img)(_p3##x,_n1##y,z,c)), \
   (I[35] = (T)(img)(_p3##x,_n2##y,z,c)), \
   (I[42] = (T)(img)(_p3##x,_n3##y,z,c)), \
   (I[1] = (T)(img)(_p2##x,_p3##y,z,c)), \
   (I[8] = (T)(img)(_p2##x,_p2##y,z,c)), \
   (I[15] = (T)(img)(_p2##x,_p1##y,z,c)), \
   (I[22] = (T)(img)(_p2##x,y,z,c)), \
   (I[29] = (T)(img)(_p2##x,_n1##y,z,c)), \
   (I[36] = (T)(img)(_p2##x,_n2##y,z,c)), \
   (I[43] = (T)(img)(_p2##x,_n3##y,z,c)), \
   (I[2] = (T)(img)(_p1##x,_p3##y,z,c)), \
   (I[9] = (T)(img)(_p1##x,_p2##y,z,c)), \
   (I[16] = (T)(img)(_p1##x,_p1##y,z,c)), \
   (I[23] = (T)(img)(_p1##x,y,z,c)), \
   (I[30] = (T)(img)(_p1##x,_n1##y,z,c)), \
   (I[37] = (T)(img)(_p1##x,_n2##y,z,c)), \
   (I[44] = (T)(img)(_p1##x,_n3##y,z,c)), \
   (I[3] = (T)(img)(x,_p3##y,z,c)), \
   (I[10] = (T)(img)(x,_p2##y,z,c)), \
   (I[17] = (T)(img)(x,_p1##y,z,c)), \
   (I[24] = (T)(img)(x,y,z,c)), \
   (I[31] = (T)(img)(x,_n1##y,z,c)), \
   (I[38] = (T)(img)(x,_n2##y,z,c)), \
   (I[45] = (T)(img)(x,_n3##y,z,c)), \
   (I[4] = (T)(img)(_n1##x,_p3##y,z,c)), \
   (I[11] = (T)(img)(_n1##x,_p2##y,z,c)), \
   (I[18] = (T)(img)(_n1##x,_p1##y,z,c)), \
   (I[25] = (T)(img)(_n1##x,y,z,c)), \
   (I[32] = (T)(img)(_n1##x,_n1##y,z,c)), \
   (I[39] = (T)(img)(_n1##x,_n2##y,z,c)), \
   (I[46] = (T)(img)(_n1##x,_n3##y,z,c)), \
   (I[5] = (T)(img)(_n2##x,_p3##y,z,c)), \
   (I[12] = (T)(img)(_n2##x,_p2##y,z,c)), \
   (I[19] = (T)(img)(_n2##x,_p1##y,z,c)), \
   (I[26] = (T)(img)(_n2##x,y,z,c)), \
   (I[33] = (T)(img)(_n2##x,_n1##y,z,c)), \
   (I[40] = (T)(img)(_n2##x,_n2##y,z,c)), \
   (I[47] = (T)(img)(_n2##x,_n3##y,z,c)), \
   x+3>=(int)(img)._width?(img).width()-1:x+3); \
   x<=(int)(x1) && ((_n3##x<(img).width() && ( \
   (I[6] = (T)(img)(_n3##x,_p3##y,z,c)), \
   (I[13] = (T)(img)(_n3##x,_p2##y,z,c)), \
   (I[20] = (T)(img)(_n3##x,_p1##y,z,c)), \
   (I[27] = (T)(img)(_n3##x,y,z,c)), \
   (I[34] = (T)(img)(_n3##x,_n1##y,z,c)), \
   (I[41] = (T)(img)(_n3##x,_n2##y,z,c)), \
   (I[48] = (T)(img)(_n3##x,_n3##y,z,c)),1)) || \
   _n2##x==--_n3##x || _n1##x==--_n2##x || x==(_n3##x = _n2##x = --_n1##x)); \
   I[0] = I[1], I[1] = I[2], I[2] = I[3], I[3] = I[4], I[4] = I[5], I[5] = I[6], \
   I[7] = I[8], I[8] = I[9], I[9] = I[10], I[10] = I[11], I[11] = I[12], I[12] = I[13], \
   I[14] = I[15], I[15] = I[16], I[16] = I[17], I[17] = I[18], I[18] = I[19], I[19] = I[20], \
   I[21] = I[22], I[22] = I[23], I[23] = I[24], I[24] = I[25], I[25] = I[26], I[26] = I[27], \
   I[28] = I[29], I[29] = I[30], I[30] = I[31], I[31] = I[32], I[32] = I[33], I[33] = I[34], \
   I[35] = I[36], I[36] = I[37], I[37] = I[38], I[38] = I[39], I[39] = I[40], I[40] = I[41], \
   I[42] = I[43], I[43] = I[44], I[44] = I[45], I[45] = I[46], I[46] = I[47], I[47] = I[48], \
   _p3##x = _p2##x, _p2##x = _p1##x, _p1##x = x++, ++_n1##x, ++_n2##x, ++_n3##x)

#define cimg_for8x8(img,x,y,z,c,I,T) \
  cimg_for8((img)._height,y) for (int x = 0, \
   _p3##x = 0, _p2##x = 0, _p1##x = 0, \
   _n1##x = 1>=((img)._width)?(img).width()-1:1, \
   _n2##x = 2>=((img)._width)?(img).width()-1:2, \
   _n3##x = 3>=((img)._width)?(img).width()-1:3, \
   _n4##x = (int)( \
   (I[0] = I[1] = I[2] = I[3] = (T)(img)(_p3##x,_p3##y,z,c)), \
   (I[8] = I[9] = I[10] = I[11] = (T)(img)(0,_p2##y,z,c)), \
   (I[16] = I[17] = I[18] = I[19] = (T)(img)(0,_p1##y,z,c)), \
   (I[24] = I[25] = I[26] = I[27] = (T)(img)(0,y,z,c)), \
   (I[32] = I[33] = I[34] = I[35] = (T)(img)(0,_n1##y,z,c)), \
   (I[40] = I[41] = I[42] = I[43] = (T)(img)(0,_n2##y,z,c)), \
   (I[48] = I[49] = I[50] = I[51] = (T)(img)(0,_n3##y,z,c)), \
   (I[56] = I[57] = I[58] = I[59] = (T)(img)(0,_n4##y,z,c)), \
   (I[4] = (T)(img)(_n1##x,_p3##y,z,c)), \
   (I[12] = (T)(img)(_n1##x,_p2##y,z,c)), \
   (I[20] = (T)(img)(_n1##x,_p1##y,z,c)), \
   (I[28] = (T)(img)(_n1##x,y,z,c)), \
   (I[36] = (T)(img)(_n1##x,_n1##y,z,c)), \
   (I[44] = (T)(img)(_n1##x,_n2##y,z,c)), \
   (I[52] = (T)(img)(_n1##x,_n3##y,z,c)), \
   (I[60] = (T)(img)(_n1##x,_n4##y,z,c)), \
   (I[5] = (T)(img)(_n2##x,_p3##y,z,c)), \
   (I[13] = (T)(img)(_n2##x,_p2##y,z,c)), \
   (I[21] = (T)(img)(_n2##x,_p1##y,z,c)), \
   (I[29] = (T)(img)(_n2##x,y,z,c)), \
   (I[37] = (T)(img)(_n2##x,_n1##y,z,c)), \
   (I[45] = (T)(img)(_n2##x,_n2##y,z,c)), \
   (I[53] = (T)(img)(_n2##x,_n3##y,z,c)), \
   (I[61] = (T)(img)(_n2##x,_n4##y,z,c)), \
   (I[6] = (T)(img)(_n3##x,_p3##y,z,c)), \
   (I[14] = (T)(img)(_n3##x,_p2##y,z,c)), \
   (I[22] = (T)(img)(_n3##x,_p1##y,z,c)), \
   (I[30] = (T)(img)(_n3##x,y,z,c)), \
   (I[38] = (T)(img)(_n3##x,_n1##y,z,c)), \
   (I[46] = (T)(img)(_n3##x,_n2##y,z,c)), \
   (I[54] = (T)(img)(_n3##x,_n3##y,z,c)), \
   (I[62] = (T)(img)(_n3##x,_n4##y,z,c)), \
   4>=((img)._width)?(img).width()-1:4); \
   (_n4##x<(img).width() && ( \
   (I[7] = (T)(img)(_n4##x,_p3##y,z,c)), \
   (I[15] = (T)(img)(_n4##x,_p2##y,z,c)), \
   (I[23] = (T)(img)(_n4##x,_p1##y,z,c)), \
   (I[31] = (T)(img)(_n4##x,y,z,c)), \
   (I[39] = (T)(img)(_n4##x,_n1##y,z,c)), \
   (I[47] = (T)(img)(_n4##x,_n2##y,z,c)), \
   (I[55] = (T)(img)(_n4##x,_n3##y,z,c)), \
   (I[63] = (T)(img)(_n4##x,_n4##y,z,c)),1)) || \
   _n3##x==--_n4##x || _n2##x==--_n3##x || _n1##x==--_n2##x || x==(_n4##x = _n3##x = _n2##x = --_n1##x); \
   I[0] = I[1], I[1] = I[2], I[2] = I[3], I[3] = I[4], I[4] = I[5], I[5] = I[6], I[6] = I[7], \
   I[8] = I[9], I[9] = I[10], I[10] = I[11], I[11] = I[12], I[12] = I[13], I[13] = I[14], I[14] = I[15], \
   I[16] = I[17], I[17] = I[18], I[18] = I[19], I[19] = I[20], I[20] = I[21], I[21] = I[22], I[22] = I[23], \
   I[24] = I[25], I[25] = I[26], I[26] = I[27], I[27] = I[28], I[28] = I[29], I[29] = I[30], I[30] = I[31], \
   I[32] = I[33], I[33] = I[34], I[34] = I[35], I[35] = I[36], I[36] = I[37], I[37] = I[38], I[38] = I[39], \
   I[40] = I[41], I[41] = I[42], I[42] = I[43], I[43] = I[44], I[44] = I[45], I[45] = I[46], I[46] = I[47], \
   I[48] = I[49], I[49] = I[50], I[50] = I[51], I[51] = I[52], I[52] = I[53], I[53] = I[54], I[54] = I[55], \
   I[56] = I[57], I[57] = I[58], I[58] = I[59], I[59] = I[60], I[60] = I[61], I[61] = I[62], I[62] = I[63], \
   _p3##x = _p2##x, _p2##x = _p1##x, _p1##x = x++, ++_n1##x, ++_n2##x, ++_n3##x, ++_n4##x)

#define cimg_for_in8x8(img,x0,y0,x1,y1,x,y,z,c,I,T) \
  cimg_for_in8((img)._height,y0,y1,y) for (int x = (int)(x0)<0?0:(int)(x0), \
   _p3##x = x-3<0?0:x-3, \
   _p2##x = x-2<0?0:x-2, \
   _p1##x = x-1<0?0:x-1, \
   _n1##x = x+1>=(img).width()?(img).width()-1:x+1, \
   _n2##x = x+2>=(img).width()?(img).width()-1:x+2, \
   _n3##x = x+3>=(img).width()?(img).width()-1:x+3, \
   _n4##x = (int)( \
   (I[0] = (T)(img)(_p3##x,_p3##y,z,c)), \
   (I[8] = (T)(img)(_p3##x,_p2##y,z,c)), \
   (I[16] = (T)(img)(_p3##x,_p1##y,z,c)), \
   (I[24] = (T)(img)(_p3##x,y,z,c)), \
   (I[32] = (T)(img)(_p3##x,_n1##y,z,c)), \
   (I[40] = (T)(img)(_p3##x,_n2##y,z,c)), \
   (I[48] = (T)(img)(_p3##x,_n3##y,z,c)), \
   (I[56] = (T)(img)(_p3##x,_n4##y,z,c)), \
   (I[1] = (T)(img)(_p2##x,_p3##y,z,c)), \
   (I[9] = (T)(img)(_p2##x,_p2##y,z,c)), \
   (I[17] = (T)(img)(_p2##x,_p1##y,z,c)), \
   (I[25] = (T)(img)(_p2##x,y,z,c)), \
   (I[33] = (T)(img)(_p2##x,_n1##y,z,c)), \
   (I[41] = (T)(img)(_p2##x,_n2##y,z,c)), \
   (I[49] = (T)(img)(_p2##x,_n3##y,z,c)), \
   (I[57] = (T)(img)(_p2##x,_n4##y,z,c)), \
   (I[2] = (T)(img)(_p1##x,_p3##y,z,c)), \
   (I[10] = (T)(img)(_p1##x,_p2##y,z,c)), \
   (I[18] = (T)(img)(_p1##x,_p1##y,z,c)), \
   (I[26] = (T)(img)(_p1##x,y,z,c)), \
   (I[34] = (T)(img)(_p1##x,_n1##y,z,c)), \
   (I[42] = (T)(img)(_p1##x,_n2##y,z,c)), \
   (I[50] = (T)(img)(_p1##x,_n3##y,z,c)), \
   (I[58] = (T)(img)(_p1##x,_n4##y,z,c)), \
   (I[3] = (T)(img)(x,_p3##y,z,c)), \
   (I[11] = (T)(img)(x,_p2##y,z,c)), \
   (I[19] = (T)(img)(x,_p1##y,z,c)), \
   (I[27] = (T)(img)(x,y,z,c)), \
   (I[35] = (T)(img)(x,_n1##y,z,c)), \
   (I[43] = (T)(img)(x,_n2##y,z,c)), \
   (I[51] = (T)(img)(x,_n3##y,z,c)), \
   (I[59] = (T)(img)(x,_n4##y,z,c)), \
   (I[4] = (T)(img)(_n1##x,_p3##y,z,c)), \
   (I[12] = (T)(img)(_n1##x,_p2##y,z,c)), \
   (I[20] = (T)(img)(_n1##x,_p1##y,z,c)), \
   (I[28] = (T)(img)(_n1##x,y,z,c)), \
   (I[36] = (T)(img)(_n1##x,_n1##y,z,c)), \
   (I[44] = (T)(img)(_n1##x,_n2##y,z,c)), \
   (I[52] = (T)(img)(_n1##x,_n3##y,z,c)), \
   (I[60] = (T)(img)(_n1##x,_n4##y,z,c)), \
   (I[5] = (T)(img)(_n2##x,_p3##y,z,c)), \
   (I[13] = (T)(img)(_n2##x,_p2##y,z,c)), \
   (I[21] = (T)(img)(_n2##x,_p1##y,z,c)), \
   (I[29] = (T)(img)(_n2##x,y,z,c)), \
   (I[37] = (T)(img)(_n2##x,_n1##y,z,c)), \
   (I[45] = (T)(img)(_n2##x,_n2##y,z,c)), \
   (I[53] = (T)(img)(_n2##x,_n3##y,z,c)), \
   (I[61] = (T)(img)(_n2##x,_n4##y,z,c)), \
   (I[6] = (T)(img)(_n3##x,_p3##y,z,c)), \
   (I[14] = (T)(img)(_n3##x,_p2##y,z,c)), \
   (I[22] = (T)(img)(_n3##x,_p1##y,z,c)), \
   (I[30] = (T)(img)(_n3##x,y,z,c)), \
   (I[38] = (T)(img)(_n3##x,_n1##y,z,c)), \
   (I[46] = (T)(img)(_n3##x,_n2##y,z,c)), \
   (I[54] = (T)(img)(_n3##x,_n3##y,z,c)), \
   (I[62] = (T)(img)(_n3##x,_n4##y,z,c)), \
   x+4>=(img).width()?(img).width()-1:x+4); \
   x<=(int)(x1) && ((_n4##x<(img).width() && ( \
   (I[7] = (T)(img)(_n4##x,_p3##y,z,c)), \
   (I[15] = (T)(img)(_n4##x,_p2##y,z,c)), \
   (I[23] = (T)(img)(_n4##x,_p1##y,z,c)), \
   (I[31] = (T)(img)(_n4##x,y,z,c)), \
   (I[39] = (T)(img)(_n4##x,_n1##y,z,c)), \
   (I[47] = (T)(img)(_n4##x,_n2##y,z,c)), \
   (I[55] = (T)(img)(_n4##x,_n3##y,z,c)), \
   (I[63] = (T)(img)(_n4##x,_n4##y,z,c)),1)) || \
   _n3##x==--_n4##x || _n2##x==--_n3##x || _n1##x==--_n2##x || x==(_n4##x = _n3##x = _n2##x = --_n1##x)); \
   I[0] = I[1], I[1] = I[2], I[2] = I[3], I[3] = I[4], I[4] = I[5], I[5] = I[6], I[6] = I[7], \
   I[8] = I[9], I[9] = I[10], I[10] = I[11], I[11] = I[12], I[12] = I[13], I[13] = I[14], I[14] = I[15], \
   I[16] = I[17], I[17] = I[18], I[18] = I[19], I[19] = I[20], I[20] = I[21], I[21] = I[22], I[22] = I[23], \
   I[24] = I[25], I[25] = I[26], I[26] = I[27], I[27] = I[28], I[28] = I[29], I[29] = I[30], I[30] = I[31], \
   I[32] = I[33], I[33] = I[34], I[34] = I[35], I[35] = I[36], I[36] = I[37], I[37] = I[38], I[38] = I[39], \
   I[40] = I[41], I[41] = I[42], I[42] = I[43], I[43] = I[44], I[44] = I[45], I[45] = I[46], I[46] = I[47], \
   I[48] = I[49], I[49] = I[50], I[50] = I[51], I[51] = I[52], I[52] = I[53], I[53] = I[54], I[54] = I[55], \
   I[56] = I[57], I[57] = I[58], I[58] = I[59], I[59] = I[60], I[60] = I[61], I[61] = I[62], I[62] = I[63], \
   _p3##x = _p2##x, _p2##x = _p1##x, _p1##x = x++, ++_n1##x, ++_n2##x, ++_n3##x, ++_n4##x)

#define cimg_for9x9(img,x,y,z,c,I,T) \
  cimg_for9((img)._height,y) for (int x = 0, \
   _p4##x = 0, _p3##x = 0, _p2##x = 0, _p1##x = 0, \
   _n1##x = 1>=((img)._width)?(img).width()-1:1, \
   _n2##x = 2>=((img)._width)?(img).width()-1:2, \
   _n3##x = 3>=((img)._width)?(img).width()-1:3, \
   _n4##x = (int)( \
   (I[0] = I[1] = I[2] = I[3] = I[4] = (T)(img)(_p4##x,_p4##y,z,c)), \
   (I[9] = I[10] = I[11] = I[12] = I[13] = (T)(img)(0,_p3##y,z,c)), \
   (I[18] = I[19] = I[20] = I[21] = I[22] = (T)(img)(0,_p2##y,z,c)), \
   (I[27] = I[28] = I[29] = I[30] = I[31] = (T)(img)(0,_p1##y,z,c)), \
   (I[36] = I[37] = I[38] = I[39] = I[40] = (T)(img)(0,y,z,c)), \
   (I[45] = I[46] = I[47] = I[48] = I[49] = (T)(img)(0,_n1##y,z,c)), \
   (I[54] = I[55] = I[56] = I[57] = I[58] = (T)(img)(0,_n2##y,z,c)), \
   (I[63] = I[64] = I[65] = I[66] = I[67] = (T)(img)(0,_n3##y,z,c)), \
   (I[72] = I[73] = I[74] = I[75] = I[76] = (T)(img)(0,_n4##y,z,c)), \
   (I[5] = (T)(img)(_n1##x,_p4##y,z,c)), \
   (I[14] = (T)(img)(_n1##x,_p3##y,z,c)), \
   (I[23] = (T)(img)(_n1##x,_p2##y,z,c)), \
   (I[32] = (T)(img)(_n1##x,_p1##y,z,c)), \
   (I[41] = (T)(img)(_n1##x,y,z,c)), \
   (I[50] = (T)(img)(_n1##x,_n1##y,z,c)), \
   (I[59] = (T)(img)(_n1##x,_n2##y,z,c)), \
   (I[68] = (T)(img)(_n1##x,_n3##y,z,c)), \
   (I[77] = (T)(img)(_n1##x,_n4##y,z,c)), \
   (I[6] = (T)(img)(_n2##x,_p4##y,z,c)), \
   (I[15] = (T)(img)(_n2##x,_p3##y,z,c)), \
   (I[24] = (T)(img)(_n2##x,_p2##y,z,c)), \
   (I[33] = (T)(img)(_n2##x,_p1##y,z,c)), \
   (I[42] = (T)(img)(_n2##x,y,z,c)), \
   (I[51] = (T)(img)(_n2##x,_n1##y,z,c)), \
   (I[60] = (T)(img)(_n2##x,_n2##y,z,c)), \
   (I[69] = (T)(img)(_n2##x,_n3##y,z,c)), \
   (I[78] = (T)(img)(_n2##x,_n4##y,z,c)), \
   (I[7] = (T)(img)(_n3##x,_p4##y,z,c)), \
   (I[16] = (T)(img)(_n3##x,_p3##y,z,c)), \
   (I[25] = (T)(img)(_n3##x,_p2##y,z,c)), \
   (I[34] = (T)(img)(_n3##x,_p1##y,z,c)), \
   (I[43] = (T)(img)(_n3##x,y,z,c)), \
   (I[52] = (T)(img)(_n3##x,_n1##y,z,c)), \
   (I[61] = (T)(img)(_n3##x,_n2##y,z,c)), \
   (I[70] = (T)(img)(_n3##x,_n3##y,z,c)), \
   (I[79] = (T)(img)(_n3##x,_n4##y,z,c)), \
   4>=((img)._width)?(img).width()-1:4); \
   (_n4##x<(img).width() && ( \
   (I[8] = (T)(img)(_n4##x,_p4##y,z,c)), \
   (I[17] = (T)(img)(_n4##x,_p3##y,z,c)), \
   (I[26] = (T)(img)(_n4##x,_p2##y,z,c)), \
   (I[35] = (T)(img)(_n4##x,_p1##y,z,c)), \
   (I[44] = (T)(img)(_n4##x,y,z,c)), \
   (I[53] = (T)(img)(_n4##x,_n1##y,z,c)), \
   (I[62] = (T)(img)(_n4##x,_n2##y,z,c)), \
   (I[71] = (T)(img)(_n4##x,_n3##y,z,c)), \
   (I[80] = (T)(img)(_n4##x,_n4##y,z,c)),1)) || \
   _n3##x==--_n4##x || _n2##x==--_n3##x || _n1##x==--_n2##x || x==(_n4##x = _n3##x = _n2##x = --_n1##x); \
   I[0] = I[1], I[1] = I[2], I[2] = I[3], I[3] = I[4], I[4] = I[5], I[5] = I[6], I[6] = I[7], I[7] = I[8], \
   I[9] = I[10], I[10] = I[11], I[11] = I[12], I[12] = I[13], I[13] = I[14], I[14] = I[15], I[15] = I[16], I[16] = I[17], \
   I[18] = I[19], I[19] = I[20], I[20] = I[21], I[21] = I[22], I[22] = I[23], I[23] = I[24], I[24] = I[25], I[25] = I[26], \
   I[27] = I[28], I[28] = I[29], I[29] = I[30], I[30] = I[31], I[31] = I[32], I[32] = I[33], I[33] = I[34], I[34] = I[35], \
   I[36] = I[37], I[37] = I[38], I[38] = I[39], I[39] = I[40], I[40] = I[41], I[41] = I[42], I[42] = I[43], I[43] = I[44], \
   I[45] = I[46], I[46] = I[47], I[47] = I[48], I[48] = I[49], I[49] = I[50], I[50] = I[51], I[51] = I[52], I[52] = I[53], \
   I[54] = I[55], I[55] = I[56], I[56] = I[57], I[57] = I[58], I[58] = I[59], I[59] = I[60], I[60] = I[61], I[61] = I[62], \
   I[63] = I[64], I[64] = I[65], I[65] = I[66], I[66] = I[67], I[67] = I[68], I[68] = I[69], I[69] = I[70], I[70] = I[71], \
   I[72] = I[73], I[73] = I[74], I[74] = I[75], I[75] = I[76], I[76] = I[77], I[77] = I[78], I[78] = I[79], I[79] = I[80], \
   _p4##x = _p3##x, _p3##x = _p2##x, _p2##x = _p1##x, _p1##x = x++, ++_n1##x, ++_n2##x, ++_n3##x, ++_n4##x)

#define cimg_for_in9x9(img,x0,y0,x1,y1,x,y,z,c,I,T) \
  cimg_for_in9((img)._height,y0,y1,y) for (int x = (int)(x0)<0?0:(int)(x0), \
   _p4##x = x-4<0?0:x-4, \
   _p3##x = x-3<0?0:x-3, \
   _p2##x = x-2<0?0:x-2, \
   _p1##x = x-1<0?0:x-1, \
   _n1##x = x+1>=(img).width()?(img).width()-1:x+1, \
   _n2##x = x+2>=(img).width()?(img).width()-1:x+2, \
   _n3##x = x+3>=(img).width()?(img).width()-1:x+3, \
   _n4##x = (int)( \
   (I[0] = (T)(img)(_p4##x,_p4##y,z,c)), \
   (I[9] = (T)(img)(_p4##x,_p3##y,z,c)), \
   (I[18] = (T)(img)(_p4##x,_p2##y,z,c)), \
   (I[27] = (T)(img)(_p4##x,_p1##y,z,c)), \
   (I[36] = (T)(img)(_p4##x,y,z,c)), \
   (I[45] = (T)(img)(_p4##x,_n1##y,z,c)), \
   (I[54] = (T)(img)(_p4##x,_n2##y,z,c)), \
   (I[63] = (T)(img)(_p4##x,_n3##y,z,c)), \
   (I[72] = (T)(img)(_p4##x,_n4##y,z,c)), \
   (I[1] = (T)(img)(_p3##x,_p4##y,z,c)), \
   (I[10] = (T)(img)(_p3##x,_p3##y,z,c)), \
   (I[19] = (T)(img)(_p3##x,_p2##y,z,c)), \
   (I[28] = (T)(img)(_p3##x,_p1##y,z,c)), \
   (I[37] = (T)(img)(_p3##x,y,z,c)), \
   (I[46] = (T)(img)(_p3##x,_n1##y,z,c)), \
   (I[55] = (T)(img)(_p3##x,_n2##y,z,c)), \
   (I[64] = (T)(img)(_p3##x,_n3##y,z,c)), \
   (I[73] = (T)(img)(_p3##x,_n4##y,z,c)), \
   (I[2] = (T)(img)(_p2##x,_p4##y,z,c)), \
   (I[11] = (T)(img)(_p2##x,_p3##y,z,c)), \
   (I[20] = (T)(img)(_p2##x,_p2##y,z,c)), \
   (I[29] = (T)(img)(_p2##x,_p1##y,z,c)), \
   (I[38] = (T)(img)(_p2##x,y,z,c)), \
   (I[47] = (T)(img)(_p2##x,_n1##y,z,c)), \
   (I[56] = (T)(img)(_p2##x,_n2##y,z,c)), \
   (I[65] = (T)(img)(_p2##x,_n3##y,z,c)), \
   (I[74] = (T)(img)(_p2##x,_n4##y,z,c)), \
   (I[3] = (T)(img)(_p1##x,_p4##y,z,c)), \
   (I[12] = (T)(img)(_p1##x,_p3##y,z,c)), \
   (I[21] = (T)(img)(_p1##x,_p2##y,z,c)), \
   (I[30] = (T)(img)(_p1##x,_p1##y,z,c)), \
   (I[39] = (T)(img)(_p1##x,y,z,c)), \
   (I[48] = (T)(img)(_p1##x,_n1##y,z,c)), \
   (I[57] = (T)(img)(_p1##x,_n2##y,z,c)), \
   (I[66] = (T)(img)(_p1##x,_n3##y,z,c)), \
   (I[75] = (T)(img)(_p1##x,_n4##y,z,c)), \
   (I[4] = (T)(img)(x,_p4##y,z,c)), \
   (I[13] = (T)(img)(x,_p3##y,z,c)), \
   (I[22] = (T)(img)(x,_p2##y,z,c)), \
   (I[31] = (T)(img)(x,_p1##y,z,c)), \
   (I[40] = (T)(img)(x,y,z,c)), \
   (I[49] = (T)(img)(x,_n1##y,z,c)), \
   (I[58] = (T)(img)(x,_n2##y,z,c)), \
   (I[67] = (T)(img)(x,_n3##y,z,c)), \
   (I[76] = (T)(img)(x,_n4##y,z,c)), \
   (I[5] = (T)(img)(_n1##x,_p4##y,z,c)), \
   (I[14] = (T)(img)(_n1##x,_p3##y,z,c)), \
   (I[23] = (T)(img)(_n1##x,_p2##y,z,c)), \
   (I[32] = (T)(img)(_n1##x,_p1##y,z,c)), \
   (I[41] = (T)(img)(_n1##x,y,z,c)), \
   (I[50] = (T)(img)(_n1##x,_n1##y,z,c)), \
   (I[59] = (T)(img)(_n1##x,_n2##y,z,c)), \
   (I[68] = (T)(img)(_n1##x,_n3##y,z,c)), \
   (I[77] = (T)(img)(_n1##x,_n4##y,z,c)), \
   (I[6] = (T)(img)(_n2##x,_p4##y,z,c)), \
   (I[15] = (T)(img)(_n2##x,_p3##y,z,c)), \
   (I[24] = (T)(img)(_n2##x,_p2##y,z,c)), \
   (I[33] = (T)(img)(_n2##x,_p1##y,z,c)), \
   (I[42] = (T)(img)(_n2##x,y,z,c)), \
   (I[51] = (T)(img)(_n2##x,_n1##y,z,c)), \
   (I[60] = (T)(img)(_n2##x,_n2##y,z,c)), \
   (I[69] = (T)(img)(_n2##x,_n3##y,z,c)), \
   (I[78] = (T)(img)(_n2##x,_n4##y,z,c)), \
   (I[7] = (T)(img)(_n3##x,_p4##y,z,c)), \
   (I[16] = (T)(img)(_n3##x,_p3##y,z,c)), \
   (I[25] = (T)(img)(_n3##x,_p2##y,z,c)), \
   (I[34] = (T)(img)(_n3##x,_p1##y,z,c)), \
   (I[43] = (T)(img)(_n3##x,y,z,c)), \
   (I[52] = (T)(img)(_n3##x,_n1##y,z,c)), \
   (I[61] = (T)(img)(_n3##x,_n2##y,z,c)), \
   (I[70] = (T)(img)(_n3##x,_n3##y,z,c)), \
   (I[79] = (T)(img)(_n3##x,_n4##y,z,c)), \
   x+4>=(img).width()?(img).width()-1:x+4); \
   x<=(int)(x1) && ((_n4##x<(img).width() && ( \
   (I[8] = (T)(img)(_n4##x,_p4##y,z,c)), \
   (I[17] = (T)(img)(_n4##x,_p3##y,z,c)), \
   (I[26] = (T)(img)(_n4##x,_p2##y,z,c)), \
   (I[35] = (T)(img)(_n4##x,_p1##y,z,c)), \
   (I[44] = (T)(img)(_n4##x,y,z,c)), \
   (I[53] = (T)(img)(_n4##x,_n1##y,z,c)), \
   (I[62] = (T)(img)(_n4##x,_n2##y,z,c)), \
   (I[71] = (T)(img)(_n4##x,_n3##y,z,c)), \
   (I[80] = (T)(img)(_n4##x,_n4##y,z,c)),1)) || \
   _n3##x==--_n4##x || _n2##x==--_n3##x || _n1##x==--_n2##x || x==(_n4##x = _n3##x = _n2##x = --_n1##x)); \
   I[0] = I[1], I[1] = I[2], I[2] = I[3], I[3] = I[4], I[4] = I[5], I[5] = I[6], I[6] = I[7], I[7] = I[8], \
   I[9] = I[10], I[10] = I[11], I[11] = I[12], I[12] = I[13], I[13] = I[14], I[14] = I[15], I[15] = I[16], I[16] = I[17], \
   I[18] = I[19], I[19] = I[20], I[20] = I[21], I[21] = I[22], I[22] = I[23], I[23] = I[24], I[24] = I[25], I[25] = I[26], \
   I[27] = I[28], I[28] = I[29], I[29] = I[30], I[30] = I[31], I[31] = I[32], I[32] = I[33], I[33] = I[34], I[34] = I[35], \
   I[36] = I[37], I[37] = I[38], I[38] = I[39], I[39] = I[40], I[40] = I[41], I[41] = I[42], I[42] = I[43], I[43] = I[44], \
   I[45] = I[46], I[46] = I[47], I[47] = I[48], I[48] = I[49], I[49] = I[50], I[50] = I[51], I[51] = I[52], I[52] = I[53], \
   I[54] = I[55], I[55] = I[56], I[56] = I[57], I[57] = I[58], I[58] = I[59], I[59] = I[60], I[60] = I[61], I[61] = I[62], \
   I[63] = I[64], I[64] = I[65], I[65] = I[66], I[66] = I[67], I[67] = I[68], I[68] = I[69], I[69] = I[70], I[70] = I[71], \
   I[72] = I[73], I[73] = I[74], I[74] = I[75], I[75] = I[76], I[76] = I[77], I[77] = I[78], I[78] = I[79], I[79] = I[80], \
   _p4##x = _p3##x, _p3##x = _p2##x, _p2##x = _p1##x, _p1##x = x++, ++_n1##x, ++_n2##x, ++_n3##x, ++_n4##x)

#define cimg_for2x2x2(img,x,y,z,c,I,T) \
 cimg_for2((img)._depth,z) cimg_for2((img)._height,y) for (int x = 0, \
   _n1##x = (int)( \
   (I[0] = (T)(img)(0,y,z,c)), \
   (I[2] = (T)(img)(0,_n1##y,z,c)), \
   (I[4] = (T)(img)(0,y,_n1##z,c)), \
   (I[6] = (T)(img)(0,_n1##y,_n1##z,c)), \
   1>=(img)._width?(img).width()-1:1); \
   (_n1##x<(img).width() && ( \
   (I[1] = (T)(img)(_n1##x,y,z,c)), \
   (I[3] = (T)(img)(_n1##x,_n1##y,z,c)), \
   (I[5] = (T)(img)(_n1##x,y,_n1##z,c)), \
   (I[7] = (T)(img)(_n1##x,_n1##y,_n1##z,c)),1)) || \
   x==--_n1##x; \
   I[0] = I[1], I[2] = I[3], I[4] = I[5], I[6] = I[7], \
   ++x, ++_n1##x)

#define cimg_for_in2x2x2(img,x0,y0,z0,x1,y1,z1,x,y,z,c,I,T) \
 cimg_for_in2((img)._depth,z0,z1,z) cimg_for_in2((img)._height,y0,y1,y) for (int x = (int)(x0)<0?0:(int)(x0), \
   _n1##x = (int)( \
   (I[0] = (T)(img)(x,y,z,c)), \
   (I[2] = (T)(img)(x,_n1##y,z,c)), \
   (I[4] = (T)(img)(x,y,_n1##z,c)), \
   (I[6] = (T)(img)(x,_n1##y,_n1##z,c)), \
   x+1>=(int)(img)._width?(img).width()-1:x+1); \
   x<=(int)(x1) && ((_n1##x<(img).width() && ( \
   (I[1] = (T)(img)(_n1##x,y,z,c)), \
   (I[3] = (T)(img)(_n1##x,_n1##y,z,c)), \
   (I[5] = (T)(img)(_n1##x,y,_n1##z,c)), \
   (I[7] = (T)(img)(_n1##x,_n1##y,_n1##z,c)),1)) || \
   x==--_n1##x); \
   I[0] = I[1], I[2] = I[3], I[4] = I[5], I[6] = I[7], \
   ++x, ++_n1##x)

#define cimg_for3x3x3(img,x,y,z,c,I,T) \
 cimg_for3((img)._depth,z) cimg_for3((img)._height,y) for (int x = 0, \
   _p1##x = 0, \
   _n1##x = (int)( \
   (I[0] = I[1] = (T)(img)(_p1##x,_p1##y,_p1##z,c)), \
   (I[3] = I[4] = (T)(img)(0,y,_p1##z,c)),  \
   (I[6] = I[7] = (T)(img)(0,_n1##y,_p1##z,c)), \
   (I[9] = I[10] = (T)(img)(0,_p1##y,z,c)), \
   (I[12] = I[13] = (T)(img)(0,y,z,c)), \
   (I[15] = I[16] = (T)(img)(0,_n1##y,z,c)), \
   (I[18] = I[19] = (T)(img)(0,_p1##y,_n1##z,c)), \
   (I[21] = I[22] = (T)(img)(0,y,_n1##z,c)), \
   (I[24] = I[25] = (T)(img)(0,_n1##y,_n1##z,c)), \
   1>=(img)._width?(img).width()-1:1); \
   (_n1##x<(img).width() && ( \
   (I[2] = (T)(img)(_n1##x,_p1##y,_p1##z,c)), \
   (I[5] = (T)(img)(_n1##x,y,_p1##z,c)), \
   (I[8] = (T)(img)(_n1##x,_n1##y,_p1##z,c)), \
   (I[11] = (T)(img)(_n1##x,_p1##y,z,c)), \
   (I[14] = (T)(img)(_n1##x,y,z,c)), \
   (I[17] = (T)(img)(_n1##x,_n1##y,z,c)), \
   (I[20] = (T)(img)(_n1##x,_p1##y,_n1##z,c)), \
   (I[23] = (T)(img)(_n1##x,y,_n1##z,c)), \
   (I[26] = (T)(img)(_n1##x,_n1##y,_n1##z,c)),1)) || \
   x==--_n1##x; \
   I[0] = I[1], I[1] = I[2], I[3] = I[4], I[4] = I[5], I[6] = I[7], I[7] = I[8], \
   I[9] = I[10], I[10] = I[11], I[12] = I[13], I[13] = I[14], I[15] = I[16], I[16] = I[17], \
   I[18] = I[19], I[19] = I[20], I[21] = I[22], I[22] = I[23], I[24] = I[25], I[25] = I[26], \
   _p1##x = x++, ++_n1##x)

#define cimg_for_in3x3x3(img,x0,y0,z0,x1,y1,z1,x,y,z,c,I,T) \
 cimg_for_in3((img)._depth,z0,z1,z) cimg_for_in3((img)._height,y0,y1,y) for (int x = (int)(x0)<0?0:(int)(x0), \
   _p1##x = x-1<0?0:x-1, \
   _n1##x = (int)( \
   (I[0] = (T)(img)(_p1##x,_p1##y,_p1##z,c)), \
   (I[3] = (T)(img)(_p1##x,y,_p1##z,c)),  \
   (I[6] = (T)(img)(_p1##x,_n1##y,_p1##z,c)), \
   (I[9] = (T)(img)(_p1##x,_p1##y,z,c)), \
   (I[12] = (T)(img)(_p1##x,y,z,c)), \
   (I[15] = (T)(img)(_p1##x,_n1##y,z,c)), \
   (I[18] = (T)(img)(_p1##x,_p1##y,_n1##z,c)), \
   (I[21] = (T)(img)(_p1##x,y,_n1##z,c)), \
   (I[24] = (T)(img)(_p1##x,_n1##y,_n1##z,c)), \
   (I[1] = (T)(img)(x,_p1##y,_p1##z,c)), \
   (I[4] = (T)(img)(x,y,_p1##z,c)),  \
   (I[7] = (T)(img)(x,_n1##y,_p1##z,c)), \
   (I[10] = (T)(img)(x,_p1##y,z,c)), \
   (I[13] = (T)(img)(x,y,z,c)), \
   (I[16] = (T)(img)(x,_n1##y,z,c)), \
   (I[19] = (T)(img)(x,_p1##y,_n1##z,c)), \
   (I[22] = (T)(img)(x,y,_n1##z,c)), \
   (I[25] = (T)(img)(x,_n1##y,_n1##z,c)), \
   x+1>=(int)(img)._width?(img).width()-1:x+1); \
   x<=(int)(x1) && ((_n1##x<(img).width() && ( \
   (I[2] = (T)(img)(_n1##x,_p1##y,_p1##z,c)), \
   (I[5] = (T)(img)(_n1##x,y,_p1##z,c)), \
   (I[8] = (T)(img)(_n1##x,_n1##y,_p1##z,c)), \
   (I[11] = (T)(img)(_n1##x,_p1##y,z,c)), \
   (I[14] = (T)(img)(_n1##x,y,z,c)), \
   (I[17] = (T)(img)(_n1##x,_n1##y,z,c)), \
   (I[20] = (T)(img)(_n1##x,_p1##y,_n1##z,c)), \
   (I[23] = (T)(img)(_n1##x,y,_n1##z,c)), \
   (I[26] = (T)(img)(_n1##x,_n1##y,_n1##z,c)),1)) || \
   x==--_n1##x); \
   I[0] = I[1], I[1] = I[2], I[3] = I[4], I[4] = I[5], I[6] = I[7], I[7] = I[8], \
   I[9] = I[10], I[10] = I[11], I[12] = I[13], I[13] = I[14], I[15] = I[16], I[16] = I[17], \
   I[18] = I[19], I[19] = I[20], I[21] = I[22], I[22] = I[23], I[24] = I[25], I[25] = I[26], \
   _p1##x = x++, ++_n1##x)

#define cimglist_for(list,l) for (int l = 0; l<(int)(list)._width; ++l)
#define cimglist_for_in(list,l0,l1,l) \
  for (int l = (int)(l0)<0?0:(int)(l0), _max##l = (unsigned int)l1<(list)._width?(int)(l1):(int)(list)._width-1; l<=_max##l; ++l)

#define cimglist_apply(list,fn) cimglist_for(list,__##fn) (list)[__##fn].fn

// Macros used to display error messages when exceptions are thrown.
// You should not use these macros is your own code.
#define _cimgdisplay_instance "[instance(%u,%u,%u,%c%s%c)] CImgDisplay::"
#define cimgdisplay_instance _width,_height,_normalization,_title?'\"':'[',_title?_title:"untitled",_title?'\"':']'
#define _cimg_instance "[instance(%u,%u,%u,%u,%p,%sshared)] CImg<%s>::"
#define cimg_instance _width,_height,_depth,_spectrum,_data,_is_shared?"":"non-",pixel_type()
#define _cimglist_instance "[instance(%u,%u,%p)] CImgList<%s>::"
#define cimglist_instance _width,_allocated_width,_data,pixel_type()

/*------------------------------------------------
 #
 #
 #  Define cimg_library:: namespace
 #
 #
 -------------------------------------------------*/
//! Contains <i>all classes and functions</i> of the \CImg library.
/**
   This namespace is defined to avoid functions and class names collisions
   that could happen with the inclusion of other C++ header files.
   Anyway, it should not happen often and you should reasonnably start most of your
   \CImg-based programs with
   \code
   #include "CImg.h"
   using namespace cimg_library;
   \endcode
   to simplify the declaration of \CImg Library objects afterwards.
**/
namespace cimg_library_suffixed {

  // Declare the four classes of the CImg Library.
  template<typename T=float> struct CImg;
  template<typename T=float> struct CImgList;
  struct CImgDisplay;
  struct CImgException;

  // Declare cimg:: namespace.
  // This is an uncomplete namespace definition here. It only contains some
  // necessary stuffs to ensure a correct declaration order of the classes and functions
  // defined afterwards.
  namespace cimg {

    // Define ascii sequences for colored terminal output.
#ifdef cimg_use_vt100
    const char t_normal[] = { 0x1b, '[', '0', ';', '0', ';', '0', 'm', 0 };
    const char t_black[] = { 0x1b, '[', '0', ';', '3', '0', ';', '5', '9', 'm', 0 };
    const char t_red[] = { 0x1b, '[', '0', ';', '3', '1', ';', '5', '9', 'm', 0 };
    const char t_green[] = { 0x1b, '[', '0', ';', '3', '2', ';', '5', '9', 'm', 0 };
    const char t_yellow[] = { 0x1b, '[', '0', ';', '3', '3', ';', '5', '9', 'm', 0 };
    const char t_blue[] = { 0x1b, '[', '0', ';', '3', '4', ';', '5', '9', 'm', 0 };
    const char t_magenta[] = { 0x1b, '[', '0', ';', '3', '5', ';', '5', '9', 'm', 0 };
    const char t_cyan[] = { 0x1b, '[', '0', ';', '3', '6', ';', '5', '9', 'm', 0 };
    const char t_white[] = { 0x1b, '[', '0', ';', '3', '7', ';', '5', '9', 'm', 0 };
    const char t_bold[] = { 0x1b, '[', '1', 'm', 0 };
    const char t_underscore[] = { 0x1b, '[', '4', 'm', 0 };
#else
# 2017 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    const char t_normal[] = { 0 };
    const char *const t_black = cimg::t_normal,
      *const t_red = cimg::t_normal,
      *const t_green = cimg::t_normal,
      *const t_yellow = cimg::t_normal,
      *const t_blue = cimg::t_normal,
      *const t_magenta = cimg::t_normal,
      *const t_cyan = cimg::t_normal,
      *const t_white = cimg::t_normal,
      *const t_bold = cimg::t_normal,
      *const t_underscore = cimg::t_normal;
#endif
# 2029 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    inline std::FILE* output(std::FILE *file=0);
    inline void info();

    //! Avoid warning messages due to unused parameters. Do nothing actually.
    template<typename T>
    inline void unused(const T&, ...) {}

    // [internal] Lock/unlock a mutex for managing concurrent threads.
    // 'lock_mode' can be { 0=unlock | 1=lock | 2=trylock }.
    // 'n' can be in [0,31] but mutex range [0,16] is reserved by CImg.
    inline int mutex(const unsigned int n, const int lock_mode=1);

    inline unsigned int& _exception_mode(const unsigned int value, const bool is_set) {
      static unsigned int mode = cimg_verbosity;
      cimg::mutex(0);
      if (is_set) mode = value;
      cimg::mutex(0,0);
      return mode;
    }

    //! Set current \CImg exception mode.
    /**
       The way error messages are handled by \CImg can be changed dynamically, using this function.
       \param mode Desired exception mode. Possible values are:
       - \c 0: Hide library messages (quiet mode).
       - \c 1: Print library messages on the console.
       - \c 2: Display library messages on a dialog window (default behavior).
       - \c 3: Do as \c 1 + add extra debug warnings (slow down the code!).
       - \c 4: Do as \c 2 + add extra debug warnings (slow down the code!).
     **/
    inline unsigned int& exception_mode(const unsigned int mode) {
      return _exception_mode(mode,true);
    }

    //! Return current \CImg exception mode.
    /**
       \note By default, return the value of configuration macro \c cimg_verbosity
    **/
    inline unsigned int& exception_mode() {
      return _exception_mode(0,false);
    }

    inline int dialog(const char *const title, const char *const msg, const char *const button1_label="OK",
                      const char *const button2_label=0, const char *const button3_label=0,
                      const char *const button4_label=0, const char *const button5_label=0,
                      const char *const button6_label=0, const bool centering=false);

    inline double eval(const char *const expression, const double x=0, const double y=0, const double z=0, const double c=0);
  }

  /*---------------------------------------
    #
    # Define the CImgException structures
    #
    --------------------------------------*/
  //! Instances of \c CImgException are thrown when errors are encountered in a \CImg function call.
  /**
     \par Overview

      CImgException is the base class of all exceptions thrown by \CImg.
      CImgException is never thrown itself. Derived classes that specify the type of errord are thrown instead.
      These derived classes can be:

      - \b CImgArgumentException: Thrown when one argument of a called \CImg function is invalid.
      This is probably one of the most thrown exception by \CImg.
      For instance, the following example throws a \c CImgArgumentException:
      \code
      CImg<float> img(100,100,1,3); // Define a 100x100 color image with float-valued pixels.
      img.mirror('e');              // Try to mirror image along the (non-existing) 'e'-axis.
      \endcode

      - \b CImgDisplayException: Thrown when something went wrong during the display of images in CImgDisplay instances.

      - \b CImgInstanceException: Thrown when an instance associated to a called \CImg method does not fit
      the function requirements. For instance, the following example throws a \c CImgInstanceException:
      \code
      const CImg<float> img;           // Define an empty image.
      const float value = img.at(0);   // Try to read first pixel value (does not exist).
      \endcode

      - \b CImgIOException: Thrown when an error occured when trying to load or save image files.
      This happens when trying to read files that do not exist or with invalid formats.
      For instance, the following example throws a \c CImgIOException:
      \code
      const CImg<float> img("missing_file.jpg");  // Try to load a file that does not exist.
      \endcode

      - \b CImgWarningException: Thrown only if configuration macro \c cimg_strict_warnings is set, and
      when a \CImg function has to display a warning message (see cimg::warn()).

      It is not recommended to throw CImgException instances by yourself, since they are expected to be thrown only by \CImg.
      When an error occurs in a library function call, \CImg may display error messages on the screen or on the
      standard output, depending on the current \CImg exception mode.
      The \CImg exception mode can be get and set by functions cimg::exception_mode() and cimg::exception_mode(unsigned int).

      \par Exceptions handling

      In all cases, when an error occurs in \CImg, an instance of the corresponding exception class is thrown.
      This may lead the program to break (this is the default behavior), but you can bypass this behavior by handling the exceptions by yourself,
      using a usual <tt>try { ... } catch () { ... }</tt> bloc, as in the following example:
      \code
      #define "CImg.h"
      using namespace cimg_library;
      int main() {
        cimg::exception_mode(0);                                    // Enable quiet exception mode.
        try {
          ...                                                       // Here, do what you want to stress the CImg library.
        } catch (CImgException &e) {                                // You succeeded: something went wrong!
          std::fprintf(stderr,"CImg Library Error: %s",e.what());   // Display your custom error message.
          ...                                                       // Do what you want now to save the ship!
          }
        }
      \endcode
  **/
  struct CImgException : public std::exception {
#define _cimg_exception_err(etype,disp_flag) \
  std::va_list ap; va_start(ap,format); cimg_vsnprintf(_message,sizeof(_message),format,ap); va_end(ap); \
  if (cimg::exception_mode()) { \
    std::fprintf(cimg::output(),"\n%s[CImg] *** %s ***%s %s\n",cimg::t_red,etype,cimg::t_normal,_message); \
    if (cimg_display && disp_flag && !(cimg::exception_mode()%2)) try { cimg::dialog(etype,_message,"Abort"); } catch (CImgException&) {} \
    if (cimg::exception_mode()>=3) cimg_library_suffixed::cimg::info(); \
  }

    char _message[16384];
    CImgException() { *_message = 0; }
    CImgException(const char *const format, ...) { _cimg_exception_err("CImgException",true); }
    //! Return a C-string containing the error message associated to the thrown exception.
    const char *what() const throw() { return _message; }
  };

  // The CImgInstanceException class is used to throw an exception related
  // to an invalid instance encountered in a library function call.
  struct CImgInstanceException : public CImgException {
    CImgInstanceException(const char *const format, ...) { _cimg_exception_err("CImgInstanceException",true); }
  };

  // The CImgArgumentException class is used to throw an exception related
  // to invalid arguments encountered in a library function call.
  struct CImgArgumentException : public CImgException {
    CImgArgumentException(const char *const format, ...) { _cimg_exception_err("CImgArgumentException",true); }
  };

  // The CImgIOException class is used to throw an exception related
  // to input/output file problems encountered in a library function call.
  struct CImgIOException : public CImgException {
    CImgIOException(const char *const format, ...) { _cimg_exception_err("CImgIOException",true); }
  };

  // The CImgDisplayException class is used to throw an exception related
  // to display problems encountered in a library function call.
  struct CImgDisplayException : public CImgException {
    CImgDisplayException(const char *const format, ...) { _cimg_exception_err("CImgDisplayException",false); }
  };

  // The CImgWarningException class is used to throw an exception for warnings
  // encountered in a library function call.
  struct CImgWarningException : public CImgException {
    CImgWarningException(const char *const format, ...) { _cimg_exception_err("CImgWarningException",false); }
  };

  /*-------------------------------------
    #
    # Define cimg:: namespace
    #
    -----------------------------------*/
  //! Contains \a low-level functions and variables of the \CImg Library.
  /**
     Most of the functions and variables within this namespace are used by the \CImg library for low-level operations.
     You may use them to access specific const values or environment variables internally used by \CImg.
     \warning Never write <tt>using namespace cimg_library::cimg;</tt> in your source code. Lot of functions in the
     <tt>cimg:: namespace</tt> have the same names as standard C functions that may be defined in the global namespace <tt>::</tt>.
  **/
  namespace cimg {

    // Define traits that will be used to determine the best data type to work in CImg functions.
    //
    template<typename T> struct type {
      static const char* string() {
        static const char* s[] = { "unknown",   "unknown8",   "unknown16",  "unknown24",
                                   "unknown32", "unknown40",  "unknown48",  "unknown56",
                                   "unknown64", "unknown72",  "unknown80",  "unknown88",
                                   "unknown96", "unknown104", "unknown112", "unknown120",
                                   "unknown128" };
        return s[(sizeof(T)<17)?sizeof(T):0];
      }
      static bool is_float() { return false; }
      static bool is_inf(const T) { return false; }
      static bool is_nan(const T) { return false; }
      static T min() { return (T)-1>0?(T)0:(T)-1<<(8*sizeof(T)-1); }
      static T max() { return (T)-1>0?(T)-1:~((T)-1<<(8*sizeof(T)-1)); }
      static T inf() { return max(); }
      static T cut(const double val) { return val<(double)min()?min():val>(double)max()?max():(T)val; }
      static const char* format() { return "%s"; }
      static const char* format(const T val) { static const char *const s = "unknown"; cimg::unused(val); return s; }
    };

    template<> struct type<bool> {
      static const char* string() { static const char *const s = "bool"; return s; }
      static bool is_float() { return false; }
      static bool is_inf(const bool) { return false; }
      static bool is_nan(const bool) { return false; }
      static bool min() { return false; }
      static bool max() { return true; }
      static bool inf() { return max(); }
      static bool is_inf() { return false; }
      static bool cut(const double val) { return val<(double)min()?min():val>(double)max()?max():(bool)val; }
      static const char* format() { return "%s"; }
      static const char* format(const bool val) { static const char* s[] = { "false", "true" }; return s[val?1:0]; }
    };

    template<> struct type<unsigned char> {
      static const char* string() { static const char *const s = "unsigned char"; return s; }
      static bool is_float() { return false; }
      static bool is_inf(const unsigned char) { return false; }
      static bool is_nan(const unsigned char) { return false; }
      static unsigned char min() { return 0; }
      static unsigned char max() { return (unsigned char)~0U; }
      static unsigned char inf() { return max(); }
      static unsigned char cut(const double val) { return val<(double)min()?min():val>(double)max()?max():(unsigned char)val; }
      static const char* format() { return "%u"; }
      static unsigned int format(const unsigned char val) { return (unsigned int)val; }
    };

    template<> struct type<char> {
      static const char* string() { static const char *const s = "char"; return s; }
      static bool is_float() { return false; }
      static bool is_inf(const char) { return false; }
      static bool is_nan(const char) { return false; }
      static char min() { return (char)(-1L<<(8*sizeof(char)-1)); }
      static char max() { return (char)~((char)(-1L<<(8*sizeof(char)-1))); }
      static char inf() { return max(); }
      static char cut(const double val) { return val<(double)min()?min():val>(double)max()?max():(char)val; }
      static const char* format() { return "%d"; }
      static int format(const char val) { return (int)val; }
    };

    template<> struct type<signed char> {
      static const char* string() { static const char *const s = "signed char"; return s; }
      static bool is_float() { return false; }
      static bool is_inf(const signed char) { return false; }
      static bool is_nan(const signed char) { return false; }
      static signed char min() { return (signed char)(-1L<<(8*sizeof(signed char)-1)); }
      static signed char max() { return ~((signed char)(-1L<<(8*sizeof(signed char)-1))); }
      static signed char inf() { return max(); }
      static signed char cut(const double val) { return val<(double)min()?min():val>(double)max()?max():(signed char)val; }
      static const char* format() { return "%d"; }
      static unsigned int format(const signed char val) { return (int)val; }
    };

    template<> struct type<unsigned short> {
      static const char* string() { static const char *const s = "unsigned short"; return s; }
      static bool is_float() { return false; }
      static bool is_inf(const unsigned short) { return false; }
      static bool is_nan(const unsigned short) { return false; }
      static unsigned short min() { return 0; }
      static unsigned short max() { return (unsigned short)~0U; }
      static unsigned short inf() { return max(); }
      static unsigned short cut(const double val) { return val<(double)min()?min():val>(double)max()?max():(unsigned short)val; }
      static const char* format() { return "%u"; }
      static unsigned int format(const unsigned short val) { return (unsigned int)val; }
    };

    template<> struct type<short> {
      static const char* string() { static const char *const s = "short"; return s; }
      static bool is_float() { return false; }
      static bool is_inf(const short) { return false; }
      static bool is_nan(const short) { return false; }
      static short min() { return (short)(-1L<<(8*sizeof(short)-1)); }
      static short max() { return ~((short)(-1L<<(8*sizeof(short)-1))); }
      static short inf() { return max(); }
      static short cut(const double val) { return val<(double)min()?min():val>(double)max()?max():(short)val; }
      static const char* format() { return "%d"; }
      static int format(const short val) { return (int)val; }
    };

    template<> struct type<unsigned int> {
      static const char* string() { static const char *const s = "unsigned int"; return s; }
      static bool is_float() { return false; }
      static bool is_inf(const unsigned int) { return false; }
      static bool is_nan(const unsigned int) { return false; }
      static unsigned int min() { return 0; }
      static unsigned int max() { return (unsigned int)~0U; }
      static unsigned int inf() { return max(); }
      static unsigned int cut(const double val) { return val<(double)min()?min():val>(double)max()?max():(unsigned int)val; }
      static const char* format() { return "%u"; }
      static unsigned int format(const unsigned int val) { return val; }
    };

    template<> struct type<int> {
      static const char* string() { static const char *const s = "int"; return s; }
      static bool is_float() { return false; }
      static bool is_inf(const int) { return false; }
      static bool is_nan(const int) { return false; }
      static int min() { return (int)(-1L<<(8*sizeof(int)-1)); }
      static int max() { return ~((int)(-1L<<(8*sizeof(int)-1))); }
      static int inf() { return max(); }
      static int cut(const double val) { return val<(double)min()?min():val>(double)max()?max():(int)val; }
      static const char* format() { return "%d"; }
      static int format(const int val) { return val; }
    };

    template<> struct type<unsigned long> {
      static const char* string() { static const char *const s = "unsigned long"; return s; }
      static bool is_float() { return false; }
      static bool is_inf(const unsigned long) { return false; }
      static bool is_nan(const unsigned long) { return false; }
      static unsigned long min() { return 0; }
      static unsigned long max() { return (unsigned long)~0UL; }
      static unsigned long inf() { return max(); }
      static unsigned long cut(const double val) { return val<(double)min()?min():val>(double)max()?max():(unsigned long)val; }
      static const char* format() { return "%lu"; }
      static unsigned long format(const unsigned long val) { return val; }
    };

    template<> struct type<long> {
      static const char* string() { static const char *const s = "long"; return s; }
      static bool is_float() { return false; }
      static bool is_inf(const long) { return false; }
      static bool is_nan(const long) { return false; }
      static long min() { return (long)(-1L<<(8*sizeof(long)-1)); }
      static long max() { return ~((long)(-1L<<(8*sizeof(long)-1))); }
      static long inf() { return max(); }
      static long cut(const double val) { return val<(double)min()?min():val>(double)max()?max():(long)val; }
      static const char* format() { return "%ld"; }
      static long format(const long val) { return val; }
    };

    template<> struct type<double> {
      static const char* string() { static const char *const s = "double"; return s; }
      static bool is_float() { return true; }
      static bool is_inf(const double val) {
#ifdef isinf
        return (bool)isinf(val);
#else
# 2364 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        return !is_nan(val) && (val<cimg::type<double>::min() || val>cimg::type<double>::max());
#endif
# 2366 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      }
      static bool is_nan(const double val) {
#ifdef isnan
        return (bool)isnan(val);
#else
# 2371 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        return !(val==val);
#endif
# 2373 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      }
      static double min() { return -1.7E308; }
      static double max() { return  1.7E308; }
      static double inf() { return max()*max(); }
      static double nan() { static const double val_nan = -std::sqrt(-1.0); return val_nan; }
      static double cut(const double val) { return val<min()?min():val>max()?max():val; }
      static const char* format() { return "%.16g"; }
      static double format(const double val) { return val; }
    };

    template<> struct type<float> {
      static const char* string() { static const char *const s = "float"; return s; }
      static bool is_float() { return true; }
      static bool is_inf(const float val) {
#ifdef isinf
        return (bool)isinf(val);
#else
# 2390 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        return !is_nan(val) && (val<cimg::type<float>::min() || val>cimg::type<float>::max());
#endif
# 2392 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      }
      static bool is_nan(const float val) {
#ifdef isnan
        return (bool)isnan(val);
#else
# 2397 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        return !(val==val);
#endif
# 2399 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      }
      static float min() { return -3.4E38f; }
      static float max() { return  3.4E38f; }
      static float inf() { return (float)cimg::type<double>::inf(); }
      static float nan() { return (float)cimg::type<double>::nan(); }
      static float cut(const double val) { return val<(double)min()?min():val>(double)max()?max():(float)val; }
      static const char* format() { return "%.16g"; }
      static double format(const float val) { return (double)val; }
    };

    template<typename T, typename t> struct superset { typedef T type; };
    template<> struct superset<bool,unsigned char> { typedef unsigned char type; };
    template<> struct superset<bool,char> { typedef char type; };
    template<> struct superset<bool,signed char> { typedef signed char type; };
    template<> struct superset<bool,unsigned short> { typedef unsigned short type; };
    template<> struct superset<bool,short> { typedef short type; };
    template<> struct superset<bool,unsigned int> { typedef unsigned int type; };
    template<> struct superset<bool,int> { typedef int type; };
    template<> struct superset<bool,unsigned long> { typedef unsigned long type; };
    template<> struct superset<bool,long> { typedef long type; };
    template<> struct superset<bool,float> { typedef float type; };
    template<> struct superset<bool,double> { typedef double type; };
    template<> struct superset<unsigned char,char> { typedef short type; };
    template<> struct superset<unsigned char,signed char> { typedef short type; };
    template<> struct superset<unsigned char,unsigned short> { typedef unsigned short type; };
    template<> struct superset<unsigned char,short> { typedef short type; };
    template<> struct superset<unsigned char,unsigned int> { typedef unsigned int type; };
    template<> struct superset<unsigned char,int> { typedef int type; };
    template<> struct superset<unsigned char,unsigned long> { typedef unsigned long type; };
    template<> struct superset<unsigned char,long> { typedef long type; };
    template<> struct superset<unsigned char,float> { typedef float type; };
    template<> struct superset<unsigned char,double> { typedef double type; };
    template<> struct superset<signed char,unsigned char> { typedef short type; };
    template<> struct superset<signed char,char> { typedef short type; };
    template<> struct superset<signed char,unsigned short> { typedef int type; };
    template<> struct superset<signed char,short> { typedef short type; };
    template<> struct superset<signed char,unsigned int> { typedef long type; };
    template<> struct superset<signed char,int> { typedef int type; };
    template<> struct superset<signed char,unsigned long> { typedef long type; };
    template<> struct superset<signed char,long> { typedef long type; };
    template<> struct superset<signed char,float> { typedef float type; };
    template<> struct superset<signed char,double> { typedef double type; };
    template<> struct superset<char,unsigned char> { typedef short type; };
    template<> struct superset<char,signed char> { typedef short type; };
    template<> struct superset<char,unsigned short> { typedef int type; };
    template<> struct superset<char,short> { typedef short type; };
    template<> struct superset<char,unsigned int> { typedef long type; };
    template<> struct superset<char,int> { typedef int type; };
    template<> struct superset<char,unsigned long> { typedef long type; };
    template<> struct superset<char,long> { typedef long type; };
    template<> struct superset<char,float> { typedef float type; };
    template<> struct superset<char,double> { typedef double type; };
    template<> struct superset<unsigned short,char> { typedef int type; };
    template<> struct superset<unsigned short,signed char> { typedef int type; };
    template<> struct superset<unsigned short,short> { typedef int type; };
    template<> struct superset<unsigned short,unsigned int> { typedef unsigned int type; };
    template<> struct superset<unsigned short,int> { typedef int type; };
    template<> struct superset<unsigned short,unsigned long> { typedef unsigned long type; };
    template<> struct superset<unsigned short,long> { typedef long type; };
    template<> struct superset<unsigned short,float> { typedef float type; };
    template<> struct superset<unsigned short,double> { typedef double type; };
    template<> struct superset<short,unsigned short> { typedef int type; };
    template<> struct superset<short,unsigned int> { typedef long type; };
    template<> struct superset<short,int> { typedef int type; };
    template<> struct superset<short,unsigned long> { typedef long type; };
    template<> struct superset<short,long> { typedef long type; };
    template<> struct superset<short,float> { typedef float type; };
    template<> struct superset<short,double> { typedef double type; };
    template<> struct superset<unsigned int,char> { typedef long type; };
    template<> struct superset<unsigned int,signed char> { typedef long type; };
    template<> struct superset<unsigned int,short> { typedef long type; };
    template<> struct superset<unsigned int,int> { typedef long type; };
    template<> struct superset<unsigned int,unsigned long> { typedef unsigned long type; };
    template<> struct superset<unsigned int,long> { typedef long type; };
    template<> struct superset<unsigned int,float> { typedef float type; };
    template<> struct superset<unsigned int,double> { typedef double type; };
    template<> struct superset<int,unsigned int> { typedef long type; };
    template<> struct superset<int,unsigned long> { typedef long type; };
    template<> struct superset<int,long> { typedef long type; };
    template<> struct superset<int,float> { typedef float type; };
    template<> struct superset<int,double> { typedef double type; };
    template<> struct superset<unsigned long,char> { typedef long type; };
    template<> struct superset<unsigned long,signed char> { typedef long type; };
    template<> struct superset<unsigned long,short> { typedef long type; };
    template<> struct superset<unsigned long,int> { typedef long type; };
    template<> struct superset<unsigned long,long> { typedef long type; };
    template<> struct superset<unsigned long,float> { typedef float type; };
    template<> struct superset<unsigned long,double> { typedef double type; };
    template<> struct superset<long,float> { typedef float type; };
    template<> struct superset<long,double> { typedef double type; };
    template<> struct superset<float,double> { typedef double type; };

    template<typename t1, typename t2, typename t3> struct superset2 {
      typedef typename superset<t1, typename superset<t2,t3>::type>::type type;
    };

    template<typename t1, typename t2, typename t3, typename t4> struct superset3 {
      typedef typename superset<t1, typename superset2<t2,t3,t4>::type>::type type;
    };

    template<typename t1, typename t2> struct last { typedef t2 type; };

#define _cimg_Tt       typename cimg::superset<T,t>::type
#define _cimg_Tfloat   typename cimg::superset<T,float>::type
#define _cimg_Ttfloat  typename cimg::superset2<T,t,float>::type
#define _cimg_Ttdouble typename cimg::superset2<T,t,double>::type

    // Define variables used internally by CImg.
#if cimg_display==1
    struct X11_info {
      volatile unsigned int nb_wins;
      pthread_t*       events_thread;
      pthread_cond_t   wait_event;
      pthread_mutex_t  wait_event_mutex;
      CImgDisplay*     wins[1024];
      Display*         display;
      unsigned int     nb_bits;
      bool             is_blue_first;
      bool             is_shm_enabled;
      bool             byte_order;
#ifdef cimg_use_xrandr
      XRRScreenSize *resolutions;
      Rotation curr_rotation;
      unsigned int curr_resolution;
      unsigned int nb_resolutions;
#endif
# 2525 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      X11_info():nb_wins(0),events_thread(0),display(0),
                 nb_bits(0),is_blue_first(false),is_shm_enabled(false),byte_order(false) {
        XInitThreads();
        pthread_mutex_init(&wait_event_mutex,0);
        pthread_cond_init(&wait_event,0);
#ifdef cimg_use_xrandr
        resolutions = 0;
        curr_rotation = 0;
        curr_resolution = nb_resolutions = 0;
#endif
# 2535 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      }

      ~X11_info() {
        if (events_thread) {
          pthread_cancel(*events_thread);
          delete events_thread;
        }
        if (display) XCloseDisplay(display);
        pthread_cond_destroy(&wait_event);
        pthread_mutex_unlock(&wait_event_mutex);
        pthread_mutex_destroy(&wait_event_mutex);
      }
    };
#if defined(cimg_module)
    X11_info& X11_attr();
#elif defined(cimg_main)
# 2551 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    X11_info& X11_attr() { static X11_info val; return val; }
#else
# 2553 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    inline X11_info& X11_attr() { static X11_info val; return val; }
#endif
# 2555 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

#elif cimg_display==2
# 2557 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    struct Win32_info {
      HANDLE wait_event;
      Win32_info() { wait_event = CreateEvent(0,FALSE,FALSE,0); }
    };
#if defined(cimg_module)
    Win32_info& Win32_attr();
#elif defined(cimg_main)
# 2564 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    Win32_info& Win32_attr() { static Win32_info val; return val; }
#else
# 2566 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    inline Win32_info& Win32_attr() { static Win32_info val; return val; }
#endif
# 2568 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 2569 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    struct Mutex_info {
#if cimg_OS==2
      HANDLE mutex[32];
      Mutex_info() { for (unsigned int i = 0; i<32; ++i) mutex[i] = CreateMutex(0,FALSE,0); }
      void lock(const unsigned int n) { WaitForSingleObject(mutex[n],INFINITE); }
      void unlock(const unsigned int n) { ReleaseMutex(mutex[n]); }
      int trylock(const unsigned int) { return 0; }
#elif defined(_PTHREAD_H)
# 2578 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      pthread_mutex_t mutex[32];
      Mutex_info() { for (unsigned int i = 0; i<32; ++i) pthread_mutex_init(&mutex[i],0); }
      void lock(const unsigned int n) { pthread_mutex_lock(&mutex[n]); }
      void unlock(const unsigned int n) { pthread_mutex_unlock(&mutex[n]); }
      int trylock(const unsigned int n) { return pthread_mutex_trylock(&mutex[n]); }
#else
# 2584 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      Mutex_info() {}
      void lock(const unsigned int) {}
      void unlock(const unsigned int) {}
      int trylock(const unsigned int) { return 0; }
#endif
# 2589 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    };
#if defined(cimg_module)
    Mutex_info& Mutex_attr();
#elif defined(cimg_main)
# 2593 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    Mutex_info& Mutex_attr() { static Mutex_info val; return val; }
#else
# 2595 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    inline Mutex_info& Mutex_attr() { static Mutex_info val; return val; }
#endif
# 2597 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

#if defined(cimg_use_magick)
    static struct Magick_info {
      Magick_info() {
        Magick::InitializeMagick("");
      }
    } _Magick_info;
#endif
# 2605 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

#if cimg_display==1
    // Define keycodes for X11-based graphical systems.
    const unsigned int keyESC        = XK_Escape;
    const unsigned int keyF1         = XK_F1;
    const unsigned int keyF2         = XK_F2;
    const unsigned int keyF3         = XK_F3;
    const unsigned int keyF4         = XK_F4;
    const unsigned int keyF5         = XK_F5;
    const unsigned int keyF6         = XK_F6;
    const unsigned int keyF7         = XK_F7;
    const unsigned int keyF8         = XK_F8;
    const unsigned int keyF9         = XK_F9;
    const unsigned int keyF10        = XK_F10;
    const unsigned int keyF11        = XK_F11;
    const unsigned int keyF12        = XK_F12;
    const unsigned int keyPAUSE      = XK_Pause;
    const unsigned int key1          = XK_1;
    const unsigned int key2          = XK_2;
    const unsigned int key3          = XK_3;
    const unsigned int key4          = XK_4;
    const unsigned int key5          = XK_5;
    const unsigned int key6          = XK_6;
    const unsigned int key7          = XK_7;
    const unsigned int key8          = XK_8;
    const unsigned int key9          = XK_9;
    const unsigned int key0          = XK_0;
    const unsigned int keyBACKSPACE  = XK_BackSpace;
    const unsigned int keyINSERT     = XK_Insert;
    const unsigned int keyHOME       = XK_Home;
    const unsigned int keyPAGEUP     = XK_Page_Up;
    const unsigned int keyTAB        = XK_Tab;
    const unsigned int keyQ          = XK_q;
    const unsigned int keyW          = XK_w;
    const unsigned int keyE          = XK_e;
    const unsigned int keyR          = XK_r;
    const unsigned int keyT          = XK_t;
    const unsigned int keyY          = XK_y;
    const unsigned int keyU          = XK_u;
    const unsigned int keyI          = XK_i;
    const unsigned int keyO          = XK_o;
    const unsigned int keyP          = XK_p;
    const unsigned int keyDELETE     = XK_Delete;
    const unsigned int keyEND        = XK_End;
    const unsigned int keyPAGEDOWN   = XK_Page_Down;
    const unsigned int keyCAPSLOCK   = XK_Caps_Lock;
    const unsigned int keyA          = XK_a;
    const unsigned int keyS          = XK_s;
    const unsigned int keyD          = XK_d;
    const unsigned int keyF          = XK_f;
    const unsigned int keyG          = XK_g;
    const unsigned int keyH          = XK_h;
    const unsigned int keyJ          = XK_j;
    const unsigned int keyK          = XK_k;
    const unsigned int keyL          = XK_l;
    const unsigned int keyENTER      = XK_Return;
    const unsigned int keySHIFTLEFT  = XK_Shift_L;
    const unsigned int keyZ          = XK_z;
    const unsigned int keyX          = XK_x;
    const unsigned int keyC          = XK_c;
    const unsigned int keyV          = XK_v;
    const unsigned int keyB          = XK_b;
    const unsigned int keyN          = XK_n;
    const unsigned int keyM          = XK_m;
    const unsigned int keySHIFTRIGHT = XK_Shift_R;
    const unsigned int keyARROWUP    = XK_Up;
    const unsigned int keyCTRLLEFT   = XK_Control_L;
    const unsigned int keyAPPLEFT    = XK_Super_L;
    const unsigned int keyALT        = XK_Alt_L;
    const unsigned int keySPACE      = XK_space;
    const unsigned int keyALTGR      = XK_Alt_R;
    const unsigned int keyAPPRIGHT   = XK_Super_R;
    const unsigned int keyMENU       = XK_Menu;
    const unsigned int keyCTRLRIGHT  = XK_Control_R;
    const unsigned int keyARROWLEFT  = XK_Left;
    const unsigned int keyARROWDOWN  = XK_Down;
    const unsigned int keyARROWRIGHT = XK_Right;
    const unsigned int keyPAD0       = XK_KP_0;
    const unsigned int keyPAD1       = XK_KP_1;
    const unsigned int keyPAD2       = XK_KP_2;
    const unsigned int keyPAD3       = XK_KP_3;
    const unsigned int keyPAD4       = XK_KP_4;
    const unsigned int keyPAD5       = XK_KP_5;
    const unsigned int keyPAD6       = XK_KP_6;
    const unsigned int keyPAD7       = XK_KP_7;
    const unsigned int keyPAD8       = XK_KP_8;
    const unsigned int keyPAD9       = XK_KP_9;
    const unsigned int keyPADADD     = XK_KP_Add;
    const unsigned int keyPADSUB     = XK_KP_Subtract;
    const unsigned int keyPADMUL     = XK_KP_Multiply;
    const unsigned int keyPADDIV     = XK_KP_Divide;

#elif cimg_display==2
# 2698 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    // Define keycodes for Windows.
    const unsigned int keyESC        = VK_ESCAPE;
    const unsigned int keyF1         = VK_F1;
    const unsigned int keyF2         = VK_F2;
    const unsigned int keyF3         = VK_F3;
    const unsigned int keyF4         = VK_F4;
    const unsigned int keyF5         = VK_F5;
    const unsigned int keyF6         = VK_F6;
    const unsigned int keyF7         = VK_F7;
    const unsigned int keyF8         = VK_F8;
    const unsigned int keyF9         = VK_F9;
    const unsigned int keyF10        = VK_F10;
    const unsigned int keyF11        = VK_F11;
    const unsigned int keyF12        = VK_F12;
    const unsigned int keyPAUSE      = VK_PAUSE;
    const unsigned int key1          = '1';
    const unsigned int key2          = '2';
    const unsigned int key3          = '3';
    const unsigned int key4          = '4';
    const unsigned int key5          = '5';
    const unsigned int key6          = '6';
    const unsigned int key7          = '7';
    const unsigned int key8          = '8';
    const unsigned int key9          = '9';
    const unsigned int key0          = '0';
    const unsigned int keyBACKSPACE  = VK_BACK;
    const unsigned int keyINSERT     = VK_INSERT;
    const unsigned int keyHOME       = VK_HOME;
    const unsigned int keyPAGEUP     = VK_PRIOR;
    const unsigned int keyTAB        = VK_TAB;
    const unsigned int keyQ          = 'Q';
    const unsigned int keyW          = 'W';
    const unsigned int keyE          = 'E';
    const unsigned int keyR          = 'R';
    const unsigned int keyT          = 'T';
    const unsigned int keyY          = 'Y';
    const unsigned int keyU          = 'U';
    const unsigned int keyI          = 'I';
    const unsigned int keyO          = 'O';
    const unsigned int keyP          = 'P';
    const unsigned int keyDELETE     = VK_DELETE;
    const unsigned int keyEND        = VK_END;
    const unsigned int keyPAGEDOWN   = VK_NEXT;
    const unsigned int keyCAPSLOCK   = VK_CAPITAL;
    const unsigned int keyA          = 'A';
    const unsigned int keyS          = 'S';
    const unsigned int keyD          = 'D';
    const unsigned int keyF          = 'F';
    const unsigned int keyG          = 'G';
    const unsigned int keyH          = 'H';
    const unsigned int keyJ          = 'J';
    const unsigned int keyK          = 'K';
    const unsigned int keyL          = 'L';
    const unsigned int keyENTER      = VK_RETURN;
    const unsigned int keySHIFTLEFT  = VK_SHIFT;
    const unsigned int keyZ          = 'Z';
    const unsigned int keyX          = 'X';
    const unsigned int keyC          = 'C';
    const unsigned int keyV          = 'V';
    const unsigned int keyB          = 'B';
    const unsigned int keyN          = 'N';
    const unsigned int keyM          = 'M';
    const unsigned int keySHIFTRIGHT = VK_SHIFT;
    const unsigned int keyARROWUP    = VK_UP;
    const unsigned int keyCTRLLEFT   = VK_CONTROL;
    const unsigned int keyAPPLEFT    = VK_LWIN;
    const unsigned int keyALT        = VK_LMENU;
    const unsigned int keySPACE      = VK_SPACE;
    const unsigned int keyALTGR      = VK_CONTROL;
    const unsigned int keyAPPRIGHT   = VK_RWIN;
    const unsigned int keyMENU       = VK_APPS;
    const unsigned int keyCTRLRIGHT  = VK_CONTROL;
    const unsigned int keyARROWLEFT  = VK_LEFT;
    const unsigned int keyARROWDOWN  = VK_DOWN;
    const unsigned int keyARROWRIGHT = VK_RIGHT;
    const unsigned int keyPAD0       = 0x60;
    const unsigned int keyPAD1       = 0x61;
    const unsigned int keyPAD2       = 0x62;
    const unsigned int keyPAD3       = 0x63;
    const unsigned int keyPAD4       = 0x64;
    const unsigned int keyPAD5       = 0x65;
    const unsigned int keyPAD6       = 0x66;
    const unsigned int keyPAD7       = 0x67;
    const unsigned int keyPAD8       = 0x68;
    const unsigned int keyPAD9       = 0x69;
    const unsigned int keyPADADD     = VK_ADD;
    const unsigned int keyPADSUB     = VK_SUBTRACT;
    const unsigned int keyPADMUL     = VK_MULTIPLY;
    const unsigned int keyPADDIV     = VK_DIVIDE;

#else
# 2789 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    // Define random keycodes when no display is available.
    // (should rarely be used then!).
    const unsigned int keyESC        = 1U;   //!< Keycode for the \c ESC key (architecture-dependent).
    const unsigned int keyF1         = 2U;   //!< Keycode for the \c F1 key (architecture-dependent).
    const unsigned int keyF2         = 3U;   //!< Keycode for the \c F2 key (architecture-dependent).
    const unsigned int keyF3         = 4U;   //!< Keycode for the \c F3 key (architecture-dependent).
    const unsigned int keyF4         = 5U;   //!< Keycode for the \c F4 key (architecture-dependent).
    const unsigned int keyF5         = 6U;   //!< Keycode for the \c F5 key (architecture-dependent).
    const unsigned int keyF6         = 7U;   //!< Keycode for the \c F6 key (architecture-dependent).
    const unsigned int keyF7         = 8U;   //!< Keycode for the \c F7 key (architecture-dependent).
    const unsigned int keyF8         = 9U;   //!< Keycode for the \c F8 key (architecture-dependent).
    const unsigned int keyF9         = 10U;  //!< Keycode for the \c F9 key (architecture-dependent).
    const unsigned int keyF10        = 11U;  //!< Keycode for the \c F10 key (architecture-dependent).
    const unsigned int keyF11        = 12U;  //!< Keycode for the \c F11 key (architecture-dependent).
    const unsigned int keyF12        = 13U;  //!< Keycode for the \c F12 key (architecture-dependent).
    const unsigned int keyPAUSE      = 14U;  //!< Keycode for the \c PAUSE key (architecture-dependent).
    const unsigned int key1          = 15U;  //!< Keycode for the \c 1 key (architecture-dependent).
    const unsigned int key2          = 16U;  //!< Keycode for the \c 2 key (architecture-dependent).
    const unsigned int key3          = 17U;  //!< Keycode for the \c 3 key (architecture-dependent).
    const unsigned int key4          = 18U;  //!< Keycode for the \c 4 key (architecture-dependent).
    const unsigned int key5          = 19U;  //!< Keycode for the \c 5 key (architecture-dependent).
    const unsigned int key6          = 20U;  //!< Keycode for the \c 6 key (architecture-dependent).
    const unsigned int key7          = 21U;  //!< Keycode for the \c 7 key (architecture-dependent).
    const unsigned int key8          = 22U;  //!< Keycode for the \c 8 key (architecture-dependent).
    const unsigned int key9          = 23U;  //!< Keycode for the \c 9 key (architecture-dependent).
    const unsigned int key0          = 24U;  //!< Keycode for the \c 0 key (architecture-dependent).
    const unsigned int keyBACKSPACE  = 25U;  //!< Keycode for the \c BACKSPACE key (architecture-dependent).
    const unsigned int keyINSERT     = 26U;  //!< Keycode for the \c INSERT key (architecture-dependent).
    const unsigned int keyHOME       = 27U;  //!< Keycode for the \c HOME key (architecture-dependent).
    const unsigned int keyPAGEUP     = 28U;  //!< Keycode for the \c PAGEUP key (architecture-dependent).
    const unsigned int keyTAB        = 29U;  //!< Keycode for the \c TAB key (architecture-dependent).
    const unsigned int keyQ          = 30U;  //!< Keycode for the \c Q key (architecture-dependent).
    const unsigned int keyW          = 31U;  //!< Keycode for the \c W key (architecture-dependent).
    const unsigned int keyE          = 32U;  //!< Keycode for the \c E key (architecture-dependent).
    const unsigned int keyR          = 33U;  //!< Keycode for the \c R key (architecture-dependent).
    const unsigned int keyT          = 34U;  //!< Keycode for the \c T key (architecture-dependent).
    const unsigned int keyY          = 35U;  //!< Keycode for the \c Y key (architecture-dependent).
    const unsigned int keyU          = 36U;  //!< Keycode for the \c U key (architecture-dependent).
    const unsigned int keyI          = 37U;  //!< Keycode for the \c I key (architecture-dependent).
    const unsigned int keyO          = 38U;  //!< Keycode for the \c O key (architecture-dependent).
    const unsigned int keyP          = 39U;  //!< Keycode for the \c P key (architecture-dependent).
    const unsigned int keyDELETE     = 40U;  //!< Keycode for the \c DELETE key (architecture-dependent).
    const unsigned int keyEND        = 41U;  //!< Keycode for the \c END key (architecture-dependent).
    const unsigned int keyPAGEDOWN   = 42U;  //!< Keycode for the \c PAGEDOWN key (architecture-dependent).
    const unsigned int keyCAPSLOCK   = 43U;  //!< Keycode for the \c CAPSLOCK key (architecture-dependent).
    const unsigned int keyA          = 44U;  //!< Keycode for the \c A key (architecture-dependent).
    const unsigned int keyS          = 45U;  //!< Keycode for the \c S key (architecture-dependent).
    const unsigned int keyD          = 46U;  //!< Keycode for the \c D key (architecture-dependent).
    const unsigned int keyF          = 47U;  //!< Keycode for the \c F key (architecture-dependent).
    const unsigned int keyG          = 48U;  //!< Keycode for the \c G key (architecture-dependent).
    const unsigned int keyH          = 49U;  //!< Keycode for the \c H key (architecture-dependent).
    const unsigned int keyJ          = 50U;  //!< Keycode for the \c J key (architecture-dependent).
    const unsigned int keyK          = 51U;  //!< Keycode for the \c K key (architecture-dependent).
    const unsigned int keyL          = 52U;  //!< Keycode for the \c L key (architecture-dependent).
    const unsigned int keyENTER      = 53U;  //!< Keycode for the \c ENTER key (architecture-dependent).
    const unsigned int keySHIFTLEFT  = 54U;  //!< Keycode for the \c SHIFTLEFT key (architecture-dependent).
    const unsigned int keyZ          = 55U;  //!< Keycode for the \c Z key (architecture-dependent).
    const unsigned int keyX          = 56U;  //!< Keycode for the \c X key (architecture-dependent).
    const unsigned int keyC          = 57U;  //!< Keycode for the \c C key (architecture-dependent).
    const unsigned int keyV          = 58U;  //!< Keycode for the \c V key (architecture-dependent).
    const unsigned int keyB          = 59U;  //!< Keycode for the \c B key (architecture-dependent).
    const unsigned int keyN          = 60U;  //!< Keycode for the \c N key (architecture-dependent).
    const unsigned int keyM          = 61U;  //!< Keycode for the \c M key (architecture-dependent).
    const unsigned int keySHIFTRIGHT = 62U;  //!< Keycode for the \c SHIFTRIGHT key (architecture-dependent).
    const unsigned int keyARROWUP    = 63U;  //!< Keycode for the \c ARROWUP key (architecture-dependent).
    const unsigned int keyCTRLLEFT   = 64U;  //!< Keycode for the \c CTRLLEFT key (architecture-dependent).
    const unsigned int keyAPPLEFT    = 65U;  //!< Keycode for the \c APPLEFT key (architecture-dependent).
    const unsigned int keyALT        = 66U;  //!< Keycode for the \c ALT key (architecture-dependent).
    const unsigned int keySPACE      = 67U;  //!< Keycode for the \c SPACE key (architecture-dependent).
    const unsigned int keyALTGR      = 68U;  //!< Keycode for the \c ALTGR key (architecture-dependent).
    const unsigned int keyAPPRIGHT   = 69U;  //!< Keycode for the \c APPRIGHT key (architecture-dependent).
    const unsigned int keyMENU       = 70U;  //!< Keycode for the \c MENU key (architecture-dependent).
    const unsigned int keyCTRLRIGHT  = 71U;  //!< Keycode for the \c CTRLRIGHT key (architecture-dependent).
    const unsigned int keyARROWLEFT  = 72U;  //!< Keycode for the \c ARROWLEFT key (architecture-dependent).
    const unsigned int keyARROWDOWN  = 73U;  //!< Keycode for the \c ARROWDOWN key (architecture-dependent).
    const unsigned int keyARROWRIGHT = 74U;  //!< Keycode for the \c ARROWRIGHT key (architecture-dependent).
    const unsigned int keyPAD0       = 75U;  //!< Keycode for the \c PAD0 key (architecture-dependent).
    const unsigned int keyPAD1       = 76U;  //!< Keycode for the \c PAD1 key (architecture-dependent).
    const unsigned int keyPAD2       = 77U;  //!< Keycode for the \c PAD2 key (architecture-dependent).
    const unsigned int keyPAD3       = 78U;  //!< Keycode for the \c PAD3 key (architecture-dependent).
    const unsigned int keyPAD4       = 79U;  //!< Keycode for the \c PAD4 key (architecture-dependent).
    const unsigned int keyPAD5       = 80U;  //!< Keycode for the \c PAD5 key (architecture-dependent).
    const unsigned int keyPAD6       = 81U;  //!< Keycode for the \c PAD6 key (architecture-dependent).
    const unsigned int keyPAD7       = 82U;  //!< Keycode for the \c PAD7 key (architecture-dependent).
    const unsigned int keyPAD8       = 83U;  //!< Keycode for the \c PAD8 key (architecture-dependent).
    const unsigned int keyPAD9       = 84U;  //!< Keycode for the \c PAD9 key (architecture-dependent).
    const unsigned int keyPADADD     = 85U;  //!< Keycode for the \c PADADD key (architecture-dependent).
    const unsigned int keyPADSUB     = 86U;  //!< Keycode for the \c PADSUB key (architecture-dependent).
    const unsigned int keyPADMUL     = 87U;  //!< Keycode for the \c PADMUL key (architecture-dependent).
    const unsigned int keyPADDIV     = 88U;  //!< Keycode for the \c PADDDIV key (architecture-dependent).
#endif
# 2880 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    const double PI = 3.14159265358979323846;   //!< Value of the mathematical constant PI

    // Define a 10x13 font (small size).
    const unsigned int font10x13[256*10*13/32] = {
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x80100c0,
      0x68000300,0x801,0xc00010,0x100c000,0x68100,0x100c0680,0x2,0x403000,0x1000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,0x0,0x0,0x4020120,
      0x58120480,0x402,0x1205008,0x2012050,0x58080,0x20120581,0x40000001,0x804812,0x2000000,0x0,0x300,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x140,0x80000,0x200402,0x800000,0x10,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x7010,0x7000000,0x8000200,0x20000,0xc0002000,0x8008,0x0,0x0,0x0,0x0,0x808,0x4000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x80000000,0x0,0x0,0x0,0x40000,0x0,0x0,0x0,0x0,0x480,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x70,0x80100c0,0x68000480,0x1001,
      0xc00010,0x1018000,0x68100,0x100c0680,0x4,0x403000,0x1020000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x20140,0x28081883,0x200801,
      0x2a00000,0x10,0x1c0201c0,0x70040f80,0xc0f81c07,0x0,0x70,0x3e0303c0,0x3c3c0f83,0xe03c2107,0xe08810,0x18c31070,0x3c0703c0,
      0x783e0842,0x22222208,0x83e04010,0x1008000,0x4000200,0x20001,0x2002,0x408008,0x0,0x0,0x100000,0x0,0x1008,0x2000000,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x20080,0x38000880,0x8078140f,0x81c00000,0x3e000,0xc020180,0x60080001,0xe0000002,0xc00042,0x108e2010,
      0xc0300c0,0x300c0303,0xf83c3e0f,0x83e0f81c,0x701c070,0x3c0c41c0,0x701c0701,0xc0001d08,0x42108421,0x8820088,0x4020120,0x58140480,
      0x802,0x1205008,0x3014050,0xc058080,0x20120581,0x40000002,0x804814,0x2020050,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x20140,
      0x281e2484,0x80200801,0x1c02000,0x10,0x22060220,0x880c0801,0x82208,0x80000001,0x20008,0x41030220,0x40220802,0x402102,0x209010,
      0x18c31088,0x22088220,0x80080842,0x22222208,0x80204010,0x1014000,0x200,0x20001,0x2000,0x8008,0x0,0x0,0x100000,0x0,0x1008,
      0x2000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x80,0x40000500,0x80800010,0x40200000,0x41000,0x12020040,0x10000003,0xa0000006,
      0x12000c4,0x31014000,0xc0300c0,0x300c0302,0x80402008,0x2008008,0x2008020,0x220c4220,0x88220882,0x20002208,0x42108421,0x8820088,
      0x0,0x300,0x0,0x0,0x0,0x14000000,0x0,0x200200,0x0,0x20000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x20000,0xfc282504,0x80001000,
      0x82a02000,0x20,0x22020020,0x8140802,0x102208,0x80801006,0x18008,0x9c848220,0x80210802,0x802102,0x20a010,0x15429104,0x22104220,
      0x80080842,0x22221405,0x404008,0x1022000,0x703c0,0x381e0701,0xc0783c02,0xc09008,0x1d83c070,0x3c078140,0x381c0882,0x21242208,
      0x81e01008,0x2000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x201e0,0x40220500,0x80800027,0x20e02800,0x9c800,0x12020040,
      0x20000883,0xa0200002,0x120a044,0x11064010,0x12048120,0x48120484,0x80802008,0x2008008,0x2008020,0x210a4411,0x4411044,0x10884508,
      0x42108421,0x503c0b0,0x1c0701c0,0x701c0707,0x70381c07,0x1c07008,0x2008020,0x20f01c0,0x701c0701,0xc0201c08,0x82208822,0x883c088,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x20000,0x50281903,0x20001000,0x80802000,0x20,0x22020040,0x30240f03,0xc0101c08,0x80801018,
      0x1fc06010,0xa48483c0,0x80210f03,0xe0803f02,0x20c010,0x15429104,0x22104220,0x70080841,0x41540805,0x804008,0x1041000,0x8220,
      0x40220881,0x882202,0x40a008,0x12422088,0x22088180,0x40100882,0x21241408,0x80201008,0x2031000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x20280,0x401c0200,0x700028,0x21205000,0x92800,0xc1fc080,0x10000883,0xa0200002,0x1205049,0x12c19010,0x12048120,0x48120484,
      0xf0803c0f,0x3c0f008,0x2008020,0x790a4411,0x4411044,0x10504908,0x42108421,0x5022088,0x2008020,0x8020080,0x88402208,0x82208808,
      0x2008020,0x1e088220,0x88220882,0x20002608,0x82208822,0x8822088,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x20000,0x501c0264,
      0xa0001000,0x8001fc00,0x7000020,0x22020080,0x83e0082,0x20202207,0x80000020,0x1020,0xa4848220,0x80210802,0x9c2102,0x20c010,
      0x12425104,0x3c1043c0,0x8080841,0x41540802,0x804008,0x1000000,0x78220,0x40220f81,0x882202,0x40c008,0x12422088,0x22088100,
      0x60100881,0x41540805,0x406008,0x1849000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x20280,0xf0140200,0x880028,0x20e0a03f,0x709c800,
      0x201c0,0x60000881,0xa0000007,0xc0284b,0x122eb020,0x12048120,0x48120487,0x80802008,0x2008008,0x2008020,0x21094411,0x4411044,
      0x10204908,0x42108421,0x2022088,0x1e0781e0,0x781e0787,0xf8403e0f,0x83e0f808,0x2008020,0x22088220,0x88220882,0x21fc2a08,0x82208822,
      0x5022050,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x20001,0xf80a0294,0x40001000,0x80002000,0x20,0x22020100,0x8040082,0x20202200,
      0x80000018,0x1fc06020,0xa48fc220,0x80210802,0x842102,0x20a010,0x12425104,0x20104240,0x8080841,0x41541402,0x1004008,0x1000000,
      0x88220,0x40220801,0x882202,0x40a008,0x12422088,0x22088100,0x18100881,0x41540805,0x801008,0x2046000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x20280,0x401c0f80,0x80880028,0x20005001,0x94800,0x20000,0x880,0xa0000000,0x5015,0x4215040,0x3f0fc3f0,0xfc3f0fc8,
      0x80802008,0x2008008,0x2008020,0x21094411,0x4411044,0x10505108,0x42108421,0x203c088,0x22088220,0x88220888,0x80402008,0x2008008,
      0x2008020,0x22088220,0x88220882,0x20002a08,0x82208822,0x5022050,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xa00a0494,0x60001000,
      0x80002004,0x8020,0x22020200,0x88040882,0x20402201,0x801006,0x18000,0x9f084220,0x40220802,0x442102,0x209010,0x10423088,0x20088220,
      0x8080840,0x80882202,0x2004008,0x1000000,0x88220,0x40220881,0x882202,0x409008,0x12422088,0x22088100,0x8100880,0x80881402,
      0x1001008,0x2000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x20280,0x40220200,0x80700027,0x20002801,0x92800,0x1fc000,0x980,
      0xa0000000,0xa017,0x84417840,0x21084210,0x84210848,0x80402008,0x2008008,0x2008020,0x2208c220,0x88220882,0x20882208,0x42108421,
      0x2020088,0x22088220,0x88220888,0xc8402208,0x82208808,0x2008020,0x22088220,0x88220882,0x20203208,0x82208822,0x2022020,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x20000,0xa03c0463,0x90000801,0x2004,0x8040,0x1c0703e0,0x70040701,0xc0401c06,0x801001,0x20020,
      0x400843c0,0x3c3c0f82,0x3c2107,0x1c0881e,0x10423070,0x20070210,0xf0080780,0x80882202,0x3e04004,0x1000000,0x783c0,0x381e0701,
      0x782202,0x408808,0x12422070,0x3c078100,0x700c0780,0x80882202,0x1e01008,0x2000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x201e0,
      0xf8000200,0x80080010,0x40000001,0x41000,0x0,0xe80,0xa0000000,0x21,0x8e21038,0x21084210,0x84210848,0xf83c3e0f,0x83e0f81c,
      0x701c070,0x3c08c1c0,0x701c0701,0xc0005c07,0x81e0781e,0x20200b0,0x1e0781e0,0x781e0787,0x30381c07,0x1c07008,0x2008020,0x1c0881c0,
      0x701c0701,0xc0201c07,0x81e0781e,0x203c020,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x80000,0x801,0x4,0x40,0x0,0x0,0x0,0x1000,
      0x0,0x3c000000,0x0,0x0,0x0,0x0,0x10000,0x0,0x0,0x4004,0x1000000,0x0,0x0,0x80000,0x400000,0x0,0x20008000,0x0,0x4,0x1008,0x2000000,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x80,0x0,0x8008000f,0x80000000,0x3e000,0x0,0x800,0xa0000400,0x0,0x0,0x0,0x0,0x80000,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x100000,0x0,0x0,0x0,0x0,0x2000,0x0,0x4020040,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x80000,
      0x402,0x8,0x40,0x0,0x0,0x0,0x2000,0x0,0x0,0x0,0x0,0x0,0x0,0xc000,0x0,0x0,0x7004,0x70000fc,0x0,0x0,0x700000,0x800000,0x0,0x20008000,
      0x0,0x4,0x808,0x4000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x80,0x0,0x80f00000,0x0,0x0,0x0,0x800,0xa0001800,0x0,0x0,0x0,0x0,
      0x300000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x600000,0x0,0x0,0x0,0x0,0x0,0x0,0x4020040
    };

    // Define a 12x24 font (normal size).
    const unsigned int font12x24[12*24*256/32] = {
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x19,0x80000000,0x198000,0x0,0x0,0x0,0x0,
      0x0,0x198,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xc001806,0xc81980,0x60000000,0xc001806,0x1980c00,0x18060198,0xc80c,
      0x180600,0xc8198000,0xc001,0x80601980,0x18000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xf,0x0,0xf0000,0x0,0x0,0x0,0x0,0x0,0x198,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x600300f,0x1301980,0x90000000,0x600300f,0x1980600,0x300f0198,0x13006,0x300f01,0x30198000,0x6003,
      0xf01980,0x30000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x6,0x0,0x60000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x7007,0x3c0000,0x3006019,
      0x80000000,0x90000000,0x3006019,0x80000300,0x60198000,0x3,0x601980,0x0,0x3006,0x1980000,0x60000000,0x0,0x0,0xe0000000,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x18000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x6000000,
      0x0,0x0,0x0,0x0,0x0,0xc800019,0x80000000,0x198000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xc0,0x0,0x0,0x1001,0x420000,0x0,0x0,0x90000000,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x18000c06,0xc80001,0x10000000,0x18000c06,0x1800,0xc060000,0xc818,0xc0600,0xc8000000,
      0x18000,0xc0600000,0xc000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x6019,0x80660207,0x800f8060,0x300c004,0x0,0x6,
      0xe00703f,0x3f00383,0xf80f07fc,0x1f01f000,0x0,0xf8,0x607f,0x7c7e07,0xfe7fe0f8,0x6063fc1f,0x86066007,0xe7060f0,0x7f80f07f,
      0x81f8fff6,0x6606c03,0x70ee077f,0xe0786000,0xf0070000,0xc000060,0xc0,0x3e000,0x60006003,0x600fc00,0x0,0x0,0x0,0x0,0x0,0x3c0603,
      0xc0000000,0x7800000,0xf0000,0x0,0xf00001f,0x80001fe0,0x7fe000,0x0,0x0,0x0,0x168fe609,0x0,0x90e07,0x6000,0x3c000e,0x70000f8,
      0x1980001f,0x0,0x1f8,0xf00000f,0xf00180,0xfe000,0xe00e,0x1001,0x20060,0x6006006,0x600600,0x600fe07c,0x7fe7fe7f,0xe7fe3fc3,
      0xfc3fc3fc,0x7e07060f,0xf00f00,0xf00f0000,0xf360660,0x6606606e,0x76001e0,0xc00180f,0x1681981,0x10000000,0xc00180f,0x1980c00,
      0x180f0198,0x3801680c,0x180f01,0x68198000,0xc001,0x80f01980,0x18600198,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x6019,
      0x8044020c,0xc01f8060,0x2004004,0x0,0xc,0x3f81f07f,0x87f80383,0xf81f87fc,0x3f83f800,0x0,0x1fc,0x780607f,0x81fe7f87,0xfe7fe1fc,
      0x6063fc1f,0x860c6007,0xe7061f8,0x7fc1f87f,0xc3fcfff6,0x6606c03,0x30c6067f,0xe0783000,0xf00d8000,0x6000060,0xc0,0x7e000,0x60006003,
      0x600fc00,0x0,0x0,0xc00,0x0,0x0,0x7c0603,0xe0000000,0xfc00000,0x1f0000,0x0,0x900003f,0xc0003fe0,0x7fe000,0x0,0x0,0x0,0x1302660f,
      0x0,0xf0606,0x6004,0x7e0006,0x60601f8,0x19800001,0x80000000,0x1f8,0x19800010,0x81080300,0x3f2000,0x2011,0x1001,0x1c0060,0x6006006,
      0x600600,0x601fe1fe,0x7fe7fe7f,0xe7fe3fc3,0xfc3fc3fc,0x7f87061f,0x81f81f81,0xf81f8000,0x3fa60660,0x66066066,0x66003f0,0x6003009,
      0x1301981,0x10000000,0x6003009,0x1980600,0x30090198,0x1f013006,0x300901,0x30198000,0x6003,0x901980,0x30600198,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x6019,0x80cc0f8c,0xc0180060,0x6006044,0x40000000,0xc,0x3181b041,0xc41c0783,0x388018,
      0x71c71800,0x0,0x106,0x18c0f061,0xc38261c6,0x600384,0x60606001,0x86186007,0xe78630c,0x60e30c60,0xe7040606,0x630cc03,0x39c30c00,
      0xc0603000,0x3018c000,0x3000060,0xc0,0x60000,0x60000000,0x6000c00,0x0,0x0,0xc00,0x0,0x0,0x600600,0x60000000,0x18400000,0x180000,
      0x0,0x19800070,0x40003600,0xc000,0x0,0x0,0x0,0x25a06,0x0,0x6030c,0x4,0xe20007,0xe060180,0xf000,0x80000000,0xf0000,0x10800000,
      0x80080600,0x7f2000,0x2020,0x80001001,0x20000,0xf00f00f,0xf00f00,0x601b0382,0x60060060,0x6000600,0x60060060,0x61c78630,0xc30c30c3,
      0xc30c000,0x30e60660,0x66066063,0xc600738,0x3006019,0x80000000,0xe0000000,0x3006019,0x80000300,0x60198000,0x3e000003,0x601980,
      0x0,0x3006,0x1980000,0x60600000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x6019,0x80cc1fcc,0xc0180060,0x6006035,0x80000000,
      0x18,0x71c03000,0xc00c0583,0x300018,0x60c60c00,0x0,0x6,0x3060f060,0xc30060c6,0x600300,0x60606001,0x86306007,0x9e78670e,0x60670e60,
      0x66000606,0x630c606,0x19830c01,0xc0601800,0x30306000,0x60,0xc0,0x60000,0x60000000,0x6000c00,0x0,0x0,0xc00,0x0,0x0,0x600600,
      0x60000000,0x18000000,0x300000,0x0,0x78060,0x6600,0x1c000,0x300c,0x39819c0,0x0,0x25a00,0x0,0x30c,0x4,0xc00003,0xc060180,0x30c1f,
      0x80000000,0x30c000,0x10800001,0x80700000,0x7f2000,0x2020,0x80001001,0x20060,0xf00f00f,0xf00f00,0xf01b0300,0x60060060,0x6000600,
      0x60060060,0x60c78670,0xe70e70e7,0xe70e000,0x70c60660,0x66066063,0xc7f8618,0x0,0x0,0x0,0x0,0x0,0x0,0x7000000,0x0,0x0,0x0,
      0x0,0x600000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x6019,0x87ff3a4c,0xc0180060,0x400600e,0x600000,0x18,0x60c03000,
      0xc00c0d83,0x700018,0x60c60c00,0x20,0x400006,0x3060f060,0xc6006066,0x600600,0x60606001,0x86606006,0x966c6606,0x60660660,0x66000606,
      0x630c666,0xf019801,0x80601800,0x30603000,0x1f06f,0xf01ec0,0xf03fe1ec,0x6703e01f,0x61c0c06,0xdc6701f0,0x6f01ec0c,0xe1f87fc6,
      0xc60cc03,0x71c60c7f,0xc0600600,0x60000000,0x30000000,0x300000,0x40040,0x88060,0x6600,0x18000,0x300c,0x1981980,0x0,0x2421f,
      0x80003ce0,0x7fc198,0x601f,0xc02021,0x980600c0,0x40230,0x80000000,0x402000,0x19806003,0x80006,0xc7f2000,0x2020,0x80001001,
      0x420060,0xf00f00f,0xf00f00,0xf01b0600,0x60060060,0x6000600,0x60060060,0x6066c660,0x66066066,0x6606208,0x60e60660,0x66066061,
      0x987fc670,0x1f01f01f,0x1f01f01,0xf039c0f0,0xf00f00f,0xf03e03,0xe03e03e0,0x1f06701f,0x1f01f01,0xf01f0060,0x1e660c60,0xc60c60c6,
      0xc6f060c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x6000,0x7ff3207,0x8c0c0000,0xc00300e,0x600000,0x30,0x60c03000,
      0xc01c0983,0xf0600030,0x31860c06,0x6001e0,0x78000e,0x23e1f861,0xc6006066,0x600600,0x60606001,0x86c06006,0x966c6606,0x60660660,
      0xe7000606,0x630c666,0xf01f803,0x600c00,0x30000000,0x3f87f,0x83f83fc3,0xf83fe3fc,0x7f83e01f,0x6380c07,0xfe7f83f8,0x7f83fc0d,
      0xf3fc7fc6,0xc71cc03,0x3183187f,0xc0600600,0x60000000,0xff806000,0x300000,0x40040,0x88070,0x6600,0x60030060,0x6001818,0x1883180,
      0x0,0x2423f,0xc0007ff0,0x607fc1f8,0x603f,0x80c01fc1,0xf80601e0,0x5f220,0x80420000,0x5f2000,0xf006006,0x80006,0xc7f2000,0x2020,
      0x82107c07,0xc03c0060,0x1f81f81f,0x81f81f80,0xf03b0600,0x60060060,0x6000600,0x60060060,0x6066c660,0x66066066,0x660671c,0x61660660,
      0x66066061,0xf860e6c0,0x3f83f83f,0x83f83f83,0xf87fe3f8,0x3f83f83f,0x83f83e03,0xe03e03e0,0x3f87f83f,0x83f83f83,0xf83f8060,
      0x3fc60c60,0xc60c60c3,0x187f8318,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x6000,0x883200,0x300c0000,0xc003035,0x80600000,
      0x30,0x66c03001,0xc0f81983,0xf86f0030,0x1f071c06,0x600787,0xfe1e001c,0x6261987f,0x86006067,0xfe7fc600,0x7fe06001,0x87c06006,
      0xf6646606,0x60e6067f,0xc3e00606,0x61986f6,0x600f007,0x600c00,0x30000000,0x21c71,0x830831c3,0x1c06031c,0x71c06003,0x6700c06,
      0x6671c318,0x71831c0f,0x16040c06,0xc318606,0x1b031803,0x80600600,0x60000000,0x30009000,0x300000,0x40040,0x7003e,0x67e0,0x90070090,
      0x9001818,0x8c3100,0x0,0x60,0x4000e730,0x900380f0,0x6034,0x80c018c7,0xfe060338,0xb0121,0x80c60000,0x909000,0x6008,0x1080006,
      0xc3f2000,0x2011,0x3180060,0x60060e0,0x19819819,0x81981981,0x9833c600,0x7fe7fe7f,0xe7fe0600,0x60060060,0x60664660,0x66066066,
      0x66063b8,0x62660660,0x66066060,0xf06066c0,0x21c21c21,0xc21c21c2,0x1c466308,0x31c31c31,0xc31c0600,0x60060060,0x31871c31,0x83183183,
      0x18318000,0x71860c60,0xc60c60c3,0x18718318,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x6000,0x1981a00,0xe03e0000,0xc003044,
      0x40600000,0x60,0x66c03001,0x80f03182,0x1c7f8030,0x3f83fc06,0x601e07,0xfe078038,0x6661987f,0x86006067,0xfe7fc61e,0x7fe06001,
      0x87e06006,0x66666606,0x7fc6067f,0x81f80606,0x61986f6,0x6006006,0x600600,0x30000000,0xc60,0xc60060c6,0xc06060c,0x60c06003,
      0x6e00c06,0x6660c60c,0x60c60c0e,0x6000c06,0xc318666,0x1f031803,0x600600,0x603c2000,0x30016800,0x1fe0000,0x1f81f8,0x1c1f,0x804067e1,
      0x68060168,0x16800810,0xc42300,0x0,0x60,0x20c331,0x68030060,0x6064,0x3fc1040,0xf006031c,0xa011e,0x818c7fe0,0x909000,0x7fe1f,
      0x80f00006,0xc0f2060,0xf80e,0x18c0780,0x780781c0,0x19819819,0x81981981,0x9833c600,0x7fe7fe7f,0xe7fe0600,0x60060060,0xfc666660,
      0x66066066,0x66061f0,0x66660660,0x66066060,0x606066e0,0xc00c00,0xc00c00c0,0xc066600,0x60c60c60,0xc60c0600,0x60060060,0x60c60c60,
      0xc60c60c6,0xc60c000,0x61c60c60,0xc60c60c3,0x1860c318,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x6000,0x1980f81,0x80373000,
      0xc003004,0x7fe0001,0xf0000060,0x60c03003,0x183180,0xc71c060,0x3181ec00,0x7000,0xe070,0x66619860,0xc6006066,0x60061e,0x60606001,
      0x87606006,0x66626606,0x7f860661,0xc01c0606,0x6198696,0xf00600e,0x600600,0x30000000,0x1fc60,0xc60060c7,0xfc06060c,0x60c06003,
      0x7c00c06,0x6660c60c,0x60c60c0c,0x7f00c06,0xc3b8666,0xe01b007,0x3c00600,0x3c7fe000,0xff03ec00,0x1fe0000,0x40040,0xe001,0xc0806603,
      0xec0e03ec,0x3ec00010,0x0,0x60000000,0x7f,0x10c3f3,0xec070060,0x6064,0x3fc1040,0x6000030c,0xa0100,0x3187fe1,0xf09f1000,0x7fe00,
      0x6,0xc012060,0x0,0xc63c03,0xc03c0380,0x19819819,0x81981981,0x98330600,0x60060060,0x6000600,0x60060060,0xfc662660,0x66066066,
      0x66060e0,0x6c660660,0x66066060,0x6060e630,0x1fc1fc1f,0xc1fc1fc1,0xfc3fe600,0x7fc7fc7f,0xc7fc0600,0x60060060,0x60c60c60,0xc60c60c6,
      0xc60c7fe,0x62c60c60,0xc60c60c1,0xb060c1b0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x6000,0xffe02c6,0x3c633000,0xc003004,
      0x7fe0001,0xf00000c0,0x60c03006,0xc6180,0xc60c060,0x60c00c00,0x7000,0xe060,0x66639c60,0x66006066,0x600606,0x60606001,0x86306006,
      0x66636606,0x60060660,0xc0060606,0x61f8696,0xf00600c,0x600300,0x30000000,0x3fc60,0xc60060c7,0xfc06060c,0x60c06003,0x7c00c06,
      0x6660c60c,0x60c60c0c,0x1f80c06,0xc1b0666,0xe01b00e,0x3c00600,0x3c43c000,0x3007de00,0x600000,0x40040,0x30000,0x61006607,0xde0c07de,
      0x7de00000,0x0,0xf07fefff,0x1f,0x8008c3f7,0xde0e0060,0x6064,0xc01047,0xfe00018c,0xb013f,0x86300061,0xf0911000,0x6000,0x6,
      0xc012060,0x3f,0x8063c0cc,0x3cc0c700,0x39c39c39,0xc39c39c1,0x98630600,0x60060060,0x6000600,0x60060060,0x60663660,0x66066066,
      0x66061f0,0x78660660,0x66066060,0x607fc618,0x3fc3fc3f,0xc3fc3fc3,0xfc7fe600,0x7fc7fc7f,0xc7fc0600,0x60060060,0x60c60c60,0xc60c60c6,
      0xc60c7fe,0x64c60c60,0xc60c60c1,0xb060c1b0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x6000,0xffe0260,0x6661b000,0xc003000,
      0x600000,0xc0,0x60c0300c,0xc7fe0,0xc60c060,0x60c01c00,0x1e07,0xfe078060,0x6663fc60,0x66006066,0x600606,0x60606001,0x86386006,
      0x6636606,0x60060660,0xe0060606,0x60f039c,0x1b806018,0x600300,0x30000000,0x70c60,0xc60060c6,0x6060c,0x60c06003,0x7600c06,
      0x6660c60c,0x60c60c0c,0x1c0c06,0xc1b03fc,0xe01f01c,0xe00600,0x70000000,0x3007fc00,0x600000,0x40040,0x0,0x62006607,0xfc1807fc,
      0x7fc00000,0x0,0xf0000000,0x1,0xc004c307,0xfc1c0060,0x6064,0xc018c0,0x600000d8,0x5f200,0x3180060,0x50a000,0x6000,0x6,0xc012000,
      0x0,0xc601c0,0x4201c600,0x3fc3fc3f,0xc3fc3fc3,0xfc7f0600,0x60060060,0x6000600,0x60060060,0x60663660,0x66066066,0x66063b8,
      0x70660660,0x66066060,0x607f860c,0x70c70c70,0xc70c70c7,0xcc60600,0x60060060,0x6000600,0x60060060,0x60c60c60,0xc60c60c6,0xc60c000,
      0x68c60c60,0xc60c60c1,0xf060c1f0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3300260,0x6661e000,0xc003000,0x600000,
      0x180,0x71c03018,0xc7fe0,0xc60c0c0,0x60c01800,0x787,0xfe1e0060,0x6663fc60,0x630060c6,0x600306,0x60606001,0x86186006,0x661e70e,
      0x60070c60,0x60060606,0x60f039c,0x19806038,0x600180,0x30000000,0x60c60,0xc60060c6,0x6060c,0x60c06003,0x6700c06,0x6660c60c,
      0x60c60c0c,0xc0c06,0xc1b039c,0x1f00e018,0x600600,0x60000000,0x1803f800,0x600000,0x40040,0x39e00,0x63006603,0xf83803f8,0x3f800000,
      0x0,0x60000000,0x0,0xc00cc303,0xf8180060,0x6064,0xc01fc0,0x60060070,0x40200,0x18c0060,0x402000,0x6000,0x6,0xc012000,0x0,0x18c0140,
      0x2014600,0x3fc3fc3f,0xc3fc3fc3,0xfc7f0300,0x60060060,0x6000600,0x60060060,0x60c61e70,0xe70e70e7,0xe70e71c,0x60e60660,0x66066060,
      0x6060060c,0x60c60c60,0xc60c60c6,0xcc60600,0x60060060,0x6000600,0x60060060,0x60c60c60,0xc60c60c6,0xc60c000,0x70c60c60,0xc60c60c0,
      0xe060c0e0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x33022e0,0x6670c000,0xc003000,0x600600,0x60180,0x31803030,
      0x41c0184,0x1831c0c0,0x71c23806,0x6001e0,0x780000,0x62630c60,0xe38261c6,0x600386,0x60606043,0x860c6006,0x661e30c,0x60030c60,
      0x740e0607,0xe0f039c,0x31c06030,0x600180,0x30000000,0x61c71,0x830831c3,0x406031c,0x60c06003,0x6300c06,0x6660c318,0x71831c0c,
      0x41c0c07,0x1c0e039c,0x1b00e030,0x600600,0x60000000,0x1c41b00e,0x601cc0,0x401f8,0x45240,0xe1803601,0xb03001b0,0x1b000000,
      0x0,0x0,0x41,0xc008e711,0xb0300060,0x6034,0x80c02020,0x60060030,0x30c00,0xc60000,0x30c000,0x0,0x7,0x1c012000,0x0,0x3180240,
      0x6024608,0x30c30c30,0xc30c30c3,0xc630382,0x60060060,0x6000600,0x60060060,0x61c61e30,0xc30c30c3,0xc30c208,0x70c70e70,0xe70e70e0,
      0x6060068c,0x61c61c61,0xc61c61c6,0x1cc62308,0x30430430,0x43040600,0x60060060,0x31860c31,0x83183183,0x18318060,0x31c71c71,
      0xc71c71c0,0xe07180e0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x6000,0x2203fc0,0x663f6000,0x6006000,0x600600,0x60300,
      0x3f81fe7f,0xc7f80187,0xf83f80c0,0x3f83f006,0x600020,0x400060,0x33e6067f,0xc1fe7f87,0xfe6001fe,0x6063fc7f,0x60e7fe6,0x660e3f8,
      0x6001f860,0x37fc0603,0xfc06030c,0x30c0607f,0xe06000c0,0x30000000,0x7fc7f,0x83f83fc3,0xfc0603fc,0x60c7fe03,0x61807c6,0x6660c3f8,
      0x7f83fc0c,0x7f80fc3,0xfc0e039c,0x3180607f,0xc0600600,0x60000000,0xfc0e00c,0x601986,0x66040040,0x4527f,0xc0803fe0,0xe07fe0e0,
      0xe000000,0x0,0x0,0x7f,0x80107ff0,0xe07fc060,0x603f,0x83fe0000,0x60060018,0xf000,0x420000,0xf0000,0x7fe00,0x7,0xfe012000,
      0x0,0x2100640,0xc0643f8,0x60660660,0x66066067,0xec3e1fe,0x7fe7fe7f,0xe7fe3fc3,0xfc3fc3fc,0x7f860e3f,0x83f83f83,0xf83f8000,
      0x5fc3fc3f,0xc3fc3fc0,0x606006fc,0x7fc7fc7f,0xc7fc7fc7,0xfcffe3f8,0x3fc3fc3f,0xc3fc7fe7,0xfe7fe7fe,0x3f860c3f,0x83f83f83,
      0xf83f8060,0x7f83fc3f,0xc3fc3fc0,0x607f8060,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x6000,0x2201f80,0x3c1e7000,0x6006000,
      0x600,0x60300,0xe01fe7f,0xc3f00183,0xe01f0180,0x1f01e006,0x600000,0x60,0x3006067f,0x807c7e07,0xfe6000f8,0x6063fc3e,0x6067fe6,
      0x660e0f0,0x6000f060,0x3bf80601,0xf806030c,0x60e0607f,0xe06000c0,0x30000000,0x1ec6f,0xf01ec0,0xf80601ec,0x60c7fe03,0x61c03c6,
      0x6660c1f0,0x6f01ec0c,0x3f007c1,0xcc0e030c,0x71c0c07f,0xc0600600,0x60000000,0x7804018,0xe01186,0x66040040,0x39e3f,0x80401fe0,
      0x407fe040,0x4000000,0x0,0x0,0x3f,0x203ce0,0x407fc060,0x601f,0x3fe0000,0x60060018,0x0,0x0,0x0,0x7fe00,0x6,0xe6012000,0x0,
      0x7e0,0x1807e1f0,0x60660660,0x66066066,0x6c3e07c,0x7fe7fe7f,0xe7fe3fc3,0xfc3fc3fc,0x7e060e0f,0xf00f00,0xf00f0000,0x8f01f81f,
      0x81f81f80,0x60600670,0x1ec1ec1e,0xc1ec1ec1,0xec79c0f0,0xf80f80f,0x80f87fe7,0xfe7fe7fe,0x1f060c1f,0x1f01f01,0xf01f0000,0x4f01cc1c,
      0xc1cc1cc0,0xc06f00c0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x200,0x0,0x6006000,0x600,0x600,0x0,0x0,0x0,0x0,
      0x600000,0x0,0x18000000,0x0,0x0,0x0,0x0,0x0,0x1800,0x0,0x0,0x0,0x600060,0x30000000,0x0,0x0,0xc,0x3,0x0,0x0,0x60000c00,0x0,
      0x0,0xc000,0x600600,0x60000000,0x18,0xc03100,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x4,0x0,0x601f8,0x0,0x0,0x0,0x0,0x6,
      0x12000,0x2000000,0x40,0x20004000,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0xc06000c0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x200,0x0,0x2004000,0xc00,0x0,0x0,0x0,0x0,0x0,0xc00000,
      0x0,0x1c000000,0x0,0x0,0x0,0x0,0x0,0xc00,0x0,0x0,0x0,0x780000,0xf0000000,0x0,0x0,0x21c,0x3,0x0,0x0,0x60000c00,0x0,0x0,0xc000,
      0x7c0603,0xe0000000,0x10,0xc02300,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x4,0x0,0x601f0,0x0,0x0,0x0,0x0,0x6,0x12000,0x1000000,
      0x40,0x7e004000,0x0,0x0,0x8,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x8,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xc06000c0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x200,0x0,0x300c000,0xc00,0x0,0x0,0x0,0x0,0x0,0xc00000,0x0,0x7800000,0x0,
      0x0,0x0,0x0,0x0,0x800,0x0,0x0,0x0,0x780000,0xf0000000,0x0,0x0,0x3f8,0x3e,0x0,0x0,0x60000c00,0x0,0x0,0x38000,0x3c0603,0xc0000000,
      0x10,0xfc00000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x4,0x0,0x60000,0x0,0x0,0x0,0x0,0x6,0x0,0x1000000,0x0,0x0,0x0,0x0,
      0x8,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x8,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3,0x80600380,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xffc,0x0,
      0x0,0x1f0,0x3c,0x0,0x0,0x60000c00,0x0,0x0,0x38000,0x600,0x0,0x0,0xf000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x6,0x0,0xe000000,0x0,0x0,0x0,0x0,0x70,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x70,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x3,0x80600380,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xffc,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x600,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0 };

    // Define a 16x32 font (large size).
    const unsigned int font16x32[16*32*256/32] = {
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xc300000,0x0,0xc300000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xe70,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x70000e0,0x3c00730,0xe7001c0,0x0,0x70000e0,0x3c00e70,0x70000e0,0x3c00e70,0x730,0x70000e0,0x3c00730,
      0xe700000,0x700,0xe003c0,0xe7000e0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x6600000,0x0,0x6600000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xe70,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x18001c0,0x6600ff0,0xe7003e0,0x0,0x18001c0,0x6600e70,0x18001c0,0x6600e70,0xff0,0x18001c0,0x6600ff0,0xe700000,0x180,
      0x1c00660,0xe7001c0,0x0,0x0,0x0,0x380,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3c00000,
      0x0,0x3c00000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xe70,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1c00380,
      0xc300ce0,0xe700630,0x0,0x1c00380,0xc300e70,0x1c00380,0xc300e70,0xce0,0x1c00380,0xc300ce0,0xe700000,0x1c0,0x3800c30,0xe700380,
      0x0,0x0,0x0,0x7c0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0xe000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1800000,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0xc300000,0x0,0xc300000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x700000,0x0,0x0,0x0,0x7c007c00,0x3e000000,
      0x0,0x0,0x630,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xe000070,0x1800000,0xc60,0x0,0xe000070,0x1800000,0xe000070,
      0x1800000,0x0,0xe000070,0x1800000,0x0,0xe00,0x700180,0x70,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x800000,0x0,0x600600,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x3f0,0xfc0,0x0,0x7000000,0x38000000,0x1c0000,0xfc0000,0x380001c0,0xe01c00,0x7f800000,0x0,0x0,0x0,0x0,0x0,0x0,0x7c,
      0x1801f00,0x0,0x0,0x1c,0x0,0x0,0x3c00000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x7300000,0x6600000,0x0,0x6600000,0x0,0x0,0x0,0x0,0xe700000,
      0x0,0x0,0x0,0x0,0x0,0xe00000,0x0,0x0,0x0,0xc000c00,0x43800000,0x0,0x0,0x630,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0xf80,0x70000e0,0x3c00730,0xe700c60,0x0,0x70000e0,0x3c00e70,0x70000e0,0x3c00e70,0xe000730,0x70000e0,0x3c00730,0xe700000,0x700,
      0xe003c0,0xe7000e0,0x38000e70,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1c0,0x6300000,0x803c00,0x7c00180,
      0xc00300,0x1000000,0x0,0x1c,0x3c007c0,0xfc007e0,0xe01ff8,0x3f03ffc,0x7e007c0,0x0,0x0,0x7c0,0x1c0,0x7f8003f0,0x7f007ff8,0x7ff803f0,
      0x70381ffc,0xff0700e,0x7000783c,0x783807c0,0x7fc007c0,0x7fc00fc0,0x7fff7038,0x700ee007,0x780f780f,0x7ffc03f0,0x70000fc0,0x3c00000,
      0x3000000,0x38000000,0x1c0000,0x1fc0000,0x380001c0,0xe01c00,0x7f800000,0x0,0x0,0x0,0x0,0x0,0x0,0xfc,0x1801f80,0x0,0x1f80000,
      0x7e,0x0,0x0,0x2400000,0xfc00000,0x7ff0000,0x7ffc0000,0x0,0x0,0x0,0x0,0xf30fb0c,0x2400000,0x0,0x240780f,0x1c0,0xfc,0x780f,
      0x18003f0,0xe700000,0x7c00000,0x0,0xff0,0x3c00000,0x78007c0,0xc00000,0xff80000,0xf80,0x7c00000,0xc000c00,0x18001c0,0x1c001c0,
      0x1c001c0,0x1c003e0,0x7fe03f0,0x7ff87ff8,0x7ff87ff8,0x1ffc1ffc,0x1ffc1ffc,0x7f007838,0x7c007c0,0x7c007c0,0x7c00000,0x7c67038,
      0x70387038,0x7038780f,0x70001fe0,0x30000c0,0x2400f30,0xe700c60,0x0,0x30000c0,0x2400e70,0x30000c0,0x2400e70,0xf700f30,0x30000c0,
      0x2400f30,0xe700000,0x300,0xc00240,0xe7000c0,0x38000e70,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1c0,
      0x630018c,0x807e00,0xfe00180,0xc00300,0x1000000,0x0,0x38,0xff01fc0,0x3ff01ff0,0x1e01ff8,0x7f83ffc,0x1ff80ff0,0x0,0x0,0xff0,
      0x1f003e0,0x7fe00ff8,0x7fc07ff8,0x7ff80ff8,0x70381ffc,0xff0701c,0x7000783c,0x78381ff0,0x7fe01ff0,0x7fe01ff0,0x7fff7038,0x781ee007,
      0x3c1e380e,0x7ffc0380,0x380001c0,0x3c00000,0x1800000,0x38000000,0x1c0000,0x3c00000,0x380001c0,0xe01c00,0x3800000,0x0,0x0,
      0x0,0x7000000,0x0,0x0,0x1e0,0x18003c0,0x0,0x3fc0000,0x70,0x0,0x0,0x6600000,0x1ff00000,0x1fff0000,0x7ffc0000,0x0,0x0,0x0,0x0,
      0xcf0239c,0x3c00000,0x0,0x3c0380e,0x1c0,0x2001fe,0x380e,0x18007f8,0xe700000,0x8600000,0x0,0xff0,0x7e00000,0x8c00870,0x1800000,
      0x1ff80000,0x180,0xc600000,0xc000c00,0x38001c0,0x3e003e0,0x3e003e0,0x3e001c0,0x7fe0ff8,0x7ff87ff8,0x7ff87ff8,0x1ffc1ffc,0x1ffc1ffc,
      0x7fc07838,0x1ff01ff0,0x1ff01ff0,0x1ff00000,0x1fec7038,0x70387038,0x7038380e,0x70003ce0,0x1800180,0x6600cf0,0xe7007c0,0x0,
      0x1800180,0x6600e70,0x1800180,0x6600e70,0x7c00cf0,0x1800180,0x6600cf0,0xe700000,0x180,0x1800660,0xe700180,0x38000e70,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1c0,0x630030c,0x3f0e700,0x1e200180,0x1800180,0x21100000,0x0,
      0x38,0x1e7819c0,0x38781038,0x1e01c00,0xf080038,0x1c381c38,0x0,0x0,0x1878,0x7fc03e0,0x70e01e18,0x70e07000,0x70001e18,0x703801c0,
      0x707038,0x70007c7c,0x7c381c70,0x70701c70,0x70703830,0x1c07038,0x381ce007,0x1c1c3c1e,0x3c0380,0x380001c0,0x7e00000,0xc00000,
      0x38000000,0x1c0000,0x3800000,0x38000000,0x1c00,0x3800000,0x0,0x0,0x0,0x7000000,0x0,0x0,0x1c0,0x18001c0,0x0,0x70c0000,0xe0,
      0x0,0x0,0xc300000,0x38300000,0x3c700000,0x3c0000,0x0,0x0,0x0,0x0,0xce022f4,0x1800000,0x0,0x1803c1e,0x1c0,0x2003c2,0x3c1e,
      0x1800e08,0x7e0,0x300000,0x0,0x7e00000,0xe700000,0x600030,0x3000000,0x3f980000,0x180,0x18200000,0xc000c00,0x1e0001c0,0x3e003e0,
      0x3e003e0,0x3e003e0,0xfe01e18,0x70007000,0x70007000,0x1c001c0,0x1c001c0,0x70e07c38,0x1c701c70,0x1c701c70,0x1c700000,0x3c787038,
      0x70387038,0x70383c1e,0x70003870,0xc00300,0xc300ce0,0x380,0x0,0xc00300,0xc300000,0xc00300,0xc300000,0xfc00ce0,0xc00300,0xc300ce0,
      0x0,0xc0,0x3000c30,0x300,0x38000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1c0,0x630031c,0xff8c300,
      0x1c000180,0x1800180,0x39380000,0x0,0x70,0x1c3801c0,0x203c001c,0x3e01c00,0x1c000038,0x381c3838,0x0,0x0,0x1038,0xe0e03e0,0x70703c08,
      0x70707000,0x70003808,0x703801c0,0x707070,0x70007c7c,0x7c383838,0x70383838,0x70387010,0x1c07038,0x381c700e,0x1e3c1c1c,0x780380,
      0x1c0001c0,0xe700000,0x0,0x38000000,0x1c0000,0x3800000,0x38000000,0x1c00,0x3800000,0x0,0x0,0x0,0x7000000,0x0,0x0,0x1c0,0x18001c0,
      0x0,0xe000000,0xe0,0x0,0x1000100,0x3800,0x70100000,0x38700000,0x780000,0x1c0,0x7801ce0,0xe380000,0x0,0x2264,0x0,0x0,0x1c1c,
      0x0,0x200780,0x1c1c,0x1800c00,0x1818,0x7f00000,0x0,0x18180000,0xc300000,0x600070,0x0,0x7f980000,0x180,0x18300000,0xc000c00,
      0x3000000,0x3e003e0,0x3e003e0,0x3e003e0,0xee03c08,0x70007000,0x70007000,0x1c001c0,0x1c001c0,0x70707c38,0x38383838,0x38383838,
      0x38380000,0x38387038,0x70387038,0x70381c1c,0x7fc03870,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xbc00000,0x0,0x0,0x0,0x0,0x0,0x0,
      0x38000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1c0,0x6300318,0xe88c300,0x1c000180,0x38001c0,
      0xfe00180,0x0,0x70,0x1c3801c0,0x1c001c,0x6e01c00,0x1c000078,0x381c3818,0x0,0x40000,0x40000038,0x1c0607e0,0x70703800,0x70707000,
      0x70003800,0x703801c0,0x7070e0,0x70007c7c,0x7c383838,0x70383838,0x70387000,0x1c07038,0x381c700e,0xf780e38,0x700380,0x1c0001c0,
      0x1c380000,0x0,0x38000000,0x1c0000,0x3800000,0x38000000,0x1c00,0x3800000,0x0,0x0,0x0,0x7000000,0x0,0x0,0x1c0,0x18001c0,0x0,
      0xe000000,0xe0,0x0,0x1000100,0x4400,0x70000000,0x38700000,0x700000,0xe0,0x7001c70,0xe380000,0x0,0x2264,0x0,0x0,0xe38,0x0,
      0x200700,0xe38,0x1800c00,0x300c,0xc300000,0x0,0x300c0000,0xc300180,0x6003c0,0x0,0x7f980000,0x180,0x18300000,0xc000c00,0x1800000,
      0x7e007e0,0x7e007e0,0x7e003e0,0xee03800,0x70007000,0x70007000,0x1c001c0,0x1c001c0,0x70707c38,0x38383838,0x38383838,0x38380000,
      0x38387038,0x70387038,0x70380e38,0x7ff039f0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1e00000,0x0,0x0,0x0,0x40000,0x0,0x0,0x38000000,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1c0,0x6300318,0x1c80e700,0x1c000180,0x38001c0,0x3800180,
      0x0,0xe0,0x381c01c0,0x1c001c,0x6e01c00,0x38000070,0x381c381c,0x0,0x3c0000,0x78000078,0x38030770,0x70707800,0x70387000,0x70007000,
      0x703801c0,0x7071c0,0x7000745c,0x7638701c,0x7038701c,0x70387000,0x1c07038,0x1c38718e,0x7700f78,0xf00380,0xe0001c0,0x381c0000,
      0x7e0,0x39e003e0,0x79c03f0,0x3ffc079c,0x39e01fc0,0xfe01c1e,0x3807778,0x39e007e0,0x39e0079c,0x73c07e0,0x7ff83838,0x701ce007,
      0x783c701c,0x1ffc01c0,0x18001c0,0x0,0x1c000100,0xe0,0x0,0x1000100,0x4200,0x70000000,0x70700100,0xf00100,0x10000e0,0x7000c70,
      0xc700000,0x0,0x2204,0x7e00000,0x1e380100,0x1ffc0f78,0x0,0xf80700,0xf78,0x1800e00,0x63e6,0x18300000,0x0,0x6fe60000,0xe700180,
      0xc00060,0x3838,0x7f980000,0x180,0x18300000,0xc000c00,0x18001c0,0x7700770,0x7700770,0x77007f0,0xee07800,0x70007000,0x70007000,
      0x1c001c0,0x1c001c0,0x70387638,0x701c701c,0x701c701c,0x701c1008,0x707c7038,0x70387038,0x70380f78,0x707039c0,0x7e007e0,0x7e007e0,
      0x7e007e0,0x1f3c03e0,0x3f003f0,0x3f003f0,0x1fc01fc0,0x1fc01fc0,0x7f039e0,0x7e007e0,0x7e007e0,0x7e00380,0x7ce3838,0x38383838,
      0x3838701c,0x39e0701c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1c0,0x6307fff,0x1c807e0c,0xe000180,
      0x30000c0,0x3800180,0x0,0xe0,0x381c01c0,0x1c001c,0xce01fe0,0x38000070,0x381c381c,0x3800380,0xfc0000,0x7e0000f0,0x30030770,
      0x70707000,0x70387000,0x70007000,0x703801c0,0x707380,0x700076dc,0x7638701c,0x7038701c,0x70387800,0x1c07038,0x1c3873ce,0x7f00770,
      0xe00380,0xe0001c0,0x700e0000,0x1ff8,0x3ff00ff0,0xffc0ff8,0x3ffc0ffc,0x3bf01fc0,0xfe01c3c,0x3807f78,0x3bf00ff0,0x3ff00ffc,
      0x77e0ff0,0x7ff83838,0x3838e007,0x3c783838,0x1ffc01c0,0x18001c0,0x0,0x7ff00380,0x1e0,0x0,0x1000100,0x4200,0x78000000,0x70700380,
      0xe00380,0x3800060,0xe000e30,0x1c600000,0x0,0x2204,0xff00000,0x7f7c0380,0x1ffc0770,0x1c0,0x3fc0700,0x18040770,0x1800780,0x4e12,
      0x18300104,0x0,0x4c320000,0x7e00180,0x1c00030,0x3838,0x7f980000,0x180,0x18302080,0xc000c00,0x18001c0,0x7700770,0x7700770,
      0x7700770,0x1ee07000,0x70007000,0x70007000,0x1c001c0,0x1c001c0,0x70387638,0x701c701c,0x701c701c,0x701c381c,0x705c7038,0x70387038,
      0x70380770,0x70383b80,0x1ff81ff8,0x1ff81ff8,0x1ff81ff8,0x3fbe0ff0,0xff80ff8,0xff80ff8,0x1fc01fc0,0x1fc01fc0,0xff83bf0,0xff00ff0,
      0xff00ff0,0xff00380,0xffc3838,0x38383838,0x38383838,0x3ff03838,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x1c0,0x7fff,0x1c803c38,0xf000000,0x70000e0,0xfe00180,0x0,0x1c0,0x381c01c0,0x3c0078,0xce01ff0,0x39e000f0,0x1c38381c,0x3800380,
      0x3e07ffc,0xf8001f0,0x307b0770,0x70e07000,0x70387000,0x70007000,0x703801c0,0x707700,0x700076dc,0x7638701c,0x7038701c,0x70387e00,
      0x1c07038,0x1c3873ce,0x3e007f0,0x1e00380,0x70001c0,0x0,0x1038,0x3c381e18,0x1c7c1e3c,0x3801e3c,0x3c7801c0,0xe01c78,0x380739c,
      0x3c781c38,0x3c381c3c,0x7c21e10,0x7003838,0x3838700e,0x1ef03838,0x3c01c0,0x18001c0,0x0,0x7fe007c0,0x1c0,0x0,0x1000100,0x6400,
      0x7e000000,0x707007c0,0x1e007c0,0x7c00070,0xe000638,0x18600000,0x0,0x0,0x1e100000,0x73ce07c0,0x3c07f0,0x1c0,0x7240700,0x1ddc3ffe,
      0x1800de0,0x8c01,0x1870030c,0x0,0x8c310000,0x3c00180,0x3800030,0x3838,0x7f980000,0x180,0x183030c0,0xc000c00,0x430001c0,0x7700770,
      0x7700770,0x7700770,0x1ce07000,0x70007000,0x70007000,0x1c001c0,0x1c001c0,0x70387638,0x701c701c,0x701c701c,0x701c1c38,0x70dc7038,
      0x70387038,0x703807f0,0x70383b80,0x10381038,0x10381038,0x10381038,0x21e71e18,0x1e3c1e3c,0x1e3c1e3c,0x1c001c0,0x1c001c0,0x1e383c78,
      0x1c381c38,0x1c381c38,0x1c380380,0x1c383838,0x38383838,0x38383838,0x3c383838,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x1c0,0x630,0x1e8000e0,0x1f000000,0x70000e0,0x39380180,0x0,0x1c0,0x3b9c01c0,0x3c07f0,0x18e01078,0x3bf800e0,
      0x7e0383c,0x3800380,0x1f807ffc,0x3f001c0,0x61ff0e38,0x7fc07000,0x70387ff0,0x7ff07000,0x7ff801c0,0x707f00,0x7000729c,0x7338701c,
      0x7070701c,0x70703fc0,0x1c07038,0x1e7873ce,0x1c003e0,0x3c00380,0x70001c0,0x0,0x1c,0x3c381c00,0x1c3c1c1c,0x3801c3c,0x383801c0,
      0xe01cf0,0x380739c,0x38381c38,0x3c381c3c,0x7801c00,0x7003838,0x3838700e,0xfe03c78,0x7801c0,0x18001c0,0x0,0x1c000c20,0xff8,
      0x0,0x1ff01ff0,0x3818,0x3fc00100,0x707e0c20,0x3c00c20,0xc200030,0xc000618,0x18c00000,0x0,0x0,0x1c000080,0xe1ce0c20,0x7803e0,
      0x1c0,0xe200700,0xff83ffe,0x1801878,0x9801,0x1cf0071c,0x7ffc0000,0x8c310000,0x7ffe,0x7000030,0x3838,0x3f980380,0x180,0xc6038e0,
      0x7f9c7f9c,0x3e1c01c0,0xe380e38,0xe380e38,0xe380f78,0x1cfc7000,0x7ff07ff0,0x7ff07ff0,0x1c001c0,0x1c001c0,0xfe387338,0x701c701c,
      0x701c701c,0x701c0e70,0x719c7038,0x70387038,0x703803e0,0x70383b80,0x1c001c,0x1c001c,0x1c001c,0xe71c00,0x1c1c1c1c,0x1c1c1c1c,
      0x1c001c0,0x1c001c0,0x1c383838,0x1c381c38,0x1c381c38,0x1c380000,0x3c383838,0x38383838,0x38383c78,0x3c383c78,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1c0,0x630,0xf800380,0x3f830000,0x70000e0,0x31080180,0x0,0x380,0x3b9c01c0,
      0x7807e0,0x38e00038,0x3c3800e0,0xff01c3c,0x3800380,0x7c000000,0x7c03c0,0x61870e38,0x7fc07000,0x70387ff0,0x7ff070fc,0x7ff801c0,
      0x707f80,0x7000739c,0x7338701c,0x7ff0701c,0x7fe00ff0,0x1c07038,0xe7073ce,0x1c003e0,0x3800380,0x38001c0,0x0,0x1c,0x381c3800,
      0x381c380e,0x380381c,0x383801c0,0xe01de0,0x380739c,0x3838381c,0x381c381c,0x7001e00,0x7003838,0x1c70718e,0x7e01c70,0xf00380,
      0x18001e0,0x1e000000,0x1c001bb0,0xff8,0x0,0x1000100,0xe0,0xff00300,0x707e1bb0,0x3801bb0,0x1bb00010,0x8000308,0x30c00000,0x0,
      0x0,0x1e0000c0,0xe1ce1bb0,0xf003e0,0x1c0,0x1c203ff8,0x63003e0,0x180181c,0x9801,0xfb00e38,0x7ffc0000,0x8fc10000,0x7ffe,0xe000860,
      0x3838,0x1f980380,0x180,0x7c01c70,0x1f001f0,0x1f003c0,0xe380e38,0xe380e38,0xe380e38,0x1cfc7000,0x7ff07ff0,0x7ff07ff0,0x1c001c0,
      0x1c001c0,0xfe387338,0x701c701c,0x701c701c,0x701c07e0,0x731c7038,0x70387038,0x703803e0,0x70383980,0x1c001c,0x1c001c,0x1c001c,
      0xe73800,0x380e380e,0x380e380e,0x1c001c0,0x1c001c0,0x381c3838,0x381c381c,0x381c381c,0x381c0000,0x387c3838,0x38383838,0x38381c70,
      0x381c1c70,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1c0,0xc30,0x7f00e00,0x33c30000,0x70000e0,0x1007ffe,
      0x0,0x380,0x3b9c01c0,0xf00078,0x30e0001c,0x3c1c01c0,0x1c381fdc,0x0,0x70000000,0x1c0380,0x63030e38,0x70707000,0x70387000,0x700070fc,
      0x703801c0,0x707b80,0x7000739c,0x7338701c,0x7fc0701c,0x7fc001f0,0x1c07038,0xe703e5c,0x3e001c0,0x7800380,0x38001c0,0x0,0x7fc,
      0x381c3800,0x381c380e,0x380381c,0x383801c0,0xe01fe0,0x380739c,0x3838381c,0x381c381c,0x7001fc0,0x7003838,0x1c70718e,0x7c01c70,
      0xe01f00,0x180007c,0x7f8c0000,0x7fc03fb8,0x1c0,0x0,0x1000100,0x700,0x1f00600,0x70703fb8,0x7803fb8,0x3fb80000,0x8000000,0x180,
      0x0,0x0,0x1fc00060,0xe1ce3fb8,0xe001c0,0x1c0,0x1c203ff8,0xc1801c0,0x180c,0x9801,0x1c70,0xc0000,0x8cc10000,0x180,0xfe007c0,
      0x3838,0x7980380,0xff0,0xe38,0x3e003e00,0x3e000380,0xe380e38,0xe380e38,0xe380e38,0x38e07000,0x70007000,0x70007000,0x1c001c0,
      0x1c001c0,0x70387338,0x701c701c,0x701c701c,0x701c03c0,0x731c7038,0x70387038,0x703801c0,0x703838e0,0x7fc07fc,0x7fc07fc,0x7fc07fc,
      0xe73800,0x380e380e,0x380e380e,0x1c001c0,0x1c001c0,0x381c3838,0x381c381c,0x381c381c,0x381c7ffc,0x38dc3838,0x38383838,0x38381c70,
      0x381c1c70,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1c0,0xc60,0xf83878,0x71e30000,0x70000e0,0x1007ffe,
      0x7f0,0x380,0x381c01c0,0x1e0003c,0x60e0001c,0x381c01c0,0x381c079c,0x0,0x7c000000,0x7c0380,0x63031c1c,0x70307000,0x70387000,
      0x7000701c,0x703801c0,0x7071c0,0x7000739c,0x71b8701c,0x7000701c,0x71e00078,0x1c07038,0xe703e7c,0x7e001c0,0xf000380,0x38001c0,
      0x0,0x1ffc,0x381c3800,0x381c3ffe,0x380381c,0x383801c0,0xe01fc0,0x380739c,0x3838381c,0x381c381c,0x7000ff0,0x7003838,0x1ef03bdc,
      0x3800ee0,0x1e01f00,0x180007c,0x61fc0000,0x7fc07f3c,0x1c0,0x0,0x1000100,0x1800,0x780c00,0x70707f3c,0xf007f3c,0x7f3c0000,0x0,
      0x3c0,0x3ffcffff,0x0,0xff00030,0xe1fe7f3c,0x1e001c0,0x1c0,0x1c200700,0xc183ffe,0xe0c,0x9801,0x1ff038e0,0xc07f0,0x8c610000,
      0x180,0x0,0x3838,0x1980380,0x0,0x1ff0071c,0xe000e000,0xe0000f80,0x1c1c1c1c,0x1c1c1c1c,0x1c1c1e38,0x38e07000,0x70007000,0x70007000,
      0x1c001c0,0x1c001c0,0x703871b8,0x701c701c,0x701c701c,0x701c03c0,0x761c7038,0x70387038,0x703801c0,0x70703870,0x1ffc1ffc,0x1ffc1ffc,
      0x1ffc1ffc,0xfff3800,0x3ffe3ffe,0x3ffe3ffe,0x1c001c0,0x1c001c0,0x381c3838,0x381c381c,0x381c381c,0x381c7ffc,0x389c3838,0x38383838,
      0x38380ee0,0x381c0ee0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1c0,0xfffc,0xbc60fc,0x70e30000,0x70000e0,
      0x180,0x7f0,0x700,0x381c01c0,0x3e0001c,0x7ffc001c,0x381c03c0,0x381c001c,0x0,0x1f807ffc,0x3f00380,0x63031ffc,0x70387000,0x70387000,
      0x7000701c,0x703801c0,0x7071e0,0x7000701c,0x71b8701c,0x7000701c,0x70f00038,0x1c07038,0x7e03e7c,0x77001c0,0xe000380,0x1c001c0,
      0x0,0x3c1c,0x381c3800,0x381c3ffe,0x380381c,0x383801c0,0xe01fe0,0x380739c,0x3838381c,0x381c381c,0x70003f8,0x7003838,0xee03bdc,
      0x3c00ee0,0x3c00380,0x18000e0,0xf00000,0x1c007e7c,0x3c0,0x0,0x1000100,0x0,0x381800,0x70707e7c,0xe007e7c,0x7e7c0000,0x0,0x7c0,
      0x0,0x0,0x3f80018,0xe1fe7e7c,0x3c001c0,0x1c0,0x1c200700,0xc183ffe,0xf0c,0x8c01,0x38e0,0xc07f0,0x8c710000,0x180,0x0,0x3838,
      0x1980000,0x0,0x71c,0x7000f0,0x700f00,0x1ffc1ffc,0x1ffc1ffc,0x1ffc1ffc,0x3fe07000,0x70007000,0x70007000,0x1c001c0,0x1c001c0,
      0x703871b8,0x701c701c,0x701c701c,0x701c07e0,0x7c1c7038,0x70387038,0x703801c0,0x7ff03838,0x3c1c3c1c,0x3c1c3c1c,0x3c1c3c1c,
      0x3fff3800,0x3ffe3ffe,0x3ffe3ffe,0x1c001c0,0x1c001c0,0x381c3838,0x381c381c,0x381c381c,0x381c0000,0x391c3838,0x38383838,0x38380ee0,
      0x381c0ee0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xfffc,0x9c01ce,0x70f60000,0x70000e0,0x180,
      0x0,0x700,0x381c01c0,0x780001c,0x7ffc001c,0x381c0380,0x381c003c,0x0,0x3e07ffc,0xf800380,0x63031ffc,0x70387000,0x70387000,
      0x7000701c,0x703801c0,0x7070f0,0x7000701c,0x71b8701c,0x7000701c,0x70700038,0x1c07038,0x7e03e7c,0xf7801c0,0x1e000380,0x1c001c0,
      0x0,0x381c,0x381c3800,0x381c3800,0x380381c,0x383801c0,0xe01fe0,0x380739c,0x3838381c,0x381c381c,0x7000078,0x7003838,0xee03a5c,
      0x7c00fe0,0x78001c0,0x18001c0,0x0,0x1c003ef8,0x380,0x0,0x1000100,0x810,0x383000,0x70703ef8,0x1e003ef8,0x3ef80000,0x0,0x7c0,
      0x0,0x0,0x78000c,0xe1c03ef8,0x78001c0,0x1c0,0x1c200700,0x63001c0,0x18003f8,0x4e12,0x1c70,0xc0000,0x4c320000,0x180,0x0,0x3838,
      0x1980000,0x0,0xe38,0x700118,0x701e00,0x1ffc1ffc,0x1ffc1ffc,0x1ffc1ffc,0x7fe07000,0x70007000,0x70007000,0x1c001c0,0x1c001c0,
      0x703871b8,0x701c701c,0x701c701c,0x701c0e70,0x7c1c7038,0x70387038,0x703801c0,0x7fc0381c,0x381c381c,0x381c381c,0x381c381c,
      0x78e03800,0x38003800,0x38003800,0x1c001c0,0x1c001c0,0x381c3838,0x381c381c,0x381c381c,0x381c0000,0x3b1c3838,0x38383838,0x38380fe0,
      0x381c0fe0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1860,0x9c0186,0x707e0000,0x30000c0,0x180,
      0x0,0xe00,0x183801c0,0xf00001c,0xe0001c,0x181c0380,0x381c0038,0x0,0xfc0000,0x7e000000,0x61873c1e,0x70383800,0x70707000,0x7000381c,
      0x703801c0,0x707070,0x7000701c,0x70f83838,0x70003838,0x70780038,0x1c07038,0x7e03c3c,0xe3801c0,0x1c000380,0xe001c0,0x0,0x381c,
      0x381c3800,0x381c3800,0x380381c,0x383801c0,0xe01ef0,0x380739c,0x3838381c,0x381c381c,0x7000038,0x7003838,0xfe03e7c,0xfe007c0,
      0x70001c0,0x18001c0,0x0,0xe001ff0,0x380,0x0,0x1000100,0x162c,0x381800,0x30701ff0,0x1c001ff0,0x1ff00000,0x0,0x3c0,0x0,0x0,
      0x380018,0xe1c01ff0,0x70001c0,0x1c0,0x1c200700,0xff801c0,0x18000f0,0x63e6,0xe38,0x0,0x6c3e0000,0x0,0x0,0x3838,0x1980000,0x0,
      0x1c70,0xf0000c,0xf01c00,0x3c1e3c1e,0x3c1e3c1e,0x3c1e3c1c,0x70e03800,0x70007000,0x70007000,0x1c001c0,0x1c001c0,0x707070f8,
      0x38383838,0x38383838,0x38381c38,0x38387038,0x70387038,0x703801c0,0x7000381c,0x381c381c,0x381c381c,0x381c381c,0x70e03800,
      0x38003800,0x38003800,0x1c001c0,0x1c001c0,0x381c3838,0x381c381c,0x381c381c,0x381c0380,0x3e1c3838,0x38383838,0x383807c0,0x381c07c0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x18c0,0x9c0186,0x783c0000,0x38001c0,0x180,0x3800000,
      0x3800e00,0x1c3801c0,0x1e00003c,0xe00038,0x1c1c0780,0x381c0038,0x3800380,0x3c0000,0x78000000,0x61ff380e,0x70383808,0x70707000,
      0x7000381c,0x703801c0,0x40707078,0x7000701c,0x70f83838,0x70003838,0x70384038,0x1c07038,0x7e03c3c,0x1e3c01c0,0x3c000380,0xe001c0,
      0x0,0x383c,0x3c381c00,0x1c3c1c00,0x3801c3c,0x383801c0,0xe01c78,0x380739c,0x38381c38,0x3c381c3c,0x7000038,0x7003878,0x7c01e78,
      0x1ef007c0,0xf0001c0,0x18001c0,0x0,0xe000ee0,0x7800380,0xe380000,0x1001ff0,0x2242,0x40380c00,0x38700ee0,0x3c000ee0,0xee00000,
      0x0,0x0,0x0,0x0,0x380030,0xe1c00ee0,0xf0001c0,0x1c0,0xe200700,0xdd801c0,0x1800038,0x300c,0x71c,0x0,0x300c0000,0x0,0x0,0x3838,
      0x1980000,0x0,0x38e0,0xb0000c,0xb01c08,0x380e380e,0x380e380e,0x380e380e,0x70e03808,0x70007000,0x70007000,0x1c001c0,0x1c001c0,
      0x707070f8,0x38383838,0x38383838,0x3838381c,0x38387038,0x70387038,0x703801c0,0x7000381c,0x383c383c,0x383c383c,0x383c383c,
      0x70e01c00,0x1c001c00,0x1c001c00,0x1c001c0,0x1c001c0,0x1c383838,0x1c381c38,0x1c381c38,0x1c380380,0x1c383878,0x38783878,0x387807c0,
      0x3c3807c0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1c0,0x18c0,0x10b801ce,0x3c3e0000,0x38001c0,0x180,
      0x3800000,0x3801c00,0x1e7801c0,0x3c002078,0xe02078,0x1c380700,0x1c3810f0,0x3800380,0x40000,0x40000380,0x307b380e,0x70701e18,
      0x70e07000,0x70001c1c,0x703801c0,0x60e0703c,0x7000701c,0x70f83c78,0x70003c70,0x703c70f0,0x1c03870,0x3c01c3c,0x3c1c01c0,0x78000380,
      0x7001c0,0x0,0x3c7c,0x3c381e18,0x1c7c1e0c,0x3801c3c,0x383801c0,0xe01c38,0x3c0739c,0x38381c38,0x3c381c3c,0x7001078,0x7803c78,
      0x7c01c38,0x1c780380,0x1e0001c0,0x18001c0,0x0,0x70c06c0,0x7000380,0xe300000,0x1000100,0x2142,0x70f00600,0x3c7006c0,0x780006c0,
      0x6c00000,0x0,0x0,0x0,0x0,0x10780060,0x73e206c0,0x1e0001c0,0x1c0,0x7240700,0x180c01c0,0x1800018,0x1818,0x30c,0x0,0x18180000,
      0x0,0x0,0x3c78,0x1980000,0x0,0x30c0,0x130000c,0x1301c18,0x380e380e,0x380e380e,0x380e380e,0x70e01e18,0x70007000,0x70007000,
      0x1c001c0,0x1c001c0,0x70e070f8,0x3c783c78,0x3c783c78,0x3c781008,0x7c783870,0x38703870,0x387001c0,0x70003a3c,0x3c7c3c7c,0x3c7c3c7c,
      0x3c7c3c7c,0x79f11e18,0x1e0c1e0c,0x1e0c1e0c,0x1c001c0,0x1c001c0,0x1c783838,0x1c381c38,0x1c381c38,0x1c380380,0x1c383c78,0x3c783c78,
      0x3c780380,0x3c380380,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1c0,0x38c0,0x1ff800fc,0x1fee0000,
      0x1800180,0x180,0x3800000,0x3801c00,0xff01ffc,0x3ffc3ff0,0xe03ff0,0xff00700,0x1ff81fe0,0x3800380,0x0,0x380,0x3000780f,0x7ff00ff8,
      0x7fc07ff8,0x70000ffc,0x70381ffc,0x7fe0701c,0x7ff8701c,0x70781ff0,0x70001ff0,0x701c7ff0,0x1c01fe0,0x3c01c38,0x380e01c0,0x7ffc0380,
      0x7001c0,0x0,0x1fdc,0x3ff00ff0,0xffc0ffc,0x3800fdc,0x38383ffe,0xe01c3c,0x1fc739c,0x38380ff0,0x3ff00ffc,0x7001ff0,0x3f81fb8,
      0x7c01c38,0x3c3c0380,0x1ffc01c0,0x18001c0,0x0,0x3fc0380,0x7000380,0xc70718c,0x1000100,0x2244,0x7ff00200,0x1fff0380,0x7ffc0380,
      0x3800000,0x0,0x0,0x0,0x0,0x1ff000c0,0x7f7e0380,0x1ffc01c0,0x1c0,0x3fc3ffe,0x1c0,0x1800018,0x7e0,0x104,0x0,0x7e00000,0x7ffe,
      0x0,0x3fde,0x1980000,0x0,0x2080,0x3300018,0x3300ff0,0x780f780f,0x780f780f,0x780f780e,0xf0fe0ff8,0x7ff87ff8,0x7ff87ff8,0x1ffc1ffc,
      0x1ffc1ffc,0x7fc07078,0x1ff01ff0,0x1ff01ff0,0x1ff00000,0x7ff01fe0,0x1fe01fe0,0x1fe001c0,0x70003bf8,0x1fdc1fdc,0x1fdc1fdc,
      0x1fdc1fdc,0x3fbf0ff0,0xffc0ffc,0xffc0ffc,0x3ffe3ffe,0x3ffe3ffe,0xff03838,0xff00ff0,0xff00ff0,0xff00000,0x3ff01fb8,0x1fb81fb8,
      0x1fb80380,0x3ff00380,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1c0,0x31c0,0x7e00078,0x7cf0000,0x1800180,
      0x0,0x3800000,0x3803800,0x3c01ffc,0x3ffc0fe0,0xe01fc0,0x3e00e00,0x7e00f80,0x3800380,0x0,0x380,0x18007007,0x7fc003f0,0x7f007ff8,
      0x700003f0,0x70381ffc,0x3f80701e,0x7ff8701c,0x707807c0,0x700007c0,0x701e1fc0,0x1c00fc0,0x3c01818,0x780f01c0,0x7ffc0380,0x3801c0,
      0x0,0xf9c,0x39e003e0,0x79c03f0,0x380079c,0x38383ffe,0xe01c1e,0x7c739c,0x383807e0,0x39e0079c,0x7000fc0,0x1f80f38,0x3801c38,
      0x781e0380,0x1ffc01c0,0x18001c0,0x0,0x1f80100,0xe000700,0x1c60718c,0x1000100,0x1e3c,0x1fc00100,0x7ff0100,0x7ffc0100,0x1000000,
      0x0,0x0,0x0,0x0,0xfc00080,0x3e3c0100,0x1ffc01c0,0x1c0,0xf83ffe,0x1c0,0x1800838,0x0,0x0,0x0,0x0,0x7ffe,0x0,0x3b9e,0x1980000,
      0x0,0x0,0x2300038,0x23003e0,0x70077007,0x70077007,0x70077007,0xe0fe03f0,0x7ff87ff8,0x7ff87ff8,0x1ffc1ffc,0x1ffc1ffc,0x7f007078,
      0x7c007c0,0x7c007c0,0x7c00000,0xc7c00fc0,0xfc00fc0,0xfc001c0,0x700039f0,0xf9c0f9c,0xf9c0f9c,0xf9c0f9c,0x1f1e03e0,0x3f003f0,
      0x3f003f0,0x3ffe3ffe,0x3ffe3ffe,0x7e03838,0x7e007e0,0x7e007e0,0x7e00000,0x63e00f38,0xf380f38,0xf380380,0x39e00380,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x800000,0x0,0xc00300,0x0,0x3000000,0x3800,0x0,0x0,0x0,0x0,
      0x0,0x300,0x0,0x0,0x1c000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xe0,0x0,0x0,0x0,0x0,0x380,0x3801c0,0x0,0x0,0x0,0x0,0x1c,0x0,0xe00000,
      0x0,0x0,0x3800001c,0x0,0x0,0x0,0x700,0x1c0,0x18001c0,0x0,0x0,0xe000700,0x18600000,0x1000100,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x200000,0x0,0x1800ff0,0x0,0x0,0x0,0x0,0x0,0x0,0x3800,0x1980000,0x1800000,0x0,0x6300070,0x6300000,0x0,
      0x0,0x0,0xc0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xc0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x40000000,
      0x0,0x700,0x38000700,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x800000,0x0,0xc00300,0x0,0x7000000,
      0x7000,0x0,0x0,0x0,0x0,0x0,0x700,0x0,0x0,0xf040000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x78,0x0,0x0,0x0,0x0,0x3f0,0x1c0fc0,0x0,0x0,
      0x0,0x0,0x1c,0x0,0xe00000,0x0,0x0,0x3800001c,0x0,0x0,0x0,0x700,0x1e0,0x18003c0,0x0,0x0,0xc000700,0x18c00000,0x1000000,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x200000,0x0,0x18007e0,0x0,0x0,0x0,0x0,0x0,0x0,0x3800,0x1980000,0xc00000,
      0x0,0x7f800e0,0x7f80000,0x0,0x0,0x0,0x60,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x60,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x700,0x38000700,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x800000,
      0x0,0x600600,0x0,0x6000000,0x0,0x0,0x0,0x0,0x0,0x0,0x600,0x0,0x0,0x7fc0000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x30,0x0,0x0,0x0,0x0,
      0x3f0,0xfc0,0x0,0x0,0x0,0x0,0x838,0x0,0x1e00000,0x0,0x0,0x3800001c,0x0,0x0,0x0,0xf00,0xfc,0x1801f80,0x0,0x0,0x8008e00,0x30c00000,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x200000,0x0,0x1800000,0x0,0x0,0x0,0x0,0x0,0x0,0x3800,0x1980000,0xc00000,
      0x0,0x3001c0,0x300000,0x0,0x0,0x0,0x60,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x60,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0xf00,0x38000f00,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x800000,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xfc0000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0xff0,0x0,0x1fc00000,0x0,0x0,0x3800001c,0x0,0x0,0x0,0x3e00,0x7c,0x1801f00,0x0,0x0,0x800fe00,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x200000,0x0,0x1800000,0x0,0x0,0x0,0x0,0x0,0x0,0x3800,0x0,0x7c00000,0x0,0x3001fc,0x300000,
      0x0,0x0,0x0,0x3e0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3e0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x3e00,0x38003e00,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xfff8,0x0,0x0,0x0,0x7e0,0x0,0x1f000000,
      0x0,0x0,0x3800001c,0x0,0x0,0x0,0x3c00,0x0,0x1800000,0x0,0x0,0x7800,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3800,0x0,0x7800000,0x0,0x0,0x0,0x0,0x0,0x0,0x3c0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3c0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3c00,0x38003c00,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xfff8,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1800000,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0 };

    // Define a 29x57 font (extra large size).
    const unsigned int font29x57[29*57*256/32] = {
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x781e00,0x0,0x0,0x7,0x81e00000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x7c0000,0xf8000,0x7e00000,0x0,0x7,
      0xc0000000,0x0,0x7c00,0xf80,0x7e000,0x0,0x7c00000,0xf80000,0x7e000000,0x0,0x0,0x1f00,0x3e0,0x1f800,0x0,0x0,0x0,0x3,0xe0000000,
      0x7c00003f,0x0,0xf8,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x3c3c00,0x0,0x0,0x3,0xc3c00000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3e1f00,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3e0000,
      0x1f0000,0x7e00000,0xf838001f,0xf80001f,0xf0000000,0x0,0x3e00,0x1f00,0x7e000,0x3e1f000,0x3e00000,0x1f00000,0x7e00003e,0x1f000000,
      0x3e0,0xe0000f80,0x7c0,0x1f800,0x3e0e00,0x7c3e000,0x0,0x1,0xf0000000,0xf800003f,0x1f0f,0x800001f0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1e7800,0x0,0x0,
      0x1,0xe7800000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3e1f00,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1e0000,0x1e0000,0xff00001,0xfe38001f,0xf80003f,
      0xf8000000,0x0,0x1e00,0x1e00,0xff000,0x3e1f000,0x1e00000,0x1e00000,0xff00003e,0x1f000000,0x7f8,0xe0000780,0x780,0x3fc00,0x7f8e00,
      0x7c3e000,0x0,0x0,0xf0000000,0xf000007f,0x80001f0f,0x800001e0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xef000,0x0,0x0,0x0,0xef000000,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3e1f00,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xf0000,0x3c0000,0x1e780003,0xfff8001f,0xf80003c,0x78000000,0x0,0xf00,0x3c00,0x1e7800,
      0x3e1f000,0xf00000,0x3c00001,0xe780003e,0x1f000000,0xfff,0xe00003c0,0xf00,0x79e00,0xfffe00,0x7c3e000,0x0,0x0,0x78000001,0xe00000f3,
      0xc0001f0f,0x800003c0,0x0,0x0,0x0,0x0,0x0,0x0,0x7,0xc0000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x7e000,0x0,0x0,0x0,0x7e000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x3e1f00,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x78000,0x780000,0x3c3c0003,0x8ff0001f,0xf800078,0x3c000000,0x0,0x780,0x7800,0x3c3c00,0x3e1f000,0x780000,0x7800003,0xc3c0003e,
      0x1f000000,0xe3f,0xc00001e0,0x1e00,0xf0f00,0xe3fc00,0x7c3e000,0x0,0x0,0x3c000003,0xc00001e1,0xe0001f0f,0x80000780,0x0,0x0,
      0x0,0x0,0x0,0x0,0x1f,0xf0000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x7e000,0x0,0x0,0x0,0x7e000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3e1f00,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xfc00,0x7e000,0xfe000,0x0,0x3c000,0xf00000,0x781e0003,
      0x83e0001f,0xf800070,0x1c000000,0x0,0x3c0,0xf000,0x781e00,0x3e1f000,0x3c0000,0xf000007,0x81e0003e,0x1f000000,0xe0f,0x800000f0,
      0x3c00,0x1e0780,0xe0f800,0x7c3e000,0x0,0x0,0x1e000007,0x800003c0,0xf0001f0f,0x80000f00,0x0,0x0,0x0,0x0,0x0,0x0,0x3f,0xf8000000,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3fc00,0x1fe000,0x3ff800,0x0,0x0,0x0,0x0,0x0,0x70,0x1c000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3c,0x78000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1f00000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xf80,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x78,0xf000000,0x0,0x0,0x780f0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x7c0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x3fc00,0x1fe000,0x3ffc00,0x0,0x0,0x0,0x0,0x0,0x70,0x1c000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1f00000,0x3e000,0x3e00000,0x0,0x78,0x3c000000,0x0,0x1f000,0x3e0,
      0x3e000,0x0,0x1f000000,0x3e0000,0x3e000000,0x0,0x0,0x7c00,0xf8,0xf800,0x0,0x0,0x0,0xf,0x80000000,0x1f00001f,0x0,0x3e,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x30000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xf80000,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0xf80,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x781c0000,0x38,0xe000000,0x0,0x0,0x380e0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xf80,0x0,0x0,0x0,0x0,0x0,0x0,0x39c00,0x1ce000,0x303e00,
      0x0,0x0,0x0,0x0,0x0,0x78,0x3c000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x4000,0x0,0x0,0x0,0x0,
      0x0,0x0,0xf80000,0x7c000,0x3e00000,0xf0380000,0x70,0x1c000000,0x0,0xf800,0x7c0,0x3e000,0x0,0xf800000,0x7c0000,0x3e000000,
      0x0,0x3c0,0xe0003e00,0x1f0,0xf800,0x3c0e00,0x0,0x0,0x7,0xc0000000,0x3e00001f,0x0,0x7c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x30000000,0xff,0x0,
      0xf8,0xf8000,0x1c000,0x0,0x0,0x0,0x0,0x1f,0xc0000000,0x1ff8,0xff00,0x0,0x0,0x3fe000,0x0,0x1fc00001,0xfe000000,0x0,0x0,0x0,
      0x0,0x7f800,0x0,0x0,0x0,0xff00000,0x0,0x0,0xff,0x0,0x0,0x0,0x0,0x0,0x0,0x3,0xf8000000,0xfe,0x0,0x7f80,0x0,0x0,0x0,0x0,0x0,
      0x0,0x3f,0xf0000000,0x7fe0,0x0,0x0,0x780000,0x1,0xe0000000,0x0,0x780000,0x3,0xfe000000,0x78000,0x3c00,0xf000,0x7800003,0xffe00000,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xfc0000f0,0x3f000,0x0,0x0,0x3fc00,0x0,0x0,0x1fc000,0x0,0x0,0x0,0x1fc0,
      0x0,0xff000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xfe1c0000,0x1c,0x1c000000,0x0,0x0,0x1c1c0,0x0,0x0,0x0,0x0,0x1fe0000,
      0x0,0x0,0x1ff,0x1f0f8,0x0,0xff000,0x0,0x0,0x0,0x3f,0xff00000f,0x80000000,0xfe0,0x3f80,0xf00,0x0,0x0,0x0,0x1,0xf8000003,0xe0000000,
      0x1c00,0xe000,0xe00,0x0,0x0,0x0,0x0,0x0,0x3c,0x78000000,0xff,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x7f0,0x3f80,0x1fc00,0xfe000,
      0x7f0000,0x0,0x1fc07000,0x0,0x0,0x0,0x0,0x0,0x3f800,0x780000,0x78000,0x7f00001,0xfc38001f,0xf800070,0x1c000000,0x0,0x7800,
      0x780,0x7f000,0x3e1f000,0x7800000,0x780000,0x7f00003e,0x1f0003f0,0x7f0,0xe0001e00,0x1e0,0x1fc00,0x7f0e00,0x7c3e000,0x0,0x3,
      0xc0000000,0x3c00003f,0x80001f0f,0x80000078,0x1e0000,0x3e1f00,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,0x3c1e0000,0x1e078000,0x30000000,0x3ff,0xc00001e0,0xf0,
      0x78000,0x1c000,0x0,0x0,0x0,0x0,0x1e0007f,0xf000007e,0x1ffff,0x7ffe0,0x1f80,0x3ffff80,0xfff803,0xfffff800,0xfff80007,0xff800000,
      0x0,0x0,0x0,0x0,0x1ffe00,0x0,0xfe0003,0xfff80000,0x3ffe01ff,0xe00003ff,0xffe01fff,0xff0003ff,0xe01e0007,0x803ffff0,0xfff80,
      0x3c000fc0,0x7800001f,0x8003f07e,0x1e000f,0xfe0007ff,0xf00003ff,0x8007ffe0,0x1fff8,0x7fffffe,0xf0003c1,0xe000079e,0xf1f,0x1f3e0,
      0x1f01ff,0xfff8003f,0xf003c000,0x7fe0,0x3f00,0x0,0x3c0000,0x1,0xe0000000,0x0,0x780000,0xf,0xfe000000,0x78000,0x3c00,0xf000,
      0x7800003,0xffe00000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x7,0xfc0000f0,0x3fe00,0x0,0x0,0xfff00,0x0,0x0,0x3fe000,
      0x0,0x0,0x0,0x1dc0,0x0,0x3fff00,0x0,0x3ffff80,0x1f,0xffff8000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xff1c07ff,0x3c0f001e,0x3c000000,
      0x0,0x0,0x1e3c0,0xf80007c,0x0,0x780000,0x0,0xfff8000,0x3e00,0x1f00000,0x7ff,0xc001f0f8,0x0,0x3ffc00,0x0,0x0,0x0,0x3f,0xff00003f,
      0xe0000000,0x3ff8,0xffe0,0x1e00,0x0,0xfffc00,0x0,0x7,0xf800000f,0xf8000000,0x1c00,0xe000,0xe00,0xf000,0x1fc000,0xfe0000,0x7f00000,
      0x3f800001,0xfc00003f,0xf80000ff,0xffc003ff,0xe007ffff,0xc03ffffe,0x1fffff0,0xfffff80,0x7fffe003,0xffff001f,0xfff800ff,0xffc01ffc,
      0xfc00,0x3c001ffc,0xffe0,0x7ff00,0x3ff800,0x1ffc000,0x0,0x7ff8f0f0,0x3c0780,0x1e03c00,0xf01e000,0x783e0001,0xf01e0000,0xffe00,
      0x3c0000,0xf0000,0x7700001,0xfe38001f,0xf800070,0x1c000000,0x0,0x3c00,0xf00,0x77000,0x3e1f000,0x3c00000,0xf00000,0x7700003e,
      0x1f0000f8,0xc0007f8,0xe0000f00,0x3c0,0x1dc00,0x7f8e00,0x7c3e000,0x0,0x1,0xe0000000,0x7800003b,0x80001f0f,0x800000f0,0x1e0000,
      0x3e1f00,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x780000,0x3c1e0000,0x1e070000,0x300001f0,0x7ff,0xc00001e0,0x1e0,0x7c000,0x1c000,0x0,0x0,0x0,0x0,0x3c000ff,0xf80007fe,
      0x3ffff,0x801ffff8,0x1f80,0x3ffff80,0x3fff803,0xfffff801,0xfffc000f,0xffc00000,0x0,0x0,0x0,0x0,0x7fff80,0x0,0xfe0003,0xffff0000,
      0xffff01ff,0xfc0003ff,0xffe01fff,0xff000fff,0xf01e0007,0x803ffff0,0xfff80,0x3c001f80,0x7800001f,0xc007f07e,0x1e001f,0xff0007ff,
      0xfc0007ff,0xc007fffc,0x3fffc,0x7fffffe,0xf0003c1,0xf0000f9e,0xf0f,0x8003e1e0,0x1e01ff,0xfff8003f,0xf001e000,0x7fe0,0x3f00,
      0x0,0x1e0000,0x1,0xe0000000,0x0,0x780000,0x1f,0xfe000000,0x78000,0x3c00,0xf000,0x7800003,0xffe00000,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0xf,0xfc0000f0,0x3ff00,0x0,0x0,0x1fff80,0x0,0x0,0xffe000,0x0,0x0,0x0,0x3de0,0x0,0x7fff80,0x0,0xfffff80,
      0x1f,0xffff8000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0xe7bc07ff,0x3e1f000f,0x78000000,0x0,0x0,0xf780,0x7800078,0x0,0x780000,0x180000,
      0x1fff8000,0x1e00,0x1e0003c,0xfff,0xc001f0f8,0x0,0x7ffe00,0x0,0x0,0x0,0x3f,0xff00007f,0xf0000000,0x3ffc,0xfff0,0x3c00,0x0,
      0x7fffc00,0x0,0x7,0xf800003f,0xfe000000,0x1c00,0xe000,0xe00,0xf000,0x1fc000,0xfe0000,0x7f00000,0x3f800001,0xfc00001f,0xe00001ff,
      0xffc00fff,0xf007ffff,0xc03ffffe,0x1fffff0,0xfffff80,0x7fffe003,0xffff001f,0xfff800ff,0xffc01fff,0xc000fc00,0x3c003ffe,0x1fff0,
      0xfff80,0x7ffc00,0x3ffe000,0x0,0xfffce0f0,0x3c0780,0x1e03c00,0xf01e000,0x781e0001,0xe01e0000,0x3fff00,0x1e0000,0x1e0000,0xf780003,
      0xcf78001f,0xf800078,0x3c000000,0x0,0x1e00,0x1e00,0xf7800,0x3e1f000,0x1e00000,0x1e00000,0xf780003e,0x1f0000fc,0x7c000f3d,
      0xe0000780,0x780,0x3de00,0xf3de00,0x7c3e000,0x0,0x0,0xf0000000,0xf000007b,0xc0001f0f,0x800001e0,0x1e0000,0x3e1f00,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,
      0x3c1e0000,0x1e0f0000,0x300007fc,0xfff,0xc00001e0,0x1e0,0x3c000,0x1c000,0x0,0x0,0x0,0x0,0x3c001ff,0xfc001ffe,0x3ffff,0xc01ffffc,
      0x3f80,0x3ffff80,0x7fff803,0xfffff803,0xfffe001f,0xffe00000,0x0,0x0,0x0,0x0,0xffff80,0x7f800,0xfe0003,0xffff8001,0xffff01ff,
      0xff0003ff,0xffe01fff,0xff001fff,0xf01e0007,0x803ffff0,0xfff80,0x3c003f00,0x7800001f,0xc007f07f,0x1e003f,0xff8007ff,0xff000fff,
      0xe007ffff,0x7fffc,0x7fffffe,0xf0003c0,0xf0000f1e,0xf07,0x8003c1f0,0x3e01ff,0xfff8003f,0xf001e000,0x7fe0,0x7f80,0x0,0xe0000,
      0x1,0xe0000000,0x0,0x780000,0x1f,0xfe000000,0x78000,0x3c00,0xf000,0x7800003,0xffe00000,0x0,0x0,0x0,0x0,0x0,0x0,0x3c000,0x0,
      0x0,0x0,0x0,0x0,0xf,0xfc0000f0,0x3ff00,0x0,0x0,0x3fff80,0x0,0x0,0xffe000,0x0,0x0,0x0,0x78f0,0x0,0xffff80,0x0,0x3fffff80,0x1f,
      0xffff8000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0xc7f80070,0x3e1f0007,0x70000000,0x0,0x0,0x7700,0x7c000f8,0x0,0x780000,0x180000,
      0x3fff8000,0x1f00,0x3e0003c,0x1f03,0xc001f0f8,0x0,0x703f00,0x0,0x0,0x0,0x3f,0xff0000f0,0xf8000000,0x303e,0xc0f8,0x7800,0x0,
      0xffffc00,0x0,0x7,0x3800003e,0x3e000000,0x1c00,0xe000,0x3c00,0xf000,0x1fc000,0xfe0000,0x7f00000,0x3f800001,0xfc00000f,0xe00001ff,
      0xffc01fff,0xf007ffff,0xc03ffffe,0x1fffff0,0xfffff80,0x7fffe003,0xffff001f,0xfff800ff,0xffc01fff,0xf000fe00,0x3c007fff,0x3fff8,
      0x1fffc0,0xfffe00,0x7fff000,0x1,0xffffc0f0,0x3c0780,0x1e03c00,0xf01e000,0x781f0003,0xe01e0000,0x3fff80,0xe0000,0x3c0000,0x1e3c0003,
      0x8ff0001f,0xf80003c,0x78000000,0x0,0xe00,0x3c00,0x1e3c00,0x3e1f000,0xe00000,0x3c00001,0xe3c0003e,0x1f00007f,0xf8000e3f,0xc0000380,
      0xf00,0x78f00,0xe3fc00,0x7c3e000,0x0,0x0,0x70000001,0xe00000f1,0xe0001f0f,0x800003c0,0x1e0000,0x3e1f00,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,0x3c1e0000,0x3c0f0000,
      0x30000ffe,0xf80,0xc00001e0,0x3c0,0x1e000,0x101c040,0x0,0x0,0x0,0x0,0x78003f0,0x7e001ffe,0x3f807,0xe01f00fe,0x3f80,0x3ffff80,
      0x7e01803,0xfffff007,0xe03f003f,0x3f00000,0x0,0x0,0x0,0x0,0xfc0fc0,0x3ffe00,0xfe0003,0xffffc003,0xf81f01ff,0xff8003ff,0xffe01fff,
      0xff003f01,0xf01e0007,0x803ffff0,0xfff80,0x3c007e00,0x7800001f,0xc007f07f,0x1e007e,0xfc007ff,0xff801f83,0xf007ffff,0x800fc07c,
      0x7fffffe,0xf0003c0,0xf0000f0f,0x1e07,0xc007c0f8,0x7c01ff,0xfff8003c,0xf000,0x1e0,0xffc0,0x0,0xf0000,0x1,0xe0000000,0x0,0x780000,
      0x3e,0x0,0x78000,0x3c00,0xf000,0x7800000,0x1e00000,0x0,0x0,0x0,0x0,0x0,0x0,0x3c000,0x0,0x0,0x0,0x0,0x0,0x1f,0x800000f0,0x1f80,
      0x0,0x0,0x7e0780,0x0,0x0,0x1f82000,0x0,0x0,0x0,0x7070,0x0,0x1f80f80,0x0,0x7fffff80,0x1f,0xffff8000,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x1,0xc3f80070,0x3f3f0007,0xf0000000,0x0,0x0,0x7f00,0x3e001f0,0x0,0x780000,0x180000,0x7f018000,0xf80,0x7c0003c,0x3e00,
      0x4001f0f8,0xfe00,0x400f00,0x0,0x0,0x0,0x7f000000,0xe0,0x38000000,0x1e,0x38,0x7800,0x0,0x1ffe1c00,0x0,0x0,0x38000078,0xf000000,
      0x1c00,0xe000,0x7f800,0xf000,0x1fc000,0xfe0000,0x7f00000,0x3f800001,0xfc00001f,0xf00001ff,0xffc03f81,0xf007ffff,0xc03ffffe,
      0x1fffff0,0xfffff80,0x7fffe003,0xffff001f,0xfff800ff,0xffc01fff,0xf800fe00,0x3c00fc1f,0x8007e0fc,0x3f07e0,0x1f83f00,0xfc1f800,
      0x3,0xf07fc0f0,0x3c0780,0x1e03c00,0xf01e000,0x780f8007,0xc01e0000,0x7e0fc0,0xf0000,0x3c0000,0x1c1c0003,0x87f0001f,0xf80003f,
      0xf8000000,0x0,0xf00,0x3c00,0x1c1c00,0x3e1f000,0xf00000,0x3c00001,0xc1c0003e,0x1f00003f,0xc0000e1f,0xc00003c0,0xf00,0x70700,
      0xe1fc00,0x7c3e000,0x0,0x0,0x78000001,0xe00000e0,0xe0001f0f,0x800003c0,0x1e0000,0x3e1f00,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,0x3c1e0000,0x3c0f0001,0xff801e0f,
      0x1f00,0x1e0,0x3c0,0x1e000,0x3c1c1e0,0x0,0x0,0x0,0x0,0x78007c0,0x1f001f9e,0x3c001,0xf010003e,0x7780,0x3c00000,0xf800000,0xf007,
      0xc01f007c,0x1f80000,0x0,0x0,0x0,0x0,0xe003e0,0x7fff00,0x1ef0003,0xc007e007,0xc00301e0,0x1fc003c0,0x1e00,0x7c00,0x301e0007,
      0x80007800,0x780,0x3c00fc00,0x7800001f,0xe00ff07f,0x1e00f8,0x3e00780,0x1fc03e00,0xf807801f,0xc01f001c,0xf000,0xf0003c0,0xf0000f0f,
      0x1e03,0xc00f8078,0x780000,0xf0003c,0xf000,0x1e0,0x1f3e0,0x0,0x78000,0x1,0xe0000000,0x0,0x780000,0x3c,0x0,0x78000,0x0,0x0,
      0x7800000,0x1e00000,0x0,0x0,0x0,0x0,0x0,0x0,0x3c000,0x0,0x0,0x0,0x0,0x0,0x1f,0xf0,0xf80,0x0,0x0,0xf80180,0x0,0x0,0x1e00000,
      0x0,0x0,0x0,0xe038,0x0,0x3e00380,0x0,0xfe0f0000,0x0,0xf0000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0xc0f00070,0x3b370003,0xe0000000,
      0x0,0x0,0x3e00,0x1e001e0,0x0,0x780000,0x180000,0x7c000000,0x780,0x780003c,0x3c00,0x0,0x7ffc0,0x780,0x0,0x0,0x3,0xffe00000,
      0x1c0,0x3c000000,0xe,0x38,0xf000,0x0,0x3ffe1c00,0x0,0x0,0x38000078,0xf000000,0x1c00,0xe000,0x7f000,0xf000,0x3de000,0x1ef0000,
      0xf780000,0x7bc00003,0xde00001e,0xf00003e7,0x80007c00,0x30078000,0x3c0000,0x1e00000,0xf000000,0xf00000,0x7800000,0x3c000001,
      0xe0001e03,0xfc00fe00,0x3c01f007,0xc00f803e,0x7c01f0,0x3e00f80,0x1f007c00,0x7,0xc01f80f0,0x3c0780,0x1e03c00,0xf01e000,0x78078007,
      0x801e0000,0x7803c0,0x78000,0x780000,0x380e0003,0x81e00000,0x1f,0xf0000000,0x0,0x780,0x7800,0x380e00,0x0,0x780000,0x7800003,
      0x80e00000,0x1ff,0x80000e07,0x800001e0,0x1e00,0xe0380,0xe07800,0x0,0x0,0x0,0x3c000003,0xc00001c0,0x70000000,0x780,0x1e0000,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x780000,0x3c1e0000,0x3c0e0007,0xfff01c07,0x1e00,0x1e0,0x780,0xf000,0x3e1c3e0,0x0,0x0,0x0,0x0,0xf0007c0,0x1f00181e,0x20000,
      0xf000001f,0xf780,0x3c00000,0x1f000000,0x1f00f,0x800f8078,0xf80000,0x0,0x0,0x0,0x0,0x8003e0,0x1fc0f80,0x1ef0003,0xc001e007,
      0x800101e0,0x7e003c0,0x1e00,0x7800,0x101e0007,0x80007800,0x780,0x3c00f800,0x7800001e,0xe00ef07f,0x801e00f0,0x1e00780,0x7c03c00,
      0x78078007,0xc01e0004,0xf000,0xf0003c0,0x78001e0f,0x1e03,0xe00f807c,0xf80000,0x1f0003c,0x7800,0x1e0,0x3e1f0,0x0,0x3c000,0x1,
      0xe0000000,0x0,0x780000,0x3c,0x0,0x78000,0x0,0x0,0x7800000,0x1e00000,0x0,0x0,0x0,0x0,0x0,0x0,0x3c000,0x0,0x0,0x0,0x0,0x0,
      0x1e,0xf0,0x780,0x0,0x0,0x1f00080,0x0,0x0,0x3c00000,0x0,0x0,0x0,0x1e03c,0x0,0x3c00080,0x0,0xf80f0000,0x0,0x1f0000,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x70,0x3bf70003,0xe0000000,0x0,0x0,0x3e00,0x1f003e0,0x0,0x780000,0x180000,0x78000000,0x7c0,0xf80003c,
      0x3c00,0x0,0x1f01f0,0x780,0x0,0x0,0xf,0x80f80000,0x1c0,0x1c000000,0xe,0x38,0x1e000,0x0,0x7ffe1c00,0x0,0x0,0x380000f0,0x7800000,
      0x1c00,0xe000,0x7fc00,0xf000,0x3de000,0x1ef0000,0xf780000,0x7bc00003,0xde00001e,0xf00003c7,0x80007800,0x10078000,0x3c0000,
      0x1e00000,0xf000000,0xf00000,0x7800000,0x3c000001,0xe0001e00,0x7e00ff00,0x3c01e003,0xc00f001e,0x7800f0,0x3c00780,0x1e003c00,
      0x7,0x800f00f0,0x3c0780,0x1e03c00,0xf01e000,0x7807c00f,0x801e0000,0xf803c0,0x3c000,0xf00000,0x780f0000,0x0,0x7,0xc0000000,
      0x0,0x3c0,0xf000,0x780f00,0x0,0x3c0000,0xf000007,0x80f00000,0x7ff,0xc0000000,0xf0,0x3c00,0x1e03c0,0x0,0x0,0x0,0x0,0x1e000007,
      0x800003c0,0x78000000,0xf00,0x1e0000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,0x3c1e0000,0x3c1e001f,0xfff03803,0x80001e00,0x1e0,0x780,0xf000,0xf9cf80,
      0x0,0x0,0x0,0x0,0xf000780,0xf00001e,0x0,0xf800000f,0xe780,0x3c00000,0x1e000000,0x1e00f,0x78078,0x7c0000,0x0,0x0,0x0,0x0,0x1e0,
      0x3f003c0,0x1ef0003,0xc000f00f,0x800001e0,0x1f003c0,0x1e00,0xf000,0x1e0007,0x80007800,0x780,0x3c01f000,0x7800001e,0xe00ef07f,
      0x801e01f0,0x1e00780,0x3c07c00,0x78078003,0xc03e0000,0xf000,0xf0003c0,0x78001e0f,0x1e01,0xf01f003c,0xf00000,0x3e0003c,0x7800,
      0x1e0,0x7c0f8,0x0,0x0,0x1,0xe0000000,0x0,0x780000,0x3c,0x0,0x78000,0x0,0x0,0x7800000,0x1e00000,0x0,0x0,0x0,0x0,0x0,0x0,0x3c000,
      0x0,0x0,0x0,0x0,0x0,0x1e,0xf0,0x780,0x0,0x0,0x1e00000,0x0,0x0,0x3c00000,0x0,0x8,0x40,0x0,0x7e0000,0x7c00000,0x1,0xf00f0000,
      0x0,0x3e0000,0x0,0x3f,0xfc0,0xfc3f0,0xfc3f0,0x0,0x0,0x0,0x70,0x39e70000,0x0,0x0,0x0,0x0,0xf003c0,0x0,0x0,0x180000,0xf8000000,
      0x3c0,0xf00003c,0x3c00,0x0,0x3c0078,0x7ff80,0x0,0x0,0x1e,0x3c0000,0x1c0,0x1c000000,0xe,0xf0,0x0,0x0,0x7ffe1c00,0x0,0x0,0x380000f0,
      0x7800000,0x1c00,0xe000,0x3c00,0x0,0x3de000,0x1ef0000,0xf780000,0x7bc00003,0xde00001e,0xf00003c7,0x8000f800,0x78000,0x3c0000,
      0x1e00000,0xf000000,0xf00000,0x7800000,0x3c000001,0xe0001e00,0x1f00ff00,0x3c03e003,0xc01f001e,0xf800f0,0x7c00780,0x3e003c00,
      0xf,0x800f80f0,0x3c0780,0x1e03c00,0xf01e000,0x7803c00f,0x1fffc0,0xf001e0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x307,0xe0000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1e0000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,0x3c1e0000,0x781e003f,0xfff03803,
      0x80001e00,0x1e0,0xf80,0xf000,0x3dde00,0x0,0x0,0x0,0x0,0xf000f00,0x780001e,0x0,0x7800000f,0x1e780,0x3c00000,0x3e000000,0x3e00f,
      0x780f0,0x7c0000,0x0,0x0,0x0,0x0,0x1e0,0x7c001e0,0x3ef8003,0xc000f00f,0x1e0,0xf003c0,0x1e00,0xf000,0x1e0007,0x80007800,0x780,
      0x3c03e000,0x7800001e,0xf01ef07b,0xc01e01e0,0xf00780,0x3e07800,0x3c078003,0xe03c0000,0xf000,0xf0003c0,0x78001e0f,0x1e00,0xf01e003e,
      0x1f00000,0x3c0003c,0x7800,0x1e0,0x78078,0x0,0x0,0x1,0xe0000000,0x0,0x780000,0x3c,0x0,0x78000,0x0,0x0,0x7800000,0x1e00000,
      0x0,0x0,0x0,0x0,0x0,0x0,0x3c000,0x0,0x0,0x0,0x0,0x0,0x1e,0xf0,0x780,0x0,0x0,0x1e00000,0x0,0x0,0x3c00000,0x0,0x18,0xc0,0x0,
      0xe70000,0x7800000,0x1,0xe00f0000,0x0,0x3c0000,0x0,0x3f,0xfc0,0xfc1f0,0x1f83f0,0x0,0x0,0x0,0x70,0x39e70000,0x0,0x0,0x0,0x0,
      0xf807c0,0x0,0x0,0x180000,0xf0000000,0x3e0,0x1f00003c,0x3e00,0x0,0x70001c,0x3fff80,0x0,0x0,0x38,0xe0000,0x1c0,0x1c000078,
      0x1c,0x1fe0,0x0,0x0,0xfffe1c00,0x0,0x0,0x380000f0,0x7800000,0x1c00,0xe000,0xe00,0x0,0x7df000,0x3ef8000,0x1f7c0000,0xfbe00007,
      0xdf00003c,0x780003c7,0x8000f000,0x78000,0x3c0000,0x1e00000,0xf000000,0xf00000,0x7800000,0x3c000001,0xe0001e00,0xf00f780,
      0x3c03c001,0xe01e000f,0xf00078,0x78003c0,0x3c001e00,0xf,0xf80f0,0x3c0780,0x1e03c00,0xf01e000,0x7803e01f,0x1ffff8,0xf001e0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3,0xe0000000,0x0,0x0,0x0,0x0,0x0,0x0,0xc000,0x0,0x0,0x0,0x0,0x1e0000,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x780000,0x3c1e0000,0x781e003e,0x30703803,0x80001e00,0x1e0,0xf00,0x7800,0xff800,0x1e0000,0x0,0x0,0x0,0x1e000f00,0x780001e,
      0x0,0x7800000f,0x3c780,0x3c00000,0x3c000000,0x3c00f,0x780f0,0x3c0000,0x0,0x0,0x2000000,0x800000,0x1e0,0x78000e0,0x3c78003,
      0xc000f01e,0x1e0,0xf803c0,0x1e00,0x1e000,0x1e0007,0x80007800,0x780,0x3c07c000,0x7800001e,0x701cf07b,0xc01e01e0,0xf00780,0x1e07800,
      0x3c078001,0xe03c0000,0xf000,0xf0003c0,0x7c003e0f,0x1e00,0xf83e001e,0x1e00000,0x7c0003c,0x3c00,0x1e0,0xf807c,0x0,0x0,0x1fe0001,
      0xe1fc0000,0x7f00003,0xf8780007,0xf000003c,0x7f0,0x783f0,0x0,0x0,0x7800000,0x1e00000,0x3e0f8000,0xfc00007,0xf8000007,0xf00001fc,
      0xf,0xc0003fc0,0x3c000,0x0,0x0,0x0,0x0,0x0,0x1e,0xf0,0x780,0x0,0x0,0x3c00000,0x0,0x0,0x3c00000,0x0,0x18,0xc0,0x0,0x1818000,
      0x7800000,0x1,0xe00f0000,0x0,0x7c0000,0x0,0x1f,0x80001f80,0x7c1f8,0x1f83e0,0x0,0x0,0x0,0x70,0x38c70007,0xf8000000,0x7f03,
      0xf0000000,0x0,0x780780,0x0,0x0,0xfe0000,0xf0000000,0x1e0,0x1e00003c,0x3f00,0x0,0xe07f0e,0x7fff80,0x0,0x0,0x70,0x70000,0x1c0,
      0x1c000078,0x3c,0x1fc0,0x0,0x0,0xfffe1c00,0x0,0x0,0x380000f0,0x7800000,0x1c00,0xe000,0xe00,0x0,0x78f000,0x3c78000,0x1e3c0000,
      0xf1e00007,0x8f00003c,0x78000787,0x8001e000,0x78000,0x3c0000,0x1e00000,0xf000000,0xf00000,0x7800000,0x3c000001,0xe0001e00,
      0xf80f780,0x3c03c001,0xe01e000f,0xf00078,0x78003c0,0x3c001e00,0xf,0x1f80f0,0x3c0780,0x1e03c00,0xf01e000,0x7801e01e,0x1ffffc,
      0xf007e0,0x3fc000,0x1fe0000,0xff00000,0x7f800003,0xfc00001f,0xe0000fc0,0xfc00007f,0xfe0,0x7f00,0x3f800,0x1fc000,0x0,0x0,0x0,
      0x1,0xf000001f,0x80000ff0,0x7f80,0x3fc00,0x1fe000,0xff0000,0x1f80000,0x1fc1e000,0x0,0x0,0x0,0x0,0x1e1fc0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,0x3c1e0000,
      0x781c007c,0x30003803,0x80001f00,0x1e0,0xf00,0x7800,0x7f000,0x1e0000,0x0,0x0,0x0,0x1e000f00,0x780001e,0x0,0x7800000f,0x3c780,
      0x3c00000,0x3c000000,0x3c00f,0x780f0,0x3c0000,0x0,0x0,0x1e000000,0xf00000,0x3e0,0xf0000e0,0x3c78003,0xc000f01e,0x1e0,0x7803c0,
      0x1e00,0x1e000,0x1e0007,0x80007800,0x780,0x3c0f8000,0x7800001e,0x701cf079,0xe01e01e0,0xf00780,0x1e07800,0x3c078001,0xe03c0000,
      0xf000,0xf0003c0,0x3c003c0f,0x3e00,0x787c001f,0x3e00000,0xf80003c,0x3c00,0x1e0,0x1f003e,0x0,0x0,0x1fffc001,0xe7ff0000,0x3ffe000f,
      0xfe78003f,0xfc001fff,0xfe001ffc,0xf0078ffc,0x1ffc00,0x7ff000,0x7800f80,0x1e0000f,0x7f1fc01e,0x3ff0001f,0xfe00079f,0xfc0007ff,
      0x3c003c7f,0xf001fff8,0x1fffff0,0x3c003c0,0xf0000f1e,0xf1f,0x7c1f0,0x1f00ff,0xffe0001e,0xf0,0x780,0x0,0x0,0x3c00000,0x100000,
      0x0,0x7800000,0x0,0x18,0xc0,0x0,0x1818000,0x7800000,0x1,0xe00f0000,0x1000000,0xf80000,0x40000002,0xf,0x80001f00,0x7e0f8,0x1f07c0,
      0x0,0x0,0x0,0x70,0x38c7003f,0xff000000,0xff8f,0xf8000100,0xffffe,0x7c0f80,0x0,0x0,0x3ffc000,0xf0000020,0x1001f0,0x3c00003c,
      0x1f80,0x0,0x1c3ffc7,0x7c0780,0x0,0x0,0xe3,0xff038000,0xe0,0x38000078,0x78,0x1ff0,0x0,0x3c003c0,0xfffe1c00,0x0,0x0,0x380000f0,
      0x7800000,0x1c00,0xe000,0xe00,0xf000,0x78f000,0x3c78000,0x1e3c0000,0xf1e00007,0x8f00003c,0x78000787,0x8001e000,0x78000,0x3c0000,
      0x1e00000,0xf000000,0xf00000,0x7800000,0x3c000001,0xe0001e00,0x780f3c0,0x3c03c001,0xe01e000f,0xf00078,0x78003c0,0x3c001e00,
      0x4000200f,0x3f80f0,0x3c0780,0x1e03c00,0xf01e000,0x7801f03e,0x1ffffe,0xf01fe0,0x3fff800,0x1fffc000,0xfffe0007,0xfff0003f,
      0xff8001ff,0xfc003ff3,0xfe0003ff,0xe0007ff8,0x3ffc0,0x1ffe00,0xfff000,0x3ff80001,0xffc0000f,0xfe00007f,0xf000003f,0xf8003c7f,
      0xe0003ffc,0x1ffe0,0xfff00,0x7ff800,0x3ffc000,0x1f80000,0xfff1c03c,0x3c01e0,0x1e00f00,0xf007800,0x781f0001,0xf01e7ff0,0x7c0007c,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,
      0x3c1e003f,0xfffff078,0x30003803,0x80000f00,0x1e0,0x1f00,0x7800,0x7f000,0x1e0000,0x0,0x0,0x0,0x3c000f00,0x780001e,0x0,0x7800000f,
      0x78780,0x3c00000,0x3c000000,0x7c00f,0x780f0,0x3c0007,0xe000003f,0x0,0xfe000000,0xfe0000,0x3c0,0x1f000070,0x7c7c003,0xc000f01e,
      0x1e0,0x7803c0,0x1e00,0x1e000,0x1e0007,0x80007800,0x780,0x3c1f0000,0x7800001e,0x783cf079,0xe01e03c0,0xf00780,0x1e0f000,0x3c078001,
      0xe03c0000,0xf000,0xf0003c0,0x3c003c07,0x81f03c00,0x7c7c000f,0x87c00000,0xf00003c,0x1e00,0x1e0,0x3e001f,0x0,0x0,0x3fffe001,
      0xefff8000,0x7fff001f,0xff78007f,0xfe001fff,0xfe003ffe,0xf0079ffe,0x1ffc00,0x7ff000,0x7801f00,0x1e0000f,0xffbfe01e,0x7ff8003f,
      0xff0007bf,0xfe000fff,0xbc003cff,0xf803fffc,0x1fffff0,0x3c003c0,0x78001e1e,0xf0f,0x800f80f0,0x1e00ff,0xffe0001e,0xf0,0x780,
      0x0,0x0,0x3c00000,0x380000,0x0,0x7800000,0x0,0x18,0xc0,0x0,0x1008000,0x7800000,0x3,0xe00f0000,0x3800000,0xf00000,0xe0000007,
      0xf,0x80001f00,0x3e0f8,0x1e07c0,0x0,0x0,0x0,0x70,0x3807007f,0xff800000,0x1ffdf,0xfc000380,0xffffe,0x3e1f00,0x0,0x0,0xfffe000,
      0xf0000030,0x3800f8,0x7c00003c,0xfc0,0x0,0x18780c3,0xf00780,0x80100,0x0,0xc3,0xffc18000,0xf0,0x78000078,0xf0,0xf0,0x0,0x3c003c0,
      0xfffe1c00,0x0,0x0,0x380000f0,0x7800801,0x1c00,0xe000,0x1e00,0xf000,0xf8f800,0x7c7c000,0x3e3e0001,0xf1f0000f,0x8f80007c,0x7c000787,
      0x8001e000,0x78000,0x3c0000,0x1e00000,0xf000000,0xf00000,0x7800000,0x3c000001,0xe0001e00,0x780f3c0,0x3c078001,0xe03c000f,
      0x1e00078,0xf0003c0,0x78001e00,0xe000701f,0x3fc0f0,0x3c0780,0x1e03c00,0xf01e000,0x7800f87c,0x1e007f,0xf07e00,0x7fffc00,0x3fffe001,
      0xffff000f,0xfff8007f,0xffc003ff,0xfe007ff7,0xff0007ff,0xf000fffc,0x7ffe0,0x3fff00,0x1fff800,0x3ff80001,0xffc0000f,0xfe00007f,
      0xf00000ff,0xf8003cff,0xf0007ffe,0x3fff0,0x1fff80,0xfffc00,0x7ffe000,0x1f80001,0xfffb803c,0x3c01e0,0x1e00f00,0xf007800,0x780f0001,
      0xe01efff8,0x3c00078,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x780000,0x3c1e003f,0xfffff078,0x30001c07,0xf80,0x1e0,0x1e00,0x3c00,0xff800,0x1e0000,0x0,0x0,0x0,0x3c001e00,
      0x3c0001e,0x0,0x7800001e,0x70780,0x3c00000,0x78000000,0x78007,0x800f00f0,0x3e0007,0xe000003f,0x3,0xfe000000,0xff8000,0x7c0,
      0x1e000070,0x783c003,0xc001f01e,0x1e0,0x7803c0,0x1e00,0x1e000,0x1e0007,0x80007800,0x780,0x3c3e0000,0x7800001e,0x3838f079,
      0xe01e03c0,0x780780,0x1e0f000,0x1e078001,0xe03c0000,0xf000,0xf0003c0,0x3c007c07,0x81f03c00,0x3ef80007,0x87800000,0x1f00003c,
      0x1e00,0x1e0,0x7c000f,0x80000000,0x0,0x3ffff001,0xffffc000,0xffff003f,0xff7800ff,0xff001fff,0xfe007ffe,0xf007bffe,0x1ffc00,
      0x7ff000,0x7803e00,0x1e0000f,0xffffe01e,0xfff8007f,0xff8007ff,0xff001fff,0xbc003dff,0xf807fffc,0x1fffff0,0x3c003c0,0x78001e0f,
      0x1e07,0xc01f00f0,0x1e00ff,0xffe0001e,0xf0,0x780,0x0,0x0,0x7c00000,0x7c0000,0x0,0x7800000,0x0,0x18,0xc0,0x0,0x1018000,0x7800000,
      0x3,0xc00f0000,0x7c00000,0x1f00001,0xf000000f,0x80000007,0xc0003e00,0x1e07c,0x3e0780,0x0,0x0,0x0,0x70,0x380700ff,0xff800000,
      0x3ffff,0xfe0007c0,0xffffe,0x1e1e00,0x0,0x780000,0x1fffe000,0xf0000078,0x7c0078,0x7800003c,0xff0,0x0,0x38e0003,0x80f00780,
      0x180300,0x0,0x1c3,0x81e1c000,0x7f,0xf0000078,0x1e0,0x38,0x0,0x3c003c0,0xfffe1c00,0x0,0x0,0x380000f0,0x7800c01,0x80001c00,
      0xe000,0x603e00,0xf000,0xf07800,0x783c000,0x3c1e0001,0xe0f0000f,0x7800078,0x3c000f87,0x8001e000,0x78000,0x3c0000,0x1e00000,
      0xf000000,0xf00000,0x7800000,0x3c000001,0xe0001e00,0x780f3c0,0x3c078000,0xf03c0007,0x81e0003c,0xf0001e0,0x78000f01,0xf000f81e,
      0x7bc0f0,0x3c0780,0x1e03c00,0xf01e000,0x78007878,0x1e001f,0xf0f800,0x7fffe00,0x3ffff001,0xffff800f,0xfffc007f,0xffe003ff,
      0xff007fff,0xff800fff,0xf001fffe,0xffff0,0x7fff80,0x3fffc00,0x3ff80001,0xffc0000f,0xfe00007f,0xf00001ff,0xfc003dff,0xf000ffff,
      0x7fff8,0x3fffc0,0x1fffe00,0xffff000,0x1f80003,0xffff803c,0x3c01e0,0x1e00f00,0xf007800,0x780f0001,0xe01ffffc,0x3c00078,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,
      0x3c1e003f,0xfffff078,0x30001e0f,0x300780,0x1e0,0x1e00,0x3c00,0x3dde00,0x1e0000,0x0,0x0,0x0,0x78001e00,0x3c0001e,0x0,0xf800003e,
      0xf0780,0x3dfc000,0x783f8000,0xf8007,0xc01f00f0,0x3e0007,0xe000003f,0x1f,0xfc000000,0x7ff000,0xf80,0x3e007c70,0x783c003,0xc001e03c,
      0x1e0,0x3c03c0,0x1e00,0x3c000,0x1e0007,0x80007800,0x780,0x3c7c0000,0x7800001e,0x3878f078,0xf01e03c0,0x780780,0x1e0f000,0x1e078001,
      0xe03e0000,0xf000,0xf0003c0,0x1e007807,0x83f03c00,0x3ef00007,0xcf800000,0x3e00003c,0xf00,0x1e0,0xf80007,0xc0000000,0x0,0x3e01f801,
      0xfe07e001,0xf80f007e,0x7f801f8,0x1f801fff,0xfe00fc0f,0xf007f83f,0x1ffc00,0x7ff000,0x7807c00,0x1e0000f,0x87e1e01f,0xe0fc00fc,
      0xfc007f8,0x1f803f03,0xfc003df0,0x3807e03c,0x1fffff0,0x3c003c0,0x78003e0f,0x1e03,0xe03e00f8,0x3e00ff,0xffe0001e,0xf0,0x780,
      0x0,0x0,0x7800000,0xfe0000,0x0,0x7800000,0x0,0x18,0xc0,0x0,0x1818000,0x7c00000,0x3,0xc00f0000,0xfe00000,0x3e00003,0xf800001f,
      0xc0000007,0xc0003e00,0x1e03c,0x3c0f80,0x0,0x0,0x0,0x70,0x380700fc,0x7800000,0x7c1fe,0x3e000fe0,0xffffe,0x1f3e00,0x0,0x780000,
      0x3f98e000,0xf000003c,0xfcf8007c,0xf800003c,0x3ffc,0x0,0x31c0001,0x80f00f80,0x380700,0x0,0x183,0x80e0c000,0x3f,0xe0000078,
      0x3c0,0x38,0x0,0x3c003c0,0xfffe1c00,0x0,0x0,0x38000078,0xf000e01,0xc003ffe0,0x1fff00,0x7ffc00,0xf000,0xf07800,0x783c000,0x3c1e0001,
      0xe0f0000f,0x7800078,0x3c000f07,0x8003c000,0x78000,0x3c0000,0x1e00000,0xf000000,0xf00000,0x7800000,0x3c000001,0xe0001e00,
      0x3c0f1e0,0x3c078000,0xf03c0007,0x81e0003c,0xf0001e0,0x78000f00,0xf801f01e,0xf3c0f0,0x3c0780,0x1e03c00,0xf01e000,0x78007cf8,
      0x1e000f,0x80f0f000,0x7c03f00,0x3e01f801,0xf00fc00f,0x807e007c,0x3f003e0,0x1f80707f,0x8f801f80,0xf003f03f,0x1f81f8,0xfc0fc0,
      0x7e07e00,0x3ff80001,0xffc0000f,0xfe00007f,0xf00003ff,0xfc003fc1,0xf801f81f,0x800fc0fc,0x7e07e0,0x3f03f00,0x1f81f800,0x1f80007,
      0xe07f003c,0x3c01e0,0x1e00f00,0xf007800,0x780f8003,0xe01fe07e,0x3e000f8,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,0x3f,0xfffff078,0x30000ffe,0x1f007c0,0x0,0x1e00,
      0x3c00,0xf9cf80,0x1e0000,0x0,0x0,0x0,0x78001e00,0x3c0001e,0x0,0xf00000fc,0x1e0780,0x3fff800,0x78ffe000,0xf0003,0xe03e00f0,
      0x3e0007,0xe000003f,0x7f,0xe01fffff,0xf00ffc00,0x1f80,0x3c01ff70,0x783c003,0xc007e03c,0x1e0,0x3c03c0,0x1e00,0x3c000,0x1e0007,
      0x80007800,0x780,0x3cfc0000,0x7800001e,0x3c78f078,0xf01e03c0,0x780780,0x3e0f000,0x1e078003,0xc01f0000,0xf000,0xf0003c0,0x1e007807,
      0x83f83c00,0x1ff00003,0xcf000000,0x3e00003c,0xf00,0x1e0,0x0,0x0,0x0,0x20007801,0xfc03e003,0xe003007c,0x3f803e0,0x7c0003c,
      0xf807,0xf007e00f,0x3c00,0xf000,0x780f800,0x1e0000f,0x87e1f01f,0x803c00f8,0x7c007f0,0xf803e01,0xfc003f80,0x80f8004,0x3c000,
      0x3c003c0,0x3c003c0f,0x1e03,0xe03e0078,0x3c0000,0x7c0001e,0xf0,0x780,0x0,0x0,0x3ffff800,0x1ff0000,0x0,0x7800000,0x0,0x18,
      0xc0,0x0,0x1818000,0x3e00000,0x3,0xc00f0000,0x1ff00000,0x3e00007,0xfc00003f,0xe0000003,0xc0003c00,0xf03c,0x3c0f00,0x0,0x0,
      0x0,0x70,0x380701f0,0x800000,0x780fc,0x1e001ff0,0x7c,0xf3c00,0x0,0x780000,0x7e182000,0xf000001f,0xfff00ffc,0xffc0003c,0x3cfe,
      0x0,0x31c0001,0x80f01f80,0x780f00,0x0,0x183,0x80e0c000,0xf,0x80000078,0x780,0x38,0x0,0x3c003c0,0x7ffe1c00,0x0,0x0,0x38000078,
      0xf000f01,0xe003ffe0,0x1fff00,0x7ff800,0xf000,0xf07800,0x783c000,0x3c1e0001,0xe0f0000f,0x78000f8,0x3e000f07,0x8003c000,0x78000,
      0x3c0000,0x1e00000,0xf000000,0xf00000,0x7800000,0x3c000001,0xe0001e00,0x3c0f1e0,0x3c078000,0xf03c0007,0x81e0003c,0xf0001e0,
      0x78000f00,0x7c03e01e,0x1e3c0f0,0x3c0780,0x1e03c00,0xf01e000,0x78003cf0,0x1e0007,0x80f1e000,0x4000f00,0x20007801,0x3c008,
      0x1e0040,0xf00200,0x780403f,0x7803e00,0x3007c00f,0x803e007c,0x1f003e0,0xf801f00,0x780000,0x3c00000,0x1e000000,0xf00007f0,
      0x3e003f00,0x7801f00f,0x800f807c,0x7c03e0,0x3e01f00,0x1f00f800,0x1f80007,0xc03e003c,0x3c01e0,0x1e00f00,0xf007800,0x78078003,
      0xc01fc03e,0x1e000f0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x780000,0x0,0xf078007c,0x300007fc,0x7e00fe0,0x0,0x1e00,0x3c00,0x3e1c3e0,0x1e0000,0x0,0x0,0x0,0xf0001e00,
      0x3c0001e,0x1,0xf000fff8,0x1e0780,0x3fffe00,0x79fff000,0x1f0001,0xfffc00f0,0x7e0007,0xe000003f,0x3ff,0x801fffff,0xf003ff80,
      0x3f00,0x3c03fff0,0xf01e003,0xffffc03c,0x1e0,0x3c03ff,0xffc01fff,0xfe03c000,0x1fffff,0x80007800,0x780,0x3df80000,0x7800001e,
      0x1c70f078,0x781e03c0,0x780780,0x3c0f000,0x1e078007,0xc01f8000,0xf000,0xf0003c0,0x1e007807,0x83f83c00,0xfe00003,0xff000000,
      0x7c00003c,0x780,0x1e0,0x0,0x0,0x0,0x7c01,0xf801f007,0xc00100f8,0x1f803c0,0x3c0003c,0x1f003,0xf007c00f,0x80003c00,0xf000,
      0x783f000,0x1e0000f,0x3c0f01f,0x3e01f0,0x3e007e0,0x7c07c00,0xfc003f00,0xf0000,0x3c000,0x3c003c0,0x3c003c0f,0x1e01,0xf07c007c,
      0x7c0000,0xfc0001e,0xf0,0x780,0x0,0x0,0x3ffff000,0x3838000,0x0,0x7800000,0x0,0x18,0xc0,0x0,0xff0000,0x3f00000,0x3,0xc00fff00,
      0x38380000,0x7c0000e,0xe000070,0x70000001,0xe0003c00,0xf01e,0x780e00,0x0,0x0,0x0,0x0,0x1e0,0x0,0x780f8,0xf003838,0xfc,0xffc00,
      0x0,0x780000,0x7c180000,0xf000000f,0xffe00fff,0xffc0003c,0x783f,0x80000000,0x6380000,0xc0f83f80,0xf81f00,0x0,0x303,0x80e06000,
      0x0,0x78,0xf00,0x78,0x0,0x3c003c0,0x7ffe1c00,0x0,0x0,0x3800003c,0x3e000f81,0xf003ffe0,0x1fff00,0x1fc000,0xf000,0x1e03c00,
      0xf01e000,0x780f0003,0xc078001e,0x3c000f0,0x1e000f07,0xff83c000,0x7ffff,0x803ffffc,0x1ffffe0,0xfffff00,0xf00000,0x7800000,
      0x3c000001,0xe0001e00,0x3c0f0f0,0x3c078000,0xf03c0007,0x81e0003c,0xf0001e0,0x78000f00,0x3e07c01e,0x1e3c0f0,0x3c0780,0x1e03c00,
      0xf01e000,0x78003ff0,0x1e0007,0x80f1e000,0xf80,0x7c00,0x3e000,0x1f0000,0xf80000,0x7c0001e,0x3c07c00,0x10078007,0x803c003c,
      0x1e001e0,0xf000f00,0x780000,0x3c00000,0x1e000000,0xf00007c0,0x1e003e00,0x7c03e007,0xc01f003e,0xf801f0,0x7c00f80,0x3e007c00,
      0xf,0x801f003c,0x3c01e0,0x1e00f00,0xf007800,0x7807c007,0xc01f801f,0x1f001f0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,0x0,0xe078003c,0x300001f0,0x3f801ff0,0x0,
      0x3c00,0x1e00,0x3c1c1e0,0x1e0000,0x0,0x0,0x0,0xf0001e0f,0x3c0001e,0x3,0xe000fff0,0x3c0780,0x3ffff00,0x7bfff800,0x1e0000,0x7ff00078,
      0x7e0007,0xe000003f,0x1ffc,0x1fffff,0xf0007ff0,0x7e00,0x3c07c3f0,0xf01e003,0xffff003c,0x1e0,0x3c03ff,0xffc01fff,0xfe03c000,
      0x1fffff,0x80007800,0x780,0x3ffc0000,0x7800001e,0x1ef0f078,0x781e03c0,0x780780,0x7c0f000,0x1e07801f,0x800ff000,0xf000,0xf0003c0,
      0xf00f807,0x83b83c00,0xfc00001,0xfe000000,0xf800003c,0x780,0x1e0,0x0,0x0,0x0,0x3c01,0xf000f007,0xc00000f0,0xf80780,0x3c0003c,
      0x1e001,0xf007c007,0x80003c00,0xf000,0x787e000,0x1e0000f,0x3c0f01f,0x1e01e0,0x1e007c0,0x3c07800,0x7c003f00,0xf0000,0x3c000,
      0x3c003c0,0x3e007c07,0x80003c00,0xf8f8003c,0x780000,0xf80001e,0xf0,0x780,0x0,0x0,0x7ffff000,0x601c000,0x3,0xffff0000,0x0,
      0xfff,0xf8007fff,0xc0000000,0x7e003c,0x1fe0000,0xc0003,0xc00fff00,0x601c0000,0xf800018,0x70000c0,0x38000001,0xe0007800,0x701e,
      0x701e00,0x0,0x0,0x0,0x0,0x1e0,0x6,0x700f8,0xf00601c,0xf8,0x7f800,0x0,0x780000,0xf8180000,0xf000000f,0x87c00fff,0xffc0003c,
      0xf01f,0xc0000000,0x6380000,0xc07ff780,0x1f03e03,0xfffffe00,0x303,0x81c06000,0x0,0x1ffff,0xfe001e00,0x180f8,0x0,0x3c003c0,
      0x3ffe1c00,0x3f00000,0x0,0x3800003f,0xfe0007c0,0xf8000000,0x18000000,0xc0000006,0x1f000,0x1e03c00,0xf01e000,0x780f0003,0xc078001e,
      0x3c000f0,0x1e001f07,0xff83c000,0x7ffff,0x803ffffc,0x1ffffe0,0xfffff00,0xf00000,0x7800000,0x3c000001,0xe000fff8,0x3c0f0f0,
      0x3c078000,0xf03c0007,0x81e0003c,0xf0001e0,0x78000f00,0x1f0f801e,0x3c3c0f0,0x3c0780,0x1e03c00,0xf01e000,0x78001fe0,0x1e0007,
      0x80f1e000,0x780,0x3c00,0x1e000,0xf0000,0x780000,0x3c0001e,0x3c07c00,0xf0007,0x8078003c,0x3c001e0,0x1e000f00,0x780000,0x3c00000,
      0x1e000000,0xf0000f80,0x1f003e00,0x3c03c003,0xc01e001e,0xf000f0,0x7800780,0x3c003c00,0xf,0x3f003c,0x3c01e0,0x1e00f00,0xf007800,
      0x7803c007,0x801f000f,0xf001e0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,0x1,0xe078003f,0xb0000000,0xfc003cf0,0x0,0x3c00,0x1e00,0x101c040,0x1e0000,0x0,0x0,0x1,
      0xe0001e1f,0x83c0001e,0x7,0xe000fff0,0x3c0780,0x3c03f80,0x7fc0fc00,0x1e0000,0xfff80078,0xfe0007,0xe000003f,0x7fe0,0x1fffff,
      0xf0000ffc,0xfc00,0x780f81f0,0xf01e003,0xffff003c,0x1e0,0x3c03ff,0xffc01fff,0xfe03c000,0x1fffff,0x80007800,0x780,0x3ffc0000,
      0x7800001e,0x1ef0f078,0x3c1e03c0,0x780780,0x1fc0f000,0x1e07ffff,0x7ff00,0xf000,0xf0003c0,0xf00f007,0xc3b87c00,0x7c00001,0xfe000000,
      0xf800003c,0x3c0,0x1e0,0x0,0x0,0x0,0x3c01,0xf000f007,0x800000f0,0xf80780,0x1e0003c,0x1e001,0xf0078007,0x80003c00,0xf000,0x78fc000,
      0x1e0000f,0x3c0f01e,0x1e01e0,0x1e007c0,0x3c07800,0x7c003e00,0xf0000,0x3c000,0x3c003c0,0x1e007807,0x80003c00,0x7df0003c,0x780000,
      0x1f00001e,0xf0,0x780,0x0,0x0,0x7800000,0xe7ce000,0x3,0xffff0000,0x0,0xfff,0xf8007fff,0xc0000000,0x1f0,0xffe000,0x1c0003,
      0xc00fff00,0xe7ce0000,0xf800039,0xf38001cf,0x9c000000,0xe0007800,0x780e,0x701c00,0x0,0x0,0x0,0x0,0x1e0,0x7,0xf0078,0xf00e7ce,
      0x1f0,0x7f800,0x0,0x780000,0xf0180000,0xf000000e,0x1c0001f,0xe000003c,0xf007,0xe0000000,0x6380000,0xc03fe780,0x3e07c03,0xfffffe00,
      0x303,0xffc06000,0x0,0x1ffff,0xfe003ffe,0x1fff0,0x0,0x3c003c0,0x1ffe1c00,0x3f00000,0x7,0xffc0001f,0xfc0003e0,0x7c000001,0xfc00000f,
      0xe000007f,0x1e000,0x1e03c00,0xf01e000,0x780f0003,0xc078001e,0x3c000f0,0x1e001e07,0xff83c000,0x7ffff,0x803ffffc,0x1ffffe0,
      0xfffff00,0xf00000,0x7800000,0x3c000001,0xe000fff8,0x3c0f078,0x3c078000,0xf03c0007,0x81e0003c,0xf0001e0,0x78000f00,0xf9f001e,
      0x783c0f0,0x3c0780,0x1e03c00,0xf01e000,0x78001fe0,0x1e0007,0x80f1e000,0x780,0x3c00,0x1e000,0xf0000,0x780000,0x3c0001e,0x3c07800,
      0xf0003,0xc078001e,0x3c000f0,0x1e000780,0x780000,0x3c00000,0x1e000000,0xf0000f00,0xf003c00,0x3c03c003,0xc01e001e,0xf000f0,
      0x7800780,0x3c003c00,0xf,0x7f003c,0x3c01e0,0x1e00f00,0xf007800,0x7803c007,0x801f000f,0xf001e0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,0x1,0xe070001f,0xf8000007,
      0xf0007cf8,0x7800000,0x3c00,0x1e00,0x1c000,0x1e0000,0x0,0x0,0x1,0xe0001e1f,0x83c0001e,0xf,0xc000fff8,0x780780,0x2000f80,0x7f803e00,
      0x3e0003,0xfffe007c,0x1fe0000,0x0,0x3ff00,0x0,0x1ff,0x8001f000,0x780f00f0,0x1f00f003,0xffffc03c,0x1e0,0x3c03ff,0xffc01fff,
      0xfe03c00f,0xf81fffff,0x80007800,0x780,0x3ffe0000,0x7800001e,0xee0f078,0x3c1e03c0,0x7807ff,0xff80f000,0x1e07fffe,0x3ffe0,
      0xf000,0xf0003c0,0xf00f003,0xc7bc7800,0xfc00000,0xfc000001,0xf000003c,0x3c0,0x1e0,0x0,0x0,0x0,0x3c01,0xe000f80f,0x800001e0,
      0xf80f00,0x1e0003c,0x3c000,0xf0078007,0x80003c00,0xf000,0x79f8000,0x1e0000f,0x3c0f01e,0x1e03c0,0x1f00780,0x3e0f000,0x7c003e00,
      0xf0000,0x3c000,0x3c003c0,0x1e007807,0x81e03c00,0x7df0003e,0xf80000,0x3e00003e,0xf0,0x7c0,0xfc000,0x80000000,0x7800000,0x1e7cf000,
      0x3,0xffff0000,0x0,0x18,0xc0,0x0,0xf80,0x7ffc00,0x380003,0xc00fff01,0xe7cf0000,0x1f000079,0xf3c003cf,0x9e000000,0xe0007000,
      0x380e,0xe01c00,0x0,0x0,0x0,0x0,0x1e0,0x3,0x800f0078,0xf01e7cf,0x3e0,0x3f000,0x0,0x780000,0xf018001f,0xfff8001e,0x1e0000f,
      0xc000003c,0xf003,0xe0000000,0x6380000,0xc00fc780,0x7c0f803,0xfffffe00,0x303,0xfe006000,0x0,0x1ffff,0xfe003ffe,0x1ffe0,0x0,
      0x3c003c0,0xffe1c00,0x3f00000,0x7,0xffc00007,0xf00001f0,0x3e00001f,0xfc0000ff,0xe00007ff,0x3e000,0x3e01e00,0x1f00f000,0xf8078007,
      0xc03c003e,0x1e001e0,0xf001e07,0xff83c000,0x7ffff,0x803ffffc,0x1ffffe0,0xfffff00,0xf00000,0x7800000,0x3c000001,0xe000fff8,
      0x3c0f078,0x3c078000,0xf03c0007,0x81e0003c,0xf0001e0,0x78000f00,0x7fe001e,0xf03c0f0,0x3c0780,0x1e03c00,0xf01e000,0x78000fc0,
      0x1e0007,0x80f1f000,0x780,0x3c00,0x1e000,0xf0000,0x780000,0x3c0001e,0x3c0f800,0x1e0003,0xc0f0001e,0x78000f0,0x3c000780,0x780000,
      0x3c00000,0x1e000000,0xf0000f00,0xf003c00,0x3c078003,0xe03c001f,0x1e000f8,0xf0007c0,0x78003e00,0x1e,0xf7803c,0x3c01e0,0x1e00f00,
      0xf007800,0x7803e00f,0x801e000f,0x80f803e0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,0x1,0xe0f0000f,0xff00001f,0x8000f87c,0x7800000,0x3c00,0x1e00,0x1c000,0x7fffff80,
      0x0,0x0,0x3,0xc0001e1f,0x83c0001e,0x1f,0x800000fe,0xf00780,0x7c0,0x7f001e00,0x3c0007,0xe03f003f,0x3fe0000,0x0,0x3fc00,0x0,
      0x7f,0x8001e000,0x781f00f0,0x1e00f003,0xc007e03c,0x1e0,0x3c03c0,0x1e00,0x3c00f,0xf81e0007,0x80007800,0x780,0x3f9f0000,0x7800001e,
      0xfe0f078,0x3c1e03c0,0x7807ff,0xff00f000,0x1e07fff8,0xfff8,0xf000,0xf0003c0,0xf81f003,0xc7bc7800,0xfe00000,0x78000003,0xe000003c,
      0x1e0,0x1e0,0x0,0x0,0x0,0x1fffc01,0xe000780f,0x1e0,0x780f00,0x1e0003c,0x3c000,0xf0078007,0x80003c00,0xf000,0x7bf0000,0x1e0000f,
      0x3c0f01e,0x1e03c0,0xf00780,0x1e0f000,0x3c003c00,0xf8000,0x3c000,0x3c003c0,0x1f00f807,0x81f03c00,0x3fe0001e,0xf00000,0x7c00007c,
      0xf0,0x3e0,0x3ff801,0x80000000,0x7800000,0x3cfcf800,0x3,0xffff0000,0x0,0x18,0xc0,0x0,0x7c00,0x1fff00,0x700003,0xc00f0003,
      0xcfcf8000,0x3e0000f3,0xf3e0079f,0x9f000000,0xf000,0x1000,0x0,0x0,0x0,0x0,0x0,0x1f0,0x1,0xc00f0078,0xf03cfcf,0x800007c0,0x1e000,
      0x0,0x780001,0xe018001f,0xfff8001c,0xe00007,0x8000003c,0xf001,0xf0000000,0x6380000,0xc0000000,0xf81f003,0xfffffe00,0x303,
      0x87006000,0x0,0x1ffff,0xfe003ffe,0x7f00,0x0,0x3c003c0,0x3fe1c00,0x3f00000,0x7,0xffc00000,0xf8,0x1f0001ff,0xf0000fff,0x80007ffc,
      0xfc000,0x3c01e00,0x1e00f000,0xf0078007,0x803c003c,0x1e001e0,0xf001e07,0x8003c000,0x78000,0x3c0000,0x1e00000,0xf000000,0xf00000,
      0x7800000,0x3c000001,0xe000fff8,0x3c0f078,0x3c078000,0xf03c0007,0x81e0003c,0xf0001e0,0x78000f00,0x3fc001e,0x1e03c0f0,0x3c0780,
      0x1e03c00,0xf01e000,0x78000780,0x1e0007,0x80f0fc00,0x3fff80,0x1fffc00,0xfffe000,0x7fff0003,0xfff8001f,0xffc0001e,0x3c0f000,
      0x1e0003,0xc0f0001e,0x78000f0,0x3c000780,0x780000,0x3c00000,0x1e000000,0xf0001e00,0xf803c00,0x3c078001,0xe03c000f,0x1e00078,
      0xf0003c0,0x78001e07,0xfffffe1e,0x1e7803c,0x3c01e0,0x1e00f00,0xf007800,0x7801e00f,0x1e0007,0x807803c0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,0x3,0xc0f00007,
      0xffc0007e,0xf03e,0x7800000,0x3c00,0x1e00,0x1c000,0x7fffff80,0x0,0x0,0x3,0xc0001e1f,0x83c0001e,0x3f,0x3e,0xf00780,0x3c0,0x7e001e00,
      0x7c000f,0x800f001f,0xffde0000,0x0,0x3e000,0x0,0xf,0x8003e000,0x781e0070,0x1e00f003,0xc001f03c,0x1e0,0x3c03c0,0x1e00,0x3c00f,
      0xf81e0007,0x80007800,0x780,0x3f1f0000,0x7800001e,0x7c0f078,0x1e1e03c0,0x7807ff,0xfc00f000,0x1e07fffe,0xffc,0xf000,0xf0003c0,
      0x781e003,0xc71c7800,0x1ff00000,0x78000003,0xe000003c,0x1e0,0x1e0,0x0,0x0,0x0,0xffffc01,0xe000780f,0x1e0,0x780fff,0xffe0003c,
      0x3c000,0xf0078007,0x80003c00,0xf000,0x7ff0000,0x1e0000f,0x3c0f01e,0x1e03c0,0xf00780,0x1e0f000,0x3c003c00,0x7f000,0x3c000,
      0x3c003c0,0xf00f007,0xc1f07c00,0x1fc0001f,0x1f00000,0xfc000ff8,0xf0,0x1ff,0xfffe07,0x80000000,0x7800000,0x7ffcfc00,0x0,0xf000000,
      0x0,0x18,0xc0,0x0,0x3e000,0x1ff80,0xe00003,0xc00f0007,0xffcfc000,0x3e0001ff,0xf3f00fff,0x9f800000,0x6000,0x0,0x0,0x7c000,
      0x0,0x0,0x0,0xfe,0x0,0xe00f007f,0xff07ffcf,0xc0000fc0,0x1e000,0x0,0x780001,0xe018001f,0xfff8001c,0xe00007,0x80000000,0xf800,
      0xf0000000,0x6380000,0xc0000000,0x1f03c000,0x1e00,0x303,0x83806000,0x0,0x78,0x0,0x0,0x0,0x3c003c0,0xfe1c00,0x3f00000,0x0,
      0x0,0x3c,0xf801fff,0xfff8,0x7ffc0,0x1f8000,0x3c01e00,0x1e00f000,0xf0078007,0x803c003c,0x1e001e0,0xf003c07,0x8003c000,0x78000,
      0x3c0000,0x1e00000,0xf000000,0xf00000,0x7800000,0x3c000001,0xe0001e00,0x3c0f03c,0x3c078000,0xf03c0007,0x81e0003c,0xf0001e0,
      0x78000f00,0x1f8001e,0x1e03c0f0,0x3c0780,0x1e03c00,0xf01e000,0x78000780,0x1e000f,0x80f0ff00,0x1ffff80,0xffffc00,0x7fffe003,
      0xffff001f,0xfff800ff,0xffc007ff,0xffc0f000,0x1fffff,0xc0fffffe,0x7fffff0,0x3fffff80,0x780000,0x3c00000,0x1e000000,0xf0001e00,
      0x7803c00,0x3c078001,0xe03c000f,0x1e00078,0xf0003c0,0x78001e07,0xfffffe1e,0x3c7803c,0x3c01e0,0x1e00f00,0xf007800,0x7801f01f,
      0x1e0007,0x807c07c0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x780000,0x3,0xc0f00000,0xfff003f0,0x1f00f03e,0x7800000,0x3c00,0x1e00,0x1c000,0x7fffff80,0x0,0x7ff80000,0x3,
      0xc0001e0f,0x3c0001e,0x7e,0x1f,0x1e00780,0x3e0,0x7e000f00,0x78000f,0x7800f,0xff9e0000,0x0,0x3fc00,0x0,0x7f,0x8003c000,0x781e0070,
      0x3e00f803,0xc000f03c,0x1e0,0x3c03c0,0x1e00,0x3c00f,0xf81e0007,0x80007800,0x780,0x3e0f8000,0x7800001e,0x7c0f078,0x1e1e03c0,
      0x7807ff,0xf000f000,0x1e07807f,0xfe,0xf000,0xf0003c0,0x781e003,0xc71c7800,0x3ef00000,0x78000007,0xc000003c,0x1e0,0x1e0,0x0,
      0x0,0x0,0x1ffffc01,0xe000780f,0x1e0,0x780fff,0xffe0003c,0x3c000,0xf0078007,0x80003c00,0xf000,0x7ff0000,0x1e0000f,0x3c0f01e,
      0x1e03c0,0xf00780,0x1e0f000,0x3c003c00,0x7ff80,0x3c000,0x3c003c0,0xf00f003,0xc1f07800,0x1fc0000f,0x1e00000,0xf8000ff0,0xf0,
      0xff,0xffffff,0x80000000,0x3fffc000,0xfff9fe00,0x0,0xf000000,0x0,0x18,0xc0,0x0,0x1f0000,0x1fc0,0x1c00003,0xc00f000f,0xff9fe000,
      0x7c0003ff,0xe7f81fff,0x3fc00000,0x0,0x0,0x0,0xfe000,0x1ffffc0f,0xfffffc00,0x0,0xff,0xf0000000,0x700f007f,0xff0fff9f,0xe0000f80,
      0x1e000,0x0,0x780001,0xe018001f,0xfff8001c,0xe00fff,0xffc00000,0xf800,0xf0000000,0x6380000,0xc0ffff80,0x3e078000,0x1e00,0x7ff80303,
      0x83c06000,0x0,0x78,0x0,0x0,0x0,0x3c003c0,0xe1c00,0x3f00000,0x0,0x7f,0xff00001e,0x7c1fff0,0xfff80,0x7ffc00,0x3f0000,0x7c01f00,
      0x3e00f801,0xf007c00f,0x803e007c,0x1f003e0,0xf803c07,0x8003c000,0x78000,0x3c0000,0x1e00000,0xf000000,0xf00000,0x7800000,0x3c000001,
      0xe0001e00,0x3c0f03c,0x3c078000,0xf03c0007,0x81e0003c,0xf0001e0,0x78000f00,0x1f8001e,0x3c03c0f0,0x3c0780,0x1e03c00,0xf01e000,
      0x78000780,0x1e001f,0xf07f80,0x3ffff80,0x1ffffc00,0xffffe007,0xffff003f,0xfff801ff,0xffc03fff,0xffc0f000,0x1fffff,0xc0fffffe,
      0x7fffff0,0x3fffff80,0x780000,0x3c00000,0x1e000000,0xf0001e00,0x7803c00,0x3c078001,0xe03c000f,0x1e00078,0xf0003c0,0x78001e07,
      0xfffffe1e,0x787803c,0x3c01e0,0x1e00f00,0xf007800,0x7800f01e,0x1e0007,0x803c0780,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,0x1ff,0xffff8000,0x3ff80fc0,0x7fc1e01f,
      0x7800000,0x3c00,0x1e00,0x0,0x7fffff80,0x0,0x7ff80000,0x7,0x80001e00,0x3c0001e,0xfc,0xf,0x1e00780,0x1e0,0x7c000f00,0x78000f,
      0x78007,0xff1e0000,0x0,0x3ff00,0x0,0x1ff,0x8003c000,0x781e0070,0x3c007803,0xc000f03c,0x1e0,0x3c03c0,0x1e00,0x3c000,0x781e0007,
      0x80007800,0x780,0x3c07c000,0x7800001e,0x7c0f078,0xf1e03c0,0x780780,0xf000,0x1e07801f,0x3e,0xf000,0xf0003c0,0x781e003,0xcf1c7800,
      0x3cf80000,0x7800000f,0x8000003c,0xf0,0x1e0,0x0,0x0,0x0,0x3ffffc01,0xe000780f,0x1e0,0x780fff,0xffe0003c,0x3c000,0xf0078007,
      0x80003c00,0xf000,0x7ff8000,0x1e0000f,0x3c0f01e,0x1e03c0,0xf00780,0x1e0f000,0x3c003c00,0x3fff0,0x3c000,0x3c003c0,0xf81f003,
      0xc3b87800,0xf80000f,0x1e00001,0xf0000ff0,0xf0,0xff,0xf03fff,0x80000000,0x3fff8001,0xfff1ff00,0x0,0xf000000,0x0,0x18,0xc0,
      0x0,0x380000,0x7c0,0x3c00003,0xc00f001f,0xff1ff000,0xf80007ff,0xc7fc3ffe,0x3fe00000,0x0,0x0,0x0,0x1ff000,0x7ffffe1f,0xffffff00,
      0x0,0x7f,0xfe000000,0x780f007f,0xff1fff1f,0xf0001f00,0x1e000,0x0,0x780001,0xe0180000,0xf000001c,0xe00fff,0xffc00000,0x7c00,
      0xf0000000,0x31c0001,0x80ffff80,0x3e078000,0x1e00,0x7ff80183,0x81c0c000,0x0,0x78,0x0,0x0,0x0,0x3c003c0,0xe1c00,0x3f00000,
      0x0,0x7f,0xff00001e,0x7c7ff03,0xc03ff8fe,0x1ffc0f0,0x7e0000,0x7800f00,0x3c007801,0xe003c00f,0x1e0078,0xf003c0,0x7803c07,0x8003c000,
      0x78000,0x3c0000,0x1e00000,0xf000000,0xf00000,0x7800000,0x3c000001,0xe0001e00,0x3c0f01e,0x3c078000,0xf03c0007,0x81e0003c,
      0xf0001e0,0x78000f00,0x3fc001e,0x7803c0f0,0x3c0780,0x1e03c00,0xf01e000,0x78000780,0x1e007f,0xf03fe0,0x7ffff80,0x3ffffc01,
      0xffffe00f,0xffff007f,0xfff803ff,0xffc07fff,0xffc0f000,0x1fffff,0xc0fffffe,0x7fffff0,0x3fffff80,0x780000,0x3c00000,0x1e000000,
      0xf0001e00,0x7803c00,0x3c078001,0xe03c000f,0x1e00078,0xf0003c0,0x78001e07,0xfffffe1e,0x707803c,0x3c01e0,0x1e00f00,0xf007800,
      0x7800f01e,0x1e0007,0x803c0780,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,0x1ff,0xffff8000,0x30f81f00,0xffe1e00f,0x87800000,0x3c00,0x1e00,0x0,0x1e0000,0x0,0x7ff80000,
      0x7,0x80001e00,0x3c0001e,0x1f8,0x7,0x83c00780,0x1e0,0x7c000f00,0xf8001e,0x3c001,0xfc1e0000,0x0,0x7fe0,0x0,0xffc,0x3c000,0x781e0070,
      0x3ffff803,0xc000783c,0x1e0,0x3c03c0,0x1e00,0x3c000,0x781e0007,0x80007800,0x780,0x3c07c000,0x7800001e,0x380f078,0xf1e03c0,
      0x780780,0xf000,0x1e07800f,0x8000001e,0xf000,0xf0003c0,0x3c3c003,0xcf1e7800,0x7c780000,0x7800000f,0x8000003c,0xf0,0x1e0,0x0,
      0x0,0x0,0x7f003c01,0xe000780f,0x1e0,0x780fff,0xffe0003c,0x3c000,0xf0078007,0x80003c00,0xf000,0x7f7c000,0x1e0000f,0x3c0f01e,
      0x1e03c0,0xf00780,0x1e0f000,0x3c003c00,0xfff8,0x3c000,0x3c003c0,0x781e003,0xc3b87800,0x1fc00007,0x83e00003,0xe0000ff8,0xf0,
      0x1ff,0xc007fe,0x0,0x7fff8001,0xffe3ff00,0x0,0x1e000000,0x0,0x18,0xc0,0x0,0x0,0x3c0,0x7800003,0xc00f001f,0xfe3ff000,0xf80007ff,
      0x8ffc3ffc,0x7fe00000,0x0,0x0,0x0,0x1ff000,0x0,0x0,0x0,0x1f,0xff000000,0x3c0f007f,0xff1ffe3f,0xf0003e00,0x1e000,0x0,0x780001,
      0xe0180000,0xf000001e,0x1e00fff,0xffc00000,0x3f00,0xf0000000,0x31c0001,0x80ffff80,0x1f03c000,0x1e00,0x7ff80183,0x81c0c000,
      0x0,0x78,0x0,0x0,0x0,0x3c003c0,0xe1c00,0x0,0x0,0x7f,0xff00003c,0xf87f007,0xc03f83ff,0x81fc01f0,0x7c0000,0x7ffff00,0x3ffff801,
      0xffffc00f,0xfffe007f,0xfff003ff,0xff807fff,0x8003c000,0x78000,0x3c0000,0x1e00000,0xf000000,0xf00000,0x7800000,0x3c000001,
      0xe0001e00,0x3c0f01e,0x3c078000,0xf03c0007,0x81e0003c,0xf0001e0,0x78000f00,0x7fe001e,0xf003c0f0,0x3c0780,0x1e03c00,0xf01e000,
      0x78000780,0x1ffffe,0xf00ff0,0xfe00780,0x7f003c03,0xf801e01f,0xc00f00fe,0x7807f0,0x3c0ffff,0xffc0f000,0x1fffff,0xc0fffffe,
      0x7fffff0,0x3fffff80,0x780000,0x3c00000,0x1e000000,0xf0001e00,0x7803c00,0x3c078001,0xe03c000f,0x1e00078,0xf0003c0,0x78001e00,
      0x1e,0xf07803c,0x3c01e0,0x1e00f00,0xf007800,0x7800783e,0x1e0007,0x801e0f80,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,0x1ff,0xffff8000,0x307c0801,0xe1f1e00f,0x87000000,
      0x3c00,0x1e00,0x0,0x1e0000,0x0,0x7ff80000,0xf,0x1e00,0x3c0001e,0x3f0,0x7,0x83fffffc,0x1e0,0x7c000f00,0xf0001e,0x3c000,0x3e0000,
      0x0,0x1ffc,0x1fffff,0xf0007ff0,0x3c000,0x781e0070,0x7ffffc03,0xc000781e,0x1e0,0x7803c0,0x1e00,0x3c000,0x781e0007,0x80007800,
      0x780,0x3c03e000,0x7800001e,0xf078,0x79e03c0,0x780780,0xf000,0x1e078007,0x8000000f,0xf000,0xf0003c0,0x3c3c001,0xee0ef000,
      0xf87c0000,0x7800001f,0x3c,0x78,0x1e0,0x0,0x0,0x0,0x7c003c01,0xe000780f,0x1e0,0x780f00,0x3c,0x3c000,0xf0078007,0x80003c00,
      0xf000,0x7e3e000,0x1e0000f,0x3c0f01e,0x1e03c0,0xf00780,0x1e0f000,0x3c003c00,0x1ffc,0x3c000,0x3c003c0,0x781e003,0xe3b8f800,
      0x1fc00007,0x83c00007,0xc00000fc,0xf0,0x3e0,0x8001f8,0x0,0x7800000,0xffc7fe00,0x0,0x1e000000,0x0,0x18,0xc0,0x0,0x0,0x1e0,
      0xf000003,0xc00f000f,0xfc7fe001,0xf00003ff,0x1ff81ff8,0xffc00000,0x0,0x0,0x0,0x1ff000,0x0,0x0,0x0,0x3,0xff800000,0x1e0f0078,
      0xffc7f,0xe0007c00,0x1e000,0x0,0x780001,0xe0180000,0xf000000e,0x1c00007,0x80000000,0x1f81,0xe0000000,0x38e0003,0x80000000,
      0xf81f000,0x1e00,0x7ff801c3,0x80e1c000,0x0,0x78,0x0,0x0,0x0,0x3c003c0,0xe1c00,0x0,0x0,0x0,0xf8,0x1f070007,0xc03803ff,0xc1c001f0,
      0xf80000,0xfffff00,0x7ffff803,0xffffc01f,0xfffe00ff,0xfff007ff,0xffc07fff,0x8001e000,0x78000,0x3c0000,0x1e00000,0xf000000,
      0xf00000,0x7800000,0x3c000001,0xe0001e00,0x780f00f,0x3c078000,0xf03c0007,0x81e0003c,0xf0001e0,0x78000f00,0xf9f001e,0xf003c0f0,
      0x3c0780,0x1e03c00,0xf01e000,0x78000780,0x1ffffc,0xf003f8,0xf800780,0x7c003c03,0xe001e01f,0xf00f8,0x7807c0,0x3c0fc1e,0xf000,
      0x1e0000,0xf00000,0x7800000,0x3c000000,0x780000,0x3c00000,0x1e000000,0xf0001e00,0x7803c00,0x3c078001,0xe03c000f,0x1e00078,
      0xf0003c0,0x78001e00,0x1e,0x1e07803c,0x3c01e0,0x1e00f00,0xf007800,0x7800783c,0x1e0007,0x801e0f00,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1ff,0xffff8000,0x303c0001,
      0xc071e007,0xcf000000,0x3c00,0x1e00,0x0,0x1e0000,0x0,0x0,0xf,0xf00,0x780001e,0x7e0,0x7,0x83fffffc,0x1e0,0x7c000f00,0x1f0001e,
      0x3c000,0x3c0000,0x0,0x3ff,0x801fffff,0xf003ff80,0x3c000,0x781e0070,0x7ffffc03,0xc000781e,0x1e0,0x7803c0,0x1e00,0x1e000,0x781e0007,
      0x80007800,0x780,0x3c01f000,0x7800001e,0xf078,0x79e03c0,0xf00780,0xf000,0x3e078007,0xc000000f,0xf000,0xf0003c0,0x3c3c001,
      0xee0ef000,0xf03e0000,0x7800003e,0x3c,0x78,0x1e0,0x0,0x0,0x0,0xf8003c01,0xe000780f,0x1e0,0x780f00,0x3c,0x3c000,0xf0078007,
      0x80003c00,0xf000,0x7c3e000,0x1e0000f,0x3c0f01e,0x1e03c0,0xf00780,0x1e0f000,0x3c003c00,0xfc,0x3c000,0x3c003c0,0x3c3e001,0xe7b8f000,
      0x3fe00007,0xc7c0000f,0xc000003e,0xf0,0x7c0,0x0,0x0,0x7c00000,0x7fcffc00,0x0,0x1e000000,0x0,0x18,0xc0,0x0,0x0,0x1e0,0x1e000003,
      0xc00f0007,0xfcffc003,0xe00001ff,0x3ff00ff9,0xff800000,0x0,0x0,0x0,0x1ff000,0x0,0x0,0x0,0x0,0x1f800000,0xf0f0078,0x7fcff,
      0xc000fc00,0x1e000,0x0,0x780001,0xe0180000,0xf000000f,0x87c00007,0x80000000,0xfe3,0xe0000000,0x18780c3,0x0,0x7c0f800,0x1e00,
      0xc3,0x80e18000,0x0,0x78,0x0,0x0,0x0,0x3c003c0,0xe1c00,0x0,0x0,0x0,0x1f0,0x3e00000f,0xc0000303,0xe00003f0,0xf00000,0xfffff80,
      0x7ffffc03,0xffffe01f,0xffff00ff,0xfff807ff,0xffc07fff,0x8001e000,0x78000,0x3c0000,0x1e00000,0xf000000,0xf00000,0x7800000,
      0x3c000001,0xe0001e00,0x780f00f,0x3c078001,0xe03c000f,0x1e00078,0xf0003c0,0x78001e00,0x1f0f801f,0xe00780f0,0x3c0780,0x1e03c00,
      0xf01e000,0x78000780,0x1ffff8,0xf000f8,0x1f000780,0xf8003c07,0xc001e03e,0xf01f0,0x780f80,0x3c1f01e,0xf000,0x1e0000,0xf00000,
      0x7800000,0x3c000000,0x780000,0x3c00000,0x1e000000,0xf0001e00,0x7803c00,0x3c078001,0xe03c000f,0x1e00078,0xf0003c0,0x78001e00,
      0x1e,0x3c07803c,0x3c01e0,0x1e00f00,0xf007800,0x78007c7c,0x1e0007,0x801f1f00,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x7,0x81c00000,0x303c0003,0x8039e003,0xef000000,
      0x3c00,0x1e00,0x0,0x1e0000,0x0,0x0,0x1e,0xf00,0x780001e,0xfc0,0x7,0x83fffffc,0x1e0,0x3c000f00,0x1e0001e,0x3c000,0x3c0000,
      0x0,0x7f,0xe01fffff,0xf00ffc00,0x3c000,0x781f00f0,0x7ffffc03,0xc000781e,0x1e0,0x7803c0,0x1e00,0x1e000,0x781e0007,0x80007800,
      0x780,0x3c01f000,0x7800001e,0xf078,0x7de01e0,0xf00780,0x7800,0x3c078003,0xc000000f,0xf000,0xf0003c0,0x3e7c001,0xee0ef001,
      0xf01e0000,0x7800003e,0x3c,0x3c,0x1e0,0x0,0x0,0x0,0xf0003c01,0xe000780f,0x1e0,0x780f00,0x3c,0x3c000,0xf0078007,0x80003c00,
      0xf000,0x781f000,0x1e0000f,0x3c0f01e,0x1e03c0,0xf00780,0x1e0f000,0x3c003c00,0x3e,0x3c000,0x3c003c0,0x3c3c001,0xe71cf000,0x7df00003,
      0xc780000f,0x8000003e,0xf0,0x780,0x0,0x0,0x3c00000,0x3fcff800,0x0,0x1e000000,0x0,0x18,0xc0,0x0,0x1f00fc,0x1e0,0x1e000001,
      0xe00f0003,0xfcff8003,0xe00000ff,0x3fe007f9,0xff000000,0x0,0x0,0x0,0x1ff000,0x0,0x0,0x0,0x0,0x7c00000,0xf0f0078,0x3fcff,0x8000f800,
      0x1e000,0x0,0x780001,0xe0180000,0xf000001f,0xffe00007,0x8000003c,0x7ff,0xc0000000,0x1c3ffc7,0x0,0x3e07c00,0x1e00,0xe3,0x80738000,
      0x0,0x78,0x0,0x0,0x0,0x3c003c0,0xe1c00,0x0,0x0,0x0,0x3e0,0x7c00001d,0xc0000001,0xe0000770,0x1f00000,0xfffff80,0x7ffffc03,
      0xffffe01f,0xffff00ff,0xfff807ff,0xffc07fff,0x8001e000,0x78000,0x3c0000,0x1e00000,0xf000000,0xf00000,0x7800000,0x3c000001,
      0xe0001e00,0x780f00f,0x3c03c001,0xe01e000f,0xf00078,0x78003c0,0x3c001e00,0x3e07c01f,0xc00780f0,0x3c0780,0x1e03c00,0xf01e000,
      0x78000780,0x1fffc0,0xf0007c,0x1e000780,0xf0003c07,0x8001e03c,0xf01e0,0x780f00,0x3c1e01e,0xf000,0x1e0000,0xf00000,0x7800000,
      0x3c000000,0x780000,0x3c00000,0x1e000000,0xf0001e00,0x7803c00,0x3c078001,0xe03c000f,0x1e00078,0xf0003c0,0x78001e00,0x1e,0x7807803c,
      0x3c01e0,0x1e00f00,0xf007800,0x78003c78,0x1e0007,0x800f1e00,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x7,0x83c00000,0x303c0003,0x8039e001,0xee000000,0x1e00,0x3c00,
      0x0,0x1e0000,0x0,0x0,0x1e,0xf00,0x780001e,0x1f80,0x7,0x83fffffc,0x1e0,0x3c000f00,0x1e0001e,0x3c000,0x3c0000,0x0,0x1f,0xfc1fffff,
      0xf07ff000,0x0,0x780f00f0,0x78003c03,0xc000781e,0x1e0,0xf803c0,0x1e00,0x1e000,0x781e0007,0x80007800,0x780,0x3c00f800,0x7800001e,
      0xf078,0x3de01e0,0xf00780,0x7800,0x3c078003,0xe000000f,0xf000,0xf0003c0,0x1e78001,0xfe0ff003,0xe01f0000,0x7800007c,0x3c,0x3c,
      0x1e0,0x0,0x0,0x0,0xf0007c01,0xe000f80f,0x800001e0,0xf80f00,0x3c,0x1e001,0xf0078007,0x80003c00,0xf000,0x780f800,0x1e0000f,
      0x3c0f01e,0x1e03c0,0x1f00780,0x3e0f000,0x7c003c00,0x1e,0x3c000,0x3c003c0,0x3c3c001,0xe71cf000,0xf8f80003,0xe780001f,0x1e,
      0xf0,0x780,0x0,0x0,0x3c00000,0x1ffff000,0x0,0x1e000000,0x0,0x18,0xc0,0x0,0x3bc1de,0x1e0,0xf000001,0xe00f0001,0xffff0007,0xc000007f,
      0xffc003ff,0xfe000000,0x0,0x0,0x0,0xfe000,0x0,0x0,0x0,0x0,0x3c00000,0x1e0f0078,0x1ffff,0x1f000,0x1e000,0x0,0x780000,0xf0180000,
      0xf000001f,0xfff00007,0x8000003c,0x1ff,0x80000000,0xe0ff0e,0x0,0x1f03e00,0x1e00,0x70,0x70000,0x0,0x78,0x0,0x0,0x0,0x3c003c0,
      0xe1c00,0x0,0x0,0x0,0x7c0,0xf8000019,0xc0000000,0xe0000670,0x1e00000,0xf000780,0x78003c03,0xc001e01e,0xf00f0,0x780780,0x3c0f807,
      0x8001e000,0x78000,0x3c0000,0x1e00000,0xf000000,0xf00000,0x7800000,0x3c000001,0xe0001e00,0xf80f007,0xbc03c001,0xe01e000f,
      0xf00078,0x78003c0,0x3c001e00,0x7c03e00f,0x800780f0,0x3c0780,0x1e03c00,0xf01e000,0x78000780,0x1e0000,0xf0003c,0x1e000f80,
      0xf0007c07,0x8003e03c,0x1f01e0,0xf80f00,0x7c1e01e,0xf800,0x1e0000,0xf00000,0x7800000,0x3c000000,0x780000,0x3c00000,0x1e000000,
      0xf0001e00,0x7803c00,0x3c078003,0xe03c001f,0x1e000f8,0xf0007c0,0x78003e00,0x1f8001f,0xf00f803c,0x3c01e0,0x1e00f00,0xf007800,
      0x78003e78,0x1e000f,0x800f9e00,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xf,0x3c00000,0x303c0003,0x8039f001,0xfe000000,0x1e00,0x3c00,0x0,0x1e0000,0x0,0x0,0x3c,0xf00,
      0x780001e,0x3f00,0x7,0x80000780,0x3e0,0x3e000f00,0x3c0001e,0x3c000,0x7c0000,0x0,0x3,0xfe000000,0xff8000,0x0,0x3c0f81f0,0xf0001e03,
      0xc000780f,0x1e0,0xf003c0,0x1e00,0xf000,0x781e0007,0x80007800,0x780,0x3c007c00,0x7800001e,0xf078,0x3de01e0,0xf00780,0x7800,
      0x3c078001,0xe000000f,0xf000,0xf0003c0,0x1e78001,0xfc07f003,0xe00f0000,0x78000078,0x3c,0x1e,0x1e0,0x0,0x0,0x0,0xf0007c01,
      0xf000f007,0x800000f0,0xf80780,0x3c,0x1e001,0xf0078007,0x80003c00,0xf000,0x7807c00,0x1e0000f,0x3c0f01e,0x1e01e0,0x1e007c0,
      0x3c07800,0x7c003c00,0x1e,0x3c000,0x3c007c0,0x1e78001,0xe71df000,0xf8f80001,0xef80003e,0x1e,0xf0,0x780,0x0,0x0,0x3c00000,
      0xfffe000,0x0,0x3e000000,0x0,0x18,0x7fff,0xc0000000,0x60c306,0x1e0,0x7800001,0xe00f0000,0xfffe0007,0x8000003f,0xff8001ff,
      0xfc000000,0x0,0x0,0x0,0x7c000,0x0,0x0,0x0,0x0,0x3c00000,0x3c0f0078,0xfffe,0x3e000,0x1e000,0x0,0x780000,0xf0180000,0xf000003c,
      0xfcf80007,0x8000003c,0x7f,0x0,0x70001c,0x0,0xf81f00,0x0,0x38,0xe0000,0x0,0x0,0x0,0x0,0x0,0x3c003c0,0xe1c00,0x0,0x0,0x0,0xf81,
      0xf0000039,0xc0000000,0xe0000e70,0x1e00000,0x1e0003c0,0xf0001e07,0x8000f03c,0x781e0,0x3c0f00,0x1e0f007,0x8000f000,0x78000,
      0x3c0000,0x1e00000,0xf000000,0xf00000,0x7800000,0x3c000001,0xe0001e00,0xf00f007,0xbc03c001,0xe01e000f,0xf00078,0x78003c0,
      0x3c001e00,0xf801f00f,0x800780f0,0x3c0780,0x1e03c00,0xf01e000,0x78000780,0x1e0000,0xf0003c,0x1e000f80,0xf0007c07,0x8003e03c,
      0x1f01e0,0xf80f00,0x7c1e01e,0x7800,0xf0000,0x780000,0x3c00000,0x1e000000,0x780000,0x3c00000,0x1e000000,0xf0000f00,0xf003c00,
      0x3c03c003,0xc01e001e,0xf000f0,0x7800780,0x3c003c00,0x1f8000f,0xe00f003c,0x7c01e0,0x3e00f00,0x1f007800,0xf8001ef8,0x1f000f,
      0x7be00,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0xf,0x3c00000,0x307c0003,0x8038f000,0xfc000000,0x1e00,0x3c00,0x0,0x1e0000,0xfc0000,0x0,0x7e00003c,0x780,0xf00001e,
      0x7e00,0xf,0x80000780,0x3c0,0x3e001e00,0x3c0001f,0x7c000,0x780007,0xe000003f,0x0,0xfe000000,0xfe0000,0x0,0x3c07c3f0,0xf0001e03,
      0xc000f80f,0x800001e0,0x1f003c0,0x1e00,0xf000,0x781e0007,0x80007800,0x4000f80,0x3c003c00,0x7800001e,0xf078,0x1fe01f0,0x1f00780,
      0x7c00,0x7c078001,0xf000001f,0xf000,0xf0003c0,0x1e78001,0xfc07f007,0xc00f8000,0x780000f8,0x3c,0x1e,0x1e0,0x0,0x0,0x0,0xf0007c01,
      0xf000f007,0xc00000f0,0xf80780,0x3c,0x1f003,0xf0078007,0x80003c00,0xf000,0x7807c00,0x1e0000f,0x3c0f01e,0x1e01e0,0x1e007c0,
      0x3c07800,0x7c003c00,0x1e,0x3c000,0x3c007c0,0x1e78000,0xfe0fe001,0xf07c0001,0xef00007c,0x1e,0xf0,0x780,0x0,0x0,0x1e00000,
      0x7cfc000,0xfc00000,0x3c00000f,0xc3f00000,0x18,0x7fff,0xc0000000,0x406303,0x3e0,0x3c00001,0xf00f0000,0x7cfc000f,0x8000001f,
      0x3f0000f9,0xf8000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3c00000,0x780700f8,0x7cfc,0x7c000,0x1e000,0x0,0x780000,0xf8180000,
      0xf0000070,0x3c0007,0x8000003c,0x3f,0x80000000,0x3c0078,0x0,0x780f00,0x0,0x1e,0x3c0000,0x0,0x0,0x0,0x0,0x0,0x3e007c0,0xe1c00,
      0x0,0x0,0x0,0xf01,0xe0000071,0xc0000000,0xe0001c70,0x1e00000,0x1e0003c0,0xf0001e07,0x8000f03c,0x781e0,0x3c0f00,0x1e0f007,
      0x8000f800,0x78000,0x3c0000,0x1e00000,0xf000000,0xf00000,0x7800000,0x3c000001,0xe0001e00,0x1f00f003,0xfc03e003,0xe01f001f,
      0xf800f8,0x7c007c0,0x3e003e01,0xf000f80f,0xf00f0,0x3c0780,0x1e03c00,0xf01e000,0x78000780,0x1e0000,0xf0003c,0x1e000f80,0xf0007c07,
      0x8003e03c,0x1f01e0,0xf80f00,0x7c1e01e,0x7c00,0xf0000,0x780000,0x3c00000,0x1e000000,0x780000,0x3c00000,0x1e000000,0xf0000f00,
      0xf003c00,0x3c03c003,0xc01e001e,0xf000f0,0x7800780,0x3c003c00,0x1f8000f,0xc00f003c,0x7c01e0,0x3e00f00,0x1f007800,0xf8001ef0,
      0x1f000f,0x7bc00,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x780000,0xf,0x3800040,0x30780003,0x8038f800,0x78000000,0x1e00,0x3c00,0x0,0x1e0000,0xfc0000,0x0,0x7e000078,
      0x780,0x1f00001e,0xfc00,0x20001f,0x780,0x80007c0,0x1f001e00,0x7c0000f,0x78000,0xf80007,0xe000003f,0x0,0x1e000000,0xf00000,
      0x3c000,0x3c03fff0,0xf0001e03,0xc001f007,0x800101e0,0x7e003c0,0x1e00,0x7800,0x781e0007,0x80007800,0x6000f00,0x3c003e00,0x7800001e,
      0xf078,0x1fe00f0,0x1e00780,0x3c00,0x78078000,0xf020001e,0xf000,0x7800780,0xff0001,0xfc07f00f,0x8007c000,0x780001f0,0x3c,0xf,
      0x1e0,0x0,0x0,0x0,0xf800fc01,0xf801f007,0xc00100f8,0x1f807c0,0x40003c,0xf807,0xf0078007,0x80003c00,0xf000,0x7803e00,0x1f0000f,
      0x3c0f01e,0x1e01f0,0x3e007e0,0x7c07c00,0xfc003c00,0x1e,0x3e000,0x3e007c0,0x1ff8000,0xfe0fe003,0xe03e0001,0xff0000fc,0x1e,
      0xf0,0x780,0x0,0x0,0x1f00080,0x3cf8000,0xfc00000,0x3c00001f,0x83f00000,0x18,0xc0,0x0,0xc06203,0x40003c0,0x1c00000,0xf80f0000,
      0x3cf8001f,0xf,0x3e000079,0xf0000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3c00000,0x700780fc,0x3cf8,0xfc000,0x1e000,0x0,0x780000,
      0x7c180000,0xf0000020,0x100007,0x8000003c,0xf,0x80000000,0x1f01f0,0x0,0x380700,0x0,0xf,0x80f80000,0x0,0x0,0x0,0x0,0x0,0x3e007c0,
      0xe1c00,0x0,0x0,0x0,0xe01,0xc0000071,0xc0000001,0xc0001c70,0x1e00040,0x1e0003c0,0xf0001e07,0x8000f03c,0x781e0,0x3c0f00,0x1e0f007,
      0x80007800,0x10078000,0x3c0000,0x1e00000,0xf000000,0xf00000,0x7800000,0x3c000001,0xe0001e00,0x7e00f003,0xfc01e003,0xc00f001e,
      0x7800f0,0x3c00780,0x1e003c00,0xe000700f,0x800f0078,0x7803c0,0x3c01e00,0x1e00f000,0xf0000780,0x1e0000,0xf0003c,0x1f001f80,
      0xf800fc07,0xc007e03e,0x3f01f0,0x1f80f80,0xfc1e01f,0x7c00,0x100f8000,0x807c0004,0x3e00020,0x1f000100,0x780000,0x3c00000,0x1e000000,
      0xf0000f80,0x1f003c00,0x3c03e007,0xc01f003e,0xf801f0,0x7c00f80,0x3e007c00,0x1f8000f,0x801f003e,0x7c01f0,0x3e00f80,0x1f007c00,
      0xf8001ff0,0x1f801f,0x7fc00,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x780000,0xf,0x7800078,0x31f80001,0xc070fc00,0xfc000000,0x1e00,0x7c00,0x0,0x1e0000,0xfc0000,0x0,0x7e000078,
      0x7c0,0x1f00001e,0x1f000,0x38003f,0x780,0xe000f80,0x1f803e00,0x780000f,0x800f8000,0x1f00007,0xe000003f,0x0,0x2000000,0x800000,
      0x3c000,0x3e01ff71,0xf0001f03,0xc007f007,0xc00301e0,0x1fc003c0,0x1e00,0x7c00,0x781e0007,0x80007800,0x7801f00,0x3c001f00,0x7800001e,
      0xf078,0xfe00f8,0x3e00780,0x3e00,0xf8078000,0xf838003e,0xf000,0x7c00f80,0xff0000,0xfc07e00f,0x8003c000,0x780001e0,0x3c,0xf,
      0x1e0,0x0,0x0,0x0,0xf801fc01,0xfc03e003,0xe003007c,0x3f803e0,0x1c0003c,0xfc0f,0xf0078007,0x80003c00,0xf000,0x7801f00,0xf8000f,
      0x3c0f01e,0x1e00f8,0x7c007f0,0xf803e01,0xfc003c00,0x8003e,0x1f000,0x1e00fc0,0xff0000,0xfe0fe007,0xc01f0000,0xfe0000f8,0x1e,
      0xf0,0x780,0x0,0x0,0xf80180,0x1cf0000,0x1f800000,0x3c00001f,0x83e00000,0x18,0xc0,0x0,0xc06203,0x70007c0,0xe00000,0x7e0f0000,
      0x1cf0001e,0x7,0x3c000039,0xe0000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x100,0x7c00000,0xe00780fc,0x2001cf0,0xf8000,0x1e000,0x0,
      0x780000,0x7e182000,0xf0000000,0x7,0x8000003c,0x7,0xc0000000,0x7ffc0,0x0,0x180300,0x0,0x3,0xffe00000,0x0,0x0,0x0,0x0,0x0,
      0x3f00fc0,0xe1c00,0x0,0x0,0x0,0xc01,0x800000e1,0xc0000003,0xc0003870,0x1f001c0,0x3e0003e1,0xf0001f0f,0x8000f87c,0x7c3e0,0x3e1f00,
      0x1f1e007,0x80007c00,0x30078000,0x3c0000,0x1e00000,0xf000000,0xf00000,0x7800000,0x3c000001,0xe0001e03,0xfc00f001,0xfc01f007,
      0xc00f803e,0x7c01f0,0x3e00f80,0x1f007c00,0x4000201f,0xc01f007c,0xf803e0,0x7c01f00,0x3e00f801,0xf0000780,0x1e0000,0xf0007c,
      0x1f003f80,0xf801fc07,0xc00fe03e,0x7f01f0,0x3f80f80,0x1fc1f03f,0x803e00,0x3007c003,0x803e001c,0x1f000e0,0xf800700,0x780000,
      0x3c00000,0x1e000000,0xf00007c0,0x3e003c00,0x3c01f00f,0x800f807c,0x7c03e0,0x3e01f00,0x1f00f800,0x1f80007,0xc03e001e,0xfc00f0,
      0x7e00780,0x3f003c01,0xf8000fe0,0x1fc03e,0x3f800,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,0x1e,0x780007f,0xfff00001,0xe0f07f03,0xfe000000,0xf00,0x7800,0x0,
      0x1e0000,0xfc0000,0x0,0x7e0000f0,0x3f0,0x7e000fff,0xfc03ffff,0xf83f00fe,0x780,0xfc03f80,0xfc0fc00,0xf800007,0xe03f0018,0x7e00007,
      0xe000003f,0x0,0x0,0x0,0x3c000,0x1e007c71,0xe0000f03,0xffffe003,0xf01f01ff,0xff8003ff,0xffe01e00,0x3f01,0xf81e0007,0x803ffff0,
      0x7e03f00,0x3c000f00,0x7ffffe1e,0xf078,0xfe007e,0xfc00780,0x1f83,0xf0078000,0x783f00fe,0xf000,0x3f03f00,0xff0000,0xfc07e01f,
      0x3e000,0x780003ff,0xfffc003c,0x7,0x800001e0,0x0,0x0,0x0,0x7e07fc01,0xfe07e001,0xf80f007e,0x7f801f8,0xfc0003c,0x7ffe,0xf0078007,
      0x807ffffe,0xf000,0x7801f00,0xfff00f,0x3c0f01e,0x1e00fc,0xfc007f8,0x1f803f03,0xfc003c00,0xf80fc,0x1fff0,0x1f83fc0,0xff0000,
      0xfc07e007,0xc01f0000,0xfe0001ff,0xffe0001e,0xf0,0x780,0x0,0x0,0xfe0780,0xfe0000,0x1f000000,0x3c00001f,0x7c00e03,0x81c00018,
      0xc0,0x0,0x406203,0x7e01fc0,0x700000,0x7fffff80,0xfe0003f,0xffffc003,0xf800001f,0xc0000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1f0,
      0x1f800001,0xc007c1fe,0x6000fe0,0x1ffffe,0x1e000,0x0,0x780000,0x3f98e03f,0xffff8000,0x7,0x8000003c,0x7,0xc0000000,0xfe00,
      0x0,0x80100,0x0,0x0,0x7f000000,0x0,0x1ffff,0xfe000000,0x0,0x0,0x3f83fe8,0xe1c00,0x0,0x0,0x0,0x801,0xc1,0xc0000007,0x80003070,
      0xfc0fc0,0x3c0001e1,0xe0000f0f,0x7878,0x3c3c0,0x1e1e00,0xf1e007,0xffc03f01,0xf007ffff,0xc03ffffe,0x1fffff0,0xfffff80,0x7fffe003,
      0xffff001f,0xfff800ff,0xffc01fff,0xf800f001,0xfc00fc1f,0x8007e0fc,0x3f07e0,0x1f83f00,0xfc1f800,0x1f,0xf07e003f,0x3f001f8,
      0x1f800fc0,0xfc007e07,0xe0000780,0x1e0000,0xf301f8,0xfc0ff80,0x7e07fc03,0xf03fe01f,0x81ff00fc,0xff807e0,0x7fc0f87f,0x81801f80,
      0xf003f01f,0x801f80fc,0xfc07e0,0x7e03f00,0xfffffc07,0xffffe03f,0xffff01ff,0xfff807e0,0x7e003c00,0x3c01f81f,0x800fc0fc,0x7e07e0,
      0x3f03f00,0x1f81f800,0x1f8000f,0xe07e001f,0x83fc00fc,0x1fe007e0,0xff003f07,0xf8000fe0,0x1fe07e,0x3f800,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,0x1e,0x780007f,
      0xffe00000,0xffe03fff,0xdf000000,0xf00,0x7800,0x0,0x0,0xfc0000,0x0,0x7e0000f0,0x1ff,0xfc000fff,0xfc03ffff,0xf83ffffc,0x780,
      0xfffff00,0x7fff800,0xf000007,0xffff001f,0xffe00007,0xe000003f,0x0,0x0,0x0,0x3c000,0x1e000001,0xe0000f03,0xffffc001,0xffff01ff,
      0xff0003ff,0xffe01e00,0x1fff,0xf81e0007,0x803ffff0,0x7fffe00,0x3c000f80,0x7ffffe1e,0xf078,0xfe003f,0xff800780,0xfff,0xf0078000,
      0x7c3ffffc,0xf000,0x3ffff00,0xff0000,0xf803e01e,0x1e000,0x780003ff,0xfffc003c,0x7,0x800001e0,0x0,0x0,0x0,0x7fffbc01,0xffffc000,
      0xffff003f,0xfff800ff,0xffc0003c,0x3ffe,0xf0078007,0x807ffffe,0xf000,0x7800f80,0x7ff00f,0x3c0f01e,0x1e007f,0xff8007ff,0xff001fff,
      0xbc003c00,0xffffc,0x1fff0,0x1fffbc0,0xff0000,0x7c07c00f,0x800f8000,0x7e0001ff,0xffe0001e,0xf0,0x780,0x0,0x0,0x7fff80,0x7c0000,
      0x1f000000,0x3c00001e,0x7c00f07,0xc1e00018,0xc0,0x0,0x60e303,0x7ffff80,0x380000,0x3fffff80,0x7c0003f,0xffffc001,0xf000000f,
      0x80000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1ff,0xff800003,0x8003ffff,0xfe0007c0,0x1ffffe,0x1e000,0x0,0x780000,0x1fffe03f,0xffff8000,
      0x7,0x8000003c,0x3,0xc0000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1ffff,0xfe000000,0x0,0x0,0x3fffdf8,0xe1c00,0x0,0x0,0x0,0x0,0x1c1,
      0xc000000f,0x7070,0x7fffc0,0x3c0001e1,0xe0000f0f,0x7878,0x3c3c0,0x1e1e00,0xf1e007,0xffc01fff,0xf007ffff,0xc03ffffe,0x1fffff0,
      0xfffff80,0x7fffe003,0xffff001f,0xfff800ff,0xffc01fff,0xf000f001,0xfc007fff,0x3fff8,0x1fffc0,0xfffe00,0x7fff000,0x3b,0xfffc003f,
      0xfff001ff,0xff800fff,0xfc007fff,0xe0000780,0x1e0000,0xf3fff8,0xffff780,0x7fffbc03,0xfffde01f,0xffef00ff,0xff7807ff,0xfbc0ffff,
      0xff800fff,0xf001ffff,0x800ffffc,0x7fffe0,0x3ffff00,0xfffffc07,0xffffe03f,0xffff01ff,0xfff803ff,0xfc003c00,0x3c00ffff,0x7fff8,
      0x3fffc0,0x1fffe00,0xffff000,0x1f,0xfffc001f,0xffbc00ff,0xfde007ff,0xef003fff,0x780007e0,0x1ffffc,0x1f800,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,0x1e,0x700003f,
      0xffc00000,0x7fc01fff,0x9f800000,0xf80,0xf800,0x0,0x0,0xfc0000,0x0,0x7e0000f0,0xff,0xf8000fff,0xfc03ffff,0xf83ffff8,0x780,
      0xffffe00,0x7fff000,0xf000003,0xfffe001f,0xffc00007,0xe000003f,0x0,0x0,0x0,0x3c000,0xf000003,0xe0000f83,0xffff0000,0xffff01ff,
      0xfc0003ff,0xffe01e00,0xfff,0xf01e0007,0x803ffff0,0x7fffc00,0x3c0007c0,0x7ffffe1e,0xf078,0x7e003f,0xff000780,0x7ff,0xe0078000,
      0x3c3ffff8,0xf000,0x1fffe00,0x7e0000,0xf803e03e,0x1f000,0x780003ff,0xfffc003c,0x7,0x800001e0,0x0,0x0,0x0,0x3fff3c01,0xefff8000,
      0x7ffe001f,0xff78007f,0xff80003c,0x1ffc,0xf0078007,0x807ffffe,0xf000,0x78007c0,0x3ff00f,0x3c0f01e,0x1e003f,0xff0007bf,0xfe000fff,
      0xbc003c00,0xffff8,0xfff0,0xfff3c0,0x7e0000,0x7c07c01f,0x7c000,0x7c0001ff,0xffe0001e,0xf0,0x780,0x0,0x0,0x3fff80,0x380000,
      0x3e000000,0x7c00003e,0x7801f07,0xc1e00018,0xc0,0x0,0x39c1ce,0x7ffff00,0x1c0000,0xfffff80,0x380003f,0xffffc000,0xe0000007,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1ff,0xff000007,0x1ffcf,0xfe000380,0x1ffffe,0x1e000,0x0,0x780000,0xfffe03f,0xffff8000,0x7,
      0x8000003c,0x3,0xc0000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1ffff,0xfe000000,0x0,0x0,0x3dffdf8,0xe1c00,0x0,0x0,0x0,0x0,0x381,
      0xc000001e,0xe070,0x7fff80,0x7c0001f3,0xe0000f9f,0x7cf8,0x3e7c0,0x1f3e00,0xfbe007,0xffc00fff,0xf007ffff,0xc03ffffe,0x1fffff0,
      0xfffff80,0x7fffe003,0xffff001f,0xfff800ff,0xffc01fff,0xc000f000,0xfc007ffe,0x3fff0,0x1fff80,0xfffc00,0x7ffe000,0x79,0xfff8001f,
      0xffe000ff,0xff0007ff,0xf8003fff,0xc0000780,0x1e0000,0xf3fff0,0x7ffe780,0x3fff3c01,0xfff9e00f,0xffcf007f,0xfe7803ff,0xf3c07ff3,
      0xff8007ff,0xe000ffff,0x7fff8,0x3fffc0,0x1fffe00,0xfffffc07,0xffffe03f,0xffff01ff,0xfff801ff,0xf8003c00,0x3c007ffe,0x3fff0,
      0x1fff80,0xfffc00,0x7ffe000,0x1d,0xfff8000f,0xff3c007f,0xf9e003ff,0xcf001ffe,0x780007c0,0x1efff8,0x1f000,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780000,0x1e,0xf000003,
      0xfe000000,0x1f000fff,0xfc00000,0x780,0xf000,0x0,0x0,0xf80000,0x0,0x7e0001e0,0x7f,0xf0000fff,0xfc03ffff,0xf81ffff0,0x780,
      0x7fff800,0x1ffe000,0x1f000000,0xfff8001f,0xff000007,0xe000003e,0x0,0x0,0x0,0x3c000,0xf800003,0xc0000783,0xfff80000,0x3ffe01ff,
      0xe00003ff,0xffe01e00,0x7ff,0xc01e0007,0x803ffff0,0x3fff800,0x3c0003c0,0x7ffffe1e,0xf078,0x7e000f,0xfe000780,0x3ff,0xc0078000,
      0x3e1fffe0,0xf000,0x7ff800,0x7e0000,0xf803e07c,0xf800,0x780003ff,0xfffc003c,0x3,0xc00001e0,0x0,0x0,0x0,0xffe3c01,0xe7ff0000,
      0x3ffc000f,0xfe78003f,0xfe00003c,0x7f0,0xf0078007,0x807ffffe,0xf000,0x78003e0,0xff00f,0x3c0f01e,0x1e001f,0xfe00079f,0xfc0007ff,
      0x3c003c00,0x7ffe0,0x1ff0,0x7fe3c0,0x7e0000,0x7c07c03e,0x3e000,0x7c0001ff,0xffe0001e,0xf0,0x780,0x0,0x0,0xfff00,0x100000,
      0x3e000000,0x7800003c,0xf800f07,0xc1e00018,0xc0,0x0,0x1f80fc,0x3fffc00,0xc0000,0x3ffff80,0x100003f,0xffffc000,0x40000002,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xfc000006,0xff87,0xfc000100,0x1ffffe,0x1e000,0x0,0x780000,0x3ffc03f,0xffff8000,0x7,
      0x8000003c,0x3,0xc0000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1ffff,0xfe000000,0x0,0x0,0x3dff9f8,0xe1c00,0x0,0x0,0x0,0x0,0x3ff,
      0xf800003c,0xfffe,0x1ffe00,0x780000f3,0xc000079e,0x3cf0,0x1e780,0xf3c00,0x7bc007,0xffc003ff,0xe007ffff,0xc03ffffe,0x1fffff0,
      0xfffff80,0x7fffe003,0xffff001f,0xfff800ff,0xffc01ffc,0xf000,0xfc001ffc,0xffe0,0x7ff00,0x3ff800,0x1ffc000,0x70,0xfff00007,
      0xff80003f,0xfc0001ff,0xe0000fff,0x780,0x1e0000,0xf3ffe0,0x1ffc780,0xffe3c00,0x7ff1e003,0xff8f001f,0xfc7800ff,0xe3c03fe1,
      0xff0003ff,0xc0007ffc,0x3ffe0,0x1fff00,0xfff800,0xfffffc07,0xffffe03f,0xffff01ff,0xfff800ff,0xf0003c00,0x3c003ffc,0x1ffe0,
      0xfff00,0x7ff800,0x3ffc000,0x38,0xfff00007,0xfe3c003f,0xf1e001ff,0x8f000ffc,0x780007c0,0x1e7ff0,0x1f000,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x30000000,
      0x1fc,0x0,0x780,0xf000,0x0,0x0,0x1f80000,0x0,0x1e0,0x1f,0xc0000000,0x0,0x1ff80,0x0,0xffc000,0x7f8000,0x0,0x3fe00007,0xfc000000,
      0x7e,0x0,0x0,0x0,0x0,0x7c00000,0x0,0x0,0xff00000,0x0,0x0,0xfe,0x0,0x0,0x3fc000,0x0,0x0,0x0,0x3,0xf8000000,0xff,0xc0000000,
      0x1ff00,0x0,0x1fe000,0x0,0x0,0x0,0x0,0x3c,0x3,0xc00001e0,0x0,0x0,0x0,0x3f80000,0x1fc0000,0x7f00003,0xf8000007,0xf0000000,
      0x0,0xf0000000,0x0,0xf000,0x0,0x0,0x0,0x7,0xf8000787,0xf00001fc,0x3c000000,0x7f80,0x0,0x1f8000,0x0,0x0,0x0,0x7c000000,0x1e,
      0xf0,0x780,0x0,0x0,0x3fc00,0x0,0x3c000000,0x7800003c,0xf000601,0xc00018,0xc0,0x0,0x0,0x3fe000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0xf,0xf0000000,0x7e03,0xf0000000,0x0,0x0,0x0,0x0,0xfe0000,0x0,0x0,0x3c,0x2007,0x80000000,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3c7e0f0,0xe1c00,0x0,0x3800000,0x0,0x0,0x3ff,0xf8000078,0xfffe,0x7f800,0x0,0x0,0x0,0x0,
      0x0,0x0,0xff,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x7f0,0x3f80,0x1fc00,0xfe000,0x7f0000,0x70,0x3fc00001,0xfe00000f,0xf000007f,
      0x800003fc,0x0,0x0,0xff00,0x7f0000,0x3f80000,0x1fc00000,0xfe000007,0xf000003f,0x80001f80,0xfc00007f,0xfe0,0x7f00,0x3f800,
      0x1fc000,0x0,0x0,0x0,0x3f,0xc0000000,0xff0,0x7f80,0x3fc00,0x1fe000,0xff0000,0x78,0x3fc00001,0xf800000f,0xc000007e,0x3f0,0x7c0,
      0x1e1fc0,0x1f000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x30000000,0x0,0x0,0x3c0,0x1e000,0x0,0x0,0x1f00000,0x0,0x3c0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x7c,0x0,0x0,0x0,0x0,0x3e00000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x7,0xe0000000,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x3c,0x1,0xe00001e0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xf0000000,0x0,0xf000,0x0,0x0,0x0,0x0,0x780,0x0,0x3c000000,
      0x0,0x0,0x0,0x0,0x0,0x0,0x78000000,0x1e,0xf0,0x780,0x0,0x0,0x0,0x0,0x3c000000,0x78000078,0xf000000,0x18,0xc0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x180000,0x0,0x0,0x3c,0x3c0f,0x80000000,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3c00000,0xe1c00,0x0,0x1800000,0x0,0x0,0x3ff,0xf80000f0,0xfffe,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0xc,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x20,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0xc,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x30,0x0,0x0,0x0,0x0,0x780,0x1e0000,0x1e000,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x30000000,
      0x0,0x0,0x3c0,0x1e000,0x0,0x0,0x1f00000,0x0,0x3c0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x7c,0x0,0x0,0x0,0x0,0x1f80000,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3,0xf0000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3c,0x1,0xe00001e0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0xe0000000,0x0,0xf000,0x0,0x0,0x0,0x0,0x780,0x0,0x3c000000,0x0,0x0,0x0,0x0,0x0,0x0,0xf8000000,
      0x1f,0xf0,0xf80,0x0,0x0,0x0,0x0,0x78000000,0xf8000078,0x1e000000,0x8,0x40,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x180000,0x0,0x0,0x3c,0x3fff,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x3c00000,0xe1c00,0x0,0x1c00000,0x0,0x0,0x1,0xc00001e0,0x70,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xe,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xe,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xf80,0x1e0000,0x3e000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x30000000,0x0,0x0,0x1e0,0x3c000,0x0,0x0,0x1f00000,
      0x0,0x780,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x7c,0x0,0x0,0x0,0x0,0xfe0100,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0xf8000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3f,0xf0000000,0xf0007fe0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0xe0000000,
      0x0,0xf000,0x0,0x0,0x0,0x0,0x780,0x0,0x3c000000,0x0,0x0,0x0,0x0,0x0,0x0,0xf0000000,0x1f,0x800000f0,0x1f80,0x0,0x0,0x0,0x0,
      0x78000000,0xf0000070,0x1c000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x180000,0x0,0x0,0x3c,0x3ffe,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3c00000,0xe1c00,0x0,0xe00000,
      0x0,0x0,0x1,0xc00003ff,0xe0000070,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0xf00,0x1e0000,0x3c000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x30000000,0x0,0x0,0x1e0,0x7c000,0x0,0x0,0x1e00000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x78,0x0,0x0,0x0,0x0,0x7fff80,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x78000000,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3f,0xf0000000,0x7fe0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x4003,0xe0000000,0x0,0x1f000,0x0,0x0,
      0x0,0x0,0x780,0x0,0x3c000000,0x0,0x0,0x0,0x0,0x0,0x1,0xf0000000,0xf,0xfc0000f0,0x3ff00,0x0,0x0,0x0,0x0,0x70000001,0xf00000e0,
      0x1c000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x180000,
      0x0,0x0,0x3c,0xff8,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3c00000,0xe1c00,0x0,0xe00000,0x0,0x0,0x1,0xc00003ff,
      0xe0000070,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1f00,0x1e0000,
      0x7c000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x30000000,0x0,0x0,0xf0,0x78000,0x0,0x0,0x3e00000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xf8,0x0,
      0x0,0x0,0x0,0x1fff80,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x20000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3f,
      0xf0000000,0x7fe0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x780f,0xc0000000,0x0,0x3e000,0x0,0x0,0x0,0x0,0x780,0x0,0x3c000000,0x0,
      0x0,0x0,0x0,0x0,0x3,0xe0000000,0xf,0xfc0000f0,0x3ff00,0x0,0x0,0x0,0x0,0xf0000103,0xe0000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x180000,0x0,0x0,0x3c,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3c00000,0x0,0x0,0x21e00000,0x0,0x0,0x1,0xc00003ff,0xe0000070,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x10f,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x10f,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3e00,0x1e0000,0xf8000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x30000000,0x0,0x0,
      0xf8,0xf8000,0x0,0x0,0x3c00000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,0x0,0x1fe00,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3f,0xf0000000,0x7fe0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x7fff,0xc0000000,0x0,0x3ffe000,0x0,0x0,0x0,0x0,0x780,0x0,0x3c000000,0x0,0x0,0x0,0x0,0x0,0x7f,0xe0000000,0x7,0xfc0000f0,
      0x3fe00,0x0,0x0,0x0,0x0,0x600001ff,0xe0000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x180000,0x0,0x0,0x3c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3c00000,0x0,0x0,
      0x3fe00000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1ff,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1ff,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x7fe00,0x1e0000,0x1ff8000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x1fffffe0,0x0,0x0,0x0,0x0,0x0,0x0,0x7fff,0x80000000,0x0,0x3ffc000,0x0,0x0,0x0,0x0,0x780,0x0,0x3c000000,0x0,
      0x0,0x0,0x0,0x0,0x7f,0xc0000000,0x0,0xfc0000f0,0x3f000,0x0,0x0,0x0,0x0,0x1ff,0xc0000000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x3c00000,0x0,0x0,0x3fc00000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1fe,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1fe,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x7fc00,0x1e0000,0x1ff0000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1fffffe0,0x0,0x0,0x0,0x0,0x0,0x0,0x3ffe,0x0,0x0,0x3ff8000,0x0,0x0,0x0,
      0x0,0x780,0x0,0x3c000000,0x0,0x0,0x0,0x0,0x0,0x7f,0x80000000,0x0,0xf0,0x0,0x0,0x0,0x0,0x0,0x1ff,0x80000000,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3c00000,0x0,0x0,0x3f800000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1fc,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1fc,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x7f800,0x1e0000,0x1fe0000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1fffffe0,0x0,0x0,0x0,0x0,0x0,0x0,0x7f8,0x0,0x0,0x3fe0000,
      0x0,0x0,0x0,0x0,0x780,0x0,0x3c000000,0x0,0x0,0x0,0x0,0x0,0x7e,0x0,0x0,0xf0,0x0,0x0,0x0,0x0,0x0,0xfe,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3c00000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x7e000,0x1e0000,0x1f80000,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1fffffe0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
      0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0 };

    // Define a 40x38 'danger' color logo (used by cimg::dialog()).
    const unsigned char logo40x38[4576] = {
      177,200,200,200,3,123,123,0,36,200,200,200,1,123,123,0,2,255,255,0,1,189,189,189,1,0,0,0,34,200,200,200,
      1,123,123,0,4,255,255,0,1,189,189,189,1,0,0,0,1,123,123,123,32,200,200,200,1,123,123,0,5,255,255,0,1,0,0,
      0,2,123,123,123,30,200,200,200,1,123,123,0,6,255,255,0,1,189,189,189,1,0,0,0,2,123,123,123,29,200,200,200,
      1,123,123,0,7,255,255,0,1,0,0,0,2,123,123,123,28,200,200,200,1,123,123,0,8,255,255,0,1,189,189,189,1,0,0,0,
      2,123,123,123,27,200,200,200,1,123,123,0,9,255,255,0,1,0,0,0,2,123,123,123,26,200,200,200,1,123,123,0,10,255,
      255,0,1,189,189,189,1,0,0,0,2,123,123,123,25,200,200,200,1,123,123,0,3,255,255,0,1,189,189,189,3,0,0,0,1,189,
      189,189,3,255,255,0,1,0,0,0,2,123,123,123,24,200,200,200,1,123,123,0,4,255,255,0,5,0,0,0,3,255,255,0,1,189,
      189,189,1,0,0,0,2,123,123,123,23,200,200,200,1,123,123,0,4,255,255,0,5,0,0,0,4,255,255,0,1,0,0,0,2,123,123,123,
      22,200,200,200,1,123,123,0,5,255,255,0,5,0,0,0,4,255,255,0,1,189,189,189,1,0,0,0,2,123,123,123,21,200,200,200,
      1,123,123,0,5,255,255,0,5,0,0,0,5,255,255,0,1,0,0,0,2,123,123,123,20,200,200,200,1,123,123,0,6,255,255,0,5,0,0,
      0,5,255,255,0,1,189,189,189,1,0,0,0,2,123,123,123,19,200,200,200,1,123,123,0,6,255,255,0,1,123,123,0,3,0,0,0,1,
      123,123,0,6,255,255,0,1,0,0,0,2,123,123,123,18,200,200,200,1,123,123,0,7,255,255,0,1,189,189,189,3,0,0,0,1,189,
      189,189,6,255,255,0,1,189,189,189,1,0,0,0,2,123,123,123,17,200,200,200,1,123,123,0,8,255,255,0,3,0,0,0,8,255,255,
      0,1,0,0,0,2,123,123,123,16,200,200,200,1,123,123,0,9,255,255,0,1,123,123,0,1,0,0,0,1,123,123,0,8,255,255,0,1,189,
      189,189,1,0,0,0,2,123,123,123,15,200,200,200,1,123,123,0,9,255,255,0,1,189,189,189,1,0,0,0,1,189,189,189,9,255,255,
      0,1,0,0,0,2,123,123,123,14,200,200,200,1,123,123,0,11,255,255,0,1,0,0,0,10,255,255,0,1,189,189,189,1,0,0,0,2,123,
      123,123,13,200,200,200,1,123,123,0,23,255,255,0,1,0,0,0,2,123,123,123,12,200,200,200,1,123,123,0,11,255,255,0,1,189,
      189,189,2,0,0,0,1,189,189,189,9,255,255,0,1,189,189,189,1,0,0,0,2,123,123,123,11,200,200,200,1,123,123,0,11,255,255,
      0,4,0,0,0,10,255,255,0,1,0,0,0,2,123,123,123,10,200,200,200,1,123,123,0,12,255,255,0,4,0,0,0,10,255,255,0,1,189,189,
      189,1,0,0,0,2,123,123,123,9,200,200,200,1,123,123,0,12,255,255,0,1,189,189,189,2,0,0,0,1,189,189,189,11,255,255,0,1,
      0,0,0,2,123,123,123,9,200,200,200,1,123,123,0,27,255,255,0,1,0,0,0,3,123,123,123,8,200,200,200,1,123,123,0,26,255,
      255,0,1,189,189,189,1,0,0,0,3,123,123,123,9,200,200,200,1,123,123,0,24,255,255,0,1,189,189,189,1,0,0,0,4,123,123,
      123,10,200,200,200,1,123,123,0,24,0,0,0,5,123,123,123,12,200,200,200,27,123,123,123,14,200,200,200,25,123,123,123,86,
      200,200,200,91,49,124,118,124,71,32,124,95,49,56,114,52,82,121,0};

    //! Get/set default output stream for the \CImg library messages.
    /**
       \param file Desired output stream. Set to \c 0 to get the currently used output stream only.
       \return Currently used output stream.
    **/
    inline std::FILE* output(std::FILE *file) {
      cimg::mutex(1);
      static std::FILE *res = stderr;
      if (file) res = file;
      cimg::mutex(1,0);
      return res;
    }

    // Return number of available CPU cores.
    inline unsigned int nb_cpus() {
      unsigned int res = 1;
#if cimg_OS==2
      SYSTEM_INFO sysinfo;
      GetSystemInfo(&sysinfo);
      res = (unsigned int)sysinfo.dwNumberOfProcessors;
#else
# 4078 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      res = (unsigned int)sysconf(_SC_NPROCESSORS_ONLN);
#endif
# 4080 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      return res?res:1U;
    }

    // Lock/unlock mutex for CImg multi-thread programming.
    inline int mutex(const unsigned int n, const int lock_mode) {
      switch (lock_mode) {
      case 0 : cimg::Mutex_attr().unlock(n); return 0;
      case 1 : cimg::Mutex_attr().lock(n); return 0;
      default : return cimg::Mutex_attr().trylock(n);
      }
    }

    //! Display a warning message on the default output stream.
    /**
       \param format C-string containing the format of the message, as with <tt>std::printf()</tt>.
       \note If configuration macro \c cimg_strict_warnings is set, this function throws a \c CImgWarningException instead.
       \warning As the first argument is a format string, it is highly recommended to write
       \code
       cimg::warn("%s",warning_message);
       \endcode
       instead of
       \code
       cimg::warn(warning_message);
       \endcode
       if \c warning_message can be arbitrary, to prevent nasty memory access.
    **/
    inline void warn(const char *const format, ...) {
      if (cimg::exception_mode()>=1) {
        char message[16384] = { 0 };
        std::va_list ap;
        va_start(ap,format);
        cimg_vsnprintf(message,sizeof(message),format,ap);
        va_end(ap);
#ifdef cimg_strict_warnings
        throw CImgWarningException(message);
#else
# 4116 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        std::fprintf(cimg::output(),"\n%s[CImg] *** Warning ***%s%s",cimg::t_red,cimg::t_normal,message);
#endif
# 4118 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      }
    }

    // Execute an external system command.
    /**
       \param command C-string containing the command line to execute.
       \param module_name Module name.
       \return Status value of the executed command, whose meaning is OS-dependent.
       \note This function is similar to <tt>std::system()</tt>
       but it does not open an extra console windows
       on Windows-based systems.
    **/
    inline int system(const char *const command, const char *const module_name=0) {
#ifdef cimg_no_system_calls
      return -1;
#else
# 4134 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#if cimg_OS==2
      PROCESS_INFORMATION pi;
      STARTUPINFO si;
      std::memset(&pi,0,sizeof(PROCESS_INFORMATION));
      std::memset(&si,0,sizeof(STARTUPINFO));
      GetStartupInfo(&si);
      si.cb = sizeof(si);
      si.wShowWindow = SW_HIDE;
      si.dwFlags |= SW_HIDE | STARTF_USESHOWWINDOW;
      const BOOL res = CreateProcess((LPCTSTR)module_name,(LPTSTR)command,0,0,FALSE,0,0,0,&si,&pi);
      if (res) {
        WaitForSingleObject(pi.hProcess, INFINITE);
        CloseHandle(pi.hThread);
        CloseHandle(pi.hProcess);
        return 0;
      } else
#endif
# 4151 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        return std::system(command);
      return module_name?0:1;
#endif
# 4154 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    }

    //! Return a reference to a temporary variable of type T.
    template<typename T>
    inline T& temporary(const T&) {
      static T temp;
      return temp;
    }

    //! Exchange values of variables \c a and \c b.
    template<typename T>
    inline void swap(T& a, T& b) { T t = a; a = b; b = t; }

    //! Exchange values of variables (\c a1,\c a2) and (\c b1,\c b2).
    template<typename T1, typename T2>
    inline void swap(T1& a1, T1& b1, T2& a2, T2& b2) {
      cimg::swap(a1,b1); cimg::swap(a2,b2);
    }

    //! Exchange values of variables (\c a1,\c a2,\c a3) and (\c b1,\c b2,\c b3).
    template<typename T1, typename T2, typename T3>
    inline void swap(T1& a1, T1& b1, T2& a2, T2& b2, T3& a3, T3& b3) {
      cimg::swap(a1,b1,a2,b2); cimg::swap(a3,b3);
    }

    //! Exchange values of variables (\c a1,\c a2,...,\c a4) and (\c b1,\c b2,...,\c b4).
    template<typename T1, typename T2, typename T3, typename T4>
    inline void swap(T1& a1, T1& b1, T2& a2, T2& b2, T3& a3, T3& b3, T4& a4, T4& b4) {
      cimg::swap(a1,b1,a2,b2,a3,b3); cimg::swap(a4,b4);
    }

    //! Exchange values of variables (\c a1,\c a2,...,\c a5) and (\c b1,\c b2,...,\c b5).
    template<typename T1, typename T2, typename T3, typename T4, typename T5>
    inline void swap(T1& a1, T1& b1, T2& a2, T2& b2, T3& a3, T3& b3, T4& a4, T4& b4, T5& a5, T5& b5) {
      cimg::swap(a1,b1,a2,b2,a3,b3,a4,b4); cimg::swap(a5,b5);
    }

    //! Exchange values of variables (\c a1,\c a2,...,\c a6) and (\c b1,\c b2,...,\c b6).
    template<typename T1, typename T2, typename T3, typename T4, typename T5, typename T6>
    inline void swap(T1& a1, T1& b1, T2& a2, T2& b2, T3& a3, T3& b3, T4& a4, T4& b4, T5& a5, T5& b5, T6& a6, T6& b6) {
      cimg::swap(a1,b1,a2,b2,a3,b3,a4,b4,a5,b5); cimg::swap(a6,b6);
    }

    //! Exchange values of variables (\c a1,\c a2,...,\c a7) and (\c b1,\c b2,...,\c b7).
    template<typename T1, typename T2, typename T3, typename T4, typename T5, typename T6, typename T7>
    inline void swap(T1& a1, T1& b1, T2& a2, T2& b2, T3& a3, T3& b3, T4& a4, T4& b4, T5& a5, T5& b5, T6& a6, T6& b6,
                     T7& a7, T7& b7) {
      cimg::swap(a1,b1,a2,b2,a3,b3,a4,b4,a5,b5,a6,b6); cimg::swap(a7,b7);
    }

    //! Exchange values of variables (\c a1,\c a2,...,\c a8) and (\c b1,\c b2,...,\c b8).
    template<typename T1, typename T2, typename T3, typename T4, typename T5, typename T6, typename T7, typename T8>
    inline void swap(T1& a1, T1& b1, T2& a2, T2& b2, T3& a3, T3& b3, T4& a4, T4& b4, T5& a5, T5& b5, T6& a6, T6& b6,
                     T7& a7, T7& b7, T8& a8, T8& b8) {
      cimg::swap(a1,b1,a2,b2,a3,b3,a4,b4,a5,b5,a6,b6,a7,b7); cimg::swap(a8,b8);
    }

    //! Return the endianness of the current architecture.
    /**
       \return \c false for <i>Little Endian</i> or \c true for <i>Big Endian</i>.
    **/
    inline bool endianness() {
      const int x = 1;
      return ((unsigned char*)&x)[0]?false:true;
    }

    //! Reverse endianness of all elements in a memory buffer.
    /**
       \param[in,out] buffer Memory buffer whose endianness must be reversed.
       \param size Number of buffer elements to reverse.
    **/
    template<typename T>
    inline void invert_endianness(T* const buffer, const unsigned long size) {
      if (size) switch (sizeof(T)) {
      case 1 : break;
      case 2 : { for (unsigned short *ptr = (unsigned short*)buffer+size; ptr>(unsigned short*)buffer; ) {
        const unsigned short val = *(--ptr);
        *ptr = (unsigned short)((val>>8)|((val<<8)));
      }
      } break;
      case 4 : { for (unsigned int *ptr = (unsigned int*)buffer+size; ptr>(unsigned int*)buffer; ) {
        const unsigned int val = *(--ptr);
        *ptr = (val>>24)|((val>>8)&0xff00)|((val<<8)&0xff0000)|(val<<24);
      }
      } break;
      default : { for (T* ptr = buffer+size; ptr>buffer; ) {
        unsigned char *pb = (unsigned char*)(--ptr), *pe = pb + sizeof(T);
        for (int i = 0; i<(int)sizeof(T)/2; ++i) swap(*(pb++),*(--pe));
      }
      }
      }
    }

    //! Reverse endianness of a single variable.
    /**
       \param[in,out] a Variable to reverse.
       \return Reference to reversed variable.
    **/
    template<typename T>
    inline T& invert_endianness(T& a) {
      invert_endianness(&a,1);
      return a;
    }

    // Conversion functions to get more precision when trying to store unsigned ints values as floats.
    inline unsigned int float2uint(const float f) {
      int tmp = 0;
      std::memcpy(&tmp,&f,sizeof(float));
      if (tmp>=0) return (unsigned int)f;
      unsigned int u;
      std::memcpy(&u,&f,sizeof(float));  // use memcpy instead of assignment to avoid undesired optimizations by C++-compiler.
      return ((u)<<1)>>1; // set sign bit to 0.
    }

    inline float uint2float(const unsigned int u) {
      if (u<(1U<<19)) return (float)u;  // Consider safe storage of unsigned int as floats until 19bits (i.e 524287).
      float f;
      const unsigned int v = u|(1U<<(8*sizeof(unsigned int)-1)); // set sign bit to 1.
      std::memcpy(&f,&v,sizeof(float)); // use memcpy instead of simple assignment to avoid undesired optimizations by C++-compiler.
      return f;
    }

    //! Return the value of a system timer, with a millisecond precision.
    /**
       \note The timer does not necessarily starts from \c 0.
    **/
    inline unsigned long time() {
#if cimg_OS==1
      struct timeval st_time;
      gettimeofday(&st_time,0);
      return (unsigned long)(st_time.tv_usec/1000 + st_time.tv_sec*1000);
#elif cimg_OS==2
# 4286 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      SYSTEMTIME st_time;
      GetSystemTime(&st_time);
      return (unsigned long)(st_time.wMilliseconds + 1000*(st_time.wSecond + 60*(st_time.wMinute + 60*st_time.wHour)));
#else
# 4290 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      return 0;
#endif
# 4292 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    }

    // Implement a tic/toc mechanism to display elapsed time of algorithms.
    inline unsigned long tictoc(const bool is_tic);

    //! Start tic/toc timer for time measurement between code instructions.
    /**
       \return Current value of the timer (same value as time()).
    **/
    inline unsigned long tic() {
      return cimg::tictoc(true);
    }

    //! End tic/toc timer and displays elapsed time from last call to tic().
    /**
       \return Time elapsed (in ms) since last call to tic().
    **/
    inline unsigned long toc() {
      return cimg::tictoc(false);
    }

    //! Sleep for a given numbers of milliseconds.
    /**
       \param milliseconds Number of milliseconds to wait for.
       \note This function frees the CPU ressources during the sleeping time.
       It can be used to temporize your program properly, without wasting CPU time.
    **/
    inline void sleep(const unsigned int milliseconds) {
#if cimg_OS==1
      struct timespec tv;
      tv.tv_sec = milliseconds/1000;
      tv.tv_nsec = (milliseconds%1000)*1000000;
      nanosleep(&tv,0);
#elif cimg_OS==2
# 4326 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      Sleep(milliseconds);
#endif
# 4328 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    }

    inline unsigned int _wait(const unsigned int milliseconds, unsigned long& timer) {
      if (!timer) timer = cimg::time();
      const unsigned long current_time = cimg::time();
      if (current_time>=timer+milliseconds) { timer = current_time; return 0; }
      const unsigned long time_diff = timer + milliseconds - current_time;
      timer = current_time + time_diff;
      cimg::sleep(time_diff);
      return (unsigned int)time_diff;
    }

    //! Wait for a given number of milliseconds since the last call to wait().
    /**
       \param milliseconds Number of milliseconds to wait for.
       \return Number of milliseconds elapsed since the last call to wait().
       \note Same as sleep() with a waiting time computed with regard to the last call
       of wait(). It may be used to temporize your program properly, without wasting CPU time.
    **/
    inline unsigned int wait(const unsigned int milliseconds) {
      cimg::mutex(3);
      static unsigned long timer = 0;
      if (!timer) timer = cimg::time();
      cimg::mutex(3,0);
      return _wait(milliseconds,timer);
    }

    // Random number generators.
    // CImg may use its own Random Number Generator (RNG) if configuration macro 'cimg_use_rng' is set.
    // Use it for instance when you have to deal with concurrent threads trying to call std::srand()
    // at the same time!
#ifdef cimg_use_rng

#if 0 /* expanded by -frewrite-includes */
#include <stdint.h>
#endif /* expanded by -frewrite-includes */
# 4362 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    // Use a custom RNG.
    inline unsigned int _rand(const unsigned int seed=0, const bool set_seed=false) {
      static unsigned long next = 1;
      cimg::mutex(4);
      if (set_seed) next = (unsigned long)seed;
      next = next*1103515245 + 12345 + rand();
      cimg::mutex(4,0);
      return (unsigned int)((next>>16)&0x7FFF);
    }

    inline void srand() {
      const unsigned int t = (unsigned int)cimg::time();
#if cimg_OS==1
      cimg::_rand(t+(unsigned int)getpid(),true);
#elif cimg_OS==2
# 4378 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      cimg::_rand(t+(unsigned int)_getpid(),true);
#else
# 4380 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      cimg::_rand(t,true);
#endif
# 4382 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    }

    inline void srand(const unsigned int seed) {
      _rand(seed,true);
    }

    inline double rand() {
      return cimg::_rand()/32767.;
    }

#else
# 4393 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    // Use the system RNG.
    inline void srand() {
      const unsigned int t = (unsigned int)cimg::time();
#if cimg_OS==1
      std::srand(t+(unsigned int)getpid());
#elif cimg_OS==2
# 4400 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      std::srand(t+(unsigned int)_getpid());
#else
# 4402 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      std::srand(t);
#endif
# 4404 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    }

    inline void srand(const unsigned int seed) {
      std::srand(seed);
    }

    //! Return a random variable between [0,1] with respect to an uniform distribution.
    /**
    **/
    inline double rand() {
      return (double)std::rand()/RAND_MAX;
    }
#endif
# 4417 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    //! Return a random variable between [-1,1] with respect to an uniform distribution.
    /**
    **/
    inline double crand() {
      return 1-2*cimg::rand();
    }

    //! Return a random variable following a gaussian distribution and a standard deviation of 1.
    /**
    **/
    inline double grand() {
      double x1, w;
      do {
        const double x2 = 2*cimg::rand() - 1.0;
        x1 = 2*cimg::rand()-1.0;
        w = x1*x1 + x2*x2;
      } while (w<=0 || w>=1.0);
      return x1*std::sqrt((-2*std::log(w))/w);
    }

    //! Return a random variable following a Poisson distribution of parameter z.
    /**
    **/
    inline unsigned int prand(const double z) {
      if (z<=1.0e-10) return 0;
      if (z>100) return (unsigned int)((std::sqrt(z) * cimg::grand()) + z);
      unsigned int k = 0;
      const double y = std::exp(-z);
      for (double s = 1.0; s>=y; ++k) s*=cimg::rand();
      return k-1;
    }

    //! Bitwise-rotate value on the left.
    template<typename T>
    inline T rol(const T a, const unsigned int n=1) {
      return n?(T)((a<<n)|(a>>((sizeof(T)<<3)-n))):a;
    }

    inline float rol(const float a, const unsigned int n=1) {
      return (float)rol((int)a,n);
    }

    inline double rol(const double a, const unsigned int n=1) {
      return (double)rol((long)a,n);
    }

    //! Bitwise-rotate value on the right.
    template<typename T>
    inline T ror(const T a, const unsigned int n=1) {
      return n?(T)((a>>n)|(a<<((sizeof(T)<<3)-n))):a;
    }

    inline float ror(const float a, const unsigned int n=1) {
      return (float)ror((int)a,n);
    }

    inline double ror(const double a, const unsigned int n=1) {
      return (double)ror((long)a,n);
    }

    //! Return absolute value of a value.
    template<typename T>
    inline T abs(const T a) {
      return a>=0?a:-a;
    }
    inline bool abs(const bool a) {
      return a;
    }
    inline unsigned char abs(const unsigned char a) {
      return a;
    }
    inline unsigned short abs(const unsigned short a) {
      return a;
    }
    inline unsigned int abs(const unsigned int a) {
      return a;
    }
    inline unsigned long abs(const unsigned long a) {
      return a;
    }
    inline double abs(const double a) {
      return std::fabs(a);
    }
    inline float abs(const float a) {
      return (float)std::fabs((double)a);
    }
    inline int abs(const int a) {
      return std::abs(a);
    }

    //! Return square of a value.
    template<typename T>
    inline T sqr(const T val) {
      return val*val;
    }

    //! Return <tt>1 + log_10(x)</tt> of a value \c x.
    inline int xln(const int x) {
      return x>0?(int)(1+std::log10((double)x)):1;
    }

    //! Return the minimum between two values.
    template<typename t1, typename t2>
    inline typename cimg::superset<t1,t2>::type min(const t1& a, const t2& b) {
      typedef typename cimg::superset<t1,t2>::type t1t2;
      return (t1t2)(a<=b?a:b);
    }

    //! Return the minimum between three values.
    template<typename t1, typename t2, typename t3>
    inline typename cimg::superset2<t1,t2,t3>::type min(const t1& a, const t2& b, const t3& c) {
      typedef typename cimg::superset2<t1,t2,t3>::type t1t2t3;
      return (t1t2t3)cimg::min(cimg::min(a,b),c);
    }

    //! Return the minimum between four values.
    template<typename t1, typename t2, typename t3, typename t4>
    inline typename cimg::superset3<t1,t2,t3,t4>::type min(const t1& a, const t2& b, const t3& c, const t4& d) {
      typedef typename cimg::superset3<t1,t2,t3,t4>::type t1t2t3t4;
      return (t1t2t3t4)cimg::min(cimg::min(a,b,c),d);
    }

    //! Return the maximum between two values.
    template<typename t1, typename t2>
    inline typename cimg::superset<t1,t2>::type max(const t1& a, const t2& b) {
      typedef typename cimg::superset<t1,t2>::type t1t2;
      return (t1t2)(a>=b?a:b);
    }

    //! Return the maximum between three values.
    template<typename t1, typename t2, typename t3>
    inline typename cimg::superset2<t1,t2,t3>::type max(const t1& a, const t2& b, const t3& c) {
      typedef typename cimg::superset2<t1,t2,t3>::type t1t2t3;
      return (t1t2t3)cimg::max(cimg::max(a,b),c);
    }

    //! Return the maximum between four values.
    template<typename t1, typename t2, typename t3, typename t4>
    inline typename cimg::superset3<t1,t2,t3,t4>::type max(const t1& a, const t2& b, const t3& c, const t4& d) {
      typedef typename cimg::superset3<t1,t2,t3,t4>::type t1t2t3t4;
      return (t1t2t3t4)cimg::max(cimg::max(a,b,c),d);
    }

    //! Return the sign of a value.
    template<typename T>
    inline T sign(const T x) {
      return (x<0)?(T)(-1):(x==0?(T)0:(T)1);
    }

    //! Return the nearest power of 2 higher than given value.
    template<typename T>
    inline unsigned long nearest_pow2(const T x) {
      unsigned long i = 1;
      while (x>i) i<<=1;
      return i;
    }

    //! Return the sinc of a given value.
    inline double sinc(const double x) {
      return x?std::sin(x)/x:1;
    }

    //! Return the modulo of a value.
    /**
       \param x Input value.
       \param m Modulo value.
       \note This modulo function accepts negative and floating-points modulo numbers, as well as variables of any type.
    **/
    template<typename T>
    inline T mod(const T& x, const T& m) {
      const double dx = (double)x, dm = (double)m;
      return (T)(dx - dm * std::floor(dx / dm));
    }
    inline int mod(const bool x, const bool m) {
      return m?(x?1:0):0;
    }
    inline int mod(const char x, const char m) {
      return x>=0?x%m:(x%m?m+x%m:0);
    }
    inline int mod(const short x, const short m) {
      return x>=0?x%m:(x%m?m+x%m:0);
    }
    inline int mod(const int x, const int m) {
      return x>=0?x%m:(x%m?m+x%m:0);
    }
    inline int mod(const long x, const long m) {
      return x>=0?x%m:(x%m?m+x%m:0);
    }
    inline int mod(const unsigned char x, const unsigned char m) {
      return x%m;
    }
    inline int mod(const unsigned short x, const unsigned short m) {
      return x%m;
    }
    inline int mod(const unsigned int x, const unsigned int m) {
      return x%m;
    }
    inline int mod(const unsigned long x, const unsigned long m) {
      return x%m;
    }

    //! Return the min-mod of two values.
    /**
       \note <i>minmod(\p a,\p b)</i> is defined to be:
       - <i>minmod(\p a,\p b) = min(\p a,\p b)</i>, if \p a and \p b have the same sign.
       - <i>minmod(\p a,\p b) = 0</i>, if \p a and \p b have different signs.
    **/
    template<typename T>
    inline T minmod(const T a, const T b) {
      return a*b<=0?0:(a>0?(a<b?a:b):(a<b?b:a));
    }

    //! Return base-2 logarithm of a value.
    inline double log2(const double x) {
      static const double base = std::log(2.0);
      return std::log(x)/base;
    }

    //! Return rounded value.
    /**
       \param x Value to be rounded.
       \param y Rounding precision.
       \param rounding_type Type of rounding operation (\c 0 = nearest, \c -1 = backward, \c 1 = forward).
       \return Rounded value, having the same type as input value \c x.
    **/
    template<typename T>
    inline T round(const T x, const double y=1, const int rounding_type=0) {
      if (y<=0) return x;
      const double sx = (double)x/y, floor = std::floor(sx), delta =  sx - floor;
      return (T)(y*(rounding_type<0?floor:rounding_type>0?std::ceil(sx):delta<0.5?floor:std::ceil(sx)));
    }

    inline double _pythagore(double a, double b) {
      const double absa = cimg::abs(a), absb = cimg::abs(b);
      if (absa>absb) { const double tmp = absb/absa; return absa*std::sqrt(1.0+tmp*tmp); }
      else { const double tmp = absa/absb; return absb==0?0:absb*std::sqrt(1.0+tmp*tmp); }
    }

    inline bool _is_self_expr(const char *expression) {
      if (!expression) return false;
      for (const char *s = expression; *s; ++s)
        if ((*s=='i' || *s=='j') && (s[1]=='(' || s[1]=='[')) return true;
      return false;
    }

    //! Convert ascii character to lower case.
    inline char uncase(const char x) {
      return (char)((x<'A'||x>'Z')?x:x-'A'+'a');
    }

    //! Convert C-string to lower case.
    inline void uncase(char *const str) {
      if (str) for (char *ptr = str; *ptr; ++ptr) *ptr = uncase(*ptr);
    }

    //! Read value in a C-string.
    /**
       \param str C-string containing the float value to read.
       \return Read value.
       \note Same as <tt>std::atof()</tt> extended to manage the retrieval of fractions from C-strings, as in <em>"1/2"</em>.
    **/
    inline double atof(const char *const str) {
      double x = 0, y = 1;
      if (!str) return 0; else { std::sscanf(str,"%lf/%lf",&x,&y); return x/y; }
    }

    //! Compare the first \p l characters of two C-strings, ignoring the case.
    /**
       \param str1 C-string.
       \param str2 C-string.
       \param l Number of characters to compare.
       \return \c 0 if the two strings are equal, something else otherwise.
       \note This function has to be defined since it is not provided by all C++-compilers (not ANSI).
    **/
    inline int strncasecmp(const char *const str1, const char *const str2, const int l) {
      if (!l) return 0;
      if (!str1) return str2?-1:0;
      const char *nstr1 = str1, *nstr2 = str2;
      int k, diff = 0; for (k = 0; k<l && !(diff = uncase(*nstr1)-uncase(*nstr2)); ++k) { ++nstr1; ++nstr2; }
      return k!=l?diff:0;
    }

    //! Compare two C-strings, ignoring the case.
    /**
       \param str1 C-string.
       \param str2 C-string.
       \return \c 0 if the two strings are equal, something else otherwise.
       \note This function has to be defined since it is not provided by all C++-compilers (not ANSI).
    **/
    inline int strcasecmp(const char *const str1, const char *const str2) {
      if (!str1) return str2?-1:0;
      const unsigned int
        l1 = (unsigned int)std::strlen(str1),
        l2 = (unsigned int)std::strlen(str2);
      return cimg::strncasecmp(str1,str2,1+(l1<l2?l1:l2));
    }

    //! Remove delimiters on the start and/or end of a C-string.
    /**
       \param[in,out] str C-string to work with (modified at output).
       \param delimiter Delimiter character code to remove.
       \param is_symmetric Tells if the removal is done only if delimiters are symmetric (both at the beginning and the end of \c s).
       \param is_iterative Tells if the removal is done if several iterations are possible.
       \return \c true if delimiters have been removed, \c false otherwise.
   **/
    inline bool strpare(char *const str, const char delimiter=' ', const bool is_symmetric=false, const bool is_iterative=false) {
      if (!str) return false;
      const int l = (int)std::strlen(str);
      int p, q;
      if (is_symmetric) for (p = 0, q = l-1; p<q && str[p]==delimiter && str[q]==delimiter; ) { --q; ++p; if (!is_iterative) break; }
      else {
        for (p = 0; p<l && str[p]==delimiter; ) { ++p; if (!is_iterative) break; }
        for (q = l-1; q>p && str[q]==delimiter; ) { --q; if (!is_iterative) break; }
      }
      const int n = q - p + 1;
      if (n!=l) { std::memmove(str,str+p,n); str[n] = 0; return true; }
      return false;
    }

    //! Replace escape sequences in C-strings by their binary ascii values.
    /**
       \param[in,out] str C-string to work with (modified at output).
     **/
    inline void strunescape(char *const str) {
#define cimg_strunescape(ci,co) case ci: *nd = co; ++ns; break;
      unsigned int val = 0;
      for (char *ns = str, *nd = str; *ns || (bool)(*nd=0); ++nd) if (*ns=='\\') switch (*(++ns)) {
            cimg_strunescape('n','\n');
            cimg_strunescape('t','\t');
            cimg_strunescape('v','\v');
            cimg_strunescape('b','\b');
            cimg_strunescape('r','\r');
            cimg_strunescape('f','\f');
            cimg_strunescape('a','\a');
            cimg_strunescape('\\','\\');
            cimg_strunescape('\?','\?');
            cimg_strunescape('\'','\'');
            cimg_strunescape('\"','\"');
          case 0 : *nd = 0; break;
          case '0' : case '1' : case '2' : case '3' : case '4' : case '5' : case '6' : case '7' :
            std::sscanf(ns,"%o",&val); while (*ns>='0' && *ns<='7') ++ns;
            *nd = val; break;
          case 'x':
            std::sscanf(++ns,"%x",&val); while ((*ns>='0' && *ns<='7') || (*ns>='a' && *ns<='f') || (*ns>='A' && *ns<='F')) ++ns;
            *nd = val; break;
          default : *nd = *(ns++);
          } else *nd = *(ns++);
    }

    // Return a temporary string describing the size of a memory buffer.
    inline const char *strbuffersize(const unsigned long size) {
      static char res[256] = { 0 };
      cimg::mutex(5);
      if (size<1024LU) cimg_snprintf(res,sizeof(res),"%lu byte%s",size,size>1?"s":"");
      else if (size<1024*1024LU) { const float nsize = size/1024.0f; cimg_snprintf(res,sizeof(res),"%.1f Kio",nsize); }
      else if (size<1024*1024*1024LU) { const float nsize = size/(1024*1024.0f); cimg_snprintf(res,sizeof(res),"%.1f Mio",nsize); }
      else { const float nsize = size/(1024*1024*1024.0f); cimg_snprintf(res,sizeof(res),"%.1f Gio",nsize); }
      cimg::mutex(5,0);
      return res;
    }

    // Return string that identifies the running OS.
    inline const char *stros() {
#if defined(linux) || defined(__linux) || defined(__linux__)
      const char *const str = "Linux";
#elif defined(sun) || defined(__sun)
# 4784 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      const char *const str = "Sun OS";
#elif defined(BSD) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__FreeBSD__) || defined (__DragonFly__)
# 4786 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      const char *const str = "BSD";
#elif defined(sgi) || defined(__sgi)
# 4788 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      const char *const str = "Irix";
#elif defined(__MACOSX__) || defined(__APPLE__)
# 4790 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      const char *const str = "Mac OS";
#elif defined(unix) || defined(__unix) || defined(__unix__)
# 4792 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      const char *const str = "Generic Unix";
#elif defined(_MSC_VER) || defined(WIN32)  || defined(_WIN32) || defined(__WIN32__) || defined(WIN64) || defined(_WIN64) || defined(__WIN64__)
# 4794 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      const char *const str = "Windows";
#else
# 4796 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      const char
        *const _str1 = std::getenv("OSTYPE"),
        *const _str2 = _str1?_str1:std::getenv("OS"),
        *const str = _str2?_str2:"Unknown OS";
#endif
# 4801 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      return str;
    }

    //! Return the basename of a filename.
    inline const char* basename(const char *const str)  {
      const char *p = 0;
      for (const char *np = str; np>=str && (p=np); np = std::strchr(np,cimg_file_separator)+1) {}
      return p;
    }

    // Return a random filename.
    inline const char* filenamerand() {
      cimg::mutex(6);
      static char randomid[9] = { 0 };
      cimg::srand();
      for (unsigned int k = 0; k<8; ++k) {
        const int v = (int)std::rand()%3;
        randomid[k] = (char)(v==0?('0'+(std::rand()%10)):(v==1?('a'+(std::rand()%26)):('A'+(std::rand()%26))));
      }
      cimg::mutex(6,0);
      return randomid;
    }

    // Convert filename as a Windows-style filename (short path name).
    inline void winformat_string(char *const str) {
      if (str && *str) {
#if cimg_OS==2
        char *const nstr = new char[MAX_PATH];
        if (GetShortPathNameA(str,nstr,MAX_PATH)) std::strcpy(str,nstr);
#endif
# 4831 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      }
    }

    //! Open a file.
    /**
       \param path Path of the filename to open.
       \param mode C-string describing the opening mode.
       \return Opened file.
       \note Same as <tt>std::fopen()</tt> but throw a \c CImgIOException when
       the specified file cannot be opened, instead of returning \c 0.
    **/
    inline std::FILE *fopen(const char *const path, const char *const mode) {
      if (!path)
        throw CImgArgumentException("cimg::fopen(): Specified file path is (null).");
      if (!mode)
        throw CImgArgumentException("cimg::fopen(): File '%s', specified mode is (null).",
                                    path);
      std::FILE *res = 0;
      if (*path=='-' && (!path[1] || path[1]=='.')) {
        res = (*mode=='r')?stdin:stdout;
#if cimg_OS==2
        if (*mode && mode[1]=='b') { // Force stdin/stdout to be in binary mode.
          if (_setmode(_fileno(res),0x8000)==-1) res = 0;
        }
#endif
# 4856 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      } else res = std::fopen(path,mode);
      if (!res) throw CImgIOException("cimg::fopen(): Failed to open file '%s' with mode '%s'.",
                                      path,mode);
      return res;
    }

    //! Close a file.
    /**
       \param file File to close.
       \return \c 0 if file has been closed properly, something else otherwise.
       \note Same as <tt>std::fclose()</tt> but display a warning message if
       the file has not been closed properly.
    **/
    inline int fclose(std::FILE *file) {
      if (!file) warn("cimg::fclose(): Specified file is (null).");
      if (!file || file==stdin || file==stdout) return 0;
      const int errn = std::fclose(file);
      if (errn!=0) warn("cimg::fclose(): Error code %d returned during file closing.",
                        errn);
      return errn;
    }

    //! Get/set path to store temporary files.
    /**
       \param user_path Specified path, or \c 0 to get the path currently used.
       \param reinit_path Force path to be recalculated (may take some time).
       \return Path where temporary files can be saved.
    **/
    inline const char* temporary_path(const char *const user_path=0, const bool reinit_path=false) {
#define _cimg_test_temporary_path(p) \
      if (!path_found) { \
        cimg_snprintf(s_path,1024,"%s",p); \
        cimg_snprintf(tmp,sizeof(tmp),"%s%c%s",s_path,cimg_file_separator,filetmp); \
        if ((file=std::fopen(tmp,"wb"))!=0) { cimg::fclose(file); std::remove(tmp); path_found = true; } \
      }
      static char *s_path = 0;
      cimg::mutex(7);
      if (reinit_path) { delete[] s_path; s_path = 0; }
      if (user_path) {
        if (!s_path) s_path = new char[1024];
        std::memset(s_path,0,1024);
        std::strncpy(s_path,user_path,1023);
      } else if (!s_path) {
        s_path = new char[1024];
        std::memset(s_path,0,1024);
        bool path_found = false;
        char tmp[1024] = { 0 }, filetmp[512] = { 0 };
        std::FILE *file = 0;
        cimg_snprintf(filetmp,sizeof(filetmp),"%s.tmp",cimg::filenamerand());
        char *tmpPath = std::getenv("TMP");
        if (!tmpPath) { tmpPath = std::getenv("TEMP"); winformat_string(tmpPath); }
        if (tmpPath) _cimg_test_temporary_path(tmpPath);
#if cimg_OS==2
        _cimg_test_temporary_path("C:\\WINNT\\Temp");
        _cimg_test_temporary_path("C:\\WINDOWS\\Temp");
        _cimg_test_temporary_path("C:\\Temp");
        _cimg_test_temporary_path("C:");
        _cimg_test_temporary_path("D:\\WINNT\\Temp");
        _cimg_test_temporary_path("D:\\WINDOWS\\Temp");
        _cimg_test_temporary_path("D:\\Temp");
        _cimg_test_temporary_path("D:");
#else
# 4918 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        _cimg_test_temporary_path("/tmp");
        _cimg_test_temporary_path("/var/tmp");
#endif
# 4921 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        if (!path_found) {
          *s_path = 0;
          std::strncpy(tmp,filetmp,sizeof(tmp)-1);
          if ((file=std::fopen(tmp,"wb"))!=0) { cimg::fclose(file); std::remove(tmp); path_found = true; }
        }
        if (!path_found) {
          cimg::mutex(7,0);
          throw CImgIOException("cimg::temporary_path(): Failed to locate path for writing temporary files.\n");
        }
      }
      cimg::mutex(7,0);
      return s_path;
    }

    //! Get/set path to the <i>Program Files/</i> directory (Windows only).
    /**
       \param user_path Specified path, or \c 0 to get the path currently used.
       \param reinit_path Force path to be recalculated (may take some time).
       \return Path containing the program files.
    **/
#if cimg_OS==2
    inline const char* programfiles_path(const char *const user_path=0, const bool reinit_path=false) {
      static char *s_path = 0;
      cimg::mutex(7);
      if (reinit_path) { delete[] s_path; s_path = 0; }
      if (user_path) {
        if (!s_path) s_path = new char[1024];
        std::memset(s_path,0,1024);
        std::strncpy(s_path,user_path,1023);
      } else if (!s_path) {
        s_path = new char[MAX_PATH];
        std::memset(s_path,0,MAX_PATH);
        // Note: in the following line, 0x26 = CSIDL_PROGRAM_FILES (not defined on every compiler).
#if !defined(__INTEL_COMPILER)
        if (!SHGetSpecialFolderPathA(0,s_path,0x0026,false)) {
          const char *const pfPath = std::getenv("PROGRAMFILES");
          if (pfPath) std::strncpy(s_path,pfPath,MAX_PATH-1);
          else std::strcpy(s_path,"C:\\PROGRA~1");
        }
#else
# 4961 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        std::strcpy(s_path,"C:\\PROGRA~1");
#endif
# 4963 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      }
      cimg::mutex(7,0);
      return s_path;
    }
#endif
# 4968 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    //! Get/set path to the ImageMagick's \c convert binary.
    /**
       \param user_path Specified path, or \c 0 to get the path currently used.
       \param reinit_path Force path to be recalculated (may take some time).
       \return Path containing the \c convert binary.
    **/
    inline const char* imagemagick_path(const char *const user_path=0, const bool reinit_path=false) {
      static char *s_path = 0;
      cimg::mutex(7);
      if (reinit_path) { delete[] s_path; s_path = 0; }
      if (user_path) {
        if (!s_path) s_path = new char[1024];
        std::memset(s_path,0,1024);
        std::strncpy(s_path,user_path,1023);
      } else if (!s_path) {
        s_path = new char[1024];
        std::memset(s_path,0,1024);
        bool path_found = false;
        std::FILE *file = 0;
#if cimg_OS==2
        const char *const pf_path = programfiles_path();
        if (!path_found) {
          std::strcpy(s_path,".\\convert.exe");
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=10 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"%s\\IMAGEM~1.%.2d-\\convert.exe",pf_path,k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 9; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"%s\\IMAGEM~1.%d-Q\\convert.exe",pf_path,k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"%s\\IMAGEM~1.%d\\convert.exe",pf_path,k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=10 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"%s\\IMAGEM~1.%.2d-\\VISUA~1\\BIN\\convert.exe",pf_path,k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 9; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"%s\\IMAGEM~1.%d-Q\\VISUA~1\\BIN\\convert.exe",pf_path,k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"%s\\IMAGEM~1.%d\\VISUA~1\\BIN\\convert.exe",pf_path,k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=10 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"C:\\IMAGEM~1.%.2d-\\convert.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 9; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"C:\\IMAGEM~1.%d-Q\\convert.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"C:\\IMAGEM~1.%d\\convert.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=10 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"C:\\IMAGEM~1.%.2d-\\VISUA~1\\BIN\\convert.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 9; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"C:\\IMAGEM~1.%d-Q\\VISUA~1\\BIN\\convert.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"C:\\IMAGEM~1.%d\\VISUA~1\\BIN\\convert.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=10 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"D:\\IMAGEM~1.%.2d-\\convert.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 9; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"D:\\IMAGEM~1.%d-Q\\convert.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"D:\\IMAGEM~1.%d\\convert.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=10 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"D:\\IMAGEM~1.%.2d-\\VISUA~1\\BIN\\convert.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 9; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"D:\\IMAGEM~1.%d-Q\\VISUA~1\\BIN\\convert.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"D:\\IMAGEM~1.%d\\VISUA~1\\BIN\\convert.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        if (!path_found) std::strcpy(s_path,"convert.exe");
#else
# 5068 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        if (!path_found) {
          std::strcpy(s_path,"./convert");
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        if (!path_found) std::strcpy(s_path,"convert");
#endif
# 5074 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        winformat_string(s_path);
      }
      cimg::mutex(7,0);
      return s_path;
    }

    //! Get/set path to the GraphicsMagick's \c gm binary.
    /**
       \param user_path Specified path, or \c 0 to get the path currently used.
       \param reinit_path Force path to be recalculated (may take some time).
       \return Path containing the \c gm binary.
    **/
    inline const char* graphicsmagick_path(const char *const user_path=0, const bool reinit_path=false) {
      static char *s_path = 0;
      cimg::mutex(7);
      if (reinit_path) { delete[] s_path; s_path = 0; }
      if (user_path) {
        if (!s_path) s_path = new char[1024];
        std::memset(s_path,0,1024);
        std::strncpy(s_path,user_path,1023);
      } else if (!s_path) {
        s_path = new char[1024];
        std::memset(s_path,0,1024);
        bool path_found = false;
        std::FILE *file = 0;
#if cimg_OS==2
        const char *const pf_path = programfiles_path();
        if (!path_found) {
          std::strcpy(s_path,".\\gm.exe");
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=10 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"%s\\GRAPHI~1.%.2d-\\gm.exe",pf_path,k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 9; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"%s\\GRAPHI~1.%d-Q\\gm.exe",pf_path,k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"%s\\GRAPHI~1.%d\\gm.exe",pf_path,k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=10 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"%s\\GRAPHI~1.%.2d-\\VISUA~1\\BIN\\gm.exe",pf_path,k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 9; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"%s\\GRAPHI~1.%d-Q\\VISUA~1\\BIN\\gm.exe",pf_path,k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"%s\\GRAPHI~1.%d\\VISUA~1\\BIN\\gm.exe",pf_path,k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=10 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"C:\\GRAPHI~1.%.2d-\\gm.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 9; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"C:\\GRAPHI~1.%d-Q\\gm.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"C:\\GRAPHI~1.%d\\gm.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=10 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"C:\\GRAPHI~1.%.2d-\\VISUA~1\\BIN\\gm.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 9; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"C:\\GRAPHI~1.%d-Q\\VISUA~1\\BIN\\gm.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"C:\\GRAPHI~1.%d\\VISUA~1\\BIN\\gm.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=10 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"D:\\GRAPHI~1.%.2d-\\gm.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 9; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"D:\\GRAPHI~1.%d-Q\\gm.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"D:\\GRAPHI~1.%d\\gm.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=10 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"D:\\GRAPHI~1.%.2d-\\VISUA~1\\BIN\\gm.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 9; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"D:\\GRAPHI~1.%d-Q\\VISUA~1\\BIN\\gm.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        for (int k = 32; k>=0 && !path_found; --k) {
          cimg_snprintf(s_path,sizeof(s_path),"D:\\GRAPHI~1.%d\\VISUA~1\\BIN\\gm.exe",k);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        if (!path_found) std::strcpy(s_path,"gm.exe");
#else
# 5179 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        if (!path_found) {
          std::strcpy(s_path,"./gm");
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        if (!path_found) std::strcpy(s_path,"gm");
#endif
# 5185 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        winformat_string(s_path);
      }
      cimg::mutex(7,0);
      return s_path;
    }

    //! Get/set path to the XMedcon's \c medcon binary.
    /**
       \param user_path Specified path, or \c 0 to get the path currently used.
       \param reinit_path Force path to be recalculated (may take some time).
       \return Path containing the \c medcon binary.
    **/
    inline const char* medcon_path(const char *const user_path=0, const bool reinit_path=false) {
      static char *s_path = 0;
      cimg::mutex(7);
      if (reinit_path) { delete[] s_path; s_path = 0; }
      if (user_path) {
        if (!s_path) s_path = new char[1024];
        std::memset(s_path,0,1024);
        std::strncpy(s_path,user_path,1023);
      } else if (!s_path) {
        s_path = new char[1024];
        std::memset(s_path,0,1024);
        bool path_found = false;
        std::FILE *file = 0;
#if cimg_OS==2
        const char *const pf_path = programfiles_path();
        if (!path_found) {
          std::strcpy(s_path,".\\medcon.exe");
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        if (!path_found) {
          cimg_snprintf(s_path,sizeof(s_path),"%s\\XMedCon\\bin\\medcon.bat",pf_path);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        if (!path_found) {
          cimg_snprintf(s_path,sizeof(s_path),"%s\\XMedCon\\bin\\medcon.exe",pf_path);
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        if (!path_found) std::strcpy(s_path,"medcon.exe");
#else
# 5226 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        if (!path_found) {
          std::strcpy(s_path,"./medcon");
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        if (!path_found) std::strcpy(s_path,"medcon");
#endif
# 5232 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        winformat_string(s_path);
      }
      cimg::mutex(7,0);
      return s_path;
    }

    //! Get/set path to the FFMPEG's \c ffmpeg binary.
    /**
       \param user_path Specified path, or \c 0 to get the path currently used.
       \param reinit_path Force path to be recalculated (may take some time).
       \return Path containing the \c ffmpeg binary.
    **/
    inline const char *ffmpeg_path(const char *const user_path=0, const bool reinit_path=false) {
      static char *s_path = 0;
      cimg::mutex(7);
      if (reinit_path) { delete[] s_path; s_path = 0; }
      if (user_path) {
        if (!s_path) s_path = new char[1024];
        std::memset(s_path,0,1024);
        std::strncpy(s_path,user_path,1023);
      } else if (!s_path) {
        s_path = new char[1024];
        std::memset(s_path,0,1024);
        bool path_found = false;
        std::FILE *file = 0;
#if cimg_OS==2
        if (!path_found) {
          std::strcpy(s_path,".\\ffmpeg.exe");
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        if (!path_found) std::strcpy(s_path,"ffmpeg.exe");
#else
# 5264 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        if (!path_found) {
          std::strcpy(s_path,"./ffmpeg");
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        if (!path_found) std::strcpy(s_path,"ffmpeg");
#endif
# 5270 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        winformat_string(s_path);
      }
      cimg::mutex(7,0);
      return s_path;
    }

    //! Get/set path to the \c gzip binary.
    /**
       \param user_path Specified path, or \c 0 to get the path currently used.
       \param reinit_path Force path to be recalculated (may take some time).
       \return Path containing the \c gzip binary.
    **/
    inline const char *gzip_path(const char *const user_path=0, const bool reinit_path=false) {
      static char *s_path = 0;
      cimg::mutex(7);
      if (reinit_path) { delete[] s_path; s_path = 0; }
      if (user_path) {
        if (!s_path) s_path = new char[1024];
        std::memset(s_path,0,1024);
        std::strncpy(s_path,user_path,1023);
      } else if (!s_path) {
        s_path = new char[1024];
        std::memset(s_path,0,1024);
        bool path_found = false;
        std::FILE *file = 0;
#if cimg_OS==2
        if (!path_found) {
          std::strcpy(s_path,".\\gzip.exe");
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        if (!path_found) std::strcpy(s_path,"gzip.exe");
#else
# 5302 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        if (!path_found) {
          std::strcpy(s_path,"./gzip");
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        if (!path_found) std::strcpy(s_path,"gzip");
#endif
# 5308 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        winformat_string(s_path);
      }
      cimg::mutex(7,0);
      return s_path;
    }

    //! Get/set path to the \c gzip binary.
    /**
       \param user_path Specified path, or \c 0 to get the path currently used.
       \param reinit_path Force path to be recalculated (may take some time).
       \return Path containing the \c gunzip binary.
    **/
    inline const char *gunzip_path(const char *const user_path=0, const bool reinit_path=false) {
      static char *s_path = 0;
      cimg::mutex(7);
      if (reinit_path) { delete[] s_path; s_path = 0; }
      if (user_path) {
        if (!s_path) s_path = new char[1024];
        std::memset(s_path,0,1024);
        std::strncpy(s_path,user_path,1023);
      } else if (!s_path) {
        s_path = new char[1024];
        std::memset(s_path,0,1024);
        bool path_found = false;
        std::FILE *file = 0;
#if cimg_OS==2
        if (!path_found) {
          std::strcpy(s_path,".\\gunzip.exe");
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        if (!path_found) std::strcpy(s_path,"gunzip.exe");
#else
# 5340 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        if (!path_found) {
          std::strcpy(s_path,"./gunzip");
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        if (!path_found) std::strcpy(s_path,"gunzip");
#endif
# 5346 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        winformat_string(s_path);
      }
      cimg::mutex(7,0);
      return s_path;
    }

    //! Get/set path to the \c dcraw binary.
    /**
       \param user_path Specified path, or \c 0 to get the path currently used.
       \param reinit_path Force path to be recalculated (may take some time).
       \return Path containing the \c dcraw binary.
    **/
    inline const char *dcraw_path(const char *const user_path=0, const bool reinit_path=false) {
      static char *s_path = 0;
      cimg::mutex(7);
      if (reinit_path) { delete[] s_path; s_path = 0; }
      if (user_path) {
        if (!s_path) s_path = new char[1024];
        std::memset(s_path,0,1024);
        std::strncpy(s_path,user_path,1023);
      } else if (!s_path) {
        s_path = new char[1024];
        std::memset(s_path,0,1024);
        bool path_found = false;
        std::FILE *file = 0;
#if cimg_OS==2
        if (!path_found) {
          std::strcpy(s_path,".\\dcraw.exe");
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        if (!path_found) std::strcpy(s_path,"dcraw.exe");
#else
# 5378 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        if (!path_found) {
          std::strcpy(s_path,"./dcraw");
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        if (!path_found) std::strcpy(s_path,"dcraw");
#endif
# 5384 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        winformat_string(s_path);
      }
      cimg::mutex(7,0);
      return s_path;
    }

    //! Get/set path to the \c wget binary.
    /**
       \param user_path Specified path, or \c 0 to get the path currently used.
       \param reinit_path Force path to be recalculated (may take some time).
       \return Path containing the \c wget binary.
    **/
    inline const char *wget_path(const char *const user_path=0, const bool reinit_path=false) {
      static char *s_path = 0;
      cimg::mutex(7);
      if (reinit_path) { delete[] s_path; s_path = 0; }
      if (user_path) {
        if (!s_path) s_path = new char[1024];
        std::memset(s_path,0,1024);
        std::strncpy(s_path,user_path,1023);
      } else if (!s_path) {
        s_path = new char[1024];
        std::memset(s_path,0,1024);
        bool path_found = false;
        std::FILE *file = 0;
#if cimg_OS==2
        if (!path_found) {
          std::strcpy(s_path,".\\wget.exe");
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        if (!path_found) std::strcpy(s_path,"wget.exe");
#else
# 5416 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        if (!path_found) {
          std::strcpy(s_path,"./wget");
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        if (!path_found) std::strcpy(s_path,"wget");
#endif
# 5422 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        winformat_string(s_path);
      }
      cimg::mutex(7,0);
      return s_path;
    }

    //! Get/set path to the \c curl binary.
    /**
       \param user_path Specified path, or \c 0 to get the path currently used.
       \param reinit_path Force path to be recalculated (may take some time).
       \return Path containing the \c curl binary.
    **/
    inline const char *curl_path(const char *const user_path=0, const bool reinit_path=false) {
      static char *s_path = 0;
      cimg::mutex(7);
      if (reinit_path) { delete[] s_path; s_path = 0; }
      if (user_path) {
        if (!s_path) s_path = new char[1024];
        std::memset(s_path,0,1024);
        std::strncpy(s_path,user_path,1023);
      } else if (!s_path) {
        s_path = new char[1024];
        std::memset(s_path,0,1024);
        bool path_found = false;
        std::FILE *file = 0;
#if cimg_OS==2
        if (!path_found) {
          std::strcpy(s_path,".\\curl.exe");
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        if (!path_found) std::strcpy(s_path,"curl.exe");
#else
# 5454 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        if (!path_found) {
          std::strcpy(s_path,"./curl");
          if ((file=std::fopen(s_path,"r"))!=0) { cimg::fclose(file); path_found = true; }
        }
        if (!path_found) std::strcpy(s_path,"curl");
#endif
# 5460 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        winformat_string(s_path);
      }
      cimg::mutex(7,0);
      return s_path;
    }

    //! Split filename into two C-strings \c body and \c extension.
    inline const char *split_filename(const char *const filename, char *const body=0) {
      if (!filename) { if (body) *body = 0; return 0; }
      const char *p = 0; for (const char *np = filename; np>=filename && (p=np); np = std::strchr(np,'.')+1) {}
      if (p==filename) {
        if (body) std::strcpy(body,filename);
        return filename + std::strlen(filename);
      }
      const unsigned int l = (unsigned int)(p - filename - 1);
      if (body) { std::memcpy(body,filename,l); body[l] = 0; }
      return p;
    }

    //! Generate a numbered version of a filename.
    inline char* number_filename(const char *const filename, const int number, const unsigned int digits, char *const str) {
      if (!filename) { if (str) *str = 0; return 0; }
      char format[1024] = { 0 }, body[1024] = { 0 };
      const char *const ext = cimg::split_filename(filename,body);
      cimg_snprintf(format,sizeof(format),"%%s_%%.%ud.%%s",digits);
      std::sprintf(str,format,body,number,ext);
      return str;
    }

    //! Try to guess format from an image file.
    /**
       \param file Input file (can be \c 0 if \c filename is set).
       \param filename Filename, as a C-string (can be \c 0 if \c file is set).
       \return C-string containing the guessed file format, or \c 0 if nothing has been guessed.
     **/
    inline const char *file_type(std::FILE *const file, const char *const filename) {
      if (!file && !filename)
        throw CImgArgumentException("cimg::file_type(): Specified filename is (null).");
      static const char
        *const _pnm = "pnm",
        *const _pfm = "pfm",
        *const _bmp = "bmp",
        *const _gif = "gif",
        *const _jpg = "jpg",
        *const _off = "off",
        *const _pan = "pan",
        *const _png = "png",
        *const _tif = "tif",
        *const _inr = "inr",
        *const _dcm = "dcm";
      std::FILE *const nfile = file?file:cimg::fopen(filename,"rb");
      const char *f_type = 0, *head;
      char header[2048] = { 0 }, item[1024] = { 0 };
      const unsigned char *const uheader = (unsigned char*)header;
      int err; char cerr;
      const unsigned int siz = (unsigned int)std::fread(header,2048,1,nfile);   // Read first 2048 bytes.
      if (!file) cimg::fclose(nfile);

      if (!std::strncmp(header,"OFF\n",4)) f_type = _off; // Check for OFF format.
      else if (!std::strncmp(header,"#INRIMAGE",9)) f_type = _inr; // Check for INRIMAGE format.
      else if (!std::strncmp(header,"PANDORE",7)) f_type = _pan; // Check for PANDORE format.
      else if (!std::strncmp(header+128,"DICM",4)) f_type = _dcm; // Check for DICOM format.
      else if (uheader[0]==0xFF && uheader[1]==0xD8 && uheader[2]==0xFF) f_type = _jpg;  // Check for JPEG format.
      else if (header[0]=='B' && header[1]=='M') f_type = _bmp;  // Check for BMP format.
      else if (header[0]=='G' && header[1]=='I' && header[2]=='F' && header[3]=='8' && header[5]=='a' && // Check for GIF format.
               (header[4]=='7' || header[4]=='9')) f_type = _gif;
      else if (uheader[0]==0x89 && uheader[1]==0x50 && uheader[2]==0x4E && uheader[3]==0x47 &&  // Check for PNG format.
               uheader[4]==0x0D && uheader[5]==0x0A && uheader[6]==0x1A && uheader[7]==0x0A) f_type = _png;
      else if ((uheader[0]==0x49 && uheader[1]==0x49) || (uheader[0]==0x4D && uheader[1]==0x4D)) f_type = _tif; // Check for TIFF format.
      else { // Check for PNM or PFM format.
        head = header;
        while (head<header+siz && (err=std::sscanf(head,"%1023[^\n]",item))!=EOF && (*item=='#' || !err))
          head+=1+(err?std::strlen(item):0);
        if (std::sscanf(item," P%d",&err)==1) f_type = _pnm;
        else if (std::sscanf(item," P%c",&cerr)==1 && (cerr=='f' || cerr=='F')) f_type = _pfm;
      }
      return f_type;
    }

    //! Read data from file.
    /**
       \param[out] ptr Pointer to memory buffer that will contain the binary data read from file.
       \param nmemb Number of elements to read.
       \param stream File to read data from.
       \return Number of read elements.
       \note Same as <tt>std::fread()</tt> but may display warning message if all elements could not be read.
    **/
    template<typename T>
    inline int fread(T *const ptr, const unsigned long nmemb, std::FILE *stream) {
      if (!ptr || nmemb<=0 || !stream)
        throw CImgArgumentException("cimg::fread(): Invalid reading request of %u %s%s from file %p to buffer %p.",
                                    nmemb,cimg::type<T>::string(),nmemb>1?"s":"",stream,ptr);

      const unsigned long wlimitT = 63*1024*1024, wlimit = wlimitT/sizeof(T);
      unsigned long to_read = nmemb, al_read = 0, l_to_read = 0, l_al_read = 0;
      do {
        l_to_read = (to_read*sizeof(T))<wlimitT?to_read:wlimit;
        l_al_read = (unsigned long)std::fread((void*)(ptr+al_read),sizeof(T),l_to_read,stream);
        al_read+=l_al_read;
        to_read-=l_al_read;
      } while (l_to_read==l_al_read && to_read>0);
      if (to_read>0)
        warn("cimg::fread(): Only %u/%u elements could be read from file.",
             al_read,nmemb);
      return al_read;
    }

    //! Write data to file.
    /**
       \param ptr Pointer to memory buffer containing the binary data to write on file.
       \param nmemb Number of elements to write.
       \param[out] stream File to write data on.
       \return Number of written elements.
       \note Similar to <tt>std::fwrite</tt> but may display warning messages if all elements could not be written.
    **/
    template<typename T>
    inline int fwrite(const T *ptr, const unsigned long nmemb, std::FILE *stream) {
      if (!ptr || !stream)
        throw CImgArgumentException("cimg::fwrite(): Invalid writing request of %u %s%s from buffer %p to file %p.",
                                    nmemb,cimg::type<T>::string(),nmemb>1?"s":"",ptr,stream);
      if (nmemb<=0) return 0;
      const unsigned long wlimitT = 63*1024*1024, wlimit = wlimitT/sizeof(T);
      unsigned long to_write = nmemb, al_write = 0, l_to_write = 0, l_al_write = 0;
      do {
        l_to_write = (to_write*sizeof(T))<wlimitT?to_write:wlimit;
        l_al_write = (unsigned long)std::fwrite((void*)(ptr+al_write),sizeof(T),l_to_write,stream);
        al_write+=l_al_write;
        to_write-=l_al_write;
      } while (l_to_write==l_al_write && to_write>0);
      if (to_write>0)
        warn("cimg::fwrite(): Only %u/%u elements could be written in file.",
             al_write,nmemb);
      return al_write;
    }

    //! Create an empty file.
    /**
       \param file Input file (can be \c 0 if \c filename is set).
       \param filename Filename, as a C-string (can be \c 0 if \c file is set).
    **/
    inline void fempty(std::FILE *const file, const char *const filename) {
      if (!file && !filename)
        throw CImgArgumentException("cimg::file_type(): Specified filename is (null).");
      std::FILE *const nfile = file?file:cimg::fopen(filename,"wb");
      if (!file) cimg::fclose(nfile);
    }

    //! Load file from network as a local temporary file.
    /**
       \param filename Filename, as a C-string.
       \param[out] filename_local C-string containing the path to a local copy of \c filename.
       \return Value of \c filename_local.
       \note Use external binaries \c wget or \c curl to perform. You must have one of these tools installed
       to be able to use this function.
    **/
    inline char *load_network_external(const char *const filename, char *const filename_local) {
      if (!filename)
        throw CImgArgumentException("cimg::load_network_external(): Specified filename is (null).");
      if (!filename_local)
        throw CImgArgumentException("cimg::load_network_external(): Specified destination string is (null).");
      const char *const _ext = cimg::split_filename(filename), *const ext = (*_ext && _ext>filename)?_ext-1:_ext;
      char command[1024] = { 0 };
      std::FILE *file = 0;
      *filename_local = 0;
      do {
        cimg_snprintf(filename_local,512,"%s%c%s%s",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand(),ext);
        if ((file=std::fopen(filename_local,"rb"))!=0) cimg::fclose(file);
      } while (file);

      // Try with 'curl' first.
      cimg_snprintf(command,sizeof(command),"%s -f --silent --compressed -o \"%s\" \"%s\"",
                    cimg::curl_path(),filename_local,filename);
      cimg::system(command);
      if (!(file = std::fopen(filename_local,"rb"))) {

        // Try with 'wget' else.
        cimg_snprintf(command,sizeof(command),"%s -q -r -l 0 --no-cache -O \"%s\" \"%s\"",
                      cimg::wget_path(),filename_local,filename);
        cimg::system(command);
        if (!(file = std::fopen(filename_local,"rb")))
          throw CImgIOException("cimg::load_network_external(): Failed to load file '%s' with external tools 'wget' or 'curl'.",filename);
        cimg::fclose(file);

        // Try gunzip it.
        cimg_snprintf(command,sizeof(command),"%s.gz",filename_local);
        std::rename(filename_local,command);
        cimg_snprintf(command,sizeof(command),"%s --quiet \"%s.gz\"",
                      gunzip_path(),filename_local);
        cimg::system(command);
        file = std::fopen(filename_local,"rb");
        if (!file) {
          cimg_snprintf(command,sizeof(command),"%s.gz",filename_local);
          std::rename(command,filename_local);
          file = std::fopen(filename_local,"rb");
        }
      }
      std::fseek(file,0,SEEK_END); // Check if file size is 0.
      if (std::ftell(file)<=0)
        throw CImgIOException("cimg::load_network_external(): Failed to load file '%s' with external commands 'wget' or 'curl'.",filename);
      cimg::fclose(file);
      return filename_local;
    }

    //! Return options specified on the command line.
    inline const char* option(const char *const name, const int argc, const char *const *const argv,
                              const char *const defaut, const char *const usage, const bool reset_static) {
      static bool first = true, visu = false;
      if (reset_static) { first = true; return 0; }
      const char *res = 0;
      if (first) {
        first = false;
        visu = cimg::option("-h",argc,argv,(char*)0,(char*)0,false)!=0;
        visu |= cimg::option("-help",argc,argv,(char*)0,(char*)0,false)!=0;
        visu |= cimg::option("--help",argc,argv,(char*)0,(char*)0,false)!=0;
      }
      if (!name && visu) {
        if (usage) {
          std::fprintf(cimg::output(),"\n %s%s%s",cimg::t_red,cimg::basename(argv[0]),cimg::t_normal);
          std::fprintf(cimg::output(),": %s",usage);
          std::fprintf(cimg::output()," (%s, %s)\n\n",__DATE__,__TIME__);
        }
        if (defaut) std::fprintf(cimg::output(),"%s\n",defaut);
      }
      if (name) {
        if (argc>0) {
          int k = 0;
          while (k<argc && std::strcmp(argv[k],name)) ++k;
          res = (k++==argc?defaut:(k==argc?argv[--k]:argv[k]));
        } else res = defaut;
        if (visu && usage) std::fprintf(cimg::output(),"    %s%-16s%s %-24s %s%s%s\n",
                                        cimg::t_bold,name,cimg::t_normal,res?res:"0",cimg::t_green,usage,cimg::t_normal);
      }
      return res;
    }

    inline const char* option(const char *const name, const int argc, const char *const *const argv,
                              const char *const defaut, const char *const usage=0) {
      return option(name,argc,argv,defaut,usage,false);
    }

    inline bool option(const char *const name, const int argc, const char *const *const argv,
                       const bool defaut, const char *const usage=0) {
      const char *const s = cimg::option(name,argc,argv,(char*)0);
      const bool res = s?(cimg::strcasecmp(s,"false") && cimg::strcasecmp(s,"off") && cimg::strcasecmp(s,"0")):defaut;
      cimg::option(name,0,0,res?"true":"false",usage);
      return res;
    }

    inline int option(const char *const name, const int argc, const char *const *const argv,
                      const int defaut, const char *const usage=0) {
      const char *const s = cimg::option(name,argc,argv,(char*)0);
      const int res = s?std::atoi(s):defaut;
      char tmp[256] = { 0 };
      cimg_snprintf(tmp,sizeof(tmp),"%d",res);
      cimg::option(name,0,0,tmp,usage);
      return res;
    }

    inline char option(const char *const name, const int argc, const char *const *const argv,
                       const char defaut, const char *const usage=0) {
      const char *const s = cimg::option(name,argc,argv,(char*)0);
      const char res = s?*s:defaut;
      char tmp[8] = { 0 };
      *tmp = res;
      cimg::option(name,0,0,tmp,usage);
      return res;
    }

    inline float option(const char *const name, const int argc, const char *const *const argv,
                        const float defaut, const char *const usage=0) {
      const char *const s = cimg::option(name,argc,argv,(char*)0);
      const float res = s?(float)cimg::atof(s):defaut;
      char tmp[256] = { 0 };
      cimg_snprintf(tmp,sizeof(tmp),"%g",res);
      cimg::option(name,0,0,tmp,usage);
      return res;
    }

    inline double option(const char *const name, const int argc, const char *const *const argv,
                         const double defaut, const char *const usage=0) {
      const char *const s = cimg::option(name,argc,argv,(char*)0);
      const double res = s?cimg::atof(s):defaut;
      char tmp[256] = { 0 };
      cimg_snprintf(tmp,sizeof(tmp),"%g",res);
      cimg::option(name,0,0,tmp,usage);
      return res;
    }

    inline const char* argument(const unsigned int nb, const int argc, const char *const *const argv, const unsigned int nb_singles=0, ...) {
      for (int k = 1, pos = 0; k<argc;) {
        const char *const item = argv[k];
        bool option = (*item=='-'), single_option = false;
        if (option) {
          va_list ap;
          va_start(ap,nb_singles);
          for (unsigned int i = 0; i<nb_singles; ++i) if (!cimg::strcasecmp(item,va_arg(ap,char*))) { single_option = true; break; }
          va_end(ap);
        }
        if (option) { ++k; if (!single_option) ++k; }
        else { if (pos++==(int)nb) return item; else ++k; }
      }
      return 0;
    }

    //! Print informations about \CImg environement variables.
    /**
       \note Output is done on the default output stream.
    **/
    inline void info() {
      char tmp[1024] = { 0 };
      std::fprintf(cimg::output(),"\n %s%sCImg Library %u.%u.%u%s, compiled %s ( %s ) with the following flags:\n\n",
                   cimg::t_red,cimg::t_bold,cimg_version/100,(cimg_version/10)%10,cimg_version%10,
                   cimg::t_normal,__DATE__,__TIME__);

      std::fprintf(cimg::output(),"  > Operating System:       %s%-13s%s %s('cimg_OS'=%d)%s\n",
                   cimg::t_bold,
                   cimg_OS==1?"Unix":(cimg_OS==2?"Windows":"Unknow"),
                   cimg::t_normal,cimg::t_green,
                   cimg_OS,
                   cimg::t_normal);

      std::fprintf(cimg::output(),"  > CPU endianness:         %s%s Endian%s\n",
                   cimg::t_bold,
                   cimg::endianness()?"Big":"Little",
                   cimg::t_normal);

      std::fprintf(cimg::output(),"  > Verbosity mode:         %s%-13s%s %s('cimg_verbosity'=%d)%s\n",
                   cimg::t_bold,
                   cimg_verbosity==0?"Quiet":(cimg_verbosity==1?"Console":(cimg_verbosity==2?"Dialog":(cimg_verbosity==3?"Console+Warnings":"Dialog+Warnings"))),
                   cimg::t_normal,cimg::t_green,
                   cimg_verbosity,
                   cimg::t_normal);

      std::fprintf(cimg::output(),"  > Stricts warnings:       %s%-13s%s %s('cimg_strict_warnings' %s)%s\n",
                   cimg::t_bold,
#ifdef cimg_strict_warnings
                   "Yes",cimg::t_normal,cimg::t_green,"defined",
#else
# 5798 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   "No",cimg::t_normal,cimg::t_green,"undefined",
#endif
# 5800 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   cimg::t_normal);

      std::fprintf(cimg::output(),"  > Using VT100 messages:   %s%-13s%s %s('cimg_use_vt100' %s)%s\n",
                   cimg::t_bold,
#ifdef cimg_use_vt100
                   "Yes",cimg::t_normal,cimg::t_green,"defined",
#else
# 5807 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   "No",cimg::t_normal,cimg::t_green,"undefined",
#endif
# 5809 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   cimg::t_normal);

      std::fprintf(cimg::output(),"  > Display type:           %s%-13s%s %s('cimg_display'=%d)%s\n",
                   cimg::t_bold,
                   cimg_display==0?"No display":cimg_display==1?"X11":cimg_display==2?"Windows GDI":"Unknown",
                   cimg::t_normal,cimg::t_green,
                   cimg_display,
                   cimg::t_normal);

#if cimg_display==1
      std::fprintf(cimg::output(),"  > Using XShm for X11:     %s%-13s%s %s('cimg_use_xshm' %s)%s\n",
                   cimg::t_bold,
#ifdef cimg_use_xshm
                   "Yes",cimg::t_normal,cimg::t_green,"defined",
#else
# 5824 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   "No",cimg::t_normal,cimg::t_green,"undefined",
#endif
# 5826 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   cimg::t_normal);

      std::fprintf(cimg::output(),"  > Using XRand for X11:    %s%-13s%s %s('cimg_use_xrandr' %s)%s\n",
                   cimg::t_bold,
#ifdef cimg_use_xrandr
                   "Yes",cimg::t_normal,cimg::t_green,"defined",
#else
# 5833 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   "No",cimg::t_normal,cimg::t_green,"undefined",
#endif
# 5835 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   cimg::t_normal);
#endif
# 5837 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      std::fprintf(cimg::output(),"  > Using OpenMP:           %s%-13s%s %s('cimg_use_openmp' %s)%s\n",
                   cimg::t_bold,
#ifdef cimg_use_openmp
                   "Yes",cimg::t_normal,cimg::t_green,"defined",
#else
# 5842 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   "No",cimg::t_normal,cimg::t_green,"undefined",
#endif
# 5844 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   cimg::t_normal);
      std::fprintf(cimg::output(),"  > Using PNG library:      %s%-13s%s %s('cimg_use_png' %s)%s\n",
                   cimg::t_bold,
#ifdef cimg_use_png
                   "Yes",cimg::t_normal,cimg::t_green,"defined",
#else
# 5850 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   "No",cimg::t_normal,cimg::t_green,"undefined",
#endif
# 5852 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   cimg::t_normal);
      std::fprintf(cimg::output(),"  > Using JPEG library:     %s%-13s%s %s('cimg_use_jpeg' %s)%s\n",
                   cimg::t_bold,
#ifdef cimg_use_jpeg
                   "Yes",cimg::t_normal,cimg::t_green,"defined",
#else
# 5858 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   "No",cimg::t_normal,cimg::t_green,"undefined",
#endif
# 5860 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   cimg::t_normal);

      std::fprintf(cimg::output(),"  > Using TIFF library:     %s%-13s%s %s('cimg_use_tiff' %s)%s\n",
                   cimg::t_bold,
#ifdef cimg_use_tiff
                   "Yes",cimg::t_normal,cimg::t_green,"defined",
#else
# 5867 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   "No",cimg::t_normal,cimg::t_green,"undefined",
#endif
# 5869 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   cimg::t_normal);

      std::fprintf(cimg::output(),"  > Using Magick++ library: %s%-13s%s %s('cimg_use_magick' %s)%s\n",
                   cimg::t_bold,
#ifdef cimg_use_magick
                   "Yes",cimg::t_normal,cimg::t_green,"defined",
#else
# 5876 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   "No",cimg::t_normal,cimg::t_green,"undefined",
#endif
# 5878 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   cimg::t_normal);

      std::fprintf(cimg::output(),"  > Using FFTW3 library:    %s%-13s%s %s('cimg_use_fftw3' %s)%s\n",
                   cimg::t_bold,
#ifdef cimg_use_fftw3
                   "Yes",cimg::t_normal,cimg::t_green,"defined",
#else
# 5885 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   "No",cimg::t_normal,cimg::t_green,"undefined",
#endif
# 5887 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   cimg::t_normal);

      std::fprintf(cimg::output(),"  > Using LAPACK library:   %s%-13s%s %s('cimg_use_lapack' %s)%s\n",
                   cimg::t_bold,
#ifdef cimg_use_lapack
                   "Yes",cimg::t_normal,cimg::t_green,"defined",
#else
# 5894 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   "No",cimg::t_normal,cimg::t_green,"undefined",
#endif
# 5896 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                   cimg::t_normal);

      cimg_snprintf(tmp,sizeof(tmp),"\"%.1020s\"",cimg::imagemagick_path());
      std::fprintf(cimg::output(),"  > Path of ImageMagick:    %s%-13s%s\n",
                   cimg::t_bold,
                   tmp,
                   cimg::t_normal);

      cimg_snprintf(tmp,sizeof(tmp),"\"%.1020s\"",cimg::graphicsmagick_path());
      std::fprintf(cimg::output(),"  > Path of GraphicsMagick: %s%-13s%s\n",
                   cimg::t_bold,
                   tmp,
                   cimg::t_normal);

      cimg_snprintf(tmp,sizeof(tmp),"\"%.1020s\"",cimg::medcon_path());
      std::fprintf(cimg::output(),"  > Path of 'medcon':       %s%-13s%s\n",
                   cimg::t_bold,
                   tmp,
                   cimg::t_normal);

      cimg_snprintf(tmp,sizeof(tmp),"\"%.1020s\"",cimg::temporary_path());
      std::fprintf(cimg::output(),"  > Temporary path:         %s%-13s%s\n",
                   cimg::t_bold,
                   tmp,
                   cimg::t_normal);

      std::fprintf(cimg::output(),"\n");
    }

    // Declare LAPACK function signatures if LAPACK support is enabled.
#ifdef cimg_use_lapack
    template<typename T>
    inline void getrf(int &N, T *lapA, int *IPIV, int &INFO) {
      dgetrf_(&N,&N,lapA,&N,IPIV,&INFO);
    }

    inline void getrf(int &N, float *lapA, int *IPIV, int &INFO) {
      sgetrf_(&N,&N,lapA,&N,IPIV,&INFO);
    }

    template<typename T>
    inline void getri(int &N, T *lapA, int *IPIV, T* WORK, int &LWORK, int &INFO) {
      dgetri_(&N,lapA,&N,IPIV,WORK,&LWORK,&INFO);
    }

    inline void getri(int &N, float *lapA, int *IPIV, float* WORK, int &LWORK, int &INFO) {
      sgetri_(&N,lapA,&N,IPIV,WORK,&LWORK,&INFO);
    }

    template<typename T>
    inline void gesvd(char &JOB, int &M, int &N, T *lapA, int &MN,
                      T *lapS, T *lapU, T *lapV, T *WORK, int &LWORK, int &INFO) {
      dgesvd_(&JOB,&JOB,&M,&N,lapA,&MN,lapS,lapU,&M,lapV,&N,WORK,&LWORK,&INFO);
    }

    inline void gesvd(char &JOB, int &M, int &N, float *lapA, int &MN,
                      float *lapS, float *lapU, float *lapV, float *WORK, int &LWORK, int &INFO) {
      sgesvd_(&JOB,&JOB,&M,&N,lapA,&MN,lapS,lapU,&M,lapV,&N,WORK,&LWORK,&INFO);
    }

    template<typename T>
    inline void getrs(char &TRANS, int &N, T *lapA, int *IPIV, T *lapB, int &INFO) {
      int one = 1;
      dgetrs_(&TRANS,&N,&one,lapA,&N,IPIV,lapB,&N,&INFO);
    }

    inline void getrs(char &TRANS, int &N, float *lapA, int *IPIV, float *lapB, int &INFO) {
      int one = 1;
      sgetrs_(&TRANS,&N,&one,lapA,&N,IPIV,lapB,&N,&INFO);
    }

    template<typename T>
    inline void syev(char &JOB, char &UPLO, int &N, T *lapA, T *lapW, T *WORK, int &LWORK, int &INFO) {
      dsyev_(&JOB,&UPLO,&N,lapA,&N,lapW,WORK,&LWORK,&INFO);
    }

    inline void syev(char &JOB, char &UPLO, int &N, float *lapA, float *lapW, float *WORK, int &LWORK, int &INFO) {
      ssyev_(&JOB,&UPLO,&N,lapA,&N,lapW,WORK,&LWORK,&INFO);
    }

    template<typename T>
    inline void sgels(char & TRANS, int &M, int &N, int &NRHS, T* lapA, int &LDA,
		      T* lapB, int &LDB, T* WORK, int &LWORK, int &INFO){
      dgels_(&TRANS, &M, &N, &NRHS, lapA, &LDA, lapB, &LDB, WORK, &LWORK, &INFO);
    }

    inline void sgels(char & TRANS, int &M, int &N, int &NRHS, float* lapA, int &LDA,
		      float* lapB, int &LDB, float* WORK, int &LWORK, int &INFO){
      sgels_(&TRANS, &M, &N, &NRHS, lapA, &LDA, lapB, &LDB, WORK, &LWORK, &INFO);
    }

#endif
# 5988 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    // End of the 'cimg' namespace
  }

  /*------------------------------------------------
   #
   #
   #   Definition of mathematical operators and
   #   external functions.
   #
   #
   -------------------------------------------------*/

#define _cimg_create_ext_operators(typ) \
  template<typename T> \
  inline CImg<typename cimg::superset<T,typ>::type> operator+(const typ val, const CImg<T>& img) { \
    return img + val; \
  } \
  template<typename T> \
  inline CImg<typename cimg::superset<T,typ>::type> operator-(const typ val, const CImg<T>& img) { \
    typedef typename cimg::superset<T,typ>::type Tt; \
    return CImg<Tt>(img._width,img._height,img._depth,img._spectrum,val)-=img; \
  } \
  template<typename T> \
  inline CImg<typename cimg::superset<T,typ>::type> operator*(const typ val, const CImg<T>& img) { \
    return img*val; \
  } \
  template<typename T> \
  inline CImg<typename cimg::superset<T,typ>::type> operator/(const typ val, const CImg<T>& img) { \
    return val*img.get_invert(); \
  } \
  template<typename T> \
  inline CImg<typename cimg::superset<T,typ>::type> operator&(const typ val, const CImg<T>& img) { \
    return img & val; \
  } \
  template<typename T> \
  inline CImg<typename cimg::superset<T,typ>::type> operator|(const typ val, const CImg<T>& img) { \
    return img | val; \
  } \
  template<typename T> \
  inline CImg<typename cimg::superset<T,typ>::type> operator^(const typ val, const CImg<T>& img) { \
    return img ^ val; \
  } \
  template<typename T> \
  inline bool operator==(const typ val, const CImg<T>& img) {   \
    return img == val; \
  } \
  template<typename T> \
  inline bool operator!=(const typ val, const CImg<T>& img) { \
    return img != val; \
  }

  _cimg_create_ext_operators(bool)
  _cimg_create_ext_operators(unsigned char)
  _cimg_create_ext_operators(char)
  _cimg_create_ext_operators(signed char)
  _cimg_create_ext_operators(unsigned short)
  _cimg_create_ext_operators(short)
  _cimg_create_ext_operators(unsigned int)
  _cimg_create_ext_operators(int)
  _cimg_create_ext_operators(unsigned long)
  _cimg_create_ext_operators(long)
  _cimg_create_ext_operators(float)
  _cimg_create_ext_operators(double)

  template<typename T>
  inline CImg<_cimg_Tfloat> operator+(const char *const expression, const CImg<T>& img) {
    return img + expression;
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> operator-(const char *const expression, const CImg<T>& img) {
    return CImg<_cimg_Tfloat>(img._width,img._height,img._depth,img._spectrum,expression,true)-=img;
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> operator*(const char *const expression, const CImg<T>& img) {
    return img*expression;
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> operator/(const char *const expression, const CImg<T>& img) {
    return expression*img.get_invert();
  }

  template<typename T>
  inline CImg<T> operator&(const char *const expression, const CImg<T>& img) {
    return img & expression;
  }

  template<typename T>
  inline CImg<T> operator|(const char *const expression, const CImg<T>& img) {
    return img | expression;
  }

  template<typename T>
  inline CImg<T> operator^(const char *const expression, const CImg<T>& img) {
    return img ^ expression;
  }

  template<typename T>
  inline bool operator==(const char *const expression, const CImg<T>& img) {
    return img == expression;
  }

  template<typename T>
  inline bool operator!=(const char *const expression, const CImg<T>& img) {
    return img != expression;
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> sqr(const CImg<T>& instance) {
    return instance.get_sqr();
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> sqrt(const CImg<T>& instance) {
    return instance.get_sqrt();
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> exp(const CImg<T>& instance) {
    return instance.get_exp();
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> log(const CImg<T>& instance) {
    return instance.get_log();
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> log2(const CImg<T>& instance) {
    return instance.get_log2();
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> log10(const CImg<T>& instance) {
    return instance.get_log10();
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> abs(const CImg<T>& instance) {
    return instance.get_abs();
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> sign(const CImg<T>& instance) {
    return instance.get_sign();
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> cos(const CImg<T>& instance) {
    return instance.get_cos();
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> sin(const CImg<T>& instance) {
    return instance.get_sin();
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> sinc(const CImg<T>& instance) {
    return instance.get_sinc();
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> tan(const CImg<T>& instance) {
    return instance.get_tan();
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> acos(const CImg<T>& instance) {
    return instance.get_acos();
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> asin(const CImg<T>& instance) {
    return instance.get_asin();
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> atan(const CImg<T>& instance) {
    return instance.get_atan();
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> cosh(const CImg<T>& instance) {
    return instance.get_cosh();
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> sinh(const CImg<T>& instance) {
    return instance.get_sinh();
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> tanh(const CImg<T>& instance) {
    return instance.get_tanh();
  }

  template<typename T>
  inline CImg<T> transpose(const CImg<T>& instance) {
    return instance.get_transpose();
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> invert(const CImg<T>& instance) {
    return instance.get_invert();
  }

  template<typename T>
  inline CImg<_cimg_Tfloat> pseudoinvert(const CImg<T>& instance) {
    return instance.get_pseudoinvert();
  }

  /*-----------------------------------
   #
   # Define the CImgDisplay structure
   #
   ----------------------------------*/
  //! Allow to create windows, display images on them and manage user events (keyboard, mouse and windows events).
  /**
     CImgDisplay methods rely on a low-level graphic library to perform: it can be either \b X-Window (X11, for Unix-based systems)
     or \b GDI32 (for Windows-based systems).
     If both libraries are missing, CImgDisplay will not be able to display images on screen, and will enter a minimal mode
     where warning messages will be outputed each time the program is trying to call one of the CImgDisplay method.

     The configuration variable \c cimg_display tells about the graphic library used.
     It is set automatically by \CImg when one of these graphic libraries has been detected.
     But, you can override its value if necessary. Valid choices are:
     - 0: Disable display capabilities.
     - 1: Use \b X-Window (X11) library.
     - 2: Use \b GDI32 library.

     Remember to link your program against \b X11 or \b GDI32 libraries if you use CImgDisplay.
  **/
  struct CImgDisplay {
    unsigned long _timer, _fps_frames, _fps_timer;
    unsigned int _width, _height, _normalization;
    float _fps_fps, _min, _max;
    bool _is_fullscreen;
    char *_title;
    volatile unsigned int _window_width, _window_height, _button, _keys[128], _released_keys[128];
    volatile int _window_x, _window_y, _mouse_x, _mouse_y, _wheel;
    volatile bool _is_closed, _is_resized, _is_moved, _is_event,
      _is_keyESC, _is_keyF1, _is_keyF2, _is_keyF3, _is_keyF4, _is_keyF5, _is_keyF6, _is_keyF7,
      _is_keyF8, _is_keyF9, _is_keyF10, _is_keyF11, _is_keyF12, _is_keyPAUSE, _is_key1, _is_key2,
      _is_key3, _is_key4, _is_key5, _is_key6, _is_key7, _is_key8, _is_key9, _is_key0,
      _is_keyBACKSPACE, _is_keyINSERT, _is_keyHOME, _is_keyPAGEUP, _is_keyTAB, _is_keyQ, _is_keyW, _is_keyE,
      _is_keyR, _is_keyT, _is_keyY, _is_keyU, _is_keyI, _is_keyO, _is_keyP, _is_keyDELETE,
      _is_keyEND, _is_keyPAGEDOWN, _is_keyCAPSLOCK, _is_keyA, _is_keyS, _is_keyD, _is_keyF, _is_keyG,
      _is_keyH, _is_keyJ, _is_keyK, _is_keyL, _is_keyENTER, _is_keySHIFTLEFT, _is_keyZ, _is_keyX,
      _is_keyC, _is_keyV, _is_keyB, _is_keyN, _is_keyM, _is_keySHIFTRIGHT, _is_keyARROWUP, _is_keyCTRLLEFT,
      _is_keyAPPLEFT, _is_keyALT, _is_keySPACE, _is_keyALTGR, _is_keyAPPRIGHT, _is_keyMENU, _is_keyCTRLRIGHT, _is_keyARROWLEFT,
      _is_keyARROWDOWN, _is_keyARROWRIGHT, _is_keyPAD0, _is_keyPAD1, _is_keyPAD2, _is_keyPAD3, _is_keyPAD4, _is_keyPAD5,
      _is_keyPAD6, _is_keyPAD7, _is_keyPAD8, _is_keyPAD9, _is_keyPADADD, _is_keyPADSUB, _is_keyPADMUL, _is_keyPADDIV;

    //@}
    //---------------------------
    //
    //! \name Plugins
    //@{
    //---------------------------

#ifdef cimgdisplay_plugin
#if 0 /* expanded by -frewrite-includes */
#include cimgdisplay_plugin
#endif /* expanded by -frewrite-includes */
# 6254 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 6255 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimgdisplay_plugin1
#if 0 /* expanded by -frewrite-includes */
#include cimgdisplay_plugin1
#endif /* expanded by -frewrite-includes */
# 6257 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 6258 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimgdisplay_plugin2
#if 0 /* expanded by -frewrite-includes */
#include cimgdisplay_plugin2
#endif /* expanded by -frewrite-includes */
# 6260 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 6261 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimgdisplay_plugin3
#if 0 /* expanded by -frewrite-includes */
#include cimgdisplay_plugin3
#endif /* expanded by -frewrite-includes */
# 6263 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 6264 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimgdisplay_plugin4
#if 0 /* expanded by -frewrite-includes */
#include cimgdisplay_plugin4
#endif /* expanded by -frewrite-includes */
# 6266 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 6267 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimgdisplay_plugin5
#if 0 /* expanded by -frewrite-includes */
#include cimgdisplay_plugin5
#endif /* expanded by -frewrite-includes */
# 6269 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 6270 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimgdisplay_plugin6
#if 0 /* expanded by -frewrite-includes */
#include cimgdisplay_plugin6
#endif /* expanded by -frewrite-includes */
# 6272 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 6273 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimgdisplay_plugin7
#if 0 /* expanded by -frewrite-includes */
#include cimgdisplay_plugin7
#endif /* expanded by -frewrite-includes */
# 6275 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 6276 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimgdisplay_plugin8
#if 0 /* expanded by -frewrite-includes */
#include cimgdisplay_plugin8
#endif /* expanded by -frewrite-includes */
# 6278 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 6279 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    //@}
    //--------------------------------------------------------
    //
    //! \name Constructors / Destructor / Instance Management
    //@{
    //--------------------------------------------------------

    //! Destructor.
    /**
       \note If the associated window is visible on the screen, it is closed by the call to the destructor.
    **/
    ~CImgDisplay() {
      assign();
    }

    //! Construct an empty display.
    /**
       \note Constructing an empty CImgDisplay instance does not make a window appearing on the screen, until
       display of valid data is performed.
       \par Example
       \code
       CImgDisplay disp;  // Does actually nothing.
       ...
       disp.display(img); // Construct new window and display image in it.
       \endcode
    **/
    CImgDisplay():
      _width(0),_height(0),_normalization(0),
      _min(0),_max(0),
      _is_fullscreen(false),
      _title(0),
      _window_width(0),_window_height(0),_button(0),
      _window_x(0),_window_y(0),_mouse_x(-1),_mouse_y(-1),_wheel(0),
      _is_closed(true),_is_resized(false),_is_moved(false),_is_event(false) {
      assign();
    }

    //! Construct a display with specified dimensions.
    /** \param width Window width.
        \param height Window height.
        \param title Window title.
        \param normalization Normalization type (<tt>0</tt>=none, <tt>1</tt>=always, <tt>2</tt>=once, <tt>3</tt>=pixel type-dependent, see normalization()).
        \param is_fullscreen Tells if fullscreen mode is enabled.
        \param is_closed Tells if associated window is initially visible or not.
        \note A black background is initially displayed on the associated window.
    **/
    CImgDisplay(const unsigned int width, const unsigned int height,
                const char *const title=0, const unsigned int normalization=3,
                const bool is_fullscreen=false, const bool is_closed=false):
      _width(0),_height(0),_normalization(0),
      _min(0),_max(0),
      _is_fullscreen(false),
      _title(0),
      _window_width(0),_window_height(0),_button(0),
      _window_x(0),_window_y(0),_mouse_x(-1),_mouse_y(-1),_wheel(0),
      _is_closed(true),_is_resized(false),_is_moved(false),_is_event(false) {
      assign(width,height,title,normalization,is_fullscreen,is_closed);
    }

    //! Construct a display from an image.
    /** \param img Image used as a model to create the window.
        \param title Window title.
        \param normalization Normalization type (<tt>0</tt>=none, <tt>1</tt>=always, <tt>2</tt>=once, <tt>3</tt>=pixel type-dependent, see normalization()).
        \param is_fullscreen Tells if fullscreen mode is enabled.
        \param is_closed Tells if associated window is initially visible or not.
        \note The pixels of the input image are initially displayed on the associated window.
    **/
    template<typename T>
    explicit CImgDisplay(const CImg<T>& img,
                         const char *const title=0, const unsigned int normalization=3,
                         const bool is_fullscreen=false, const bool is_closed=false):
      _width(0),_height(0),_normalization(0),
      _min(0),_max(0),
      _is_fullscreen(false),
      _title(0),
      _window_width(0),_window_height(0),_button(0),
      _window_x(0),_window_y(0),_mouse_x(-1),_mouse_y(-1),_wheel(0),
      _is_closed(true),_is_resized(false),_is_moved(false),_is_event(false) {
      assign(img,title,normalization,is_fullscreen,is_closed);
    }

    //! Construct a display from an image list.
    /** \param list The images list to display.
        \param title Window title.
        \param normalization Normalization type (<tt>0</tt>=none, <tt>1</tt>=always, <tt>2</tt>=once, <tt>3</tt>=pixel type-dependent, see normalization()).
        \param is_fullscreen Tells if fullscreen mode is enabled.
        \param is_closed Tells if associated window is initially visible or not.
        \note All images of the list, appended along the X-axis, are initially displayed on the associated window.
    **/
    template<typename T>
    explicit CImgDisplay(const CImgList<T>& list,
                         const char *const title=0, const unsigned int normalization=3,
                         const bool is_fullscreen=false, const bool is_closed=false):
      _width(0),_height(0),_normalization(0),
      _min(0),_max(0),
      _is_fullscreen(false),
      _title(0),
      _window_width(0),_window_height(0),_button(0),
      _window_x(0),_window_y(0),_mouse_x(-1),_mouse_y(-1),_wheel(0),
      _is_closed(true),_is_resized(false),_is_moved(false),_is_event(false) {
      assign(list,title,normalization,is_fullscreen,is_closed);
    }

    //! Construct a display as a copy of an existing one.
    /**
        \param disp Display instance to copy.
        \note The pixel buffer of the input window is initially displayed on the associated window.
    **/
    CImgDisplay(const CImgDisplay& disp):
      _width(0),_height(0),_normalization(0),
      _min(0),_max(0),
      _is_fullscreen(false),
      _title(0),
      _window_width(0),_window_height(0),_button(0),
      _window_x(0),_window_y(0),_mouse_x(-1),_mouse_y(-1),_wheel(0),
      _is_closed(true),_is_resized(false),_is_moved(false),_is_event(false) {
      assign(disp);
    }

#if cimg_display==0

    static void _no_display_exception() {
      throw CImgDisplayException("CImgDisplay(): No display available.");
    }

    //! Destructor - Empty constructor \inplace.
    /**
       \note Replace the current instance by an empty display.
    **/
    CImgDisplay& assign() {
      return flush();
    }

    //! Construct a display with specified dimensions \inplace.
    /**
    **/
    CImgDisplay& assign(const unsigned int width, const unsigned int height,
                        const char *const title=0, const unsigned int normalization=3,
                        const bool is_fullscreen=false, const bool is_closed=false) {
      cimg::unused(width,height,title,normalization,is_fullscreen,is_closed);
      _no_display_exception();
      return assign();
    }

    //! Construct a display from an image \inplace.
    /**
    **/
    template<typename T>
    CImgDisplay& assign(const CImg<T>& img,
                        const char *const title=0, const unsigned int normalization=3,
                        const bool is_fullscreen=false, const bool is_closed=false) {
      _no_display_exception();
      return assign(img._width,img._height,title,normalization,is_fullscreen,is_closed);
    }

    //! Construct a display from an image list \inplace.
    /**
    **/
    template<typename T>
    CImgDisplay& assign(const CImgList<T>& list,
                        const char *const title=0, const unsigned int normalization=3,
                        const bool is_fullscreen=false, const bool is_closed=false) {
      _no_display_exception();
      return assign(list._width,list._width,title,normalization,is_fullscreen,is_closed);
    }

    //! Construct a display as a copy of another one \inplace.
    /**
    **/
    CImgDisplay& assign(const CImgDisplay &disp) {
      _no_display_exception();
      return assign(disp._width,disp._height);
    }

#endif
# 6455 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    //! Return a reference to an empty display.
    /**
       \note Can be useful for writing function prototypes where one of the argument (of type CImgDisplay&)
       must have a default value.
       \par Example
       \code
       void foo(CImgDisplay& disp=CImgDisplay::empty());
       \endcode
    **/
    static CImgDisplay& empty() {
      static CImgDisplay _empty;
      return _empty.assign();
    }

#define cimg_fitscreen(dx,dy,dz) CImgDisplay::_fitscreen(dx,dy,dz,128,-85,false),CImgDisplay::_fitscreen(dx,dy,dz,128,-85,true)
    static unsigned int _fitscreen(const unsigned int dx, const unsigned int dy, const unsigned int dz,
                                   const int dmin, const int dmax,const bool return_y) {
      const unsigned int _nw = dx + (dz>1?dz:0), _nh = dy + (dz>1?dz:0);
      unsigned int nw = _nw?_nw:1, nh = _nh?_nh:1;
      const unsigned int
        sw = CImgDisplay::screen_width(), sh = CImgDisplay::screen_height(),
        mw = dmin<0?(unsigned int)(sw*-dmin/100):(unsigned int)dmin,
        mh = dmin<0?(unsigned int)(sh*-dmin/100):(unsigned int)dmin,
        Mw = dmax<0?(unsigned int)(sw*-dmax/100):(unsigned int)dmax,
        Mh = dmax<0?(unsigned int)(sh*-dmax/100):(unsigned int)dmax;
      if (nw<mw) { nh = nh*mw/nw; nh+=(nh==0?1:0); nw = mw; }
      if (nh<mh) { nw = nw*mh/nh; nw+=(nw==0?1:0); nh = mh; }
      if (nw>Mw) { nh = nh*Mw/nw; nh+=(nh==0?1:0); nw = Mw; }
      if (nh>Mh) { nw = nw*Mh/nh; nw+=(nw==0?1:0); nh = Mh; }
      if (nw<mw) nw = mw;
      if (nh<mh) nh = mh;
      return return_y?nh:nw;
    }

    //@}
    //------------------------------------------
    //
    //! \name Overloaded Operators
    //@{
    //------------------------------------------

    //! Display image on associated window.
    /**
       \note <tt>disp = img</tt> is equivalent to <tt>disp.display(img)</tt>.
    **/
    template<typename t>
    CImgDisplay& operator=(const CImg<t>& img) {
      return display(img);
    }

    //! Display list of images on associated window.
    /**
       \note <tt>disp = list</tt> is equivalent to <tt>disp.display(list)</tt>.
    **/
    template<typename t>
    CImgDisplay& operator=(const CImgList<t>& list) {
      return display(list);
    }

    //! Construct a display as a copy of another one \inplace.
    /**
       \note Equivalent to assign(const CImgDisplay&).
     **/
    CImgDisplay& operator=(const CImgDisplay& disp) {
      return assign(disp);
    }

    //! Return \c false if display is empty, \c true otherwise.
    /**
       \note <tt>if (disp) { ... }</tt> is equivalent to <tt>if (!disp.is_empty()) { ... }</tt>.
    **/
    operator bool() const {
      return !is_empty();
    }

    //@}
    //------------------------------------------
    //
    //! \name Instance Checking
    //@{
    //------------------------------------------

    //! Return \c true if display is empty, \c false otherwise.
    /**
    **/
    bool is_empty() const {
      return !(_width && _height);
    }

    //! Return \c true if display is closed (i.e. not visible on the screen), \c false otherwise.
    /**
       \note
       - When a user physically closes the associated window, the display is set to closed.
       - A closed display is not destroyed. Its associated window can be show again on the screen using show().
    **/
    bool is_closed() const {
      return _is_closed;
    }

    //! Return \c true if associated window has been resized on the screen, \c false otherwise.
    /**
    **/
    bool is_resized() const {
      return _is_resized;
    }

    //! Return \c true if associated window has been moved on the screen, \c false otherwise.
    /**
    **/
    bool is_moved() const {
      return _is_moved;
    }

    //! Return \c true if any event has occured on the associated window, \c false otherwise.
    /**
    **/
    bool is_event() const {
      return _is_event;
    }

    //! Return \c true if current display is in fullscreen mode, \c false otherwise.
    /**
    **/
    bool is_fullscreen() const {
      return _is_fullscreen;
    }

    //! Return \c true if any key is being pressed on the associated window, \c false otherwise.
    /**
       \note The methods below do the same only for specific keys.
    **/
    bool is_key() const {
      return _is_keyESC || _is_keyF1 || _is_keyF2 || _is_keyF3 ||
        _is_keyF4 || _is_keyF5 || _is_keyF6 || _is_keyF7 ||
        _is_keyF8 || _is_keyF9 || _is_keyF10 || _is_keyF11 ||
        _is_keyF12 || _is_keyPAUSE || _is_key1 || _is_key2 ||
        _is_key3 || _is_key4 || _is_key5 || _is_key6 ||
        _is_key7 || _is_key8 || _is_key9 || _is_key0 ||
        _is_keyBACKSPACE || _is_keyINSERT || _is_keyHOME ||
        _is_keyPAGEUP || _is_keyTAB || _is_keyQ || _is_keyW ||
        _is_keyE || _is_keyR || _is_keyT || _is_keyY ||
        _is_keyU || _is_keyI || _is_keyO || _is_keyP ||
        _is_keyDELETE || _is_keyEND || _is_keyPAGEDOWN ||
        _is_keyCAPSLOCK || _is_keyA || _is_keyS || _is_keyD ||
        _is_keyF || _is_keyG || _is_keyH || _is_keyJ ||
        _is_keyK || _is_keyL || _is_keyENTER ||
        _is_keySHIFTLEFT || _is_keyZ || _is_keyX || _is_keyC ||
        _is_keyV || _is_keyB || _is_keyN || _is_keyM ||
        _is_keySHIFTRIGHT || _is_keyARROWUP || _is_keyCTRLLEFT ||
        _is_keyAPPLEFT || _is_keyALT || _is_keySPACE || _is_keyALTGR ||
        _is_keyAPPRIGHT || _is_keyMENU || _is_keyCTRLRIGHT ||
        _is_keyARROWLEFT || _is_keyARROWDOWN || _is_keyARROWRIGHT ||
        _is_keyPAD0 || _is_keyPAD1 || _is_keyPAD2 ||
        _is_keyPAD3 || _is_keyPAD4 || _is_keyPAD5 ||
        _is_keyPAD6 || _is_keyPAD7 || _is_keyPAD8 ||
        _is_keyPAD9 || _is_keyPADADD || _is_keyPADSUB ||
        _is_keyPADMUL || _is_keyPADDIV;
    }

    //! Return \c true if key specified by given keycode is being pressed on the associated window, \c false otherwise.
    /**
       \param keycode Keycode to test.
       \note Keycode constants are defined in the cimg namespace and are architecture-dependent. Use them to ensure
       your code stay portable (see cimg::keyESC).
       \par Example
       \code
       CImgDisplay disp(400,400);
       while (!disp.is_closed()) {
         if (disp.key(cimg::keyTAB)) { ... }  // Equivalent to 'if (disp.is_keyTAB())'.
         disp.wait();
       }
       \endcode
    **/
    bool is_key(const unsigned int keycode) const {
#define _cimg_iskey_test(k) if (keycode==cimg::key##k) return _is_key##k;
      _cimg_iskey_test(ESC); _cimg_iskey_test(F1); _cimg_iskey_test(F2); _cimg_iskey_test(F3);
      _cimg_iskey_test(F4); _cimg_iskey_test(F5); _cimg_iskey_test(F6); _cimg_iskey_test(F7);
      _cimg_iskey_test(F8); _cimg_iskey_test(F9); _cimg_iskey_test(F10); _cimg_iskey_test(F11);
      _cimg_iskey_test(F12); _cimg_iskey_test(PAUSE); _cimg_iskey_test(1); _cimg_iskey_test(2);
      _cimg_iskey_test(3); _cimg_iskey_test(4); _cimg_iskey_test(5); _cimg_iskey_test(6);
      _cimg_iskey_test(7); _cimg_iskey_test(8); _cimg_iskey_test(9); _cimg_iskey_test(0);
      _cimg_iskey_test(BACKSPACE); _cimg_iskey_test(INSERT); _cimg_iskey_test(HOME);
      _cimg_iskey_test(PAGEUP); _cimg_iskey_test(TAB); _cimg_iskey_test(Q); _cimg_iskey_test(W);
      _cimg_iskey_test(E); _cimg_iskey_test(R); _cimg_iskey_test(T); _cimg_iskey_test(Y);
      _cimg_iskey_test(U); _cimg_iskey_test(I); _cimg_iskey_test(O); _cimg_iskey_test(P);
      _cimg_iskey_test(DELETE); _cimg_iskey_test(END); _cimg_iskey_test(PAGEDOWN);
      _cimg_iskey_test(CAPSLOCK); _cimg_iskey_test(A); _cimg_iskey_test(S); _cimg_iskey_test(D);
      _cimg_iskey_test(F); _cimg_iskey_test(G); _cimg_iskey_test(H); _cimg_iskey_test(J);
      _cimg_iskey_test(K); _cimg_iskey_test(L); _cimg_iskey_test(ENTER);
      _cimg_iskey_test(SHIFTLEFT); _cimg_iskey_test(Z); _cimg_iskey_test(X); _cimg_iskey_test(C);
      _cimg_iskey_test(V); _cimg_iskey_test(B); _cimg_iskey_test(N); _cimg_iskey_test(M);
      _cimg_iskey_test(SHIFTRIGHT); _cimg_iskey_test(ARROWUP); _cimg_iskey_test(CTRLLEFT);
      _cimg_iskey_test(APPLEFT); _cimg_iskey_test(ALT); _cimg_iskey_test(SPACE); _cimg_iskey_test(ALTGR);
      _cimg_iskey_test(APPRIGHT); _cimg_iskey_test(MENU); _cimg_iskey_test(CTRLRIGHT);
      _cimg_iskey_test(ARROWLEFT); _cimg_iskey_test(ARROWDOWN); _cimg_iskey_test(ARROWRIGHT);
      _cimg_iskey_test(PAD0); _cimg_iskey_test(PAD1); _cimg_iskey_test(PAD2);
      _cimg_iskey_test(PAD3); _cimg_iskey_test(PAD4); _cimg_iskey_test(PAD5);
      _cimg_iskey_test(PAD6); _cimg_iskey_test(PAD7); _cimg_iskey_test(PAD8);
      _cimg_iskey_test(PAD9); _cimg_iskey_test(PADADD); _cimg_iskey_test(PADSUB);
      _cimg_iskey_test(PADMUL); _cimg_iskey_test(PADDIV);
      return false;
    }

    //! Return \c true if key specified by given keycode is being pressed on the associated window, \c false otherwise.
    /**
       \param keycode C-string containing the keycode label of the key to test.
       \note Use it when the key you want to test can be dynamically set by the user.
       \par Example
       \code
       CImgDisplay disp(400,400);
       const char *const keycode = "TAB";
       while (!disp.is_closed()) {
         if (disp.is_key(keycode)) { ... }  // Equivalent to 'if (disp.is_keyTAB())'.
         disp.wait();
       }
       \endcode
    **/
    bool is_key(const char *const keycode) const {
#define _cimg_iskey_test2(k) if (!cimg::strcasecmp(keycode,#k)) return _is_key##k;
      _cimg_iskey_test2(ESC); _cimg_iskey_test2(F1); _cimg_iskey_test2(F2); _cimg_iskey_test2(F3);
      _cimg_iskey_test2(F4); _cimg_iskey_test2(F5); _cimg_iskey_test2(F6); _cimg_iskey_test2(F7);
      _cimg_iskey_test2(F8); _cimg_iskey_test2(F9); _cimg_iskey_test2(F10); _cimg_iskey_test2(F11);
      _cimg_iskey_test2(F12); _cimg_iskey_test2(PAUSE); _cimg_iskey_test2(1); _cimg_iskey_test2(2);
      _cimg_iskey_test2(3); _cimg_iskey_test2(4); _cimg_iskey_test2(5); _cimg_iskey_test2(6);
      _cimg_iskey_test2(7); _cimg_iskey_test2(8); _cimg_iskey_test2(9); _cimg_iskey_test2(0);
      _cimg_iskey_test2(BACKSPACE); _cimg_iskey_test2(INSERT); _cimg_iskey_test2(HOME);
      _cimg_iskey_test2(PAGEUP); _cimg_iskey_test2(TAB); _cimg_iskey_test2(Q); _cimg_iskey_test2(W);
      _cimg_iskey_test2(E); _cimg_iskey_test2(R); _cimg_iskey_test2(T); _cimg_iskey_test2(Y);
      _cimg_iskey_test2(U); _cimg_iskey_test2(I); _cimg_iskey_test2(O); _cimg_iskey_test2(P);
      _cimg_iskey_test2(DELETE); _cimg_iskey_test2(END); _cimg_iskey_test2(PAGEDOWN);
      _cimg_iskey_test2(CAPSLOCK); _cimg_iskey_test2(A); _cimg_iskey_test2(S); _cimg_iskey_test2(D);
      _cimg_iskey_test2(F); _cimg_iskey_test2(G); _cimg_iskey_test2(H); _cimg_iskey_test2(J);
      _cimg_iskey_test2(K); _cimg_iskey_test2(L); _cimg_iskey_test2(ENTER);
      _cimg_iskey_test2(SHIFTLEFT); _cimg_iskey_test2(Z); _cimg_iskey_test2(X); _cimg_iskey_test2(C);
      _cimg_iskey_test2(V); _cimg_iskey_test2(B); _cimg_iskey_test2(N); _cimg_iskey_test2(M);
      _cimg_iskey_test2(SHIFTRIGHT); _cimg_iskey_test2(ARROWUP); _cimg_iskey_test2(CTRLLEFT);
      _cimg_iskey_test2(APPLEFT); _cimg_iskey_test2(ALT); _cimg_iskey_test2(SPACE); _cimg_iskey_test2(ALTGR);
      _cimg_iskey_test2(APPRIGHT); _cimg_iskey_test2(MENU); _cimg_iskey_test2(CTRLRIGHT);
      _cimg_iskey_test2(ARROWLEFT); _cimg_iskey_test2(ARROWDOWN); _cimg_iskey_test2(ARROWRIGHT);
      _cimg_iskey_test2(PAD0); _cimg_iskey_test2(PAD1); _cimg_iskey_test2(PAD2);
      _cimg_iskey_test2(PAD3); _cimg_iskey_test2(PAD4); _cimg_iskey_test2(PAD5);
      _cimg_iskey_test2(PAD6); _cimg_iskey_test2(PAD7); _cimg_iskey_test2(PAD8);
      _cimg_iskey_test2(PAD9); _cimg_iskey_test2(PADADD); _cimg_iskey_test2(PADSUB);
      _cimg_iskey_test2(PADMUL); _cimg_iskey_test2(PADDIV);
      return false;
    }

    //! Return \c true if specified key sequence has been typed on the associated window, \c false otherwise.
    /**
       \param keycodes_sequence Buffer of keycodes to test.
       \param length Number of keys in the \c keycodes_sequence buffer.
       \param remove_sequence Tells if the key sequence must be removed from the key history, if found.
       \note Keycode constants are defined in the cimg namespace and are architecture-dependent. Use them to ensure
       your code stay portable (see cimg::keyESC).
       \par Example
       \code
       CImgDisplay disp(400,400);
       const unsigned int key_seq[] = { cimg::keyCTRLLEFT, cimg::keyD };
       while (!disp.is_closed()) {
         if (disp.is_key_sequence(key_seq,2)) { ... }  // Test for the 'CTRL+D' keyboard event.
         disp.wait();
       }
       \endcode
    **/
    bool is_key_sequence(const unsigned int *const keycodes_sequence, const unsigned int length, const bool remove_sequence=false) {
      if (keycodes_sequence && length) {
        const unsigned int
          *const ps_end = keycodes_sequence + length - 1,
          *const pk_end = (unsigned int*)_keys + 1 + sizeof(_keys)/sizeof(unsigned int) - length,
          k = *ps_end;
        for (unsigned int *pk = (unsigned int*)_keys; pk<pk_end; ) {
          if (*(pk++)==k) {
            bool res = true;
            const unsigned int *ps = ps_end, *pk2 = pk;
            for (unsigned int i = 1; i<length; ++i) res = (*(--ps)==*(pk2++));
            if (res) {
              if (remove_sequence) std::memset((void*)(pk-1),0,sizeof(unsigned int)*length);
              return true;
            }
          }
        }
      }
      return false;
    }

#define _cimg_iskey_def(k) \
    bool is_key##k() const { \
      return _is_key##k; \
    }

    //! Return \c true if the \c ESC key is being pressed on the associated window, \c false otherwise.
    /**
       \note Similar methods exist for all keys managed by \CImg (see cimg::keyESC).
    **/
    _cimg_iskey_def(ESC); _cimg_iskey_def(F1); _cimg_iskey_def(F2); _cimg_iskey_def(F3);
    _cimg_iskey_def(F4); _cimg_iskey_def(F5); _cimg_iskey_def(F6); _cimg_iskey_def(F7);
    _cimg_iskey_def(F8); _cimg_iskey_def(F9); _cimg_iskey_def(F10); _cimg_iskey_def(F11);
    _cimg_iskey_def(F12); _cimg_iskey_def(PAUSE); _cimg_iskey_def(1); _cimg_iskey_def(2);
    _cimg_iskey_def(3); _cimg_iskey_def(4); _cimg_iskey_def(5); _cimg_iskey_def(6);
    _cimg_iskey_def(7); _cimg_iskey_def(8); _cimg_iskey_def(9); _cimg_iskey_def(0);
    _cimg_iskey_def(BACKSPACE); _cimg_iskey_def(INSERT); _cimg_iskey_def(HOME);
    _cimg_iskey_def(PAGEUP); _cimg_iskey_def(TAB); _cimg_iskey_def(Q); _cimg_iskey_def(W);
    _cimg_iskey_def(E); _cimg_iskey_def(R); _cimg_iskey_def(T); _cimg_iskey_def(Y);
    _cimg_iskey_def(U); _cimg_iskey_def(I); _cimg_iskey_def(O); _cimg_iskey_def(P);
    _cimg_iskey_def(DELETE); _cimg_iskey_def(END); _cimg_iskey_def(PAGEDOWN);
    _cimg_iskey_def(CAPSLOCK); _cimg_iskey_def(A); _cimg_iskey_def(S); _cimg_iskey_def(D);
    _cimg_iskey_def(F); _cimg_iskey_def(G); _cimg_iskey_def(H); _cimg_iskey_def(J);
    _cimg_iskey_def(K); _cimg_iskey_def(L); _cimg_iskey_def(ENTER);
    _cimg_iskey_def(SHIFTLEFT); _cimg_iskey_def(Z); _cimg_iskey_def(X); _cimg_iskey_def(C);
    _cimg_iskey_def(V); _cimg_iskey_def(B); _cimg_iskey_def(N); _cimg_iskey_def(M);
    _cimg_iskey_def(SHIFTRIGHT); _cimg_iskey_def(ARROWUP); _cimg_iskey_def(CTRLLEFT);
    _cimg_iskey_def(APPLEFT); _cimg_iskey_def(ALT); _cimg_iskey_def(SPACE); _cimg_iskey_def(ALTGR);
    _cimg_iskey_def(APPRIGHT); _cimg_iskey_def(MENU); _cimg_iskey_def(CTRLRIGHT);
    _cimg_iskey_def(ARROWLEFT); _cimg_iskey_def(ARROWDOWN); _cimg_iskey_def(ARROWRIGHT);
    _cimg_iskey_def(PAD0); _cimg_iskey_def(PAD1); _cimg_iskey_def(PAD2);
    _cimg_iskey_def(PAD3); _cimg_iskey_def(PAD4); _cimg_iskey_def(PAD5);
    _cimg_iskey_def(PAD6); _cimg_iskey_def(PAD7); _cimg_iskey_def(PAD8);
    _cimg_iskey_def(PAD9); _cimg_iskey_def(PADADD); _cimg_iskey_def(PADSUB);
    _cimg_iskey_def(PADMUL); _cimg_iskey_def(PADDIV);

    //@}
    //------------------------------------------
    //
    //! \name Instance Characteristics
    //@{
    //------------------------------------------

#if cimg_display==0

    //! Return width of the screen (current resolution along the X-axis).
    /**
    **/
    static int screen_width() {
      _no_display_exception();
      return 0;
    }

    //! Return height of the screen (current resolution along the Y-axis).
    /**
    **/
    static int screen_height() {
      _no_display_exception();
      return 0;
    }

#endif
# 6802 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    //! Return display width.
    /**
       \note The width of the display (i.e. the width of the pixel data buffer associated to the CImgDisplay instance)
       may be different from the actual width of the associated window.
    **/
    int width() const {
      return (int)_width;
    }

    //! Return display height.
    /**
       \note The height of the display (i.e. the height of the pixel data buffer associated to the CImgDisplay instance)
       may be different from the actual height of the associated window.
    **/
    int height() const {
      return (int)_height;
    }

    //! Return normalization type of the display.
    /**
       The normalization type tells about how the values of an input image are normalized by the CImgDisplay to be correctly displayed.
       The range of values for pixels displayed on screen is <tt>[0,255]</tt>. If the range of values of the data to display
       is different, a normalization may be required for displaying the data in a correct way.
       The normalization type can be one of:
       - \c 0: Value normalization is disabled. It is then assumed that all input data to be displayed by the CImgDisplay instance
       have values in range <tt>[0,255]</tt>.
       - \c 1: Value normalization is always performed (this is the default behavior).
       Before displaying an input image, its values will be (virtually) stretched
       in range <tt>[0,255]</tt>, so that the contrast of the displayed pixels will be maximum.
       Use this mode for images whose minimum and maximum values are not prescribed to known values (e.g. float-valued images).
       Note that when normalized versions of images are computed for display purposes, the actual values of these images are not modified.
       - \c 2: Value normalization is performed once (on the first image display), then the same normalization coefficients are kept for
       next displayed frames.
       - \c 3: Value normalization depends on the pixel type of the data to display. For integer pixel types, the normalization
       is done regarding the minimum/maximum values of the type (no normalization occurs then for <tt>unsigned char</tt>).
       For float-valued pixel types, the normalization is done regarding the minimum/maximum value of the image data instead.

    **/
    unsigned int normalization() const {
      return _normalization;
    }

    //! Return title of the associated window as a C-string.
    /**
       \note Window title may be not visible, depending on the used window manager or if the current display is in fullscreen mode.
    **/
    const char *title() const {
      return _title;
    }

    //! Return width of the associated window.
    /**
       \note The width of the display (i.e. the width of the pixel data buffer associated to the CImgDisplay instance)
       may be different from the actual width of the associated window.
    **/
    int window_width() const {
      return (int)_window_width;
    }

    //! Return height of the associated window.
    /**
       \note The height of the display (i.e. the height of the pixel data buffer associated to the CImgDisplay instance)
       may be different from the actual height of the associated window.
    **/
    int window_height() const {
      return (int)_window_height;
    }

    //! Return X-coordinate of the associated window.
    /**
       \note The returned coordinate corresponds to the location of the upper-left corner of the associated window.
    **/
    int window_x() const {
      return _window_x;
    }

    //! Return Y-coordinate of the associated window.
    /**
       \note The returned coordinate corresponds to the location of the upper-left corner of the associated window.
    **/
    int window_y() const {
      return _window_y;
    }

    //! Return X-coordinate of the mouse pointer.
    /**
       \note
       - If the mouse pointer is outside window area, \c -1 is returned.
       - Otherwise, the returned value is in the range [0,width()-1].
    **/
    int mouse_x() const {
      return _mouse_x;
    }

    //! Return Y-coordinate of the mouse pointer.
    /**
       \note
       - If the mouse pointer is outside window area, \c -1 is returned.
       - Otherwise, the returned value is in the range [0,height()-1].
    **/
    int mouse_y() const {
      return _mouse_y;
    }

    //! Return current state of the mouse buttons.
    /**
       \note Three mouse buttons can be managed. If one button is pressed, its corresponding bit in the returned value is set:
       - bit \c 0 (value \c 0x1): State of the left mouse button.
       - bit \c 1 (value \c 0x2): State of the right mouse button.
       - bit \c 2 (value \c 0x4): State of the middle mouse button.

       Several bits can be activated if more than one button are pressed at the same time.
       \par Example
       \code
       CImgDisplay disp(400,400);
       while (!disp.is_closed()) {
         if (disp.button()&1) { // Left button clicked.
           ...
         }
         if (disp.button()&2) { // Right button clicked.
           ...
         }
         if (disp.button()&4) { // Middle button clicked.
           ...
         }
         disp.wait();
       }
       \endcode
    **/
    unsigned int button() const {
      return _button;
    }

    //! Return current state of the mouse wheel.
    /**
       \note
       - The returned value can be positive or negative depending on whether the mouse wheel has been scrolled forward or backward.
       - Scrolling the wheel forward add \c 1 to the wheel value.
       - Scrolling the wheel backward substract \c 1 to the wheel value.
       - The returned value cumulates the number of forward of backward scrolls since the creation of the display, or since the
       last reset of the wheel value (using set_wheel()). It is strongly recommended to quickly reset the wheel counter
       when an action has been performed regarding the current wheel value. Otherwise, the returned wheel value may be for instance \c 0
       despite the fact that many scrolls have been done (as many in forward as in backward directions).
       \par Example
       \code
       CImgDisplay disp(400,400);
       while (!disp.is_closed()) {
         if (disp.wheel()) {
           int counter = disp.wheel();  // Read the state of the mouse wheel.
           ...                          // Do what you want with 'counter'.
           disp.set_wheel();            // Reset the wheel value to 0.
         }
         disp.wait();
       }
       \endcode
    **/
    int wheel() const {
      return _wheel;
    }

    //! Return one entry from the pressed keys history.
    /**
       \param pos Indice to read from the pressed keys history (indice \c 0 corresponds to latest entry).
       \return Keycode of a pressed key or \c 0 for a released key.
       \note
       - Each CImgDisplay stores a history of the pressed keys in a buffer of size \c 128. When a new key is pressed,
       its keycode is stored in the pressed keys history. When a key is released, \c 0 is put instead.
       This means that up to the 64 last pressed keys may be read from the pressed keys history.
       When a new value is stored, the pressed keys history is shifted so that the latest entry is always
       stored at position \c 0.
       - Keycode constants are defined in the cimg namespace and are architecture-dependent. Use them to ensure
       your code stay portable (see cimg::keyESC).
    **/
    unsigned int key(const unsigned int pos=0) const {
      return pos<(sizeof(_keys)/sizeof(unsigned int))?_keys[pos]:0;
    }

    //! Return one entry from the released keys history.
    /**
       \param pos Indice to read from the released keys history (indice \c 0 corresponds to latest entry).
       \return Keycode of a released key or \c 0 for a pressed key.
       \note
       - Each CImgDisplay stores a history of the released keys in a buffer of size \c 128. When a new key is released,
       its keycode is stored in the pressed keys history. When a key is pressed, \c 0 is put instead.
       This means that up to the 64 last released keys may be read from the released keys history.
       When a new value is stored, the released keys history is shifted so that the latest entry is always
       stored at position \c 0.
       - Keycode constants are defined in the cimg namespace and are architecture-dependent. Use them to ensure
       your code stay portable (see cimg::keyESC).
    **/
    unsigned int released_key(const unsigned int pos=0) const {
      return pos<(sizeof(_released_keys)/sizeof(unsigned int))?_released_keys[pos]:0;
    }

    //! Return keycode corresponding to the specified string.
    /**
       \note Keycode constants are defined in the cimg namespace and are architecture-dependent. Use them to ensure
       your code stay portable (see cimg::keyESC).
       \par Example
       \code
       const unsigned int keyTAB = CImgDisplay::keycode("TAB");  // Return cimg::keyTAB.
       \endcode
    **/
    static unsigned int keycode(const char *const keycode) {
#define _cimg_keycode(k) if (!cimg::strcasecmp(keycode,#k)) return cimg::key##k;
      _cimg_keycode(ESC); _cimg_keycode(F1); _cimg_keycode(F2); _cimg_keycode(F3);
      _cimg_keycode(F4); _cimg_keycode(F5); _cimg_keycode(F6); _cimg_keycode(F7);
      _cimg_keycode(F8); _cimg_keycode(F9); _cimg_keycode(F10); _cimg_keycode(F11);
      _cimg_keycode(F12); _cimg_keycode(PAUSE); _cimg_keycode(1); _cimg_keycode(2);
      _cimg_keycode(3); _cimg_keycode(4); _cimg_keycode(5); _cimg_keycode(6);
      _cimg_keycode(7); _cimg_keycode(8); _cimg_keycode(9); _cimg_keycode(0);
      _cimg_keycode(BACKSPACE); _cimg_keycode(INSERT); _cimg_keycode(HOME);
      _cimg_keycode(PAGEUP); _cimg_keycode(TAB); _cimg_keycode(Q); _cimg_keycode(W);
      _cimg_keycode(E); _cimg_keycode(R); _cimg_keycode(T); _cimg_keycode(Y);
      _cimg_keycode(U); _cimg_keycode(I); _cimg_keycode(O); _cimg_keycode(P);
      _cimg_keycode(DELETE); _cimg_keycode(END); _cimg_keycode(PAGEDOWN);
      _cimg_keycode(CAPSLOCK); _cimg_keycode(A); _cimg_keycode(S); _cimg_keycode(D);
      _cimg_keycode(F); _cimg_keycode(G); _cimg_keycode(H); _cimg_keycode(J);
      _cimg_keycode(K); _cimg_keycode(L); _cimg_keycode(ENTER);
      _cimg_keycode(SHIFTLEFT); _cimg_keycode(Z); _cimg_keycode(X); _cimg_keycode(C);
      _cimg_keycode(V); _cimg_keycode(B); _cimg_keycode(N); _cimg_keycode(M);
      _cimg_keycode(SHIFTRIGHT); _cimg_keycode(ARROWUP); _cimg_keycode(CTRLLEFT);
      _cimg_keycode(APPLEFT); _cimg_keycode(ALT); _cimg_keycode(SPACE); _cimg_keycode(ALTGR);
      _cimg_keycode(APPRIGHT); _cimg_keycode(MENU); _cimg_keycode(CTRLRIGHT);
      _cimg_keycode(ARROWLEFT); _cimg_keycode(ARROWDOWN); _cimg_keycode(ARROWRIGHT);
      _cimg_keycode(PAD0); _cimg_keycode(PAD1); _cimg_keycode(PAD2);
      _cimg_keycode(PAD3); _cimg_keycode(PAD4); _cimg_keycode(PAD5);
      _cimg_keycode(PAD6); _cimg_keycode(PAD7); _cimg_keycode(PAD8);
      _cimg_keycode(PAD9); _cimg_keycode(PADADD); _cimg_keycode(PADSUB);
      _cimg_keycode(PADMUL); _cimg_keycode(PADDIV);
      return 0;
    }

    //! Return the current refresh rate, in frames per second.
    /**
       \note Returns a significant value when the current instance is used to display successive frames.
       It measures the delay between successive calls to frames_per_second().
    **/
    float frames_per_second() {
      if (!_fps_timer) _fps_timer = cimg::time();
      const float delta = (cimg::time()-_fps_timer)/1000.0f;
      ++_fps_frames;
      if (delta>=1) {
        _fps_fps = _fps_frames/delta;
        _fps_frames = 0;
        _fps_timer = cimg::time();
      }
      return _fps_fps;
    }

    //@}
    //---------------------------------------
    //
    //! \name Window Manipulation
    //@{
    //---------------------------------------

#if cimg_display==0

    //! Display image on associated window.
    /**
       \param img Input image to display.
       \note This method returns immediately.
    **/
    template<typename T>
    CImgDisplay& display(const CImg<T>& img) {
      return assign(img);
    }

#endif
# 7073 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    //! Display list of images on associated window.
    /**
       \param list List of images to display.
       \param axis Axis used to append the images along, for the visualization (can be \c x, \c y, \c z or \c c).
       \param align Relative position of aligned images when displaying lists with images of different sizes
       (\c 0 for upper-left, \c 0.5 for centering and \c 1 for lower-right).
       \note This method returns immediately.
    **/
    template<typename T>
    CImgDisplay& display(const CImgList<T>& list, const char axis='x', const float align=0) {
      return display(list.get_append(axis,align));
    }

#if cimg_display==0

    //! Show (closed) associated window on the screen.
    /**
       \note
       - Force the associated window of a display to be visible on the screen, even if it has been closed before.
       - Using show() on a visible display does nothing.
    **/
    CImgDisplay& show() {
      return assign();
    }

    //! Close (visible) associated window and make it disappear from the screen.
    /**
       \note
       - A closed display only means the associated window is not visible anymore. This does not mean the display has been destroyed.
       Use show() to make the associated window reappear.
       - Using close() on a closed display does nothing.
    **/
    CImgDisplay& close() {
      return assign();
    }

    //! Move associated window to a new location.
    /**
       \param pos_x X-coordinate of the new window location.
       \param pos_y Y-coordinate of the new window location.
       \note Depending on the window manager behavior, this method may not succeed (no exceptions are thrown nevertheless).
    **/
    CImgDisplay& move(const int pos_x, const int pos_y) {
      return assign(pos_x,pos_y);
    }

#endif
# 7121 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    //! Resize display to the size of the associated window.
    /**
       \param force_redraw Tells if the previous window content must be updated and refreshed as well.
       \note
       - Calling this method ensures that width() and window_width() become equal, as well as height() and window_height().
       - The associated window is also resized to specified dimensions.
    **/
    CImgDisplay& resize(const bool force_redraw=true) {
      resize(_window_width,_window_height,force_redraw);
      return *this;
    }

#if cimg_display==0

    //! Resize display to the specified size.
    /**
       \param width Requested display width.
       \param height Requested display height.
       \param force_redraw Tells if the previous window content must be updated and refreshed as well.
       \note The associated window is also resized to specified dimensions.
    **/
    CImgDisplay& resize(const int width, const int height, const bool force_redraw=true) {
      return assign(width,height,0,3,force_redraw);
    }

#endif
# 7148 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    //! Resize display to the size of an input image.
    /**
       \param img Input image to take size from.
       \param force_redraw Tells if the previous window content must be resized and updated as well.
       \note
       - Calling this method ensures that width() and <tt>img.width()</tt> become equal, as well as height() and <tt>img.height()</tt>.
       - The associated window is also resized to specified dimensions.
    **/
    template<typename T>
    CImgDisplay& resize(const CImg<T>& img, const bool force_redraw=true) {
      return resize(img._width,img._height,force_redraw);
    }

    //! Resize display to the size of another CImgDisplay instance.
    /**
       \param disp Input display to take size from.
       \param force_redraw Tells if the previous window content must be resized and updated as well.
       \note
       - Calling this method ensures that width() and <tt>disp.width()</tt> become equal, as well as height() and <tt>disp.height()</tt>.
       - The associated window is also resized to specified dimensions.
    **/
    CImgDisplay& resize(const CImgDisplay& disp, const bool force_redraw=true) {
      return resize(disp._width,disp._height,force_redraw);
    }

    // [internal] Render pixel buffer with size (wd,hd) from source buffer of size (ws,hs).
    template<typename t, typename T>
    static void _render_resize(const T *ptrs, const unsigned int ws, const unsigned int hs,
                               t *ptrd, const unsigned int wd, const unsigned int hd) {
      unsigned int *const offx = new unsigned int[wd], *const offy = new unsigned int[hd+1], *poffx, *poffy;
      float s, curr, old;
      s = (float)ws/wd;
      poffx = offx; curr = 0; for (unsigned int x = 0; x<wd; ++x) { old = curr; curr+=s; *(poffx++) = (unsigned int)curr - (unsigned int)old; }
      s = (float)hs/hd;
      poffy = offy; curr = 0; for (unsigned int y = 0; y<hd; ++y) { old = curr; curr+=s; *(poffy++) = ws*((unsigned int)curr - (unsigned int)old); }
      *poffy = 0;
      poffy = offy;
      for (unsigned int y = 0; y<hd; ) {
        const T *ptr = ptrs;
        poffx = offx;
        for (unsigned int x = 0; x<wd; ++x) { *(ptrd++) = *ptr; ptr+=*(poffx++); }
        ++y;
        unsigned int dy = *(poffy++);
        for ( ; !dy && y<hd; std::memcpy(ptrd,ptrd - wd,sizeof(t)*wd), ++y, ptrd+=wd, dy = *(poffy++)) {}
        ptrs+=dy;
      }
      delete[] offx; delete[] offy;
    }

    //! Set normalization type.
    /**
       \param normalization New normalization mode.
    **/
    CImgDisplay& set_normalization(const unsigned int normalization) {
      _normalization = normalization;
      _min = _max = 0;
      return *this;
    }

#if cimg_display==0

    //! Set title of the associated window.
    /**
       \param format C-string containing the format of the title, as with <tt>std::printf()</tt>.
       \warning As the first argument is a format string, it is highly recommended to write
       \code
       disp.set_title("%s",window_title);
       \endcode
       instead of
       \code
       disp.set_title(window_title);
       \endcode
       if \c window_title can be arbitrary, to prevent nasty memory access.
    **/
    CImgDisplay& set_title(const char *const format, ...) {
      return assign(0,0,format);
    }

#endif
# 7228 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    //! Enable or disable fullscreen mode.
    /**
       \param is_fullscreen Tells is the fullscreen mode must be activated or not.
       \param force_redraw Tells if the previous window content must be displayed as well.
       \note
       - When the fullscreen mode is enabled, the associated window fills the entire screen but the size of the current display
       is not modified.
       - The screen resolution may be switched to fit the associated window size and ensure it appears the largest as possible.
       For X-Window (X11) users, the configuration flag \c cimg_use_xrandr has to be set to allow the screen resolution change
       (requires the X11 extensions to be enabled).
    **/
    CImgDisplay& set_fullscreen(const bool is_fullscreen, const bool force_redraw=true) {
      if (is_empty() || _is_fullscreen==is_fullscreen) return *this;
      return toggle_fullscreen(force_redraw);
    }

#if cimg_display==0

    //! Toggle fullscreen mode.
    /**
       \param force_redraw Tells if the previous window content must be displayed as well.
       \note Enable fullscreen mode if it was not enabled, and disable it otherwise.
    **/
    CImgDisplay& toggle_fullscreen(const bool force_redraw=true) {
      return assign(_width,_height,0,3,force_redraw);
    }

    //! Show mouse pointer.
    /**
       \note Depending on the window manager behavior, this method may not succeed (no exceptions are thrown nevertheless).
    **/
    CImgDisplay& show_mouse() {
      return assign();
    }

    //! Hide mouse pointer.
    /**
       \note Depending on the window manager behavior, this method may not succeed (no exceptions are thrown nevertheless).
    **/
    CImgDisplay& hide_mouse() {
      return assign();
    }

    //! Move mouse pointer to a specified location.
    /**
       \note Depending on the window manager behavior, this method may not succeed (no exceptions are thrown nevertheless).
    **/
    CImgDisplay& set_mouse(const int pos_x, const int pos_y) {
      return assign(pos_x,pos_y);
    }

#endif
# 7281 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    //! Simulate a mouse button release event.
    /**
       \note All mouse buttons are considered released at the same time.
    **/
    CImgDisplay& set_button() {
      _button = 0;
      _is_event = true;
#if cimg_display==1
      pthread_cond_broadcast(&cimg::X11_attr().wait_event);
#elif cimg_display==2
# 7292 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      SetEvent(cimg::Win32_attr().wait_event);
#endif
# 7294 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      return *this;
    }

    //! Simulate a mouse button press or release event.
    /**
       \param button Buttons event code, where each button is associated to a single bit.
       \param is_pressed Tells if the mouse button is considered as pressed or released.
    **/
    CImgDisplay& set_button(const unsigned int button, const bool is_pressed=true) {
      const unsigned int buttoncode = button==1?1:button==2?2:button==3?4:0;
      if (is_pressed) _button |= buttoncode; else _button &= ~buttoncode;
      _is_event = buttoncode?true:false;
      if (buttoncode) {
#if cimg_display==1
        pthread_cond_broadcast(&cimg::X11_attr().wait_event);
#elif cimg_display==2
# 7310 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        SetEvent(cimg::Win32_attr().wait_event);
#endif
# 7312 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      }
      return *this;
    }

    //! Flush all mouse wheel events.
    /**
       \note Make wheel() to return \c 0, if called afterwards.
    **/
    CImgDisplay& set_wheel() {
      _wheel = 0;
      _is_event = true;
#if cimg_display==1
      pthread_cond_broadcast(&cimg::X11_attr().wait_event);
#elif cimg_display==2
# 7326 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      SetEvent(cimg::Win32_attr().wait_event);
#endif
# 7328 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      return *this;
    }

    //! Simulate a wheel event.
    /**
       \param amplitude Amplitude of the wheel scrolling to simulate.
       \note Make wheel() to return \c amplitude, if called afterwards.
    **/
    CImgDisplay& set_wheel(const int amplitude) {
      _wheel+=amplitude;
      _is_event = amplitude?true:false;
      if (amplitude) {
#if cimg_display==1
        pthread_cond_broadcast(&cimg::X11_attr().wait_event);
#elif cimg_display==2
# 7343 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        SetEvent(cimg::Win32_attr().wait_event);
#endif
# 7345 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      }
      return *this;
    }

    //! Flush all key events.
    /**
       \note Make key() to return \c 0, if called afterwards.
    **/
    CImgDisplay& set_key() {
      std::memset((void*)_keys,0,sizeof(_keys));
      std::memset((void*)_released_keys,0,sizeof(_released_keys));
      _is_keyESC = _is_keyF1 = _is_keyF2 = _is_keyF3 = _is_keyF4 = _is_keyF5 = _is_keyF6 = _is_keyF7 = _is_keyF8 = _is_keyF9 =
        _is_keyF10 = _is_keyF11 = _is_keyF12 = _is_keyPAUSE = _is_key1 = _is_key2 = _is_key3 = _is_key4 = _is_key5 = _is_key6 =
        _is_key7 = _is_key8 = _is_key9 = _is_key0 = _is_keyBACKSPACE = _is_keyINSERT = _is_keyHOME = _is_keyPAGEUP = _is_keyTAB =
        _is_keyQ = _is_keyW = _is_keyE = _is_keyR = _is_keyT = _is_keyY = _is_keyU = _is_keyI = _is_keyO = _is_keyP = _is_keyDELETE =
        _is_keyEND = _is_keyPAGEDOWN = _is_keyCAPSLOCK = _is_keyA = _is_keyS = _is_keyD = _is_keyF = _is_keyG = _is_keyH = _is_keyJ =
        _is_keyK = _is_keyL = _is_keyENTER = _is_keySHIFTLEFT = _is_keyZ = _is_keyX = _is_keyC = _is_keyV = _is_keyB = _is_keyN =
        _is_keyM = _is_keySHIFTRIGHT = _is_keyARROWUP = _is_keyCTRLLEFT = _is_keyAPPLEFT = _is_keyALT = _is_keySPACE = _is_keyALTGR = _is_keyAPPRIGHT =
        _is_keyMENU = _is_keyCTRLRIGHT = _is_keyARROWLEFT = _is_keyARROWDOWN = _is_keyARROWRIGHT = _is_keyPAD0 = _is_keyPAD1 = _is_keyPAD2 =
        _is_keyPAD3 = _is_keyPAD4 = _is_keyPAD5 = _is_keyPAD6 = _is_keyPAD7 = _is_keyPAD8 = _is_keyPAD9 = _is_keyPADADD = _is_keyPADSUB =
        _is_keyPADMUL = _is_keyPADDIV = false;
      _is_event = true;
#if cimg_display==1
      pthread_cond_broadcast(&cimg::X11_attr().wait_event);
#elif cimg_display==2
# 7370 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      SetEvent(cimg::Win32_attr().wait_event);
#endif
# 7372 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      return *this;
    }

    //! Simulate a keyboard press/release event.
    /**
       \param keycode Keycode of the associated key.
       \param is_pressed Tells if the key is considered as pressed or released.
       \note Keycode constants are defined in the cimg namespace and are architecture-dependent. Use them to ensure
       your code stay portable (see cimg::keyESC).
    **/
    CImgDisplay& set_key(const unsigned int keycode, const bool is_pressed=true) {
#define _cimg_set_key(k) if (keycode==cimg::key##k) _is_key##k = is_pressed;
      _cimg_set_key(ESC); _cimg_set_key(F1); _cimg_set_key(F2); _cimg_set_key(F3);
      _cimg_set_key(F4); _cimg_set_key(F5); _cimg_set_key(F6); _cimg_set_key(F7);
      _cimg_set_key(F8); _cimg_set_key(F9); _cimg_set_key(F10); _cimg_set_key(F11);
      _cimg_set_key(F12); _cimg_set_key(PAUSE); _cimg_set_key(1); _cimg_set_key(2);
      _cimg_set_key(3); _cimg_set_key(4); _cimg_set_key(5); _cimg_set_key(6);
      _cimg_set_key(7); _cimg_set_key(8); _cimg_set_key(9); _cimg_set_key(0);
      _cimg_set_key(BACKSPACE); _cimg_set_key(INSERT); _cimg_set_key(HOME);
      _cimg_set_key(PAGEUP); _cimg_set_key(TAB); _cimg_set_key(Q); _cimg_set_key(W);
      _cimg_set_key(E); _cimg_set_key(R); _cimg_set_key(T); _cimg_set_key(Y);
      _cimg_set_key(U); _cimg_set_key(I); _cimg_set_key(O); _cimg_set_key(P);
      _cimg_set_key(DELETE); _cimg_set_key(END); _cimg_set_key(PAGEDOWN);
      _cimg_set_key(CAPSLOCK); _cimg_set_key(A); _cimg_set_key(S); _cimg_set_key(D);
      _cimg_set_key(F); _cimg_set_key(G); _cimg_set_key(H); _cimg_set_key(J);
      _cimg_set_key(K); _cimg_set_key(L); _cimg_set_key(ENTER);
      _cimg_set_key(SHIFTLEFT); _cimg_set_key(Z); _cimg_set_key(X); _cimg_set_key(C);
      _cimg_set_key(V); _cimg_set_key(B); _cimg_set_key(N); _cimg_set_key(M);
      _cimg_set_key(SHIFTRIGHT); _cimg_set_key(ARROWUP); _cimg_set_key(CTRLLEFT);
      _cimg_set_key(APPLEFT); _cimg_set_key(ALT); _cimg_set_key(SPACE); _cimg_set_key(ALTGR);
      _cimg_set_key(APPRIGHT); _cimg_set_key(MENU); _cimg_set_key(CTRLRIGHT);
      _cimg_set_key(ARROWLEFT); _cimg_set_key(ARROWDOWN); _cimg_set_key(ARROWRIGHT);
      _cimg_set_key(PAD0); _cimg_set_key(PAD1); _cimg_set_key(PAD2);
      _cimg_set_key(PAD3); _cimg_set_key(PAD4); _cimg_set_key(PAD5);
      _cimg_set_key(PAD6); _cimg_set_key(PAD7); _cimg_set_key(PAD8);
      _cimg_set_key(PAD9); _cimg_set_key(PADADD); _cimg_set_key(PADSUB);
      _cimg_set_key(PADMUL); _cimg_set_key(PADDIV);
      if (is_pressed) {
        if (*_keys)
          std::memmove((void*)(_keys+1),(void*)_keys,sizeof(_keys) - sizeof(unsigned int));
        *_keys = keycode;
        if (*_released_keys) {
          std::memmove((void*)(_released_keys+1),(void*)_released_keys,sizeof(_released_keys) - sizeof(unsigned int));
          *_released_keys = 0;
        }
      } else {
        if (*_keys) {
          std::memmove((void*)(_keys+1),(void*)_keys,sizeof(_keys) - sizeof(unsigned int));
          *_keys = 0;
        }
        if (*_released_keys)
          std::memmove((void*)(_released_keys+1),(void*)_released_keys,sizeof(_released_keys) - sizeof(unsigned int));
        *_released_keys = keycode;
      }
      _is_event = keycode?true:false;
      if (keycode) {
#if cimg_display==1
        pthread_cond_broadcast(&cimg::X11_attr().wait_event);
#elif cimg_display==2
# 7431 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        SetEvent(cimg::Win32_attr().wait_event);
#endif
# 7433 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      }
      return *this;
    }

    //! Flush all display events.
    /**
       \note Remove all passed events from the current display.
    **/
    CImgDisplay& flush() {
      set_key().set_button().set_wheel();
      _is_resized = _is_moved = _is_event = false;
      _fps_timer = _fps_frames = _timer = 0;
      _fps_fps = 0;
      return *this;
    }

    //! Wait for any user event occuring on the current display.
    CImgDisplay& wait() {
      wait(*this);
      return *this;
    }

    //! Wait for a given number of milliseconds since the last call to wait().
    /**
       \param milliseconds Number of milliseconds to wait for.
       \note Similar to cimg::wait().
    **/
    CImgDisplay& wait(const unsigned int milliseconds) {
      cimg::_wait(milliseconds,_timer);
      return *this;
    }

    //! Wait for any event occuring on the display \c disp1.
    static void wait(CImgDisplay& disp1) {
      disp1._is_event = false;
      while (!disp1._is_closed && !disp1._is_event) wait_all();
    }

    //! Wait for any event occuring either on the display \c disp1 or \c disp2.
    static void wait(CImgDisplay& disp1, CImgDisplay& disp2) {
      disp1._is_event = disp2._is_event = false;
      while ((!disp1._is_closed || !disp2._is_closed) &&
             !disp1._is_event && !disp2._is_event) wait_all();
    }

    //! Wait for any event occuring either on the display \c disp1, \c disp2 or \c disp3.
    static void wait(CImgDisplay& disp1, CImgDisplay& disp2, CImgDisplay& disp3) {
      disp1._is_event = disp2._is_event = disp3._is_event = false;
      while ((!disp1._is_closed || !disp2._is_closed || !disp3._is_closed) &&
             !disp1._is_event && !disp2._is_event && !disp3._is_event) wait_all();
    }

    //! Wait for any event occuring either on the display \c disp1, \c disp2, \c disp3 or \c disp4.
    static void wait(CImgDisplay& disp1, CImgDisplay& disp2, CImgDisplay& disp3, CImgDisplay& disp4) {
      disp1._is_event = disp2._is_event = disp3._is_event = disp4._is_event = false;
      while ((!disp1._is_closed || !disp2._is_closed || !disp3._is_closed || !disp4._is_closed) &&
             !disp1._is_event && !disp2._is_event && !disp3._is_event && !disp4._is_event) wait_all();
    }

    //! Wait for any event occuring either on the display \c disp1, \c disp2, \c disp3, \c disp4 or \c disp5.
    static void wait(CImgDisplay& disp1, CImgDisplay& disp2, CImgDisplay& disp3, CImgDisplay& disp4, CImgDisplay& disp5) {
      disp1._is_event = disp2._is_event = disp3._is_event = disp4._is_event = disp5._is_event = false;
      while ((!disp1._is_closed || !disp2._is_closed || !disp3._is_closed || !disp4._is_closed || !disp5._is_closed) &&
             !disp1._is_event && !disp2._is_event && !disp3._is_event && !disp4._is_event && !disp5._is_event) wait_all();
    }

    //! Wait for any event occuring either on the display \c disp1, \c disp2, \c disp3, \c disp4, ... \c disp6.
    static void wait(CImgDisplay& disp1, CImgDisplay& disp2, CImgDisplay& disp3, CImgDisplay& disp4, CImgDisplay& disp5,
                     CImgDisplay& disp6) {
      disp1._is_event = disp2._is_event = disp3._is_event = disp4._is_event = disp5._is_event =
        disp6._is_event = false;
      while ((!disp1._is_closed || !disp2._is_closed || !disp3._is_closed || !disp4._is_closed || !disp5._is_closed ||
              !disp6._is_closed) &&
             !disp1._is_event && !disp2._is_event && !disp3._is_event && !disp4._is_event && !disp5._is_event &&
             !disp6._is_event) wait_all();
    }

    //! Wait for any event occuring either on the display \c disp1, \c disp2, \c disp3, \c disp4, ... \c disp7.
    static void wait(CImgDisplay& disp1, CImgDisplay& disp2, CImgDisplay& disp3, CImgDisplay& disp4, CImgDisplay& disp5,
                     CImgDisplay& disp6, CImgDisplay& disp7) {
      disp1._is_event = disp2._is_event = disp3._is_event = disp4._is_event = disp5._is_event =
        disp6._is_event = disp7._is_event = false;
      while ((!disp1._is_closed || !disp2._is_closed || !disp3._is_closed || !disp4._is_closed || !disp5._is_closed ||
              !disp6._is_closed || !disp7._is_closed) &&
             !disp1._is_event && !disp2._is_event && !disp3._is_event && !disp4._is_event && !disp5._is_event &&
             !disp6._is_event && !disp7._is_event) wait_all();
    }

    //! Wait for any event occuring either on the display \c disp1, \c disp2, \c disp3, \c disp4, ... \c disp8.
    static void wait(CImgDisplay& disp1, CImgDisplay& disp2, CImgDisplay& disp3, CImgDisplay& disp4, CImgDisplay& disp5,
                     CImgDisplay& disp6, CImgDisplay& disp7, CImgDisplay& disp8) {
      disp1._is_event = disp2._is_event = disp3._is_event = disp4._is_event = disp5._is_event =
        disp6._is_event = disp7._is_event = disp8._is_event = false;
      while ((!disp1._is_closed || !disp2._is_closed || !disp3._is_closed || !disp4._is_closed || !disp5._is_closed ||
              !disp6._is_closed || !disp7._is_closed || !disp8._is_closed) &&
             !disp1._is_event && !disp2._is_event && !disp3._is_event && !disp4._is_event && !disp5._is_event &&
             !disp6._is_event && !disp7._is_event && !disp8._is_event) wait_all();
    }

    //! Wait for any event occuring either on the display \c disp1, \c disp2, \c disp3, \c disp4, ... \c disp9.
    static void wait(CImgDisplay& disp1, CImgDisplay& disp2, CImgDisplay& disp3, CImgDisplay& disp4, CImgDisplay& disp5,
                     CImgDisplay& disp6, CImgDisplay& disp7, CImgDisplay& disp8, CImgDisplay& disp9) {
      disp1._is_event = disp2._is_event = disp3._is_event = disp4._is_event = disp5._is_event =
        disp6._is_event = disp7._is_event = disp8._is_event = disp9._is_event = false;
      while ((!disp1._is_closed || !disp2._is_closed || !disp3._is_closed || !disp4._is_closed || !disp5._is_closed ||
              !disp6._is_closed || !disp7._is_closed || !disp8._is_closed || !disp9._is_closed) &&
             !disp1._is_event && !disp2._is_event && !disp3._is_event && !disp4._is_event && !disp5._is_event &&
             !disp6._is_event && !disp7._is_event && !disp8._is_event && !disp9._is_event) wait_all();
    }

    //! Wait for any event occuring either on the display \c disp1, \c disp2, \c disp3, \c disp4, ... \c disp10.
    static void wait(CImgDisplay& disp1, CImgDisplay& disp2, CImgDisplay& disp3, CImgDisplay& disp4, CImgDisplay& disp5,
                     CImgDisplay& disp6, CImgDisplay& disp7, CImgDisplay& disp8, CImgDisplay& disp9, CImgDisplay& disp10) {
      disp1._is_event = disp2._is_event = disp3._is_event = disp4._is_event = disp5._is_event =
        disp6._is_event = disp7._is_event = disp8._is_event = disp9._is_event = disp10._is_event = false;
      while ((!disp1._is_closed || !disp2._is_closed || !disp3._is_closed || !disp4._is_closed || !disp5._is_closed ||
              !disp6._is_closed || !disp7._is_closed || !disp8._is_closed || !disp9._is_closed || !disp10._is_closed) &&
             !disp1._is_event && !disp2._is_event && !disp3._is_event && !disp4._is_event && !disp5._is_event &&
             !disp6._is_event && !disp7._is_event && !disp8._is_event && !disp9._is_event && !disp10._is_event) wait_all();
    }

#if cimg_display==0

    //! Wait for any window event occuring in any opened CImgDisplay.
    static void wait_all() {
      return _no_display_exception();
    }

    //! Render image into internal display buffer.
    /**
       \param img Input image data to render.
       \note
       - Convert image data representation into the internal display buffer (architecture-dependent structure).
       - The content of the associated window is not modified, until paint() is called.
       - Should not be used for common CImgDisplay uses, since display() is more useful.
    **/
    template<typename T>
    CImgDisplay& render(const CImg<T>& img) {
      return assign(img);
    }

    //! Paint internal display buffer on associated window.
    /**
       \note
       - Update the content of the associated window with the internal display buffer, e.g. after a render() call.
       - Should not be used for common CImgDisplay uses, since display() is more useful.
    **/
    CImgDisplay& paint() {
      return assign();
    }

    //! Take a snapshot of the associated window content.
    /**
       \param[out] img Output snapshot. Can be empty on input.
    **/
    template<typename T>
    const CImgDisplay& snapshot(CImg<T>& img) const {
      cimg::unused(img);
      _no_display_exception();
      return *this;
    }
#endif
# 7595 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    // X11-based implementation
    //--------------------------
#if cimg_display==1

    Atom _wm_window_atom, _wm_protocol_atom;
    Window _window, _background_window;
    Colormap _colormap;
    XImage *_image;
    void *_data;
#ifdef cimg_use_xshm
    XShmSegmentInfo *_shminfo;
#endif
# 7608 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    static int screen_width() {
      Display *const dpy = cimg::X11_attr().display;
      int res = 0;
      if (!dpy) {
        Display *const _dpy = XOpenDisplay(0);
        if (!_dpy)
          throw CImgDisplayException("CImgDisplay::screen_width(): Failed to open X11 display.");
        res = DisplayWidth(_dpy,DefaultScreen(_dpy));
        XCloseDisplay(_dpy);
      } else {
#ifdef cimg_use_xrandr
        if (cimg::X11_attr().resolutions && cimg::X11_attr().curr_resolution)
          res = cimg::X11_attr().resolutions[cimg::X11_attr().curr_resolution].width;
        else res = DisplayWidth(dpy,DefaultScreen(dpy));
#else
# 7624 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        res = DisplayWidth(dpy,DefaultScreen(dpy));
#endif
# 7626 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      }
      return res;
    }

    static int screen_height() {
      Display *const dpy = cimg::X11_attr().display;
      int res = 0;
      if (!dpy) {
        Display *const _dpy = XOpenDisplay(0);
        if (!_dpy)
          throw CImgDisplayException("CImgDisplay::screen_height(): Failed to open X11 display.");
        res = DisplayHeight(_dpy,DefaultScreen(_dpy));
        XCloseDisplay(_dpy);
      } else {
#ifdef cimg_use_xrandr
        if (cimg::X11_attr().resolutions && cimg::X11_attr().curr_resolution)
          res = cimg::X11_attr().resolutions[cimg::X11_attr().curr_resolution].height;
        else res = DisplayHeight(dpy,DefaultScreen(dpy));
#else
# 7645 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        res = DisplayHeight(dpy,DefaultScreen(dpy));
#endif
# 7647 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      }
      return res;
    }

    static void wait_all() {
      if (!cimg::X11_attr().display) return;
      if (cimg::mutex(13,2)) { cimg::sleep(10); return; }
      pthread_cond_wait(&cimg::X11_attr().wait_event,&cimg::X11_attr().wait_event_mutex);
      cimg::mutex(13,0);
    }

    void _handle_events(const XEvent *const pevent) {
      Display *const dpy = cimg::X11_attr().display;
      XEvent event = *pevent;
      switch (event.type) {
      case ClientMessage : {
        if ((int)event.xclient.message_type==(int)_wm_protocol_atom &&
            (int)event.xclient.data.l[0]==(int)_wm_window_atom) {
          XUnmapWindow(cimg::X11_attr().display,_window);
          _is_closed = _is_event = true;
          pthread_cond_broadcast(&cimg::X11_attr().wait_event);
        }
      } break;
      case ConfigureNotify : {
        while (XCheckWindowEvent(dpy,_window,StructureNotifyMask,&event)) {}
        const unsigned int nw = event.xconfigure.width, nh = event.xconfigure.height;
        const int nx = event.xconfigure.x, ny = event.xconfigure.y;
        if (nw && nh && (nw!=_window_width || nh!=_window_height)) {
          _window_width = nw; _window_height = nh; _mouse_x = _mouse_y = -1;
          XResizeWindow(dpy,_window,_window_width,_window_height);
          _is_resized = _is_event = true;
          pthread_cond_broadcast(&cimg::X11_attr().wait_event);
        }
        if (nx!=_window_x || ny!=_window_y) {
          _window_x = nx; _window_y = ny; _is_moved = _is_event = true;
          pthread_cond_broadcast(&cimg::X11_attr().wait_event);
        }
      } break;
      case Expose : {
        while (XCheckWindowEvent(dpy,_window,ExposureMask,&event)) {}
        _paint(false);
        if (_is_fullscreen) {
          XWindowAttributes attr;
          XGetWindowAttributes(dpy,_window,&attr);
          while (attr.map_state!=IsViewable) XSync(dpy,0);
          XSetInputFocus(dpy,_window,RevertToParent,CurrentTime);
        }
      } break;
      case ButtonPress : {
        do {
          _mouse_x = event.xmotion.x; _mouse_y = event.xmotion.y;
          if (_mouse_x<0 || _mouse_y<0 || _mouse_x>=width() || _mouse_y>=height()) _mouse_x = _mouse_y = -1;
          switch (event.xbutton.button) {
          case 1 : set_button(1); break;
          case 3 : set_button(2); break;
          case 2 : set_button(3); break;
          }
        } while (XCheckWindowEvent(dpy,_window,ButtonPressMask,&event));
      } break;
      case ButtonRelease : {
        do {
          _mouse_x = event.xmotion.x; _mouse_y = event.xmotion.y;
          if (_mouse_x<0 || _mouse_y<0 || _mouse_x>=width() || _mouse_y>=height()) _mouse_x = _mouse_y = -1;
          switch (event.xbutton.button) {
          case 1 : set_button(1,false); break;
          case 3 : set_button(2,false); break;
          case 2 : set_button(3,false); break;
          case 4 : set_wheel(1); break;
          case 5 : set_wheel(-1); break;
          }
        } while (XCheckWindowEvent(dpy,_window,ButtonReleaseMask,&event));
      } break;
      case KeyPress : {
        char tmp = 0; KeySym ksym;
        XLookupString(&event.xkey,&tmp,1,&ksym,0);
        set_key((unsigned int)ksym,true);
      } break;
      case KeyRelease : {
        char keys_return[32];  // Check that the key has been physically unpressed.
        XQueryKeymap(dpy,keys_return);
        const unsigned int kc = event.xkey.keycode, kc1 = kc/8, kc2 = kc%8;
        const bool is_key_pressed = kc1>=32?false:(keys_return[kc1]>>kc2)&1;
        if (!is_key_pressed) {
          char tmp = 0; KeySym ksym;
          XLookupString(&event.xkey,&tmp,1,&ksym,0);
          set_key((unsigned int)ksym,false);
        }
      } break;
      case EnterNotify: {
        while (XCheckWindowEvent(dpy,_window,EnterWindowMask,&event)) {}
        _mouse_x = event.xmotion.x;
        _mouse_y = event.xmotion.y;
        if (_mouse_x<0 || _mouse_y<0 || _mouse_x>=width() || _mouse_y>=height()) _mouse_x = _mouse_y = -1;
      } break;
      case LeaveNotify : {
        while (XCheckWindowEvent(dpy,_window,LeaveWindowMask,&event)) {}
        _mouse_x = _mouse_y =-1; _is_event = true;
        pthread_cond_broadcast(&cimg::X11_attr().wait_event);
      } break;
      case MotionNotify : {
        while (XCheckWindowEvent(dpy,_window,PointerMotionMask,&event)) {}
        _mouse_x = event.xmotion.x;
        _mouse_y = event.xmotion.y;
        if (_mouse_x<0 || _mouse_y<0 || _mouse_x>=width() || _mouse_y>=height()) _mouse_x = _mouse_y = -1;
        _is_event = true;
        pthread_cond_broadcast(&cimg::X11_attr().wait_event);
      } break;
      }
    }

    static void* _events_thread(void *) { // Thread to manage events for all opened display windows.
      Display *const dpy = cimg::X11_attr().display;
      XEvent event;
      pthread_setcanceltype(PTHREAD_CANCEL_DEFERRED,0);
      pthread_setcancelstate(PTHREAD_CANCEL_ENABLE,0);
      for (;;) {
        XLockDisplay(dpy);
        bool event_flag = XCheckTypedEvent(dpy,ClientMessage,&event);
        if (!event_flag) event_flag = XCheckMaskEvent(dpy,
                                                      ExposureMask | StructureNotifyMask | ButtonPressMask |
                                                      KeyPressMask | PointerMotionMask | EnterWindowMask | LeaveWindowMask|
                                                      ButtonReleaseMask | KeyReleaseMask,&event);
        if (event_flag)
          for (unsigned int i = 0; i<cimg::X11_attr().nb_wins; ++i)
            if (!cimg::X11_attr().wins[i]->_is_closed && event.xany.window==cimg::X11_attr().wins[i]->_window)
              cimg::X11_attr().wins[i]->_handle_events(&event);
        XUnlockDisplay(dpy);
        pthread_testcancel();
        cimg::sleep(8);
      }
      return 0;
    }

    void _set_colormap(Colormap& _colormap, const unsigned int dim) {
      XColor colormap[256];
      switch (dim) {
      case 1 : { // colormap for greyscale images
        for (unsigned int index = 0; index<256; ++index) {
          colormap[index].pixel = index;
          colormap[index].red = colormap[index].green = colormap[index].blue = (unsigned short)(index<<8);
          colormap[index].flags = DoRed | DoGreen | DoBlue;
        }
      } break;
      case 2 : { // colormap for RG images
        for (unsigned int index = 0, r = 8; r<256; r+=16)
          for (unsigned int g = 8; g<256; g+=16) {
            colormap[index].pixel = index;
            colormap[index].red = colormap[index].blue = (unsigned short)(r<<8);
            colormap[index].green = (unsigned short)(g<<8);
            colormap[index++].flags = DoRed | DoGreen | DoBlue;
          }
      } break;
      default : { // colormap for RGB images
        for (unsigned int index = 0, r = 16; r<256; r+=32)
          for (unsigned int g = 16; g<256; g+=32)
            for (unsigned int b = 32; b<256; b+=64) {
              colormap[index].pixel = index;
              colormap[index].red = (unsigned short)(r<<8);
              colormap[index].green = (unsigned short)(g<<8);
              colormap[index].blue = (unsigned short)(b<<8);
              colormap[index++].flags = DoRed | DoGreen | DoBlue;
            }
      }
      }
      XStoreColors(cimg::X11_attr().display,_colormap,colormap,256);
    }

    void _map_window() {
      Display *const dpy = cimg::X11_attr().display;
      bool is_exposed = false, is_mapped = false;
      XWindowAttributes attr;
      XEvent event;
      XMapRaised(dpy,_window);
      do { // Wait for the window to be mapped.
        XWindowEvent(dpy,_window,StructureNotifyMask | ExposureMask,&event);
        switch (event.type) {
        case MapNotify : is_mapped = true; break;
        case Expose : is_exposed = true; break;
        }
      } while (!is_exposed || !is_mapped);
      do { // Wait for the window to be visible.
        XGetWindowAttributes(dpy,_window,&attr);
        if (attr.map_state!=IsViewable) { XSync(dpy,0); cimg::sleep(10); }
      } while (attr.map_state!=IsViewable);
      _window_x = attr.x;
      _window_y = attr.y;
    }

    void _paint(const bool wait_expose=true) {
      if (_is_closed || !_image) return;
      Display *const dpy = cimg::X11_attr().display;
      if (wait_expose) { // Send an expose event sticked to display window to force repaint.
        XEvent event;
        event.xexpose.type = Expose;
        event.xexpose.serial = 0;
        event.xexpose.send_event = 1;
        event.xexpose.display = dpy;
        event.xexpose.window = _window;
        event.xexpose.x = 0;
        event.xexpose.y = 0;
        event.xexpose.width = width();
        event.xexpose.height = height();
        event.xexpose.count = 0;
        XSendEvent(dpy,_window,0,0,&event);
      } else { // Repaint directly (may be called from the expose event).
        GC gc = DefaultGC(dpy,DefaultScreen(dpy));
#ifdef cimg_use_xshm
        if (_shminfo) XShmPutImage(dpy,_window,gc,_image,0,0,0,0,_width,_height,1);
        else XPutImage(dpy,_window,gc,_image,0,0,0,0,_width,_height);
#else
# 7857 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        XPutImage(dpy,_window,gc,_image,0,0,0,0,_width,_height);
#endif
# 7859 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      }
    }

    template<typename T>
    void _resize(T pixel_type, const unsigned int ndimx, const unsigned int ndimy, const bool force_redraw) {
      Display *const dpy = cimg::X11_attr().display;
      cimg::unused(pixel_type);

#ifdef cimg_use_xshm
      if (_shminfo) {
        XShmSegmentInfo *const nshminfo = new XShmSegmentInfo;
        XImage *const nimage = XShmCreateImage(dpy,DefaultVisual(dpy,DefaultScreen(dpy)),
                                               cimg::X11_attr().nb_bits,ZPixmap,0,nshminfo,ndimx,ndimy);
        if (!nimage) { delete nshminfo; return; }
        else {
          nshminfo->shmid = shmget(IPC_PRIVATE,ndimx*ndimy*sizeof(T),IPC_CREAT | 0777);
          if (nshminfo->shmid==-1) { XDestroyImage(nimage); delete nshminfo; return; }
          else {
            nshminfo->shmaddr = nimage->data = (char*)shmat(nshminfo->shmid,0,0);
            if (nshminfo->shmaddr==(char*)-1) { shmctl(nshminfo->shmid,IPC_RMID,0); XDestroyImage(nimage); delete nshminfo; return; }
            else {
              nshminfo->readOnly = 0;
              cimg::X11_attr().is_shm_enabled = true;
              XErrorHandler oldXErrorHandler = XSetErrorHandler(_assign_xshm);
              XShmAttach(dpy,nshminfo);
              XFlush(dpy);
              XSetErrorHandler(oldXErrorHandler);
              if (!cimg::X11_attr().is_shm_enabled) {
                shmdt(nshminfo->shmaddr);
                shmctl(nshminfo->shmid,IPC_RMID,0);
                XDestroyImage(nimage);
                delete nshminfo;
                return;
              } else {
                T *const ndata = (T*)nimage->data;
                if (force_redraw) _render_resize((T*)_data,_width,_height,ndata,ndimx,ndimy);
                else std::memset(ndata,0,sizeof(T)*ndimx*ndimy);
                XShmDetach(dpy,_shminfo);
                XDestroyImage(_image);
                shmdt(_shminfo->shmaddr);
                shmctl(_shminfo->shmid,IPC_RMID,0);
                delete _shminfo;
                _shminfo = nshminfo;
                _image = nimage;
                _data = (void*)ndata;
              }
            }
          }
        }
      } else
#endif
# 7910 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        {
          T *ndata = (T*)std::malloc(ndimx*ndimy*sizeof(T));
          if (force_redraw) _render_resize((T*)_data,_width,_height,ndata,ndimx,ndimy);
          else std::memset(ndata,0,sizeof(T)*ndimx*ndimy);
          _data = (void*)ndata;
          XDestroyImage(_image);
          _image = XCreateImage(dpy,DefaultVisual(dpy,DefaultScreen(dpy)),
                                cimg::X11_attr().nb_bits,ZPixmap,0,(char*)_data,ndimx,ndimy,8,0);
        }
    }

    void _init_fullscreen() {
      if (!_is_fullscreen || _is_closed) return;
      Display *const dpy = cimg::X11_attr().display;
      _background_window = 0;

#ifdef cimg_use_xrandr
      int foo;
      if (XRRQueryExtension(dpy,&foo,&foo)) {
        XRRRotations(dpy,DefaultScreen(dpy),&cimg::X11_attr().curr_rotation);
        if (!cimg::X11_attr().resolutions) {
          cimg::X11_attr().resolutions = XRRSizes(dpy,DefaultScreen(dpy),&foo);
          cimg::X11_attr().nb_resolutions = (unsigned int)foo;
        }
        if (cimg::X11_attr().resolutions) {
          cimg::X11_attr().curr_resolution = 0;
          for (unsigned int i = 0; i<cimg::X11_attr().nb_resolutions; ++i) {
            const unsigned int
              nw = (unsigned int)(cimg::X11_attr().resolutions[i].width),
              nh = (unsigned int)(cimg::X11_attr().resolutions[i].height);
            if (nw>=_width && nh>=_height &&
                nw<=(unsigned int)(cimg::X11_attr().resolutions[cimg::X11_attr().curr_resolution].width) &&
                nh<=(unsigned int)(cimg::X11_attr().resolutions[cimg::X11_attr().curr_resolution].height))
              cimg::X11_attr().curr_resolution = i;
          }
          if (cimg::X11_attr().curr_resolution>0) {
            XRRScreenConfiguration *config = XRRGetScreenInfo(dpy,DefaultRootWindow(dpy));
            XRRSetScreenConfig(dpy,config,DefaultRootWindow(dpy),
                               cimg::X11_attr().curr_resolution,cimg::X11_attr().curr_rotation,CurrentTime);
            XRRFreeScreenConfigInfo(config);
            XSync(dpy,0);
          }
        }
      }
      if (!cimg::X11_attr().resolutions)
        cimg::warn(_cimgdisplay_instance
                   "init_fullscreen(): Xrandr extension not supported by the X server.",
                   cimgdisplay_instance);
#endif
# 7959 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

      const unsigned int sx = screen_width(), sy = screen_height();
      if (sx==_width && sy==_height) return;
      XSetWindowAttributes winattr;
      winattr.override_redirect = 1;
      _background_window = XCreateWindow(dpy,DefaultRootWindow(dpy),0,0,sx,sy,0,0,
                                         InputOutput,CopyFromParent,CWOverrideRedirect,&winattr);
      const unsigned long buf_size = (unsigned long)sx*sy*(cimg::X11_attr().nb_bits==8?1:(cimg::X11_attr().nb_bits==16?2:4));
      void *background_data = std::malloc(buf_size);
      std::memset(background_data,0,buf_size);
      XImage *background_image = XCreateImage(dpy,DefaultVisual(dpy,DefaultScreen(dpy)),cimg::X11_attr().nb_bits,
                                              ZPixmap,0,(char*)background_data,sx,sy,8,0);
      XEvent event;
      XSelectInput(dpy,_background_window,StructureNotifyMask);
      XMapRaised(dpy,_background_window);
      do XWindowEvent(dpy,_background_window,StructureNotifyMask,&event);
      while (event.type!=MapNotify);
      GC gc = DefaultGC(dpy,DefaultScreen(dpy));
#ifdef cimg_use_xshm
      if (_shminfo) XShmPutImage(dpy,_background_window,gc,background_image,0,0,0,0,sx,sy,0);
      else XPutImage(dpy,_background_window,gc,background_image,0,0,0,0,sx,sy);
#else
# 7981 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      XPutImage(dpy,_background_window,gc,background_image,0,0,0,0,sx,sy);
#endif
# 7983 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      XWindowAttributes attr;
      XGetWindowAttributes(dpy,_background_window,&attr);
      while (attr.map_state!=IsViewable) XSync(dpy,0);
      XDestroyImage(background_image);
    }

    void _desinit_fullscreen() {
      if (!_is_fullscreen) return;
      Display *const dpy = cimg::X11_attr().display;
      XUngrabKeyboard(dpy,CurrentTime);
#ifdef cimg_use_xrandr
      if (cimg::X11_attr().resolutions && cimg::X11_attr().curr_resolution) {
        XRRScreenConfiguration *config = XRRGetScreenInfo(dpy,DefaultRootWindow(dpy));
        XRRSetScreenConfig(dpy,config,DefaultRootWindow(dpy),0,cimg::X11_attr().curr_rotation,CurrentTime);
        XRRFreeScreenConfigInfo(config);
        XSync(dpy,0);
        cimg::X11_attr().curr_resolution = 0;
      }
#endif
# 8002 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      if (_background_window) XDestroyWindow(dpy,_background_window);
      _background_window = 0;
      _is_fullscreen = false;
    }

    static int _assign_xshm(Display *dpy, XErrorEvent *error) {
      cimg::unused(dpy,error);
      cimg::X11_attr().is_shm_enabled = false;
      return 0;
    }

    void _assign(const unsigned int dimw, const unsigned int dimh, const char *const ptitle=0,
                 const unsigned int normalization_type=3,
                 const bool fullscreen_flag=false, const bool closed_flag=false) {
      cimg::mutex(14);

      // Allocate space for window title
      const char *const nptitle = ptitle?ptitle:"";
      const unsigned int s = std::strlen(nptitle) + 1;
      char *const tmp_title = s?new char[s]:0;
      if (s) std::memcpy(tmp_title,nptitle,s*sizeof(char));

      // Destroy previous display window if existing
      if (!is_empty()) assign();

      // Open X11 display and retrieve graphical properties.
      Display* &dpy = cimg::X11_attr().display;
      if (!dpy) {
        dpy = XOpenDisplay(0);
        if (!dpy)
          throw CImgDisplayException(_cimgdisplay_instance
                                     "assign(): Failed to open X11 display.",
                                     cimgdisplay_instance);

        cimg::X11_attr().nb_bits = DefaultDepth(dpy,DefaultScreen(dpy));
        if (cimg::X11_attr().nb_bits!=8 && cimg::X11_attr().nb_bits!=16 && cimg::X11_attr().nb_bits!=24 && cimg::X11_attr().nb_bits!=32)
          throw CImgDisplayException(_cimgdisplay_instance
                                     "assign(): Invalid %u bits screen mode detected "
                                     "(only 8, 16, 24 and 32 bits modes are managed).",
                                     cimgdisplay_instance,
                                     cimg::X11_attr().nb_bits);
        XVisualInfo vtemplate;
        vtemplate.visualid = XVisualIDFromVisual(DefaultVisual(dpy,DefaultScreen(dpy)));
        int nb_visuals;
        XVisualInfo *vinfo = XGetVisualInfo(dpy,VisualIDMask,&vtemplate,&nb_visuals);
        if (vinfo && vinfo->red_mask<vinfo->blue_mask) cimg::X11_attr().is_blue_first = true;
        cimg::X11_attr().byte_order = ImageByteOrder(dpy);
	XFree(vinfo);

        XLockDisplay(dpy);
        cimg::X11_attr().events_thread = new pthread_t;
        pthread_create(cimg::X11_attr().events_thread,0,_events_thread,0);
      } else XLockDisplay(dpy);

      // Set display variables.
      _width = cimg::min(dimw,(unsigned int)screen_width());
      _height = cimg::min(dimh,(unsigned int)screen_height());
      _normalization = normalization_type<4?normalization_type:3;
      _is_fullscreen = fullscreen_flag;
      _window_x = _window_y = 0;
      _is_closed = closed_flag;
      _title = tmp_title;
      flush();

      // Create X11 window (and LUT, if 8bits display)
      if (_is_fullscreen) {
        if (!_is_closed) _init_fullscreen();
        const unsigned int sx = screen_width(), sy = screen_height();
        XSetWindowAttributes winattr;
        winattr.override_redirect = 1;
        _window = XCreateWindow(dpy,DefaultRootWindow(dpy),(sx-_width)/2,(sy-_height)/2,_width,_height,0,0,
                                InputOutput,CopyFromParent,CWOverrideRedirect,&winattr);
      } else
        _window = XCreateSimpleWindow(dpy,DefaultRootWindow(dpy),0,0,_width,_height,0,0L,0L);

      XSelectInput(dpy,_window,
		   ExposureMask | StructureNotifyMask | ButtonPressMask | KeyPressMask | PointerMotionMask |
		   EnterWindowMask | LeaveWindowMask | ButtonReleaseMask | KeyReleaseMask);

      XStoreName(dpy,_window,_title?_title:" ");
      if (cimg::X11_attr().nb_bits==8) {
        _colormap = XCreateColormap(dpy,_window,DefaultVisual(dpy,DefaultScreen(dpy)),AllocAll);
        _set_colormap(_colormap,3);
        XSetWindowColormap(dpy,_window,_colormap);
      }

      static const char *const _window_class = cimg_appname;
      XClassHint *const window_class = XAllocClassHint();
      window_class->res_name = (char*)_window_class;
      window_class->res_class = (char*)_window_class;
      XSetClassHint(dpy,_window,window_class);
      XFree(window_class);

      _window_width = _width;
      _window_height = _height;

      // Create XImage
#ifdef cimg_use_xshm
      _shminfo = 0;
      if (XShmQueryExtension(dpy)) {
        _shminfo = new XShmSegmentInfo;
        _image = XShmCreateImage(dpy,DefaultVisual(dpy,DefaultScreen(dpy)),cimg::X11_attr().nb_bits,ZPixmap,0,_shminfo,_width,_height);
        if (!_image) { delete _shminfo; _shminfo = 0; }
        else {
          _shminfo->shmid = shmget(IPC_PRIVATE,_image->bytes_per_line*_image->height,IPC_CREAT|0777);
          if (_shminfo->shmid==-1) { XDestroyImage(_image); delete _shminfo; _shminfo = 0; }
          else {
            _shminfo->shmaddr = _image->data = (char*)(_data = shmat(_shminfo->shmid,0,0));
            if (_shminfo->shmaddr==(char*)-1) { shmctl(_shminfo->shmid,IPC_RMID,0); XDestroyImage(_image); delete _shminfo; _shminfo = 0; }
            else {
              _shminfo->readOnly = 0;
              cimg::X11_attr().is_shm_enabled = true;
              XErrorHandler oldXErrorHandler = XSetErrorHandler(_assign_xshm);
              XShmAttach(dpy,_shminfo);
              XSync(dpy,0);
              XSetErrorHandler(oldXErrorHandler);
              if (!cimg::X11_attr().is_shm_enabled) {
                shmdt(_shminfo->shmaddr); shmctl(_shminfo->shmid,IPC_RMID,0); XDestroyImage(_image); delete _shminfo; _shminfo = 0;
              }
            }
          }
        }
      }
      if (!_shminfo)
#endif
# 8127 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        {
          const unsigned long buf_size = (unsigned long)_width*_height*(cimg::X11_attr().nb_bits==8?1:(cimg::X11_attr().nb_bits==16?2:4));
          _data = std::malloc(buf_size);
          _image = XCreateImage(dpy,DefaultVisual(dpy,DefaultScreen(dpy)),cimg::X11_attr().nb_bits,ZPixmap,0,(char*)_data,_width,_height,8,0);
        }

      _wm_window_atom = XInternAtom(dpy,"WM_DELETE_WINDOW",0);
      _wm_protocol_atom = XInternAtom(dpy,"WM_PROTOCOLS",0);
      XSetWMProtocols(dpy,_window,&_wm_window_atom,1);

      if (_is_fullscreen) XGrabKeyboard(dpy,_window,1,GrabModeAsync,GrabModeAsync,CurrentTime);
      cimg::X11_attr().wins[cimg::X11_attr().nb_wins++]=this;
      if (!_is_closed) _map_window(); else { _window_x = _window_y = cimg::type<int>::min(); }
      XUnlockDisplay(dpy);
      cimg::mutex(14,0);
    }

    CImgDisplay& assign() {
      if (is_empty()) return flush();
      Display *const dpy = cimg::X11_attr().display;
      XLockDisplay(dpy);

      // Remove display window from event thread list.
      unsigned int i;
      for (i = 0; i<cimg::X11_attr().nb_wins && cimg::X11_attr().wins[i]!=this; ++i) {}
      for (; i<cimg::X11_attr().nb_wins-1; ++i) cimg::X11_attr().wins[i] = cimg::X11_attr().wins[i+1];
      --cimg::X11_attr().nb_wins;

      // Destroy window, image, colormap and title.
      if (_is_fullscreen && !_is_closed) _desinit_fullscreen();
      XDestroyWindow(dpy,_window);
      _window = 0;
#ifdef cimg_use_xshm
      if (_shminfo) {
        XShmDetach(dpy,_shminfo);
        XDestroyImage(_image);
        shmdt(_shminfo->shmaddr);
        shmctl(_shminfo->shmid,IPC_RMID,0);
        delete _shminfo;
        _shminfo = 0;
      } else
#endif
# 8169 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        XDestroyImage(_image);
      _data = 0; _image = 0;
      if (cimg::X11_attr().nb_bits==8) XFreeColormap(dpy,_colormap);
      _colormap = 0;
      XSync(dpy,0);

      // Reset display variables.
      delete[] _title;
      _width = _height = _normalization = _window_width = _window_height = 0;
      _window_x = _window_y = 0;
      _is_fullscreen = false;
      _is_closed = true;
      _min = _max = 0;
      _title = 0;
      flush();

      XUnlockDisplay(dpy);
      return *this;
    }

    CImgDisplay& assign(const unsigned int dimw, const unsigned int dimh, const char *const title=0,
                        const unsigned int normalization_type=3,
                        const bool fullscreen_flag=false, const bool closed_flag=false) {
      if (!dimw || !dimh) return assign();
      _assign(dimw,dimh,title,normalization_type,fullscreen_flag,closed_flag);
      _min = _max = 0;
      std::memset(_data,0,(cimg::X11_attr().nb_bits==8?sizeof(unsigned char):
                           (cimg::X11_attr().nb_bits==16?sizeof(unsigned short):sizeof(unsigned int)))*(unsigned long)_width*_height);
      return paint();
    }

    template<typename T>
    CImgDisplay& assign(const CImg<T>& img, const char *const title=0,
                        const unsigned int normalization_type=3,
                        const bool fullscreen_flag=false, const bool closed_flag=false) {
      if (!img) return assign();
      CImg<T> tmp;
      const CImg<T>& nimg = (img._depth==1)?img:(tmp=img.get_projections2d((img._width-1)/2,(img._height-1)/2,(img._depth-1)/2));
      _assign(nimg._width,nimg._height,title,normalization_type,fullscreen_flag,closed_flag);
      if (_normalization==2) _min = (float)nimg.min_max(_max);
      return render(nimg).paint();
    }

    template<typename T>
    CImgDisplay& assign(const CImgList<T>& list, const char *const title=0,
                        const unsigned int normalization_type=3,
                        const bool fullscreen_flag=false, const bool closed_flag=false) {
      if (!list) return assign();
      CImg<T> tmp;
      const CImg<T> img = list>'x', &nimg = (img._depth==1)?img:(tmp=img.get_projections2d((img._width-1)/2,(img._height-1)/2,(img._depth-1)/2));
      _assign(nimg._width,nimg._height,title,normalization_type,fullscreen_flag,closed_flag);
      if (_normalization==2) _min = (float)nimg.min_max(_max);
      return render(nimg).paint();
    }

    CImgDisplay& assign(const CImgDisplay& disp) {
      if (!disp) return assign();
      _assign(disp._width,disp._height,disp._title,disp._normalization,disp._is_fullscreen,disp._is_closed);
      std::memcpy(_data,disp._data,(cimg::X11_attr().nb_bits==8?sizeof(unsigned char):
                                    cimg::X11_attr().nb_bits==16?sizeof(unsigned short):
                                    sizeof(unsigned int))*(unsigned long)_width*_height);
      return paint();
    }

    CImgDisplay& resize(const int nwidth, const int nheight, const bool force_redraw=true) {
      if (!nwidth || !nheight || (is_empty() && (nwidth<0 || nheight<0))) return assign();
      if (is_empty()) return assign(nwidth,nheight);
      Display *const dpy = cimg::X11_attr().display;
      const unsigned int
        tmpdimx = (nwidth>0)?nwidth:(-nwidth*width()/100),
        tmpdimy = (nheight>0)?nheight:(-nheight*height()/100),
        dimx = tmpdimx?tmpdimx:1,
        dimy = tmpdimy?tmpdimy:1;
      XLockDisplay(dpy);
      if (_window_width!=dimx || _window_height!=dimy) {
        XWindowAttributes attr;
        for (unsigned int i = 0; i<10; ++i) {
          XResizeWindow(dpy,_window,dimx,dimy);
          XGetWindowAttributes(dpy,_window,&attr);
          if (attr.width==(int)dimx && attr.height==(int)dimy) break;
          cimg::wait(5);
        }
      }
      if (_width!=dimx || _height!=dimy) switch (cimg::X11_attr().nb_bits) {
        case 8 :  { unsigned char pixel_type = 0; _resize(pixel_type,dimx,dimy,force_redraw); } break;
        case 16 : { unsigned short pixel_type = 0; _resize(pixel_type,dimx,dimy,force_redraw); } break;
        default : { unsigned int pixel_type = 0; _resize(pixel_type,dimx,dimy,force_redraw); }
        }
      _window_width = _width = dimx; _window_height = _height = dimy;
      _is_resized = false;
      XUnlockDisplay(dpy);
      if (_is_fullscreen) move((screen_width()-_width)/2,(screen_height()-_height)/2);
      if (force_redraw) return paint();
      return *this;
    }

    CImgDisplay& toggle_fullscreen(const bool force_redraw=true) {
      if (is_empty()) return *this;
      if (force_redraw) {
        const unsigned long buf_size = (unsigned long)_width*_height*(cimg::X11_attr().nb_bits==8?1:(cimg::X11_attr().nb_bits==16?2:4));
        void *image_data = std::malloc(buf_size);
        std::memcpy(image_data,_data,buf_size);
        assign(_width,_height,_title,_normalization,!_is_fullscreen,false);
        std::memcpy(_data,image_data,buf_size);
        std::free(image_data);
        return paint();
      }
      return assign(_width,_height,_title,_normalization,!_is_fullscreen,false);
    }

    CImgDisplay& show() {
      if (is_empty() || !_is_closed) return *this;
      Display *const dpy = cimg::X11_attr().display;
      XLockDisplay(dpy);
      if (_is_fullscreen) _init_fullscreen();
      _map_window();
      _is_closed = false;
      XUnlockDisplay(dpy);
      return paint();
    }

    CImgDisplay& close() {
      if (is_empty() || _is_closed) return *this;
      Display *const dpy = cimg::X11_attr().display;
      XLockDisplay(dpy);
      if (_is_fullscreen) _desinit_fullscreen();
      XUnmapWindow(dpy,_window);
      _window_x = _window_y = -1;
      _is_closed = true;
      XUnlockDisplay(dpy);
      return *this;
    }

    CImgDisplay& move(const int posx, const int posy) {
      if (is_empty()) return *this;
      show();
      Display *const dpy = cimg::X11_attr().display;
      XLockDisplay(dpy);
      XMoveWindow(dpy,_window,posx,posy);
      _window_x = posx; _window_y = posy;
      _is_moved = false;
      XUnlockDisplay(dpy);
      return paint();
    }

    CImgDisplay& show_mouse() {
      if (is_empty()) return *this;
      Display *const dpy = cimg::X11_attr().display;
      XLockDisplay(dpy);
      XUndefineCursor(dpy,_window);
      XUnlockDisplay(dpy);
      return *this;
    }

    CImgDisplay& hide_mouse() {
      if (is_empty()) return *this;
      Display *const dpy = cimg::X11_attr().display;
      XLockDisplay(dpy);
      const char pix_data[8] = { 0 };
      XColor col;
      col.red = col.green = col.blue = 0;
      Pixmap pix = XCreateBitmapFromData(dpy,_window,pix_data,8,8);
      Cursor cur = XCreatePixmapCursor(dpy,pix,pix,&col,&col,0,0);
      XFreePixmap(dpy,pix);
      XDefineCursor(dpy,_window,cur);
      XUnlockDisplay(dpy);
      return *this;
    }

    CImgDisplay& set_mouse(const int posx, const int posy) {
      if (is_empty() || _is_closed) return *this;
      Display *const dpy = cimg::X11_attr().display;
      XLockDisplay(dpy);
      XWarpPointer(dpy,0L,_window,0,0,0,0,posx,posy);
      _mouse_x = posx; _mouse_y = posy;
      _is_moved = false;
      XSync(dpy,0);
      XUnlockDisplay(dpy);
      return *this;
    }

    CImgDisplay& set_title(const char *const format, ...) {
      if (is_empty()) return *this;
      char tmp[1024] = { 0 };
      va_list ap;
      va_start(ap, format);
      cimg_vsnprintf(tmp,sizeof(tmp),format,ap);
      va_end(ap);
      if (!std::strcmp(_title,tmp)) return *this;
      delete[] _title;
      const unsigned int s = std::strlen(tmp) + 1;
      _title = new char[s];
      std::memcpy(_title,tmp,s*sizeof(char));
      Display *const dpy = cimg::X11_attr().display;
      XLockDisplay(dpy);
      XStoreName(dpy,_window,tmp);
      XUnlockDisplay(dpy);
      return *this;
    }

    template<typename T>
    CImgDisplay& display(const CImg<T>& img) {
      if (!img)
        throw CImgArgumentException(_cimgdisplay_instance
                                    "display(): Empty specified image.",
                                    cimgdisplay_instance);
      if (is_empty()) return assign(img);
      return render(img).paint(false);
    }

    CImgDisplay& paint(const bool wait_expose=true) {
      if (is_empty()) return *this;
      Display *const dpy = cimg::X11_attr().display;
      XLockDisplay(dpy);
      _paint(wait_expose);
      XUnlockDisplay(dpy);
      return *this;
    }

    template<typename T>
    CImgDisplay& render(const CImg<T>& img, const bool flag8=false) {
      if (!img)
        throw CImgArgumentException(_cimgdisplay_instance
                                    "render(): Empty specified image.",
                                    cimgdisplay_instance);
      if (is_empty()) return *this;
      if (img._depth!=1) return render(img.get_projections2d((img._width-1)/2,(img._height-1)/2,(img._depth-1)/2));
      if (cimg::X11_attr().nb_bits==8 && (img._width!=_width || img._height!=_height)) return render(img.get_resize(_width,_height,1,-100,1));
      if (cimg::X11_attr().nb_bits==8 && !flag8 && img._spectrum==3) {
        static const CImg<typename CImg<T>::ucharT> default_colormap = CImg<typename CImg<T>::ucharT>::default_LUT256();
        return render(img.get_index(default_colormap,1,false));
      }

      Display *const dpy = cimg::X11_attr().display;
      const T
        *data1 = img._data,
        *data2 = (img._spectrum>1)?img.data(0,0,0,1):data1,
        *data3 = (img._spectrum>2)?img.data(0,0,0,2):data1;

      if (cimg::X11_attr().is_blue_first) cimg::swap(data1,data3);
      XLockDisplay(dpy);

      if (!_normalization || (_normalization==3 && cimg::type<T>::string()==cimg::type<unsigned char>::string())) {
        _min = _max = 0;
        switch (cimg::X11_attr().nb_bits) {
        case 8 : { // 256 colormap, no normalization
          _set_colormap(_colormap,img._spectrum);
          unsigned char *const ndata = (img._width==_width && img._height==_height)?(unsigned char*)_data:new unsigned char[(unsigned long)img._width*img._height];
          unsigned char *ptrd = (unsigned char*)ndata;
          switch (img._spectrum) {
          case 1 : for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) (*ptrd++) = (unsigned char)*(data1++);
            break;
          case 2 : for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
	      const unsigned char R = (unsigned char)*(data1++), G = (unsigned char)*(data2++);
	      (*ptrd++) = (R&0xf0) | (G>>4);
	    } break;
          default : for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
	      const unsigned char R = (unsigned char)*(data1++), G = (unsigned char)*(data2++), B = (unsigned char)*(data3++);
	      (*ptrd++) = (R&0xe0) | ((G>>5)<<2) | (B>>6);
	    }
          }
          if (ndata!=_data) { _render_resize(ndata,img._width,img._height,(unsigned char*)_data,_width,_height); delete[] ndata; }
        } break;
        case 16 : { // 16 bits colors, no normalization
          unsigned short *const ndata = (img._width==_width && img._height==_height)?(unsigned short*)_data:new unsigned short[(unsigned long)img._width*img._height];
          unsigned char *ptrd = (unsigned char*)ndata;
          const unsigned int M = 248;
          switch (img._spectrum) {
          case 1 :
            if (cimg::X11_attr().byte_order) for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
              const unsigned char val = (unsigned char)*(data1++), G = val>>2;
              *(ptrd++) = (val&M) | (G>>3);
              *(ptrd++) = (G<<5) | (G>>1);
              } else for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
              const unsigned char val = (unsigned char)*(data1++), G = val>>2;
              *(ptrd++) = (G<<5) | (G>>1);
              *(ptrd++) = (val&M) | (G>>3);
            }
            break;
          case 2 :
            if (cimg::X11_attr().byte_order) for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
              const unsigned char G = (unsigned char)*(data2++)>>2;
              *(ptrd++) = ((unsigned char)*(data1++)&M) | (G>>3);
              *(ptrd++) = (G<<5);
              } else for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
              const unsigned char G = (unsigned char)*(data2++)>>2;
              *(ptrd++) = (G<<5);
              *(ptrd++) = ((unsigned char)*(data1++)&M) | (G>>3);
            }
            break;
          default :
            if (cimg::X11_attr().byte_order) for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
              const unsigned char G = (unsigned char)*(data2++)>>2;
              *(ptrd++) = ((unsigned char)*(data1++)&M) | (G>>3);
              *(ptrd++) = (G<<5) | ((unsigned char)*(data3++)>>3);
              } else for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
              const unsigned char G = (unsigned char)*(data2++)>>2;
              *(ptrd++) = (G<<5) | ((unsigned char)*(data3++)>>3);
              *(ptrd++) = ((unsigned char)*(data1++)&M) | (G>>3);
            }
          }
          if (ndata!=_data) { _render_resize(ndata,img._width,img._height,(unsigned short*)_data,_width,_height); delete[] ndata; }
        } break;
        default : { // 24 bits colors, no normalization
          unsigned int *const ndata = (img._width==_width && img._height==_height)?(unsigned int*)_data:new unsigned int[(unsigned long)img._width*img._height];
          if (sizeof(int)==4) { // 32 bits int uses optimized version
            unsigned int *ptrd = ndata;
            switch (img._spectrum) {
            case 1 :
              if (cimg::X11_attr().byte_order==cimg::endianness())
                for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
                  const unsigned char val = (unsigned char)*(data1++);
                  *(ptrd++) = (val<<16) | (val<<8) | val;
                }
              else
                for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
                 const unsigned char val = (unsigned char)*(data1++);
                  *(ptrd++) = (val<<16) | (val<<8) | val;
                }
              break;
            case 2 :
              if (cimg::X11_attr().byte_order==cimg::endianness())
                for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy)
                  *(ptrd++) = ((unsigned char)*(data1++)<<16) | ((unsigned char)*(data2++)<<8);
              else
                for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy)
                  *(ptrd++) = ((unsigned char)*(data2++)<<16) | ((unsigned char)*(data1++)<<8);
              break;
            default :
              if (cimg::X11_attr().byte_order==cimg::endianness())
                for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy)
                  *(ptrd++) = ((unsigned char)*(data1++)<<16) | ((unsigned char)*(data2++)<<8) | (unsigned char)*(data3++);
              else
                for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy)
                  *(ptrd++) = ((unsigned char)*(data3++)<<24) | ((unsigned char)*(data2++)<<16) | ((unsigned char)*(data1++)<<8);
            }
          } else {
            unsigned char *ptrd = (unsigned char*)ndata;
            switch (img._spectrum) {
            case 1 :
              if (cimg::X11_attr().byte_order) for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
                *(ptrd++) = 0;
                *(ptrd++) = (unsigned char)*(data1++);
                *(ptrd++) = 0;
                *(ptrd++) = 0;
                } else for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
                *(ptrd++) = 0;
                *(ptrd++) = 0;
                *(ptrd++) = (unsigned char)*(data1++);
                *(ptrd++) = 0;
              }
              break;
            case 2 :
              if (cimg::X11_attr().byte_order) cimg::swap(data1,data2);
              for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
                *(ptrd++) = 0;
                *(ptrd++) = (unsigned char)*(data2++);
                *(ptrd++) = (unsigned char)*(data1++);
                *(ptrd++) = 0;
              }
              break;
            default :
              if (cimg::X11_attr().byte_order) for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
                *(ptrd++) = 0;
                *(ptrd++) = (unsigned char)*(data1++);
                *(ptrd++) = (unsigned char)*(data2++);
                *(ptrd++) = (unsigned char)*(data3++);
                } else for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
                *(ptrd++) = (unsigned char)*(data3++);
                *(ptrd++) = (unsigned char)*(data2++);
                *(ptrd++) = (unsigned char)*(data1++);
                *(ptrd++) = 0;
              }
            }
          }
          if (ndata!=_data) { _render_resize(ndata,img._width,img._height,(unsigned int*)_data,_width,_height); delete[] ndata; }
        }
        }
      } else {
        if (_normalization==3) {
          if (cimg::type<T>::is_float()) _min = (float)img.min_max(_max);
          else { _min = (float)cimg::type<T>::min(); _max = (float)cimg::type<T>::max(); }
        } else if ((_min>_max) || _normalization==1) _min = (float)img.min_max(_max);
        const float delta = _max - _min, mm = 255/(delta?delta:1.0f);
        switch (cimg::X11_attr().nb_bits) {
        case 8 : { // 256 colormap, with normalization
          _set_colormap(_colormap,img._spectrum);
          unsigned char *const ndata = (img._width==_width && img._height==_height)?(unsigned char*)_data:new unsigned char[(unsigned long)img._width*img._height];
          unsigned char *ptrd = (unsigned char*)ndata;
          switch (img._spectrum) {
          case 1 : for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
              const unsigned char R = (unsigned char)((*(data1++)-_min)*mm);
              *(ptrd++) = R;
            } break;
          case 2 : for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
              const unsigned char
                R = (unsigned char)((*(data1++)-_min)*mm),
                G = (unsigned char)((*(data2++)-_min)*mm);
            (*ptrd++) = (R&0xf0) | (G>>4);
          } break;
          default :
            for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
              const unsigned char
                R = (unsigned char)((*(data1++)-_min)*mm),
                G = (unsigned char)((*(data2++)-_min)*mm),
                B = (unsigned char)((*(data3++)-_min)*mm);
              *(ptrd++) = (R&0xe0) | ((G>>5)<<2) | (B>>6);
            }
          }
          if (ndata!=_data) { _render_resize(ndata,img._width,img._height,(unsigned char*)_data,_width,_height); delete[] ndata; }
        } break;
        case 16 : { // 16 bits colors, with normalization
          unsigned short *const ndata = (img._width==_width && img._height==_height)?(unsigned short*)_data:new unsigned short[(unsigned long)img._width*img._height];
          unsigned char *ptrd = (unsigned char*)ndata;
          const unsigned int M = 248;
          switch (img._spectrum) {
          case 1 :
            if (cimg::X11_attr().byte_order) for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
              const unsigned char val = (unsigned char)((*(data1++)-_min)*mm), G = val>>2;
              *(ptrd++) = (val&M) | (G>>3);
              *(ptrd++) = (G<<5) | (val>>3);
              } else for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
              const unsigned char val = (unsigned char)((*(data1++)-_min)*mm), G = val>>2;
              *(ptrd++) = (G<<5) | (val>>3);
              *(ptrd++) = (val&M) | (G>>3);
            }
            break;
          case 2 :
            if (cimg::X11_attr().byte_order) for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
              const unsigned char G = (unsigned char)((*(data2++)-_min)*mm)>>2;
              *(ptrd++) = ((unsigned char)((*(data1++)-_min)*mm)&M) | (G>>3);
              *(ptrd++) = (G<<5);
              } else for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
              const unsigned char G = (unsigned char)((*(data2++)-_min)*mm)>>2;
              *(ptrd++) = (G<<5);
              *(ptrd++) = ((unsigned char)((*(data1++)-_min)*mm)&M) | (G>>3);
            }
            break;
          default :
            if (cimg::X11_attr().byte_order) for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
              const unsigned char G = (unsigned char)((*(data2++)-_min)*mm)>>2;
              *(ptrd++) = ((unsigned char)((*(data1++)-_min)*mm)&M) | (G>>3);
              *(ptrd++) = (G<<5) | ((unsigned char)((*(data3++)-_min)*mm)>>3);
              } else for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
              const unsigned char G = (unsigned char)((*(data2++)-_min)*mm)>>2;
              *(ptrd++) = (G<<5) | ((unsigned char)((*(data3++)-_min)*mm)>>3);
              *(ptrd++) = ((unsigned char)((*(data1++)-_min)*mm)&M) | (G>>3);
            }
          }
          if (ndata!=_data) { _render_resize(ndata,img._width,img._height,(unsigned short*)_data,_width,_height); delete[] ndata; }
        } break;
        default : { // 24 bits colors, with normalization
          unsigned int *const ndata = (img._width==_width && img._height==_height)?(unsigned int*)_data:new unsigned int[(unsigned long)img._width*img._height];
          if (sizeof(int)==4) { // 32 bits int uses optimized version
            unsigned int *ptrd = ndata;
            switch (img._spectrum) {
            case 1 :
              if (cimg::X11_attr().byte_order==cimg::endianness())
                for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
                  const unsigned char val = (unsigned char)((*(data1++)-_min)*mm);
                  *(ptrd++) = (val<<16) | (val<<8) | val;
                }
              else
                for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
                  const unsigned char val = (unsigned char)((*(data1++)-_min)*mm);
                  *(ptrd++) = (val<<24) | (val<<16) | (val<<8);
                }
              break;
            case 2 :
              if (cimg::X11_attr().byte_order==cimg::endianness())
                for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy)
                  *(ptrd++) =
                    ((unsigned char)((*(data1++)-_min)*mm)<<16) |
                    ((unsigned char)((*(data2++)-_min)*mm)<<8);
              else
                for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy)
                  *(ptrd++) =
                    ((unsigned char)((*(data2++)-_min)*mm)<<16) |
                    ((unsigned char)((*(data1++)-_min)*mm)<<8);
              break;
            default :
              if (cimg::X11_attr().byte_order==cimg::endianness())
                for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy)
                  *(ptrd++) =
                    ((unsigned char)((*(data1++)-_min)*mm)<<16) |
                    ((unsigned char)((*(data2++)-_min)*mm)<<8) |
                    (unsigned char)((*(data3++)-_min)*mm);
              else
                for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy)
                  *(ptrd++) =
                    ((unsigned char)((*(data3++)-_min)*mm)<<24) |
                    ((unsigned char)((*(data2++)-_min)*mm)<<16) |
                    ((unsigned char)((*(data1++)-_min)*mm)<<8);
            }
          } else {
            unsigned char *ptrd = (unsigned char*)ndata;
            switch (img._spectrum) {
            case 1 :
              if (cimg::X11_attr().byte_order) for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
                const unsigned char val = (unsigned char)((*(data1++)-_min)*mm);
                (*ptrd++) = 0;
                (*ptrd++) = val;
                (*ptrd++) = val;
                (*ptrd++) = val;
                } else for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
                const unsigned char val = (unsigned char)((*(data1++)-_min)*mm);
                (*ptrd++) = val;
                (*ptrd++) = val;
                (*ptrd++) = val;
                (*ptrd++) = 0;
              }
              break;
            case 2 :
              if (cimg::X11_attr().byte_order) cimg::swap(data1,data2);
              for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
                (*ptrd++) = 0;
                (*ptrd++) = (unsigned char)((*(data2++)-_min)*mm);
                (*ptrd++) = (unsigned char)((*(data1++)-_min)*mm);
                (*ptrd++) = 0;
              }
              break;
            default :
              if (cimg::X11_attr().byte_order) for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
                (*ptrd++) = 0;
                (*ptrd++) = (unsigned char)((*(data1++)-_min)*mm);
                (*ptrd++) = (unsigned char)((*(data2++)-_min)*mm);
                (*ptrd++) = (unsigned char)((*(data3++)-_min)*mm);
                } else for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
                (*ptrd++) = (unsigned char)((*(data3++)-_min)*mm);
                (*ptrd++) = (unsigned char)((*(data2++)-_min)*mm);
                (*ptrd++) = (unsigned char)((*(data1++)-_min)*mm);
                (*ptrd++) = 0;
              }
            }
          }
          if (ndata!=_data) { _render_resize(ndata,img._width,img._height,(unsigned int*)_data,_width,_height); delete[] ndata; }
	}
        }
      }
      XUnlockDisplay(dpy);
      return *this;
    }

    template<typename T>
    const CImgDisplay& snapshot(CImg<T>& img) const {
      if (is_empty()) { img.assign(); return *this; }
      const unsigned char *ptrs = (unsigned char*)_data;
      img.assign(_width,_height,1,3);
      T
        *data1 = img.data(0,0,0,0),
        *data2 = img.data(0,0,0,1),
        *data3 = img.data(0,0,0,2);
      if (cimg::X11_attr().is_blue_first) cimg::swap(data1,data3);
      switch (cimg::X11_attr().nb_bits) {
      case 8 : {
        for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
          const unsigned char val = *(ptrs++);
          *(data1++) = (T)(val&0xe0);
          *(data2++) = (T)((val&0x1c)<<3);
          *(data3++) = (T)(val<<6);
        }
      } break;
      case 16 : {
        if (cimg::X11_attr().byte_order) for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
          const unsigned char val0 = *(ptrs++), val1 = *(ptrs++);
          *(data1++) = (T)(val0&0xf8);
          *(data2++) = (T)((val0<<5) | ((val1&0xe0)>>5));
          *(data3++) = (T)(val1<<3);
          } else for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
          const unsigned short val0 = *(ptrs++), val1 = *(ptrs++);
          *(data1++) = (T)(val1&0xf8);
          *(data2++) = (T)((val1<<5) | ((val0&0xe0)>>5));
          *(data3++) = (T)(val0<<3);
        }
      } break;
      default : {
        if (cimg::X11_attr().byte_order) for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
          ++ptrs;
          *(data1++) = (T)*(ptrs++);
          *(data2++) = (T)*(ptrs++);
          *(data3++) = (T)*(ptrs++);
          } else for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
            *(data3++) = (T)*(ptrs++);
            *(data2++) = (T)*(ptrs++);
            *(data1++) = (T)*(ptrs++);
            ++ptrs;
          }
      }
      }
      return *this;
    }

    // Windows-based implementation.
    //-------------------------------
#elif cimg_display==2
# 8764 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    bool _is_mouse_tracked, _is_cursor_visible;
    HANDLE _thread, _is_created, _mutex;
    HWND _window, _background_window;
    CLIENTCREATESTRUCT _ccs;
    unsigned int *_data;
    DEVMODE _curr_mode;
    BITMAPINFO _bmi;
    HDC _hdc;

    static int screen_width() {
      DEVMODE mode;
      mode.dmSize = sizeof(DEVMODE);
      mode.dmDriverExtra = 0;
      EnumDisplaySettings(0,ENUM_CURRENT_SETTINGS,&mode);
      return mode.dmPelsWidth;
    }

    static int screen_height() {
      DEVMODE mode;
      mode.dmSize = sizeof(DEVMODE);
      mode.dmDriverExtra = 0;
      EnumDisplaySettings(0,ENUM_CURRENT_SETTINGS,&mode);
      return mode.dmPelsHeight;
    }

    static void wait_all() {
      WaitForSingleObject(cimg::Win32_attr().wait_event,INFINITE);
    }

    static LRESULT APIENTRY _handle_events(HWND window, UINT msg, WPARAM wParam, LPARAM lParam) {
#ifdef _WIN64
      CImgDisplay *const disp = (CImgDisplay*)GetWindowLongPtr(window,GWLP_USERDATA);
#else
# 8798 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      CImgDisplay *const disp = (CImgDisplay*)GetWindowLong(window,GWL_USERDATA);
#endif
# 8800 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      MSG st_msg;
      switch (msg) {
      case WM_CLOSE :
        disp->_mouse_x = disp->_mouse_y = -1;
        disp->_window_x = disp->_window_y = 0;
        disp->set_button().set_key(0).set_key(0,false)._is_closed = true;
        ReleaseMutex(disp->_mutex);
        ShowWindow(disp->_window,SW_HIDE);
        disp->_is_event = true;
        SetEvent(cimg::Win32_attr().wait_event);
        return 0;
      case WM_SIZE : {
        while (PeekMessage(&st_msg,window,WM_SIZE,WM_SIZE,PM_REMOVE)) {}
        WaitForSingleObject(disp->_mutex,INFINITE);
        const unsigned int nw = LOWORD(lParam),nh = HIWORD(lParam);
        if (nw && nh && (nw!=disp->_width || nh!=disp->_height)) {
          disp->_window_width = nw;
          disp->_window_height = nh;
          disp->_mouse_x = disp->_mouse_y = -1;
          disp->_is_resized = disp->_is_event = true;
          SetEvent(cimg::Win32_attr().wait_event);
        }
        ReleaseMutex(disp->_mutex);
      } break;
      case WM_MOVE : {
        while (PeekMessage(&st_msg,window,WM_SIZE,WM_SIZE,PM_REMOVE)) {}
        WaitForSingleObject(disp->_mutex,INFINITE);
        const int nx = (int)(short)(LOWORD(lParam)), ny = (int)(short)(HIWORD(lParam));
        if (nx!=disp->_window_x || ny!=disp->_window_y) {
          disp->_window_x = nx;
          disp->_window_y = ny;
          disp->_is_moved = disp->_is_event = true;
          SetEvent(cimg::Win32_attr().wait_event);
        }
        ReleaseMutex(disp->_mutex);
      } break;
      case WM_PAINT :
        disp->paint();
        break;
      case WM_KEYDOWN :
        disp->set_key((unsigned int)wParam);
        SetEvent(cimg::Win32_attr().wait_event);
        break;
      case WM_KEYUP :
        disp->set_key((unsigned int)wParam,false);
        SetEvent(cimg::Win32_attr().wait_event);
        break;
      case WM_MOUSEMOVE : {
        while (PeekMessage(&st_msg,window,WM_MOUSEMOVE,WM_MOUSEMOVE,PM_REMOVE)) {}
        disp->_mouse_x = LOWORD(lParam);
        disp->_mouse_y = HIWORD(lParam);
#if (_WIN32_WINNT>=0x0400) && !defined(NOTRACKMOUSEEVENT)
        if (!disp->_is_mouse_tracked) {
          TRACKMOUSEEVENT tme;
          tme.cbSize = sizeof(TRACKMOUSEEVENT);
          tme.dwFlags = TME_LEAVE;
          tme.hwndTrack = disp->_window;
          if (TrackMouseEvent(&tme)) disp->_is_mouse_tracked = true;
        }
#endif
# 8860 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        if (disp->_mouse_x<0 || disp->_mouse_y<0 || disp->_mouse_x>=disp->width() || disp->_mouse_y>=disp->height())
          disp->_mouse_x = disp->_mouse_y = -1;
        disp->_is_event = true;
        SetEvent(cimg::Win32_attr().wait_event);
      } break;
      case WM_MOUSELEAVE : {
        disp->_mouse_x = disp->_mouse_y = -1;
        disp->_is_mouse_tracked = false;
      } break;
      case WM_LBUTTONDOWN :
        disp->set_button(1);
        SetEvent(cimg::Win32_attr().wait_event);
        break;
      case WM_RBUTTONDOWN :
        disp->set_button(2);
        SetEvent(cimg::Win32_attr().wait_event);
        break;
      case WM_MBUTTONDOWN :
        disp->set_button(3);
        SetEvent(cimg::Win32_attr().wait_event);
        break;
      case WM_LBUTTONUP :
        disp->set_button(1,false);
        SetEvent(cimg::Win32_attr().wait_event);
        break;
      case WM_RBUTTONUP :
        disp->set_button(2,false);
        SetEvent(cimg::Win32_attr().wait_event);
        break;
      case WM_MBUTTONUP :
        disp->set_button(3,false);
        SetEvent(cimg::Win32_attr().wait_event);
        break;
      case 0x020A : // WM_MOUSEWHEEL:
        disp->set_wheel((int)((short)HIWORD(wParam))/120);
        SetEvent(cimg::Win32_attr().wait_event);
      case WM_SETCURSOR :
        if (disp->_is_cursor_visible) while (ShowCursor(TRUE)<0);
        else while (ShowCursor(FALSE)>=0);
        break;
      }
      return DefWindowProc(window,msg,wParam,lParam);
    }

    static DWORD WINAPI _events_thread(void* arg) {
      CImgDisplay *const disp = (CImgDisplay*)(((void**)arg)[0]);
      const char *const title = (const char*)(((void**)arg)[1]);
      MSG msg;
      delete[] (void**)arg;
      disp->_bmi.bmiHeader.biSize = sizeof(BITMAPINFOHEADER);
      disp->_bmi.bmiHeader.biWidth = disp->width();
      disp->_bmi.bmiHeader.biHeight = -disp->height();
      disp->_bmi.bmiHeader.biPlanes = 1;
      disp->_bmi.bmiHeader.biBitCount = 32;
      disp->_bmi.bmiHeader.biCompression = BI_RGB;
      disp->_bmi.bmiHeader.biSizeImage = 0;
      disp->_bmi.bmiHeader.biXPelsPerMeter = 1;
      disp->_bmi.bmiHeader.biYPelsPerMeter = 1;
      disp->_bmi.bmiHeader.biClrUsed = 0;
      disp->_bmi.bmiHeader.biClrImportant = 0;
      disp->_data = new unsigned int[(unsigned long)disp->_width*disp->_height];
      if (!disp->_is_fullscreen) { // Normal window
        RECT rect;
        rect.left = rect.top = 0; rect.right = disp->_width-1; rect.bottom = disp->_height-1;
        AdjustWindowRect(&rect,WS_CAPTION | WS_SYSMENU | WS_THICKFRAME | WS_MINIMIZEBOX | WS_MAXIMIZEBOX,false);
        const int
          border1 = (rect.right - rect.left + 1 - disp->_width)/2,
          border2 = rect.bottom - rect.top + 1 - disp->_height - border1;
        disp->_window = CreateWindowA("MDICLIENT",title?title:" ",
                                     WS_OVERLAPPEDWINDOW | (disp->_is_closed?0:WS_VISIBLE), CW_USEDEFAULT,CW_USEDEFAULT,
                                     disp->_width + 2*border1, disp->_height + border1 + border2,
                                     0,0,0,&(disp->_ccs));
        if (!disp->_is_closed) {
          GetWindowRect(disp->_window,&rect);
          disp->_window_x = rect.left + border1;
          disp->_window_y = rect.top + border2;
        } else disp->_window_x = disp->_window_y = 0;
      } else { // Fullscreen window
        const unsigned int sx = screen_width(), sy = screen_height();
        disp->_window = CreateWindowA("MDICLIENT",title?title:" ",
                                     WS_POPUP | (disp->_is_closed?0:WS_VISIBLE), (sx-disp->_width)/2, (sy-disp->_height)/2,
                                     disp->_width,disp->_height,0,0,0,&(disp->_ccs));
        disp->_window_x = disp->_window_y = 0;
      }
      SetForegroundWindow(disp->_window);
      disp->_hdc = GetDC(disp->_window);
      disp->_window_width = disp->_width;
      disp->_window_height = disp->_height;
      disp->flush();
#ifdef _WIN64
      SetWindowLongPtr(disp->_window,GWLP_USERDATA,(LONG_PTR)disp);
      SetWindowLongPtr(disp->_window,GWLP_WNDPROC,(LONG_PTR)_handle_events);
#else
# 8953 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      SetWindowLong(disp->_window,GWL_USERDATA,(LONG)disp);
      SetWindowLong(disp->_window,GWL_WNDPROC,(LONG)_handle_events);
#endif
# 8956 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      SetEvent(disp->_is_created);
      while (GetMessage(&msg,0,0,0)) DispatchMessage(&msg);
      return 0;
    }

    CImgDisplay& _update_window_pos() {
      if (_is_closed) _window_x = _window_y = -1;
      else {
        RECT rect;
        rect.left = rect.top = 0; rect.right = _width-1; rect.bottom = _height-1;
        AdjustWindowRect(&rect,WS_CAPTION | WS_SYSMENU | WS_THICKFRAME | WS_MINIMIZEBOX | WS_MAXIMIZEBOX,false);
        const int
          border1 = (rect.right - rect.left + 1 - _width)/2,
          border2 = rect.bottom - rect.top + 1 - _height - border1;
        GetWindowRect(_window,&rect);
        _window_x = rect.left + border1;
        _window_y = rect.top + border2;
      }
      return *this;
    }

    void _init_fullscreen() {
      _background_window = 0;
      if (!_is_fullscreen || _is_closed) _curr_mode.dmSize = 0;
      else {
        DEVMODE mode;
        unsigned int imode = 0, ibest = 0, bestbpp = 0, bw = ~0U, bh = ~0U;
        for (mode.dmSize = sizeof(DEVMODE), mode.dmDriverExtra = 0; EnumDisplaySettings(0,imode,&mode); ++imode) {
          const unsigned int nw = mode.dmPelsWidth, nh = mode.dmPelsHeight;
          if (nw>=_width && nh>=_height && mode.dmBitsPerPel>=bestbpp && nw<=bw && nh<=bh) {
            bestbpp = mode.dmBitsPerPel;
            ibest = imode;
            bw = nw; bh = nh;
          }
        }
        if (bestbpp) {
          _curr_mode.dmSize = sizeof(DEVMODE); _curr_mode.dmDriverExtra = 0;
          EnumDisplaySettings(0,ENUM_CURRENT_SETTINGS,&_curr_mode);
          EnumDisplaySettings(0,ibest,&mode);
          ChangeDisplaySettings(&mode,0);
        } else _curr_mode.dmSize = 0;

        const unsigned int sx = screen_width(), sy = screen_height();
        if (sx!=_width || sy!=_height) {
          CLIENTCREATESTRUCT background_ccs;
          _background_window = CreateWindowA("MDICLIENT","",WS_POPUP | WS_VISIBLE, 0,0,sx,sy,0,0,0,&background_ccs);
          SetForegroundWindow(_background_window);
        }
      }
    }

    void _desinit_fullscreen() {
      if (!_is_fullscreen) return;
      if (_background_window) DestroyWindow(_background_window);
      _background_window = 0;
      if (_curr_mode.dmSize) ChangeDisplaySettings(&_curr_mode,0);
      _is_fullscreen = false;
    }

    CImgDisplay& _assign(const unsigned int dimw, const unsigned int dimh, const char *const ptitle=0,
                         const unsigned int normalization_type=3,
                         const bool fullscreen_flag=false, const bool closed_flag=false) {

      // Allocate space for window title
      const char *const nptitle = ptitle?ptitle:"";
      const unsigned int s = (unsigned int)std::strlen(nptitle) + 1;
      char *const tmp_title = s?new char[s]:0;
      if (s) std::memcpy(tmp_title,nptitle,s*sizeof(char));

      // Destroy previous window if existing
      if (!is_empty()) assign();

      // Set display variables
      _width = cimg::min(dimw,(unsigned int)screen_width());
      _height = cimg::min(dimh,(unsigned int)screen_height());
      _normalization = normalization_type<4?normalization_type:3;
      _is_fullscreen = fullscreen_flag;
      _window_x = _window_y = 0;
      _is_closed = closed_flag;
      _is_cursor_visible = true;
      _is_mouse_tracked = false;
      _title = tmp_title;
      flush();
      if (_is_fullscreen) _init_fullscreen();

      // Create event thread
      void *const arg = (void*)(new void*[2]);
      ((void**)arg)[0] = (void*)this;
      ((void**)arg)[1] = (void*)_title;
      _mutex = CreateMutex(0,FALSE,0);
      _is_created = CreateEvent(0,FALSE,FALSE,0);
      _thread = CreateThread(0,0,_events_thread,arg,0,0);
      WaitForSingleObject(_is_created,INFINITE);
      return *this;
    }

    CImgDisplay& assign() {
      if (is_empty()) return flush();
      DestroyWindow(_window);
      TerminateThread(_thread,0);
      delete[] _data;
      delete[] _title;
      _data = 0;
      _title = 0;
      if (_is_fullscreen) _desinit_fullscreen();
      _width = _height = _normalization = _window_width = _window_height = 0;
      _window_x = _window_y = 0;
      _is_fullscreen = false;
      _is_closed = true;
      _min = _max = 0;
      _title = 0;
      flush();
      return *this;
    }

    CImgDisplay& assign(const unsigned int dimw, const unsigned int dimh, const char *const title=0,
                        const unsigned int normalization_type=3,
                        const bool fullscreen_flag=false, const bool closed_flag=false) {
      if (!dimw || !dimh) return assign();
      _assign(dimw,dimh,title,normalization_type,fullscreen_flag,closed_flag);
      _min = _max = 0;
      std::memset(_data,0,sizeof(unsigned int)*_width*_height);
      return paint();
    }

    template<typename T>
    CImgDisplay& assign(const CImg<T>& img, const char *const title=0,
                        const unsigned int normalization_type=3,
                        const bool fullscreen_flag=false, const bool closed_flag=false) {
      if (!img) return assign();
      CImg<T> tmp;
      const CImg<T>& nimg = (img._depth==1)?img:(tmp=img.get_projections2d((img._width-1)/2,(img._height-1)/2,(img._depth-1)/2));
      _assign(nimg._width,nimg._height,title,normalization_type,fullscreen_flag,closed_flag);
      if (_normalization==2) _min = (float)nimg.min_max(_max);
      return display(nimg);
    }

    template<typename T>
    CImgDisplay& assign(const CImgList<T>& list, const char *const title=0,
                        const unsigned int normalization_type=3,
                        const bool fullscreen_flag=false, const bool closed_flag=false) {
      if (!list) return assign();
      CImg<T> tmp;
      const CImg<T> img = list>'x', &nimg = (img._depth==1)?img:(tmp=img.get_projections2d((img._width-1)/2,(img._height-1)/2,(img._depth-1)/2));
      _assign(nimg._width,nimg._height,title,normalization_type,fullscreen_flag,closed_flag);
      if (_normalization==2) _min = (float)nimg.min_max(_max);
      return display(nimg);
    }

    CImgDisplay& assign(const CImgDisplay& disp) {
      if (!disp) return assign();
      _assign(disp._width,disp._height,disp._title,disp._normalization,disp._is_fullscreen,disp._is_closed);
      std::memcpy(_data,disp._data,sizeof(unsigned int)*_width*_height);
      return paint();
    }

    CImgDisplay& resize(const int nwidth, const int nheight, const bool force_redraw=true) {
      if (!nwidth || !nheight || (is_empty() && (nwidth<0 || nheight<0))) return assign();
      if (is_empty()) return assign(nwidth,nheight);
      const unsigned int
        tmpdimx = (nwidth>0)?nwidth:(-nwidth*_width/100),
        tmpdimy = (nheight>0)?nheight:(-nheight*_height/100),
        dimx = tmpdimx?tmpdimx:1,
        dimy = tmpdimy?tmpdimy:1;
      if (_window_width!=dimx || _window_height!=dimy) {
        RECT rect; rect.left = rect.top = 0; rect.right = dimx - 1; rect.bottom = dimy - 1;
        AdjustWindowRect(&rect,WS_CAPTION | WS_SYSMENU | WS_THICKFRAME | WS_MINIMIZEBOX | WS_MAXIMIZEBOX,false);
        const int cwidth = rect.right - rect.left + 1, cheight = rect.bottom - rect.top + 1;
        SetWindowPos(_window,0,0,0,cwidth,cheight,SWP_NOMOVE | SWP_NOZORDER | SWP_NOCOPYBITS);
      }
      if (_width!=dimx || _height!=dimy) {
        unsigned int *const ndata = new unsigned int[dimx*dimy];
        if (force_redraw) _render_resize(_data,_width,_height,ndata,dimx,dimy);
        else std::memset(ndata,0x80,sizeof(unsigned int)*dimx*dimy);
        delete[] _data;
        _data = ndata;
        _bmi.bmiHeader.biWidth = dimx;
        _bmi.bmiHeader.biHeight = -(int)dimy;
        _width = dimx;
        _height = dimy;
      }
      _window_width = dimx; _window_height = dimy;
      _is_resized = false;
      if (_is_fullscreen) move((screen_width()-_width)/2,(screen_height()-_height)/2);
      if (force_redraw) return paint();
      return *this;
    }

    CImgDisplay& toggle_fullscreen(const bool force_redraw=true) {
      if (is_empty()) return *this;
      if (force_redraw) {
        const unsigned long buf_size = _width*_height*4UL;
        void *odata = std::malloc(buf_size);
        std::memcpy(odata,_data,buf_size);
        assign(_width,_height,_title,_normalization,!_is_fullscreen,false);
        std::memcpy(_data,odata,buf_size);
        std::free(odata);
        return paint();
      }
      return assign(_width,_height,_title,_normalization,!_is_fullscreen,false);
    }

    CImgDisplay& show() {
      if (is_empty() || !_is_closed) return *this;
      _is_closed = false;
      if (_is_fullscreen) _init_fullscreen();
      ShowWindow(_window,SW_SHOW);
      _update_window_pos();
      return paint();
    }

    CImgDisplay& close() {
      if (is_empty() || _is_closed) return *this;
      _is_closed = true;
      if (_is_fullscreen) _desinit_fullscreen();
      ShowWindow(_window,SW_HIDE);
      _window_x = _window_y = 0;
      return *this;
    }

    CImgDisplay& move(const int posx, const int posy) {
      if (is_empty()) return *this;
      if (!_is_fullscreen) {
        RECT rect; rect.left = rect.top = 0; rect.right = _window_width-1; rect.bottom = _window_height-1;
        AdjustWindowRect(&rect,WS_CAPTION | WS_SYSMENU | WS_THICKFRAME | WS_MINIMIZEBOX | WS_MAXIMIZEBOX,false);
        const int border1 = (rect.right-rect.left+1-_width)/2, border2 = rect.bottom-rect.top+1-_height-border1;
        SetWindowPos(_window,0,posx-border1,posy-border2,0,0,SWP_NOSIZE | SWP_NOZORDER);
      } else SetWindowPos(_window,0,posx,posy,0,0,SWP_NOSIZE | SWP_NOZORDER);
      _window_x = posx;
      _window_y = posy;
      _is_moved = false;
      return show();
    }

    CImgDisplay& show_mouse() {
      if (is_empty()) return *this;
      _is_cursor_visible = true;
      SendMessage(_window,WM_SETCURSOR,0,0);
      return *this;
    }

    CImgDisplay& hide_mouse() {
      if (is_empty()) return *this;
      _is_cursor_visible = false;
      SendMessage(_window,WM_SETCURSOR,0,0);
      return *this;
    }

    CImgDisplay& set_mouse(const int posx, const int posy) {
      if (_is_closed || posx<0 || posy<0) return *this;
      _update_window_pos();
      const int res = (int)SetCursorPos(_window_x + posx,_window_y + posy);
      if (res) { _mouse_x = posx; _mouse_y = posy; }
      return *this;
    }

    CImgDisplay& set_title(const char *const format, ...) {
      if (is_empty()) return *this;
      char tmp[1024] = { 0 };
      va_list ap;
      va_start(ap, format);
      cimg_vsnprintf(tmp,sizeof(tmp),format,ap);
      va_end(ap);
      if (!std::strcmp(_title,tmp)) return *this;
      delete[] _title;
      const unsigned int s = (unsigned int)std::strlen(tmp) + 1;
      _title = new char[s];
      std::memcpy(_title,tmp,s*sizeof(char));
      SetWindowTextA(_window, tmp);
      return *this;
    }

    template<typename T>
    CImgDisplay& display(const CImg<T>& img) {
      if (!img)
        throw CImgArgumentException(_cimgdisplay_instance
                                    "display(): Empty specified image.",
                                    cimgdisplay_instance);
      if (is_empty()) return assign(img);
      return render(img).paint();
    }

    CImgDisplay& paint() {
      if (_is_closed) return *this;
      WaitForSingleObject(_mutex,INFINITE);
      SetDIBitsToDevice(_hdc,0,0,_width,_height,0,0,0,_height,_data,&_bmi,DIB_RGB_COLORS);
      ReleaseMutex(_mutex);
      return *this;
    }

    template<typename T>
    CImgDisplay& render(const CImg<T>& img) {
      if (!img)
        throw CImgArgumentException(_cimgdisplay_instance
                                    "render(): Empty specified image.",
                                    cimgdisplay_instance);

      if (is_empty()) return *this;
      if (img._depth!=1) return render(img.get_projections2d((img._width-1)/2,(img._height-1)/2,(img._depth-1)/2));

      const T
        *data1 = img._data,
        *data2 = (img._spectrum>=2)?img.data(0,0,0,1):data1,
        *data3 = (img._spectrum>=3)?img.data(0,0,0,2):data1;

      WaitForSingleObject(_mutex,INFINITE);
      unsigned int
        *const ndata = (img._width==_width && img._height==_height)?_data:new unsigned int[(unsigned long)img._width*img._height],
        *ptrd = ndata;

      if (!_normalization || (_normalization==3 && cimg::type<T>::string()==cimg::type<unsigned char>::string())) {
        _min = _max = 0;
        switch (img._spectrum) {
        case 1 : {
          for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
            const unsigned char val = (unsigned char)*(data1++);
            *(ptrd++) = (val<<16) | (val<<8) | val;
          }
        } break;
        case 2 : {
          for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy)
            *(ptrd++) = ((unsigned char)*(data1++)<<16) | ((unsigned char)*(data2++)<<8);
        } break;
        default : {
          for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy)
            *(ptrd++) = ((unsigned char)*(data1++)<<16) | ((unsigned char)*(data2++)<<8) | (unsigned char)*(data3++);
        }
        }
      } else {
        if (_normalization==3) {
          if (cimg::type<T>::is_float()) _min = (float)img.min_max(_max);
          else { _min = (float)cimg::type<T>::min(); _max = (float)cimg::type<T>::max(); }
        } else if ((_min>_max) || _normalization==1) _min = (float)img.min_max(_max);
        const float delta = _max - _min, mm = 255/(delta?delta:1.0f);
        switch (img._spectrum) {
        case 1 : {
          for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
            const unsigned char val = (unsigned char)((*(data1++)-_min)*mm);
            *(ptrd++) = (val<<16) | (val<<8) | val;
          }
        } break;
        case 2 : {
          for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
            const unsigned char
              R = (unsigned char)((*(data1++)-_min)*mm),
              G = (unsigned char)((*(data2++)-_min)*mm);
            *(ptrd++) = (R<<16) | (G<<8);
          }
        } break;
        default : {
          for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
            const unsigned char
              R = (unsigned char)((*(data1++)-_min)*mm),
              G = (unsigned char)((*(data2++)-_min)*mm),
              B = (unsigned char)((*(data3++)-_min)*mm);
            *(ptrd++) = (R<<16) | (G<<8) | B;
          }
        }
        }
      }
      if (ndata!=_data) { _render_resize(ndata,img._width,img._height,_data,_width,_height); delete[] ndata; }
      ReleaseMutex(_mutex);
      return *this;
    }

    template<typename T>
    const CImgDisplay& snapshot(CImg<T>& img) const {
      if (is_empty()) { img.assign(); return *this; }
      const unsigned int *ptrs = _data;
      img.assign(_width,_height,1,3);
      T
        *data1 = img.data(0,0,0,0),
        *data2 = img.data(0,0,0,1),
        *data3 = img.data(0,0,0,2);
      for (unsigned long xy = (unsigned long)img._width*img._height; xy>0; --xy) {
        const unsigned int val = *(ptrs++);
        *(data1++) = (T)(unsigned char)(val>>16);
        *(data2++) = (T)(unsigned char)((val>>8)&0xFF);
        *(data3++) = (T)(unsigned char)(val&0xFF);
      }
      return *this;
    }
#endif
# 9339 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    //@}
  };

  /*
   #--------------------------------------
   #
   #
   #
   # Definition of the CImg<T> structure
   #
   #
   #
   #--------------------------------------
   */

  //! Class representing an image (up to 4 dimensions wide), each pixel being of type \c T.
  /**
     This is the main class of the %CImg Library. It declares and constructs
     an image, allows access to its pixel values, and is able to perform various image operations.

     \par Image representation

     A %CImg image is defined as an instance of the container \c CImg<T>, which contains a regular grid of pixels,
     each pixel value being of type \c T. The image grid can have up to 4 dimensions: width, height, depth
     and number of channels.
     Usually, the three first dimensions are used to describe spatial coordinates <tt>(x,y,z)</tt>, while the number of channels
     is rather used as a vector-valued dimension (it may describe the R,G,B color channels for instance).
     If you need a fifth dimension, you can use image lists \c CImgList<T> rather than simple images \c CImg<T>.

     Thus, the \c CImg<T> class is able to represent volumetric images of vector-valued pixels,
     as well as images with less dimensions (1d scalar signal, 2d color images, ...).
     Most member functions of the class CImg<\c T> are designed to handle this maximum case of (3+1) dimensions.

     Concerning the pixel value type \c T:
     fully supported template types are the basic C++ types: <tt>unsigned char, char, short, unsigned int, int,
     unsigned long, long, float, double, ... </tt>.
     Typically, fast image display can be done using <tt>CImg<unsigned char></tt> images,
     while complex image processing algorithms may be rather coded using <tt>CImg<float></tt> or <tt>CImg<double></tt>
     images that have floating-point pixel values. The default value for the template T is \c float.
     Using your own template types may be possible. However, you will certainly have to define the complete set
     of arithmetic and logical operators for your class.

     \par Image structure

     The \c CImg<T> structure contains \e six fields:
     - \c _width defines the number of \a columns of the image (size along the X-axis).
     - \c _height defines the number of \a rows of the image (size along the Y-axis).
     - \c _depth defines the number of \a slices of the image (size along the Z-axis).
     - \c _spectrum defines the number of \a channels of the image (size along the C-axis).
     - \c _data defines a \a pointer to the \a pixel \a data (of type \c T).
     - \c _is_shared is a boolean that tells if the memory buffer \c data is shared with
       another image.

     You can access these fields publicly although it is recommended to use the dedicated functions
     width(), height(), depth(), spectrum() and ptr() to do so.
     Image dimensions are not limited to a specific range (as long as you got enough available memory).
     A value of \e 1 usually means that the corresponding dimension is \a flat.
     If one of the dimensions is \e 0, or if the data pointer is null, the image is considered as \e empty.
     Empty images should not contain any pixel data and thus, will not be processed by CImg member functions
     (a CImgInstanceException will be thrown instead).
     Pixel data are stored in memory, in a non interlaced mode (See \ref cimg_storage).

     \par Image declaration and construction

     Declaring an image can be done by using one of the several available constructors.
     Here is a list of the most used:

     - Construct images from arbitrary dimensions:
         - <tt>CImg<char> img;</tt> declares an empty image.
         - <tt>CImg<unsigned char> img(128,128);</tt> declares a 128x128 greyscale image with
         \c unsigned \c char pixel values.
         - <tt>CImg<double> img(3,3);</tt> declares a 3x3 matrix with \c double coefficients.
         - <tt>CImg<unsigned char> img(256,256,1,3);</tt> declares a 256x256x1x3 (color) image
         (colors are stored as an image with three channels).
         - <tt>CImg<double> img(128,128,128);</tt> declares a 128x128x128 volumetric and greyscale image
         (with \c double pixel values).
         - <tt>CImg<> img(128,128,128,3);</tt> declares a 128x128x128 volumetric color image
         (with \c float pixels, which is the default value of the template parameter \c T).
         - \b Note: images pixels are <b>not automatically initialized to 0</b>. You may use the function \c fill() to
         do it, or use the specific constructor taking 5 parameters like this:
         <tt>CImg<> img(128,128,128,3,0);</tt> declares a 128x128x128 volumetric color image with all pixel values to 0.

     - Construct images from filenames:
         - <tt>CImg<unsigned char> img("image.jpg");</tt> reads a JPEG color image from the file "image.jpg".
         - <tt>CImg<float> img("analyze.hdr");</tt> reads a volumetric image (ANALYZE7.5 format) from the file "analyze.hdr".
         - \b Note: You need to install <a href="http://www.imagemagick.org">ImageMagick</a>
         to be able to read common compressed image formats (JPG,PNG, ...) (See \ref cimg_files_io).

     - Construct images from C-style arrays:
         - <tt>CImg<int> img(data_buffer,256,256);</tt> constructs a 256x256 greyscale image from a \c int* buffer
         \c data_buffer (of size 256x256=65536).
         - <tt>CImg<unsigned char> img(data_buffer,256,256,1,3,false);</tt> constructs a 256x256 color image
         from a \c unsigned \c char* buffer \c data_buffer (where R,G,B channels follow each others).
         - <tt>CImg<unsigned char> img(data_buffer,256,256,1,3,true);</tt> constructs a 256x256 color image
         from a \c unsigned \c char* buffer \c data_buffer (where R,G,B channels are multiplexed).

         The complete list of constructors can be found <a href="#constructors">here</a>.

     \par Most useful functions

     The \c CImg<T> class contains a lot of functions that operates on images.
     Some of the most useful are:

     - operator()(): allows to access or write pixel values.
     - display(): displays the image in a new window.
  **/
  template<typename T>
  struct CImg {

    unsigned int _width, _height, _depth, _spectrum;
    bool _is_shared;
    T *_data;

    //! Simple iterator type, to loop through each pixel value of an image instance.
    /**
       \note
       - The \c CImg<T>::iterator type is defined to be a <tt>T*</tt>.
       - You will seldom have to use iterators in %CImg, most classical operations
         being achieved (often in a faster way) using methods of \c CImg<T>.
       \par Example
       \code
       CImg<float> img("reference.jpg");                                         // Load image from file.
       for (CImg<float>::iterator it = img.begin(), it<img.end(); ++it) *it = 0; // Set all pixels to '0', through a CImg iterator.
       img.fill(0);                                                              // Do the same with a built-in method.
       \endcode
   **/
    typedef T* iterator;

    //! Simple const iterator type, to loop through each pixel value of a \c const image instance.
    /**
       \note
       - The \c CImg<T>::const_iterator type is defined to be a \c const \c T*.
       - You will seldom have to use iterators in %CImg, most classical operations
         being achieved (often in a faster way) using methods of \c CImg<T>.
       \par Example
       \code
       const CImg<float> img("reference.jpg");                                    // Load image from file.
       float sum = 0;
       for (CImg<float>::iterator it = img.begin(), it<img.end(); ++it) sum+=*it; // Compute sum of all pixel values, through a CImg iterator.
       const float sum2 = img.sum();                                              // Do the same with a built-in method.
       \endcode
    **/
    typedef const T* const_iterator;

    //! Pixel value type.
    /**
       Refer to the type of the pixel values of an image instance.
       \note
       - The \c CImg<T>::value_type type of a \c CImg<T> is defined to be a \c T.
       - \c CImg<T>::value_type is actually not used in %CImg methods. It has been mainly defined for
         compatibility with STL naming conventions.
    **/
    typedef T value_type;

    // Define common types related to template type T.
    typedef typename cimg::superset<T,bool>::type Tbool;
    typedef typename cimg::superset<T,unsigned char>::type Tuchar;
    typedef typename cimg::superset<T,char>::type Tchar;
    typedef typename cimg::superset<T,unsigned short>::type Tushort;
    typedef typename cimg::superset<T,short>::type Tshort;
    typedef typename cimg::superset<T,unsigned int>::type Tuint;
    typedef typename cimg::superset<T,int>::type Tint;
    typedef typename cimg::superset<T,unsigned long>::type Tulong;
    typedef typename cimg::superset<T,long>::type Tlong;
    typedef typename cimg::superset<T,float>::type Tfloat;
    typedef typename cimg::superset<T,double>::type Tdouble;
    typedef typename cimg::last<T,bool>::type boolT;
    typedef typename cimg::last<T,unsigned char>::type ucharT;
    typedef typename cimg::last<T,char>::type charT;
    typedef typename cimg::last<T,unsigned short>::type ushortT;
    typedef typename cimg::last<T,short>::type shortT;
    typedef typename cimg::last<T,unsigned int>::type uintT;
    typedef typename cimg::last<T,int>::type intT;
    typedef typename cimg::last<T,unsigned long>::type ulongT;
    typedef typename cimg::last<T,long>::type longT;
    typedef typename cimg::last<T,float>::type floatT;
    typedef typename cimg::last<T,double>::type doubleT;

    //@}
    //---------------------------
    //
    //! \name Plugins
    //@{
    //---------------------------
#ifdef cimg_plugin
#if 0 /* expanded by -frewrite-includes */
#include cimg_plugin
#endif /* expanded by -frewrite-includes */
# 1 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp" 1
/*
 #
 #  File        : gmic.cpp
 #                ( C++ source file )
 #
 #  Description : GREYC's Magic for Image Computing - G'MIC Language interpreter
 #                ( http://gmic.sourceforge.net )
 #                This file is also a part of the CImg Library project.
 #                ( http://cimg.sourceforge.net )
 #
 #  Copyright   : David Tschumperle
 #                ( http://tschumperle.users.greyc.fr/ )
 #
 #  License     : CeCILL v2.0
 #                ( http://www.cecill.info/licences/Licence_CeCILL_V2-en.html )
 #
 #  This software is governed by the CeCILL  license under French law and
 #  abiding by the rules of distribution of free software.  You can  use,
 #  modify and/ or redistribute the software under the terms of the CeCILL
 #  license as circulated by CEA, CNRS and INRIA at the following URL
 #  "http://www.cecill.info".
 #
 #  As a counterpart to the access to the source code and  rights to copy,
 #  modify and redistribute granted by the license, users are provided only
 #  with a limited warranty  and the software's author,  the holder of the
 #  economic rights,  and the successive licensors  have only  limited
 #  liability.
 #
 #  In this respect, the user's attention is drawn to the risks associated
 #  with loading,  using,  modifying and/or developing or reproducing the
 #  software by the user in light of its specific status of free software,
 #  that may mean  that it is complicated to manipulate,  and  that  also
 #  therefore means  that it is reserved for developers  and  experienced
 #  professionals having in-depth computer knowledge. Users are therefore
 #  encouraged to load and test the software's suitability as regards their
 #  requirements in conditions enabling the security of their systems and/or
 #  data to be ensured and,  more generally, to use and operate it in the
 #  same conditions as regards security.
 #
 #  The fact that you are presently reading this means that you have had
 #  knowledge of the CeCILL license and that you accept its terms.
 #
*/

// Add G'MIC-specific methods to the CImg library.
//------------------------------------------------
#ifdef cimg_plugin

// Additional arithmetic/boolean operators.

template<typename t>
CImg<T>& operator_eq(const t val) {
  cimg_for(*this,ptrd,T) *ptrd = (T)(*ptrd == (T)val);
  return *this;
}

CImg<T>& operator_eq(const char *const expression) {
  const unsigned int omode = cimg::exception_mode();
  cimg::exception_mode() = 0;
  try {
    const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(),
      &base = _base?_base:*this;
    _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator_eq");
    T *ptrd = *expression=='<'?end()-1:_data;
    if (*expression=='<')
      cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd == (T)mp.eval(x,y,z,c)); --ptrd; }
    else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd == (T)mp.eval(x,y,z,c)); ++ptrd; }
  } catch (CImgException&) {
    cimg::exception_mode() = omode;
    CImg<T> values(_width,_height,_depth,_spectrum);
    values = expression;
    operator_eq(values);
  }
  cimg::exception_mode() = omode;
  return *this;
}

template<typename t>
CImg<T>& operator_eq(const CImg<t>& img) {
  const unsigned long siz = size(), isiz = img.size();
  if (siz && isiz) {
    if (is_overlapped(img)) return operator_eq(+img);
    T *ptrd = _data, *const ptre = _data + siz;
    if (siz>isiz)
      for (unsigned long n = siz/isiz; n; --n)
        for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd)
          *ptrd = (T)(*ptrd == (T)*(ptrs++));
    for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)(*ptrd == (T)*(ptrs++));
  }
  return *this;
}

template<typename t>
CImg<T>& operator_neq(const t val) {
  cimg_for(*this,ptrd,T) *ptrd = (T)(*ptrd != (T)val);
  return *this;
}

CImg<T>& operator_neq(const char *const expression) {
  const unsigned int omode = cimg::exception_mode();
  cimg::exception_mode() = 0;
  try {
    const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(),
      &base = _base?_base:*this;
    _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator_neq");
    T *ptrd = *expression=='<'?end()-1:_data;
    if (*expression=='<')
      cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd != (T)mp.eval(x,y,z,c)); --ptrd; }
    else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd != (T)mp.eval(x,y,z,c)); ++ptrd; }
  } catch (CImgException&) {
    cimg::exception_mode() = omode;
    CImg<T> values(_width,_height,_depth,_spectrum);
    values = expression;
    operator_neq(values);
  }
  cimg::exception_mode() = omode;
  return *this;
}

template<typename t>
CImg<T>& operator_neq(const CImg<t>& img) {
  const unsigned long siz = size(), isiz = img.size();
  if (siz && isiz) {
    if (is_overlapped(img)) return operator_neq(+img);
    T *ptrd = _data, *const ptre = _data + siz;
    if (siz>isiz)
      for (unsigned long n = siz/isiz; n; --n)
        for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd)
          *ptrd = (T)(*ptrd != (T)*(ptrs++));
    for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)(*ptrd != (T)*(ptrs++));
  }
  return *this;
}

template<typename t>
CImg<T>& operator_gt(const t val) {
  cimg_for(*this,ptrd,T) *ptrd = (T)(*ptrd > (T)val);
  return *this;
}

CImg<T>& operator_gt(const char *const expression) {
  const unsigned int omode = cimg::exception_mode();
  cimg::exception_mode() = 0;
  try {
    const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(),
      &base = _base?_base:*this;
    _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator_gt");
    T *ptrd = *expression=='<'?end()-1:_data;
    if (*expression=='<')
      cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd > (T)mp.eval(x,y,z,c)); --ptrd; }
    else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd > (T)mp.eval(x,y,z,c)); ++ptrd; }
  } catch (CImgException&) {
    cimg::exception_mode() = omode;
    CImg<T> values(_width,_height,_depth,_spectrum);
    values = expression;
    operator_gt(values);
  }
  cimg::exception_mode() = omode;
  return *this;
}

template<typename t>
CImg<T>& operator_gt(const CImg<t>& img) {
  const unsigned long siz = size(), isiz = img.size();
  if (siz && isiz) {
    if (is_overlapped(img)) return operator_gt(+img);
    T *ptrd = _data, *const ptre = _data + siz;
    if (siz>isiz)
      for (unsigned long n = siz/isiz; n; --n)
        for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd)
          *ptrd = (T)(*ptrd > (T)*(ptrs++));
    for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)(*ptrd > (T)*(ptrs++));
  }
  return *this;
}

template<typename t>
CImg<T>& operator_ge(const t val) {
  cimg_for(*this,ptrd,T) *ptrd = (T)(*ptrd >= (T)val);
  return *this;
}

CImg<T>& operator_ge(const char *const expression) {
  const unsigned int omode = cimg::exception_mode();
  cimg::exception_mode() = 0;
  try {
    const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(),
      &base = _base?_base:*this;
    _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator_ge");
    T *ptrd = *expression=='<'?end()-1:_data;
    if (*expression=='<')
      cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd >= (T)mp.eval(x,y,z,c)); --ptrd; }
    else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd >= (T)mp.eval(x,y,z,c)); ++ptrd; }
  } catch (CImgException&) {
    cimg::exception_mode() = omode;
    CImg<T> values(_width,_height,_depth,_spectrum);
    values = expression;
    operator_ge(values);
  }
  cimg::exception_mode() = omode;
  return *this;
}

template<typename t>
CImg<T>& operator_ge(const CImg<t>& img) {
  const unsigned long siz = size(), isiz = img.size();
  if (siz && isiz) {
    if (is_overlapped(img)) return operator_ge(+img);
    T *ptrd = _data, *const ptre = _data + siz;
    if (siz>isiz)
      for (unsigned long n = siz/isiz; n; --n)
        for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd)
          *ptrd = (T)(*ptrd >= (T)*(ptrs++));
    for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)(*ptrd >= (T)*(ptrs++));
  }
  return *this;
}

template<typename t>
CImg<T>& operator_lt(const t val) {
  cimg_for(*this,ptrd,T) *ptrd = (T)(*ptrd < (T)val);
  return *this;
}

CImg<T>& operator_lt(const char *const expression) {
  const unsigned int omode = cimg::exception_mode();
  cimg::exception_mode() = 0;
  try {
    const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(),
      &base = _base?_base:*this;
    _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator_lt");
    T *ptrd = *expression=='<'?end()-1:_data;
    if (*expression=='<')
      cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd < (T)mp.eval(x,y,z,c)); --ptrd; }
    else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd < (T)mp.eval(x,y,z,c)); ++ptrd; }
  } catch (CImgException&) {
    cimg::exception_mode() = omode;
    CImg<T> values(_width,_height,_depth,_spectrum);
    values = expression;
    operator_lt(values);
  }
  cimg::exception_mode() = omode;
  return *this;
}

template<typename t>
CImg<T>& operator_lt(const CImg<t>& img) {
  const unsigned long siz = size(), isiz = img.size();
  if (siz && isiz) {
    if (is_overlapped(img)) return operator_lt(+img);
    T *ptrd = _data, *const ptre = _data + siz;
    if (siz>isiz)
      for (unsigned long n = siz/isiz; n; --n)
        for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd)
          *ptrd = (T)(*ptrd < (T)*(ptrs++));
    for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)(*ptrd < (T)*(ptrs++));
  }
  return *this;
}

template<typename t>
CImg<T>& operator_le(const t val) {
  cimg_for(*this,ptrd,T) *ptrd = (T)(*ptrd <= (T)val);
  return *this;
}

CImg<T>& operator_le(const char *const expression) {
  const unsigned int omode = cimg::exception_mode();
  cimg::exception_mode() = 0;
  try {
    const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(),
      &base = _base?_base:*this;
    _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator_le");
    T *ptrd = *expression=='<'?end()-1:_data;
    if (*expression=='<')
      cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd <= (T)mp.eval(x,y,z,c)); --ptrd; }
    else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd <= (T)mp.eval(x,y,z,c)); ++ptrd; }
  } catch (CImgException&) {
    cimg::exception_mode() = omode;
    CImg<T> values(_width,_height,_depth,_spectrum);
    values = expression;
    operator_le(values);
  }
  cimg::exception_mode() = omode;
  return *this;
}

template<typename t>
CImg<T>& operator_le(const CImg<t>& img) {
  const unsigned long siz = size(), isiz = img.size();
  if (siz && isiz) {
    if (is_overlapped(img)) return operator_le(+img);
    T *ptrd = _data, *const ptre = _data + siz;
    if (siz>isiz)
      for (unsigned long n = siz/isiz; n; --n)
        for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd)
          *ptrd = (T)(*ptrd <= (T)*(ptrs++));
    for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)(*ptrd <= (T)*(ptrs++));
  }
  return *this;
}

CImg<T>& mul(const char *const expression) {
  return operator*=(expression);
}

CImg<T> get_mul(const char *const expression) const {
  return (+*this).mul(expression);
}

CImg<T>& div(const char *const expression) {
  return operator/=(expression);
}

CImg<T> get_div(const char *const expression) const {
  return (+*this).div(expression);
}

template<typename t>
const CImg<T>& gmic_symmetric_eigen(CImg<t>& val, CImg<t>& vec) const {
  if (spectrum()!=3 && spectrum()!=6) return symmetric_eigen(val,vec);
  val.assign(width(),height(),depth(),spectrum()==3?2:3);
  vec.assign(width(),height(),depth(),spectrum()==3?2:6);
  CImg<t> _val, _vec;
  cimg_forXYZ(*this,x,y,z) {
    get_tensor_at(x,y,z).symmetric_eigen(_val,_vec);
    val.set_vector_at(_val,x,y,z);
    if (spectrum()==3) {
      vec(x,y,z,0) = _vec(0,0);
      vec(x,y,z,1) = _vec(0,1);
    } else {
      vec(x,y,z,0) = _vec(0,0);
      vec(x,y,z,1) = _vec(0,1);
      vec(x,y,z,2) = _vec(0,2);

      vec(x,y,z,3) = _vec(1,0);
      vec(x,y,z,4) = _vec(1,1);
      vec(x,y,z,5) = _vec(1,2);
    }
  }
  return *this;
}

// Additional geometric and drawing operators.

template<typename t>
CImg<T>& replace(CImg<t>& img) {
  return img.move_to(*this);
}

template<typename t>
CImg<T> get_replace(const CImg<t>& img) const {
  return +img;
}

CImg<T>& gmic_autocrop(const CImg<T>& color=CImg<T>::empty()) {
  if (color.width()==1) autocrop(*color);
  else autocrop(color);
  return *this;
}

CImg<T> get_gmic_autocrop(const CImg<T>& color=CImg<T>::empty()) {
  return (+*this).gmic_autocrop(color);
}

CImg<T> get_gmic_set(const double value,
                     const int x, const int y, const int z, const int v) const {
  return (+*this).gmic_set(value,x,y,z,v);
}

CImg<T>& gmic_set(const double value,
                  const int x, const int y, const int z, const int v) {
  (*this).atXYZC(x,y,z,v,0) = (T)value;
  return *this;
}

CImg<T> get_draw_point(const int x, const int y, const int z, const T *const col,
                       const float opacity) const {
  return (+*this).draw_point(x,y,z,col,opacity);
}

CImg<T> get_draw_line(const int x0, const int y0, const int x1, const int y1, const T *const col,
                      const float opacity, const unsigned int pattern) const {
  return (+*this).draw_line(x0,y0,x1,y1,col,opacity,pattern);
}

template<typename t>
CImg<T> get_draw_polygon(const CImg<t>& pts, const T *const col, const float opacity) const {
  return (+*this).draw_polygon(pts,col,opacity);
}

template<typename t>
CImg<T> get_draw_polygon(const CImg<t>& pts, const T *const col, const float opacity,
                         const unsigned int pattern) const {
  return (+*this).draw_polygon(pts,col,opacity,pattern);
}

CImg<T> get_draw_circle(const int x, const int y, const int r, const T *const col,
                        const float opacity) const {
  return (+*this).draw_circle(x,y,r,col,opacity);
}

CImg<T> get_draw_circle(const int x, const int y, const int r, const T *const col,
                        const float opacity,
                        const unsigned int pattern) const {
  return (+*this).draw_circle(x,y,r,col,opacity,pattern);
}

CImg<T> get_draw_ellipse(const int x, const int y, const float r0, const float r1,
                         const float angle, const T *const col, const float opacity) const {
  return (+*this).draw_ellipse(x,y,r0,r1,angle,col,opacity);
}

CImg<T> get_draw_ellipse(const int x, const int y, const float r0, const float r1,
                         const float angle, const T *const col, const float opacity,
                         const unsigned int pattern) const {
  return (+*this).draw_ellipse(x,y,r0,r1,angle,col,opacity,pattern);
}

CImg<T>& gmic_draw_text(const int x, const int y,
                        const char *const text, const T *const col,
                        const int bg, const float opacity, const unsigned int siz,
                        const unsigned int nb_cols) {
  if (is_empty()) {
    const T one[] = { 1 };
    assign().draw_text(x,y,"%s",one,0,opacity,siz,text).resize(-100,-100,1,nb_cols);
    cimg_forC(*this,c) get_shared_channel(c)*=col[c];
  } else draw_text(x,y,"%s",col,bg,opacity,siz,text);
  return *this;
}

CImg<T> get_gmic_draw_text(const int x, const int y,
                           const char *const text, const T *const col,
                           const int bg, const float opacity, const unsigned int siz,
                           const unsigned int nb_cols) const {
  return (+*this).gmic_draw_text(x,y,text,col,bg,opacity,siz,nb_cols);
}

CImg<T> get_draw_image(const int x, const int y, const int z, const int c,
                       const CImg<T>& sprite, const CImg<T>& mask, const float opacity,
                       const float max_opacity_mask) const {
  return (+*this).draw_image(x,y,z,c,sprite,mask,opacity,max_opacity_mask);
}

CImg<T> get_draw_image(const int x, const int y, const int z, const int c,
                       const CImg<T>& sprite, const float opacity) const {
  return (+*this).draw_image(x,y,z,c,sprite,opacity);
}

CImg<T> get_draw_plasma(const float alpha, const float beta, const unsigned int scale) const {
  return (+*this).draw_plasma(alpha,beta,scale);
}

CImg<T> get_draw_mandelbrot(const CImg<T>& color_palette, const float opacity,
                            const double z0r, const double z0i, const double z1r, const double z1i,
                            const unsigned int itermax, const bool normalized_iteration,
                            const bool julia_set, const double paramr, const double parami) const {
  return (+*this).draw_mandelbrot(color_palette,opacity,z0r,z0i,z1r,z1i,itermax,
                                  normalized_iteration,julia_set,paramr,parami);
}

template<typename t, typename tc>
CImg<T> get_draw_graph(const CImg<t>& data,
                       const tc *const color, const float opacity=1,
                       const unsigned int plot_type=1, const int vertex_type=1,
                       const double ymin=0, const double ymax=0,
                       const unsigned int pattern=~0U) const {
  return (+*this).draw_graph(data,color,opacity,plot_type,vertex_type,ymin,ymax,pattern);
}

template<typename tc>
CImg<T> get_draw_axes(const float x0, const float x1, const float y0, const float y1,
                      const tc *const color, const float opacity=1,
                      const int subdivisionx=-60, const int subdivisiony=-60,
                      const float precisionx=0, const float precisiony=0,
                      const unsigned int patternx=~0U, const unsigned int patterny=~0U,
                      const unsigned int font_height=13) const {
  return (+*this).draw_axes(x0,x1,y0,y1,color,opacity,subdivisionx,subdivisiony,
                            precisionx,precisiony,patternx,patterny,font_height);
}

template<typename tc>
CImg<T> get_draw_grid(const float sizex, const float sizey,
                      const float offsetx, const float offsety,
                      const bool invertx, const bool inverty,
                      const tc *const color, const float opacity=1,
                      const unsigned int patternx=~0U, const unsigned int patterny=~0U) {
  return (+*this).draw_grid(sizex,sizey,offsetx,offsety,invertx,inverty,color,opacity,
                            patternx,patterny);
}

template<typename t1, typename t2>
CImg<T> get_draw_quiver(const CImg<t1>& flow,
                        const t2 *const color, const float opacity=1,
                        const unsigned int sampling=25, const float factor=-20,
                        const bool arrows=true, const unsigned int pattern=~0U) const {
  return (+*this).draw_quiver(flow,color,opacity,sampling,factor,arrows,pattern);
}

CImg<T> get_draw_fill(const int x, const int y, const int z,
                      const T *const col, const float opacity,
                      const float tolerance, const bool is_high_connectivity) const {
  return (+*this).draw_fill(x,y,z,col,opacity,tolerance,is_high_connectivity);
}

static bool is_almost(const T x, const T c) {
  return x>=c && x<c+1;
}

template<typename tp, typename tf, typename tc, typename to>
CImg<T> get_draw_object3d(const float x0, const float y0, const float z0,
                          const CImg<tp>& vertices, const CImgList<tf>& primitives,
                          const CImgList<tc>& colors, const CImgList<to>& opacities,
                          const unsigned int render_mode, const bool double_sided,
                          const float focale,
                          const float light_x, const float light_y,const float light_z,
                          const float specular_light, const float specular_shine,
                          CImg<floatT>& zbuffer) const {
  return (+*this).draw_object3d(x0,y0,z0,vertices,primitives,colors,opacities,render_mode,
                                double_sided,focale,light_x,light_y,light_z,specular_light,
                                specular_shine,zbuffer);
}

// Additional 3d objects operators.

CImgList<T> get_split_CImg3d() const {
  char error_message[1024] = { 0 };
  if (!is_CImg3d(false,error_message))
    throw CImgInstanceException(_cimg_instance
                                "get_split_CImg3d(): image instance is not a CImg3d (%s).",
                                cimg_instance,error_message);
  CImgList<T> res;
  const T *ptr0 = _data, *ptr = ptr0 + 6;
  CImg<T>(ptr0,1,ptr-ptr0,1,1).move_to(res); // Header.
  ptr0 = ptr;
  const unsigned int nbv = (unsigned int)*(ptr++), nbp = (unsigned int)*(ptr++);
  CImg<T>(ptr0,1,ptr-ptr0,1,1).move_to(res); // Nb vertices and primitives.
  ptr0 = ptr; ptr+=3*nbv;
  CImg<T>(ptr0,1,ptr-ptr0,1,1).move_to(res); // Vertices.
  ptr0 = ptr;
  for (unsigned int i = 0; i<nbp; ++i) ptr+=(unsigned int)(*ptr) + 1;
  CImg<T>(ptr0,1,ptr-ptr0,1,1).move_to(res); // Primitives.
  ptr0 = ptr;
  for (unsigned int i = 0; i<nbp; ++i) {
    const T val = *(ptr++);
    if (val!=-128) ptr+=2;
    else {
      const unsigned int
        w = (unsigned int)*(ptr++),
        h = (unsigned int)*(ptr++),
        s = (unsigned int)*(ptr++);
      if (w*h*s!=0) ptr+=w*h*s;
    }
  }
  CImg<T>(ptr0,1,ptr-ptr0,1,1).move_to(res); // Colors/Textures.
  ptr0 = ptr;
  for (unsigned int i = 0; i<nbp; ++i) {
    const T val = *(ptr++);
    if (val==-128) {
      const unsigned int
        w = (unsigned int)*(ptr++),
        h = (unsigned int)*(ptr++),
        s = (unsigned int)*(ptr++);
      if (w*h*s!=0) ptr+=w*h*s;
    }
  }
  CImg<T>(ptr0,1,ptr-ptr0,1,1).move_to(res); // Opacities.
  return res;
}

static CImg<T> append_CImg3d(const CImgList<T>& images) {
  if (!images) return CImg<T>();
  if (images.size()==1) return +images[0];
  char error_message[1024] = { 0 };
  unsigned int nbv = 0, nbp = 0;
  unsigned long siz = 0;
  cimglist_for(images,l) {
    const CImg<T>& img = images[l];
    if (!img.is_CImg3d(false,error_message))
      throw CImgArgumentException("append_CImg3d(): image [%d] (%u,%u,%u,%u,%p) "
                                  "is not a CImg3d (%s).",
                                  img._width,img._height,img._depth,img._spectrum,img._data,
                                  error_message);
    siz+=img.size() - 8;
    nbv+=cimg::float2uint((float)img[6]);
    nbp+=cimg::float2uint((float)img[7]);
  }

  CImg<T> res(1,siz + 8);
  const T **const ptrs = new const T*[images.size()];
  T *ptrd = res._data;
  *(ptrd++) = (T)('C' + 0.5f); *(ptrd++) = (T)('I' + 0.5f); // Create object header.
  *(ptrd++) = (T)('m' + 0.5f); *(ptrd++) = (T)('g' + 0.5f);
  *(ptrd++) = (T)('3' + 0.5f); *(ptrd++) = (T)('d' + 0.5f);
  *(ptrd++) = (T)nbv;
  *(ptrd++) = (T)nbp;
  cimglist_for(images,l) { // Merge object points.
    const CImg<T>& img = images[l];
    const unsigned int nbv = cimg::float2uint((float)img[6]);
    std::memcpy(ptrd,img._data + 8,3*nbv*sizeof(T));
    ptrd+=3*nbv;
    ptrs[l] = img._data + 8 + 3*nbv;
  }
  unsigned long poff = 0;
  cimglist_for(images,l) { // Merge object primitives.
    const unsigned int
      nbv = cimg::float2uint((float)images[l][6]),
      nbp = cimg::float2uint((float)images[l][7]);
    for (unsigned int p = 0; p<nbp; ++p) {
      const unsigned int
        nbi = cimg::float2uint((float)*(ptrs[l]++)),
        _nbi = nbi<5?nbi:nbi==5?2:nbi/3;
      *(ptrd++) = (T)cimg::uint2float(nbi);
      for (unsigned int i = 0; i<_nbi; ++i) *(ptrd++) = (T)(*(ptrs[l]++) + poff);
      for (unsigned int i = nbi-_nbi; i; --i) *(ptrd++) = *(ptrs[l]++);
    }
    poff+=nbv;
  }
  unsigned long voff = 0;
  cimglist_for(images,l) { // Merge object colors.
    const unsigned int nbc = cimg::float2uint((float)images[l][7]);
    for (unsigned int c = 0; c<nbc; ++c)
      if (*(ptrs[l])==(T)-128) {
        *(ptrd++) = *(ptrs[l]++);
        const unsigned int
          w = (unsigned int)*(ptrs[l]++),
          h = (unsigned int)*(ptrs[l]++),
          s = (unsigned int)*(ptrs[l]++);
        if (!h && !s) { *(ptrd++) = (T)(w + voff); *(ptrd++) = 0; *(ptrd++) = 0; }
        else {
          *(ptrd++) = (T)w; *(ptrd++) = (T)h; *(ptrd++) = (T)s;
          const unsigned long whs = (unsigned long)w*h*s;
          std::memcpy(ptrd,ptrs[l],whs*sizeof(T));
          ptrs[l]+=whs; ptrd+=whs;
        }
      } else { *(ptrd++) = *(ptrs[l]++); *(ptrd++) = *(ptrs[l]++); *(ptrd++) = *(ptrs[l]++); }
    voff+=nbc;
  }
  voff = 0;
  cimglist_for(images,l) { // Merge object opacities.
    const unsigned int nbo = cimg::float2uint((float)images[l][7]);
    for (unsigned int o = 0; o<nbo; ++o)
      if (*(ptrs[l])==(T)-128) {
        *(ptrd++) = *(ptrs[l]++);
        const unsigned int
          w = (unsigned int)*(ptrs[l]++),
          h = (unsigned int)*(ptrs[l]++),
          s = (unsigned int)*(ptrs[l]++);
        if (!h && !s) { *(ptrd++) = (T)(w + voff); *(ptrd++) = 0; *(ptrd++) = 0; }
        else {
          *(ptrd++) = (T)w; *(ptrd++) = (T)h; *(ptrd++) = (T)s;
          const unsigned long whs = (unsigned long)w*h*s;
          std::memcpy(ptrd,ptrs[l],whs*sizeof(T));
          ptrs[l]+=whs; ptrd+=whs;
        }
      } else *(ptrd++) = *(ptrs[l]++);
    voff+=nbo;
  }
  delete[] ptrs;
  return res;
}

template<typename t>
CImg<T>& rotate_CImg3d(const CImg<t>& rot) {
  char error_message[1024] = { 0 };
  if (!is_CImg3d(false,error_message))
    throw CImgInstanceException(_cimg_instance
                                "rotate_CImg3d(): image instance is not a CImg3d (%s).",
                                cimg_instance,error_message);
  const unsigned int nbv = cimg::float2uint((float)(*this)[6]);
  const T *ptrs = data() + 8;
  const float
    a = (float)rot(0,0), b = (float)rot(1,0), c = (float)rot(2,0),
    d = (float)rot(0,1), e = (float)rot(1,1), f = (float)rot(2,1),
    g = (float)rot(0,2), h = (float)rot(1,2), i = (float)rot(2,2);
  T *ptrd = data() + 8;
  for (unsigned int j = 0; j<nbv; ++j) {
    const float x = (float)*(ptrs++), y = (float)*(ptrs++), z = (float)*(ptrs++);
    *(ptrd++) = (T)(a*x + b*y + c*z);
    *(ptrd++) = (T)(d*x + e*y + f*z);
    *(ptrd++) = (T)(g*x + h*y + i*z);
  }
  return *this;
}

template<typename t>
CImg<T> get_rotate_CImg3d(const CImg<t>& rot) const {
  return (+*this).rotate_CImg3d(rot);
}

CImg<T>& shift_CImg3d(const float tx, const float ty, const float tz) {
  char error_message[1024] = { 0 };
  if (!is_CImg3d(false,error_message))
    throw CImgInstanceException(_cimg_instance
                                "shift_CImg3d(): image instance is not a CImg3d (%s).",
                                cimg_instance,error_message);
  const unsigned int nbv = cimg::float2uint((float)(*this)[6]);
  T *ptrd = data() + 8;
  for (unsigned int j = 0; j<nbv; ++j) { *(ptrd++)+=(T)tx; *(ptrd++)+=(T)ty; *(ptrd++)+=(T)tz; }
  return *this;
}

CImg<T> get_shift_CImg3d(const float tx, const float ty, const float tz) const {
  return (+*this).shift_CImg3d(tx,ty,tz);
}

CImg<T>& scale_CImg3d(const float sx, const float sy, const float sz) {
  char error_message[1024] = { 0 };
  if (!is_CImg3d(false,error_message))
    throw CImgInstanceException(_cimg_instance
                                "scale_CImg3d(): image instance is not a CImg3d (%s).",
                                cimg_instance,error_message);
  const unsigned int nbv = cimg::float2uint((float)(*this)[6]);
  T *ptrd = data() + 8;
  for (unsigned int j = 0; j<nbv; ++j) { *(ptrd++)*=(T)sx; *(ptrd++)*=(T)sy; *(ptrd++)*=(T)sz; }
  return *this;
}

CImg<T> get_scale_CImg3d(const float sx, const float sy, const float sz) const {
  return (+*this).scale_CImg3d(sx,sy,sz);
}

CImg<T>& reverse_CImg3d() {
  char error_message[1024] = { 0 };
  if (!is_CImg3d(false,error_message))
    throw CImgInstanceException(_cimg_instance
                                "reverse_CImg3d(): image instance is not a CImg3d (%s).",
                                cimg_instance,error_message);
  T *p = _data + 6;
  const unsigned int nbv = (unsigned int)*(p++), nbp = (unsigned int)*(p++);
  p+=3*nbv;
  for (unsigned int i = 0; i<nbp; ++i) {
    const unsigned int nb = (unsigned int)*(p++);
    switch(nb) {
    case 2: case 3: cimg::swap(p[0],p[1]); break;
    case 6: cimg::swap(p[0],p[1],p[2],p[4],p[3],p[5]); break;
    case 9: cimg::swap(p[0],p[1],p[3],p[5],p[4],p[6]); break;
    case 4: cimg::swap(p[0],p[1],p[2],p[3]); break;
    case 12: cimg::swap(p[0],p[1],p[2],p[3],p[4],p[6],p[5],p[7],p[8],p[10],p[9],p[11]); break;
    }
    p+=nb;
  }
  return *this;
}

CImg<T> get_reverse_CImg3d() const {
  return (+*this).reverse_CImg3d();
}

CImg<T>& color_CImg3d(const float R, const float G, const float B, const float opacity,
                      const bool set_RGB, const bool set_opacity) {
  char error_message[1024] = { 0 };
  if (!is_CImg3d(false,error_message))
    throw CImgInstanceException(_cimg_instance
                                "color_CImg3d(): image instance is not a CImg3d (%s).",
                                cimg_instance,error_message);
  T *ptrd = data() + 6;
  const unsigned int
    nbv = cimg::float2uint((float)*(ptrd++)),
    nbp = cimg::float2uint((float)*(ptrd++));
  ptrd+=3*nbv;
  for (unsigned int i = 0; i<nbp; ++i) { const unsigned int N = (unsigned int)*(ptrd++); ptrd+=N; }
  for (unsigned int c = 0; c<nbp; ++c)
    if (*ptrd==(T)-128) {
      ++ptrd;
      const unsigned int
        w = (unsigned int)*(ptrd++),
        h = (unsigned int)*(ptrd++),
        s = (unsigned int)*(ptrd++);
      ptrd+=w*h*s;
    } else if (set_RGB) { *(ptrd++) = (T)R; *(ptrd++) = (T)G; *(ptrd++) = (T)B; } else ptrd+=3;
  if (set_opacity)
    for (unsigned int o = 0; o<nbp; ++o) {
      if (*ptrd==(T)-128) {
        ++ptrd;
        const unsigned int
          w = (unsigned int)*(ptrd++),
          h = (unsigned int)*(ptrd++),
          s = (unsigned int)*(ptrd++);
        ptrd+=w*h*s;
      } else *(ptrd++) = (T)opacity;
    }
  return *this;
}

CImg<T> get_color_CImg3d(const float R, const float G, const float B,
                         const float opacity, const bool set_RGB, const bool set_opacity) const {
  return (+*this).color_CImg3d(R,G,B,opacity,set_RGB,set_opacity);
}

CImg<T>& texturize_CImg3d(const CImg<T>& texture, const CImg<T>& coords) {
  return get_texturize_CImg3d(texture,coords).move_to(*this);
}

CImg<T> get_texturize_CImg3d(const CImg<T>& texture, const CImg<T>& coords) const {
  CImgList<uintT> primitives;
  CImgList<T> colors;
  CImgList<floatT> opacities;
  const CImg<floatT> points = get_CImg3dtoobject3d(primitives,colors,opacities,false);
  points.texturize_object3d(primitives,colors,texture,coords);
  return points.get_object3dtoCImg3d(primitives,colors,opacities,false);
}

CImg<T>& convert_primitives_CImg3d(const unsigned int mode) {
  char error_message[1024] = { 0 };
  if (!is_CImg3d(false,error_message))
    throw CImgInstanceException(_cimg_instance
                                "convert_primitives_CImg3d(): image instance is not a CImg3d (%s).",
                                cimg_instance,error_message);
  CImgList<uintT> primitives;
  CImgList<floatT> colors, opacities;
  CImg3dtoobject3d(primitives,colors,opacities,false);
  const unsigned int psiz = primitives.size();
  CImg<uintT> P;
  CImg<floatT> C, O;
  for (unsigned int p = 0; p<psiz; ++p) {
    primitives[p].move_to(P);
    colors[p].move_to(C);
    opacities[p].move_to(O);
    switch (P.size()) {
    case 1 : // Point.
      P.move_to(primitives);
      if (mode==2) {
        if (C.size()==3) C.move_to(colors);
        else C.get_vector_at(C.width()/2,C.height()/2).move_to(colors);
        if (O.size()==1) O.move_to(opacities);
        else O.get_vector_at(O.width()/2,O.height()/2).move_to(opacities);
      } else { C.move_to(colors); O.move_to(opacities); }
      break;
    case 2 : // Colored segment.
      if (mode) { P.move_to(primitives); C.move_to(colors); O.move_to(opacities); }
      else {
        CImg<uintT>::vector(P[0]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[1]).move_to(primitives);
        C.move_to(colors); O.move_to(opacities);
      }
      break;
    case 3 : // Colored triangle.
      if (mode==2) {
        P.move_to(primitives); C.move_to(colors); O.move_to(opacities);
      } else if (mode==1) {
        CImg<uintT>::vector(P[0],P[1]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[1],P[2]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[2],P[0]).move_to(primitives);
        C.move_to(colors); O.move_to(opacities);
      } else {
        CImg<uintT>::vector(P[0]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[1]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[2]).move_to(primitives);
        C.move_to(colors); O.move_to(opacities);
      }
      break;
    case 4 : // Colored quadrangle.
      if (mode==2) {
        P.move_to(primitives); C.move_to(colors); O.move_to(opacities);
      } else if (mode==1) {
        CImg<uintT>::vector(P[0],P[1]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[1],P[2]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[2],P[3]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[3],P[0]).move_to(primitives);
        C.move_to(colors); O.move_to(opacities);
      } else {
        CImg<uintT>::vector(P[0]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[1]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[2]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[3]).move_to(primitives);
        C.move_to(colors); O.move_to(opacities);
      }
      break;
    case 5 : // Sphere.
      if (mode==2) {
        P.move_to(primitives); C.move_to(colors); O.move_to(opacities);
      } else if (mode==1) {
        CImg<uintT>::vector(P[0],P[1]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
      } else {
        CImg<uintT>::vector(P[0]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
        CImg<uintT>::vector(P[1]).move_to(primitives);
        colors.insert(C); opacities.insert(O);
      }
      break;
    case 6 : // Textured segment.
      if (mode==2) {
        CImg<uintT>::vector(P[0],P[1]).move_to(primitives);
        C.get_vector_at(P[2],P[3]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[2],P[3])).move_to(opacities);
        else O.move_to(opacities);
      } else if (mode==1) {
        P.move_to(primitives); C.move_to(colors); O.move_to(opacities);
      } else {
        CImg<uintT>::vector(P[0]).move_to(primitives);
        C.get_vector_at(P[2],P[3]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[2],P[3])).move_to(opacities);
        else opacities.insert(O);
        CImg<uintT>::vector(P[1]).move_to(primitives);
        C.get_vector_at(P[4],P[5]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[4],P[5])).move_to(opacities);
        else O.move_to(opacities);
      }
      break;
    case 9 : // Textured triangle.
      if (mode==2) {
        CImg<uintT>::vector(P[0],P[1],P[2]).move_to(primitives);
        C.get_vector_at(P[3],P[4]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[3],P[4])).move_to(opacities);
        else O.move_to(opacities);
      } else if (mode==1) {
        CImg<uintT>::vector(P[0],P[1],P[3],P[4],P[5],P[6]).
          move_to(primitives);
        C.move_to(colors); opacities.insert(O);
        CImg<uintT>::vector(P[1],P[2],P[3],P[4],P[7],P[8]).
          move_to(primitives);
        colors.insert(colors.back(),~0U,true); opacities.insert(O);
        CImg<uintT>::vector(P[2],P[0],P[7],P[8],P[1],P[3]).
          move_to(primitives);
        colors.insert(colors.back(),~0U,true); O.move_to(opacities);
      } else {
        CImg<uintT>::vector(P[0]).move_to(primitives);
        C.get_vector_at(P[3],P[4]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[3],P[4])).move_to(opacities);
        else opacities.insert(O);
        CImg<uintT>::vector(P[1]).move_to(primitives);
        C.get_vector_at(P[5],P[6]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[5],P[6])).move_to(opacities);
        else opacities.insert(O);
        CImg<uintT>::vector(P[2]).move_to(primitives);
        C.get_vector_at(P[7],P[8]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[7],P[8])).move_to(opacities);
        else O.move_to(opacities);
      }
      break;
    case 12 : // Textured quadrangle.
      if (mode==2) {
        CImg<uintT>::vector(P[0],P[1],P[2],P[3]).move_to(primitives);
        C.get_vector_at(P[4],P[5]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[4],P[5])).move_to(opacities);
        else O.move_to(opacities);
      } else if (mode==1) {
        CImg<uintT>::vector(P[0],P[1],P[4],P[5],P[6],P[7]).
          move_to(primitives);
        C.move_to(colors); opacities.insert(O);
        CImg<uintT>::vector(P[1],P[2],P[6],P[7],P[8],P[9]).
          move_to(primitives);
        colors.insert(colors.back(),~0U,true); opacities.insert(O);
        CImg<uintT>::vector(P[2],P[3],P[8],P[9],P[10],P[11]).
          move_to(primitives);
        colors.insert(colors.back(),~0U,true); opacities.insert(O);
        CImg<uintT>::vector(P[3],P[0],P[10],P[11],P[4],P[5]).
          move_to(primitives);
        colors.insert(colors.back(),~0U,true); O.move_to(opacities);
      } else {
        CImg<uintT>::vector(P[0]).move_to(primitives);
        C.get_vector_at(P[4],P[5]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[4],P[5])).move_to(opacities);
        else opacities.insert(O);
        CImg<uintT>::vector(P[1]).move_to(primitives);
        C.get_vector_at(P[6],P[7]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[6],P[7])).move_to(opacities);
        else opacities.insert(O);
        CImg<uintT>::vector(P[2]).move_to(primitives);
        C.get_vector_at(P[8],P[9]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[8],P[9])).move_to(opacities);
        else opacities.insert(O);
        CImg<uintT>::vector(P[3]).move_to(primitives);
        C.get_vector_at(P[10],P[11]).move_to(colors);
        if (O.size()!=1) CImg<floatT>::vector(O(P[10],P[11])).move_to(opacities);
        else O.move_to(opacities);
      }
      break;
    default : // Other primitives.
      P.move_to(primitives);
      C.move_to(colors);
      O.move_to(opacities);
    }
  }
  if (psiz) {
    primitives.remove(0,psiz-1);
    colors.remove(0,psiz-1);
    opacities.remove(0,psiz-1);
  }
  object3dtoCImg3d(primitives,colors,opacities,false);
  return *this;
}

CImg<T> get_convert_primitives_CImg3d(const unsigned int mode) const {
  return (+*this).convert_primitives_CImg3d(mode);
}

// Additional filters.

template<typename t>
CImg<T>& inpaint(const CImg<t>& mask, const unsigned int method=1) {
  if (!is_sameXYZ(mask))
    throw CImgArgumentException("CImg<%s>::inpaint(): Invalid mask (%u,%u,%u,%u,%p) for "
                                "instance image (%u,%u,%u,%u,%p).",
                                pixel_type(),mask._width,mask._height,mask._depth,
                                mask._spectrum,mask._data,
                                _width,_height,_depth,_spectrum,_data);
  CImg<t> _mask(mask,false), _nmask(mask,false);
  bool is_pixel = false;

  do {
    is_pixel = false;

    if (depth()==1) { // 2d image.
      CImg_3x3(M,t);
      CImg_3x3(I,T);

      switch (method) {
      case 0: // Average 2d (low-connectivity).
        cimg_for3x3(_mask,x,y,0,0,M,t) if (Mcc && (!Mcp || !Mpc || !Mnc || !Mcn)) {
          is_pixel = true;
          const unsigned int wcp = Mcp?0:1, wpc = Mpc?0:1, wnc = Mnc?0:1, wcn = Mcn?0:1,
            sumw = wcp + wpc + wnc + wcn;
          cimg_forC(*this,k) {
            cimg_get3x3(*this,x,y,0,k,I,T);
            (*this)(x,y,k) = (T)((wcp*Icp + wpc*Ipc + wnc*Inc + wcn*Icn)/(float)sumw);
          }
          _nmask(x,y) = 0;
        }
        break;

      case 1: // Average 2d (high-connectivity).
        cimg_for3x3(_mask,x,y,0,0,M,t) if (Mcc && (!Mpp || !Mcp || !Mnp || !Mpc || !Mnc || !Mpn || !Mcn || !Mnn)) {
          is_pixel = true;
          const unsigned int
            wpp = Mpp?0:1, wcp = Mcp?0:2, wnp = Mnp?0:1,
            wpc = Mpc?0:2, wnc = Mnc?0:2,
            wpn = Mpn?0:1, wcn = Mcn?0:2, wnn = Mnn?0:1,
            sumw = wpp + wcp + wnp + wpc + wnc + wpn + wcn + wnn;
          cimg_forC(*this,k) {
            cimg_get3x3(*this,x,y,0,k,I,T);
            (*this)(x,y,k) = (T)((wpp*Ipp + wcp*Icp + wnp*Inp + wpc*Ipc + wnc*Inc + wpn*Ipn + wcn*Icn + wnn*Inn)/(float)sumw);
          }
          _nmask(x,y) = 0;
        }
        break;

      case 2: { // Median 2d (low-connectivity).
        T J[4];
        cimg_for3x3(_mask,x,y,0,0,M,t)
          if (Mcc && (!Mcp || !Mpc || !Mnc || !Mcn)) {
            is_pixel = true;
            cimg_forC(*this,k) {
              cimg_get3x3(*this,x,y,0,k,I,T);
              unsigned int ind = 0;
              if (!Mcp) J[ind++] = Icp;
              if (!Mpc) J[ind++] = Ipc;
              if (!Mnc) J[ind++] = Inc;
              if (!Mcn) J[ind++] = Icn;
              (*this)(x,y,k) = CImg<T>(J,ind,1,1,1,true).kth_smallest(ind>>1);
            }
            _nmask(x,y) = 0;
          }
      } break;

      default: // Median 2d (high-connectivity).
        T J[8];
        cimg_for3x3(_mask,x,y,0,0,M,t) if (Mcc && (!Mpp || !Mcp || !Mnp || !Mpc || !Mnc || !Mpn || !Mcn || !Mnn)) {
          is_pixel = true;
          cimg_forC(*this,k) {
            cimg_get3x3(*this,x,y,0,k,I,T);
            unsigned int ind = 0;
            if (!Mpp) J[ind++] = Ipp; if (!Mcp) J[ind++] = Icp; if (!Mnp) J[ind++] = Inp;
            if (!Mpc) J[ind++] = Ipc; if (!Mnc) J[ind++] = Inc;
            if (!Mpn) J[ind++] = Ipn; if (!Mcn) J[ind++] = Icn; if (!Mnn) J[ind++] = Inn;
            (*this)(x,y,k) = CImg<T>(J,ind,1,1,1,true).kth_smallest(ind>>1);
          }
          _nmask(x,y) = 0;
        }
      }

    } else { // 3d image.
      CImg_3x3x3(M,t);
      CImg_3x3x3(I,T);

      switch (method) {
      case 0: // Average 3d (low-connectivity).
        cimg_for3x3x3(_mask,x,y,z,0,M,t) if (Mccc && (!Mccp || !Mcpc || !Mpcc || !Mncc || !Mcnc || !Mccn)) {
          is_pixel = true;
          const unsigned int
            wccp = Mccp?0:1, wcpc = Mcpc?0:1, wpcc = Mpcc?0:1,
            wncc = Mncc?0:1, wcnc = Mcnc?0:1, wccn = Mccn?0:1,
            sumw = wcpc + wpcc + wccp + wncc + wcnc + wccn;
          cimg_forC(*this,k) {
            cimg_get3x3x3(*this,x,y,z,k,I,T);
            (*this)(x,y,z,k) = (T)((wccp*Iccp + wcpc*Icpc + wpcc*Ipcc + wncc*Incc + wcnc*Icnc + wccn*Iccn)/(float)sumw);
          }
          _nmask(x,y,z) = 0;
        }
        break;

      case 1: // Average 3d (high-connectivity).
        cimg_for3x3x3(_mask,x,y,z,0,M,t)
          if (Mccc && (!Mppp || !Mcpp || !Mnpp || !Mpcp || !Mccp || !Mncp || !Mpnp || !Mcnp || !Mnnp ||
                       !Mppc || !Mcpc || !Mnpc || !Mpcc || !Mncc || !Mpnc || !Mcnc || !Mnnc ||
                       !Mppn || !Mcpn || !Mnpn || !Mpcn || !Mccn || !Mncn || !Mpnn || !Mcnn || !Mnnn)) {
            is_pixel = true;
            const unsigned int
              wppp = Mppp?0:1, wcpp = Mcpp?0:2, wnpp = Mnpp?0:1,
              wpcp = Mpcp?0:2, wccp = Mccp?0:4, wncp = Mncp?0:2,
              wpnp = Mpnp?0:1, wcnp = Mcnp?0:2, wnnp = Mnnp?0:1,
              wppc = Mppc?0:2, wcpc = Mcpc?0:4, wnpc = Mnpc?0:2,
              wpcc = Mpcc?0:4, wncc = Mncc?0:4,
              wpnc = Mpnc?0:2, wcnc = Mcnc?0:4, wnnc = Mnnc?0:2,
              wppn = Mppn?0:1, wcpn = Mcpn?0:2, wnpn = Mnpn?0:1,
              wpcn = Mpcn?0:2, wccn = Mccn?0:4, wncn = Mncn?0:2,
              wpnn = Mpnn?0:1, wcnn = Mcnn?0:2, wnnn = Mnnn?0:1,
              sumw = wppp + wcpp + wnpp + wpcp + wccp + wncp + wpnp + wcnp + wnnp +
              wppc + wcpc + wnpc + wpcc + wncc + wpnc + wcnc + wnnc +
              wppn + wcpn + wnpn + wpcn + wccn + wncn + wpnn + wcnn + wnnn;
            cimg_forC(*this,k) {
              cimg_get3x3x3(*this,x,y,z,k,I,T);
              (*this)(x,y,z,k) = (T)((wppp*Ippp + wcpp*Icpp + wnpp*Inpp +
                                      wpcp*Ipcp + wccp*Iccp + wncp*Incp +
                                      wpnp*Ipnp + wcnp*Icnp + wnnp*Innp +
                                      wppc*Ippc + wcpc*Icpc + wnpc*Inpc +
                                      wpcc*Ipcc + wncc*Incc +
                                      wpnc*Ipnc + wcnc*Icnc + wnnc*Innc +
                                      wppn*Ippn + wcpn*Icpn + wnpn*Inpn +
                                      wpcn*Ipcn + wccn*Iccn + wncn*Incn +
                                      wpnn*Ipnn + wcnn*Icnn + wnnn*Innn)/(float)sumw);
            }
            _nmask(x,y,z) = 0;
          }
        break;

      case 2: { // Median 3d (low-connectivity).
        T J[6];
        cimg_for3x3x3(_mask,x,y,z,0,M,t)
          if (Mccc && (!Mccp || !Mcpc || !Mpcc || !Mncc || !Mcnc || !Mccn)) {
            is_pixel = true;
            cimg_forC(*this,k) {
              cimg_get3x3x3(*this,x,y,z,k,I,T);
              unsigned int ind = 0;
              if (!Mccp) J[ind++] = Iccp; if (!Mcpc) J[ind++] = Icpc; if (!Mpcc) J[ind++] = Ipcc;
              if (!Mncc) J[ind++] = Incc; if (!Mcnc) J[ind++] = Icnc; if (!Mccn) J[ind++] = Iccn;
              (*this)(x,y,z,k) = CImg<T>(J,ind,1,1,1,true).kth_smallest(ind>>1);
            }
            _nmask(x,y,z) = 0;
          }
      } break;

      default: { // Median 3d (high-connectivity).
        T J[26];
        cimg_for3x3x3(_mask,x,y,z,0,M,t)
          if (Mccc && (!Mppp || !Mcpp || !Mnpp || !Mpcp || !Mccp || !Mncp || !Mpnp || !Mcnp || !Mnnp ||
                       !Mppc || !Mcpc || !Mnpc || !Mpcc || !Mncc || !Mpnc || !Mcnc || !Mnnc ||
                       !Mppn || !Mcpn || !Mnpn || !Mpcn || !Mccn || !Mncn || !Mpnn || !Mcnn || !Mnnn)) {
            is_pixel = true;
            cimg_forC(*this,k) {
              cimg_get3x3x3(*this,x,y,z,k,I,T);
              unsigned int ind = 0;
              if (!Mppp) J[ind++] = Ippp; if (!Mcpp) J[ind++] = Icpp; if (!Mnpp) J[ind++] = Inpp;
              if (!Mpcp) J[ind++] = Ipcp; if (!Mccp) J[ind++] = Iccp; if (!Mncp) J[ind++] = Incp;
              if (!Mpnp) J[ind++] = Ipnp; if (!Mcnp) J[ind++] = Icnp; if (!Mnnp) J[ind++] = Innp;
              if (!Mppc) J[ind++] = Ippc; if (!Mcpc) J[ind++] = Icpc; if (!Mnpc) J[ind++] = Inpc;
              if (!Mpcc) J[ind++] = Ipcc; if (!Mncc) J[ind++] = Incc;
              if (!Mpnc) J[ind++] = Ipnc; if (!Mcnc) J[ind++] = Icnc; if (!Mnnc) J[ind++] = Innc;
              if (!Mppn) J[ind++] = Ippn; if (!Mcpn) J[ind++] = Icpn; if (!Mnpn) J[ind++] = Inpn;
              if (!Mpcn) J[ind++] = Ipcn; if (!Mccn) J[ind++] = Iccn; if (!Mncn) J[ind++] = Incn;
              if (!Mpnn) J[ind++] = Ipnn; if (!Mcnn) J[ind++] = Icnn; if (!Mnnn) J[ind++] = Innn;
              (*this)(x,y,z,k) = CImg<T>(J,ind,1,1,1,true).kth_smallest(ind>>1);
            }
            _nmask(x,y,z) = 0;
          }
      } break;
      }
    }

    _mask = _nmask;
  } while (is_pixel);
  return *this;
}

template<typename t>
CImg<T> get_inpaint(const CImg<t>& mask, const unsigned int method=1) const {
  return (+*this).inpaint(mask,method);
}

template<typename t>
CImg<T>& inpaint_patch(const CImg<t>& mask, const unsigned int patch_size=11,
                       const unsigned int lookup_size=22, const float lookup_factor=1,
                       const unsigned int lookup_increment=1,
                       const unsigned int blend_size=0, const float blend_threshold=0.5f,
                       const float blend_decay=0.02, const unsigned int blend_scales=10,
                       const bool is_blend_outer=false) {
  if (depth()>1)
    throw CImgInstanceException(_cimg_instance
                                "inpaint_patch(): Instance image is volumetric (should be 2d).",
                                cimg_instance);
  if (!is_sameXYZ(mask))
    throw CImgArgumentException(_cimg_instance
                                "inpaint_patch() : Sizes of instance image and specified mask "
                                "(%u,%u,%u,%u) do not match.",
                                cimg_instance,
                                mask._width,mask._height,mask._depth,mask._spectrum);
  if (!patch_size)
    throw CImgArgumentException(_cimg_instance
                                "inpaint_patch() : Specified patch size is 0, must be strictly "
                                "positive.",
                                cimg_instance);
  if (!lookup_size)
    throw CImgArgumentException(_cimg_instance
                                "inpaint_patch() : Specified lookup size is 0, must be strictly "
                                "positive.",
                                cimg_instance);
  if (lookup_factor<0)
    throw CImgArgumentException(_cimg_instance
                                "inpaint_patch() : Specified lookup factor %g is negative, must be "
                                "positive.",
                                cimg_instance,
                                lookup_factor);
  if (!lookup_increment)
    throw CImgArgumentException(_cimg_instance
                                "inpaint_patch() : Specified lookup increment is 0, must be strictly "
                                "positive.",
                                cimg_instance);
  if (blend_decay<0)
    throw CImgArgumentException(_cimg_instance
                                "inpaint_patch() : Specified blend decay %g is negative, must be "
                                "positive.",
                                cimg_instance,
                                blend_decay);

  // Find (dilated by 2) bounding box for the inpainting mask.
  unsigned int xm0 = _width, ym0 = _height, xm1 = 0, ym1 = 0;
  bool is_mask_found = false;
  cimg_forXY(mask,x,y) if (mask(x,y)) {
    is_mask_found = true;
    if (x<(int)xm0) xm0 = (unsigned int)x;
    if (x>(int)xm1) xm1 = (unsigned int)x;
    if (y<(int)ym0) ym0 = (unsigned int)y;
    if (y>(int)ym1) ym1 = (unsigned int)y;
  }
  if (!is_mask_found) return *this;
  xm0 = xm0>2?xm0-2:0;
  ym0 = ym0>2?ym0-2:0;
  xm1 = xm1<_width-3?xm1+2:_width-1;
  ym1 = ym1<_height-3?ym1+2:_height-1;
  int ox = xm0, oy = ym0;
  unsigned int dx = xm1 - xm0 + 1U, dy = ym1 - ym0 + 1U;

  // Construct normalized version of the mask.
  CImg<ucharT> nmask(dx,dy);
  unsigned char *ptrM = nmask.data();
  cimg_for_inXY(mask,xm0,ym0,xm1,ym1,x,y) *(ptrM++) = mask(x,y)?0:1;
  xm0 = ym0 = 0; xm1 = dx - 1; ym1 = dy - 1;

  // Start patch filling algorithm.
  const int p2 = (int)patch_size/2, p1 = (int)patch_size - p2 - 1;
  const unsigned int patch_size2 = patch_size*patch_size;
  unsigned int _lookup_size = lookup_size, nb_lookups = 0, nb_fails = 0, nb_saved_patches = 0;
  bool is_strict_search = true;
  const float one = 1;

  CImg<floatT> confidences(nmask), priorities(dx,dy,1,2,-1), pC;
  CImg<unsigned int> saved_patches(4,256), is_visited(width(),height(),1,1,0);
  CImg<ucharT> pM, pN;  // Pre-declare patch variables (avoid iterative memory alloc/dealloc).
  CImg<T> pP, pbest;
  CImg<floatT> weights(patch_size,patch_size,1,1,0);
  weights.draw_gaussian((float)p1,(float)p1,patch_size/15.0f,&one)/=patch_size2;
  unsigned int target_index = 0;

  while (true) {

    // Extract mask border points and compute priorities to find target point.
    unsigned int nb_border_points = 0;
    float target_confidence = -1, target_priority = -1;
    int target_x = -1, target_y = -1;
    CImg_5x5(M,unsigned char);

    cimg_for_in5x5(nmask,xm0,ym0,xm1,ym1,x,y,0,0,M,unsigned char)
      if (!Mcc && (Mcp || Mcn || Mpc || Mnc)) { // Found mask border point.

        float confidence_term = -1, data_term = -1;
        if (priorities(x,y)>=0) { // If priority has already been computed.
          confidence_term = priorities(x,y,0);
          data_term = priorities(x,y,1);
        } else { // If priority must be computed/updated.

          // Compute smoothed normal vector.
          const float
            Npc = (4.0f*Mpc + 2.0f*Mbc + 2.0f*Mcc + 2.0f*Mpp + 2.0f*Mpn + Mbp + Mbn + Mcp + Mcn)/16,  // N = smoothed 3x3 neighborhood of M.
            Nnc = (4.0f*Mnc + 2.0f*Mac + 2.0f*Mcc + 2.0f*Mnp + 2.0f*Mnn + Map + Man + Mcp + Mcn)/16,
            Ncp = (4.0f*Mcp + 2.0f*Mcb + 2.0f*Mcc + 2.0f*Mpp + 2.0f*Mnp + Mpb + Mnb + Mpc + Mnc)/16,
            Ncn = (4.0f*Mcn + 2.0f*Mca + 2.0f*Mcc + 2.0f*Mpn + 2.0f*Mnn + Mpa + Mna + Mpc + Mnc)/16,
            _nx = 0.5f*(Nnc - Npc),
            _ny = 0.5f*(Ncn - Ncp),
            nn = std::sqrt(1e-8f + _nx*_nx + _ny*_ny),
            nx = _nx/nn,
            ny = _ny/nn;

          // Compute confidence term.
          nmask._inpaint_patch_crop(x-p1,y-p1,x+p2,y+p2,1).move_to(pM);
          confidences._inpaint_patch_crop(x-p1,y-p1,x+p2,y+p2,1).move_to(pC);
          confidence_term = 0;
          const unsigned char *ptrM = pM.data();
          cimg_for(pC,ptrC,float) confidence_term+=*ptrC**(ptrM++);
          confidence_term/=patch_size2;
          priorities(x,y,0) = confidence_term;

          // Compute data term.
          _inpaint_patch_crop(ox+x-p1,oy+y-p1,ox+x+p2,oy+y+p2,2).move_to(pP);
          float mean_ix2 = 0, mean_ixiy = 0, mean_iy2 = 0;

          CImg_3x3(I,T);
          CImg_3x3(_M, unsigned char);
          cimg_forC(pP,c) cimg_for3x3(pP,p,q,0,c,I,T) { // Compute weight-mean of structure tensor inside patch.
            cimg_get3x3(pM,p,q,0,0,_M,unsigned char);
            const float
              ixf = (float)(_Mnc*_Mcc*(Inc-Icc)),
              iyf = (float)(_Mcn*_Mcc*(Icn-Icc)),
              ixb = (float)(_Mcc*_Mpc*(Icc-Ipc)),
              iyb = (float)(_Mcc*_Mcp*(Icc-Icp)),
              ix = cimg::abs(ixf)>cimg::abs(ixb)?ixf:ixb,
              iy = cimg::abs(iyf)>cimg::abs(iyb)?iyf:iyb,
              w = weights(p,q);
            mean_ix2 += w*ix*ix;
            mean_ixiy += w*ix*iy;
            mean_iy2 += w*iy*iy;
          }
          const float // Compute tensor-directed data term.
            ux = mean_ix2*(-ny) + mean_ixiy*nx,
            uy = mean_ixiy*(-ny) + mean_iy2*nx;
          data_term = std::sqrt(ux*ux + uy*uy);
          priorities(x,y,1) = data_term;
        }
        const float priority = confidence_term*data_term;
        if (priority>target_priority) {
          target_priority = priority; target_confidence = confidence_term;
          target_x = ox + x; target_y = oy + y;
        }
        ++nb_border_points;
      }
    if (!nb_border_points) break; // No more mask border points to inpaint!

    // Locate already reconstructed neighbors (if any), to get good origins for patch lookup.
    CImg<unsigned int> lookup_candidates(2,256);
    unsigned int nb_lookup_candidates = 0, *ptr_lookup_candidates = lookup_candidates.data();
    const unsigned int *ptr_saved_patches = saved_patches.data();
    const int
      x0 = target_x - (int)patch_size, y0 = target_y - (int)patch_size,
      x1 = target_x + (int)patch_size, y1 = target_y + (int)patch_size;
    for (unsigned int k = 0; k<nb_saved_patches; ++k) {
      const unsigned int
        src_x = *(ptr_saved_patches++), src_y = *(ptr_saved_patches++),
        dest_x = *(ptr_saved_patches++), dest_y = *(ptr_saved_patches++);
      if ((int)dest_x>=x0 && (int)dest_y>=y0 && (int)dest_x<=x1 && (int)dest_y<=y1) {
        const int off_x = target_x - dest_x, off_y = target_y - dest_y;
        *(ptr_lookup_candidates++) = src_x + off_x;
        *(ptr_lookup_candidates++) = src_y + off_y;
        if (++nb_lookup_candidates>=lookup_candidates._height) lookup_candidates.resize(2,-200,1,1,0);
      }
    }
    *(ptr_lookup_candidates++) = target_x;  // Add also target point as a center for the patch lookup.
    *(ptr_lookup_candidates++) = target_y;
    ++nb_lookup_candidates;

    // Divide size of lookup regions if several lookup sources have been detected.
    unsigned int final_lookup_size = _lookup_size;
    if (nb_lookup_candidates>1) {
      const unsigned int _final_lookup_size = (unsigned int)cimg::round(_lookup_size*lookup_factor/std::sqrt((float)nb_lookup_candidates),1,1);
      final_lookup_size = _final_lookup_size + 1 - (_final_lookup_size%2);
    }
    const int l2 = (int)final_lookup_size/2, l1 = (int)final_lookup_size - l2 - 1;

#ifdef gmic_debug
    CImg<ucharT> visu(*this,false);
    for (unsigned int C = 0; C<nb_lookup_candidates; ++C) {
      const int
        xl = lookup_candidates(0,C),
        yl = lookup_candidates(1,C);
      visu.draw_rectangle(xl-l1,yl-l1,xl+l2,yl+l2,CImg<ucharT>::vector(0,255,0).data(),0.2f);
    }
    visu.draw_rectangle(target_x-p1,target_y-p1,target_x+p2,target_y+p2,CImg<ucharT>::vector(255,0,0).data(),0.5f);
    static int foo = 0;
    if (!(foo%1)) {
      //      visu.save("video.ppm",foo);
      static CImgDisplay disp_debug;
      disp_debug.display(visu).set_title("DEBUG");
    }
    ++foo;
#endif
# 1397 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

    // Find best patch candidate to fill target point.
    _inpaint_patch_crop(target_x-p1,target_y-p1,target_x+p2,target_y+p2,0).move_to(pP);
    nmask._inpaint_patch_crop(target_x-ox-p1,target_y-oy-p1,target_x-ox+p2,target_y-oy+p2,0).
      move_to(pM);
    float best_ssd = cimg::type<float>::max();
    int best_x = -1, best_y = -1;
    ++target_index;

    ptr_lookup_candidates = lookup_candidates.data();
    for (unsigned int C = 0; C<nb_lookup_candidates; ++C) {
      const int
        xl = (int)*(ptr_lookup_candidates++),
        yl = (int)*(ptr_lookup_candidates++),
        x0 = cimg::max(p1,xl-l1), y0 = cimg::max(p1,yl-l1),
        x1 = cimg::min(width()-1-p2,xl+l2), y1 = cimg::min(height()-1-p2,yl+l2);
      for (int y = y0; y<=y1; y+=lookup_increment)
        for (int x = x0; x<=x1; x+=lookup_increment) if (is_visited(x,y)!=target_index) {
            if (is_strict_search) mask._inpaint_patch_crop(x-p1,y-p1,x+p2,y+p2,1).move_to(pN);
            else nmask._inpaint_patch_crop(x-ox-p1,y-oy-p1,x-ox+p2,y-oy+p2,0).move_to(pN);
            if ((is_strict_search && pN.sum()==0) || (!is_strict_search && pN.sum()==patch_size2)) {
              _inpaint_patch_crop(x-p1,y-p1,x+p2,y+p2,0).move_to(pC);
              float ssd = 0;
              const T *_pP = pP._data;
              const float *_pC = pC._data;
              cimg_for(pM,_pM,unsigned char) { if (*_pM) {
                  cimg_forC(pC,c) { ssd+=cimg::sqr((Tfloat)*_pC-(Tfloat)*_pP); _pC+=patch_size2; _pP+=patch_size2; }
                  if (ssd>=best_ssd) break;
                  _pC-=pC._spectrum*patch_size2;
                  _pP-=pC._spectrum*patch_size2;
                }
                ++_pC; ++_pP;
              }
              if (ssd<best_ssd) { best_ssd = ssd; best_x = x; best_y = y; }
            }
            is_visited(x,y) = target_index;
          }
    }

    if (best_x<0) { // If no best patch found.
      priorities(target_x-ox,target_y-oy,0)/=10; // Reduce its priority (lower data_term).
      if (++nb_fails>=4) { // If too much consecutive fails :
        nb_fails = 0;
        _lookup_size+=_lookup_size/2; // Try to expand the lookup size.
        if (++nb_lookups>=3) {
          if (is_strict_search) { // If still fails, switch to non-strict search mode.
            is_strict_search = false;
            _lookup_size = lookup_size;
            nb_lookups = 0;
          }
          else return *this; // Pathological case, probably a weird mask.
        }
      }
    } else { // Best patch found -> reconstruct missing part on the target patch.
      _lookup_size = lookup_size;
      nb_lookups = nb_fails = 0;
      _inpaint_patch_crop(best_x-p1,best_y-p1,best_x+p2,best_y+p2,0).move_to(pbest);
      nmask._inpaint_patch_crop(target_x-ox-p1,target_y-oy-p1,target_x-ox+p2,target_y-oy+p2,1).
        move_to(pM);
      cimg_for(pM,ptr,unsigned char) *ptr=1-*ptr;
      draw_image(target_x-p1,target_y-p1,pbest,pM,1,1);
      confidences.draw_image(target_x-ox-p1,target_y-oy-p1,pC.fill(target_confidence),pM,1,1);
      nmask.draw_rectangle(target_x-ox-p1,target_y-oy-p1,0,0,target_x-ox+p2,target_y-oy+p2,0,0,1);
      priorities.draw_rectangle(target_x-ox-(int)patch_size,
                                target_y-oy-(int)patch_size,0,0,
                                target_x-ox+3*p2/2,
                                target_y-oy+3*p2/2,0,0,-1);
      // Remember patch positions.
      unsigned int *ptr_saved_patches = saved_patches.data(0,nb_saved_patches);
      *(ptr_saved_patches++) = best_x;
      *(ptr_saved_patches++) = best_y;
      *(ptr_saved_patches++) = target_x;
      *ptr_saved_patches = target_y;
      if (++nb_saved_patches>=saved_patches._height) saved_patches.resize(4,-200,1,1,0);
    }
  }
  nmask.assign();  // Free some unused memory resources.
  priorities.assign();
  confidences.assign();
  is_visited.assign();

  // Blend inpainting result (if requested), using multi-scale blending algorithm.
  if (blend_size && blend_scales) {
    const float _blend_threshold = cimg::max(0.0f,cimg::min(1.0f,blend_threshold));
    saved_patches._height = nb_saved_patches;

    // Re-crop image and mask if outer blending is activated.
    if (is_blend_outer) {
      const int
        b2 = (int)blend_size/2, b1 = (int)blend_size - b2 - 1,
        xb0 = cimg::max(0,ox-b1),
        yb0 = cimg::max(0,oy-b1),
        xb1 = cimg::min(_width-1,xb0 + dx + b1 + b2),
        yb1 = cimg::min(_height-1,yb0 + dy + b1 + b2);
      ox = xb0; oy = yb0; dx = xb1 - xb0 + 1U, dy = yb1 - yb0 + 1U;
    }

    // Generate map of source offsets.
    CImg<unsigned int> offsets(dx,dy,1,2);
    unsigned int *ptr = saved_patches.end();
    cimg_forY(saved_patches,i) {
      const unsigned int yd = *(--ptr), xd = *(--ptr), ys = *(--ptr), xs = *(--ptr);
      for (int l=-p1; l<=p2; ++l)
        for (int k=-p1; k<=p2; ++k) {
          const int xdk = xd+k, ydl = yd+l;
          if (xdk>=0 && xdk<=width()-1 && ydl>=0 && ydl<=height()-1 && mask(xd+k,yd+l)) {
            offsets(xd-ox+k,yd-oy+l,0) = xs+k;
            offsets(xd-ox+k,yd-oy+l,1) = ys+l;
          }
        }
    }
    unsigned int *ptrx = offsets.data(0,0,0,0), *ptry = offsets.data(0,0,0,1);
    cimg_forXY(offsets,x,y) {
      if (!mask(x+ox,y+oy)) { *ptrx = x+ox; *ptry = y+oy; }
      ++ptrx; ++ptry;
    }

    // Generate map of local blending amplitudes.
    CImg<floatT> blend_map(dx,dy,1,1,0);
    CImg_3x3(I,float);
    cimg_for3XY(offsets,x,y) if (mask(x+ox,y+oy)) {
      const float
        iox = cimg::max((float)offsets(_n1x,y,0)-offsets(x,y,0),
                        (float)offsets(x,y,0)-offsets(_p1x,y,0)),
        ioy = cimg::max((float)offsets(x,_n1y,1)-offsets(x,y,1),
                        (float)offsets(x,y,1)-offsets(x,_p1y,1)),
        ion = std::sqrt(iox*iox+ioy*ioy);
      float iin = 0;
      cimg_forC(*this,c) {
        cimg_get3x3(*this,x,y,0,c,I,float);
        const float
          iix = (float)cimg::max(Inc-Icc,Icc-Ipc),
          iiy = (float)cimg::max(Icn-Icc,Icc-Icp);
        iin+=std::log(1+iix*iix+iiy*iiy);
      }
      iin/=_spectrum;
      blend_map(x,y) = ion*iin;
    }
    blend_map.threshold(blend_map.max()*_blend_threshold).distance(1);
    cimg_forXY(blend_map,x,y) blend_map(x,y) = 1/(1+blend_decay*blend_map(x,y));
    blend_map.quantize(blend_scales+1,false);
    float bm, bM = blend_map.max_min(bm);
    if (bm==bM) blend_map.fill((float)blend_scales);

    // Generate blending scales.
    CImg<T> result = _inpaint_patch_crop(ox,oy,ox+dx-1,oy+dy-1,0);
    for (unsigned int blend_iter = 1; blend_iter<=blend_scales; ++blend_iter) {
      const unsigned int
        _blend_width = blend_iter*blend_size/blend_scales,
        blend_width = _blend_width?_blend_width+1-(_blend_width%2):0;
      if (!blend_width) continue;
      const int b2 = (int)blend_width/2, b1 = (int)blend_width - b2 - 1;
      CImg<floatT>
        blended = _inpaint_patch_crop(ox,oy,ox+dx-1,oy+dy-1,0),
        cumul(dx,dy,1,1);
      weights.assign(blend_width,blend_width,1,1,0).
        draw_gaussian((float)b1,(float)b1,blend_width/4.0f,&one);
      cimg_forXY(cumul,x,y) cumul(x,y) = mask(x+ox,y+oy)?0.0f:1.0f;
      blended.mul(cumul);

      unsigned int *ptr = saved_patches.data();
      cimg_forY(saved_patches,l) {
        const int xs = (int)*(ptr++), ys = (int)*(ptr++), xd = (int)*(ptr++), yd = (int)*(ptr++);
        if (xs-b1<0 || ys-b1<0 || xs+b2>=width() || ys+b2>=height()) { // Blend with partial patch.
          const int
            xs0 = cimg::max(0,xs - b1),
            ys0 = cimg::max(0,ys - b1),
            xs1 = cimg::min(width()-1,xs + b2),
            ys1 = cimg::min(height()-1,ys + b2);
          _inpaint_patch_crop(xs0,ys0,xs1,ys1,0).move_to(pP);
          weights._inpaint_patch_crop(xs0-xs+b1,ys0-ys+b1,xs1-xs+b1,ys1-ys+b1,0).move_to(pC);
          blended.draw_image(xd+xs0-xs-ox,yd+ys0-ys-oy,pP,pC,-1);
          cumul.draw_image(xd+xs0-xs-ox,yd+ys0-ys-oy,pC,-1);
        } else { // Blend with full-size patch.
          _inpaint_patch_crop(xs-b1,ys-b1,xs+b2,ys+b2,0).move_to(pP);
          blended.draw_image(xd-b1-ox,yd-b1-oy,pP,weights,-1);
          cumul.draw_image(xd-b1-ox,yd-b1-oy,weights,-1);
        }
      }

      if (is_blend_outer) {
        cimg_forXY(blended,x,y) if (blend_map(x,y)==blend_iter) {
          const float cum = cumul(x,y);
          if (cum>0) cimg_forC(*this,c) result(x,y,c) = (T)(blended(x,y,c)/cum);
        }
      } else { cimg_forXY(blended,x,y) if (mask(x+ox,y+oy) && blend_map(x,y)==blend_iter) {
          const float cum = cumul(x,y);
          if (cum>0) cimg_forC(*this,c) result(x,y,c) = (T)(blended(x,y,c)/cum);
        }
      }
    }
    if (is_blend_outer) draw_image(ox,oy,result);
    else cimg_forXY(result,x,y) if (mask(x+ox,y+oy))
           cimg_forC(*this,c) (*this)(x+ox,y+oy,c) = (T)result(x,y,c);
  }
  return *this;
}

// Special crop function that supports more boundary conditions :
// 0=dirichlet (with value 0), 1=dirichlet (with value 1) and 2=neumann.
CImg<T> _inpaint_patch_crop(const int x0, const int y0, const int x1, const int y1,
                            const unsigned int boundary=0) const {
  const int
    nx0 = x0<x1?x0:x1, nx1 = x0^x1^nx0,
    ny0 = y0<y1?y0:y1, ny1 = y0^y1^ny0;
  CImg<T> res(1U + nx1 - nx0,1U + ny1 - ny0,1,_spectrum);
  if (nx0<0 || nx1>=width() || ny0<0 || ny1>=height()) {
    if (boundary>=2) cimg_forXYZC(res,x,y,z,c) res(x,y,z,c) = _atXY(nx0+x,ny0+y,z,c);
    else res.fill((T)boundary).draw_image(-nx0,-ny0,*this);
  } else res.draw_image(-nx0,-ny0,*this);
  return res;
}

template<typename t>
CImg<T> get_inpaint_patch(const CImg<t>& mask, const unsigned int patch_size=11,
                          const unsigned int lookup_size=22, const float lookup_factor=1,
                          const unsigned int lookup_increment=1,
                          const unsigned int blend_size=0, const float blend_threshold=0.5,
                          const float blend_decay=0.02f, const unsigned int blend_scales=10,
                          const bool is_blend_outer=false) const {
  return (+*this).inpaint_patch(mask,patch_size,lookup_size,lookup_factor,lookup_increment,
                                blend_size,blend_threshold,blend_decay,blend_scales,is_blend_outer);
}

// Additional convenience functions.

CImg<T>& mark() {
  unsigned int siz = _width;
  if (siz<2) assign(siz=2,1,1,1,0); else if (_data[siz-2]) resize(++siz,1,1,1,0);
  T &last = _data[siz-1];
  if (last<cimg::type<T>::max()) ++last;
  return *this;
}

CImg<T> get_mark() const {
  return (+*this).mark();
}

CImg<T>& copymark() {
  return get_copymark().move_to(*this);
}

CImg<T> get_copymark() const {
  if (is_empty()) return CImg<T>::string("~");
  CImg<T> res = get_resize(_width+1,1,1,1,0);
  const char *const ext = cimg::split_filename(_data);
  if (*ext) {
    const int l = (int)(ext - _data - 1);
    if (l>0) {
      if (_data[l-1]=='~') return +*this;
      std::memcpy(res._data,_data,l);
    }
    res[l] = '~'; res[l+1] = '.';
    std::memcpy(res._data+l+2,ext,_data+_width-ext);
  } else {
    const unsigned int l = (int)(ext - _data);
    if (_data[l-1]=='~' || (l>1 && _data[l-1]==']' && _data[l-2]=='~')) return +*this;
    std::memcpy(res._data,_data,l);
    res[l] = '~';
    if (ext>_data && *(ext-1)==']') cimg::swap(res[l],res[l-1]);
    std::memcpy(res._data+l+1,ext,_data+_width-ext);
  }
  return res;
}

const CImg<T>& gmic_print(const char *const title, const bool is_debug,
                          const bool is_valid) const {
  CImg<doubleT> st;
  if (is_valid && !is_empty()) st = get_stats();
  const unsigned long siz = size(), msiz = _is_shared?0:siz*sizeof(T), siz1 = siz-1,
    mdisp = msiz<8*1024?0:(msiz<8*1024*1024?1:2),
    wh = _width*_height, whd = _width*_height*_depth,
    w1 = _width-1, wh1 = _width*_height-1, whd1 = _width*_height*_depth-1;

  std::fprintf(cimg::output(),"%s%s%s%s:\n  %ssize%s = (%u,%u,%u,%u) [%lu %s].\n  %sdata%s = %s",
               cimg::t_magenta,cimg::t_bold,title,cimg::t_normal,
               cimg::t_bold,cimg::t_normal,_width,_height,_depth,_spectrum,
               mdisp==0?msiz:(mdisp==1?(msiz>>10):(msiz>>20)),
               mdisp==0?"b":(mdisp==1?"Kio":"Mio"),
               cimg::t_bold,cimg::t_normal,
               is_debug?"":"(");
  if (is_debug) std::fprintf(cimg::output(),"%p = (",_data);

  if (is_valid) {
    if (is_empty()) std::fprintf(cimg::output(),") [%s].\n",
                                 pixel_type());
    else {
      cimg_foroff(*this,off) {
        std::fprintf(cimg::output(),cimg::type<T>::format(),cimg::type<T>::format(_data[off]));
        if (off!=siz1) std::fprintf(cimg::output(),"%s",
                                    off%whd==whd1?"^":
                                    off%wh==wh1?"\\":
                                    off%_width==w1?";":",");
        if (off==11 && siz>24) { off = siz1-12; std::fprintf(cimg::output(),"... "); }
      }
      std::fprintf(cimg::output(),") [%s%s].\n  %smin%s = %g, %smax%s = %g, %smean%s = %g, "
                   "%sstd%s = %g, %scoords_min%s = (%u,%u,%u,%u), "
                   "%scoords_max%s = (%u,%u,%u,%u).\n",
                   _is_shared?"shared ":"",pixel_type(),
                   cimg::t_bold,cimg::t_normal,st[0],
                   cimg::t_bold,cimg::t_normal,st[1],
                   cimg::t_bold,cimg::t_normal,st[2],
                   cimg::t_bold,cimg::t_normal,std::sqrt(st[3]),
                   cimg::t_bold,cimg::t_normal,(int)st[4],(int)st[5],(int)st[6],(int)st[7],
                   cimg::t_bold,cimg::t_normal,(int)st[8],(int)st[9],(int)st[10],(int)st[11]);
    }
  } else std::fprintf(cimg::output(),"%s%sinvalid pointer%s) [shared %s].\n",
                      cimg::t_red,cimg::t_bold,cimg::t_normal,
                      pixel_type());
  std::fflush(cimg::output());
  return *this;
}

//--------------- End of CImg plug-in ----------------------------

#else // #ifdef cimg_plugin
# 1713 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

#if 0 /* expanded by -frewrite-includes */
#include "gmic.h"
#endif /* expanded by -frewrite-includes */
# 1715 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#if defined(gmic_float)
#if 0 /* expanded by -frewrite-includes */
#include "gmic_def.h"
#endif /* expanded by -frewrite-includes */
# 1717 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#else // #ifdef gmic_float
# 1718 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
extern char data_gmic_def[];
extern unsigned int size_data_gmic_def;
#endif // #ifdef gmic_float
# 1721 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

using namespace cimg_library;
#undef min
#undef max

// Define some useful variables and macros.
//------------------------------------------

// Ellipsize a string.
#define gmic_ellipsize(s,l) { if (l>=5 && s[l-2]) s[l-4] = s[l-3] = s[l-2] = '.'; }

// Return current selection as a selection string.
#define gmic_selection selection2string(selection,images_names,true).data()

// Return image argument as a shared or non-shared copy of one existing image.
inline bool _gmic_image_arg(const unsigned int ind, const CImg<unsigned int>& selection) {
  cimg_forY(selection,l) if (selection[l]==ind) return true;
  return false;
}
#define gmic_image_arg(ind) gmic_check(_gmic_image_arg(ind,selection)?images[ind]:\
                                       images[ind].get_shared())

// Return true if specified filename corresponds to an existing file or directory.
inline bool gmic_check_filename(const char *const filename) {
  bool res = false;
#if cimg_OS==2
  const unsigned int attr = (unsigned int)GetFileAttributesA(filename);
  res = (attr!=~0U);
#else
# 1750 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  try {
    std::FILE *file = cimg::fopen(filename,"r");
    if (file) { res = true; cimg::fclose(file); }
  } catch (CImgException&) {}
#endif
# 1755 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  return res;
}

// Manage mutexes.
struct _gmic_mutex {
#if cimg_OS==2
  HANDLE mutex[256];
  _gmic_mutex() { for (unsigned int i = 0; i<256; ++i) mutex[i] = CreateMutex(0,FALSE,0); }
  void lock(const unsigned int n) { WaitForSingleObject(mutex[n],INFINITE); }
  void unlock(const unsigned int n) { ReleaseMutex(mutex[n]); }
#elif defined(_PTHREAD_H)
# 1766 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  pthread_mutex_t mutex[256];
  _gmic_mutex() { for (unsigned int i = 0; i<256; ++i) pthread_mutex_init(&mutex[i],0); }
  void lock(const unsigned int n) { pthread_mutex_lock(&mutex[n]); }
  void unlock(const unsigned int n) { pthread_mutex_unlock(&mutex[n]); }
#else
# 1771 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  _gmic_mutex() {}
  void lock(const unsigned int) {}
  void unlock(const unsigned int) {}
#endif
# 1775 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
};
inline _gmic_mutex& gmic_mutex() { static _gmic_mutex val; return val; }

// Code for managing argument substitutions from a command.
inline const char *gmic_ellipsize_arg(const char *const argument, CImg<char>& argument_text) {
  if (argument_text) return argument_text;
  const unsigned int l = std::strlen(argument);
  if (l>=72) {
    argument_text.assign(72);
    std::memcpy(argument_text.data(),argument,32);
    std::memcpy(argument_text.data()+32," ... ",5);
    std::memcpy(argument_text.data()+37,argument+l-34,35); // Last '\0' is included.
  }
  return argument_text?argument_text:argument;
}

#define gmic_substitute_args() { \
  const char *const argument0 = argument; \
  substitute_item(argument,images,images_names,variables_sizes).move_to(_argument); \
  argument_text = gmic_ellipsize_arg(argument=argument_text=_argument,_argument_text); \
  if (is_debug) { \
    if (std::strcmp(argument,argument0)) debug(images,"Command '%s': arguments = '%s' -> '%s'.", \
                                               command,argument0,argument); \
    else debug(images,"Command '%s': arguments = '%s'.", \
               command,argument0); \
  }}

// Code for having 'get' or 'non-get' versions of G'MIC commands.
#define gmic_apply(instance,function) { \
  unsigned int posi = 0; \
  const bool is_inlist = images.contains(gmic_check(instance),posi); \
  if (is_get_version) { \
    instance.get_##function.move_to(images); \
    if (is_inlist) images_names[posi].get_copymark().mark().move_to(images_names); \
    else CImg<char>::string("[unnamed]").move_to(images_names); \
  } else { instance.function; images_names[posi].mark(); } \
}

// Code for simple commands that has no arguments and act on images.
#define gmic_simple_item(option,function,description) \
  if (!std::strcmp(option,command)) { \
    print(images,description,gmic_selection); \
    cimg_forY(selection,l) gmic_apply(images[selection[l]],function()); \
    is_released = false; continue; \
}

// Code for the type cast command.
#define gmic_cast(pixel_type,st_type) \
  if (!std::strcmp(argument,#pixel_type)) { \
    if (std::strcmp(st_type,cimg::type<T>::string())) { \
      if (!is_default_type) { --position; break; } \
      else { \
        print(images,"Set pixel data type to '%s'.",st_type); \
        CImgList<pixel_type> cast_images; \
        images.move_to(cast_images); \
        is_default_type = false; \
        is_released = false; \
        _parse_##pixel_type(commands_line,++position,cast_images,images_names,variables_sizes); \
        is_default_type = true; \
        cast_images.move_to(images); \
      } \
    } else { print(images,"Set pixel data type to '%s'.",st_type); ++position; } \
    continue; \
  }

// Code for G'MIC arithmetic commands.
#define gmic_arithmetic_item(command_name,\
                             function1,description1,arg1_1,arg1_2,arg1_3,value_type1, \
                             function2,description2,arg2_1,arg2_2, \
                             description3,arg3_1,arg3_2, \
                             description4) \
 if (!std::strcmp(command_name,command)) { \
   gmic_substitute_args(); \
   CImg<unsigned int> ind; \
   double value = 0; \
   char sep = 0; \
   *indices = *formula = 0; \
   if (std::sscanf(argument,"%lf%c",&value,&end)==1 || \
       (std::sscanf(argument,"%lf%c%c",&value,&sep,&end)==2 && sep=='%')) { \
      const char *const ssep = sep=='%'?"%":""; \
      print(images,description1 ".",arg1_1,arg1_2,arg1_3); \
      cimg_forY(selection,l) { \
       CImg<T>& img = gmic_check(images[selection[l]]); \
       double nvalue = value; \
       if (sep=='%' && img) { \
         double vmin = 0, vmax = (double)img.max_min(vmin); \
         nvalue = vmin + (vmax-vmin)*value/100; \
       } \
       if (is_get_version) { \
         images_names.insert(images_names[selection[l]].get_copymark().mark()); \
         images.insert(img); images.back().function1((value_type1)nvalue); \
       } else { \
         images_names[selection[l]].mark(); \
         img.function1((value_type1)nvalue); \
       } \
      } \
      ++position; \
   } else if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 && \
              sep==']' \
              && (ind=selection2cimg(indices,images.size(),images_names,command_name,\
                                     true,false,CImg<char>::empty())).  \
              height()==1) { \
     print(images,description2 ".",arg2_1,arg2_2); \
     const CImg<T> img0 = gmic_image_arg(*ind); \
     cimg_forY(selection,l) { \
       CImg<T>& img = gmic_check(images[selection[l]]); \
       if (is_get_version) { \
         images_names.insert(images_names[selection[l]].get_copymark().mark()); \
         images.insert(img); images.back().function2(img0); \
       } else { \
         images_names[selection[l]].mark(); img.function2(img0); \
       } \
     } \
     ++position; \
   } else if (std::sscanf(argument,"'%4095[^']%c%c",formula,&sep,&end)==2 && sep=='\'') { \
     gmic_strreplace(formula); print(images,description3 ".",arg3_1,arg3_2); \
     cimg_forY(selection,l) { \
       CImg<T>& img = gmic_check(images[selection[l]]); \
       if (is_get_version) { \
         images_names.insert(images_names[selection[l]].get_copymark().mark()); \
         images.insert(img); images.back().function2((const char*)formula); \
       } else { \
         images_names[selection[l]].mark(); img.function2((const char*)formula); \
       } \
     } \
     ++position; \
   } else { \
     print(images,description4 ".",gmic_selection); \
     if (images && selection) { \
       if (is_get_version) { \
         CImg<T> img0 = CImg<T>(gmic_check(images[selection[0]]),false); \
         for (unsigned int l = 1; l<(unsigned int)selection.height(); ++l) \
           img0.function2(gmic_check(images[selection[l]])); \
         images_names.insert(images_names[selection[0]].get_copymark().mark()); \
         img0.move_to(images); \
       } else if (selection.height()>=2) { \
       const unsigned int ind0 = selection[0]; \
       CImg<T>& img0 = gmic_check(images[ind0]); \
       for (unsigned int l = 1; l<(unsigned int)selection.height(); ++l) \
         img0.function2(gmic_check(images[selection[l]])); \
       images_names[ind0].mark(); \
       remove_images(images,images_names,selection,1,selection.height()-1); \
       }}} is_released = false; continue; \
   }

// Return a 8-bits hashcode from a string.
//----------------------------------------
inline unsigned int gmic_hashcode(const char *const str, const bool is_variable) {
  if (!str) return 0;
  unsigned int hash = 0;
  if (is_variable) {
    if (*str=='_') return 255;
    for (const char *s = str; *s; ++s) hash+=*s;
    return hash%255;
  }
  for (const char *s = str; *s; ++s) hash+=*s;
  return hash&255;
}

// Tells if the the implementation of a G'MIC command contains arguments.
//------------------------------------------------------------------------
inline bool gmic_command_has_arguments(const char *const command) {
  if (!command || !*command) return false;
  for (const char *s = std::strchr(command,'$'); s; s = std::strchr(s,'$')) {
    const char c = *(++s);
    if (c=='#' ||
        c=='*' ||
        c=='=' ||
        (c>'0' && c<='9') ||
        (c=='-' && *(s+1)>'0' && *(s+1)<='9') ||
        (c=='\"' && *(s+1)=='*' && *(s+2)=='\"') ||
        (c=='{' && (*(s+1)=='^' ||
                    (*(s+1)>'0' && *(s+1)<='9') ||
                    (*(s+1)=='-' && *(s+2)>'0' && *(s+2)<='9')))) return true;
  }
  return false;
}

// Compute the basename of a filename.
//------------------------------------
inline const char* gmic_basename(const char *const s)  {
  if (!s) return s;
  const unsigned int l = (unsigned int)std::strlen(s);
  if (*s=='[' && (s[l-1]==']' || s[l-1]=='.')) return s;
  const char *p = 0;
  for (const char *np = s; np>=s && (p=np); np = std::strchr(np,cimg_file_separator)+1) {}
  return p;
}

// Thread structure and routine for command '-parallel'.
//------------------------------------------------------
template<typename T>
struct st_gmic_parallel {
  gmic gmic_instance;
  CImgList<T> *images;
  CImgList<char> *images_names, commands_line;
  unsigned int variables_sizes[256], wait_mode;
  gmic_exception exception;
#ifdef gmic_is_parallel
#if cimg_OS!=2
  pthread_t thread_id;
#else
# 1977 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  HANDLE thread_id;
#endif // #if cimg_OS!=2
# 1979 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#endif // #ifdef gmic_is_parallel
# 1980 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
};

template<typename T>
#if cimg_OS!=2
static void *gmic_parallel(void *arg)
#else
# 1986 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
static DWORD WINAPI gmic_parallel(void *arg)
#endif
# 1988 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
{
  st_gmic_parallel<T> &st = *(st_gmic_parallel<T>*)arg;
  unsigned int pos = 0;
  try {
    st.gmic_instance._parse(st.commands_line,pos,*st.images,*st.images_names,st.variables_sizes);
  } catch (gmic_exception &e) {
    st.exception._command_help.assign(e._command_help);
    st.exception._message.assign(e._message);
  }
#if defined(gmic_is_parallel) && cimg_OS!=2
  pthread_exit(0);
#else
# 2000 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  return 0;
#endif
# 2002 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
}

// Return Levenshtein distance between two strings.
// (adapted from http://rosettacode.org/wiki/Levenshtein_distance#C)
//------------------------------------------------------------------
static int _gmic_levenshtein(const char *const s, const char *const t,
                             CImg<int>& d, const int i, const int j) {
  const int ls = d.width()-1, lt = d.height()-1;
  if (d(i,j)>=0) return d(i,j);
  int x;
  if (i==ls) x = lt - j;
  else if (j==lt) x = ls - i;
  else if (s[i]==t[j]) x = _gmic_levenshtein(s,t,d,i+1,j+1);
  else {
    x = _gmic_levenshtein(s,t,d,i+1,j+1);
    int y;
    if ((y=_gmic_levenshtein(s,t,d,i,j+1))<x) x = y;
    if ((y=_gmic_levenshtein(s,t,d,i+1,j))<x) x = y;
    ++x;
  }
  return d(i,j) = x;
}

inline int gmic_levenshtein(const char *const s, const char *const t) {
  const char *const ns = s?s:"", *const nt = t?t:"";
  const int ls = std::strlen(ns), lt = std::strlen(nt);
  if (!ls) return lt; else if (!lt) return ls;
  CImg<int> d(1+ls,1+lt,1,1,-1);
  return _gmic_levenshtein(ns,nt,d,0,0);
}

// Constructors / destructors.
//----------------------------
#if defined(gmic_float) || !defined(gmic_split_compilation)

gmic::gmic():gmic_new_attr {}

gmic::~gmic() {
  debug("%sEnd G'MIC instance.%s\n",cimg::t_bold,cimg::t_normal);
  delete[] commands;
  delete[] commands_names;
  delete[] commands_has_arguments;
  delete[] _variables;
  delete[] _variables_names;
  delete[] variables;
  delete[] variables_names;
}

gmic::gmic(const char *const commands_line, const char *const custom_commands,
           const bool include_default_commands, float *const p_progress, int *const p_cancel):gmic_new_attr {
  CImgList<float> images;
  CImgList<char> images_names;
  _gmic(commands_line,images,images_names,custom_commands,include_default_commands,
        p_progress,p_cancel);
}

// Get current scope as a string.
//-------------------------------
CImg<char> gmic::scope2string(const bool is_last_slash) const {
  CImgList<char> res;
  const unsigned int siz = (unsigned int)scope.size();
  if (siz<=8) res.assign(scope);
  else {
    res.assign(8);
    res[0].assign(scope[0]);
    res[1].assign(scope[1]);
    res[2].assign(scope[2]);
    res[3].assign("..",3);
    res[4].assign(scope[siz-4]);
    res[5].assign(scope[siz-3]);
    res[6].assign(scope[siz-2]);
    res[7].assign(scope[siz-1]);
  }
  cimglist_for(res,l) res[l].back() = '/';
  if (!is_last_slash) --(res.back()._width);
  CImg<char>::vector(0).move_to(res);
  return res>'x';
}

CImg<char> gmic::scope2string(const CImg<unsigned int>& scope_selection,
                              const bool is_last_slash) const {
  const CImg<char> def_scope("./",3);
  if (!scope_selection) return def_scope;
  CImgList<char> res(scope_selection.height());
  cimglist_for(res,l) res[l].assign(scope[scope_selection(l)]).back() = '/';
  if (!is_last_slash) --(res.back()._width);
  CImg<char>::vector(0).move_to(res);
  return res>'x';
}

// Parse items from a G'MIC command line.
//---------------------------------------
CImgList<char> gmic::commands_line_to_CImgList(const char *const commands_line) {
  if (!commands_line || !*commands_line) return CImgList<char>();
  bool is_dquoted = false;
  const char *ptrs0 = commands_line;
  while (*ptrs0==' ') ++ptrs0;  // Remove leading spaces to first item.
  CImg<char> item(std::strlen(ptrs0)+1);
  CImgList<char> items;
  char *ptrd = item.data(), c = 0;
  for (const char *ptrs = ptrs0; *ptrs; ++ptrs) {
    c = *ptrs;
    if (c=='\\') { // If escaped character.
      c = *(++ptrs);
      if (!c) { c = '\\'; --ptrs; }
      else if (c=='$') c = _dollar;
      else if (c=='{') c = _lbrace;
      else if (c=='}') c = _rbrace;
      else if (c==',') c = _comma;
      else if (c=='\"') c = _dquote;
      else if (c=='@') c = _arobace;
      else if (c==' ') c = ' ';
      else *(ptrd++) = '\\';
      *(ptrd++) = c;
    } else if (is_dquoted) { // If non-escaped character inside string.
      if (c=='\"') is_dquoted = false;
      else if (c==1) while (c!=' ') c = *(++ptrs); // Discard debug infos inside string.
      else *(ptrd++) = c=='$'?_dollar:c=='{'?_lbrace:c=='}'?_rbrace:
             c==','?_comma:c=='@'?_arobace:c;
    } else { // Non-escaped character outside string.
      if (c=='\"') is_dquoted = true;
      else if (c==' ') {
        *ptrd = 0; CImg<char>(item.data(),ptrd - item.data() + 1).move_to(items);
        ptrd = item.data();
        ++ptrs; while (*ptrs==' ') ++ptrs; ptrs0 = ptrs--;  // Remove trailing spaces to next item.
      } else *(ptrd++) = c;
    }
  }
  if (is_dquoted) error("Invalid command line: Double quotes are not closed, in expression '%s'.",
                        commands_line);
  if (ptrd!=item.data() && c!=' ') {
    *ptrd = 0; CImg<char>(item.data(),ptrd - item.data() + 1).move_to(items);
  }
  if (is_debug) {
    debug("Decompose command line into %u items: ",items.size());
    cimglist_for(items,l) {
      if (items(l,0)==1) debug("  item[%u] = (debug info 0x%s)",l,items[l].data()+1);
      else debug("  item[%u] = '%s'",l,items[l].data());
    }
  }
  return items;
}

// Print log message.
//-------------------
gmic& gmic::print(const char *format, ...) {
  if (verbosity<0 && !is_debug) return *this;
  va_list ap;
  va_start(ap,format);
  CImg<char> message(16384,1,1,1,0);
  cimg_vsnprintf(message,message.width(),format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  gmic_strreplace(message);
  if (*message!='\r')
    for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
  nb_carriages = 1;
  std::fprintf(cimg::output(),
               "[gmic]%s %s",
               scope2string().data(),message.data());
  std::fflush(cimg::output());
  return *this;
}

// Print warning message.
//-----------------------
gmic& gmic::warn(const char *format, ...) {
  if (verbosity<0 && !is_debug) return *this;
  va_list ap;
  va_start(ap,format);
  CImg<char> message(1024+512,1,1,1,0);
  cimg_snprintf(message,512,"*** Warning in %s *** ",scope2string().data());
  cimg_vsnprintf(message.data() + std::strlen(message),1024,format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  gmic_strreplace(message);
  if (*message!='\r')
    for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
  nb_carriages = 1;
  std::fprintf(cimg::output(),
               "%s[gmic]%s %s%s%s",
               cimg::t_red,scope2string().data(),cimg::t_bold,message.data(),cimg::t_normal);
  std::fflush(cimg::output());
  return *this;
}

// Print error message, and quit interpreter.
//-------------------------------------------
gmic& gmic::error(const char *const format, ...) {
  va_list ap;
  va_start(ap,format);
  CImg<char> message(1024+512,1,1,1,0);
  if (debug_filename<commands_files.size() && debug_line!=~0U)
    cimg_snprintf(message,512,"*** Error in %s (file '%s', %sline %u) *** ",
                  scope2string().data(),commands_files[debug_filename].data(),
                  is_debug_infos?"":"call from ",debug_line);
  else cimg_snprintf(message,512,"*** Error in %s *** ",scope2string().data());
  cimg_vsnprintf(message.data() + std::strlen(message),1024,format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  gmic_strreplace(message);
  if (verbosity>=0 || is_debug) {
    if (*message!='\r')
      for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
    nb_carriages = 1;
    std::fprintf(cimg::output(),"[gmic]%s %s%s%s%s",
                 scope2string().data(),cimg::t_bold,cimg::t_red,message.data(),cimg::t_normal);
    std::fflush(cimg::output());
  }
  message.move_to(status);
  throw gmic_exception(0,status);
  return *this;
}

// Print debug message.
//---------------------
gmic& gmic::debug(const char *format, ...) {
  if (!is_debug) return *this;
  va_list ap;
  va_start(ap,format);
  CImg<char> message(1024,1,1,1,0);
  cimg_vsnprintf(message,message.width(),format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  if (*message!='\r')
    for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
  nb_carriages = 1;
  std::fprintf(cimg::output(),
               "%s<gmic>%s ",
               cimg::t_green,scope2string().data());
  for (char *s = message; *s; ++s) {
    char c = *s;
    if (c<' ') switch (c) {
      case _dollar : std::fprintf(cimg::output(),"\\$"); break;
      case _lbrace : std::fprintf(cimg::output(),"\\{"); break;
      case _rbrace : std::fprintf(cimg::output(),"\\}"); break;
      case _comma : std::fprintf(cimg::output(),"\\,"); break;
      case _dquote : std::fprintf(cimg::output(),"\\\""); break;
      case _arobace : std::fprintf(cimg::output(),"\\@"); break;
      default : std::fputc(c,cimg::output());
      }
    else std::fputc(c,cimg::output());
  }
  std::fprintf(cimg::output(),
               "%s",
               cimg::t_normal);
  std::fflush(cimg::output());
  return *this;
}

// Add custom commands from a char* buffer.
//------------------------------------------
gmic& gmic::add_commands(const char *const data_commands,
                         CImgList<char> commands_names[256],
                         CImgList<char> commands[256],
                         CImgList<char> commands_has_arguments[256],
                         const char *const commands_file) {
  if (!data_commands || !*data_commands) return *this;
  CImg<char> com(256*1024), line(256*1024);
  char mac[256] = { 0 }, debug_info[32] = { 0 };
  unsigned int pos[256] = { 0 }, line_number = 1;
  bool is_last_slash = false, _is_last_slash = false, is_newline = false;
  int ind = -1, l_debug_info = 0;
  char sep = 0;
  if (commands_file) CImg<char>::string(commands_file).move_to(commands_files);

  for (const char *data = data_commands; *data; is_last_slash = _is_last_slash, line_number+=is_newline?1:0) {

    // Read new line.
    char *_line = line, *const line_end = line.end();
    while (*data!='\n' && *data && _line<line_end) *(_line++) = *(data++);
    if (_line<line_end) *_line = 0; else *(line_end-1) = 0;
    if (*data=='\n') { is_newline = true; ++data; } else is_newline = false; // Skip next '\n'.

    // Replace non-usual characters by spaces.
    for (_line = line; *_line; ++_line) if ((unsigned char)*_line<' ') *_line = ' ';
    _line = line; if (*_line=='#') *_line = 0; else do { // Remove comments.
        if ((_line=std::strchr(_line,'#')) && *(_line-1)==' ') { *--_line = 0; break; }
      } while (_line++);

    // Remove useless trailing spaces.
    char *linee = line.data() + std::strlen(line) - 1;
    while (linee>=line && *linee==' ') --linee; *(linee+1) = 0;
    char *lines = line; while (*lines==' ') ++lines; // Remove useless leading spaces.
    if (!*lines) continue; // Empty line.

    // Check if last character is a '\'...
    _is_last_slash = false;
    for (_line = linee; *_line=='\\' && _line>=lines; --_line) _is_last_slash = !_is_last_slash;
    if (_is_last_slash) *(linee--) = 0; // .. and remove it if necessary.
    if (!*lines) continue; // Empty line found.
    *mac = *com = 0;

    if (!is_last_slash && std::strchr(lines,':') && // Check for a command definition.
        std::sscanf(lines,"%255[a-zA-Z0-9_] %c %262143[^\n]",mac,&sep,com.data())>=2 &&
        (*lines<'0' || *lines>'9') && sep==':') {
      ind = gmic_hashcode(mac,false);
      CImg<char>::string(mac).move_to(commands_names[ind],pos[ind]);
      CImg<char> body = CImg<char>::string(com);
      CImg<char>::vector((char)gmic_command_has_arguments(body)).
        move_to(commands_has_arguments[ind],pos[ind]);
      if (commands_file) { // Insert code with debug infos.
        if (commands_files.width()<2)
          l_debug_info = cimg_snprintf(debug_info+1,sizeof(debug_info)-2,"%x",line_number);
        else
          l_debug_info = cimg_snprintf(debug_info+1,sizeof(debug_info)-2,"%x,%x",
                                            line_number,commands_files.width()-1);
        debug_info[0] = 1; debug_info[l_debug_info+1] = ' ';
        ((CImg<char>(debug_info,l_debug_info+2,1,1,1,true),body)>'x').move_to(commands[ind],pos[ind]++);
      } else body.move_to(commands[ind],pos[ind]++); // Insert code without debug infos.
    } else { // Continuation of a previous line.
      if (ind<0) error("Command '-command': Syntax error in expression '%s'.",lines);
      const unsigned int p = pos[ind] - 1;
      if (!is_last_slash) commands[ind][p].back() = ' ';
      else --(commands[ind][p]._width);
      const CImg<char> body = CImg<char>(lines,linee - lines + 2);
      commands_has_arguments[ind](p,0) |= (char)gmic_command_has_arguments(body);
      if (commands_file && !is_last_slash) { // Insert code with debug infos.
        if (commands_files.width()<2)
          l_debug_info = cimg_snprintf(debug_info+1,sizeof(debug_info)-2,"%x",line_number);
        else
          l_debug_info = cimg_snprintf(debug_info+1,sizeof(debug_info)-2,"%x,%x",
                                            line_number,commands_files.width()-1);
        debug_info[0] = 1; debug_info[l_debug_info+1] = ' ';
        ((commands[ind][p],CImg<char>(debug_info,l_debug_info+2,1,1,1,true),body)>'x').move_to(commands[ind][p]);
      } else commands[ind][p].append(body,'x'); // Insert code without debug infos.
    }
  }

  if (is_debug) {
    CImg<unsigned int> hdist(256);
    unsigned int nb_commands = 0;
    cimg_forX(hdist,i) { hdist[i] = commands[i].size(); nb_commands+=commands[i].size(); }
    const CImg<double> st = hdist.get_stats();
    debug("Distribution of command hashes: [ %s ], min = %u, max = %u, mean = %g, "
          "std = %g (%u commands).",
          hdist.value_string().data(),(unsigned int)st[0],(unsigned int)st[1],st[2],
          std::sqrt(st[3]),nb_commands);
  }
  return *this;
}

// Add commands from a file.
//---------------------------
gmic& gmic::add_commands(std::FILE *const file,
                         const char *const filename,
                         CImgList<char> commands_names[256],
                         CImgList<char> commands[256],
                         CImgList<char> commands_has_arguments[256],
                         const bool add_debug_infos) {
  if (!file) return *this;
  std::fseek(file,0,SEEK_END);
  const long siz = std::ftell(file);
  std::rewind(file);
  if (siz>0) {
    CImg<char> buffer(siz+1);
    if (std::fread(buffer.data(),sizeof(char),siz,file)) {
      buffer[siz] = 0;
      try { add_commands(buffer.data(),commands_names,commands,commands_has_arguments,
                         add_debug_infos?(filename?filename:"(FILE*)"):0); }
      catch (...) { std::fclose(file); throw; }
    }
  }
  return *this;
}

// Return subset indices from a selection string.
//-----------------------------------------------
CImg<unsigned int> gmic::selection2cimg(const char *const string, const unsigned int indice_max,
                                        const CImgList<char>& names,
                                        const char *const command, const bool is_selection,
                                        const bool allow_new_name, CImg<char> &new_name) {
  if (string && !*string) return CImg<unsigned int>(); // Empty selection.
  if (!string || (*string=='^' && !string[1])) { // Whole selection.
    if (indice_max) return CImg<unsigned int>::sequence(indice_max,0,indice_max-1);
    else return CImg<unsigned int>();
  }
  const char *const stype = is_selection?"selection":"subset";
  const int
    ctypel = is_selection?'[':'{',
    ctyper = is_selection?']':'}';
  CImg<bool> is_selected(1,indice_max,1,1,false);

  bool is_inverse = *string=='^';
  const char *it = string + (is_inverse?1:0);
  for (bool stopflag = false; !stopflag; ) {
    CImg<char> name(256), item;
    float ind0 = 0, ind1 = 0, step = 1;
    int iind0 = 0, iind1 = 0;
    bool is_label = false;
    char sep = 0;

    const char *const it_comma = std::strchr(it,',');
    if (it_comma) { item.assign(it,it_comma-it+1); item.back() = 0; it = it_comma + 1; }
    else { CImg<char>::string(it).move_to(item); stopflag = true; }

    char end, *const it_colon = std::strchr(item,':');
    if (it_colon) {
      *it_colon = 0;
      if (std::sscanf(it_colon+1,"%f%c",&step,&end)!=1 || step<=0)
        error("Command '%s': Invalid %s %c%s%c (syntax error after colon ':').",
              command,stype,ctypel,string,ctyper);
    }
    if (!*item) { // Particular cases [:N] or [^:N].
      if (is_inverse) { iind0 = 0; iind1 = -1; is_inverse = false; }
      else continue;
    } else if (std::sscanf(item,"%f%c",&ind0,&end)==1) { // Single indice.
      iind1 = iind0 = (int)cimg::round(ind0);
    } else if (std::sscanf(item,"%f-%f%c",&ind0,&ind1,&end)==2) { // Sequence between 2 indices.
      iind0 = (int)cimg::round(ind0);
      iind1 = (int)cimg::round(ind1);
    } else if (std::sscanf(item,"%255[a-zA-Z0-9_]%c",name.data(),&end)==1 && // Label.
               (*name<'0' || *name>'9')) {
      cimglist_for(names,l) if (names[l] && !std::strcmp(names[l],name)) {
        is_selected(l) = true; is_label = true;
      }
      if (!is_label) {
        if (allow_new_name && !new_name) {
          iind0 = iind1 = -1;
          CImg<char>::string(name).move_to(new_name);
        } else error("Command '%s': Invalid %s %c%s%c (undefined label '%s').",
                     command,stype,ctypel,string,ctyper,name.data());
      }
    } else if (std::sscanf(item,"%f%c%c",&ind0,&sep,&end)==2 && sep=='%') { // Single percent.
      iind1 = iind0 = (int)cimg::round(ind0*((int)indice_max-1)/100)-(ind0<0?1:0);
    } else if (std::sscanf(item,"%f%%-%f%c%c",&ind0,&ind1,&sep,&end)==3 && sep=='%') {
      // Sequence between 2 percents.
      iind0 = (int)cimg::round(ind0*((int)indice_max-1)/100)-(ind0<0?1:0);
      iind1 = (int)cimg::round(ind1*((int)indice_max-1)/100)-(ind1<0?1:0);
    } else if (std::sscanf(item,"%f%%-%f%c",&ind0,&ind1,&end)==2) {
      // Sequence between a percent and an indice.
      iind0 = (int)cimg::round(ind0*((int)indice_max-1)/100)-(ind0<0?1:0);;
      iind1 = (int)cimg::round(ind1);
    } else if (std::sscanf(item,"%f-%f%c%c",&ind0,&ind1,&sep,&end)==3 && sep=='%') {
      // Sequence between an indice and a percent.
      iind0 = (int)cimg::round(ind0);
      iind1 = (int)cimg::round(ind1*((int)indice_max-1)/100)-(ind1<0?1:0);;
    } else error("Command '%s': Invalid %s %c%s%c.",
                 command,stype,ctypel,string,ctyper);

    if (!indice_max) error("Command '%s': Invalid %s %c%s%c (no data available).",
                           command,stype,ctypel,string,ctyper);
    if (!is_label) {
      int
        uind0 = iind0<0?iind0+indice_max:iind0,
        uind1 = iind1<0?iind1+indice_max:iind1;
      if (uind0>uind1) { cimg::swap(uind0,uind1); cimg::swap(iind0,iind1); }
      if (uind0<0 || uind0>=(int)indice_max)
        error("Command '%s': Invalid %s %c%s%c (contains starting indice '%d', "
              "not in range -%u..%u).",
              command,stype,ctypel,string,ctyper,iind0,indice_max,indice_max-1);
      if (uind1<0 || uind1>=(int)indice_max)
        error("Command '%s': Invalid %s %c%s%c (contains ending indice '%d', "
              "not in range -%u..%u).",
              command,stype,ctypel,string,ctyper,iind1,indice_max,indice_max-1);
      const int istep = (int)cimg::round(step);
      for (int l = uind0; l<=uind1; l+=istep) is_selected[l] = true;
    }
  }
  unsigned int indice = 0;
  cimg_for(is_selected,p,bool) if (*p) ++indice;
  CImg<unsigned int> selection(1,is_inverse?indice_max-indice:indice);
  indice = 0;
  if (is_inverse) { cimg_forY(is_selected,l) if (!is_selected[l]) selection[indice++] = l; }
  else cimg_forY(is_selected,l) if (is_selected[l]) selection[indice++] = l;
  return selection;
}

// Return selection or filename strings from a set of indices.
//------------------------------------------------------------
CImg<char> gmic::selection2string(const CImg<unsigned int>& selection,
                                  const CImgList<char>& images_names,
                                  const bool display_indices) const {
  CImg<char> res(1024);
  if (display_indices) {
    switch (selection.height()) {
    case 0: cimg_snprintf(res.data(),res.width()," []"); break;
    case 1: cimg_snprintf(res.data(),res.width()," [%u]",
                          selection[0]); break;
    case 2: cimg_snprintf(res.data(),res.width(),"s [%u,%u]",
                          selection[0],selection[1]); break;
    case 3: cimg_snprintf(res.data(),res.width(),"s [%u,%u,%u]",
                          selection[0],selection[1],selection[2]); break;
    case 4: cimg_snprintf(res.data(),res.width(),"s [%u,%u,%u,%u]",
                          selection[0],selection[1],selection[2],selection[3]); break;
    default: cimg_snprintf(res.data(),res.width(),"s [%u,..,%u]",
                           selection[0],selection.back());
    }
    return res;
  }

  switch (selection.height()) {
  case 0:
    *res = 0;
    break;
  case 1:
    cimg_snprintf(res.data(),res.width(),"%s%s",
                  gmic_basename(images_names[selection[0]].data()),
                  images_names[selection[0]].back()?"*":"");
    break;
  case 2:
    cimg_snprintf(res.data(),res.width(),"%s%s, %s%s",
                  gmic_basename(images_names[selection[0]].data()),
                  images_names[selection[0]].back()?"*":"",
                  gmic_basename(images_names[selection[1]].data()),
                  images_names[selection[1]].back()?"*":"");
    break;
  case 3:
    cimg_snprintf(res.data(),res.width(),"%s%s, %s%s, %s%s",
                  gmic_basename(images_names[selection[0]].data()),
                  images_names[selection[0]].back()?"*":"",
                  gmic_basename(images_names[selection[1]].data()),
                  images_names[selection[1]].back()?"*":"",
                  gmic_basename(images_names[selection[2]].data()),
                  images_names[selection[2]].back()?"*":"");
    break;
  case 4:
    cimg_snprintf(res.data(),res.width(),"%s%s, %s%s, %s%s, %s%s",
                  gmic_basename(images_names[selection[0]].data()),
                  images_names[selection[0]].back()?"*":"",
                  gmic_basename(images_names[selection[1]].data()),
                  images_names[selection[1]].back()?"*":"",
                  gmic_basename(images_names[selection[2]].data()),
                  images_names[selection[2]].back()?"*":"",
                  gmic_basename(images_names[selection[3]].data()),
                  images_names[selection[3]].back()?"*":"");
    break;
  default:
    cimg_snprintf(res.data(),res.width(),"%s%s, .., %s%s",
                  gmic_basename(images_names[selection[0]].data()),
                  images_names[selection[0]].back()?"*":"",
                  gmic_basename(images_names[selection.back()].data()),
                  images_names[selection.back()].back()?"*":"");
  }
  return res;
}

#endif // #if defined(gmic_float) || !defined(gmic_split_compilation)
# 2540 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

// Print log message.
//-------------------
template<typename T>
gmic& gmic::print(const CImgList<T>& list, const char *format, ...) {
  if (verbosity<0 && !is_debug) return *this;
  va_list ap;
  va_start(ap,format);
  CImg<char> message(16384,1,1,1,0);
  cimg_vsnprintf(message,message.width(),format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  gmic_strreplace(message);
  if (*message!='\r')
    for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
  nb_carriages = 1;
  std::fprintf(cimg::output(),
               "[gmic]-%u%s %s",
               list.size(),scope2string().data(),message.data());
  std::fflush(cimg::output());
  return *this;
}

template<typename T>
gmic& gmic::print(const CImgList<T>& list, const CImg<unsigned int>& scope_selection,
                  const char *format, ...) {
  if (verbosity<0 && !is_debug) return *this;
  va_list ap;
  va_start(ap,format);
  CImg<char> message(16384,1,1,1,0);
  cimg_vsnprintf(message,message.width(),format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  gmic_strreplace(message);
  if (*message!='\r')
    for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
  nb_carriages = 1;
  if (scope_selection)
    std::fprintf(cimg::output(),
                 "[gmic]-%u%s %s",
                 list.size(),scope2string(scope_selection).data(),message.data());
  else std::fprintf(cimg::output(),"%s",message.data());
  std::fflush(cimg::output());
  return *this;
}

// Print warning message.
//-----------------------
template<typename T>
gmic& gmic::warn(const CImgList<T>& list, const char *format, ...) {
  if (verbosity<0 && !is_debug) return *this;
  va_list ap;
  va_start(ap,format);
  CImg<char> message(1024+512,1,1,1,0);
  cimg_snprintf(message,512,"*** Warning in %s *** ",scope2string().data());
  cimg_vsnprintf(message.data() + std::strlen(message),1024,format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  gmic_strreplace(message);
  if (*message!='\r')
    for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
  nb_carriages = 1;
  std::fprintf(cimg::output(),
               "[gmic]-%u%s %s%s%s%s",
               list.size(),scope2string().data(),cimg::t_bold,cimg::t_red,message.data(),cimg::t_normal);
  std::fflush(cimg::output());
  return *this;
}

template<typename T>
gmic& gmic::warn(const CImgList<T>& list, const CImg<unsigned int>& scope_selection,
                 const char *format, ...) {
  if (verbosity<0 && !is_debug) return *this;
  va_list ap;
  va_start(ap,format);
  CImg<char> message(1024+512,1,1,1,0);
  cimg_snprintf(message,512,"*** Warning in %s *** ",scope2string(scope_selection).data());
  cimg_vsnprintf(message.data() + std::strlen(message),1024,format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  gmic_strreplace(message);
  if (*message!='\r')
    for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
  nb_carriages = 1;
  if (scope_selection)
    std::fprintf(cimg::output(),
                 "[gmic]-%u%s %s%s%s%s",
                 list.size(),scope2string(scope_selection).data(),
                 cimg::t_bold,cimg::t_red,message.data(),cimg::t_normal);
  else std::fprintf(cimg::output(),
                    "%s%s%s%s",
                    cimg::t_bold,cimg::t_red,message.data(),cimg::t_normal);
  std::fflush(cimg::output());
  return *this;
}

// Print error message, and quit interpreter.
//-------------------------------------------
template<typename T>
gmic& gmic::error(const CImgList<T>& list, const char *const format, ...) {
  va_list ap;
  va_start(ap,format);
  CImg<char> message(1024+512,1,1,1,0);
  if (debug_filename<commands_files.size() && debug_line!=~0U)
    cimg_snprintf(message,512,"*** Error in %s (file '%s', %sline %u) *** ",
                  scope2string().data(),commands_files[debug_filename].data(),
                  is_debug_infos?"":"call from ",debug_line);
  else
    cimg_snprintf(message,512,"*** Error in %s *** ",scope2string().data());
  cimg_vsnprintf(message.data() + std::strlen(message),1024,format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  gmic_strreplace(message);
  if (verbosity>=0 || is_debug) {
    if (*message!='\r')
      for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
    nb_carriages = 1;
    std::fprintf(cimg::output(),
                 "[gmic]-%u%s %s%s%s%s",
                 list.size(),scope2string().data(),
                 cimg::t_bold,cimg::t_red,message.data(),cimg::t_normal);
    std::fflush(cimg::output());
  }
  message.move_to(status);
  throw gmic_exception(0,status);
  return *this;
}

template<typename T>
gmic& gmic::error(const char *const command, const CImgList<T>& list,
                  const char *const format, ...) {
  va_list ap;
  va_start(ap,format);
  CImg<char> message(1024+512,1,1,1,0);
  if (debug_filename<commands_files.size() && debug_line!=~0U)
    cimg_snprintf(message,512,"*** Error in %s (file '%s', %sline %u) *** ",
                  scope2string().data(),commands_files[debug_filename].data(),
                  is_debug_infos?"":"call from ",debug_line);
  else
    cimg_snprintf(message,512,"*** Error in %s *** ",scope2string().data());
  cimg_vsnprintf(message.data() + std::strlen(message),1024,format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  gmic_strreplace(message);
  if (verbosity>=0 || is_debug) {
    if (*message!='\r')
      for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
    nb_carriages = 1;
    std::fprintf(cimg::output(),
                 "[gmic]-%u%s %s%s%s%s",
                 list.size(),scope2string().data(),
                 cimg::t_bold,cimg::t_red,message.data(),cimg::t_normal);
    std::fflush(cimg::output());
  }
  message.move_to(status);
  throw gmic_exception(command,status);
  return *this;
}

template<typename T>
gmic& gmic::error(const CImgList<T>& list, const CImg<unsigned int>& scope_selection,
                  const char *const format, ...) {
  va_list ap;
  va_start(ap,format);
  CImg<char> message(1024+512,1,1,1,0);
  if (debug_filename<commands_files.size() && debug_line!=~0U)
    cimg_snprintf(message,512,"*** Error in %s (file '%s', %sline %u) *** ",
                  scope2string().data(),commands_files[debug_filename].data(),
                  is_debug_infos?"":"call from ",debug_line);
  else
    cimg_snprintf(message,512,"*** Error in %s *** ",scope2string().data());
  cimg_vsnprintf(message.data() + std::strlen(message),1024,format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  gmic_strreplace(message);
  if (verbosity>=0 || is_debug) {
    if (*message!='\r')
      for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
    nb_carriages = 1;
    if (scope_selection)
      std::fprintf(cimg::output(),
                   "[gmic]-%u%s %s%s%s%s",
                   list.size(),scope2string(scope_selection).data(),
                   cimg::t_bold,cimg::t_red,message.data(),cimg::t_normal);
    else std::fprintf(cimg::output(),"%s",message.data());
    std::fflush(cimg::output());
  }
  message.move_to(status);
  throw gmic_exception(0,status);
  return *this;
}

// Print bad-argument error message, and quit interpreter.
//--------------------------------------------------------
#define arg_error(command) _arg_error(images,command,argument_text)
template<typename T>
gmic& gmic::_arg_error(const CImgList<T>& list, const char *const command,
                       const char *const argument) {
  CImg<char> message(1024,1,1,1,0);
  if (debug_filename<commands_files.size() && debug_line!=~0U)
    cimg_snprintf(message,message.width(),
                  "*** Error in %s (file '%s', %sline %u) *** Command '-%s': Invalid argument '%s'.",
                  scope2string().data(),commands_files[debug_filename].data(),
                  is_debug_infos?"":"call from ",debug_line,command,argument);
  else
    cimg_snprintf(message,message.width(),
                  "*** Error in %s *** Command '-%s': Invalid argument '%s'.",
                  scope2string().data(),command,argument);
  gmic_ellipsize(message,message.width());
  gmic_strreplace(message);
  if (verbosity>=0 || is_debug) {
    if (*message!='\r')
      for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
    nb_carriages = 1;
    std::fprintf(cimg::output(),
                 "[gmic]-%u%s %s%s%s%s",
                 list.size(),scope2string().data(),
                 cimg::t_bold,cimg::t_red,message.data(),cimg::t_normal);
    std::fflush(cimg::output());
  }
  message.move_to(status);
  throw gmic_exception(command,status);
  return *this;
}

// Print debug message.
//---------------------
template<typename T>
gmic& gmic::debug(const CImgList<T>& list, const char *format, ...) {
  if (!is_debug) return *this;
  va_list ap;
  va_start(ap,format);
  CImg<char> message(1024,1,1,1,0);
  cimg_vsnprintf(message,message.width(),format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  if (*message!='\r')
    for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
  nb_carriages = 1;
  std::fprintf(cimg::output(),
               "%s<gmic>-%u%s ",
               cimg::t_green,list.size(),scope2string().data());
  for (char *s = message; *s; ++s) {
    char c = *s;
    if (c<' ') {
      switch (c) {
      case _dollar : std::fprintf(cimg::output(),"\\$"); break;
      case _lbrace : std::fprintf(cimg::output(),"\\{"); break;
      case _rbrace : std::fprintf(cimg::output(),"\\}"); break;
      case _comma : std::fprintf(cimg::output(),"\\,"); break;
      case _dquote : std::fprintf(cimg::output(),"\\\""); break;
      case _arobace : std::fprintf(cimg::output(),"\\@"); break;
      default : std::fputc(c,cimg::output());
      }
    } else std::fputc(c,cimg::output());
  }
  std::fprintf(cimg::output(),
               "%s",
               cimg::t_normal);
  std::fflush(cimg::output());
  return *this;
}

// Check if a shared image of the image list is safe or not.
//----------------------------------------------------------
template<typename T>
inline bool gmic_is_valid_pointer(const T *const ptr) {
#if cimg_OS==1
  const int result = access((const char*)ptr,F_OK);
  if (result==-1 && errno==EFAULT) return false;
#elif cimg_OS==2
# 2811 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  return !IsBadReadPtr((void*)ptr,1);
#endif
# 2813 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  return true;
}

template<typename T>
CImg<T>& gmic::check_image(const CImgList<T>& list, CImg<T>& img) {
  check_image(list,(const CImg<T>&)img);
  return img;
}

template<typename T>
const CImg<T>& gmic::check_image(const CImgList<T>& list, const CImg<T>& img) {
#ifdef gmic_check_image
  if (!img.is_shared() || gmic_is_valid_pointer(img.data())) return img;
  if (is_debug) error(list,"Image list contains an invalid shared image (%p,%d,%d,%d,%d) "
                      "(references a deallocated buffer).",
                      img.data(),img.width(),img.height(),img.depth(),img.spectrum());
  else error(list,"Image list contains an invalid shared image (%d,%d,%d,%d) "
             "(references a deallocated buffer).",
             img.width(),img.height(),img.depth(),img.spectrum());
#else
# 2833 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  cimg::unused(list);
#endif
# 2835 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  return img;
}

#define gmic_check(img) check_image(images,img)

// Remove list of images in a selection.
//---------------------------------------
template<typename T>
gmic& gmic::remove_images(CImgList<T> &images, CImgList<char> &images_names,
                          const CImg<unsigned int>& selection,
                          const unsigned int start, const unsigned int end) {
  if (start==0 && end==(unsigned int)selection.height()-1 && selection.height()==images.width()) {
    images.assign();
    images_names.assign();
  } else for (int l = (int)end; l>=(int)start; ) {
      unsigned int eind = selection[l--], ind = eind;
      while (l>=(int)start && selection[l]==ind-1) ind = selection[l--];
      images.remove(ind,eind); images_names.remove(ind,eind);
    }
  return *this;
}

// Template constructors.
//-----------------------
template<typename T>
gmic::gmic(const int argc, const char *const *const argv,
           CImgList<T>& images, CImgList<char>& images_names,
           const char *custom_commands, const bool include_default_commands,
           float *const p_progress, int *const p_cancel):gmic_new_attr {
  CImgList<char> items;
  for (int l = 1; l<argc; ++l) {
    if (std::strchr(argv[l],' ')) {
      CImg<char>(1,1,1,1,'\"').move_to(items);
      CImg<char>(argv[l],std::strlen(argv[l])).move_to(items);
      CImg<char>::string("\"").move_to(items);
    } else CImg<char>::string(argv[l]).move_to(items);
    if (l<argc-1) items.back().back()=' ';
  }
  const CImg<char> commands_line(items>'x');
  _gmic(commands_line.data(),images,images_names,custom_commands,include_default_commands,
        p_progress,p_cancel);
}

template<typename T>
gmic::gmic(const char *const commands_line, CImgList<T>& images, CImgList<char>& images_names,
           const char *custom_commands, const bool include_default_commands,
           float *const p_progress, int *const p_cancel):gmic_new_attr {
  _gmic(commands_line,images,images_names,custom_commands,include_default_commands,
        p_progress,p_cancel);
}

template<typename T>
void gmic::_gmic(const char *const commands_line, CImgList<T>& images,
                 CImgList<char>& images_names,
                 const char *custom_commands, const bool include_default_commands,
                 float *const p_progress, int *const p_cancel) {

  // Initialize class variables and default G'MIC environment.
  setlocale(LC_NUMERIC,"C");
  cimg::srand();
  verbosity = 0;
  nb_carriages = 0;
  debug_filename = ~0U;
  debug_line = ~0U;
  is_released = true;
  is_debug = false;
  is_debug_infos = false;
  is_start = true;
  is_quit = false;
  is_return = false;
  is_double3d = true;
  is_default_type = true;
  check_elif = false;
  reference_time = cimg::time();
  background3d.assign(1,2,1,3).fill(32,64,32,116,64,96).resize(1,256,1,3,3);
  render3d = 4;
  renderd3d = -1;
  focale3d = 700;
  light3d.assign();
  light3d_x = light3d_y = 0;
  light3d_z = -5e8f;
  specular_lightness3d = 0.15f;
  specular_shininess3d = 0.8f;
  if (p_progress) progress = p_progress; else { _progress = -1; progress = &_progress; }
  if (p_cancel) cancel = p_cancel; else { _cancel = 0; cancel = &_cancel; }
  for (unsigned int l = 0; l<256; ++l) {
    commands_names[l].assign();
    commands[l].assign();
    commands_has_arguments[l].assign();
    _variables[l].assign();
    variables[l] = &_variables[l];
    _variables_names[l].assign();
    variables_names[l] = &_variables_names[l];
  }
  if (include_default_commands)
    add_commands(data_gmic_def,commands_names,commands,commands_has_arguments);
  add_commands(custom_commands,commands_names,commands,commands_has_arguments);

#if gmic_is_beta==1
  const char *const s_gmic_is_beta = "_gmic_is_beta";
  const unsigned int hashcode = gmic_hashcode(s_gmic_is_beta,true);
  CImg<char>::string(s_gmic_is_beta).move_to(*variables_names[hashcode]);
  CImg<char>::string("1").move_to(*variables[hashcode]);
#endif // #if gmic_is_beta==1
# 2939 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

  // Seek for a '-debug' option on the commands line.
  const CImgList<char> items = commands_line_to_CImgList(commands_line);
  cimglist_for(items,l) if (!std::strcmp("-debug",items[l].data())) { is_debug = true; break; }
  if (is_debug) {
    debug(images,"%sStart G'MIC instance, in debug mode.%s",cimg::t_bold,cimg::t_normal);
    debug(images,"Initial command line: '%s'.",commands_line);
    is_start = false;
  }
  if (is_debug) commands_line_to_CImgList(commands_line); // Do it twice, when debug enabled.

  // Launch the G'MIC interpreter.
  try {
    parse(items,images,images_names);
  } catch (gmic_exception &e) {
    print(images,"Abort G'MIC instance.\n");
    throw e;
  }
}

// Print infos on selected images.
//---------------------------------
template<typename T>
gmic& gmic::print_images(const CImgList<T>& images, const CImgList<char>& images_names,
                         const CImg<unsigned int>& selection, const bool is_header) {
  if (!images || !images_names || !selection) {
    if (is_header) print(images,"Print image [].");
    return *this;
  }
  char title[256] = { 0 };
  if (is_header) print(images,"Print image%s.\n",
                       gmic_selection);
  if (verbosity>=0 || is_debug) cimg_forY(selection,l) {
      const unsigned int ind = selection[l];
      const CImg<T>& img = images[ind];
      bool is_valid = true;
      int _verbosity = verbosity;
      bool _is_debug = is_debug;
      verbosity = -1; is_debug = false;
      try { gmic_check(img); } catch (gmic_exception&) { is_valid = false; }
      verbosity = _verbosity; is_debug = _is_debug;
      cimg_snprintf(title,sizeof(title),"[%u] = '%s'",
                    ind,images_names[ind].data());
      gmic_ellipsize(title,sizeof(title));
      img.gmic_print(title,is_debug,is_valid);
    }
  nb_carriages = 0;
  return *this;
}

// Display selected images.
//-------------------------
#ifdef gmic_float

template<typename T>
gmic& gmic::display_images(const CImgList<T>& images, const CImgList<char>& images_names,
                           const CImg<unsigned int>& selection, unsigned int *const XYZ) {
  if (!images || !images_names || !selection) { print(images,"Display image []."); return *this; }

  // Check for available display.
#if cimg_display==0
  print(images,"Display image%s",gmic_selection);
  if (verbosity>=0 || is_debug) {
    if (XYZ) std::fprintf(cimg::output(),", from point (%u,%u,%u)",XYZ[0],XYZ[1],XYZ[2]);
    std::fprintf(cimg::output()," (console output only, no display support).\n");
    std::fflush(cimg::output());
    print_images(images,images_names,selection,false);
  }
#else // #if cimg_display==0
# 3008 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  bool is_available_display = false;
  try {
    is_available_display = (bool)CImgDisplay::screen_width();
  } catch (CImgDisplayException&) {
    print(images,"Display image%s",gmic_selection);
    if (verbosity>=0 || is_debug) {
      if (XYZ) std::fprintf(cimg::output(),", from point (%u,%u,%u)",XYZ[0],XYZ[1],XYZ[2]);
      std::fprintf(cimg::output()," (console output only, no display available).\n");
      std::fflush(cimg::output());
      print_images(images,images_names,selection,false);
    }
  }
  if (!is_available_display) return *this;

  CImgList<T> visu;
  CImg<bool> is_valid(1,selection.height(),1,1,true);
  cimg_forY(selection,l) {
    const CImg<T>& img = images[selection[l]];
    int _verbosity = verbosity;
    bool _is_debug = is_debug;
    verbosity = -1; is_debug = false;
    try { gmic_check(img); } catch (gmic_exception&) { is_valid[l] = false; }
    verbosity = _verbosity; is_debug = _is_debug;
  }

  cimg_forY(selection,l) {
    const unsigned int ind = selection[l];
    const CImg<T>& img = images[ind];
    if (img && is_valid[l]) visu.insert(img,~0U,true);
    else visu.insert(1);
  }
  const CImg<char> _gmic_names = selection2string(selection,images_names,false);
  const char *const gmic_names = _gmic_names.data();
  print(images,"Display image%s = '%s'",gmic_selection,gmic_names);
  if (verbosity>=0 || is_debug) {
    if (XYZ) std::fprintf(cimg::output(),", from point (%u,%u,%u).\n",XYZ[0],XYZ[1],XYZ[2]);
    else std::fprintf(cimg::output(),".\n");
    std::fflush(cimg::output());
  }
  if (visu) {
    CImgDisplay _disp, &disp = instant_window[0]?instant_window[0]:_disp;
    char title[256] = { 0 };
    if (visu.size()==1)
      cimg_snprintf(title,sizeof(title),"%s (%dx%dx%dx%d)",
                    gmic_names,
                    visu[0].width(),visu[0].height(),visu[0].depth(),visu[0].spectrum());
    else
      cimg_snprintf(title,sizeof(title),"%s (%u)",
                    gmic_names,visu.size());
    gmic_ellipsize(title,sizeof(title));
    CImg<bool> is_shared(visu.size());
    cimglist_for(visu,l) {
      is_shared[l] = visu[l].is_shared();
      visu[l]._is_shared = images[selection[l]].is_shared();
    }
    print_images(images,images_names,selection,false);
    if (disp) visu.display(disp.set_title("%s",title),false,'x',0.5f,XYZ);
    else visu.display(title,false,'x',0.5f,XYZ);
    nb_carriages = 0;
    cimglist_for(visu,l) visu[l]._is_shared = is_shared(l);
  }
#endif // #if cimg_display==0
# 3070 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  return *this;
}

// Display plots of selected images.
//----------------------------------
template<typename T>
gmic& gmic::display_plots(const CImgList<T>& images, const CImgList<char>& images_names,
                          const CImg<unsigned int>& selection,
                          const unsigned int plot_type, const unsigned int vertex_type,
                          const double xmin, const double xmax,
                          const double ymin, const double ymax) {
  if (!images || !images_names || !selection) { print(images,"Plot image []."); return *this; }
#if cimg_display==0
  print(images,"Plot image%s (console output only, no display support).\n",gmic_selection);
  print_images(images,images_names,selection,false);
  cimg::unused(plot_type,vertex_type,xmin,xmax,ymin,ymax);
#else // #if cimg_display==0
# 3087 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  bool is_available_display = false;
  try {
    is_available_display = (bool)CImgDisplay::screen_width();
  } catch (CImgDisplayException&) {
    print(images,"Plot image%s (console output only, no display available).",gmic_selection);
    print_images(images,images_names,selection,false);
  }
  if (!is_available_display) return *this;

  CImgList<unsigned int> empty_indices;
  cimg_forY(selection,l) if (!gmic_check(images[selection(l)]))
    CImg<unsigned int>::vector(selection(l)).move_to(empty_indices);
  if (empty_indices) {
    const CImg<char> _eselec = selection2string(empty_indices>'y',images_names,true);
    const char *const eselec = _eselec.data();
    warn(images,"Command '-plot': Image%s %s empty.",
         eselec,empty_indices.size()>1?"are":"is");
  }

  CImgDisplay _disp, &disp = instant_window[0]?instant_window[0]:_disp;
  cimg_forY(selection,l) {
    const unsigned int ind = selection[l];
    const CImg<T>& img = images[ind];
    if (img) {
      print(images,"Plot image%s = '%s'.",gmic_selection,
            selection2string(selection,images_names,false).data());
      if (verbosity>=0 || is_debug) {
        std::fputc('\n',cimg::output());
        std::fflush(cimg::output());
        img.print(images_names[ind].data());
      }
      if (!disp) disp.assign(cimg_fitscreen(640,480,1),0,0);
      img.display_graph(disp.set_title("%s%s (%dx%dx%dx%d)",
                                       gmic_basename(images_names[ind].data()),
                                       images_names[ind].back()?"*":"",
                                       img.width(),img.height(),img.depth(),img.spectrum()),
                        plot_type,vertex_type,0,xmin,xmax,0,ymin,ymax);
      nb_carriages = 0;
    }
  }
#endif // #if cimg_display==0
# 3128 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  return *this;
}

// Display selected 3d objects.
//-----------------------------
template<typename T>
gmic& gmic::display_objects3d(const CImgList<T>& images, const CImgList<char>& images_names,
                              const CImg<unsigned int>& selection) {
  if (!images || !images_names || !selection) {
    print(images,"Display 3d object [].");
    return *this;
  }
  char message[1024] = { 0 };
  cimg_forY(selection,l) if (!gmic_check(images[selection[l]]).is_CImg3d(true,message))
    error(images,"Command '-display3d': Invalid 3d object [%d] in selected image%s (%s).",
          selection[l],gmic_selection,message);
#if cimg_display==0
  print(images,"Display 3d object%s (skipped, no display support).",gmic_selection);
#else // #if cimg_display==0
# 3147 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  bool is_available_display = false;
  try {
    is_available_display = (bool)CImgDisplay::screen_width();
  } catch (CImgDisplayException&) {
    print(images,"Display 3d object%s (skipped, no display available).",gmic_selection);
  }
  if (!is_available_display) return *this;

  CImgDisplay _disp, &disp = instant_window[0]?instant_window[0]:_disp;
  cimg_forY(selection,l) {
    const unsigned int ind = selection[l];
    const CImg<T>& img = images[ind];
    if (!disp) disp.assign(cimg_fitscreen(640,480,1),0,0);
    CImg<unsigned char> background = background3d.get_resize(disp.width(),disp.height(),1,3);
    background.display(disp);
    CImgList<unsigned int> primitives;
    CImgList<unsigned char> colors;
    CImgList<float> opacities;
    CImg<float> vertices(img,false);
    float _pose3d[16] = { 1,0,0,0, 0,1,0,0, 0,0,1,0, 0,0,0,1 };
    if (pose3d) std::memcpy(_pose3d,pose3d.data(),16*sizeof(float));
    vertices.CImg3dtoobject3d(primitives,colors,opacities,false);
    print(images,"Display 3d object [%u] = '%s%s' (%d vertices, %u primitives).",
          ind,images_names[ind].data(),
          images_names[ind].back()?"*":"",
          vertices.width(),primitives.size());
    disp.set_title("%s%s (%d vertices, %u primitives)",
                   gmic_basename(images_names[ind].data()),
                   images_names[ind].back()?"*":"",
                   vertices.width(),primitives.size());
    if (light3d) colors.insert(light3d,~0U,true);
    background.display_object3d(disp,vertices,primitives,colors,opacities,
                                !(bool)pose3d,render3d,renderd3d,is_double3d,focale3d,
                                light3d_x,light3d_y,light3d_z,
                                specular_lightness3d,specular_shininess3d,
                                true,_pose3d);
    print(images,"Selected 3d pose = [ %g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g ].",
          _pose3d[0],_pose3d[1],_pose3d[2],_pose3d[3],
          _pose3d[4],_pose3d[5],_pose3d[6],_pose3d[7],
          _pose3d[8],_pose3d[9],_pose3d[10],_pose3d[11],
          _pose3d[12],_pose3d[13],_pose3d[14],_pose3d[15]);
    if (disp.is_closed()) break;
  }
#endif // #if cimg_display==0
# 3191 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  return *this;
}

#endif // #ifdef gmic_float
# 3195 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

// Substitute '@', '{}' and '$' expressions in a string.
//-------------------------------------------------------
template<typename T>
CImg<char> gmic::substitute_item(const char *const source,
                                 CImgList<T>& images,
                                 CImgList<char>& images_names,
                                 unsigned int variables_sizes[256]) {
  if (!source) return CImg<char>();
  CImgList<char> substituted_items;
  CImg<char> inbraces;

  for (const char *nsource = source; *nsource; )
    if (*nsource!='@' && *nsource!='{' && *nsource!='$') {
      // If not starting with '@', '{', or '$'.
      const char *const nsource0 = nsource;
      do { ++nsource; } while (*nsource && *nsource!='@' && *nsource!='{' && *nsource!='$');
      CImg<char>(nsource0,nsource - nsource0).move_to(substituted_items);
    } else { // '@', '{}' or '$' expression found.
      CImg<char> substr(256);
      CImg<unsigned int> _ind;
      if (inbraces) *inbraces = 0; else inbraces.assign(1,1,1,1,0);
      int ind = 0, l_inbraces = 0;
      bool is_braces = false;
      char end, sep = 0;

      // '{}' expression -> Mathematical evaluation, seq. of ascii codes or strings comparison.
      if (*nsource=='{') {
        const char *const ptr_beg = nsource + 1, *ptr_end = ptr_beg;
        unsigned int p = 0;
        for (p = 1; p>0 && *ptr_end; ++ptr_end) { if (*ptr_end=='{') ++p; if (*ptr_end=='}') --p; }
        if (p) { CImg<char>(nsource++,1).move_to(substituted_items); continue; }
        l_inbraces = ptr_end - ptr_beg - 1;
        if (l_inbraces>0) {
          inbraces.assign(ptr_beg,l_inbraces + 1).back() = 0;
          substitute_item(inbraces,images,images_names,variables_sizes).move_to(inbraces);
          gmic_strreplace(inbraces);
        }
        nsource+=l_inbraces + 2;
        if (*inbraces) {
          const CImg<T>& img = images.size()?gmic_check(images.back()):CImg<T>::empty();
          bool is_substitution_done = false;

          // Special regular cases to optimize: {w},{h},{d},{s}.
          if (!inbraces[1]) {
            switch (*inbraces) {
            case 'w' :
              cimg_snprintf(substr,substr.width(),"%d",img.width());
              is_substitution_done = true;
              break;
            case 'h' :
              cimg_snprintf(substr,substr.width(),"%d",img.height());
              is_substitution_done = true;
              break;
            case 'd' :
              cimg_snprintf(substr,substr.width(),"%d",img.depth());
              is_substitution_done = true;
              break;
            case 's' :
              cimg_snprintf(substr,substr.width(),"%d",img.spectrum());
              is_substitution_done = true;
              break;
            }
            if (is_substitution_done)
              CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
          }

          // Sequence of ascii codes.
          if (!is_substitution_done && inbraces.width()>=3 && *inbraces=='\'' &&
              inbraces[inbraces.width()-2]=='\'') {
            const char *s = inbraces.data() + 1;
            if (inbraces.width()>3) {
              inbraces[inbraces.width()-2] = 0;
              for (*substr=0, cimg::strunescape(inbraces); *s; ++s) {
                cimg_snprintf(substr,substr.width(),"%d,",(int)(unsigned char)*s);
                CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
              }
              if (*substr) --(substituted_items.back()._width);
            }
            is_substitution_done = true;
          }

          // Sequence of ascii characters.
          if (!is_substitution_done && inbraces.width()>=3 && *inbraces=='`' &&
              inbraces[inbraces.width()-2]=='`') {
            if (inbraces.width()>3) {
              unsigned int nb_values = 1;
              cimg_for(inbraces,p,char) if (*p==',') ++nb_values;
              inbraces[inbraces.width()-2] = 0;
              try {
                CImg<char>(nb_values,1,1,1,inbraces.data()+1,false).move_to(substituted_items);
                is_substitution_done = true;
              } catch (CImgException &e) {
                const char *const e_ptr = std::strstr(e.what(),": ");
                error(images,"Item substitution '{`value1,..,valueN`}': %s",
                      e_ptr?e_ptr+2:e.what());
              }
            }
            is_substitution_done = true;
          }

          // Strings comparison.
          if (!is_substitution_done && inbraces.width()>=5) {
            char *const peq = std::strstr(inbraces,"'=='");
            if (peq) {
              *peq = 0;
              cimg_snprintf(substr,substr.width(),"%d",(int)!std::strcmp(inbraces,peq+4));
              CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
              is_substitution_done = true;
            } else {
              char *const pne = std::strstr(inbraces,"'!='");
              if (pne) {
                *pne = 0;
                cimg_snprintf(substr,substr.width(),"%d",(int)std::strcmp(inbraces,pne+4));
                CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
                is_substitution_done = true;
              }
            }
          }

          // Mathematical expression [truncated output].
          if (!is_substitution_done && inbraces.width()>=3 && *inbraces=='_') try {
              cimg_snprintf(substr,substr.width(),"%g",img.eval(inbraces.data(1)));
              CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
              is_substitution_done = true;
            } catch (CImgException& e) {
              const char *const e_ptr = std::strstr(e.what(),": ");
              error(images,"Item substitution '{_expression}': %s",
                    e_ptr?e_ptr+2:e.what());
            }

          // Mathematical expression [full precision output].
          if (!is_substitution_done) try {
              cimg_snprintf(substr,substr.width(),"%.16g",img.eval(inbraces.data()));
              CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
            } catch (CImgException& e) {
              const char *const e_ptr = std::strstr(e.what(),": ");
              error(images,"Item substitution '{expression}': %s",
                    e_ptr?e_ptr+2:e.what());
            }
        }
        continue;

        // '@{..}' and ${..} expressions.
      } else if (nsource[1]=='{') {
        const char *const ptr_beg = nsource + 2, *ptr_end = ptr_beg; unsigned int p = 0;
        for (p = 1; p>0 && *ptr_end; ++ptr_end) { if (*ptr_end=='{') ++p; if (*ptr_end=='}') --p; }
        if (p) { CImg<char>(nsource++,1).move_to(substituted_items); continue; }
        l_inbraces = ptr_end - ptr_beg - 1;
        if (l_inbraces>0) {
          inbraces.assign(ptr_beg,l_inbraces + 1).back() = 0;
          substitute_item(inbraces,images,images_names,variables_sizes).move_to(inbraces);
        }
        is_braces = true;
      }

      // Substitute '@#' -> number of images in the list.
      if (*nsource=='@' && nsource[1]=='#') {
        nsource+=2;
        cimg_snprintf(substr,substr.width(),"%u",images.size());
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

      // Substitute '@*' -> number of available cpus.
      } else if (*nsource=='@' && nsource[1]=='*') {
        nsource+=2;
        cimg_snprintf(substr,substr.width(),"%u",cimg::nb_cpus());
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

      // Substitute '@^' -> current level of verbosity.
      } else if (*nsource=='@' && nsource[1]=='^') {
        nsource+=2;
        cimg_snprintf(substr,substr.width(),"%d",verbosity);
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

        // Substitute '@.' -> current version number of the G'MIC interpreter.
      } else if (*nsource=='@' && nsource[1]=='.') {
        nsource+=2;
        cimg_snprintf(substr,substr.width(),"%u",gmic_version);
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

        // Substitute '@%' -> pid of the current process.
      } else if (*nsource=='@' && nsource[1]=='%') {
        nsource+=2;
#if cimg_OS==1
        cimg_snprintf(substr,substr.width(),"%u",(unsigned int)getpid());
#elif cimg_OS==2
# 3381 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        cimg_snprintf(substr,substr.width(),"%u",(unsigned int)_getpid());
#else // #if cimg_OS==1
# 3383 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        cimg_snprintf(substr,substr.width(),"0");
#endif // #if cimg_OS==1
# 3385 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

        // Substitute '@|' -> current value of the timer.
      } else if (*nsource=='@' && nsource[1]=='|') {
        nsource+=2;
        cimg_snprintf(substr,substr.width(),"%g",(cimg::time()-reference_time)/1000.);
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

        // Substitute '@?' -> current type of image pixels.
      } else if (*nsource=='@' && nsource[1]=='?') {
        nsource+=2;
        cimg_snprintf(substr,substr.width(),"%s",CImg<T>::pixel_type());
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

        // Substitute '@!' -> visibility state of the first instant display window.
      } else if (*nsource=='@' && nsource[1]=='!') {
        nsource+=2;
#if cimg_display==0
        std::strcpy(substr,"0");
#else // #if cimg_display==0
# 3405 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        cimg_snprintf(substr,substr.width(),"%d",
                      instant_window[0]?(instant_window[0].is_closed()?0:1):0);
#endif // #if cimg_display==0
# 3408 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

        // Substitute '@{!}', @{!1}, '@{!,subset}' and '@{!1,subset}'
        // -> features of an instant display window.
      } else if (*nsource=='@' && inbraces[0]=='!' &&
                 (inbraces[1]==0 ||
                  (inbraces[1]>='0' && inbraces[1]<='9' && inbraces[2]==0) ||
                  (inbraces[1]==',' && inbraces[2]) ||
                  (inbraces[1]>='0' && inbraces[1]<='9' && inbraces[2]==',' && inbraces[3]))) {
        nsource+=l_inbraces + 3;
#if cimg_display==0
        std::strcpy(substr,"0");
#else // #if cimg_display==0
# 3421 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        unsigned int wind = 0;
        bool is_substitution_done = true;
        const char *ninbraces = inbraces.data() + 1;
        if (*ninbraces>='0' && *ninbraces<='9') wind = (unsigned int)(*(ninbraces++)-'0');
        if (!*ninbraces)
          cimg_snprintf(substr,substr.width(),"%d",
                        instant_window[wind]?(instant_window[wind].is_closed()?0:1):0);
        else if (*ninbraces==',') switch (*(++ninbraces)) {
          case 'w' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",instant_window[wind].width());
            else if (ninbraces[1]=='h' && !ninbraces[2])
              cimg_snprintf(substr,substr.width(),"%d",
                            instant_window[wind].width()*instant_window[wind].height());
            else is_substitution_done = false;
            break;
          case 'h' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",instant_window[wind].height());
            else is_substitution_done = false;
            break;
          case 'd' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",instant_window[wind].window_width());
            else if (ninbraces[1]=='e' && !ninbraces[2])
              cimg_snprintf(substr,substr.width(),"%d",
                            instant_window[wind].window_width()*
                            instant_window[wind].window_height());
            else is_substitution_done = false;
            break;
          case 'e' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",instant_window[wind].window_height());
            else is_substitution_done = false;
            break;
          case 'u' :
            if (!ninbraces[1]) try {
                cimg_snprintf(substr,substr.width(),"%d",CImgDisplay::screen_width());
              } catch (CImgDisplayException&) { std::strcpy(substr,"0"); }
            else if (ninbraces[1]=='v' && !ninbraces[2]) try {
                cimg_snprintf(substr,substr.width(),"%d",
                              CImgDisplay::screen_width()*CImgDisplay::screen_height());
              } catch (CImgDisplayException&) { std::strcpy(substr,"0"); }
            else is_substitution_done = false;
            break;
          case 'v' :
            if (!ninbraces[1]) try {
                cimg_snprintf(substr,substr.width(),"%d",CImgDisplay::screen_height());
              } catch (CImgDisplayException&) { std::strcpy(substr,"0"); }
            else is_substitution_done = false;
            break;
          case 'x' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",instant_window[wind].mouse_x());
            else is_substitution_done = false;
            break;
          case 'y' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",instant_window[wind].mouse_y());
            else is_substitution_done = false;
            break;
          case 'n' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",instant_window[wind].normalization());
            else is_substitution_done = false;
            break;
          case 'b' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",instant_window[wind].button());
            else is_substitution_done = false;
            break;
          case 'o' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",instant_window[wind].wheel());
            else is_substitution_done = false;
            break;
          case 'c' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",(int)instant_window[wind].is_closed());
            else is_substitution_done = false;
            break;
          case 'r' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",(int)instant_window[wind].is_resized());
            else is_substitution_done = false;
            break;
          case 'm' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",(int)instant_window[wind].is_moved());
            else is_substitution_done = false;
            break;
          case 'k' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%u",instant_window[wind].key());
            else is_substitution_done = false;
            break;
          default :
            cimg_snprintf(substr,substr.width(),"%d",instant_window[wind].is_key(ninbraces));
          } else cimg_snprintf(substr,substr.width(),"@{!%s}",inbraces.data());
        if (!is_substitution_done) std::strcpy(substr,"0");
#endif // #if cimg_display==0
# 3522 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

        // Substitute '@/' -> number of levels in current global scope.
      } else if (*nsource=='@' && nsource[1]=='/') {
        nsource+=2;
        cimg_snprintf(substr,substr.width(),"%u",scope.size());
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

        // Substitute '@{/}' and '@{/,subset}' -> content of the global scope.
      } else if (*nsource=='@' && inbraces[0]=='/' &&
                 (inbraces[1]==0 || (inbraces[1]==',' && inbraces[2]))) {
        nsource+=l_inbraces + 3;
        const CImg<unsigned int>
          subset = selection2cimg(inbraces[1]?inbraces.data()+2:0,scope.size(),
                                  CImgList<char>::empty(),
                                  "Item substitution '@{/[,subset]}'",false,
                                  false,CImg<char>::empty());
        if (subset) cimg_foroff(subset,i)
                      substituted_items.insert(scope[subset[i]]).back().back() = '/';

        // Substitute '$/' -> current scope.
      } else if (*nsource=='$' && nsource[1]=='/') {
        cimg_snprintf(substr,substr.width(),"%s",scope.back().data());
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
        nsource+=2;

        // Substitute '@>' and '@<' -> current number of nested loops.
      } else if (*nsource=='@' && (nsource[1]=='>' || nsource[1]=='<')) {
        nsource+=2;
        cimg_snprintf(substr,substr.width(),"%u",repeatdones.size());
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

        // Substitute '@{>}', '@{<}', '@{>,subset}' and '@{<,subset}'
        // -> forward/backward indice(s) of current loop(s).
      } else if (*nsource=='@' && (*inbraces=='>' || *inbraces=='<') &&
                 (inbraces[1]==0 || (inbraces[1]==',' && inbraces[2]))) {
        nsource+=l_inbraces + 3;
        const CImg<unsigned int>
          subset = selection2cimg(inbraces[1]?inbraces.data()+2:0,repeatdones.size(),
                                  CImgList<char>::empty(),
                                  "Item substitution '@{>[,subset]}'",false,
                                  false,CImg<char>::empty());
        if (subset) {
          cimg_foroff(subset,i) {
            cimg_snprintf(substr,substr.width(),"%u",
                          *inbraces=='>'?repeatdones(subset[i],2):repeatdones(subset[i],1)-1);
            CImg<char>::string(substr.data()).move_to(substituted_items).back().back()=',';
          }
          --(substituted_items.back()._width);
        }

        // Substitute '$>', '${>}', '$<' and '${<}' -> forward/backward indice of current loop.
      } else if (*nsource=='$' &&
                 (nsource[1]=='>' || nsource[1]=='<' ||
                  ((*inbraces=='>' || *inbraces=='<') && inbraces[1]==0))) {
        const char direction = is_braces?*inbraces:nsource[1];
        if (!repeatdones)
          error(images,"Item substitution '$%s': There is no loop currently running.",
                is_braces?(direction=='>'?"{>}":"{<}"):(direction=='>'?">":"<"));
        cimg_snprintf(substr,substr.width(),"%u",
                      direction=='>'?repeatdones.back()(2):repeatdones.back()(1)-1);
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
        nsource+=is_braces?4:2;

        // Substitute '$name' and '${name}' -> variable, image indice or environment variable.
      } else if (*nsource=='$' &&
                 (((is_braces && std::sscanf(inbraces,"%255[a-zA-Z0-9_]",substr.data())==1)) ||
                  (std::sscanf(nsource+1,"%255[a-zA-Z0-9_]",substr.data())==1)) &&
                 (*substr<'0' || *substr>'9')) {
        const CImg<char>& name = is_braces?inbraces:substr;
        const unsigned int sind = gmic_hashcode(name,true);
        const bool is_global = *name=='_';
	const int lind = is_global?0:(int)variables_sizes[sind];
        if (is_global) cimg::mutex(29);
        const CImgList<char>
          &__variables = *variables[sind],
          &__variables_names = *variables_names[sind];
        bool is_name_found = false;
	for (int l = __variables.width()-1; l>=lind; --l)
          if (!std::strcmp(__variables_names[l],name)) {
            is_name_found = true; ind = l; break;
          }
        if (is_name_found) {
          if (__variables[ind].size()>1)
            CImg<char>(__variables[ind].data(),__variables[ind].size()-1).
              move_to(substituted_items);
        } else {
	  for (int l = images.width()-1; l>=0; --l)
            if (images_names[l] && !std::strcmp(images_names[l],name)) {
              is_name_found = true; ind = l; break;
            }
          if (is_name_found) {
            char text[64];
            cimg_snprintf(text,sizeof(text),"%d",ind);
            CImg<char>(text,std::strlen(text)).move_to(substituted_items);
          } else {
            const char *const s_env = std::getenv(name);
            if (s_env) CImg<char>(s_env,std::strlen(s_env)).move_to(substituted_items);
          }
        }
        if (is_global) cimg::mutex(29,0);
        nsource+=is_braces?l_inbraces + 3:std::strlen(substr)+1;

        // Substitute '@ind', '@{ind}' and '@{ind,argument}' -> image values or feature.
      } else if (*nsource=='@' && (std::sscanf(nsource+1,"%d",&ind)==1 ||
                                   ((end=0),std::sscanf(inbraces,"%d%c",&ind,&end)==1) ||
                                   ((end=1),std::sscanf(inbraces,"%d,%c",&ind,&sep)==2) ||
                                   (std::sscanf(nsource+1,"%255[a-zA-Z0-9_]",substr.data())==1 &&
                                    (_ind=selection2cimg(substr,images.size(),images_names,
                                                         "Item substitution '@name'",true,
                                                         false,CImg<char>::empty())).height()>0) ||
                                   (((end=0),std::sscanf(inbraces,"%255[a-zA-Z0-9_]%c",
                                                         substr.data(),&end)==1) &&
                                    (_ind=selection2cimg(substr,images.size(),images_names,
                                                         "Item substitution '@{name}'",true,
                                                         false,CImg<char>::empty())).height()>0) ||
                                   (((end=1),std::sscanf(inbraces,"%255[a-zA-Z0-9_],%c",
                                                         substr.data(),&sep)==2) &&
                                    (_ind=selection2cimg(substr,images.size(),images_names,
                                                         "Item substitution '@{name,feature}'",
                                                         true,false,
                                                         CImg<char>::empty())).height()>0))) {
        if (_ind) {
          if (_ind.height()>1)
            error(images,"Item substitution '%s': Selection [%s] specifies %d items.",
                  !*inbraces?"@name":end?"@{name,feature}":"@{name}",
                  substr.data(),_ind.height());
          ind=*_ind;
        }
        const unsigned int
          l_ind = _ind?std::strlen(substr):cimg_snprintf(substr,substr.width(),"%d",ind);
        nsource+=is_braces?l_inbraces + 3:l_ind + 1;
        int nind = ind;
        if (nind<0) nind+=images.width();
        if (nind<0 || nind>=images.width()) {
          if (images.width())
            error(images,"Item substitution '%s': Invalid indice '%d' (not in range -%u..%u).",
                  !*inbraces?"@indice":end?"@{indice,feature}":"@{indice}",
                  ind,images.size(),images.size()-1);
          else
            error(images,"Item substitution '%s': Invalid indice '%d' (no image data available).",
                  !*inbraces?"@indice":end?"@{indice,feature}":"@{indice}",ind);
        }
        const CImg<T>& img = gmic_check(images[nind]);
        char argx[256], argy[256], argz[256], argc[256];
        *argx = *argy = *argz = *argc = 0;
        char sepp = 0, sepx = 0, sepy = 0, sepz = 0, sepc = 0;
        float x = 0, y = 0, z = 0, v = 0, bcond = 0;
        bool is_substitution_done = false;
        const char *subset = sep?inbraces.data() + l_ind + 1:&sep;
        *substr = 0;

        // Test for simple arguments '@{ind,arg}' where 'arg' is w,h,d,s,....
        if (*subset) {
          is_substitution_done = true;
          switch (*subset) {
          case 'w' :
            if (subset[1]=='h') {
              if (subset[2]=='d') {
                if (subset[3]=='s' && !subset[4])
                  cimg_snprintf(substr,substr.width(),"%d",
                                img.width()*img.height()*img.depth()*img.spectrum());
                else if (!subset[3])
                  cimg_snprintf(substr,substr.width(),"%d",
                                img.width()*img.height()*img.depth());
                else is_substitution_done = false;
              } else if (!subset[2])
                cimg_snprintf(substr,substr.width(),"%d",img.width()*img.height());
              else is_substitution_done = false;
            } else if (!subset[1])
              cimg_snprintf(substr,substr.width(),"%d",img.width());
            else is_substitution_done = false;
            break;
          case 'h' :
            if (!subset[1]) cimg_snprintf(substr,substr.width(),"%d",img.height());
            else is_substitution_done = false;
            break;
          case 'd' :
            if (!subset[1]) cimg_snprintf(substr,substr.width(),"%d",img.depth());
            else is_substitution_done = false;
            break;
          case 's' :
            if (!subset[1]) cimg_snprintf(substr,substr.width(),"%d",img.spectrum());
            else is_substitution_done = false;
            break;
          case 'r' :
            if (!subset[1]) cimg_snprintf(substr,substr.width(),"%d",img.is_shared());
            else is_substitution_done = false;
            break;
          case 'n' :
            if (!subset[1]) cimg_snprintf(substr,substr.width(),"%s",images_names[nind].data());
            else is_substitution_done = false;
            break;
          case 'b' :
            if (!subset[1]) {
              cimg::split_filename(images_names[nind].data(),substr);
              const char *const basename = cimg::basename(substr);
              if (substr.data()!=basename)
                substr.draw_image(CImg<char>::string(basename));
            } else is_substitution_done = false;
            break;
          case 'x' :
            if (!subset[1])
              cimg_snprintf(substr,substr.width(),"%s",
                            cimg::split_filename(images_names[nind].data()));
            else is_substitution_done = false;
            break;
          case 'f' :
            if (!subset[1]) {
              CImg<char> _substr(images_names[nind]);
              char *const basename = const_cast<char*>(cimg::basename(_substr));
              *basename = 0;
              std::strcpy(substr,_substr);
            } else is_substitution_done = false;
            break;
          case '#' :
            if (!subset[1]) cimg_snprintf(substr,substr.width(),"%lu",img.size());
            else is_substitution_done = false;
            break;
          case '+' :
            if (!subset[1]) {
              double res = img?(double)img.front():0;
              for (const T *ptrs = img.data() + 1, *ptre = img.end(); ptrs<ptre;
                   res+=(double)*ptrs++) {}
              cimg_snprintf(substr,substr.width(),"%.16g",res);
            } else is_substitution_done = false;
            break;
          case '-' :
            if (!subset[1]) {
              double res = img?(double)img.front():0;
              for (const T *ptrs = img.data() + 1, *ptre = img.end(); ptrs<ptre;
                   res-=(double)*ptrs++) {}
              cimg_snprintf(substr,substr.width(),"%.16g",res);
            } else is_substitution_done = false;
            break;
          case '*' :
            if (!subset[1]) {
              double res = img?(double)img.front():0;
              for (const T *ptrs = img.data() + 1, *ptre = img.end(); ptrs<ptre;
                   res*=(double)*ptrs++) {}
              cimg_snprintf(substr,substr.width(),"%.16g",res);
            } else is_substitution_done = false;
            break;
          case '/' : if (!subset[1]) {
              double res = img?(double)img.front():0;
              for (const T *ptrs = img.data() + 1, *ptre = img.end(); ptrs<ptre;
                   res/=(double)*ptrs++) {}
              cimg_snprintf(substr,substr.width(),"%.16g",res);
            } else is_substitution_done = false;
            break;
          case 'm' :
            if (!subset[1]) cimg_snprintf(substr,substr.width(),"%.16g",(double)img.min());
            else is_substitution_done = false;
            break;
          case 'M' :
            if (!subset[1]) cimg_snprintf(substr,substr.width(),"%.16g",(double)img.max());
            else is_substitution_done = false;
            break;
          case 'a' :
            if (!subset[1]) cimg_snprintf(substr,substr.width(),"%.16g",img.mean());
            else is_substitution_done = false;
            break;
          case 'v' :
            if (!subset[1]) cimg_snprintf(substr,substr.width(),"%.16g",img.variance());
            else is_substitution_done = false;
            break;
          case 't' :
            if (!subset[1]) {
              const unsigned int siz = (unsigned int)img.size();
              if (siz) {
                unsigned int strsiz = 0;
                cimg_for(img,ptr,T) if ((unsigned char)*ptr) ++strsiz;
                if (strsiz) {
                  CImg<char> text(strsiz+1), _text = text.get_shared_points(0,strsiz-1,0,0,0);
                  _text = CImg<T>(img.data(),strsiz,1,1,1,true);
                  text.back() = 0;
                  gmic_strreplace(text.data());
                  _text.move_to(substituted_items);
                }
              }
              *substr = 0;
            } else is_substitution_done = false;
            break;
          case 'c' :
            if (!subset[1]) {
              CImg<unsigned int> st;
              if (img) st = img.get_stats(); else st.assign(8,1,1,1,0);
              cimg_snprintf(substr,substr.width(),"%u,%u,%u,%u",st[4],st[5],st[6],st[7]);
            } else is_substitution_done = false;
            break;
          case 'C' :
            if (!subset[1]) {
              CImg<unsigned int> st;
              if (img) st = img.get_stats(); else st.assign(12,1,1,1,0);
              cimg_snprintf(substr,substr.width(),"%u,%u,%u,%u",st[8],st[9],st[10],st[11]);
            } else is_substitution_done = false;
            break;
          default : is_substitution_done = false;
          }

          // Test for access to pixel value '@{ind,(x,y,z,c,boundary)}'.
          if (is_substitution_done) {
            if (*substr) CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
          } else if ((std::sscanf(subset,"(%255[0-9.eE%+-]%c%c",
                                  argx,&sepp,&end)==2 ||
                      std::sscanf(subset,"(%255[0-9.eE%+-],%255[0-9.eE%+-]%c%c",
                                  argx,argy,&sepp,&end)==3 ||
                      std::sscanf(subset,"(%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-]%c%c",
                                  argx,argy,argz,&sepp,&end)==4 ||
                      std::sscanf(subset,"(%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                                  "%255[0-9.eE%+-]%c%c",
                                  argx,argy,argz,argc,&sepp,&end)==5 ||
                      std::sscanf(subset,"(%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                                  "%255[0-9.eE%+-],%f%c%c",
                                  argx,argy,argz,argc,&bcond,&sepp,&end)==6) &&
                     sepp==')' &&
                     (std::sscanf(argx,"%f%c",&x,&end)==1 ||
                      (std::sscanf(argx,"%f%c%c",&x,&sepx,&end)==2 && sepx=='%')) &&
                     (!*argy ||
                      std::sscanf(argy,"%f%c",&y,&end)==1 ||
                      (std::sscanf(argy,"%f%c%c",&y,&sepy,&end)==2 && sepy=='%')) &&
                     (!*argz ||
                      std::sscanf(argz,"%f%c",&z,&end)==1 ||
                      (std::sscanf(argz,"%f%c%c",&z,&sepz,&end)==2 && sepz=='%')) &&
                     (!*argc ||
                      std::sscanf(argc,"%f%c",&v,&end)==1 ||
                      (std::sscanf(argc,"%f%c%c",&v,&sepc,&end)==2 && sepc=='%'))) {
            const int
              nx = (int)cimg::round(sepx=='%'?x*(img.width()-1)/100:x),
              ny = (int)cimg::round(sepy=='%'?y*(img.height()-1)/100:y),
              nz = (int)cimg::round(sepz=='%'?z*(img.depth()-1)/100:z),
              nv = (int)cimg::round(sepc=='%'?v*(img.spectrum()-1)/100:v);
            cimg_snprintf(substr,substr.width(),"%.16g",
                          bcond?(double)img.atXYZC(nx,ny,nz,nv):(double)img.atXYZC(nx,ny,nz,nv,0));
            CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
            is_substitution_done = true;
          }
        }

        // Test for values subset, as in '@{ind,0-10}'.
        if (!is_substitution_done) {
          CImg<T> values;
          is_substitution_done = true;
          if (!*subset) values = img.get_shared();
          else {
            int _verbosity = verbosity;
            bool _is_debug = is_debug;
            verbosity = -1; is_debug = false;
            try {
              const CImg<unsigned int>
                inds = selection2cimg(subset,img.size(),
                                      CImgList<char>::empty(),"",false,false,CImg<char>::empty());
              values.assign(1,inds.height());
              cimg_foroff(inds,p) values[p] = img[inds(p)];
            } catch (gmic_exception&) {
              is_substitution_done = false;
            }
            verbosity = _verbosity; is_debug = _is_debug;
          }
          if (is_substitution_done) {
            cimg_foroff(values,p) {
              cimg_snprintf(substr,substr.width(),"%.16g",(double)values[p]);
              CImg<char>::string(substr).move_to(substituted_items).back().back() = ',';
            }
            if (values) --(substituted_items.back()._width);
          }
        }

        // -> 'argument' is considered as math expression associated to an image, as '@{ind,w/2}'.
        if (!is_substitution_done) {
          try {
            cimg_snprintf(substr,substr.width(),"%.16g",img.eval(subset));
          } catch (CImgException&) {
            error(images,"Item substitution '@{%d,%s}': Invalid argument '%s'.",
                  ind,subset,subset);
          }
          CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
        }

        // Substitute '@' by itself, if no @-pattern matches.
      } else if (!is_braces || *nsource!='@') CImg<char>(nsource++,1).move_to(substituted_items);

      // Substitute '@{command}' by the status value after command execution.
      else {
        nsource+=l_inbraces + 3;
        if (l_inbraces>0) {
          const CImgList<char>
            ncommands_line = commands_line_to_CImgList(gmic_strreplace(inbraces));
          unsigned int nposition = 0;
          CImg<char>::string("*substitute").move_to(scope);
	  unsigned int nvariables_sizes[256];
	  for (unsigned int l = 0; l<256; ++l) nvariables_sizes[l] = variables[l]->size();
          _parse(ncommands_line,nposition,images,images_names,nvariables_sizes);
	  for (unsigned int l = 0; l<255; ++l) if (variables[l]->size()>nvariables_sizes[l]) {
	      variables_names[l]->remove(nvariables_sizes[l],variables[l]->size()-1);
	      variables[l]->remove(nvariables_sizes[l],variables[l]->size()-1);
	    }
          scope.remove();
          is_return = false;
        }
        if (status.width()>1)
          CImg<char>(status.data(),status.width()-1).move_to(substituted_items);
        continue;
      }
    }
  CImg<char>::vector(0).move_to(substituted_items);
  return substituted_items>'x';
}

// Main parsing procedure.
//------------------------
template<typename T>
gmic& gmic::_parse(const CImgList<char>& commands_line, unsigned int& position,
                   CImgList<T> &images, CImgList<char> &images_names,
                   unsigned int variables_sizes[256]) {

#ifdef gmic_float
  typedef typename cimg::superset<T,float>::type Tfloat;
  typedef typename cimg::superset<T,long>::type Tlong;
#endif // #ifdef gmic_float
# 3942 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

  const unsigned int initial_scope_size = scope.size(), initial_debug_line = debug_line;
  bool is_endlocal = false;
  char end;

  // Allocate string variables, widely used afterwards
  // (prevents stack overflow on recursive calls while remaining thread-safe).
  CImgList<st_gmic_parallel<T> > threads_data;
  CImg<char> _formula(4096), _message(1024), _title(256), _indices(256),
    _argx(256), _argy(256), _argz(256), _argc(256);
  char
    *const formula = _formula.fill(0).data(),
    *const message = _message.fill(0).data(),
    *const title = _title.fill(0).data(),
    *const indices = _indices.fill(0).data(),
    *const argx = _argx.fill(0).data(),
    *const argy = _argy.fill(0).data(),
    *const argz = _argz.fill(0).data(),
    *const argc = _argc.fill(0).data();

#ifdef gmic_float
  CImg<char> _color(4096);
  char *const color = _color.data();
#endif // #ifdef gmic_float
# 3966 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

  try {

    // Init parser environment.
    cimg::exception_mode() = 0;
    if (images.size()<images_names.size())
      images_names.remove(images.size(),images_names.size()-1);
    else if (images.size()>images_names.size())
      images_names.insert(images.size() - images_names.size(),CImg<char>::string("[unnamed]"));

    is_debug_infos = false;
    if (is_debug) {
      nb_carriages = 2;
      debug(images,"%sStart G'MIC parser in scope '%s/' [%s].%s",
            cimg::t_bold,scope.back().data(),CImg<T>::pixel_type(),cimg::t_normal);
      is_start = false;
    }

    // Begin command line parsing.
    if (!commands_line && is_start) { print(images,"Start G'MIC parser."); is_start = false; }
    while (position<commands_line.size() && !is_quit && !is_return) {

      // Process debug infos.
      while (position<commands_line.size() && *commands_line[position]==1) {
        const CImg<char> &code = commands_line[position];
        if (!std::sscanf(code.data()+1,"%x,%x",&debug_line,&(debug_filename=0)))
          debug_filename = debug_line = ~0U;
        else is_debug_infos = true;
        ++position;
      }
      if (position>=commands_line.size()) continue;

      // Check consistency of the parser environment.
      if (images_names.size()!=images.size())
        error("Internal error: Images (%u) and images names (%u) have different size.",
              images_names.size(),images.size());
      if (!scope)
        error("Internal error: Scope is empty.");
      if (scope.size()>64)
        error("Internal error: Scope overflow (infinite recursion ?).");

      // Substitute expressions in current item.
      const char
        *const initial_item = commands_line[position].data(),
        *const initial_argument = position+1<commands_line.size()?commands_line[position+1].data():"";

      CImg<char> _item, _argument, _argument_text;
      substitute_item(initial_item,images,images_names,variables_sizes).move_to(_item);
      char *item = _item.data();
      const char *argument = initial_argument, *argument_text = initial_argument;

      // Split command/restriction, if necessary.
      CImg<char> _command(256), _restriction(256);
      char *const command = _command.data(), *const restriction = _restriction.data();
      *command = *restriction = 0;

      bool is_get_version = false, is_restriction = false;
      CImg<unsigned int> selection;
      CImg<char> new_name;
      if (item[0]=='-' && item[1] && item[1]!='.') {
        char sep0 = 0, sep1 = 0;
        if (item[1]=='-' && item[2] && item[2]!='[' && (item[2]!='3' || item[3]!='d')) {
          ++item; is_get_version = true;
        }
        gmic_strreplace(item);
        const int err = std::sscanf(item,"%255[^[]%c%255[a-zA-Z_0-9.eE%^,:+-]%c%c",
                                    command,&sep0,restriction,&sep1,&end);
        if (err==1) selection = CImg<unsigned int>::sequence(images.size(),0,images.size()-1);
        else if (err==2 && sep0=='[' && item[std::strlen(command)+1]==']') {
          selection.assign(); is_restriction = true;
        } else if (err==4 && sep1==']') {
          is_restriction = true;
          if ((!std::strcmp("-wait",command) || !std::strcmp("-cursor",command)) && !is_get_version)
            selection = selection2cimg(restriction,10,CImgList<char>::empty(),command,true,
                                       false,CImg<char>::empty());
          else if ((!std::strcmp("-i",command) || !std::strcmp("-input",command)) &&
                   !is_get_version)
            selection = selection2cimg(restriction,images.size()+1,images_names,command,true,
                                       true,new_name);
          else if ((!std::strcmp("-e",command) || !std::strcmp("-echo",command) ||
                    !std::strcmp("-error",command) || !std::strcmp("-warn",command)) &&
                   !is_get_version)
            selection = selection2cimg(restriction,scope.size(),CImgList<char>::empty(),
                                       command,true,false,CImg<char>::empty());
          else
            selection = selection2cimg(restriction,images.size(),images_names,command,true,
                                       false,CImg<char>::empty());
        } else {
          std::strncpy(command,item,_command.size()-1);
          command[_command.size()-1] = *restriction = 0;
        }
        if (is_get_version) --item;
      } else {
        std::strncpy(command,item,_command.size()-1);
        command[_command.size()-1] = *restriction = 0;
      }
      ++position;

      if (is_debug) {
        const char *const _initial_item = initial_item+(is_get_version?1:0);
        if (std::strcmp(item,_initial_item))
          debug(images,"Item '%s' -> '%s', indice%s.",
                _initial_item,item,gmic_selection);
        else
          debug(images,"Item '%s', indice%s.",
                _initial_item,gmic_selection);
      }

      // Check for verbosity command, prior to the first output of a log message.
      bool is_verbose_argument = false;
      const int old_verbosity = verbosity;
      if (!std::strcmp("-v",item) || !std::strcmp("-verbose",item)) {
        // Do a first fast check.
        if (*argument=='-' && !argument[1]) { --verbosity; is_verbose_argument = true; }
        else if (*argument=='+' && !argument[1]) { ++verbosity; is_verbose_argument = true; }
        else {
          gmic_substitute_args();
          if (*argument=='-' && !argument[1]) { --verbosity; is_verbose_argument = true; }
          else if (*argument=='+' && !argument[1]) { ++verbosity; is_verbose_argument = true; }
          else {
            float level = 0;
            if (std::sscanf(argument,"%f%c",&level,&end)==1) {
              verbosity = (int)cimg::round(level);
              is_verbose_argument = true;
            }
            else verbosity = 0;
          }
        }
      }
      if (is_start) { print(images,"Start G'MIC parser."); is_start = false; }

      // Check for cancellation point.
      if (*cancel) {
        if (verbosity>0 || is_debug) print(images,"Cancel G'MIC instance.\n");
        dowhiles.assign();
        repeatdones.assign();
        position = commands_line.size();
        is_released = is_quit = true;
        break;
      }

      // Begin command interpretation.
      if (*item=='-' && item[1]) {

        // Replace some shortcut names whose three first chars are different than correspondent
        // regular names (not all shortcuts are replaced, but it reduces the number of string
        // comparisons afterwards).
        char _item[16] = { 0 }, command1 = command[1];
        const char
          command2 = command1?command[2]:0, command3 = command2?command[3]:0,
          command4 = command3?command[4]:0, command5 = command4?command[5]:0;

        if (!command2) switch (command1) {  // One-char shortcuts.
          case 'm' : if (!is_get_version && !is_restriction) {
              std::strcpy(item=_item,"-command"); command1 = 'c';
            } break;
          case 'd' : std::strcpy(command,"-display"); break;
          case 'e' : std::strcpy(command,"-echo"); break;
          case 'i' : std::strcpy(command,"-input"); break;
          case 'o' : std::strcpy(command,"-output"); break;
          case 'p' : std::strcpy(command,"-print"); break;
          case 'v' : if (!is_get_version && !is_restriction)
              std::strcpy(item=_item,"-verbose"); break;
          case 'w' : std::strcpy(command,"-window"); break;
          case 'k' : std::strcpy(command,"-keep"); break;
          case '+' : std::strcpy(command,"-add"); command1 = 'a'; break;
          case '/' : std::strcpy(command,"-div"); command1 = 'd'; break;
          case '>' : std::strcpy(command,"-gt"); command1 = 'g'; break;
          case '<' : std::strcpy(command,"-lt"); command1 = 'l'; break;
          case '%' : std::strcpy(command,"-mod"); command1 = 'm'; break;
          case '*' : std::strcpy(command,"-mul"); command1 = 'm'; break;
          case '^' : std::strcpy(command,"-pow"); command1 = 'p'; break;
          case '-' : std::strcpy(command,"-sub"); command1 = 's'; break;
          case 'c' : std::strcpy(command,"-cut"); break;
          case 'f' : std::strcpy(command,"-fill"); break;
          case 'n' : std::strcpy(command,"-normalize"); break;
          case '=' : std::strcpy(command,"-set"); command1 = 's'; break;
          case 't' : std::strcpy(command,"-text"); break;
          case 'a' : std::strcpy(command,"-append"); break;
          case 'z' : std::strcpy(command,"-crop"); command1 = 'c'; break;
          case 'r' : std::strcpy(command,"-resize"); break;
          case 's' : std::strcpy(command,"-split"); break;
          case 'y' : std::strcpy(command,"-unroll"); command1 = 'u'; break;
          case 'b' : std::strcpy(command,"-blur"); break;
          case 'g' : std::strcpy(command,"-gradient"); break;
          case 'j' : std::strcpy(command,"-image"); command1 = 'i'; break;
          case 'q' : if (!is_get_version && !is_restriction)
              std::strcpy(item=_item,"-quit"); break;
          case 'l' : std::strcpy(command,"-local"); break;
          case 'u' : if (!is_get_version && !is_restriction)
              std::strcpy(item=_item,"-status"); command1 = 's'; break;
          case 'x' : if (!is_get_version && !is_restriction)
              std::strcpy(item=_item,"-exec"); command1 = 'e'; break;
          } else if (!command3) { // Two-chars shortcuts.
          if (command1=='s' && command2=='h') std::strcpy(command,"-shared");
          else if (command1=='m' && command2=='v') std::strcpy(command,"-move");
          else if (command1=='n' && command2=='m') std::strcpy(command,"-name");
          else if (command1=='r' && command2=='m') std::strcpy(command,"-remove");
          else if (command1=='r' && command2=='v') std::strcpy(command,"-reverse");
          else if (command1=='<' && command2=='<') { std::strcpy(command,"-bsl"); command1 = 'b'; }
          else if (command1=='>' && command2=='>') { std::strcpy(command,"-bsr"); command1 = 'b'; }
          else if (command1=='=' && command2=='=') { std::strcpy(command,"-eq"); command1 = 'e'; }
          else if (command1=='>' && command2=='=') { std::strcpy(command,"-ge"); command1 = 'g'; }
          else if (command1=='<' && command2=='=') { std::strcpy(command,"-le"); command1 = 'l'; }
          else if (command1=='/' && command2=='/') {
            std::strcpy(command,"-mdiv"); command1 = 'm';
          }
          else if (command1=='*' && command2=='*') {
            std::strcpy(command,"-mmul"); command1 = 'm';
          }
          else if (command1=='!' && command2=='=') { std::strcpy(command,"-neq"); command1 = 'n'; }
        } else if (!command4 && command2=='3' && command3=='d') switch (command1) {
            // Three-chars shortcuts (ending with '3d').
          case 'd' : std::strcpy(command,"-display3d"); break;
          case '+' : std::strcpy(command,"-add3d"); command1 = 'a'; break;
          case 'b' : if (!is_get_version && !is_restriction)
              std::strcpy(item=_item,"-background3d"); break;
          case '/' : std::strcpy(command,"-div3d"); command1 = 'd'; break;
          case 'f' : if (!is_get_version && !is_restriction)
              std::strcpy(item=_item,"-focale3d"); break;
          case 'l' : if (!is_get_version && !is_restriction)
              std::strcpy(item=_item,"-light3d"); break;
          case 'm' : if (!is_get_version && !is_restriction)
              std::strcpy(item=_item,"-mode3d"); break;
          case '*' : std::strcpy(command,"-mul3d"); command1 = 'm'; break;
          case 'o' : std::strcpy(command,"-opacity3d"); break;
          case 'p' : std::strcpy(command,"-primitives3d"); break;
          case 'r' : std::strcpy(command,"-rotate3d"); break;
          case 's' : std::strcpy(command,"-split3d"); break;
          case '-' : std::strcpy(command,"-sub3d"); command1 = 's'; break;
          case 't' : std::strcpy(command,"-texturize3d"); break;
          } else if (!command5 && command3=='3' && command4=='d') {
          // Four-chars shortcuts (ending with '3d').
          if (command1=='d' && command2=='b') {
            if (!is_get_version && !is_restriction) std::strcpy(item=_item,"-double3d");
          } else if (command1=='m' && command2=='d') {
            if (!is_get_version && !is_restriction) std::strcpy(item=_item,"-moded3d");
          }
          else if (command1=='r' && command2=='v') std::strcpy(command,"-reverse3d");
          else if (command1=='s' && command2=='l') {
            if (!is_get_version && !is_restriction) std::strcpy(item=_item,"-specl3d");
          }
          else if (command1=='s' && command2=='s') {
            if (!is_get_version && !is_restriction) std::strcpy(item=_item,"-specs3d");
          }
        }

        // Check if new name has been requested for a command that does not allow that.
        if (new_name && std::strcmp("-input",command) && !is_get_version)
          error(images,"Item '%s %s': Unknow name '%s'.",
                initial_item,initial_argument,new_name.data());

        //----------------------------
        // Commands starting by '-a..'
        //----------------------------
        if (command1=='a') {

          // Append.
          if (!std::strcmp("-append",command)) {
            gmic_substitute_args();
            float align = 0;
            char axis = 0, sep = 0;
            CImg<unsigned int> ind;
            if ((std::sscanf(argument,"%c%c",
                             &axis,&end)==1 ||
                 std::sscanf(argument,"%c,%f%c",
                             &axis,&align,&end)==2) &&
                (axis=='x' || axis=='y' || axis=='z' || axis=='c')) {
              print(images,"Append image%s along the '%c'-axis, with alignment %g.",
                    gmic_selection,
                    axis,align);
              if (selection) {
                CImgList<T> subimages;
                cimg_forY(selection,l) if (gmic_check(images[selection[l]]))
                  subimages.insert(gmic_check(images[selection[l]]),~0U,true);
                CImg<T> img = subimages.get_append(axis,align);
                CImg<char> name = images_names[selection[0]].get_mark();
                if (is_get_version) {
                  img.move_to(images);
                  images_names.insert(name.copymark());
                } else if (selection.height()>=2) {
                  remove_images(images,images_names,selection,1,selection.height()-1);
                  img.move_to(images[selection[0]].assign());
                  name.move_to(images_names[selection[0]]);
                }
              }
            } else if ((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c,%c%c",
                                    indices,&sep,&axis,&end)==3 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c,%c,%f%c",
                                    indices,&sep,&axis,&(align=0),&end)==4) &&
                       (axis=='x' || axis=='y' || axis=='z' || axis=='c') &&
                       sep==']' &&
                       (ind=selection2cimg(indices,images.size(),images_names,"-append",true,
                                           false,CImg<char>::empty())).height()==1) {
              print(images,"Append image [%u] to image%s, along the '%c'-axis, with alignment %g.",
                    *ind,gmic_selection,axis,align);
              const CImg<T> img0 = gmic_image_arg(*ind);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],append(img0,axis,align));
            } else arg_error("append");
            is_released = false; ++position; continue;
          }

          // Autocrop.
          if (!std::strcmp("-autocrop",command)) {
            gmic_substitute_args();
            CImg<T> is_arg;
            if (*argument && std::sscanf(argument,"%4095[0-9.,eE+-]%c",formula,&end)==1)
              try { CImg<T>(1).fill(argument,true).move_to(is_arg); }
              catch (CImgException&) { is_arg.assign(); }
            if (is_arg) {
              print(images,"Auto-crop image%s by vector '%s'.",
                    gmic_selection,
                    argument_text);
              ++position;
            } else print(images,"Auto-crop image%s.",
                         gmic_selection);
            cimg_forY(selection,l) {
              CImg<T>& img = images[selection[l]];
              if (is_arg) {
                const CImg<T> col = CImg<T>(img.spectrum()).fill(argument,true);
                gmic_apply(img,gmic_autocrop(col));
              }
              else gmic_apply(img,gmic_autocrop());
            }
            is_released = false; continue;
          }

#ifdef gmic_float

          // Add.
          gmic_arithmetic_item("-add",
                               operator+=,
                               "Add %g%s to image%s",
                               value,ssep,gmic_selection,Tfloat,
                               operator+=,
                               "Add image [%d] to image%s",
                               ind[0],gmic_selection,
                               "Add expression %s to image%s",
                               argument_text,gmic_selection,
                               "Add image%s");

          // Add 3d objects together, or shift a 3d object.
          if (!std::strcmp("-add3d",command)) {
            gmic_substitute_args();
            float tx = 0, ty = 0, tz = 0;
            CImg<unsigned int> ind;
            char sep = 0;
            if (std::sscanf(argument,"%f%c",
                            &tx,&end)==1 ||
                std::sscanf(argument,"%f,%f%c",
                            &tx,&ty,&end)==2 ||
                std::sscanf(argument,"%f,%f,%f%c",
                            &tx,&ty,&tz,&end)==3) {
              print(images,"Shift 3d object%s by displacement (%g,%g,%g).",
                    gmic_selection,
                    tx,ty,tz);
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                CImg<T>& img = gmic_check(images[ind]);
                try { gmic_apply(img,shift_CImg3d(tx,ty,tz)); }
                catch (CImgException &e) {
                  if (!img.is_CImg3d(true,message))
                    error(images,
                          "Command '-add3d': Invalid 3d object [%d], in selected image%s (%s).",
                          ind,gmic_selection,message);
                  else throw e;
                }
              }
              ++position;
            } else if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 &&
                       sep==']' &&
                       (ind=selection2cimg(indices,images.size(),images_names,"-add3d",true,
                                           false,CImg<char>::empty())).height()==1) {
              const CImg<T> img0 = gmic_image_arg(*ind);
              print(images,"Merge 3d object%s with 3d object [%u].",
                    gmic_selection,*ind);
              CImgList<T> nimages(2);
              nimages[1].assign(img0,true);
              cimg_forY(selection,l) {
                const unsigned int _ind = selection[l];
                CImg<T>& img = gmic_check(images[_ind]);
                nimages[0].assign(img,true);
                CImg<T> res;
                try { CImg<T>::append_CImg3d(nimages).move_to(res); }
                catch (CImgException &e) {
                  if (!img0.is_CImg3d(true,message))
                    error(images,"Command '-add3d': Invalid 3d object [%u], in specified "
                          "argument '%s' (%s).",
                          *ind,argument_text,message);
                  else if (!img.is_CImg3d(true,message))
                    error(images,
                          "Command '-add3d': Invalid 3d object [%d], in selected image%s (%s).",
                          _ind,gmic_selection,message);
                  else throw e;
                }
                if (is_get_version) {
                  res.move_to(images);
                  images_names[_ind].get_mark().copymark().move_to(images_names);
                } else {
                  res.move_to(images[_ind].assign());
                  images_names[_ind].mark();
                }
              }
              ++position;
            } else {
              print(images,"Merge 3d object%s.",
                    gmic_selection);
              if (selection) {
                CImgList<T> subimages(selection.height());
                cimg_forY(selection,l) subimages[l].assign(gmic_check(images[selection[l]]),true);
                CImg<T> img;
                try { CImg<T>::append_CImg3d(subimages).move_to(img); }
                catch (CImgException &e) {
                  cimg_forY(selection,l) {
                    const unsigned int ind = selection[l];
                    if (!images[ind].is_CImg3d(true,message))
                      error(images,
                            "Command '-add3d': Invalid 3d object [%d], in selected image%s (%s).",
                            ind,gmic_selection,message);
                  }
                  throw e;
                }
                CImg<char> name = images_names[selection[0]].get_mark();
                if (is_get_version) {
                  img.move_to(images);
                  images_names.insert(name.copymark());
                } else if (selection.height()>=2) {
                  remove_images(images,images_names,selection,1,selection.height()-1);
                  img.move_to(images[selection[0]].assign());
                  name.move_to(images_names[selection[0]]);
                }
              }
            }
            is_released = false; continue;
          }

          // Absolute value.
          gmic_simple_item("-abs",abs,"Compute pointwise absolute value of image%s.");

          // Bitwise and.
          gmic_arithmetic_item("-and",
                               operator&=,
                               "Compute bitwise AND of image%s by %g%s",
                               gmic_selection,value,ssep,Tlong,
                               operator&=,
                               "Compute bitwise AND of image%s by image [%d]",
                               gmic_selection,ind[0],
                               "Compute bitwise AND of image%s by expression %s",
                               gmic_selection,argument_text,
                               "Compute sequential bitwise AND of image%s");

          // Arc-tangent (two arguments).
          if (!std::strcmp("-atan2",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind;
            char sep = 0;
            if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                            indices,&sep,&end)==2 && sep==']' &&
                (ind=selection2cimg(indices,images.size(),images_names,"-atan2",true,
                                    false,CImg<char>::empty())).height()==1) {
              print(images,"Compute pointwise oriented arc-tangent of image%s, "
                    "with x-argument [%u].",
                    gmic_selection,
                    *ind);
              const CImg<T> img0 = gmic_image_arg(*ind);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],atan2(img0));
            } else arg_error("atan2");
            is_released = false; ++position; continue;
          }

          // Arc-cosine.
          gmic_simple_item("-acos",acos,"Compute pointwise arc-cosine of image%s.");

          // Arc-sine.
          gmic_simple_item("-asin",asin,"Compute pointwise arc-sine of image%s.");

          // Arc-tangent.
          gmic_simple_item("-atan",atan,"Compute pointwise arc-tangent of image%s.");

          // Draw axes.
          if (!std::strcmp("-axes",command)) {
            gmic_substitute_args();
            float xmin = 0, xmax = 0, ymin = 0, ymax = 0, opacity = 1, siz = 13;
            unsigned int pattern = ~0U;
            char seph = 0;
            *color = 0;
            if (std::sscanf(argument,"%f,%f%c",
                            &xmin,&xmax,&end)==2 ||
                std::sscanf(argument,"%f,%f,%f,%f%c",
                            &xmin,&xmax,&ymin,&ymax,&end)==4 ||
                std::sscanf(argument,"%f,%f,%f,%f,%f%c",
                            &xmin,&xmax,&ymin,&ymax,&siz,&end)==5 ||
                std::sscanf(argument,"%f,%f,%f,%f,%f,%f%c",
                            &xmin,&xmax,&ymin,&ymax,&siz,&opacity,&end)==6 ||
                (std::sscanf(argument,"%f,%f,%f,%f,%f,%f,0%c%x%c",
                             &xmin,&xmax,&ymin,&ymax,&siz,&opacity,&seph,&pattern,&end)==8 &&
                 seph=='x') ||
                (std::sscanf(argument,"%f,%f,%f,%f,%f,%f,%4095[0-9.eE,+-]%c",
                             &xmin,&xmax,&ymin,&ymax,&siz,&opacity,color,&end)==7 &&
                 (bool)(pattern=~0U)) ||
                (*color=0,std::sscanf(argument,"%f,%f,%f,%f,%f,%f,0%c%x,%4095[0-9.eE,+-]%c",
                                      &xmin,&xmax,&ymin,&ymax,&siz,&opacity,
                                      &seph,&pattern,color,&end)==9 && seph=='x')) {
              siz = cimg::round(siz);
              print(images,"Draw xy-axes on image%s, with x-range (%g,%g), y-range (%g,%g), "
                    "font height %g, opacity %g, pattern 0x%x and color (%s).",
                    gmic_selection,
                    xmin,xmax,
                    ymin,ymax,
                    siz,opacity,pattern,
                    *color?color:"default");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]], col(img.spectrum(),1,1,1,0);
                col.fill(color,true);
                gmic_apply(img,draw_axes(xmin,xmax,ymin,ymax,col.data(),opacity,
                                         -60,-60,0,0,pattern,pattern,(unsigned int)siz));
              }
            } else arg_error("axes");
            is_released = false; ++position; continue;
          }

#endif // #ifdef gmic_float
# 4488 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='a'.

        //----------------------------
        // Commands starting by '-b..'
        //----------------------------
        else if (command1=='b') {

#ifdef gmic_float

          // Blur.
          if (!std::strcmp("-blur",command)) {
            gmic_substitute_args();
            unsigned int boundary = 1, is_gaussian = 0;
            float sigma = -1;
            char sep = 0;
            if ((std::sscanf(argument,"%f%c",
                             &sigma,&end)==1 ||
                 (std::sscanf(argument,"%f%c%c",
                              &sigma,&sep,&end)==2 && sep=='%') ||
                 std::sscanf(argument,"%f,%u%c",
                             &sigma,&boundary,&end)==2 ||
                 (std::sscanf(argument,"%f%c,%u%c",
                              &sigma,&sep,&boundary,&end)==3 && sep=='%') ||
                 std::sscanf(argument,"%f,%u,%u%c",
                             &sigma,&boundary,&is_gaussian,&end)==3 ||
                 (std::sscanf(argument,"%f%c,%u,%u%c",
                              &sigma,&sep,&boundary,&is_gaussian,&end)==4 && sep=='%')) &&
                sigma>=0 && boundary<=1 && is_gaussian<=1) {
              print(images,"Blur image%s, with standard deviation %g%s, %s boundary conditions "
                    "and %s kernel.",
                    gmic_selection,
                    sigma,sep=='%'?"%":"",
                    boundary?"neumann":"dirichlet",
                    is_gaussian?"gaussian":"quasi-gaussian");
              if (sep=='%') sigma = -sigma;
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],blur(sigma,(bool)boundary,(bool)is_gaussian));
            } else arg_error("blur");
            is_released = false; ++position; continue;
          }

          // Bitwise right shift.
          gmic_arithmetic_item("-bsr",
                               operator>>=,
                               "Compute bitwise right shift of image%s by %g%s",
                               gmic_selection,value,ssep,Tlong,
                               operator>>=,
                               "Compute bitwise right shift of image%s by image [%d]",
                               gmic_selection,ind[0],
                               "Compute bitwise right shift of image%s by expression %s",
                               gmic_selection,argument_text,
                               "Compute sequential bitwise right shift of image%s");

          // Bitwise left shift.
          gmic_arithmetic_item("-bsl",
                               operator<<=,
                               "Compute bitwise left shift of image%s by %g%s",
                               gmic_selection,value,ssep,Tlong,
                               operator<<=,
                               "Compute bitwise left shift of image%s by image [%d]",
                               gmic_selection,ind[0],
                               "Compute bitwise left shift of image%s by expression %s",
                               gmic_selection,argument_text,
                               "Compute sequential bitwise left shift of image%s");

          // Bilateral filter.
          if (!std::strcmp("-bilateral",command)) {
            gmic_substitute_args();
            float sigma_s = 0, sigma_r = 0;
            CImg<unsigned int> ind;
            char sep_s =  0, sep_r = 0;
            if ((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             indices,argx,argy,&end)==3) &&
                (std::sscanf(argx,"%f%c",&sigma_s,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&sigma_s,&sep_s,&end)==2 && sep_s=='%')) &&
                (std::sscanf(argy,"%f%c",&sigma_r,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&sigma_r,&sep_r,&end)==2 && sep_r=='%')) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-bilateral",true,
                                    false,CImg<char>::empty())).height()==1 &&
                sigma_s>=0 && sigma_r>=0) {
              print(images,"Apply joint bilateral filter on image%s, with guide image [%u] "
                    "and standard deviations %g%s and %g.",
                    gmic_selection,
                    *ind,
                    sigma_s,sep_s=='%'?"%":"",
                    sigma_r,sep_r=='%'?"%":"");
              const CImg<T> guide = gmic_image_arg(*ind);
              if (sep_s=='%') sigma_s = -sigma_s;
              if (sep_r=='%') sigma_r = -sigma_r;
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],blur_bilateral(guide,sigma_s,sigma_r));
            } else if ((std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                                    argx,argy,&end)==2) &&
                       (std::sscanf(argx,"%f%c",&sigma_s,&end)==1 ||
                        (std::sscanf(argx,"%f%c%c",&sigma_s,&sep_s,&end)==2 && sep_s=='%')) &&
                       (std::sscanf(argy,"%f%c",&sigma_r,&end)==1 ||
                        (std::sscanf(argy,"%f%c%c",&sigma_r,&sep_r,&end)==2 && sep_r=='%')) &&
                       sigma_s>=0 && sigma_r>=0) {
              print(images,"Apply bilateral filter on image%s, with standard deviations %g%s "
                    "and %g.",
                    gmic_selection,
                    sigma_s,sep_s=='%'?"%":"",
                    sigma_r,sep_r=='%'?"%":"");
              if (sep_s=='%') sigma_s = -sigma_s;
              if (sep_r=='%') sigma_r = -sigma_r;
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],
                           blur_bilateral(images[selection[l]],sigma_s,sigma_r));
            } else arg_error("bilateral");
            is_released = false; ++position; continue;
          }

          // Set 3d background color.
          if (!std::strcmp("-background3d",item)) {
            gmic_substitute_args();
            float R = 0, G = 0, B = 0;
            CImg<unsigned int> ind;
            char sep = 0;
            const int nb = std::sscanf(argument,"%f,%f,%f%c",
                                       &R,&G,&B,&end);
            R = cimg::round(R);
            G = cimg::round(G);
            B = cimg::round(B);
            if (nb>=1 && nb<=3) {
              switch (nb) {
              case 1 : background3d.assign(1,1,1,3,(unsigned char)R); break;
              case 2 : background3d.assign(1,1,1,3,(unsigned char)R,(unsigned char)G,0); break;
              case 3 : background3d.assign(1,1,1,3,(unsigned char)R,(unsigned char)G,
                                           (unsigned char)B); break;
              }
              print(images,"Set 3d background color to (%u,%u,%u).",
                    (unsigned int)R,(unsigned int)G,(unsigned int)B);
              ++position;
            } else if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 &&
                       sep==']' &&
                       (ind=selection2cimg(indices,images.size(),images_names,"-background3d",true,
                                           false,CImg<char>::empty())).height()==1) {
              print(images,"Set 3d background from image [%u].",*ind);
              background3d.assign(images[*ind],false);
              ++position;
            } else {
              print(images,"Reset 3d background to default.");
              background3d.assign(1,2,1,3).fill(32,64,32,116,64,96).resize(1,256,1,3,3);
            }
            continue;
          }

#endif // #ifdef gmic_float
# 4636 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='b'.

        //----------------------------
        // Commands starting by '-c..'
        //----------------------------
        else if (command1=='c') {

          // Check expression or filename.
          if (!std::strcmp("-check",item)) {
            gmic_substitute_args();
            CImg<char> arg_check(argument,std::strlen(argument)+1);
            gmic_strreplace(arg_check);
            bool is_cond = false, is_filename = false;
            const CImg<T> &img = images.size()?images.back():CImg<T>::empty();
            try { if (img.eval(arg_check)) is_cond = true; }
            catch (CImgException&) {
              is_filename = true;
              is_cond = gmic_check_filename(arg_check);
            }
            if (verbosity>0 || is_debug) {
              print(images,"Check %s '%s' -> %s.",
                    is_filename?"file":"expression",
                    argument_text,
                    is_filename?(is_cond?"found":"not found"):(is_cond?"true":"false"));
            }
            if (!is_cond) {
              if (scope.size()>1 && scope.back()[0]!='*')
                error(scope.back().data(),images,"Command '-check': %s '%s' %s.",
                      is_filename?"file":"expression",
                      argument_text,
                      is_filename?"does not exist":"is false");
              else error(images,"Command '-check': %s '%s' %s.",
                         is_filename?"file":"expression",
                         argument_text,
                         is_filename?"does not exist":"is false");
            }
            ++position; continue;
          }

          // Crop.
          if (!std::strcmp("-crop",command)) {
            gmic_substitute_args();
            CImg<char> st0(64), st1(64), st2(64), st3(64), st4(64), st5(64), st6(64), st7(64);
            char sep0 = 0, sep1 = 0, sep2 = 0, sep3 = 0, sep4 = 0, sep5 = 0, sep6 = 0, sep7 = 0;
            float a0 = 0, a1 = 0, a2 = 0, a3 = 0, a4 = 0, a5 = 0, a6 = 0, a7 = 0;
            *st0 = *st1 = *st2 = *st3 = *st4 = *st5 = *st6 = *st7 = 0;
            unsigned int boundary = 0;
            if ((boundary=0,std::sscanf(argument,"%63[0-9.eE%+-],%63[0-9.eE%+-]%c",
                                        st0.data(),
                                        st1.data(),&end)==2 ||
                 std::sscanf(argument,"%63[0-9.eE%+-],%63[0-9.eE%+-],%u%c",
                             st0.data(),
                             st1.data(),&boundary,&end)==3) &&
                (std::sscanf(st0,"%f%c",&a0,&end)==1 ||
                 (std::sscanf(st0,"%f%c%c",&a0,&sep0,&end)==2 && sep0=='%')) &&
                (std::sscanf(st1,"%f%c",&a1,&end)==1 ||
                 (std::sscanf(st1,"%f%c%c",&a1,&sep1,&end)==2 && sep1=='%')) &&
                boundary<=1) {
              print(images,"Crop image%s with selection (%g%s) x (%g%s) and "
                    "%s boundary conditions.",
                    gmic_selection,
                    a0,sep0=='%'?"%":"",
                    a1,sep1=='%'?"%":"",
                    boundary?"neumann":"dirichlet");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  x0 = (int)cimg::round(sep0=='%'?a0*(img.width()-1)/100:a0),
                  x1 = (int)cimg::round(sep1=='%'?a1*(img.width()-1)/100:a1);
                gmic_apply(img,crop(x0,x1,(bool)boundary));
              }
              ++position;
            } else if ((boundary=0,std::sscanf(argument,
                                               "%63[0-9.eE%+-],%63[0-9.eE%+-],"
                                               "%63[0-9.eE%+-],%63[0-9.eE%+-]%c",
                                               st0.data(),st1.data(),
                                               st2.data(),st3.data(),&end)==4 ||
                        std::sscanf(argument,
                                    "%63[0-9.eE%+-],%63[0-9.eE%+-],"
                                    "%63[0-9.eE%+-],%63[0-9.eE%+-],%u%c",
                                    st0.data(),st1.data(),
                                    st2.data(),st3.data(),&boundary,&end)==5) &&
                       (std::sscanf(st0,"%f%c",&a0,&end)==1 ||
                        (std::sscanf(st0,"%f%c%c",&a0,&sep0,&end)==2 && sep0=='%')) &&
                       (std::sscanf(st1,"%f%c",&a1,&end)==1 ||
                        (std::sscanf(st1,"%f%c%c",&a1,&sep1,&end)==2 && sep1=='%')) &&
                       (std::sscanf(st2,"%f%c",&a2,&end)==1 ||
                        (std::sscanf(st2,"%f%c%c",&a2,&sep2,&end)==2 && sep2=='%')) &&
                       (std::sscanf(st3,"%f%c",&a3,&end)==1 ||
                        (std::sscanf(st3,"%f%c%c",&a3,&sep3,&end)==2 && sep3=='%')) &&
                       boundary<=1) {
              print(images,
                    "Crop image%s with selection (%g%s,%g%s) x (%g%s,%g%s) and "
                    "%s boundary conditions.",
                    gmic_selection,
                    a0,sep0=='%'?"%":"",
                    a1,sep1=='%'?"%":"",
                    a2,sep2=='%'?"%":"",
                    a3,sep3=='%'?"%":"",
                    boundary?"neumann":"dirichlet");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  x0 = (int)cimg::round(sep0=='%'?a0*(img.width()-1)/100:a0),
                  y0 = (int)cimg::round(sep1=='%'?a1*(img.height()-1)/100:a1),
                  x1 = (int)cimg::round(sep2=='%'?a2*(img.width()-1)/100:a2),
                  y1 = (int)cimg::round(sep3=='%'?a3*(img.height()-1)/100:a3);
                gmic_apply(img,crop(x0,y0,x1,y1,(bool)boundary));
              }
              ++position;
            } else if ((boundary=0,std::sscanf(argument,
                                               "%63[0-9.eE%+-],%63[0-9.eE%+-],%63[0-9.eE%+-],"
                                               "%63[0-9.eE%+-],%63[0-9.eE%+-],%63[0-9.eE%+-]%c",
                                               st0.data(),st1.data(),st2.data(),
                                               st3.data(),st4.data(),st5.data(),&end)==6 ||
                        std::sscanf(argument,"%63[0-9.eE%+-],%63[0-9.eE%+-],%63[0-9.eE%+-],"
                                    "%63[0-9.eE%+-],%63[0-9.eE%+-],%63[0-9.eE%+-],%u%c",
                                    st0.data(),st1.data(),st2.data(),
                                    st3.data(),st4.data(),st5.data(),&boundary,&end)==7) &&
                       (std::sscanf(st0,"%f%c",&a0,&end)==1 ||
                        (std::sscanf(st0,"%f%c%c",&a0,&sep0,&end)==2 && sep0=='%')) &&
                       (std::sscanf(st1,"%f%c",&a1,&end)==1 ||
                        (std::sscanf(st1,"%f%c%c",&a1,&sep1,&end)==2 && sep1=='%')) &&
                       (std::sscanf(st2,"%f%c",&a2,&end)==1 ||
                        (std::sscanf(st2,"%f%c%c",&a2,&sep2,&end)==2 && sep2=='%')) &&
                       (std::sscanf(st3,"%f%c",&a3,&end)==1 ||
                        (std::sscanf(st3,"%f%c%c",&a3,&sep3,&end)==2 && sep3=='%')) &&
                       (std::sscanf(st4,"%f%c",&a4,&end)==1 ||
                        (std::sscanf(st4,"%f%c%c",&a4,&sep4,&end)==2 && sep4=='%')) &&
                       (std::sscanf(st5,"%f%c",&a5,&end)==1 ||
                        (std::sscanf(st5,"%f%c%c",&a5,&sep5,&end)==2 && sep5=='%')) &&
                       boundary<=1) {
              print(images,"Crop image%s with selection (%g%s,%g%s,%g%s) x (%g%s,%g%s,%g%s) "
                    "and %s boundary conditions.",
                    gmic_selection,
                    a0,sep0=='%'?"%":"",
                    a1,sep1=='%'?"%":"",
                    a2,sep2=='%'?"%":"",
                    a3,sep3=='%'?"%":"",
                    a4,sep4=='%'?"%":"",
                    a5,sep5=='%'?"%":"",
                    boundary?"neumann":"dirichlet");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  x0 = (int)cimg::round(sep0=='%'?a0*(img.width()-1)/100:a0),
                  y0 = (int)cimg::round(sep1=='%'?a1*(img.height()-1)/100:a1),
                  z0 = (int)cimg::round(sep2=='%'?a2*(img.depth()-1)/100:a2),
                  x1 = (int)cimg::round(sep3=='%'?a3*(img.width()-1)/100:a3),
                  y1 = (int)cimg::round(sep4=='%'?a4*(img.height()-1)/100:a4),
                  z1 = (int)cimg::round(sep5=='%'?a5*(img.depth()-1)/100:a5);
                gmic_apply(img,crop(x0,y0,z0,x1,y1,z1,(bool)boundary));
              }
              ++position;
            } else if ((boundary=0,std::sscanf(argument,
                                               "%63[0-9.eE%+-],%63[0-9.eE%+-],%63[0-9.eE%+-],"
                                               "%63[0-9.eE%+-],%63[0-9.eE%+-],%63[0-9.eE%+-],"
                                               "%63[0-9.eE%+-],%63[0-9.eE%+-]%c",
                                               st0.data(),st1.data(),st2.data(),st3.data(),
                                               st4.data(),st5.data(),st6.data(),st7.data(),&end)==8 ||
                        std::sscanf(argument,"%63[0-9.eE%+-],%63[0-9.eE%+-],%63[0-9.eE%+-],"
                                    "%63[0-9.eE%+-],%63[0-9.eE%+-],%63[0-9.eE%+-],"
                                    "%63[0-9.eE%+-],%63[0-9.eE%+-],%u%c",
                                    st0.data(),st1.data(),st2.data(),st3.data(),
                                    st4.data(),st5.data(),st6.data(),st7.data(),&boundary,&end)==9) &&
                       (std::sscanf(st0,"%f%c",&a0,&end)==1 ||
                        (std::sscanf(st0,"%f%c%c",&a0,&sep0,&end)==2 && sep0=='%')) &&
                       (std::sscanf(st1,"%f%c",&a1,&end)==1 ||
                        (std::sscanf(st1,"%f%c%c",&a1,&sep1,&end)==2 && sep1=='%')) &&
                       (std::sscanf(st2,"%f%c",&a2,&end)==1 ||
                        (std::sscanf(st2,"%f%c%c",&a2,&sep2,&end)==2 && sep2=='%')) &&
                       (std::sscanf(st3,"%f%c",&a3,&end)==1 ||
                        (std::sscanf(st3,"%f%c%c",&a3,&sep3,&end)==2 && sep3=='%')) &&
                       (std::sscanf(st4,"%f%c",&a4,&end)==1 ||
                        (std::sscanf(st4,"%f%c%c",&a4,&sep4,&end)==2 && sep4=='%')) &&
                       (std::sscanf(st5,"%f%c",&a5,&end)==1 ||
                        (std::sscanf(st5,"%f%c%c",&a5,&sep5,&end)==2 && sep5=='%')) &&
                       (std::sscanf(st6,"%f%c",&a6,&end)==1 ||
                        (std::sscanf(st6,"%f%c%c",&a6,&sep6,&end)==2 && sep6=='%')) &&
                       (std::sscanf(st7,"%f%c",&a7,&end)==1 ||
                        (std::sscanf(st7,"%f%c%c",&a7,&sep7,&end)==2 && sep7=='%')) &&
                       boundary<=1) {
              print(images,
                    "Crop image%s with selection (%g%s,%g%s,%g%s,%g%s) x (%g%s,%g%s,%g%s,%g%s) "
                    "and %s boundary conditions.",
                    gmic_selection,
                    a0,sep0=='%'?"%":"",
                    a1,sep1=='%'?"%":"",
                    a2,sep2=='%'?"%":"",
                    a3,sep3=='%'?"%":"",
                    a4,sep4=='%'?"%":"",
                    a5,sep5=='%'?"%":"",
                    a6,sep6=='%'?"%":"",
                    a7,sep7=='%'?"%":"",
                    boundary?"neumann":"dirichlet");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  x0 = (int)cimg::round(sep0=='%'?a0*(img.width()-1)/100:a0),
                  y0 = (int)cimg::round(sep1=='%'?a1*(img.height()-1)/100:a1),
                  z0 = (int)cimg::round(sep2=='%'?a2*(img.depth()-1)/100:a2),
                  v0 = (int)cimg::round(sep3=='%'?a3*(img.spectrum()-1)/100:a3),
                  x1 = (int)cimg::round(sep4=='%'?a4*(img.width()-1)/100:a4),
                  y1 = (int)cimg::round(sep5=='%'?a5*(img.height()-1)/100:a5),
                  z1 = (int)cimg::round(sep6=='%'?a6*(img.depth()-1)/100:a6),
                  v1 = (int)cimg::round(sep7=='%'?a7*(img.spectrum()-1)/100:a7);
                gmic_apply(img,crop(x0,y0,z0,v0,x1,y1,z1,v1,(bool)boundary));
              }
              ++position;
            } else {
#if cimg_display==0
              print(images,"Crop image%s in interactive mode (skipped, no display support).",
                    gmic_selection);
#else // #if cimg_display==0
# 4850 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
              bool is_available_display = false;
              try {
                is_available_display = (bool)CImgDisplay::screen_width();
              } catch (CImgDisplayException&) {
                print(images,"Crop image%s in interactive mode (skipped, no display available).",
                      gmic_selection);
              }
              if (is_available_display) {
                print(images,"Crop image%s in interactive mode.",
                      gmic_selection);
                CImgDisplay _disp, &disp = instant_window[0]?instant_window[0]:_disp;
                cimg_forY(selection,l) {
                  CImg<T>& img = gmic_check(images[selection[l]]);
                  if (disp) disp.resize(cimg_fitscreen(img.width(),img.height(),1),false);
                  else disp.assign(cimg_fitscreen(img.width(),img.height(),1),0,1);
                  disp.set_title("%s: crop",gmic_basename(images_names[selection[l]].data()));
                  const CImg<int> s = img.get_select(disp,2);
                  print(images,"Crop image [%d] with selection (%d,%d,%d) x (%d,%d,%d).",
                        selection[l],
                        s[0],s[1],s[2],
                        s[3],s[4],s[5]);
                  gmic_apply(img,crop(s[0],s[1],s[2],s[3],s[4],s[5]));
                }
              }
#endif // #if cimg_display==0
# 4875 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            }
            is_released = false; continue;
          }

          // Keep channels.
          if (!std::strcmp("-channels",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind0, ind1;
            float value0 = 0, value1 = 0;
            char sep0 = 0, sep1 = 0;
            *argx = *argy = 0;
            if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-]%c",
                            argx,&end)==1 &&
                ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c]",indices,&sep0,&end)==2 &&
                  sep0==']' &&
                  (ind0=selection2cimg(indices,images.size(),images_names,"-channels",true,
                                       false,CImg<char>::empty())).height()==1) ||
                 std::sscanf(argx,"%f%c",&value0,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&value0,&sep0,&end)==2 && sep0=='%'))) {
              if (ind0) { value0 = images[*ind0].spectrum() - 1.0f; sep0 = 0; }
              print(images,"Keep channel %g%s of image%s.",
                    value0,sep0=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  nvalue0 = (int)cimg::round(sep0=='%'?value0*(img.spectrum()-1)/100:value0);
                gmic_apply(img,channel(nvalue0));
              }
            } else if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                                   argx,argy,&end)==2 &&
                       ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep0,&end)==2 &&
                         sep0==']' &&
                         (ind0=selection2cimg(indices,images.size(),images_names,"-channels",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        std::sscanf(argx,"%f%c",&value0,&end)==1 ||
                        (std::sscanf(argx,"%f%c%c",&value0,&sep0,&end)==2 && sep0=='%')) &&
                       ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",formula,&sep0,&end)==2 &&
                         sep0==']' &&
                         (ind1=selection2cimg(formula,images.size(),images_names,"-channels",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        std::sscanf(argy,"%f%c",&value1,&end)==1 ||
                        (std::sscanf(argy,"%f%c%c",&value1,&sep1,&end)==2 && sep1=='%'))) {
              if (ind0) { value0 = images[*ind0].spectrum() - 1.0f; sep0 = 0; }
              if (ind1) { value1 = images[*ind1].spectrum() - 1.0f; sep1 = 0; }
              print(images,"Keep channels %g%s..%g%s of image%s.",
                    value0,sep0=='%'?"%":"",
                    value1,sep1=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  nvalue0 = (int)cimg::round(sep0=='%'?value0*(img.spectrum()-1)/100:value0),
                  nvalue1 = (int)cimg::round(sep1=='%'?value1*(img.spectrum()-1)/100:value1);
                gmic_apply(img,channels(nvalue0,nvalue1));
              }
            } else arg_error("channels");
            is_released = false; ++position; continue;
          }

          // Keep columns.
          if (!std::strcmp("-columns",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind0, ind1;
            float value0 = 0, value1 = 0;
            char sep0 = 0, sep1 = 0;
            *argx = *argy = 0;
            if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-]%c",
                            argx,&end)==1 &&
                ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c]",indices,&sep0,&end)==2 &&
                  sep0==']' &&
                  (ind0=selection2cimg(indices,images.size(),images_names,"-columns",true,
                                       false,CImg<char>::empty())).height()==1) ||
                 std::sscanf(argx,"%f%c",&value0,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&value0,&sep0,&end)==2 && sep0=='%'))) {
              if (ind0) { value0 = images[*ind0].width() - 1.0f; sep0 = 0; }
              print(images,"Keep column %g%s of image%s.",
                    value0,sep0=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int nvalue0 = (int)cimg::round(sep0=='%'?value0*(img.width()-1)/100:value0);
                gmic_apply(img,column(nvalue0));
              }
            } else if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                                   argx,argy,&end)==2 &&
                       ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep0,&end)==2 &&
                         sep0==']' &&
                         (ind0=selection2cimg(indices,images.size(),images_names,"-columns",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        std::sscanf(argx,"%f%c",&value0,&end)==1 ||
                        (std::sscanf(argx,"%f%c%c",&value0,&sep0,&end)==2 && sep0=='%')) &&
                       ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",formula,&sep0,&end)==2 &&
                         sep0==']' &&
                         (ind1=selection2cimg(formula,images.size(),images_names,"-columns",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        std::sscanf(argy,"%f%c",&value1,&end)==1 ||
                        (std::sscanf(argy,"%f%c%c",&value1,&sep1,&end)==2 && sep1=='%'))) {
              if (ind0) { value0 = images[*ind0].width() - 1.0f; sep0 = 0; }
              if (ind1) { value1 = images[*ind1].width() - 1.0f; sep1 = 0; }
              print(images,"Keep columns %g%s..%g%s of image%s.",
                    value0,sep0=='%'?"%":"",
                    value1,sep1=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  nvalue0 = (int)cimg::round(sep0=='%'?value0*(img.width()-1)/100:value0),
                  nvalue1 = (int)cimg::round(sep1=='%'?value1*(img.width()-1)/100:value1);
                gmic_apply(img,columns(nvalue0,nvalue1));
              }
            } else arg_error("columns");
            is_released = false; ++position; continue;
          }

          // Import custom commands.
          if (!std::strcmp("-command",item)) {
            gmic_substitute_args();
            CImg<char> _arg_command(argument,std::strlen(argument)+1);
            const char *arg_command_text = argument_text;
            char *arg_command = _arg_command;
            gmic_strreplace(arg_command);

            unsigned int siz = 0;
            for (unsigned int l = 0; l<256; ++l) siz+=commands[l].size();

            bool add_debug_infos = true;
            if ((*arg_command=='0' || *arg_command=='1') && arg_command[1]==',') {
              add_debug_infos = (*arg_command=='1');
              arg_command+=2; arg_command_text+=2;
            }

            std::FILE *file = std::fopen(arg_command,"rb");
            if (file) {
              print(images,"Import custom commands from file '%s'%s",
                    arg_command_text,
                    !add_debug_infos?" without debug infos":"");
              add_commands(file,arg_command,commands_names,commands,commands_has_arguments,add_debug_infos);
              std::fclose(file);
            } else if (!cimg::strncasecmp(arg_command,"http://",7) ||
                       !cimg::strncasecmp(arg_command,"https://",8)) { // Try to read from network.
              print(images,"Import custom commands from URL '%s'%s",
                    arg_command_text,
                    !add_debug_infos?" without debug infos":"");
              CImg<char> filename_tmp(1024);
              try {
                file = std::fopen(cimg::load_network_external(arg_command,filename_tmp),"r");
              } catch (...) {
                file = 0;
              }
              if (file) {
                add_commands(file,arg_command,commands_names,commands,commands_has_arguments,add_debug_infos);
                std::fclose(file);
              } else
                error(images,"Command '-command': Unable to reach custom commands file '%s' "
                      "from network.",
                      arg_command_text);
              std::remove(filename_tmp);
            } else {
              print(images,"Import custom commands from expression '%s'",
                    arg_command_text);
              add_commands(arg_command,commands_names,commands,commands_has_arguments);
            }
            if (verbosity>=0 || is_debug) {
              unsigned int nb_added = 0;
              for (unsigned int l = 0; l<256; ++l) nb_added+=commands[l].size();
              nb_added-=siz;
              std::fprintf(cimg::output()," (added %u command%s, total %u).",
                           nb_added,nb_added>1?"s":"",siz+nb_added);
              std::fflush(cimg::output());
            }
            ++position; continue;
          }

          // Camera input.
          if (!std::strcmp("-camera",item)) {
            gmic_substitute_args();
            float
              cam_index = 0, nb_frames = 1, skip_frames = 0,
              capture_width = 0, capture_height = 0;
            unsigned int release_cam = 0;
            if ((std::sscanf(argument,"%f%c",
                             &cam_index,&end)==1 ||
                 std::sscanf(argument,"%f,%f%c",
                             &cam_index,&nb_frames,&end)==2 ||
                 std::sscanf(argument,"%f,%f,%f%c",
                             &cam_index,&nb_frames,&skip_frames,&end)==3 ||
                 std::sscanf(argument,"%f,%f,%f,%u%c",
                             &cam_index,&nb_frames,&skip_frames,&release_cam,&end)==4 ||
                 std::sscanf(argument,"%f,%f,%f,%u,%f,%f,%c",
                             &cam_index,&nb_frames,&skip_frames,&release_cam,
                             &capture_width,&capture_height,&end)==6) &&
                cam_index>=0 && nb_frames>=0 && skip_frames>=0 && release_cam<=1 &&
                ((!capture_width && !capture_height) || (capture_width>0 && capture_height>0)))
              ++position;
            cam_index = cimg::round(cam_index);
            nb_frames = cimg::round(nb_frames);
            skip_frames = cimg::round(skip_frames);
            capture_width = cimg::round(capture_width);
            capture_height = cimg::round(capture_height);
            if (release_cam) {
              print(images,"Release camera #%g.",cam_index);
              CImg<T>::get_load_camera((unsigned int)cam_index,0,true);
            } else {
              if (capture_width)
                print(images,"Insert %g image%s from camera #%g, with %g frames skipping "
                      "and resolution %gx%g.",
                      cam_index,nb_frames,nb_frames>1?"s":"",skip_frames,
                      capture_width,capture_height);
              else print(images,"Insert %g image%s from camera #%g, with %g frames skipping.",
                         cam_index,nb_frames,nb_frames>1?"s":"",skip_frames);
              cimg_snprintf(title,_title.size(),"[Camera #%g]",cam_index);
              const CImg<char> _title = CImg<char>::string(title);
              if (nb_frames>1) {
                std::fputc('\n',cimg::output());
                std::fflush(cimg::output());
              }
              for (unsigned int k = 0; k<(unsigned int)nb_frames; ++k) {
                if (nb_frames>1 && (verbosity>=0 || is_debug)) {
                  std::fprintf(cimg::output(),"\r  > Image %u/%u        ",
                               k+1,(unsigned int)nb_frames);
                  std::fflush(cimg::output());
                }
                CImg<T>::get_load_camera((unsigned int)cam_index,(unsigned int)skip_frames,false,
                                         (unsigned int)capture_width,(unsigned int)capture_height).
                  move_to(images);
                images_names.insert(_title);
              }
            }
            is_released = false; continue;
          }

          // Check validity of 3d object.
          if (!std::strcmp("-check3d",command) && !is_get_version) {
            gmic_substitute_args();
            bool is_full_check = true;
            if (!argument[1] && (*argument=='0' || *argument=='1')) {
              is_full_check = (*argument=='1');
              ++position;
            } else is_full_check = true;
            if (verbosity>0 || is_debug)
              print(images,"Check validity of 3d object%s (%s check)",
                    gmic_selection,
                    is_full_check?"full":"fast");
            cimg_forY(selection,l) {
              const unsigned int ind = selection[l];
              CImg<T>& img = gmic_check(images[ind]);
              if (!img.is_CImg3d(is_full_check,message)) {
                if (verbosity>0 || is_debug) {
                  std::fprintf(cimg::output()," -> invalid.");
                  std::fflush(cimg::output());
                }
                error(images,
                      "Command '-check3d': Invalid 3d object [%d], in selected image%s (%s).",
                      ind,gmic_selection,message);
              }
            }
            if (verbosity>0 || is_debug) {
              std::fprintf(cimg::output()," -> valid.");
              std::fflush(cimg::output());
            }
            continue;
          }

#ifdef gmic_float

          // Cut.
          if (!std::strcmp("-cut",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind0, ind1;
            double value0 = 0, value1 = 0;
            char sep0 = 0, sep1 = 0;
            *argx = *argy = 0;
            if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                            argx,argy,&end)==2 &&
                ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep0,&end)==2 &&
                  sep0==']' &&
                  (ind0=selection2cimg(indices,images.size(),images_names,"-cut",true,
                                       false,CImg<char>::empty())).height()==1) ||
                 (std::sscanf(argx,"%lf%c%c",&value0,&sep0,&end)==2 && sep0=='%') ||
                 std::sscanf(argx,"%lf%c",&value0,&end)==1) &&
                ((std::sscanf(argy,"[%255[a-zA-Z0-9_.%+-]%c%c",formula,&sep1,&end)==2 &&
                  sep1==']' &&
                  (ind1=selection2cimg(formula,images.size(),images_names,"-cut",true,
                                       false,CImg<char>::empty())).height()==1) ||
                 (std::sscanf(argy,"%lf%c%c",&value1,&sep1,&end)==2 && sep1=='%') ||
                 std::sscanf(argy,"%lf%c",&value1,&end)==1)) {
              if (ind0) { value0 = images[*ind0].min(); sep0 = 0; }
              if (ind1) { value1 = images[*ind1].max(); sep1 = 0; }
              print(images,"Cut image%s in range [%g%s,%g%s].",
                    gmic_selection,
                    value0,sep0=='%'?"%":"",
                    value1,sep1=='%'?"%":"");
              cimg_forY(selection,l) {
                CImg<T> &img = gmic_check(images[selection[l]]);
                double vmin = 0, vmax = 0, nvalue0 = value0, nvalue1 = value1;
                if (sep0=='%' || sep1=='%') {
                  if (img) vmax = (double)img.max_min(vmin);
                  if (sep0=='%') nvalue0 = vmin + (vmax-vmin)*value0/100;
                  if (sep1=='%') nvalue1 = vmin + (vmax-vmin)*value1/100;
                }
                gmic_apply(img,cut((T)nvalue0,(T)nvalue1));
              }
              ++position;
            } else if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep0,&end)==2 &&
                       sep0==']' &&
                       (ind0=selection2cimg(indices,images.size(),images_names,"-cut",true,
                                            false,CImg<char>::empty())).height()==1) {
              if (images[*ind0]) value1 = (double)images[*ind0].max_min(value0);
              print(images,"Cut image%s in range [%g,%g].",
                    gmic_selection,
                    value0,
                    value1);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],cut((T)value0,(T)value1));
              ++position;
            } else {
#if cimg_display==0
              print(images,"Cut image%s in interactive mode (skipped, no display support).",
                    gmic_selection);
#else // #if cimg_display==0
# 5195 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
              bool is_available_display = false;
              try {
                is_available_display = (bool)CImgDisplay::screen_width();
              } catch (CImgDisplayException&) {
                print(images,"Cut image%s in interactive mode (skipped, no display available).",
                      gmic_selection);
              }
              if (is_available_display) {
                print(images,"Cut image%s in interactive mode.",
                      gmic_selection);
                CImgDisplay _disp, &disp = instant_window[0]?instant_window[0]:_disp;
                cimg_forY(selection,l) {
                  CImg<T> &img = gmic_check(images[selection[l]]);
                  if (img) {
                    CImg<T> visu = img.depth()>1?img.get_projections2d(img.width()/2,
                                                                       img.height()/2,
                                                                       img.depth()/2).
                      channels(0,cimg::min(3,img.spectrum())-1):
                      img.get_channels(0,cimg::min(3,img.spectrum()-1));
                    const unsigned int
                      w = CImgDisplay::_fitscreen(visu.width(),visu.height(),1,256,-85,false),
                      h = CImgDisplay::_fitscreen(visu.width(),visu.height(),1,256,-85,true);
                    if (disp) disp.resize(w,h,false); else disp.assign(w,h,0,0);
                    double vmin = 0, vmax = (double)img.max_min(vmin),
                      percent0 = 0, percent1 = 100;
                    bool stopflag = false, is_clicked = false;
                    int omx = -1, omy = -1;
                    CImg<unsigned char> res;
                    for (disp.show().flush(); !stopflag; ) {
                      const unsigned char white[] = { 255,255,255 }, black[] = { 0,0,0 };
                      const unsigned int key = disp.key();
                      if (!res)
                        disp.display((res=visu.get_cut((T)(vmin + percent0*(vmax-vmin)/100),
                                                       (T)(vmin + percent1*(vmax-vmin)/100)).
                                      resize(disp).normalize((T)0,(T)255)).
                                     draw_text(0,0,"Cut [%g,%g] = [%.3g%%,%.3g%%]",
                                               white,black,0.7f,13,
                                               (double)(vmin + percent0*(vmax-vmin)/100),
                                               (double)(vmin + percent1*(vmax-vmin)/100),
                                               percent0,percent1)).
                          set_title("%s (%dx%dx%dx%d)",
                                    gmic_basename(images_names[selection[l]].data()),
                                    img.width(),img.height(),img.depth(),img.spectrum()).wait();
                      const int mx = disp.mouse_x(), my = disp.mouse_y();
                      if (disp.button()) {
                        if (mx>=0 && my>=0 && (mx!=omx || my!=omy)) {
                          percent0 = (my-16)*100.0/(disp.height()-32);
                          percent1 = (mx-16)*100.0/(disp.width()-32);
                          if (percent0<0) percent0 = 0; else if (percent0>101) percent0 = 101;
                          if (percent1<0) percent1 = 0; else if (percent1>101) percent1 = 101;
                          if (percent0>percent1) cimg::swap(percent0,percent1);
                          omx = mx; omy = my; res.assign();
                        }
                        is_clicked = true;
                      } else if (is_clicked) break;
                      if (disp.is_closed() || (key && key!=cimg::keyCTRLLEFT)) stopflag = true;
                      if (key==cimg::keyD && disp.is_keyCTRLLEFT()) {
                        disp.resize(cimg_fitscreen(3*disp.width()/2,3*disp.height()/2,1),
                                    stopflag=false).set_key(cimg::keyD,false);
                        res.assign();
                      }
                      if (key==cimg::keyC && disp.is_keyCTRLLEFT()) {
                        disp.resize(cimg_fitscreen(2*disp.width()/3,2*disp.height()/3,1),
                                    stopflag=false).set_key(cimg::keyC,false);
                        res.assign();
                      }
                      if (disp.is_resized()) { disp.resize(false); res.assign(); }
                    }
                    print(images,"Cut image [%d] in range [%g,%g] = [%.3g%%,%.3g%%].",
                          selection[l],
                          (double)(vmin + percent0*(vmax-vmin)/100),
                          (double)(vmin + percent1*(vmax-vmin)/100),
                          percent0,percent1);
                    gmic_apply(img,cut((T)(vmin + percent0*(vmax-vmin)/100),
                                       (T)(vmin + percent1*(vmax-vmin)/100)));
                  } else { gmic_apply(img,replace(img)); }
                }
              }
#endif // #if cimg_display==0
# 5274 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            }
            is_released = false; continue;
          }

          // Cosine.
          gmic_simple_item("-cos",cos,"Compute pointwise cosine of image%s.");

          // Convolve.
          if (!std::strcmp("-convolve",command)) {
            gmic_substitute_args();
            unsigned int boundary = 1, is_normalized = 0;
            CImg<unsigned int> ind;
            char sep = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                              indices,&sep,&end)==2 && sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u%c",
                             indices,&boundary,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u%c",
                             indices,&boundary,&is_normalized,&end)==3) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-convolve",true,
                                    false,CImg<char>::empty())).height()==1 &&
                boundary<=1) {
              print(images,
                    "Convolve image%s with mask [%u] and %s boundary conditions, "
                    "with%s normalization.",
                    gmic_selection,
                    *ind,
                    boundary?"neumann":"dirichlet",
                    is_normalized?"":"out");
              const CImg<T> mask = gmic_image_arg(*ind);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],convolve(mask,boundary,(bool)is_normalized));
            } else arg_error("convolve");
            is_released = false; ++position; continue;
          }

          // Correlate.
          if (!std::strcmp("-correlate",command)) {
            gmic_substitute_args();
            unsigned int boundary = 1, is_normalized = 0;
            CImg<unsigned int> ind;
            char sep = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                              indices,&sep,&end)==2 && sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u%c",
                             indices,&boundary,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u%c",
                             indices,&boundary,&is_normalized,&end)==3) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-correlate",true,
                                    false,CImg<char>::empty())).height()==1 &&
                boundary<=1) {
              print(images,
                    "Correlate image%s with mask [%u] and %s boundary conditions, "
                    "with%s normalization.",
                    gmic_selection,
                    *ind,
                    boundary?"neumann":"dirichlet",
                    is_normalized?"":"out");
              const CImg<T> mask = gmic_image_arg(*ind);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],correlate(mask,boundary,(bool)is_normalized));
            } else arg_error("correlate");
            is_released = false; ++position; continue;
          }

          // Set 3d object color.
          if (!std::strcmp("-color3d",command) || !std::strcmp("-col3d",command)) {
            gmic_substitute_args();
            float R = 200, G = 200, B = 200, opacity = -1;
            if ((std::sscanf(argument,"%f%c",
                             &R,&end)==1 && ((B=G=R),1)) ||
                (std::sscanf(argument,"%f,%f%c",
                             &R,&G,&end)==2 && ((B=0),1)) ||
                std::sscanf(argument,"%f,%f,%f%c",
                            &R,&G,&B,&end)==3 ||
                std::sscanf(argument,"%f,%f,%f,%f%c",
                            &R,&G,&B,&opacity,&end)==4) {
              const bool set_opacity = (opacity>=0);
              if (set_opacity)
                print(images,"Set colors of 3d object%s to (%g,%g,%g), with opacity %g.",
                      gmic_selection,
                      R,G,B,
                      opacity);
              else
                print(images,"Set color of 3d object%s to (%g,%g,%g).",
                      gmic_selection,
                      R,G,B);
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                CImg<T>& img = gmic_check(images[ind]);
                try { gmic_apply(img,color_CImg3d(R,G,B,opacity,true,set_opacity)); }
                catch (CImgException &e) {
                  if (!img.is_CImg3d(true,message))
                    error(images,"Command '-color3d': Invalid 3d object [%d], "
                          "in selected image%s (%s).",
                          ind,gmic_selection,message);
                  else throw e;
                }
              }
            } else arg_error("color3d");
            is_released = false; ++position; continue;
          }

          // Show/hide mouse cursor.
          if (!std::strcmp("-cursor",command) && !is_get_version) {
            gmic_substitute_args();
            if (!is_restriction)
              CImg<unsigned int>::vector(0,1,2,3,4,5,6,7,8,9).move_to(selection);
            bool value = true;
            if (!argument[1] && (*argument=='0' || *argument=='1')) {
              value = (*argument=='1'); ++position;
            } else value = true;

#if cimg_display==0
            print(images,"%s mouse cursor for instant window%s (skipped, no display support).",
                  value?"Show":"Hide",
                  gmic_selection);
#else
# 5392 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            try {
              if (value) cimg_forY(selection,l) { if (!instant_window[l].is_closed()) instant_window[selection[l]].show_mouse(); }
              else cimg_forY(selection,l) { if (!instant_window[l].is_closed()) instant_window[selection[l]].hide_mouse(); }
              print(images,"%s mouse cursor for instant window%s.",
                    value?"Show":"Hide",
                    gmic_selection);
            } catch (CImgDisplayException&) {
              print(images,"%s mouse cursor for instant window%s (skipped, no display available).",
                    value?"Show":"Hide",
                    gmic_selection);
            }
#endif
# 5404 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            continue;
          }

          // Hyperbolic cosine.
          gmic_simple_item("-cosh",cosh,"Compute pointwise hyperbolic cosine of image%s.");

#endif // #ifdef gmic_float
# 5411 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='c'.

        //----------------------------
        // Commands starting by '-d..'
        //----------------------------
        else if (command1=='d') {

          // Done.
          if (!std::strcmp("-done",item)) {
            const CImg<char> &s = scope.back();
            if (s[0]!='*' || s[1]!='r')
              error(images,"Command '-done': Not associated to a '-repeat' command "
                    "within the same scope.");
            if (--repeatdones.back()(1)) {
              ++repeatdones.back()(2);
              position = repeatdones.back()(0);
            } else {
              if (verbosity>0 || is_debug) print(images,"End 'repeat..done' block.");
              repeatdones.remove();
              scope.remove();
            }
            continue;
          }

          // Do..while.
          if (!std::strcmp("-do",item)) {
            CImg<char>::string("*do").move_to(scope);
            if (verbosity>0 || is_debug) print(images,"Start '-do..-while' block.");
            CImg<unsigned int>::vector(position).move_to(dowhiles);
            continue;
          }

          // Enable debug mode (useful when '-debug' is invoked from a custom command).
          if (!std::strcmp("-debug",item)) {
            is_debug = true;
            continue;
          }

#ifdef gmic_float

          // Divide.
          gmic_arithmetic_item("-div",
                               operator/=,
                               "Divide image%s by %g%s",
                               gmic_selection,value,ssep,Tfloat,
                               div,
                               "Divide image%s by image [%d]",
                               gmic_selection,ind[0],
                               "Divide image%s by expression %s",
                               gmic_selection,argument_text,
                               "Divide image%s");

          // Distance function.
          if (!std::strcmp("-distance",command)) {
            gmic_substitute_args();
            unsigned int algorithm = 0, off = 0;
            char sep1 = 0, sep2 = 0;
            CImg<unsigned int> ind;
            double value = 0;
            int metric = 2;
            if ((std::sscanf(argument,"%lf%c",
                             &value,&end)==1 ||
                 (std::sscanf(argument,"%lf%c%c",
                              &value,&sep1,&end)==2 && sep1=='%') ||
                 std::sscanf(argument,"%lf,%d%c",
                             &value,&metric,&end)==2 ||
                 (std::sscanf(argument,"%lf%c,%d%c",
                              &value,&sep1,&metric,&end)==3 && sep1=='%')) &&
                metric>=0 && metric<=3) {
              print(images,"Compute Euclidean distance map to isovalue %g%s in image%s, "
                    "with %s metric.",
                    value,sep1=='%'?"%":"",
                    gmic_selection,
                    metric==0?"chebyshev":metric==1?"manhattan":metric==2?"euclidean":
                    "squared-euclidean");
              cimg_forY(selection,l) {
                CImg<T> &img = gmic_check(images[selection[l]]);
                double nvalue = value;
                if (sep1=='%' && img) {
                  double vmin, vmax = (double)img.max_min(vmin);
                  nvalue = vmin + value*(vmax-vmin)/100;
                }
                gmic_apply(img,distance((T)nvalue,metric));
              }
            } else if ((((std::sscanf(argument,"%lf,[%255[a-zA-Z0-9_.%+-]%c%c",
                                      &value,indices,&sep2,&end)==3 ||
                          (std::sscanf(argument,"%lf%c,[%255[a-zA-Z0-9_.%+-]%c%c",
                                       &value,&sep1,indices,&sep2,&end)==4 && sep1=='%')) &&
                         sep2==']') ||
                        ((std::sscanf(argument,"%lf,[%255[a-zA-Z0-9_.%+-]],%u%c",
                                     &value,indices,&algorithm,&end)==3 ||
                          (std::sscanf(argument,"%lf%c,[%255[a-zA-Z0-9_.%+-]],%u%c",
                                       &value,&sep1,indices,&algorithm,&end)==4 && sep1=='%')) &&
                         algorithm<=4)) &&
                       (ind=selection2cimg(indices,images.size(),images_names,"-distance",true,
                                           false,CImg<char>::empty())).height()==1) {
              print(images,"Compute distance map%s to isovalue %g%s in image%s, "
                    "using %s algorithm, with metric [%u].",
                    selection.height()>1?(algorithm>=3?"s and return paths":"s"):
                    (algorithm>=3?" and return path":""),
                    value,sep1=='%'?"%":"",
                    gmic_selection,
                    algorithm==0?"fast-marching":algorithm==1||algorithm==3?
                    "low-connectivity dijkstra":"high-connectivity dijkstra",
                    *ind);
              const CImg<T> custom_metric = gmic_image_arg(*ind);
              if (algorithm<3) cimg_forY(selection,l) {
                  CImg<T> &img = gmic_check(images[selection[l]]);
                  double nvalue = value;
                  if (sep1=='%' && img) {
                    double vmin, vmax = (double)img.max_min(vmin);
                    nvalue = vmin + value*(vmax-vmin)/100;
                  }
                  if (!algorithm) { gmic_apply(img,distance_eikonal((T)nvalue,custom_metric)); }
                  else { gmic_apply(img,distance_dijkstra((T)nvalue,custom_metric,algorithm==2)); }
                } else cimg_forY(selection,l) {
                  const unsigned int ind = selection[l] + off;
                  CImg<T>& img = gmic_check(images[ind]);
                  double nvalue = value;
                  if (sep1=='%' && img) {
                    double vmin, vmax = (double)img.max_min(vmin);
                    nvalue = vmin + value*(vmax-vmin)/100;
                  }
                  CImg<char> name = images_names[ind].get_mark();
                  CImg<T> path(1),
                    dist = img.get_distance_dijkstra((T)nvalue,custom_metric,algorithm==4,path);
                  if (is_get_version) {
                    images_names.insert(2,name.copymark());
                    dist.move_to(images,~0U);
                    path.move_to(images,~0U);
                  } else {
                    off+=1;
                    dist.move_to(images[ind].assign());
                    path.move_to(images,ind+1);
                    images_names[ind] = name;
                    images_names.insert(name.copymark(),ind+1);
                  }
                }
            } else arg_error("distance");
            is_released = false; ++position; continue;
          }

          // Dilate.
          if (!std::strcmp("-dilate",command)) {
            gmic_substitute_args();
            float sx = 3, sy = 3, sz = 1;
            unsigned int boundary = 1, is_normalized = 0;
            CImg<unsigned int> ind;
            char sep = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                              indices,&sep,&end)==2 && sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u%c",
                             indices,&boundary,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u%c",
                             indices,&boundary,&is_normalized,&end)==3) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-dilate",true,
                                    false,CImg<char>::empty())).height()==1 &&
                boundary<=1) {
              print(images,"Dilate image%s with mask [%u] and %s boundary conditions, "
                    "with%s normalization.",
                    gmic_selection,
                    *ind,
                    boundary?"neumann":"dirichlet",
                    is_normalized?"":"out");
              const CImg<T> mask = gmic_image_arg(*ind);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],dilate(mask,boundary,
                                                                            (bool)is_normalized));
            } else if ((std::sscanf(argument,"%f%c",
                                    &sx,&end)==1) &&
                       sx>=0) {
              sx = cimg::round(sx);
              print(images,"Dilate image%s with mask of size %g and neumann boundary conditions.",
                    gmic_selection,
                    sx);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],dilate((unsigned int)sx));
            } else if ((std::sscanf(argument,"%f,%f%c",
                                    &sx,&sy,&end)==2 ||
                        std::sscanf(argument,"%f,%f,%f%c",
                                    &sx,&sy,&sz,&end)==3) &&
                       sx>=0 && sy>=0 && sz>=0) {
              sx = cimg::round(sx);
              sy = cimg::round(sy);
              sz = cimg::round(sz);
              print(images,"Dilate image%s with %gx%gx%g mask and neumann boundary conditions.",
                    gmic_selection,
                    sx,sy,sz);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],dilate((unsigned int)sx,(unsigned int)sy,
                                                       (unsigned int)sz));
            } else arg_error("dilate");
            is_released = false; ++position; continue;
          }

          // Set double-sided mode for 3d rendering.
          if (!std::strcmp("-double3d",item)) {
            gmic_substitute_args();
            bool value = true;
            if (!argument[1] && (*argument=='0' || *argument=='1')) {
              value = (*argument=='1');
              ++position;
            } else value = true;
            is_double3d = value;
            print(images,"%s double-sided mode for 3d rendering.",
                  is_double3d?"Enable":"Disable");
            continue;
          }

          // Patch-based smoothing.
          if (!std::strcmp("-denoise",command)) {
            gmic_substitute_args();
            float sigma_s = 10, sigma_r = 10, smoothness = 1;
            unsigned int is_fast_approximation = 0;
            float psize = 5, rsize = 6;
            if ((std::sscanf(argument,"%f%c",
                             &sigma_s,&end)==1 ||
                 std::sscanf(argument,"%f,%f%c",
                             &sigma_s,&sigma_r,&end)==2 ||
                 std::sscanf(argument,"%f,%f,%f%c",
                             &sigma_s,&sigma_r,&psize,&end)==3 ||
                 std::sscanf(argument,"%f,%f,%f,%f%c",
                             &sigma_s,&sigma_r,&psize,&rsize,&end)==4 ||
                 std::sscanf(argument,"%f,%f,%f,%f,%f%c",
                             &sigma_s,&sigma_r,&psize,&rsize,&smoothness,&end)==5 ||
                 std::sscanf(argument,"%f,%f,%f,%f,%f,%u%c",
                             &sigma_s,&sigma_r,&psize,&rsize,&smoothness,
                             &is_fast_approximation,&end)==6) &&
                sigma_s>=0 && sigma_r>=0 && psize>=0 && rsize>=0 && is_fast_approximation<=1) {
              psize = cimg::round(psize);
              rsize = cimg::round(rsize);
              print(images,"Denoise image%s using %gx%g patchs, with standard deviations %lg,%g, "
                    "lookup size %g and smoothness %g.",
                    gmic_selection,
                    psize,
                    psize,
                    sigma_s,
                    sigma_r,
                    rsize,
                    smoothness);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],blur_patch(sigma_s,sigma_r,
                                                           (unsigned int)psize,(unsigned int)rsize,
                                                           smoothness,
                                                           (bool)is_fast_approximation));
            } else arg_error("denoise");
            is_released = false; ++position; continue;
          }

          // Deriche filter.
          if (!std::strcmp("-deriche",command)) {
            gmic_substitute_args();
            unsigned int boundary = 1, order = 0;
            char sep = 0, axis = 0;
            float sigma = 0;
            if ((std::sscanf(argument,"%f,%u,%c%c",&sigma,&order,&axis,&end)==3 ||
                 (std::sscanf(argument,"%f%c,%u,%c%c",&sigma,&sep,&order,&axis,&end)==4 &&
                  sep=='%') ||
                 std::sscanf(argument,"%f,%u,%c,%u%c",&sigma,&order,&axis,&boundary,&end)==4 ||
                 (std::sscanf(argument,"%f%c,%u,%c,%u%c",
                              &sigma,&sep,&order,&axis,&boundary,&end)==5 && sep=='%')) &&
                sigma>=0 && order<=2 && (axis=='x' || axis=='y' || axis=='z' || axis=='c') &&
                boundary<=1) {
              print(images,"Apply Deriche filter on image%s, with standard "
                    "deviation %g%s, order %d, axis '%c' and %s boundary conditions.",
                    gmic_selection,
                    sigma,sep=='%'?"%":"",
                    order,axis,
                    boundary?"neumann":"dirichlet");
              if (sep=='%') sigma = -sigma;
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],deriche(sigma,order,axis,(bool)boundary));
            } else arg_error("deriche");
            is_released = false; ++position; continue;
          }

          // Dijkstra algorithm.
          if (!std::strcmp("-dijkstra",command)) {
            gmic_substitute_args();
            float snode = 0, enode = 0;
            if (std::sscanf(argument,"%f,%f%c",&snode,&enode,&end)==2 &&
                snode>=0 && enode>=0) {
              snode = cimg::round(snode);
              enode = cimg::round(enode);
              print(images,"Compute minimal path from adjacency matri%s%s with the "
                    "Dijkstra algorithm.",
                    selection.height()>1?"ce":"x",gmic_selection);
              unsigned int off = 0;
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l] + off;
                CImg<char> name = images_names[ind].get_mark();
                if (is_get_version) {
                  CImg<T> path, dist = gmic_check(images[ind]).get_dijkstra((unsigned int)snode,
                                                                              (unsigned int)enode,
                                                                              path);
                  images_names.insert(name.copymark());
                  name.move_to(images_names);
                  dist.move_to(images);
                  path.move_to(images);
                } else {
                  CImg<T> path;
                  gmic_check(images[ind]).dijkstra((unsigned int)snode,(unsigned int)enode,path);
                  images_names.insert(name.get_copymark(),ind+1);
                  name.move_to(images_names[ind]);
                  images.insert(path,ind+1);
                  ++off;
                }
              }
            } else arg_error("dijkstra");
            is_released = false; ++position; continue;
          }

          // Estimate displacement field.
          if (!std::strcmp("-displacement",command)) {
            gmic_substitute_args();
            float nb_scales = 0, nb_iterations = 10000, smoothness = 0.1f, precision = 5.0f;
            unsigned int is_backward = 1;
            CImg<unsigned int> ind;
            char sep = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                              indices,&sep,&end)==2 && sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f%c",
                             indices,&smoothness,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f%c",
                             indices,&smoothness,&precision,&end)==3 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f%c",
                             indices,&smoothness,&precision,&nb_scales,&end)==4 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f%c",
                             indices,&smoothness,&precision,&nb_scales,&nb_iterations,&end)==5 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f,%u%c",
                             indices,&smoothness,&precision,&nb_scales,&nb_iterations,
                             &is_backward,&end)==6) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-displacement",true,
                                    false,CImg<char>::empty())).height()==1 &&
                precision>=0 && nb_scales>=0 && nb_iterations>=0 && is_backward<=1) {
              nb_scales = cimg::round(nb_scales);
              nb_iterations = cimg::round(nb_iterations);
              print(images,"Estimate displacement field from source [%u] to image%s, with "
                    "%s smoothness %g, precision %g, %g scales, %g iterations, in %s direction.",
                    *ind,
                    gmic_selection,
                    smoothness>=0?"isotropic":"anisotropic",cimg::abs(smoothness),
                    precision,
                    nb_scales,
                    nb_iterations,
                    is_backward?"backward":"forward");
              const CImg<T> source = gmic_image_arg(*ind);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],displacement(source,smoothness,precision,
                                                             (unsigned int)nb_scales,
                                                             (unsigned int)nb_iterations,
                                                             (bool)is_backward));
            } else arg_error("displacement");
            is_released = false; ++position; continue;
          }

          // Display.
          if (!std::strcmp("-display",command) && !is_get_version) {
            gmic_substitute_args();
            unsigned int X,Y,Z, XYZ[3];
            bool is_xyz = false;
            if (std::sscanf(argument,"%u,%u,%u%c",
                            &X,&Y,&Z,&end)==3) { is_xyz = true; ++position; }
            XYZ[0] = X; XYZ[1] = Y; XYZ[2] = Z;
            display_images(images,images_names,selection,is_xyz?XYZ:0);
            is_released = true; continue;
          }

          // Display 3d object.
          if (!std::strcmp("-display3d",command) && !is_get_version) {
            display_objects3d(images,images_names,selection);
            is_released = true; continue;
          }

#endif // #ifdef gmic_float
# 5784 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='d'.

        //----------------------------
        // Commands starting by '-e..'
        //----------------------------
        else if (command1=='e') {

          // Endif.
          if (!std::strcmp("-endif",item)) {
            const CImg<char> &s = scope.back();
            if (s[0]!='*' || s[1]!='i')
              error(images,
                    "Command '-endif': Not associated to a '-if' command within the same scope.");
            if (verbosity>0 || is_debug) print(images,"End 'if..endif' block.");
            check_elif = false;
            scope.remove();
            continue;
          }

          // Else and elif.
          if (!std::strcmp("-else",item) || (!std::strcmp("-elif",item) && !check_elif)) {
            const CImg<char> &s = scope.back();
            if (s[0]!='*' || s[1]!='i')
              error(images,
                    "Command '%s': Not associated to a '-if' command within the same scope.",
                    item);
            check_elif = false;
            if (verbosity>0 || is_debug) print(images,"Reach '-else' block.");
            for (int nb_ifs = 1; nb_ifs && position<commands_line.size(); ++position) {
              const char *const it = commands_line[position].data();
              if (!std::strcmp("-if",it)) ++nb_ifs;
              else if (!std::strcmp("-endif",it)) { if (!--nb_ifs) --position; }
            }
            continue;
          }

          // End local environment.
          if (!std::strcmp("-endlocal",item) || !std::strcmp("-endl",item)) {
            const CImg<char> &s = scope.back();
            if (s[0]!='*' || s[1]!='l')
              error(images,"Command '-endlocal': Not associated to a '-local' command within "
                    "the same scope.");
            if (verbosity>0 || is_debug) print(images,"End 'local..endlocal' block.");
            is_endlocal = true;
            break;
          }

          // Echo.
          if (!std::strcmp("-echo",command) && !is_get_version) {
            if (verbosity>=0 || is_debug) {
              gmic_substitute_args();
              CImg<char> str(argument,std::strlen(argument)+1);
              cimg::strunescape(str);
              if (is_restriction) print(images,selection,"%s",str.data());
              else print(images,"%s",str.data());
            }
            ++position; continue;
          }

          // Exec.
          if (!std::strcmp("-exec",item)) {
            gmic_substitute_args();
#ifdef gmic_noexec
            print(images,"Execute external command '%s' (skipped, no exec allowed).",
                  argument_text);
#else // #ifdef gmic_noexec
# 5850 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            print(images,"Execute external command '%s'\n",
                  argument_text);
            CImg<char> arg_exec(argument,std::strlen(argument)+1);
            gmic_strreplace(arg_exec);
            cimg::mutex(31);
            const int errcode = cimg::system(arg_exec);
            cimg::mutex(31,0);
            cimg_snprintf(title,_title.size(),"%d",errcode);
            CImg<char>::string(title).move_to(status);
            if (errcode) print(images,"Command '-exec' returned error code '%d'.",
                               errcode);
#endif // #ifdef gmic_noexec
# 5862 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            ++position; continue;
          }

          // Error.
          if (!std::strcmp("-error",command) && !is_get_version) {
            gmic_substitute_args();
            CImg<char> str(argument,std::strlen(argument)+1);
            cimg::strunescape(str);
            if (is_restriction) error(images,selection,"%s",str.data());
            else error(images,"%s",str.data());
          }

          // Invert endianness.
          gmic_simple_item("-endian",invert_endianness,"Invert data endianness of image%s.");

#ifdef gmic_float

          // Exponential.
          gmic_simple_item("-exp",exp,"Compute pointwise exponential of image%s.");

          // Test equality.
          gmic_arithmetic_item("-eq",
                               operator_eq,
                               "Compute boolean equality between image%s and %g%s",
                               gmic_selection,value,ssep,T,
                               operator_eq,
                               "Compute boolean equality between image%s and image [%d]",
                               gmic_selection,ind[0],
                               "Compute boolean equality between image%s and expression %s'",
                               gmic_selection,argument_text,
                               "Compute boolean equality between image%s");

          // Draw ellipse.
          if (!std::strcmp("-ellipse",command)) {
            gmic_substitute_args();
            CImg<char> argR(256), argr(256);
            *argx = *argy = *argR = *argr = *color = 0;
            float x = 0, y = 0, R = 0, r = 0, angle = 0, opacity = 1;
            char sepx = 0, sepy = 0, sepR = 0, sepr = 0, seph = 0;
            unsigned int pattern = ~0U;
            if ((std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             argx,argy,argR.data(),&end)==3 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-]%c",
                             argx,argy,argR.data(),argr.data(),&end)==4 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-],%f%c",
                             argx,argy,argR.data(),argr.data(),&angle,&end)==5 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-],%f,%f%c",
                             argx,argy,argR.data(),argr.data(),&angle,&opacity,&end)==6 ||
                 (std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                              "%255[0-9.eE%+-],%f,%f,0%c%x%c",
                              argx,argy,argR.data(),argr.data(),&angle,&opacity,&seph,&pattern,&end)==8 &&
                  seph=='x') ||
                 (std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                              "%255[0-9.eE%+-],%f,%f,%4095[0-9.eE,+-]%c",
                              argx,argy,argR.data(),argr.data(),&angle,&opacity,color,&end)==7 && (bool)(pattern=~0U))||
                 (*color=0,std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                                       "%255[0-9.eE%+-],%f,%f,0%c%x,%4095[0-9.eE,+-]%c",
                                       argx,argy,argR.data(),argr.data(),&angle,&opacity,&seph,&pattern,
                                       color,&end)==9 &&
                  seph=='x')) &&
                (std::sscanf(argx,"%f%c",&x,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&x,&sepx,&end)==2 && sepx=='%')) &&
                (std::sscanf(argy,"%f%c",&y,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&y,&sepy,&end)==2 && sepy=='%')) &&
                (std::sscanf(argR,"%f%c",&R,&end)==1 ||
                 (std::sscanf(argR,"%f%c%c",&R,&sepR,&end)==2 && sepR=='%')) &&
                (!*argr ||
                 std::sscanf(argr,"%f%c",&r,&end)==1 ||
                 (std::sscanf(argr,"%f%c%c",&r,&sepr,&end)==2 && sepr=='%'))) {
              if (!*argr) r = R;
              print(images,"Draw %s ellipse at (%g%s,%g%s) with radii (%g%s,%g%s) on image%s, "
                    "with orientation %g°, opacity %g and color (%s).",
                    seph=='x'?"outlined":"filled",
                    x,sepx=='%'?"%":"",
                    y,sepy=='%'?"%":"",
                    R,sepR=='%'?"%":"",
                    r,sepr=='%'?"%":"",
                    gmic_selection,
                    angle,
                    opacity,
                    *color?color:"default");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]], col(img.spectrum(),1,1,1,0);
                col.fill(color,true);
                const float rmax = std::sqrt((float)cimg::sqr(img.width()) +
                                             cimg::sqr(img.height()));
                const int
                  nx = (int)cimg::round(sepx=='%'?x*(img.width()-1)/100:x),
                  ny = (int)cimg::round(sepy=='%'?y*(img.height()-1)/100:y);
                const float
                  nR = cimg::round(sepR=='%'?R*rmax/100:R),
                  nr = cimg::round(sepr=='%'?r*rmax/100:r);
                if (seph=='x') {
                  if (nR==nr) { gmic_apply(img,draw_circle(nx,ny,(int)nR,col.data(),opacity,~0U));}
                  else { gmic_apply(img,draw_ellipse(nx,ny,nR,nr,angle,col.data(),opacity,~0U)); }
                } else {
                  if (nR==nr) { gmic_apply(img,draw_circle(nx,ny,(int)nR,col.data(),opacity)); }
                  else { gmic_apply(img,draw_ellipse(nx,ny,nR,nr,angle,col.data(),opacity)); }
                }
              }
            } else arg_error("ellipse");
            is_released = false; ++position; continue;
          }

          // Equalize.
          if (!std::strcmp("-equalize",command)) {
            gmic_substitute_args();
            char sep = 0, sep0 = 0, sep1 = 0;
            double value0 = 0, value1 = 0;
            float nb_levels = 256;
            if ((std::sscanf(argument,"%f%c",
                             &nb_levels,&end)==1 ||
                 (std::sscanf(argument,"%f%c%c",
                              &nb_levels,&sep,&end)==2 && sep=='%') ||
                 std::sscanf(argument,"%f,%lf,%lf%c",
                             &nb_levels,&value0,&value1,&end)==3 ||
                 (std::sscanf(argument,"%f%c,%lf,%lf%c",
                              &nb_levels,&sep,&value0,&value1,&end)==4 && sep=='%') ||
                 (std::sscanf(argument,"%f,%lf%c,%lf%c",
                              &nb_levels,&value0,&sep0,&value1,&end)==4 && sep0=='%') ||
                 (std::sscanf(argument,"%f%c,%lf%c,%lf%c",
                              &nb_levels,&sep,&value0,&sep0,&value1,&end)==5 && sep=='%' &&
                  sep0=='%') ||
                 (std::sscanf(argument,"%f,%lf,%lf%c%c",
                              &nb_levels,&value0,&value1,&sep1,&end)==4 && sep1=='%') ||
                 (std::sscanf(argument,"%f%c,%lf,%lf%c%c",
                              &nb_levels,&sep,&value0,&value1,&sep1,&end)==5 && sep=='%' &&
                  sep1=='%') ||
                 (std::sscanf(argument,"%f,%lf%c,%lf%c%c",
                              &nb_levels,&value0,&sep0,&value1,&sep1,&end)==5 && sep0=='%' &&
                  sep1=='%') ||
                 (std::sscanf(argument,"%f%c,%lf%c,%lf%c%c",
                              &nb_levels,&sep,&value0,&sep0,&value1,&sep1,&end)==6 && sep=='%' &&
                  sep0=='%' && sep1=='%')) &&
                nb_levels>=0.5) {
              nb_levels = cimg::round(nb_levels); ++position; }
            else { nb_levels = 256; value0 = value1 = 0; sep = sep0 = sep1 = 0; }
            if (value0==value1 && value0==0) { value1 = 100; sep0 = sep1 = '%'; }
            print(images,"Equalize histogram of image%s, with %g%s levels in range [%g%s,%g%s].",
                  gmic_selection,
                  nb_levels,sep=='%'?"%":"",
                  value0,sep0=='%'?"%":"",
                  value1,sep1=='%'?"%":"");
            cimg_forY(selection,l) {
              CImg<T>& img = gmic_check(images[selection[l]]);
              double vmin = 0, vmax = 0, nvalue0 = value0, nvalue1 = value1;
              if (sep0=='%' || sep1=='%') {
                if (img) vmax = (double)img.max_min(vmin);
                if (sep0=='%') nvalue0 = vmin + (vmax-vmin)*value0/100;
                if (sep1=='%') nvalue1 = vmin + (vmax-vmin)*value1/100;
              }
              const unsigned int
                _nb_levels = cimg::max(1U,
                                       (unsigned int)cimg::round(sep=='%'?
                                                                 nb_levels*(1+nvalue1-nvalue0)/100:
                                                                 nb_levels));
              gmic_apply(images[selection[l]],equalize(_nb_levels,(T)nvalue0,(T)nvalue1));
            }
            is_released = false; continue;
          }

          // Erode.
          if (!std::strcmp("-erode",command)) {
            gmic_substitute_args();
            unsigned int boundary = 1, is_normalized = 0;
            float sx = 3, sy = 3, sz = 1;
            CImg<unsigned int> ind;
            char sep = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                              indices,&sep,&end)==2 && sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u%c",
                             indices,&boundary,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u%c",
                             indices,&boundary,&is_normalized,&end)==3) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-erode",true,
                                    false,CImg<char>::empty())).height()==1 &&
                boundary<=1) {
              print(images,"Erode image%s with mask [%u] and %s boundary conditions, "
                    "with%s normalization.",
                    gmic_selection,
                    *ind,
                    boundary?"neumann":"dirichlet",
                    is_normalized?"":"out");
              const CImg<T> mask = gmic_image_arg(*ind);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],erode(mask,boundary,(bool)is_normalized));
            } else if ((std::sscanf(argument,"%f%c",
                                    &sx,&end)==1) &&
                       sx>=0) {
              sx = cimg::round(sx);
              print(images,"Erode image%s with mask of size %g and neumann boundary conditions.",
                    gmic_selection,
                    sx);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],erode((unsigned int)sx));
            } else if ((std::sscanf(argument,"%f,%f%c",
                                    &sx,&sy,&end)==2 ||
                        std::sscanf(argument,"%f,%f,%f%c",
                                    &sx,&sy,&sz,&end)==3) &&
                       sx>=0 && sy>=0 && sz>=0) {
              sx = cimg::round(sx);
              sy = cimg::round(sy);
              sz = cimg::round(sz);
              print(images,"Erode image%s with %gx%gx%g mask and neumann boundary conditions.",
                    gmic_selection,
                    sx,sy,sz);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],erode((unsigned int)sx,(unsigned int)sy,
                                                      (unsigned int)sz));
            } else arg_error("erode");
            is_released = false; ++position; continue;
          }

          // Build 3d elevation.
          if (!std::strcmp("-elevation3d",command)) {
            gmic_substitute_args();
            CImg<typename CImg<T>::Tfloat> elev;
            CImg<unsigned int> ind;
            float fact = 1;
            char sep = 0;
            *formula = 0;
            if (std::sscanf(argument,"'%4095[^']'%c",formula,&end)==1) {
              print(images,"Build 3d elevation of image%s, with elevation formula '%s'.",
                    gmic_selection,
                    formula);
              cimg_forY(selection,l) {
                CImg<T>& img = gmic_check(images[selection[l]]);
                elev.assign(img.width(),img.height(),1,1,formula,true);
                CImgList<unsigned int> primitives;
                CImgList<float> colors;
                CImg<float> vertices = img.get_elevation3d(primitives,colors,elev);
                vertices.object3dtoCImg3d(primitives,colors,false);
                gmic_apply(img,replace(vertices));
              }
              ++position;
            } else if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 &&
                       sep==']' &&
                       (ind=selection2cimg(indices,images.size(),images_names,"-elevation3d",true,
                                           false,CImg<char>::empty())).height()==1) {
              print(images,"Build 3d elevation of image%s, with elevation map [%u].",
                    gmic_selection,
                    *ind);
              if (images[*ind].spectrum()>1) images[*ind].get_norm().move_to(elev);
              else elev = gmic_image_arg(*ind);
              cimg_forY(selection,l) {
                CImg<T>& img = gmic_check(images[selection[l]]);
                CImgList<unsigned int> primitives;
                CImgList<float> colors;
                CImg<float> vertices = img.get_elevation3d(primitives,colors,elev);
                vertices.object3dtoCImg3d(primitives,colors,false);
                gmic_apply(img,replace(vertices));
              }
              ++position;
            } else {
              if (std::sscanf(argument,"%f%c",
                              &fact,&end)==1) {
                print(images,"Build 3d elevation of image%s, with elevation factor %g.",
                      gmic_selection,
                      fact);
                ++position;
              } else
                print(images,"Build 3d elevation of image%s.",
                      gmic_selection);
              cimg_forY(selection,l) {
                CImg<T>& img = gmic_check(images[selection[l]]);
                CImgList<unsigned int> primitives;
                CImgList<float> colors;
                elev.assign();
                if (fact==1 && img.spectrum()==1) elev = img.get_shared();
                else if (img.spectrum()>1) (img.get_norm().move_to(elev))*=fact;
                else (elev = img)*=fact;
                CImg<float> vertices = img.get_elevation3d(primitives,colors,elev);
                vertices.object3dtoCImg3d(primitives,colors,false);
                gmic_apply(img,replace(vertices));
              }
            }
            is_released = false; continue;
          }

          // Eigenvalues/eigenvectors.
          if (!std::strcmp("-eigen",command)) {
            print(images,"Compute eigen-values/vectors of symmetric matri%s or matrix field%s.",
                  selection.height()>1?"ce":"x",gmic_selection);
            CImg<float> val, vec;
            unsigned int off = 0;
            cimg_forY(selection,l) {
              const unsigned int ind = selection[l] + off;
              CImg<char> name = images_names[ind].get_mark();
              gmic_check(images[ind]).gmic_symmetric_eigen(val,vec);
              if (is_get_version) {
                images_names.insert(name.copymark());
                name.move_to(images_names);
                val.move_to(images);
                vec.move_to(images);
              } else {
                images_names.insert(name.get_copymark(),ind+1); name.move_to(images_names[ind]);
                val.move_to(images[ind].assign()); images.insert(vec,ind+1);
                ++off;
              }
            }
            is_released = false; continue;
          }

#endif // #ifdef gmic_float
# 6168 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='e'.

        //----------------------------
        // Commands starting by '-f..'
        //----------------------------
        else if (command1=='f') {

#ifdef gmic_float

          // Fill.
          if (!std::strcmp("-fill",command)) {
            gmic_substitute_args();
            double value = 0;
            CImg<unsigned int> ind;
            char sep = 0;
            if (std::sscanf(argument,"%lf%c",
                            &value,&end)==1) {
              print(images,"Fill image%s with %g.",
                    gmic_selection,
                    value);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],fill((T)value));
            } else if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 &&
                       sep==']' &&
                       (ind=selection2cimg(indices,images.size(),images_names,"-fill",true,
                                           false,CImg<char>::empty())).height()==1) {
              print(images,"Fill image%s with values from image [%u].",
                    gmic_selection,
                    *ind);
              const CImg<T> values = gmic_image_arg(*ind);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],fill(values));
            } else {
              CImg<char> arg_fill_text(argument_text,std::strlen(argument_text)+1);
              cimg::strpare(arg_fill_text,'\'',true,false);
              print(images,"Fill image%s with expression '%s'.",
                    gmic_selection,
                    arg_fill_text.data());
              CImg<char> arg_fill(argument,std::strlen(argument)+1);
              cimg::strpare(arg_fill,'\'',true,false);
              gmic_strreplace(arg_fill);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],fill(arg_fill.data(),true));
            }
            is_released = false; ++position; continue;
          }

          // Flood fill.
          if (!std::strcmp("-flood",command)) {
            gmic_substitute_args();
            float x = 0, y = 0, z = 0, tolerance = 0, opacity = 1;
            unsigned int is_high_connectivity = 0;
            char sepx = 0, sepy = 0, sepz = 0;
            *argx = *argy = *argz = *color = 0;
            if ((std::sscanf(argument,"%255[0-9.eE%+-]%c",
                             argx,&end)==1 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             argx,argy,&end)==2 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             argx,argy,argz,&end)==3 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f%c",
                             argx,argy,argz,&tolerance,&end)==4 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f,%u%c",
                             argx,argy,argz,&tolerance,&is_high_connectivity,&end)==5 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f,%u,%f%c",
                             argx,argy,argz,&tolerance,&is_high_connectivity,&opacity,&end)==6 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f,%u,%f,"
                             "%4095[0-9.eE,+-]%c",
                             argx,argy,argz,&tolerance,&is_high_connectivity,
                             &opacity,color,&end)==7) &&
                (std::sscanf(argx,"%f%c",&x,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&x,&sepx,&end)==2 && sepx=='%')) &&
                (!*argy ||
                 std::sscanf(argy,"%f%c",&y,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&y,&sepy,&end)==2 && sepy=='%')) &&
                (!*argz ||
                 std::sscanf(argz,"%f%c",&z,&end)==1 ||
                 (std::sscanf(argz,"%f%c%c",&z,&sepz,&end)==2 && sepz=='%')) &&
                tolerance>=0) {
              print(images,
                    "Flood fill image%s from (%g%s,%g%s,%g%s), with tolerance %g, %s connectivity,"
                    "opacity %g and color (%s).",
                    gmic_selection,
                    x,sepx=='%'?"%":"",
                    y,sepy=='%'?"%":"",
                    z,sepz=='%'?"%":"",
                    tolerance,
                    is_high_connectivity?"high":"low",
                    opacity,
                    *color?color:"default");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]], col(img.spectrum(),1,1,1,0);
                col.fill(color,true);
                const int
                  nx = (int)cimg::round(sepx=='%'?x*(img.width()-1)/100:x),
                  ny = (int)cimg::round(sepy=='%'?y*(img.height()-1)/100:y),
                  nz = (int)cimg::round(sepz=='%'?z*(img.depth()-1)/100:z);
                gmic_apply(img,draw_fill(nx,ny,nz,col.data(),opacity,tolerance,
                                         (bool)is_high_connectivity));
              }
            } else arg_error("flood");
            is_released = false; ++position; continue;
          }

          // Set 3d focale.
          if (!std::strcmp("-focale3d",item)) {
            gmic_substitute_args();
            float value = 700;
            if (std::sscanf(argument,"%f%c",&value,&end)==1) ++position;
            else value = 700;
            focale3d = value;
            print(images,"Set 3d focale to %g.",
                  focale3d);
            continue;
          }

#endif // #ifdef gmic_float
# 6282 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='f'.

        //----------------------------
        // Commands starting by '-g..'
        //----------------------------
        else if (command1=='g') {

#ifdef gmic_float

          // Greater or equal.
          gmic_arithmetic_item("-ge",
                               operator_ge,
                               "Compute boolean 'greater or equal than' between image%s and %g%s",
                               gmic_selection,value,ssep,T,
                               operator_ge,
                               "Compute boolean 'greater or equal than' between image%s "
                               "and image [%d]",
                               gmic_selection,ind[0],
                               "Compute boolean 'greater or equal than' between image%s "
                               "and expression %s'",
                               gmic_selection,argument_text,
                               "Compute boolean 'greater or equal than' between image%s");

          // Greater than.
          gmic_arithmetic_item("-gt",
                               operator_gt,
                               "Compute boolean 'greater than' between image%s and %g%s",
                               gmic_selection,value,ssep,T,
                               operator_gt,
                               "Compute boolean 'greater than' between image%s and image [%d]",
                               gmic_selection,ind[0],
                               "Compute boolean 'greater than' between image%s and expression %s'",
                               gmic_selection,argument_text,
                               "Compute boolean 'greater than' between image%s");

          // Compute gradient.
          if (!std::strcmp("-gradient",command)) {
            gmic_substitute_args();
            char axes[16];
            int scheme = 3;
            *axes = 0;
            if ((std::sscanf(argument,"%15[xyz]%c",
                             axes,&end)==1 ||
                 std::sscanf(argument,"%15[xyz],%d%c",
                             axes,&scheme,&end)==2) &&
                scheme>=-1 && scheme<=5) {
              ++position;
              print(images,"Compute gradient of image%s along axes '%s', with %s scheme.",
                    gmic_selection,
                    axes,
                    scheme==-1?"backward differences":scheme==4?"deriche":scheme==5?"vanvliet":
                    scheme==1?"forward differences":scheme==2?"sobel":
                    scheme==3?"rotation invariant":"centered differences");
            } else print(images,"Compute gradient of image%s, with rotation invariant scheme.",
                         gmic_selection);
            unsigned int off = 0;
            cimg_forY(selection,l) {
              const unsigned int ind = selection[l] + off;
              CImg<T>& img = gmic_check(images[ind]);
              CImg<char> name = images_names[ind].get_mark();
              CImgList<T> gradient = img.get_gradient(*axes?axes:0,scheme);
              if (is_get_version) {
                images_names.insert(gradient.size(),name.copymark());
                gradient.move_to(images,~0U);
              } else {
                off+=gradient.size() - 1;
                gradient[0].move_to(images[ind].assign());
                for (unsigned int i = 1; i<gradient.size(); ++i) gradient[i].move_to(images,ind+i);
                images_names[ind] = name;
                if (gradient.size()>1)
                  images_names.insert(gradient.size()-1,name.copymark(),ind+1);
              }
            }
            is_released = false; continue;
          }

          // Draw graph.
          if (!std::strcmp("-graph",command)) {
            gmic_substitute_args();
            double ymin = 0, ymax = 0, xmin = 0, xmax = 0;
            unsigned int plot_type = 1, vertex_type = 1;
            float resolution = 65536, opacity = 1;
            unsigned int pattern = ~0U;
            CImg<unsigned int> ind;
            char sep = 0, seph = 0;
            *formula = *color = 0;
            if (((std::sscanf(argument,"'%1023[^']%c%c",
                              formula,&sep,&end)==2 && sep=='\'') ||
                 std::sscanf(argument,"'%1023[^']',%f%c",
                             formula,&resolution,&end)==2 ||
                 std::sscanf(argument,"'%1023[^']',%f,%u%c",
                             formula,&resolution,&plot_type,&end)==3 ||
                 std::sscanf(argument,"'%1023[^']',%f,%u,%u%c",
                             formula,&resolution,&plot_type,&vertex_type,&end)==4 ||
                 std::sscanf(argument,"'%1023[^']',%f,%u,%u,%lf,%lf%c",
                             formula,&resolution,&plot_type,&vertex_type,&xmin,&xmax,&end)==6 ||
                 std::sscanf(argument,"'%1023[^']',%f,%u,%u,%lf,%lf,%lf,%lf%c",
                             formula,&resolution,&plot_type,&vertex_type,&xmin,&xmax,
                             &ymin,&ymax,&end)==8 ||
                 std::sscanf(argument,"'%1023[^']',%f,%u,%u,%lf,%lf,%lf,%lf,%f%c",
                             formula,&resolution,&plot_type,&vertex_type,
                             &xmin,&xmax,&ymin,&ymax,&opacity,&end)==9 ||
                 (std::sscanf(argument,"'%1023[^']',%f,%u,%u,%lf,%lf,%lf,%lf,%f,0%c%x%c",
                              formula,&resolution,&plot_type,&vertex_type,&xmin,&xmax,
                              &ymin,&ymax,&opacity,&seph,&pattern,&end)==11 && seph=='x') ||
                 (std::sscanf(argument,"'%1023[^']',%f,%u,%u,%lf,%lf,%lf,%lf,%f,%4095[0-9.eE,+-]%c",
                              formula,&resolution,&plot_type,&vertex_type,&xmin,&xmax,&ymin,&ymax,
                              &opacity,color,&end)==10 && (bool)(pattern=~0U)) ||
                 (*color=0,std::sscanf(argument,"'%1023[^']',%f,%u,%u,%lf,%lf,%lf,%lf,%f,0%c%x,"
                                       "%4095[0-9.eE,+-]%c",
                                       formula,&resolution,&plot_type,&vertex_type,&xmin,&xmax,
                                       &ymin,&ymax,&opacity,&seph,&pattern,color,&end)==12 &&
                  seph=='x')) &&
                resolution>0 && plot_type<=3 && vertex_type<=7) {
              resolution = cimg::round(resolution);
              gmic_strreplace(formula);
              print(images,
                    "Draw graph of formula '%s' on image%s, with resolution %g, %s contours, "
                    "%s vertices, x-range = (%g,%g), y-range = (%g,%g), opacity %g, "
                    "pattern 0x%x and color (%s).",
                    formula,
                    gmic_selection,
                    resolution,
                    plot_type==0?"no":plot_type==1?"linear":plot_type==2?"spline":"bar",
                    vertex_type==0?"no":vertex_type==1?"dot":vertex_type==2?"straight cross":
                    vertex_type==3?"diagonal cross":vertex_type==4?"filled circle":
                    vertex_type==5?"outlined circle":vertex_type==6?"square":"diamond",
                    xmin,xmax,
                    ymin,ymax,
                    opacity,pattern,
                    *color?color:"default");
              if (xmin==0 && xmax==0) { xmin = -4; xmax = 4; }
              if (!plot_type && !vertex_type) plot_type = 1;
              if (resolution<1) resolution = 65536;

              CImg<double> values(4,(unsigned int)resolution--,1,1,0);
              const double dx = xmax - xmin;
              cimg_forY(values,X) values(0,X) = xmin + X*dx/resolution;
              cimg::eval(formula,values).move_to(values);

              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]], col(img.spectrum(),1,1,1,0);
                col.fill(color,true);
                gmic_apply(img,draw_graph(values,col.data(),opacity,plot_type,vertex_type,
                                          ymin,ymax,pattern));
              }
            } else if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                                     indices,&sep,&end)==2 && sep==']') ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u%c",
                                    indices,&plot_type,&end)==2 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u%c",
                                    indices,&plot_type,&vertex_type,&end)==3 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u,%lf,%lf%c",
                                    indices,&plot_type,&vertex_type,&ymin,&ymax,&end)==5 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u,%lf,%lf,%f%c",
                                    indices,&plot_type,&vertex_type,&ymin,&ymax,&opacity,&end)==6||
                        (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u,%lf,%lf,%f,0%c%x%c",
                                     indices,&plot_type,&vertex_type,&ymin,&ymax,&opacity,&seph,
                                     &pattern,&end)==8 &&
                         seph=='x') ||
                        (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u,%lf,%lf,%f,"
                                     "%4095[0-9.eE,+-]%c",
                                     indices,&plot_type,&vertex_type,&ymin,&ymax,&opacity,
                                     color,&end)==7 &&
                         (bool)(pattern=~0U)) ||
                        (*color=0,std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u,%lf,%lf,"
                                              "%f,0%c%x,%4095[0-9.eE,+-]%c",
                                              indices,&plot_type,&vertex_type,&ymin,&ymax,
                                              &opacity,&seph,&pattern,color,&end)==9 &&
                         seph=='x')) &&
                       (ind=selection2cimg(indices,images.size(),images_names,"-graph",true,
                                           false,CImg<char>::empty())).height()==1 &&
                       plot_type<=3 && vertex_type<=7) {
              if (!plot_type && !vertex_type) plot_type = 1;
              print(images,"Draw graph of dataset [%u] on image%s, with %s contours, %s vertices, "
                    "y-range = (%g,%g), opacity %g, pattern 0x%x and color (%s).",
                    *ind,
                    gmic_selection,
                    plot_type==0?"no":plot_type==1?"linear":plot_type==2?"spline":"bar",
                    vertex_type==0?"no":vertex_type==1?"dot":vertex_type==2?"straight cross":
                    vertex_type==3?"diagonal cross":vertex_type==4?"filled circle":
                    vertex_type==5?"outlined circle":vertex_type==6?"square":"diamond",
                    ymin,ymax,
                    opacity,pattern,
                    *color?color:"default");
              const CImg<T> values = gmic_image_arg(*ind);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]], col(img.spectrum(),1,1,1,0);
                col.fill(color,true);
                gmic_apply(img,draw_graph(values,col.data(),opacity,plot_type,vertex_type,
                                          ymin,ymax,pattern));
              }
            } else arg_error("graph");
            is_released = false; ++position; continue;
          }

#endif // #ifdef gmic_float
# 6479 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='g'.

        //----------------------------
        // Commands starting by '-h..'
        //----------------------------
        else if (command1=='h') {

#ifdef gmic_float

          // Histogram.
          if (!std::strcmp("-histogram",command)) {
            gmic_substitute_args();
            char sep = 0, sep0 = 0, sep1 = 0;
            double value0 = 0, value1 = 0;
            float nb_levels = 256;
            if ((std::sscanf(argument,"%f%c",
                             &nb_levels,&end)==1 ||
                 (std::sscanf(argument,"%f%c%c",
                              &nb_levels,&sep,&end)==2 && sep=='%') ||
                 std::sscanf(argument,"%f,%lf,%lf%c",
                             &nb_levels,&value0,&value1,&end)==3 ||
                 (std::sscanf(argument,"%f%c,%lf,%lf%c",
                              &nb_levels,&sep,&value0,&value1,&end)==4 && sep=='%') ||
                 (std::sscanf(argument,"%f,%lf%c,%lf%c",
                              &nb_levels,&value0,&sep0,&value1,&end)==4 && sep0=='%') ||
                 (std::sscanf(argument,"%f%c,%lf%c,%lf%c",
                              &nb_levels,&sep,&value0,&sep0,&value1,&end)==5 && sep=='%' &&
                  sep0=='%') ||
                 (std::sscanf(argument,"%f,%lf,%lf%c%c",
                              &nb_levels,&value0,&value1,&sep1,&end)==4 && sep1=='%') ||
                 (std::sscanf(argument,"%f%c,%lf,%lf%c%c",
                              &nb_levels,&sep,&value0,&value1,&sep1,&end)==5 && sep=='%' &&
                  sep1=='%') ||
                 (std::sscanf(argument,"%f,%lf%c,%lf%c%c",
                              &nb_levels,&value0,&sep0,&value1,&sep1,&end)==5 && sep0=='%' &&
                  sep1=='%') ||
                 (std::sscanf(argument,"%f%c,%lf%c,%lf%c%c",
                              &nb_levels,&sep,&value0,&sep0,&value1,&sep1,&end)==6 && sep=='%' &&
                  sep0=='%' && sep1=='%')) &&
                nb_levels>0) { nb_levels = cimg::round(nb_levels); ++position; }
            else { nb_levels = 256; value0 = value1 = 0; sep = sep0 = sep1 = 0; }
            if (value0==value1 && value0==0) { value1 = 100; sep0 = sep1 = '%'; }
            print(images,"Compute histogram of image%s, using %g%s level%s in range [%g%s,%g%s].",
                  gmic_selection,
                  nb_levels,sep=='%'?"%":"",
                  nb_levels>1?"s":"",
                  value0,sep0=='%'?"%":"",
                  value1,sep1=='%'?"%":"");
            cimg_forY(selection,l) {
              CImg<T> &img = gmic_check(images[selection[l]]);
              double vmin = 0, vmax = 0, nvalue0 = value0, nvalue1 = value1;
              if (sep0=='%' || sep1=='%') {
                if (img) vmax = (double)img.max_min(vmin);
                if (sep0=='%') nvalue0 = vmin + (vmax-vmin)*value0/100;
                if (sep1=='%') nvalue1 = vmin + (vmax-vmin)*value1/100;
              }
              const unsigned int
                _nb_levels = cimg::max(1U,
                                       (unsigned int)cimg::round(sep=='%'?
                                                                 nb_levels*(1+nvalue1-nvalue0)/100:
                                                                 nb_levels));
              gmic_apply(images[selection[l]],histogram(_nb_levels,(T)nvalue0,(T)nvalue1));
            }
            is_released = false; continue;
          }

          // HSI to RGB.
          gmic_simple_item("-hsi2rgb",HSItoRGB,"Convert image%s from HSI to RGB color bases.");

          // HSL to RGB.
          gmic_simple_item("-hsl2rgb",HSLtoRGB,"Convert image%s from HSL to RGB color bases.");

          // HSV to RGB.
          gmic_simple_item("-hsv2rgb",HSVtoRGB,"Convert image%s from HSV to RGB color bases.");

          // Compute Hessian.
          if (!std::strcmp("-hessian",command)) {
            gmic_substitute_args();
            CImg<char> axes(64);
            *axes = 0;
            if (std::sscanf(argument,"%63[xyz]%c",
                            axes.data(),&end)==1) {
              ++position;
              print(images,"Compute Hessian of image%s along axes '%s'.",
                    gmic_selection,
                    axes.data());
            } else
              print(images,"Compute Hessian of image%s.",
                    gmic_selection);
            unsigned int off = 0;
            cimg_forY(selection,l) {
              const unsigned int ind = selection[l] + off;
              CImg<T>& img = gmic_check(images[ind]);
              CImg<char> name = images_names[ind].get_mark();
              CImgList<T> hessian = img.get_hessian(*axes?axes.data():0);
              if (is_get_version) {
                images_names.insert(hessian.size(),name.copymark());
                hessian.move_to(images,~0U);
              } else {
                off+=hessian.size() - 1;
                hessian[0].move_to(images[ind].assign());
                for (unsigned int i = 1; i<hessian.size(); ++i) hessian[i].move_to(images,ind+i);
                images_names[ind] = name;
                if (hessian.size()>1) images_names.insert(hessian.size()-1,name.copymark(),ind+1);
              }
            }
            is_released = false; continue;
          }

#endif // #ifdef gmic_float
# 6589 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='h'.

        //----------------------------
        // Commands starting by '-i..'
        //----------------------------
        else if (command1=='i' && !(command[2]=='f' && !command[3])) {   // (Skip for '-if').

#ifdef gmic_float

          // Draw image.
          if (!std::strcmp("-image",command)) {
            gmic_substitute_args();
            char sep = 0, sepx = 0, sepy = 0, sepz = 0, sepc = 0;
            CImg<char> indicesm(256);
            float x = 0, y = 0, z = 0, c = 0, opacity = 1, max_opacity_mask = 1;
            CImg<unsigned int> ind, indm;
            *indices = *indicesm = *argx = *argy = *argz = *argc = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                              indices,&sep,&end)==2 && sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-]%c",
                             indices,argx,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             indices,argx,argy,&end)==3 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-]%c",
                             indices,argx,argy,argz,&end)==4 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-]%c",
                             indices,argx,argy,argz,argc,&end)==5 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-],%255[0-9.eE%+-],%f%c",
                             indices,argx,argy,argz,argc,&opacity,&end)==6 ||
                 (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                              "%255[0-9.eE%+-],%255[0-9.eE%+-],%f,[%255[a-zA-Z0-9_.%+-]%c%c",
                              indices,argx,argy,argz,argc,&opacity,indicesm.data(),&sep,&end)==8 &&
                  sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-],%255[0-9.eE%+-],%f,[%255[a-zA-Z0-9_.%+-]],%f%c",
                             indices,argx,argy,argz,argc,&opacity,indicesm.data(),
                             &max_opacity_mask,&end)==8) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-image",true,
                                    false,CImg<char>::empty())).height()==1 &&
                (!*indicesm ||
                 (indm = selection2cimg(indicesm,images.size(),images_names,"-image",true,
                                        false,CImg<char>::empty())).height()==1) &&
                (!*argx ||
                 std::sscanf(argx,"%f%c",&x,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&x,&sepx,&end)==2 && sepx=='%')) &&
                (!*argy ||
                 std::sscanf(argy,"%f%c",&y,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&y,&sepy,&end)==2 && sepy=='%')) &&
                (!*argz ||
                 std::sscanf(argz,"%f%c",&z,&end)==1 ||
                 (std::sscanf(argz,"%f%c%c",&z,&sepz,&end)==2 && sepz=='%')) &&
                (!*argc ||
                 std::sscanf(argc,"%f%c",&c,&end)==1 ||
                 (std::sscanf(argc,"%f%c%c",&c,&sepc,&end)==2 && sepc=='%'))) {
              const CImg<T> sprite = gmic_image_arg(*ind);
              CImg<T> mask;
              if (indm) {
                mask = gmic_image_arg(*indm);
                print(images,"Draw image [%u] at (%g%s,%g%s,%g%s,%g%s) on image%s, "
                      "with opacity %g and mask [%u].",
                      *ind,
                      x,sepx=='%'?"%":"",
                      y,sepy=='%'?"%":"",
                      z,sepz=='%'?"%":"",
                      c,sepc=='%'?"%":"",
                      gmic_selection,
                      opacity,
                      *indm);
              } else print(images,"Draw image [%u] at (%g%s,%g%s,%g%s,%g%s) on image%s, "
                           "with opacity %g.",
                           *ind,
                           x,sepx=='%'?"%":"",
                           y,sepy=='%'?"%":"",
                           z,sepz=='%'?"%":"",
                           c,sepc=='%'?"%":"",
                           gmic_selection,
                           opacity);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  nx = (int)cimg::round(sepx=='%'?x*(img.width()-1)/100:x),
                  ny = (int)cimg::round(sepy=='%'?y*(img.height()-1)/100:y),
                  nz = (int)cimg::round(sepz=='%'?z*(img.depth()-1)/100:z),
                  nc = (int)cimg::round(sepc=='%'?c*(img.spectrum()-1)/100:c);
                if (indm) {
                  gmic_apply(img,draw_image(nx,ny,nz,nc,sprite,mask,opacity,max_opacity_mask));
                } else {
                  gmic_apply(img,draw_image(nx,ny,nz,nc,sprite,opacity));
                }
              }
            } else arg_error("image");
            is_released = false; ++position; continue;
          }

          // Index image with a LUT.
          if (!std::strcmp("-index",command)) {
            gmic_substitute_args();
            unsigned int lut_type = 0, map_indexes = 0;
            float dithering = 0;
            CImg<unsigned int> ind;
            char sep = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                            indices,&sep,&end)==2 && sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f%c",
                             indices,&dithering,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%u%c",
                             indices,&dithering,&map_indexes,&end)==3) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-index",true,
                                    false,CImg<char>::empty())).height()==1) {
              const float ndithering = dithering<0?0:dithering>1?1:dithering;
              print(images,"Index values in image%s by LUT [%u], with dithering level %g%s.",
                    gmic_selection,
                    *ind,
                    ndithering,
                    map_indexes?" and index mapping":"");
              const CImg<T> palette = gmic_image_arg(*ind);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],index(palette,ndithering,(bool)map_indexes));
            } else if ((std::sscanf(argument,"%u%c",&lut_type,&end)==1 ||
                        std::sscanf(argument,"%u,%f%c",&lut_type,&dithering,&end)==2 ||
                        std::sscanf(argument,"%u,%f,%u%c",
                                    &lut_type,&dithering,&map_indexes,&end)==3) &&
                       lut_type<=7) {
              const float ndithering = dithering<0?0:dithering>1?1:dithering;
              print(images,"Index values in image%s by %s color LUT, with dithering level %g%s.",
                    gmic_selection,
                    lut_type==0?"default":lut_type==1?"HSV":lut_type==2?"lines":lut_type==3?"hot":
                    lut_type==4?"cool":lut_type==5?"jet":lut_type==6?"flag":"cube",
                    ndithering,map_indexes?" and index mapping":"");
              const CImg<T>
                palette = lut_type==0?CImg<T>::default_LUT256():lut_type==1?CImg<T>::HSV_LUT256():
                lut_type==2?CImg<T>::lines_LUT256():lut_type==3?CImg<T>::hot_LUT256():
                lut_type==4?CImg<T>::cool_LUT256():lut_type==5?CImg<T>::jet_LUT256():
                lut_type==6?CImg<T>::flag_LUT256():CImg<T>::cube_LUT256();
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],index(palette,ndithering,(bool)map_indexes));
            } else arg_error("index");
            is_released = false; ++position; continue;
          }

          // Matrix inverse.
          gmic_simple_item("-invert",invert,"Invert matrix image%s.");

          // Extract 3d isoline.
          if (!std::strcmp("-isoline3d",command)) {
            gmic_substitute_args();
            float x0 = -3, y0 = -3, x1 = 3, y1 = 3, value = 0, dx = 256, dy = 256;
            char sep = 0, sepx = 0, sepy = 0;
            *formula = 0;
            if (std::sscanf(argument,"%f%c",
                            &value,&end)==1 ||
                std::sscanf(argument,"%f%c%c",
                            &value,&sep,&end)==2) {
              print(images,"Extract 3d isolines from image%s, using isovalue %g%s.",
                    gmic_selection,
                    value,sep=='%'?"%":"");
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                CImg<T>& img = gmic_check(images[ind]);
                if (img) {
                  CImg<float> vertices;
                  CImgList<unsigned int> primitives;
                  CImgList<unsigned char> colors;
                  CImg<unsigned char> palette;
                  palette.assign(3,img.spectrum(),1,1,220).noise(35,1);
                  if (img.spectrum()==1) palette(0) = palette(1) = palette(2) = 200;
                  else {
                    palette(0,0) = 255; palette(1,0) = palette(2,0) = 30;
                    palette(0,1) = palette(2,1) = 30; palette(1,1) = 255;
                    if (img.spectrum()>=3) palette(0,2) = palette(1,2) = 30; palette(2,2) = 255;
                  }
                  cimg_forC(img,k) {
                    const CImg<T> channel = img.get_shared_channel(k);
                    float nvalue = value;
                    if (sep=='%') {
                      float vmin = 0, vmax = (float)channel.max_min(vmin);
                      nvalue = vmin + (vmax-vmin)*value/100;
                    }
                    CImgList<unsigned int> prims;
                    const CImg<float> pts = img.get_shared_channel(k).get_isoline3d(prims,nvalue);
                    vertices.append_object3d(primitives,pts,prims);
                    colors.insert(prims.size(),CImg<unsigned char>::vector(palette(0,k),
                                                                           palette(1,k),
                                                                           palette(2,k)));
                  }
                  if (!vertices)
                    warn(images,"Command '-isoline3d': Isovalue %g%s not found in image [%u].",
                         value,sep=='%'?"%":"",ind);
                  vertices.object3dtoCImg3d(primitives,colors,false);
                  gmic_apply(img,replace(vertices));
                } else { gmic_apply(img,replace(img)); }
              }
            } else if ((std::sscanf(argument,"'%4095[^']',%f%c",
                                    formula,&value,&end)==2 ||
                        std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f%c",
                                    formula,&value,&x0,&y0,&x1,&y1,&end)==6 ||
                        std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f%c",
                                    formula,&value,&x0,&y0,&x1,&y1,&dx,&dy,&end)==8 ||
                        (std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f%c,%f%c",
                                     formula,&value,&x0,&y0,&x1,&y1,&dx,&sepx,&dy,&end)==9 &&
                         sepx=='%') ||
                        (std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f%c%c",
                                     formula,&value,&x0,&y0,&x1,&y1,&dx,&dy,&sepy,&end)==9 &&
                         sepy=='%') ||
                        (std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f%c,%f%c%c",
                                     formula,&value,&x0,&y0,&x1,&y1,&dx,&sepx,&dy,&sepy,&end)==10&&
                         sepx=='%' && sepy=='%')) &&
                       dx>0 && dy>0) {
              dx = cimg::round(dx);
              dy = cimg::round(dy);
              gmic_strreplace(formula);
              print(images,"Extract 3d isoline %g from formula '%s', in range (%g,%g)-(%g,%g) "
                    "with size %g%sx%g%s.",
                    value,
                    formula,
                    x0,y0,
                    x1,y1,
                    dx,sepx=='%'?"%":"",
                    dy,sepy=='%'?"%":"");
              if (sepx=='%') dx = -dx;
              if (sepy=='%') dy = -dy;
              CImgList<unsigned int> primitives;
              CImg<T> vertices = CImg<T>::isoline3d(primitives,(const char*)formula,value,
                                                    x0,y0,x1,y1,(int)dx,(int)dy);
              vertices.object3dtoCImg3d(primitives,false).move_to(images);
              cimg_snprintf(title,_title.size(),"[3d isoline %g of '%s']",value,formula);
              gmic_ellipsize(title,_title.size());
              CImg<char>::string(title).move_to(images_names);
            } else arg_error("isoline3d");
            is_released = false; ++position; continue;
          }

          // Extract 3d isosurface.
          if (!std::strcmp("-isosurface3d",command)) {
            gmic_substitute_args();
            float x0 = -3, y0 = -3, z0 = -3, x1 = 3, y1 = 3, z1 = 3, value = 0,
              dx = 32, dy = 32, dz = 32;
            char sep = 0, sepx = 0, sepy = 0, sepz = 0;
            *formula = 0;
            if (std::sscanf(argument,"%f%c",
                            &value,&end)==1 ||
                std::sscanf(argument,"%f%c%c",
                            &value,&sep,&end)==2) {
              print(images,"Extract 3d isosurface from image%s, using isovalue %g%s.",
                    gmic_selection,
                    value,sep=='%'?"%":"");
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                CImg<T>& img = gmic_check(images[ind]);
                if (img) {
                  CImg<float> vertices;
                  CImgList<unsigned int> primitives;
                  CImgList<unsigned char> colors;
                  CImg<unsigned char> palette;
                  palette.assign(3,img.spectrum(),1,1,220).noise(35,1);
                  if (img.spectrum()==1) palette(0) = palette(1) = palette(2) = 200;
                  else {
                    palette(0,0) = 255; palette(1,0) = palette(2,0) = 30;
                    palette(0,1) = palette(2,1) = 30; palette(1,1) = 255;
                    if (img.spectrum()>=3) palette(0,2) = palette(1,2) = 30; palette(2,2) = 255;
                  }
                  cimg_forC(img,k) {
                    const CImg<T> channel = img.get_shared_channel(k);
                    float nvalue = value;
                    if (sep=='%') {
                      float vmin = 0, vmax = (float)channel.max_min(vmin);
                      nvalue = vmin + (vmax-vmin)*value/100;
                    }
                    CImgList<unsigned int> prims;
                    const CImg<float> pts = channel.get_isosurface3d(prims,nvalue);
                    vertices.append_object3d(primitives,pts,prims);
                    colors.insert(prims.size(),CImg<unsigned char>::vector(palette(0,k),
                                                                           palette(1,k),
                                                                           palette(2,k)));
                  }
                  if (!vertices) {
                    if (img.depth()>1)
                      warn(images,
                           "Command '-isosurface3d': Isovalue %g%s not found in image [%u].",
                           value,sep=='%'?"%":"",ind);
                    else
                      warn(images,
                           "Command '-isosurface3d': Image [%u] has a single slice, "
                           "isovalue %g%s not found.",
                           ind,value,sep=='%'?"%":"");
                  }
                  vertices.object3dtoCImg3d(primitives,colors,false);
                  gmic_apply(img,replace(vertices));
                } else { gmic_apply(img,replace(img)); }
              }
            } else if ((std::sscanf(argument,"'%4095[^']',%f%c",
                                    formula,&value,&end)==2 ||
                        std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f%c",
                                    formula,&value,&x0,&y0,&z0,&x1,&y1,&z1,&end)==8 ||
                        std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f,%f,%f,%f%c",
                                    formula,&value,&x0,&y0,&z0,&x1,&y1,&z1,&dx,&dy,&dz,&end)==11 ||
                        (std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f,%f%c,%f,%f%c",
                                     formula,&value,&x0,&y0,&z0,&x1,&y1,&z1,
                                     &dx,&sepx,&dy,&dz,&end)==12 &&
                         sepx=='%') ||
                        (std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f,%f,%f%c,%f%c",
                                     formula,&value,&x0,&y0,&z0,&x1,&y1,&z1,
                                     &dx,&dy,&sepy,&dz,&end)==12 &&
                         sepy=='%') ||
                        (std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f,%f,%f,%f%c%c",
                                     formula,&value,&x0,&y0,&z0,&x1,&y1,&z1,
                                     &dx,&dy,&dz,&sepz,&end)==12 &&
                         sepz=='%') ||
                        (std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f,%f%c,%f%c,%f%c",
                                     formula,&value,&x0,&y0,&z0,&x1,&y1,&z1,
                                     &dx,&sepx,&dy,&sepy,&dz,&end)==13 &&
                         sepx=='%' && sepy=='%') ||
                        (std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f,%f%c,%f,%f%c%c",
                                     formula,&value,&x0,&y0,&z0,&x1,&y1,&z1,
                                     &dx,&sepx,&dy,&dz,&sepz,&end)==13 &&
                         sepx=='%' && sepz=='%') ||
                        (std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f,%f,%f%c,%f%c%c",
                                     formula,&value,&x0,&y0,&z0,&x1,&y1,&z1,
                                     &dx,&dy,&sepy,&dz,&sepz,&end)==13 &&
                         sepy=='%' && sepz=='%') ||
                        (std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f,%f%c,%f%c,%f%c%c",
                                     formula,&value,&x0,&y0,&z0,&x1,&y1,&z1,
                                     &dx,&sepx,&dy,&sepy,&dz,&sepz,&end)==14 &&
                         sepx=='%' && sepy=='%' && sepz=='%')) &&
                       dx>0 && dy>0 && dz>0) {
              dx = cimg::round(dx);
              dy = cimg::round(dy);
              dz = cimg::round(dz);
              gmic_strreplace(formula);
              print(images,"Extract 3d isosurface %g from formula '%s', "
                    "in range (%g,%g,%g)-(%g,%g,%g) with size %g%sx%g%sx%g%s.",
                    value,
                    formula,
                    x0,y0,z0,
                    x1,y1,z1,
                    dx,sepx=='%'?"%":"",
                    dy,sepy=='%'?"%":"",
                    dz,sepz=='%'?"%":"");
              if (sepx=='%') dx = -dx;
              if (sepy=='%') dy = -dy;
              if (sepz=='%') dz = -dz;
              CImgList<unsigned int> primitives;
              CImg<T> vertices = CImg<T>::isosurface3d(primitives,(const char*)formula,value,
                                                       x0,y0,z0,x1,y1,z1,(int)dx,(int)dy,(int)dz);
              vertices.object3dtoCImg3d(primitives,false).move_to(images);
              cimg_snprintf(title,_title.size(),"[3d isosurface %g of '%s']",value,formula);
              gmic_ellipsize(title,_title.size());
              CImg<char>::string(title).move_to(images_names);
            } else arg_error("isosurface3d");
            is_released = false; ++position; continue;
          }

          // Inpaint.
          if (!std::strcmp("-inpaint",command)) {
            gmic_substitute_args();
            float patch_size = 11, lookup_size = 22, lookup_factor = 0.5, lookup_increment = 1,
              blend_size = 0, blend_threshold = 0, blend_decay = 0.05f, blend_scales = 10;
            unsigned int is_blend_outer = 1, method = 1;
            CImg<unsigned int> ind;
            char sep = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 && sep==']') ||
                 (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%c%c",indices,&sep,&end)==2 && sep=='0') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],0,%u%c",indices,&method,&end)==2) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-inpaint",true,
                                    false,CImg<char>::empty())).height()==1 &&
                method<=3) {
              print(images,"Inpaint image%s masked by image [%u], with %s algorithm.",
                    gmic_selection,
                    *ind,
                    method==0?"low-connectivity average":method==1?"high-connectivity average":
                    method==2?"low-connectivity median":"high-connectivity median");
              const CImg<T> mask = gmic_image_arg(*ind);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],inpaint(mask,method));
            } else if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                                     indices,&sep,&end)==2 && sep==']') ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f%c",
                                    indices,&patch_size,&end)==2 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f%c",
                                    indices,&patch_size,&lookup_size,&end)==3 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f%c",
                                    indices,&patch_size,&lookup_size,&lookup_factor,&end)==4 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f%c",
                                    indices,&patch_size,&lookup_size,&lookup_factor,&lookup_increment,&end)==5 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f,%f%c",
                                    indices,&patch_size,&lookup_size,&lookup_factor,&lookup_increment,
                                    &blend_size,&end)==6 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f,%f,%f%c",
                                    indices,&patch_size,&lookup_size,&lookup_factor,&lookup_increment,
                                    &blend_size,&blend_threshold,&end)==7 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f,%f,%f,%f%c",
                                    indices,&patch_size,&lookup_size,&lookup_factor,&lookup_increment,
                                    &blend_size,&blend_threshold,&blend_decay,&end)==8 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f,%f,%f,%f,%f%c",
                                    indices,&patch_size,&lookup_size,&lookup_factor,&lookup_increment,
                                    &blend_size,&blend_threshold,&blend_decay,&blend_scales,&end)==9 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f,%f,%f,%f,%f,%u%c",
                                    indices,&patch_size,&lookup_size,&lookup_factor,&lookup_increment,
                                    &blend_size,&blend_threshold,&blend_decay,&blend_scales,
                                    &is_blend_outer,&end)==10) &&
                       (ind=selection2cimg(indices,images.size(),images_names,"-inpaint",true,
                                           false,CImg<char>::empty())).height()==1 &&
                       patch_size>=0.5 && lookup_size>=0.5 && lookup_factor>=0 &&
                       blend_size>=0 && blend_threshold>=0 && blend_threshold<=1 &&
                       blend_decay>=0 && blend_scales>=0.5 && is_blend_outer<=1) {
              const CImg<T> mask = gmic_image_arg(*ind);
              patch_size = cimg::round(patch_size);
              lookup_size = cimg::round(lookup_size);
              lookup_increment = cimg::round(lookup_increment);
              blend_size = cimg::round(blend_size);
              blend_scales = cimg::round(blend_scales);
              print(images,"Inpaint image%s masked by image [%d], with patch size %g, "
                    "lookup size %g, lookup factor %g, lookup_increment %g, blend size %g, blend threshold %g, "
                    "blend decay %g, %g blend scale%s and outer blending %s.",
                    gmic_selection,*ind,
                    patch_size,lookup_size,lookup_factor,lookup_increment,
                    blend_size,blend_threshold,blend_decay,blend_scales,blend_scales!=1?"s":"",
                    is_blend_outer?"enabled":"disabled");
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],
                           inpaint_patch(mask,
                                         (unsigned int)patch_size,(unsigned int)lookup_size,
                                         lookup_factor,
                                         (unsigned int)lookup_increment,
                                         (unsigned int)blend_size,blend_threshold,blend_decay,
                                         (unsigned int)blend_scales,(bool)is_blend_outer));
            } else arg_error("inpaint");
            is_released = false; ++position; continue;
          }

#endif // #ifdef gmic_float
# 7023 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='i'.

        //----------------------------
        // Commands starting by '-k..'
        //----------------------------
        else if (command1=='k') {

          // Keep images.
          if (!std::strcmp("-keep",command)) {
            print(images,"Keep image%s",
                  gmic_selection);
            CImgList<T> _images, nimages(selection.height());
            CImgList<char> _images_names, nimages_names(selection.height());
            if (is_get_version) { _images.assign(images); _images_names.assign(images_names); }
            cimg_forY(selection,l) {
              nimages[l].swap(images[selection[l]]);
              nimages_names[l].swap(images_names[selection[l]]);
            }
            nimages.move_to(images);
            nimages_names.move_to(images_names);
            if (is_get_version) {
              _images.move_to(images,0);
              _images_names.move_to(images_names,0);
            }
            if (verbosity>=0 || is_debug) {
              std::fprintf(cimg::output()," (%u image%s left).",
                           images.size(),images.size()==1?"":"s");
              std::fflush(cimg::output());
            }
            is_released = false; continue;
          }

        } // command1=='k'.

        //----------------------------
        // Commands starting by '-l..'
        //----------------------------
        else if (command1=='l') {

          // Start local environnement.
          if (!std::strcmp("-local",command)) {
            CImg<char>::string("*local").move_to(scope);
            if (verbosity>0 || is_debug)
              print(images,"Start '-local..-endlocal' block, with image%s.",
                    gmic_selection);
            CImgList<T> nimages(selection.height());
            CImgList<char> nimages_names(selection.height());
            if (is_get_version) cimg_forY(selection,l) {
                nimages[l].assign(images[selection[l]]);
                nimages_names[l].assign(images_names[selection[l]]).copymark();
              } else cimg_forY(selection,l) {
                if (images[selection[l]].is_shared())
                  nimages[l] = CImg<T>(images[selection[l]],true);
                else nimages[l].swap(images[selection[l]]);
                nimages_names[l].swap(images_names[selection[l]]);
              }
            const unsigned int local_scope_size = scope.size();
            CImg<char> exception_message, exception_command;
            try {
              _parse(commands_line,position,nimages,nimages_names,variables_sizes);
            } catch (gmic_exception &e) {
              int nb_locals = 0;
              for (nb_locals = 1; nb_locals && position<commands_line.size(); ++position) {
                const char *const it = commands_line[position].data();
                if (!std::strcmp("-local",it) || !std::strcmp("-l",it) ||
                    !std::strcmp("--local",it) || !std::strcmp("--l",it) ||
                    !std::strncmp("-local[",it,7) || !std::strncmp("-l[",it,3) ||
                    !std::strncmp("--local[",it,8) || !std::strncmp("--l[",it,4)) ++nb_locals;
                else if (!std::strcmp("-endlocal",it) || !std::strcmp("-endl",it)) --nb_locals;
                else if (nb_locals==1 && !std::strcmp("-onfail",it)) break;
              }
              if (scope.size()>local_scope_size) scope.remove(local_scope_size,scope.size()-1);
              if (nb_locals==1 && position<commands_line.size()) { // Onfail block found.
                if (verbosity>0 || is_debug) print(images,"Reach '-onfail' block.");
                _parse(commands_line,++position,nimages,nimages_names,variables_sizes);
              } else { // Onfail block not found.
                exception_message.assign(e._message);
                exception_command.assign(e._command_help);
              }
            }
            scope.remove();
            if (is_get_version) {
              nimages.move_to(images,~0U);
              nimages_names.move_to(images_names,~0U);
            } else {
              const unsigned int nb = cimg::min((unsigned int)selection.height(),nimages.size());
              if (nb>0) {
                for (unsigned int i = 0; i<nb; ++i) {
                  if (images[selection[i]].is_shared()) {
                    images[selection[i]] = nimages[i];
                    nimages[i].assign();
                  } else images[selection[i]].swap(nimages[i]);
                  images_names[selection[i]].swap(nimages_names[i]);
                }
                nimages.remove(0,nb-1);
                nimages_names.remove(0,nb-1);
              }
              if (nb<(unsigned int)selection.height())
                remove_images(images,images_names,selection,nb,selection.height()-1);
              else if (nimages) {
                const unsigned int ind0 = selection?selection.back()+1:images.size();
                images.insert(nimages,ind0);
                nimages_names.move_to(images_names,ind0);
              }
            }
            if (exception_message || exception_command)
              throw gmic_exception(exception_command.data(),exception_message.data());
            continue;
          }

#ifdef gmic_float

          // Less or equal.
          gmic_arithmetic_item("-le",
                               operator_le,"Compute boolean 'less or equal than' between image%s "
                               "and %g%s",
                               gmic_selection,value,ssep,T,
                               operator_le,"Compute boolean 'less or equal than' between image%s "
                               "and image [%d]",
                               gmic_selection,ind[0],
                               "Compute boolean 'less or equal than' between image%s and "
                               "expression %s'",
                               gmic_selection,argument_text,
                               "Compute boolean 'less or equal than' between image%s");

          // Less than.
          gmic_arithmetic_item("-lt",
                               operator_lt,
                               "Compute boolean 'less than' between image%s and %g%s",
                               gmic_selection,value,ssep,T,
                               operator_lt,
                               "Compute boolean 'less than' between image%s and image [%d]",
                               gmic_selection,ind[0],
                               "Compute boolean 'less than' between image%s and expression %s'",
                               gmic_selection,argument_text,
                               "Compute boolean 'less than' between image%s");

          // Logarithm, base-e.
          gmic_simple_item("-log",log,"Compute pointwise base-e logarithm of image%s.");

          // Logarithm, base-2.
          gmic_simple_item("-log2",log2,"Compute pointwise base-2 logarithm of image%s.");

          // Logarithm, base-10.
          gmic_simple_item("-log10",log10,"Compute pointwise base-10 logarithm of image%s.");

          // Draw line.
          if (!std::strcmp("-line",command)) {
            gmic_substitute_args();
            *argx = *argy = *argz = *argc = *color = 0;
            float x0 = 0, y0 = 0, x1 = 0, y1 = 0, opacity = 1;
            char sepx0 = 0, sepy0 = 0, sepx1 = 0, sepy1 = 0, seph = 0;
            unsigned int pattern = ~0U;
            if ((std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-]%c",
                             argx,argy,argz,argc,&end)==4 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-],%f%c",
                             argx,argy,argz,argc,&opacity,&end)==5 ||
                 (std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                              "%255[0-9.eE%+-],%f,0%c%x%c",
                              argx,argy,argz,argc,&opacity,&seph,&pattern,&end)==7 &&
                  seph=='x') ||
                 (std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                              "%255[0-9.eE%+-],%f,%4095[0-9.eE,+-]%c",
                              argx,argy,argz,argc,&opacity,color,&end)==6 && (bool)(pattern=~0U)) ||
                 (*color=0,std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                                       "%255[0-9.eE%+-],%f,0%c%x,%4095[0-9.eE,+-]%c",
                                       argx,argy,argz,argc,&opacity,&seph,
                                       &pattern,color,&end)==8 && seph=='x')) &&
                (std::sscanf(argx,"%f%c",&x0,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&x0,&sepx0,&end)==2 && sepx0=='%')) &&
                (std::sscanf(argy,"%f%c",&y0,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&y0,&sepy0,&end)==2 && sepy0=='%')) &&
                (std::sscanf(argz,"%f%c",&x1,&end)==1 ||
                 (std::sscanf(argz,"%f%c%c",&x1,&sepx1,&end)==2 && sepx1=='%')) &&
                (std::sscanf(argc,"%f%c",&y1,&end)==1 ||
                 (std::sscanf(argc,"%f%c%c",&y1,&sepy1,&end)==2 && sepy1=='%'))) {
              print(images,"Draw line (%g%s,%g%s) - (%g%s,%g%s) on image%s, with opacity %g, "
                    "pattern 0x%x and color (%s).",
                    x0,sepx0=='%'?"%":"",
                    y0,sepy0=='%'?"%":"",
                    x1,sepx1=='%'?"%":"",
                    y1,sepy1=='%'?"%":"",
                    gmic_selection,
                    opacity,pattern,
                    *color?color:"default");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]], col(img.spectrum(),1,1,1,0);
                col.fill(color,true);
                const int
                  nx0 = (int)cimg::round(sepx0=='%'?x0*(img.width()-1)/100:x0),
                  ny0 = (int)cimg::round(sepy0=='%'?y0*(img.height()-1)/100:y0),
                  nx1 = (int)cimg::round(sepx1=='%'?x1*(img.width()-1)/100:x1),
                  ny1 = (int)cimg::round(sepy1=='%'?y1*(img.height()-1)/100:y1);
                gmic_apply(img,draw_line(nx0,ny0,nx1,ny1,col.data(),opacity,pattern));
              }
            } else arg_error("line");
            is_released = false; ++position; continue;
          }

          // Lab to RGB
          gmic_simple_item("-lab2rgb",LabtoRGB,"Convert image%s from Lab to RGB color bases.");

          // Label connected components.
          if (!std::strcmp("-label",command)) {
            gmic_substitute_args();
            unsigned int is_high_connectivity = 0;
            float tolerance = 0;
            if ((std::sscanf(argument,"%f%c",&tolerance,&end)==1 ||
                 std::sscanf(argument,"%f,%u%c",&tolerance,&is_high_connectivity,&end)==2) &&
                tolerance>=0) ++position;
            else { tolerance = 0; is_high_connectivity = 0; }
            print(images,
                  "Label connected components on image%s, with tolerance %g and "
                  "%s connectivity.",
                  gmic_selection,tolerance,is_high_connectivity?"high":"low");
            cimg_forY(selection,l)
              gmic_apply(images[selection[l]],label((bool)is_high_connectivity,tolerance));
            is_released = false; continue;
          }

          // Set 3d light position.
          if (!std::strcmp("-light3d",item)) {
            gmic_substitute_args();
            float lx = 0, ly = 0, lz = -5e8f;
            CImg<unsigned int> ind;
            char sep = 0;
            if (std::sscanf(argument,"%f,%f,%f%c",
                            &lx,&ly,&lz,&end)==3) {
              print(images,"Set 3d light position to (%g,%g,%g).",
                    lx,ly,lz);
              light3d_x = lx;
              light3d_y = ly;
              light3d_z = lz;
              ++position;
            } else if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 &&
                       sep==']' &&
                       (ind=selection2cimg(indices,images.size(),images_names,"-light3d",true,
                                           false,CImg<char>::empty())).height()==1) {
              print(images,"Set 3d light texture from image [%u].",*ind);
              light3d.assign(images[*ind],false);
              ++position;
            } else {
              print(images,"Reset 3d light to default.");
              light3d.assign();
              light3d_x = light3d_y = 0; light3d_z = -5e8f;
            }
            continue;
          }

#endif // #ifdef gmic_float
# 7275 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='l'.

        //----------------------------
        // Commands starting by '-m..'
        //----------------------------
        else if (command1=='m') {

          // Move images.
          if (!std::strcmp("-move",command)) {
            gmic_substitute_args();
            float pos = 0;
            char sep = 0;
            if (std::sscanf(argument,"%f%c",&pos,&end)==1 ||
                (std::sscanf(argument,"%f%c%c",&pos,&sep,&end)==2 && sep=='%')) {
              const int
                _ind0 = (int)cimg::round(sep=='%'?pos*images.size()/100:pos),
                ind0 = _ind0<0?_ind0+(int)images.size():_ind0;
              if (ind0<0 || ind0>(int)images.size())
                error(images,"Command '-move': Invalid position '%d' (not in range -%u..%u).",
                      _ind0,images.size(),images.size()-1);
              print(images,"Move image%s to position %d.",
                    gmic_selection,
                    ind0);
              CImgList<T> _images, nimages;
              CImgList<char> _images_names, nimages_names;
              if (is_get_version) {
                _images.insert(images.size());
                // Copy original list while preserving shared state of each item.
                cimglist_for(_images,l) _images[l].assign(images[l],images[l].is_shared());
                _images_names.assign(images_names);
              }
              nimages.insert(selection.height());
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                if (is_get_version) images[ind].move_to(nimages[l]);
                else images[ind].swap(nimages[l]);
                // Empty shared image as a special item to be removed later.
                images[ind]._is_shared = true;
                images_names[ind].move_to(nimages_names);
              }
              images.insert(nimages.size(),ind0);
              cimglist_for(nimages,l) nimages[l].swap(images[ind0+l]);
              nimages_names.move_to(images_names,ind0);
              cimglist_for(images,l) if (!images[l] && images[l].is_shared()) {
                images.remove(l); images_names.remove(l--); // Remove special items.
              }
              if (is_get_version) {
                cimglist_for(images,l) // Replace shared items by non-shared one for a get version.
                  if (images[l].is_shared()) {
                    CImg<T> tmp; (images[l].move_to(tmp)).swap(images[l]);
                  }
                images.insert(_images.size(),0);
                cimglist_for(_images,l) images[l].swap(_images[l]);
                _images_names.move_to(images_names,0);
              }
            } else arg_error("move");
            is_released = false; ++position; continue;
          }

          // Mirror.
          if (!std::strcmp("-mirror",command)) {
            gmic_substitute_args();
            bool is_valid_argument = true;
            for (const char *s = argument; *s; ++s) {
              const char _s = *s;
              if (_s!='x' && _s!='y' && _s!='z' && _s!='c') { is_valid_argument = false; break; }
            }
            if (*argument && is_valid_argument) {
              print(images,"Mirror image%s along the '%s'-ax%cs.",
                    gmic_selection,
                    argument_text,
                    std::strlen(argument)>1?'e':'i');
              cimg_forY(selection,l) gmic_apply(images[selection[l]],mirror(argument));
            } else arg_error("mirror");
            is_released = false; ++position; continue;
          }

          // Manage mutexes.
          if (!std::strcmp("-mutex",item)) {
            gmic_substitute_args();
            unsigned int number, is_lock = 1;
            if ((std::sscanf(argument,"%u%c",
                             &number,&end)==1 ||
                 std::sscanf(argument,"%u,%u%c",
                             &number,&is_lock,&end)==2) &&
                number<256 && is_lock<=1) {
              print(images,"%s mutex #%u.",
                    is_lock?"Lock":"Unlock",number);
              if (is_lock) gmic_mutex().lock(number);
              else gmic_mutex().unlock(number);
            } else arg_error("mutex");
            ++position; continue;
          }

#ifdef gmic_float

          // Multiplication.
          gmic_arithmetic_item("-mul",
                               operator*=,
                               "Multiply image%s by %g%s",
                               gmic_selection,value,ssep,Tfloat,
                               mul,
                               "Multiply image%s by image [%d]",
                               gmic_selection,ind[0],
                               "Multiply image%s by expression %s",
                               gmic_selection,argument_text,
                               "Multiply image%s");
          // Modulo.
          gmic_arithmetic_item("-mod",
                               operator%=,
                               "Compute pointwise modulo of image%s by %g%s",
                               gmic_selection,value,ssep,T,
                               operator%=,
                               "Compute pointwise modulo of image%s by image [%d]",
                               gmic_selection,ind[0],
                               "Compute pointwise modulo of image%s by expression %s",
                               gmic_selection,argument_text,
                               "Compute sequential pointwise modulo of image%s");

          // Max.
          gmic_arithmetic_item("-max",
                               max,
                               "Compute pointwise maximum between image%s and %g%s",
                               gmic_selection,value,ssep,T,
                               max,
                               "Compute pointwise maximum between image%s and image [%d]",
                               gmic_selection,ind[0],
                               "Compute pointwise maximum between image%s and expression %s",
                               gmic_selection,argument_text,
                               "Compute pointwise maximum of all image%s together");
          // Min.
          gmic_arithmetic_item("-min",
                               min,
                               "Compute pointwise minimum between image%s and %g%s",
                               gmic_selection,value,ssep,T,
                               min,
                               "Compute pointwise minimum between image%s and image [%d]",
                               gmic_selection,ind[0],
                               "Compute pointwise minimum between image%s and expression %s",
                               gmic_selection,argument_text,
                               "Compute pointwise minimum of image%s");

          // Matrix multiplication.
          gmic_arithmetic_item("-mmul",
                               operator*=,
                               "Multiply matrix/vector%s by %g%s",
                               gmic_selection,value,ssep,Tfloat,
                               operator*=,
                               "Multiply matrix/vector%s by matrix/vector image [%d]",
                               gmic_selection,ind[0],
                               "Multiply matrix/vector%s by expression %s",
                               gmic_selection,argument_text,
                               "Multiply matrix/vector%s");

          // Set 3d rendering modes.
          if (!std::strcmp("-mode3d",item)) {
            gmic_substitute_args();
            int value = 4;
            if (std::sscanf(argument,"%d%c",
                            &value,&end)==1 &&
                value>=-1 && value<=5) ++position;
            else value = 4;
            render3d = value;
            print(images,"Set static 3d rendering mode to %s.",
                  render3d==-1?"bounding-box":
                  render3d==0?"pointwise":render3d==1?"linear":render3d==2?"flat":
                  render3d==3?"flat-shaded":render3d==4?"Gouraud-shaded":
                  render3d==5?"Phong-shaded":"none");
            continue;
          }

          if (!std::strcmp("-moded3d",item)) {
            gmic_substitute_args();
            int value = -1;
            if (std::sscanf(argument,"%d%c",
                            &value,&end)==1 &&
                value>=-1 && value<=5) ++position;
            else value = -1;
            renderd3d = value;
            print(images,"Set dynamic 3d rendering mode to %s.",
                  renderd3d==-1?"bounding-box":
                  renderd3d==0?"pointwise":renderd3d==1?"linear":renderd3d==2?"flat":
                  renderd3d==3?"flat-shaded":renderd3d==4?"Gouraud-shaded":
                  renderd3d==5?"Phong-shaded":"none");
            continue;
          }

          // Map LUT.
          if (!std::strcmp("-map",command)) {
            gmic_substitute_args();
            unsigned int lut_type = 0;
            CImg<unsigned int> ind;
            char sep = 0;
            if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 &&
                sep==']' &&
                (ind=selection2cimg(indices,images.size(),images_names,"-map",true,
                                    false,CImg<char>::empty())).height()==1) {
              print(images,"Map LUT [%u] on image%s.",
                    *ind,
                    gmic_selection);
              const CImg<T> palette = gmic_image_arg(*ind);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],map(palette));
            } else if (std::sscanf(argument,"%u%c",&lut_type,&end)==1 &&
                       lut_type<=7) {
              print(images,"Map %s color LUT on image%s.",
                    lut_type==0?"default":lut_type==1?"HSV":lut_type==2?"lines":lut_type==3?"hot":
                    lut_type==4?"cool":lut_type==5?"jet":lut_type==6?"flag":"cube",
                    gmic_selection);
              const CImg<T>
                palette = lut_type==0?CImg<T>::default_LUT256():lut_type==1?CImg<T>::HSV_LUT256():
                lut_type==2?CImg<T>::lines_LUT256():lut_type==3?CImg<T>::hot_LUT256():
                lut_type==4?CImg<T>::cool_LUT256():lut_type==5?CImg<T>::jet_LUT256():
                lut_type==6?CImg<T>::flag_LUT256():CImg<T>::cube_LUT256();
              cimg_forY(selection,l) gmic_apply(images[selection[l]],map(palette));
            } else arg_error("map");
            is_released = false; ++position; continue;
          }

          // Median filter.
          if (!std::strcmp("-median",command)) {
            gmic_substitute_args();
            float siz = 3;
            if (std::sscanf(argument,"%f%c",
                            &siz,&end)==1 &&
                siz>=0) {
              siz = cimg::round(siz);
              print(images,"Apply median filter of size %g, on image%s.",
                    siz,
                    gmic_selection);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],blur_median((unsigned int)siz));
            } else arg_error("median");
            is_released = false; ++position; continue;
          }

          // Matrix division.
          gmic_arithmetic_item("-mdiv",
                               operator/=,
                               "Divide matrix/vector%s by %g%s",
                               gmic_selection,value,ssep,Tfloat,
                               operator/=,
                               "Divide matrix/vector%s by matrix/vector image [%d]",
                               gmic_selection,ind[0],
                               "Divide matrix/vector%s by expression %s",
                               gmic_selection,argument_text,
                               "Divide matrix/vector%s");

          // MSE.
          if (!std::strcmp("-mse",command)) {
            print(images,"Compute the %dx%d matrix of MSE values, from image%s.",
                  selection.height(),selection.height(),
                  gmic_selection);
            if (selection) {
              CImgList<T> subimages(selection.height());
              cimg_forY(selection,l) subimages[l].assign(gmic_check(images[selection[l]]),true);
              CImg<T> img(subimages.size(),subimages.size(),1,1,(T)0);
              cimg_forXY(img,x,y) if (x>y) img(x,y) = img(y,x) = (T)subimages[x].MSE(subimages[y]);
              CImg<char> name = CImg<char>::string("[MSE]");
              if (is_get_version) {
                img.move_to(images);
                name.move_to(images_names);
              } else {
                remove_images(images,images_names,selection,1,selection.height()-1);
                img.move_to(images[selection[0]].assign());
                name.move_to(images_names[selection[0]]);
              }
            }
            is_released = false; continue;
          }

          // Draw mandelbrot/julia fractal.
          if (!std::strcmp("-mandelbrot",command)) {
            gmic_substitute_args();
            double z0r = -2, z0i = -2, z1r = 2, z1i = 2, paramr = 0, parami = 0;
            unsigned int is_julia = 0;
            float opacity = 1, itermax = 100;
            if ((std::sscanf(argument,"%lf,%lf,%lf,%lf%c",
                             &z0r,&z0i,&z1r,&z1i,&end)==4 ||
                 std::sscanf(argument,"%lf,%lf,%lf,%lf,%f%c",
                             &z0r,&z0i,&z1r,&z1i,&itermax,&end)==5 ||
                 std::sscanf(argument,"%lf,%lf,%lf,%lf,%f,%u%c",
                             &z0r,&z0i,&z1r,&z1i,&itermax,&is_julia,&end)==6 ||
                 std::sscanf(argument,"%lf,%lf,%lf,%lf,%f,%u,%lf,%lf%c",
                             &z0r,&z0i,&z1r,&z1i,&itermax,&is_julia,&paramr,
                             &parami,&end)==8 ||
                 std::sscanf(argument,"%lf,%lf,%lf,%lf,%f,%u,%lf,%lf,%f%c",
                             &z0r,&z0i,&z1r,&z1i,&itermax,&is_julia,
                             &paramr,&parami,&opacity,&end)==9) &&
                itermax>=0 && is_julia<=1) {
              itermax = cimg::round(itermax);
              print(images,"Draw %s fractal on image%s, from complex area (%g,%g)-(%g,%g) "
                    "with c0 = (%g,%g) and %g iterations.",
                    is_julia?"julia":"mandelbrot",
                    gmic_selection,
                    z0r,z0i,
                    z1r,z1i,
                    paramr,parami,
                    itermax);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],draw_mandelbrot(CImg<T>(),opacity,z0r,z0i,z1r,z1i,
                                                                (unsigned int)itermax,true,
                                                                (bool)is_julia,
                                                                paramr,parami));
            } else arg_error("mandelbrot");
            is_released = false; ++position; continue;
          }

#endif // #ifdef gmic_float
# 7583 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='m'.

        //----------------------------
        // Commands starting by '-n..'
        //----------------------------
        else if (command1=='n') {

          // Set image name.
          if (!std::strcmp("-name",command) && !is_get_version) {
            gmic_substitute_args();
            const unsigned int l = std::strlen(argument);
            CImg<char> name(argument,l+1);
            unsigned int is_modified=0;
            if (l>=2 && name[l-2]==',' && (name[l-1]=='0' || name[l-1]=='1')) {
              is_modified = name[l-1]!='0';
              name[l-2] = 0;
            }
            print(images,"Set name of image%s to '%s'%s.",
                  gmic_selection,name.data(),is_modified?" (modified)":"");
            gmic_strreplace(name);
            if (is_modified) name.mark();
            cimg_forY(selection,l) images_names[selection[l]].assign(name);
            ++position; continue;
          }

#ifdef gmic_float

          // Normalize.
          if (!std::strcmp("-normalize",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind0, ind1;
            double value0 = 0, value1 = 0;
            char sep0 = 0, sep1 = 0;
            *argx = *argy = 0;
            if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                            argx,argy,&end)==2 &&
                ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep0,&end)==2 &&
                  sep0==']' &&
                  (ind0=selection2cimg(indices,images.size(),images_names,"-normalize",true,
                                       false,CImg<char>::empty())).height()==1) ||
                 (std::sscanf(argx,"%lf%c%c",&value0,&sep0,&end)==2 && sep0=='%') ||
                 std::sscanf(argx,"%lf%c",&value0,&end)==1) &&
                ((std::sscanf(argy,"[%255[a-zA-Z0-9_.%+-]%c%c",formula,&sep1,&end)==2 &&
                  sep1==']' &&
                  (ind1=selection2cimg(formula,images.size(),images_names,"-normalize",true,
                                       false,CImg<char>::empty())).height()==1) ||
                 (std::sscanf(argy,"%lf%c%c",&value1,&sep1,&end)==2 && sep1=='%') ||
                 std::sscanf(argy,"%lf%c",&value1,&end)==1)) {
              if (ind0) { value0 = images[*ind0].min(); sep0 = 0; }
              if (ind1) { value1 = images[*ind1].max(); sep1 = 0; }
              print(images,"Normalize image%s in range [%g%s,%g%s].",
                    gmic_selection,
                    value0,sep0=='%'?"%":"",
                    value1,sep1=='%'?"%":"");
              cimg_forY(selection,l) {
                CImg<T>& img = gmic_check(images[selection[l]]);
                double vmin = 0, vmax = 0, nvalue0 = value0, nvalue1 = value1;
                if (sep0=='%' || sep1=='%') {
                  if (img) vmax = (double)img.max_min(vmin);
                  if (sep0=='%') nvalue0 = vmin + (vmax-vmin)*value0/100;
                  if (sep1=='%') nvalue1 = vmin + (vmax-vmin)*value1/100;
                }
                gmic_apply(img,normalize((T)nvalue0,(T)nvalue1));
              }
            } else if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep0,&end)==2 &&
                       sep0==']' &&
                       (ind0=selection2cimg(indices,images.size(),images_names,"-normalize",true,
                                            false,CImg<char>::empty())).height()==1) {
              if (images[*ind0]) value1 = (double)images[*ind0].max_min(value0);
              print(images,"Normalize image%s in range [%g,%g].",
                    gmic_selection,
                    value0,
                    value1);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],normalize((T)value0,(T)value1));
            } else arg_error("normalize");
            is_released = false; ++position; continue;
          }

          // Test difference.
          gmic_arithmetic_item("-neq",
                               operator_neq,
                               "Compute boolean inequality between image%s and %g%s",
                               gmic_selection,value,ssep,T,
                               operator_neq,
                               "Compute boolean inequality between image%s and image [%d]",
                               gmic_selection,ind[0],
                               "Compute boolean inequality between image%s and expression %s'",
                               gmic_selection,argument_text,
                               "Compute boolean inequality between image%s");

          // Add noise.
          if (!std::strcmp("-noise",command)) {
            gmic_substitute_args();
            int noise_type = 0;
            float sigma = 0;
            char sep = 0;
            if ((std::sscanf(argument,"%f%c",
                             &sigma,&end)==1 ||
                 (std::sscanf(argument,"%f%c%c",
                              &sigma,&sep,&end)==2 && sep=='%') ||
                 std::sscanf(argument,"%f,%d%c",
                             &sigma,&noise_type,&end)==2 ||
                 (std::sscanf(argument,"%f%c,%d%c",
                              &sigma,&sep,&noise_type,&end)==3 && sep=='%')) &&
                sigma>=0 && noise_type>=0 && noise_type<=4) {
              const char *s_type = noise_type==0?"gaussian":
                noise_type==1?"uniform":
                noise_type==2?"salt&pepper":
                noise_type==3?"poisson":"rice";
              if (sep=='%') sigma = -sigma;
              print(images,"Add %s noise to image%s, with standard deviation %g%s.",
                    s_type,
                    gmic_selection,
                    cimg::abs(sigma),sep=='%'?"%":"");
              cimg_forY(selection,l) gmic_apply(images[selection[l]],noise(sigma,noise_type));
            } else arg_error("noise");
            is_released = false; ++position; continue;
          }

#endif // #ifdef gmic_float
# 7704 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='n'.

        //----------------------------
        // Commands starting by '-o..'
        //----------------------------
        else if (command1=='o') {

          // Output.
          if (!std::strcmp("-output",command) && !is_get_version) {
            gmic_substitute_args();
            char cext[8];
            CImg<char> _filename(4096), filename_tmp(1024), options(256);
            *cext = *_filename = *filename_tmp = *options = 0;
            if (std::sscanf(argument,"%8[a-zA-Z]:%4095[^,],%255s",cext,_filename.data(),options.data())<2 ||
                !cext[1]) {  // length of 'ext' must be >=2 (avoid case 'C:\\..' on Windows).
              *cext = *_filename = *options = 0;
              if (std::sscanf(argument,"%4095[^,],%255s",_filename.data(),options.data())!=2) {
                std::strncpy(_filename,argument,_filename.width()-1);
                _filename[_filename.width()-1] = 0;
              }
            }
            gmic_strreplace(_filename);
            gmic_strreplace(options);

            if (*cext) { // Force output to be written as a '.ext' file : generate random filename.
              if (*_filename=='-' && (!_filename[1] || _filename[1]=='.')) {
                // Simplify filename 'ext:-.foo' as '-.ext'.
                cimg_snprintf(_filename,_filename.width(),"-.%s",cext);
                *cext = 0;
              } else {
                std::FILE *file = 0;
                do {
                  cimg_snprintf(filename_tmp,filename_tmp.width(),"%s%c%s.%s",
                                cimg::temporary_path(),cimg_file_separator,
                                cimg::filenamerand(),cext);
                  if ((file=std::fopen(filename_tmp,"rb"))!=0) std::fclose(file);
                } while (file);
              }
            }
            const char
              *const filename = *cext?filename_tmp:_filename,
              *const ext = cimg::split_filename(filename);

            if (!cimg::strcasecmp(ext,"off")) {
              CImg<char> nfilename(4096);
              *nfilename = 0;
              std::strncpy(nfilename,filename,nfilename.width()-1);
              nfilename[nfilename.width()-1] = 0;
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                const CImg<T>& img = gmic_check(images[ind]);
                if (selection.height()!=1) cimg::number_filename(filename,l,6,nfilename);
                CImgList<unsigned int> primitives;
                CImgList<float> colors, opacities;
                CImg<float> vertices(img,false);
                try {
                  vertices.CImg3dtoobject3d(primitives,colors,opacities,false).
                    save_off(primitives,colors,nfilename);
                } catch (CImgException &e) {
                  if (!vertices.is_CImg3d(true,message))
                    error(images,
                          "Command '-output': 3d object file '%s', invalid 3d object [%u] "
                          "in selected image%s (%s).",
                          nfilename.data(),ind,gmic_selection,message);
                  else throw e;
                }
                print(images,"Output 3d object [%u] as file '%s'.",
                      ind,
                      nfilename.data());
              }
            } else if (!cimg::strcasecmp(ext,"tiff") || !cimg::strcasecmp(ext,"tif")) {
              float _compression = 0;
              if (std::sscanf(options,"%f%c",&_compression,&end)!=1) _compression = 0;
              if (_compression<0) _compression = 0; else if (_compression>6) _compression = 6;
              const unsigned int compression = (unsigned int)cimg::round(_compression);
              CImgList<T> output_images(selection.height());
              CImgList<unsigned int> empty_indices;
              cimg_forY(selection,l) if (!gmic_check(images[selection(l)]))
                CImg<unsigned int>::vector(selection(l)).move_to(empty_indices);
              if (empty_indices) {
                const CImg<char> _eselec = selection2string(empty_indices>'y',images_names,true);
                const char *const eselec = _eselec.data();
                warn(images,"Command '-output': Image%s %s empty.",
                     eselec,empty_indices.size()>1?"are":"is");
              }
              cimg_forY(selection,l)
                output_images[l].assign(images[selection[l]],output_images[l]?true:false);
              if (output_images.size()==1)
                print(images,"Output image%s as file '%s', with %s compression "
                      "(1 image %dx%dx%dx%d).",
                      gmic_selection,
                      _filename.data(),
                      compression==0?"no":compression==1?"CCITTRLE":compression==2?"CCITT4":
                      compression==3?"CCITT6":compression==4?"LZW":compression==5?"JPEG1":"JPEG2",
                      output_images[0].width(),output_images[0].height(),
                      output_images[0].depth(),output_images[0].spectrum());
              else print(images,"Output image%s as file '%s', with %s compression.",
                         gmic_selection,
                         _filename.data(),
                         compression==0?"no":compression==1?"CCITTRLE":compression==2?"CCITT4":
                         compression==3?"CCITT6":compression==4?"LZW":compression==5?"JPEG1":
                         "JPEG2");
              if (!output_images)
                error(images,"Command '-output': File '%s', instance list (%u,%p) is empty.",
                      _filename.data(),output_images.size(),output_images.data());
              if (output_images.size()==1) output_images[0].save_tiff(filename,compression);
              else output_images.save_tiff(filename,compression);
            } else if (!cimg::strcasecmp(ext,"gif")) {
              float _fps = 0, _nb_loops = 0;
              CImgList<T> output_images(selection.height());
              CImgList<unsigned int> empty_indices;
              cimg_forY(selection,l) if (!gmic_check(images[selection(l)]))
                CImg<unsigned int>::vector(selection(l)).move_to(empty_indices);
              if (empty_indices) {
                const CImg<char> _eselec = selection2string(empty_indices>'y',images_names,true);
                const char *const eselec = _eselec.data();
                warn(images,"Command '-output': Image%s %s empty.",
                     eselec,empty_indices.size()>1?"are":"is");
              }
              cimg_forY(selection,l)
                output_images[l].assign(images[selection[l]],output_images[l]?true:false);
              if (output_images.size()>1 && std::sscanf(options,"%f,%f",&_fps,&_nb_loops)>=1) {
                // Save animated .gif file.
                const unsigned int
                  fps = (unsigned int)cimg::round(_fps),
                  nb_loops = (unsigned int)cimg::round(_nb_loops);
                if (nb_loops)
                  print(images,
                        "Output image%s as animated file '%s', with %u fps and %u loops.",
                        gmic_selection,_filename.data(),fps,nb_loops);
                else
                  print(images,
                        "Output image%s as animated file '%s', with %u fps.",
                        gmic_selection,_filename.data(),fps);
                output_images.save_gif_external(filename,fps,nb_loops);
              } else {
                if (output_images.size()==1)
                  print(images,"Output image%s as file '%s' (1 image %dx%dx%dx%d).",
                        gmic_selection,
                        _filename.data(),
                        output_images[0].width(),output_images[0].height(),
                        output_images[0].depth(),output_images[0].spectrum());
                else print(images,"Output image%s as file '%s'.",
                           gmic_selection,
                           _filename.data());
                output_images.save(filename); // Save distinct .gif files.
              }
            } else if (!cimg::strcasecmp(ext,"jpeg") || !cimg::strcasecmp(ext,"jpg")) {
              float quality = 100;
              if (std::sscanf(options,"%f%c",&quality,&end)!=1) quality = 100;
              if (quality<0) quality = 0; else if (quality>100) quality = 100;
              CImgList<T> output_images(selection.height());
              CImgList<unsigned int> empty_indices;
              cimg_forY(selection,l) if (!gmic_check(images[selection(l)]))
                CImg<unsigned int>::vector(selection(l)).move_to(empty_indices);
              if (empty_indices) {
                const CImg<char> _eselec = selection2string(empty_indices>'y',images_names,true);
                const char *const eselec = _eselec.data();
                warn(images,"Command '-output': Image%s %s empty.",
                     eselec,empty_indices.size()>1?"are":"is");
              }
              cimg_forY(selection,l)
                output_images[l].assign(images[selection[l]],output_images[l]?true:false);
              if (output_images.size()==1)
                print(images,
                      "Output image%s as file '%s', with quality %g%% (1 image %dx%dx%dx%d).",
                      gmic_selection,
                      _filename.data(),
                      quality,
                      output_images[0].width(),output_images[0].height(),
                      output_images[0].depth(),output_images[0].spectrum());
              else print(images,"Output image%s as file '%s', with quality %g%%.",
                         gmic_selection,
                         _filename.data(),
                         quality);
              if (!output_images)
                error(images,"Command '-output': File '%s', instance list (%u,%p) is empty.",
                      _filename.data(),output_images.size(),output_images.data());
              if (output_images.size()==1)
                output_images[0].save_jpeg(filename,(unsigned int)cimg::round(quality));
              else {
                CImg<char> nfilename(4096);
                cimglist_for(output_images,l) {
                  cimg::number_filename(filename,l,6,nfilename);
                  output_images[l].save_jpeg(nfilename,(unsigned int)cimg::round(quality));
                }
              }
            } else if (!cimg::strcasecmp(ext,"mnc") && *options) {
              CImgList<T> output_images(selection.height());
              CImgList<unsigned int> empty_indices;
              cimg_forY(selection,l) if (!gmic_check(images[selection(l)]))
                CImg<unsigned int>::vector(selection(l)).move_to(empty_indices);
              if (empty_indices) {
                const CImg<char> _eselec = selection2string(empty_indices>'y',images_names,true);
                const char *const eselec = _eselec.data();
                warn(images,"Command '-output': Image%s %s empty.",
                     eselec,empty_indices.size()>1?"are":"is");
              }
              cimg_forY(selection,l)
                output_images[l].assign(images[selection[l]],output_images[l]?true:false);
              if (output_images.size()==1)
                print(images,
                      "Output image%s as file '%s', with header get from file '%s' "
                      "(1 image %dx%dx%dx%d).",
                      gmic_selection,
                      _filename.data(),
                      options.data(),
                      output_images[0].width(),output_images[0].height(),
                      output_images[0].depth(),output_images[0].spectrum());
              else
                print(images,
                      "Output image%s as file '%s', with header get from file '%s'.",
                      gmic_selection,
                      _filename.data(),
                      options.data());
              if (output_images.size()==1)
                output_images[0].save_minc2(filename,options);
              else {
                CImg<char> nfilename(4096);
                cimglist_for(output_images,l) {
                  cimg::number_filename(filename,l,6,nfilename);
                  output_images[l].save_minc2(nfilename,options);
                }
              }
            } else if (!cimg::strcasecmp(ext,"raw")) {
              const char *const stype = std::sscanf(options,"%255[A-zA-Z]%c",argx,&end)==1?argx:
                cimg::type<T>::string();
              CImgList<T> output_images(selection.height());
              CImgList<unsigned int> empty_indices;
              cimg_forY(selection,l) if (!gmic_check(images[selection(l)]))
                CImg<unsigned int>::vector(selection(l)).move_to(empty_indices);
              if (empty_indices) {
                const CImg<char> _eselec = selection2string(empty_indices>'y',images_names,true);
                const char *const eselec = _eselec.data();
                warn(images,"Command '-output': Image%s %s empty.",
                     eselec,empty_indices.size()>1?"are":"is");
              }
              cimg_forY(selection,l)
                output_images[l].assign(images[selection[l]],images[selection[l]]?true:false);
              if (output_images.size()==1)
                print(images,
                      "Output image%s as file '%s', with pixel type '%s' (1 image %dx%dx%dx%d).",
                      gmic_selection,
                      _filename.data(),
                      stype,
                      output_images[0].width(),output_images[0].height(),
                      output_images[0].depth(),output_images[0].spectrum());
              else print(images,"Output image%s as file '%s', with pixel type '%s'.",
                         gmic_selection,
                         _filename.data(),
                         stype);
              if (!output_images)
                error(images,"Command '-output': File '%s', instance list (%u,%p) is empty.",
                      _filename.data(),output_images.size(),output_images.data());

#define gmic_save_raw(value_type,svalue_type)                           \
              if (!std::strcmp(stype,svalue_type)) {                    \
                if (output_images.size()==1)                            \
                  CImg<value_type>(output_images[0]).save_raw(filename); \
                else {                                                  \
                  CImg<char> nfilename(4096);                           \
                  cimglist_for(output_images,l) {                       \
                    cimg::number_filename(filename,l,6,nfilename);      \
                    CImg<value_type>(output_images[l]).save_raw(nfilename); \
                  }                                                     \
                }                                                       \
              }
              gmic_save_raw(bool,"bool")
              else gmic_save_raw(unsigned char,"uchar")
                else gmic_save_raw(unsigned char,"unsigned char")
                  else gmic_save_raw(char,"char")
                    else gmic_save_raw(unsigned short,"ushort")
                      else gmic_save_raw(unsigned short,"unsigned short")
                        else gmic_save_raw(short,"short")
                          else gmic_save_raw(unsigned int,"uint")
                            else gmic_save_raw(unsigned int,"unsigned int")
                              else gmic_save_raw(int,"int")
                                else gmic_save_raw(float,"float")
                                  else gmic_save_raw(double,"double")
                                    else error(images,
                                               "Command '-output': File '%s', invalid specified "
                                               "pixel type '%s'.",
                                               _filename.data(),stype);
            } else
              if (!cimg::strcasecmp(ext,"avi") || !cimg::strcasecmp(ext,"mov") ||
                  !cimg::strcasecmp(ext,"asf") || !cimg::strcasecmp(ext,"divx") ||
                  !cimg::strcasecmp(ext,"flv") || !cimg::strcasecmp(ext,"mpg") ||
                  !cimg::strcasecmp(ext,"m1v") || !cimg::strcasecmp(ext,"m2v") ||
                  !cimg::strcasecmp(ext,"m4v") || !cimg::strcasecmp(ext,"mjp") ||
                  !cimg::strcasecmp(ext,"mkv") || !cimg::strcasecmp(ext,"mpe") ||
                  !cimg::strcasecmp(ext,"movie") || !cimg::strcasecmp(ext,"ogm") ||
                  !cimg::strcasecmp(ext,"qt") || !cimg::strcasecmp(ext,"rm") ||
                  !cimg::strcasecmp(ext,"vob") || !cimg::strcasecmp(ext,"wmv") ||
                  !cimg::strcasecmp(ext,"xvid") || !cimg::strcasecmp(ext,"mpeg") ||
                  !cimg::strcasecmp(ext,"ogg")) {
                float fps = 0, bitrate = 0;
                std::sscanf(options,"%f,%f",&fps,&bitrate);
                fps = cimg::round(fps);
                bitrate = cimg::round(bitrate);
                if (!fps) fps = 25;
                if (!bitrate) bitrate = 2048;
                CImgList<T> output_images(selection.height());
                CImgList<unsigned int> empty_indices;
                cimg_forY(selection,l) if (!gmic_check(images[selection(l)]))
                  CImg<unsigned int>::vector(selection(l)).move_to(empty_indices);
                if (empty_indices) {
                  const CImg<char> _eselec = selection2string(empty_indices>'y',images_names,true);
                  const char *const eselec = _eselec.data();
                  warn(images,"Command '-output': Image%s %s empty.",
                       eselec,empty_indices.size()>1?"are":"is");
                }
                cimg_forY(selection,l)
                  output_images[l].assign(images[selection[l]],output_images[l]?true:false);
                print(images,"Output image%s as file '%s', with %g fps and bitrate %gk.",
                      gmic_selection,
                      _filename.data(),
                      fps,bitrate);
                if (!output_images)
                  error(images,"Command '-output': File '%s, instance list (%u,%p) is empty.",
                        _filename.data(),output_images.size(),output_images.data());
                output_images.save_ffmpeg(filename,(unsigned int)fps,(unsigned int)bitrate);
              } else {
                CImgList<T> output_images(selection.height());
                CImgList<unsigned int> empty_indices;
                cimg_forY(selection,l) if (!gmic_check(images[selection(l)]))
                  CImg<unsigned int>::vector(selection(l)).move_to(empty_indices);
                if (empty_indices) {
                  const CImg<char> _eselec = selection2string(empty_indices>'y',images_names,true);
                  const char *const eselec = _eselec.data();
                  warn(images,"Command '-output': Image%s %s empty.",
                       eselec,empty_indices.size()>1?"are":"is");
                }
                cimg_forY(selection,l)
                  output_images[l].assign(images[selection[l]],output_images[l]?true:false);
                if (output_images.size()==1)
                  print(images,"Output image%s as file '%s' (1 image %dx%dx%dx%d).",
                        gmic_selection,
                        _filename.data(),
                        output_images[0].width(),output_images[0].height(),
                        output_images[0].depth(),output_images[0].spectrum());
                else print(images,"Output image%s as file '%s'.",
                           gmic_selection,
                           _filename.data());
                output_images.save(filename);
              }

            if (*cext) { // When output forced to 'ext' : copy final file to specified location.
              try {
                CImg<unsigned char>::get_load_raw(filename_tmp).save_raw(_filename);
                std::remove(filename_tmp);
              } catch (...) {
                error(images,
                      "Command '-output': Invalid write of file '%s from temporary file '%s'.",
                      _filename.data(),filename_tmp.data());
              }
            }
            is_released = true; ++position; continue;
          }

          // Exception handling in local environments.
          if (!std::strcmp("-onfail",item)) {
            const CImg<char> &s = scope.back();
            if (s[0]!='*' || s[1]!='l')
              error(images,"Command '-onfail': Not associated to a '-local' command within "
                    "the same scope.");
            for (int nb_locals = 1; nb_locals && position<commands_line.size(); ++position) {
              const char *const it = commands_line[position].data();
              if (!std::strcmp("-local",it) || !std::strcmp("-l",it) ||
                  !std::strcmp("--local",it) || !std::strcmp("--l",it) ||
                  !std::strncmp("-local[",it,7) || !std::strncmp("-l[",it,3) ||
                  !std::strncmp("--local[",it,8) || !std::strncmp("--l[",it,4)) ++nb_locals;
              else if (!std::strcmp("-endlocal",it) || !std::strcmp("-endl",it)) {
                --nb_locals; if (!nb_locals) --position;
              }
            }
            continue;
          }

#ifdef gmic_float

          // Draw 3d object.
          if (!std::strcmp("-object3d",command)) {
            gmic_substitute_args();
            float x = 0, y = 0, z = 0, opacity = 1;
            char sep = 0, sepx = 0, sepy = 0;
            unsigned int
              is_zbuffer = 1,
              _render3d = (unsigned int)cimg::max(0,render3d),
              _is_double3d = is_double3d?1:0;
            float
              _focale3d = focale3d,
              _light3d_x = light3d_x,
              _light3d_y = light3d_y,
              _light3d_z = light3d_z,
              _specular_lightness3d = specular_lightness3d,
              _specular_shininess3d = specular_shininess3d;
            CImg<unsigned int> ind;
            *argx = *argy = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                              indices,&sep,&end)==2 && sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-]%c",
                             indices,argx,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             indices,argx,argy,&end)==3 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%f%c",
                             indices,argx,argy,&z,&end)==4 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%f,%f%c",
                             indices,argx,argy,&z,&opacity,&end)==5 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%f,%f,%u%c",
                             indices,argx,argy,&z,&opacity,&_render3d,&end)==6 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%f,%f,%u,%u%c",
                             indices,argx,argy,&z,&opacity,&_render3d,&_is_double3d,&end)==7 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%f,%f,%u,%u,%u%c",
                             indices,argx,argy,&z,&opacity,&_render3d,&_is_double3d,&is_zbuffer,
                             &end)==8 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%f,%f,%u,%u,%u,%f%c",
                             indices,argx,argy,&z,&opacity,&_render3d,&_is_double3d,&is_zbuffer,
                             &_focale3d,&end)==9 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%f,%f,%u,%u,%u,%f,%f,%f,%f%c",
                             indices,argx,argy,&z,&opacity,&_render3d,&_is_double3d,&is_zbuffer,
                             &_focale3d,&_light3d_x,&_light3d_y,&_light3d_z,&end)==12 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%f,%f,%u,%u,%u,%f,%f,%f,%f,%f,%f%c",
                             indices,argx,argy,&z,&opacity,&_render3d,&_is_double3d,&is_zbuffer,
                             &_focale3d,&_light3d_x,&_light3d_y,&_light3d_z,
                             &_specular_lightness3d,&_specular_shininess3d,&end)==14) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-object3d",true,
                                    false,CImg<char>::empty())).height()==1 &&
                (!*argx ||
                 std::sscanf(argx,"%f%c",&x,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&x,&sepx,&end)==2 && sepx=='%')) &&
                (!*argy ||
                 std::sscanf(argy,"%f%c",&y,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&y,&sepy,&end)==2 && sepy=='%')) &&
                _render3d<=5 && is_zbuffer<=1 && _is_double3d<=1) {
              const CImg<T> img0 = gmic_image_arg(*ind);

              print(images,"Draw 3d object [%u] at (%g%s,%g%s,%g) on image%s, with opacity %g, "
                    "%s rendering, %s-sided mode, %sz-buffer, focale %g, 3d light at (%g,%g,%g) "
                    "and specular properties (%g,%g)",
                    *ind,
                    x,sepx=='%'?"%":"",
                    y,sepy=='%'?"%":"",
                    z,
                    gmic_selection,
                    opacity,
                    _render3d==0?"dot":_render3d==1?"wireframe":_render3d==2?"flat":
                    _render3d==3?"flat-shaded":_render3d==4?"gouraud-shaded":"phong-shaded",
                    _is_double3d?"double":"simple",
                    is_zbuffer?"":"no ",
                    _focale3d,_light3d_x,_light3d_y,_light3d_z,
                    _specular_lightness3d,_specular_shininess3d);
              CImgList<unsigned int> primitives;
              CImgList<float> colors, opacities;
              CImgList<unsigned char> _colors;  // 'uchar' colors when rendering with light.
              CImg<float> vertices(img0,false);
              try {
                if (_render3d>=3) {
                  vertices.CImg3dtoobject3d(primitives,_colors,opacities,false);
                  if (light3d) _colors.insert(light3d,~0U,true);
                } else vertices.CImg3dtoobject3d(primitives,colors,opacities,false);
              }
              catch (CImgException &e) {
                if (!vertices.is_CImg3d(true,message))
                  error(images,"Command '-object3d': Invalid 3d object [%u], specified "
                        "in argument '%s' (%s).",
                        *ind,argument_text,message);
                else throw e;
              }
              cimglist_for(opacities,o) if (!opacities[o].is_shared()) opacities[o]*=opacity;

              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const float
                  nx = sepx=='%'?x*(img.width()-1)/100:x,
                  ny = sepy=='%'?y*(img.height()-1)/100:y;
                CImg<float> zbuffer(is_zbuffer?img.width():0,is_zbuffer?img.height():0,1,1,0);
                if (colors) {
                  gmic_apply(img,draw_object3d(nx,ny,z,vertices,primitives,colors,opacities,
                                               _render3d,_is_double3d,_focale3d,
                                               _light3d_x,_light3d_y,_light3d_z,
                                               _specular_lightness3d,_specular_shininess3d,
                                               zbuffer));
                } else {
                  gmic_apply(img,draw_object3d(nx,ny,z,vertices,primitives,_colors,opacities,
                                               _render3d,_is_double3d,_focale3d,
                                               _light3d_x,_light3d_y,_light3d_z,
                                               _specular_lightness3d,_specular_shininess3d,
                                               zbuffer));
                }
              }
            } else arg_error("object3d");
            is_released = false; ++position; continue;
          }

          // Bitwise or.
          gmic_arithmetic_item("-or",
                               operator|=,
                               "Compute bitwise OR of image%s by %g%s",
                               gmic_selection,value,ssep,Tlong,
                               operator|=,
                               "Compute bitwise OR of image%s by image [%d]",
                               gmic_selection,ind[0],
                               "Compute bitwise OR of image%s by expression %s",
                               gmic_selection,argument_text,
                               "Compute sequential bitwise OR of image%s");

          // Set 3d object opacity.
          if (!std::strcmp("-opacity3d",command)) {
            gmic_substitute_args();
            float value = 1;
            if (std::sscanf(argument,"%f%c",
                            &value,&end)==1) ++position;
            else value = 1;
            print(images,"Set opacity of 3d object%s to %g.",
                  gmic_selection,
                  value);
            cimg_forY(selection,l) {
              const unsigned int ind = selection[l];
              CImg<T>& img = gmic_check(images[ind]);
              try { gmic_apply(img,color_CImg3d(0,0,0,value,false,true)); }
              catch (CImgException &e) {
                if (!img.is_CImg3d(true,message))
                  error(images,"Command '-opacity3d': Invalid 3d object [%d], "
                        "in selected image%s (%s).",
                        ind,gmic_selection,message);
                else throw e;
              }
            }
            is_released = false; continue;
          }

#endif // #ifdef gmic_float
# 8244 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='o'.

        //----------------------------
        // Commands starting by '-p..'
        //----------------------------
        else if (command1=='p') {

          // Run multiple commands in parallel.
          if (!std::strcmp("-parallel",item)) {
            gmic_substitute_args();
            const char *_arg = argument, *_arg_text = argument_text;
            unsigned int wait_mode = 2;
            if ((*_arg=='0' || *_arg=='1' || *_arg=='2') && (_arg[1]==',' || !_arg[1])) {
              wait_mode = (unsigned int)(*_arg-'0'); _arg+=2; _arg_text+=2;
            }
            CImgList<char> arguments = CImg<char>::string(_arg).get_split(',',false,false);
            CImg<st_gmic_parallel<T> >(1,arguments.width()).move_to(threads_data);
            CImg<st_gmic_parallel<T> > &_threads_data = threads_data.back();

#ifdef gmic_is_parallel
            print(images,"Execute %d command%s '%s' in parallel%s.",
                  arguments.width(),arguments.width()>1?"s":"",_arg_text,
                  wait_mode==2?(arguments.width()>1?" and wait immediately they finish":
                                " and wait immediately it finishes"):
                  wait_mode==1?" and defer thread waiting at return point":"");
#else
# 8270 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            print(images,"Execute %d commands '%s' (run sequentially, "
                  "parallel computing disabled).",
                  arguments.width(),_arg_text);
#endif // #ifdef gmic_is_parallel
# 8274 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

            cimg_forY(_threads_data,l) {
              gmic &gi = _threads_data[l].gmic_instance;
              for (unsigned int i = 0; i<256; ++i) {
                gi.commands[i].assign(commands[i],true);
                gi.commands_names[i].assign(commands_names[i],true);
                gi.commands_has_arguments[i].assign(commands_has_arguments[i],true);
                gi.variables[i] = &gi._variables[i];
                gi.variables_names[i] = &gi._variables_names[i];
                _threads_data[l].variables_sizes[i] = 0;
              }

              gi.variables[255] = variables[255];  // Share global variables between all threads.
              gi.variables_names[255] = variables_names[255];
              gi.scope.assign(scope);
              gi.commands_files.assign(commands_files,true);
              cimg_snprintf(title,_title.size(),"*thread%d",l);
              CImg<char>::string(title).move_to(gi.scope);
              gi.background3d.assign(background3d);
              gi.light3d.assign(light3d);
              gi.pose3d.assign(pose3d);
              gi.status.assign(status);
              gi.debug_filename = debug_filename;
              gi.debug_line = debug_line;
              gi.focale3d = focale3d;
              gi.light3d_x = light3d_x;
              gi.light3d_y = light3d_y;
              gi.light3d_z = light3d_z;
              gi.specular_lightness3d = specular_lightness3d;
              gi.specular_shininess3d = specular_shininess3d;
              gi._progress = 0;
              gi.progress = &gi._progress;
              gi.is_released = is_released;
              gi.is_debug = is_debug;
              gi.is_start = false;
              gi.is_quit = false;
              gi.is_return = false;
              gi.is_double3d = is_double3d;
              gi.is_default_type = is_default_type;
              gi.check_elif = false;
              gi.verbosity = verbosity;
              gi.render3d = render3d;
              gi.renderd3d = renderd3d;
              gi._cancel = _cancel;
              gi.cancel = cancel;
              gi.nb_carriages = nb_carriages;
              gi.reference_time = reference_time;
              _threads_data[l].images = &images;
              _threads_data[l].images_names = &images_names;
              _threads_data[l].wait_mode = wait_mode;

              // Substitute special characters codes appearing outside strings.
              arguments[l].resize(1,arguments[l].height()+1,1,1,0);
              bool is_dquoted = false;
              for (char *s = arguments[l].data(); *s; ++s) {
                const char c = *s;
                if (c=='\"') is_dquoted = !is_dquoted;
                if (!is_dquoted) *s = c<' '?(c==_dollar?'$':c==_lbrace?'{':c==_rbrace?'}':
                                             c==_comma?',':c==_dquote?'\"':c==_arobace?'@':c):c;
              }
              gi.commands_line_to_CImgList(arguments[l].data()).
               move_to(_threads_data[l].commands_line);

#ifdef gmic_is_parallel
#if cimg_OS!=2
              pthread_create(&_threads_data[l].thread_id,0,gmic_parallel<T>,
                             (void*)&_threads_data[l]);
#else
# 8342 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
              _threads_data[l].thread_id = CreateThread(0,0,gmic_parallel<T>,
                                                        (void*)&_threads_data[l],0,0);
#endif // #if cimg_OS!=2
# 8345 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#else
# 8346 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
              gmic_parallel<T>((void*)&_threads_data[l]);

#endif // #ifdef gmic_is_parallel
# 8349 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
          }

            if (wait_mode==2) { // Wait for thread termination.
              cimg_forY(_threads_data,l) {
#ifdef gmic_is_parallel
#if cimg_OS!=2
                pthread_join(_threads_data[l].thread_id,0);
#else
# 8357 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
                WaitForSingleObject(_threads_data[l].thread_id,INFINITE);
                CloseHandle(_threads_data[l].thread_id);
#endif // #if cimg_OS!=2
# 8360 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#endif // #ifdef gmic_is_parallel
# 8361 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
                is_released&=_threads_data[l].gmic_instance.is_released;
              }

              // Get status modified by first thread.
              _threads_data[0].gmic_instance.status.move_to(status);

              // Check for possible exceptions thrown by threads.
              cimg_forY(_threads_data,l) if (_threads_data[l].exception._message)
                throw _threads_data[l].exception;

              threads_data.remove();
            }

            ++position; continue;
          }

          // Permute axes.
          if (!std::strcmp("-permute",command)) {
            gmic_substitute_args();
            print(images,"Permute axes of image%s, with permutation '%s'.",
                  gmic_selection,argument_text);
            cimg_forY(selection,l) gmic_apply(images[selection[l]],permute_axes(argument));
            is_released = false; ++position; continue;
          }

          // Set progress indice.
          if (!std::strcmp("-progress",item)) {
            gmic_substitute_args();
            float value = -1;
            if (std::sscanf(argument,"%f%c",
                            &value,&end)==1) {
              if (value<0) value = -1; else if (value>100) value = 100;
              if (value>=0)
                print(images,"Set progress indice to %g%%.",
                      value);
              else
                print(images,"Disable progress indice.");
              *progress = value;
            } else arg_error("progress");
            ++position; continue;
          }

          // Print.
          if (!std::strcmp("-print",command) && !is_get_version) {
            print_images(images,images_names,selection);
            is_released = true; continue;
          }

#ifdef gmic_float

          // Power.
          gmic_arithmetic_item("-pow",
                               pow,
                               "Compute image%s to the power of %g%s",
                               gmic_selection,value,ssep,Tfloat,
                               pow,
                               "Compute image%s to the power of image [%d]",
                               gmic_selection,ind[0],
                               "Compute image%s to the power of expression %s",
                               gmic_selection,argument_text,
                               "Compute sequential power of image%s");

          // Draw point.
          if (!std::strcmp("-point",command)) {
            gmic_substitute_args();
            float x = 0, y = 0, z = 0, opacity = 1;
            char sepx = 0, sepy = 0, sepz = 0;
            *argx = *argy = *argz = *color = 0;
            if ((std::sscanf(argument,"%255[0-9.eE%+-]%c",
                             argx,&end)==1 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             argx,argy,&end)==2 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             argx,argy,argz,&end)==3 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f%c",
                             argx,argy,argz,&opacity,&end)==4 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f,"
                             "%4095[0-9.eE,+-]%c",
                             argx,argy,argz,&opacity,color,&end)==5) &&
                (std::sscanf(argx,"%f%c",&x,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&x,&sepx,&end)==2 && sepx=='%')) &&
                (!*argy ||
                 std::sscanf(argy,"%f%c",&y,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&y,&sepy,&end)==2 && sepy=='%')) &&
                (!*argz ||
                 std::sscanf(argz,"%f%c",&z,&end)==1 ||
                 (std::sscanf(argz,"%f%c%c",&z,&sepz,&end)==2 && sepz=='%'))) {
              print(images,
                    "Draw point (%g%s,%g%s,%g%s) on image%s, with opacity %g and color (%s).",
                    x,sepx=='%'?"%":"",
                    y,sepy=='%'?"%":"",
                    z,sepz=='%'?"%":"",
                    gmic_selection,
                    opacity,
                    *color?color:"default");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]], col(img.spectrum(),1,1,1,0);
                col.fill(color,true);
                const int
                  nx = (int)cimg::round(sepx=='%'?x*(img.width()-1)/100:x),
                  ny = (int)cimg::round(sepy=='%'?y*(img.height()-1)/100:y),
                  nz = (int)cimg::round(sepz=='%'?z*(img.depth()-1)/100:z);
                gmic_apply(img,draw_point(nx,ny,nz,col.data(),opacity));
              }
            } else arg_error("point");
            is_released = false; ++position; continue;
          }

          // Draw polygon.
          if (!std::strcmp("-polygon",command)) {
            gmic_substitute_args();
            CImg<char> strint(256);
            *strint = *color = 0;
            float N = 0, x0 = 0, y0 = 0, opacity = 1;
            char sepx = 0, sepy = 0, seph = 0;
            unsigned int pattern = 0;
            if (std::sscanf(argument,"%f%c",
                            &N,&end)==2 && N>=1) {
              N = cimg::round(N);
              const char
                *nargument = argument + cimg_snprintf(strint,strint.width(),"%u",
                                                      (unsigned int)N) + 1,
                *const eargument = argument + std::strlen(argument);
              CImg<float> coords0((unsigned int)N,2,1,1,0);
              CImg<bool> percents((unsigned int)N,2,1,1,0);
              for (unsigned int n = 0; n<(unsigned int)N; ++n) if (nargument<eargument) {
                  sepx = sepy = 0;
                  if (std::sscanf(nargument,"%255[0-9.eE%+-],%255[0-9.eE%+-]",
                                  argx,argy)==2 &&
                      (std::sscanf(argx,"%f%c",&x0,&end)==1 ||
                       (std::sscanf(argx,"%f%c%c",&x0,&sepx,&end)==2 && sepx=='%')) &&
                      (std::sscanf(argy,"%f%c",&y0,&end)==1 ||
                       (std::sscanf(argy,"%f%c%c",&y0,&sepy,&end)==2 && sepy=='%'))) {
                    coords0(n,0) = x0; percents(n,0) = (sepx=='%');
                    coords0(n,1) = y0; percents(n,1) = (sepy=='%');
                    nargument+=std::strlen(argx) + std::strlen(argy) + 2;
                  } else arg_error("polygon");
                } else arg_error("polygon");
              if (nargument<eargument &&
                  std::sscanf(nargument,"%4095[0-9.eE+-]",color)==1 &&
                  std::sscanf(color,"%f",&opacity)==1) {
                nargument+=std::strlen(color) + 1;
                *color = 0;
              }
              if (nargument<eargument &&
                  std::sscanf(nargument,"0%c%4095[0-9a-fA-F]",&seph,color)==2 && seph=='x' &&
                  std::sscanf(color,"%x%c",&pattern,&end)==1) {
                nargument+=std::strlen(color)+3;
                *color = 0;
              }
              const char *const _color = nargument<eargument?nargument:&(end=0);
              if (seph=='x')
                print(images,"Draw %g-vertices outlined polygon on image%s, with opacity %g, "
                      "pattern 0x%x and color (%s).",
                      N,
                      gmic_selection,
                      opacity,pattern,
                      *_color?_color:"default");
              else
                print(images,"Draw %g-vertices filled polygon on image%s, with opacity %g "
                      "and color (%s).",
                      N,
                      gmic_selection,
                      opacity,
                      *_color?_color:"default");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                CImg<int> coords(coords0);
                cimg_forX(coords,p) {
                  if (percents(p,0))
                    coords(p,0) = (int)cimg::round(coords0(p,0)*(img.width()-1)/100);
                  else coords(p,0) = (int)cimg::round(coords(p,0));
                  if (percents(p,1))
                    coords(p,1) = (int)cimg::round(coords0(p,1)*(img.height()-1)/100);
                  else coords(p,1) = (int)cimg::round(coords(p,1));
                }
                CImg<T> col(img.spectrum(),1,1,1,0);
                col.fill(_color,true);
                if (seph=='x') { gmic_apply(img,draw_polygon(coords,col.data(),opacity,pattern)); }
                else { gmic_apply(img,draw_polygon(coords,col.data(),opacity)); }
              }
            } else arg_error("polygon");
            is_released = false; ++position; continue;
          }

          // Draw plasma fractal.
          if (!std::strcmp("-plasma",command)) {
            gmic_substitute_args();
            float alpha = 1, beta = 1, scale = 8;
            if ((std::sscanf(argument,"%f%c",
                             &alpha,&end)==1 ||
                 std::sscanf(argument,"%f,%f%c",
                             &alpha,&beta,&end)==2 ||
                 std::sscanf(argument,"%f,%f,%f%c",
                             &alpha,&beta,&scale,&end)==3) &&
                scale>=0) ++position;
            else { alpha = beta = 1; scale = 8; }
            const unsigned int _scale = (unsigned int)cimg::round(scale);
            print(images,"Draw plasma fractal on image%s, with alpha %g, beta %g and scale %u.",
                  gmic_selection,
                  alpha,
                  beta,
                  _scale);
            cimg_forY(selection,l)
              gmic_apply(images[selection[l]],draw_plasma(alpha,beta,_scale));
            is_released = false; continue;
          }

          // Set 3d pose.
          if (!std::strcmp("-pose3d",item)) {
            gmic_substitute_args();
            CImg<float> _p3d(16,1,1,1,0);
            float *const p3d = _p3d.data();
            if (std::sscanf(argument,"%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f%c",
                            p3d,p3d+1,p3d+2,p3d+3,p3d+4,p3d+5,p3d+6,p3d+7,
                            p3d+8,p3d+9,p3d+10,p3d+11,p3d+12,p3d+13,p3d+14,p3d+15,
                            &end)==16) {
              print(images,"Set 3d pose matrix to [ %g,%g,%g,%g; %g,%g,%g,%g; %g,%g,%g,%g; "
                    "%g,%g,%g,%g ].",
                    p3d[0],p3d[1],p3d[2],p3d[3],
                    p3d[4],p3d[5],p3d[6],p3d[7],
                    p3d[8],p3d[9],p3d[10],p3d[11],
                    p3d[12],p3d[13],p3d[14],p3d[15]);
              pose3d.assign(p3d,4,4,1,1,false);
              ++position;
            } else {
              print(images,"Reset 3d pose matrix to default.");
              pose3d.assign();
            }
            continue;
          }

          // Convert 3d object primitives.
          if (!std::strcmp("-primitives3d",command)) {
            gmic_substitute_args();
            unsigned int mode = 0;
            if (std::sscanf(argument,"%u%c",
                            &mode,&end)==1 &&
                mode<=2) {
              print(images,"Convert primitives of 3d object%s to %s.",
                    gmic_selection,
                    mode==0?"points":mode==1?"segments":"no-textures");
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                CImg<T> &img = gmic_check(images[ind]);
                try { gmic_apply(img,convert_primitives_CImg3d(mode)); }
                catch (CImgException &e) {
                  if (!img.is_CImg3d(true,message))
                    error(images,"Command '-primitives3d': Invalid 3d object [%d], "
                          "in selected image%s (%s).",
                          ind,gmic_selection,message);
                  else throw e;
                }
              }
            } else arg_error("primitives3d");
            is_released = false; ++position; continue;
          }

          // Display as a graph plot.
          if (!std::strcmp("-plot",command) && !is_get_version) {
            gmic_substitute_args();
            double ymin = 0, ymax = 0, xmin = 0, xmax = 0;
            unsigned int plot_type = 1, vertex_type = 1;
            float resolution = 65536;
            char sep = 0;
            *formula = 0;
            if (((std::sscanf(argument,"'%1023[^']%c%c",
                              formula,&sep,&end)==2 && sep=='\'') ||
                 std::sscanf(argument,"'%1023[^']',%f%c",
                             formula,&resolution,&end)==2 ||
                 std::sscanf(argument,"'%1023[^']',%f,%u%c",
                             formula,&resolution,&plot_type,&end)==3 ||
                 std::sscanf(argument,"'%1023[^']',%f,%u,%u%c",
                             formula,&resolution,&plot_type,&vertex_type,&end)==4 ||
                 std::sscanf(argument,"'%1023[^']',%f,%u,%u,%lf,%lf%c",
                             formula,&resolution,&plot_type,&vertex_type,&xmin,&xmax,&end)==6 ||
                 std::sscanf(argument,"'%1023[^']',%f,%u,%u,%lf,%lf,%lf,%lf%c",
                             formula,&resolution,&plot_type,&vertex_type,
                             &xmin,&xmax,&ymin,&ymax,&end)==8) &&
                resolution>0 && plot_type<=3 && vertex_type<=7) {
              resolution = cimg::round(resolution);
              gmic_strreplace(formula);
              if (xmin==0 && xmax==0) { xmin = -4; xmax = 4; }
              if (!plot_type && !vertex_type) plot_type = 1;
              if (resolution<1) resolution = 65536;
              CImgList<double> tmp_img(1);
              CImg<double> &values = tmp_img[0];

              values.assign(4,(unsigned int)resolution--,1,1,0);
              const double dx = xmax - xmin;
              cimg_forY(values,X) values(0,X) = xmin + X*dx/resolution;
              cimg::eval(formula,values).move_to(values);

              CImgList<char> tmp_name;
              cimg_snprintf(message,_message.size(),"[Plot of '%s']",formula);
              CImg<char>::string(message).move_to(tmp_name);
              display_plots(tmp_img,tmp_name,CImg<unsigned int>::vector(0),
                            plot_type,vertex_type,xmin,xmax,ymin,ymax);
              ++position;
            } else {
              plot_type = 1; vertex_type = 0; ymin = ymax = xmin = xmax = 0;
              if ((std::sscanf(argument,"%u%c",
                               &plot_type,&end)==1 ||
                   std::sscanf(argument,"%u,%u%c",
                               &plot_type,&vertex_type,&end)==2 ||
                   std::sscanf(argument,"%u,%u,%lf,%lf%c",
                               &plot_type,&vertex_type,&xmin,&xmax,&end)==4 ||
                   std::sscanf(argument,"%u,%u,%lf,%lf,%lf,%lf%c",
                               &plot_type,&vertex_type,&xmin,&xmax,&ymin,&ymax,&end)==6) &&
                  plot_type<=3 && vertex_type<=7) ++position;
              if (!plot_type && !vertex_type) plot_type = 1;
              display_plots(images,images_names,selection,plot_type,vertex_type,
                            xmin,xmax,ymin,ymax);
            }
            is_released = true; continue;
          }

#endif // #ifdef gmic_float
# 8679 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='p'.

        //----------------------------
        // Commands starting by '-q..'
        //----------------------------
        else if (command1=='q') {

#ifdef gmic_float

          // Draw quiver.
          if (!std::strcmp("-quiver",command)) {
            gmic_substitute_args();
            float sampling = 25, factor = -20, opacity = 1;
            unsigned int is_arrows = 1, pattern = ~0U;
            CImg<unsigned int> ind;
            char seph = 0;
            *color = 0;
            if ((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]]%c",
                             indices,&end)==1 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f%c",
                             indices,&sampling,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f%c",
                             indices,&sampling,&factor,&end)==3 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%u%c",
                             indices,&sampling,&factor,&is_arrows,&end)==4 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%u,%f%c",
                             indices,&sampling,&factor,&is_arrows,&opacity,&end)==5 ||
                 (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%u,%f,0%c%x%c",
                              indices,&sampling,&factor,&is_arrows,
                              &opacity,&seph,&pattern,&end)==7 && seph=='x') ||
                 (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%u,%f,%4095[0-9.eE,+-]%c",
                              indices,&sampling,&factor,&is_arrows,&opacity,color,&end)==6 &&
                  (bool)(pattern=~0U)) ||
                 (*color=0,std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%u,"
                                       "%f,0%c%x,%4095[0-9.eE,+-]%c",
                                       indices,&sampling,&factor,&is_arrows,
                                       &opacity,&seph,&pattern,color,&end)==8 &&
                  seph=='x')) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-quiver",true,
                                    false,CImg<char>::empty())).height()==1 &&
                sampling>0 && is_arrows<=1) {
              sampling = cimg::round(sampling);
              print(images,"Draw 2d vector field [%u] on image%s, with sampling %g, factor %g, "
                    "arrows %s, opacity %g, pattern 0x%x and color (%s).",
                    *ind,
                    gmic_selection,
                    sampling,
                    factor,
                    is_arrows?"enabled":"disabled",
                    opacity,pattern,
                    *color?color:"default");
              const CImg<T> flow = gmic_image_arg(*ind);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]], col(img.spectrum(),1,1,1,0);
                col.fill(color,true);
                gmic_apply(img,draw_quiver(flow,col.data(),opacity,(unsigned int)sampling,
                                           factor,(bool)is_arrows,pattern));
              }
            } else arg_error("quiver");
            is_released = false; ++position; continue;
          }

#endif // #ifdef gmic_float
# 8742 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='q'.

        //----------------------------
        // Commands starting by '-r..'
        //----------------------------
        else if (command1=='r') {

          // Remove images.
          if (!std::strcmp("-remove",command)) {
            print(images,"Remove image%s",
                  gmic_selection);
            CImgList<T> _images;
            CImgList<char> _images_names;
            if (is_get_version) { _images.assign(images); _images_names.assign(images_names); }
            remove_images(images,images_names,selection,0,selection.height()-1);
            if (is_get_version) {
              _images.move_to(images,0);
              _images_names.move_to(images_names,0);
            }
            if (verbosity>=0 || is_debug) {
              std::fprintf(cimg::output()," (%u image%s left).",
                           images.size(),images.size()==1?"":"s");
              std::fflush(cimg::output());
            }
            is_released = false; continue;
          }

          // Repeat.
          if (!std::strcmp("-repeat",item)) {
            gmic_substitute_args();
            float number = 0;
            if (std::sscanf(argument,"%f%c",
                            &number,&end)==1) {
              const unsigned int nb = number>0?(unsigned int)cimg::round(number):0U;
              if (nb) {
                CImg<char>::string("*repeat").move_to(scope);
                if (verbosity>0 || is_debug)
                  print(images,"Start '-repeat..-done' block (%u iteration%s).",
                        nb,nb>1?"s":"");
                CImg<unsigned int>::vector(position+1,nb,0).move_to(repeatdones);
              } else {
                if (verbosity>0 || is_debug)
                  print(images,"Skip 'repeat..done' block (0 iteration).",
                        nb);
                int nb_repeats = 0;
                for (nb_repeats = 1; nb_repeats && position<commands_line.size(); ++position) {
                  const char *it = commands_line[position].data();
                  if (!std::strcmp("-repeat",it)) ++nb_repeats;
                  else if (!std::strcmp("-done",it)) --nb_repeats;
                }
                if (nb_repeats && position>=commands_line.size())
                  error(images,"Command '-repeat': Missing associated '-done' command.");
                continue;
              }
            } else arg_error("repeat");
            ++position; continue;
          }

          // Resize.
          if (!std::strcmp("-resize",command)) {
            gmic_substitute_args();
            float valx = 100, valy = 100, valz = 100, valc = 100, cx = 0, cy = 0, cz = 0, cc = 0;
            char sep = 0, sepx = '%', sepy = '%', sepz = '%', sepc = '%';
            CImg<char> indicesy(256), indicesz(256), indicesc(256);
            CImg<unsigned int> ind, indx, indy, indz, indc;
            unsigned int boundary = 0;
            int interpolation = 1;
            *indices = *indicesy = *indicesz = *indicesc = *argx = *argy = *argz = *argc = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                              indices,&sep,&end)==2 && sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%d%c",
                             indices,&interpolation,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%d,%u%c",
                             indices,&interpolation,&boundary,&end)==3 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%d,%u,%f%c",
                             indices,&interpolation,&boundary,&cx,&end)==4 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%d,%u,%f,%f%c",
                             indices,&interpolation,&boundary,&cx,&cy,&end)==5 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%d,%u,%f,%f,%f%c",
                             indices,&interpolation,&boundary,&cx,&cy,&cz,&end)==6 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%d,%u,%f,%f,%f,%f%c",
                             indices,&interpolation,&boundary,&cx,&cy,&cz,&cc,&end)==7) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-resize",true,
                                    false,CImg<char>::empty())).height()==1 &&
                interpolation>=-1 && interpolation<=6 && boundary<=2 &&
                cx>=0 && cx<=1 && cy>=0 && cy<=1 && cz>=0 && cz<=1 && cc>=0 && cc<=1) {
              const int
                nvalx = images[*ind].width(),
                nvaly = images[*ind].height(),
                nvalz = images[*ind].depth(),
                nvalc = images[*ind].spectrum();
              print(images,"Resize image%s to %dx%dx%dx%d, with %s interpolation, "
                    "%s boundary conditions and alignment (%g,%g,%g,%g).",
                    gmic_selection,
                    nvalx,nvaly,nvalz,nvalc,
                    interpolation<=0?"no":interpolation==1?"nearest-neighbor":
                    interpolation==2?"moving average":interpolation==3?"linear":
                    interpolation==4?"grid":interpolation==5?"cubic":"lanczos",
                    boundary<=0?"dirichlet":boundary==1?"neumann":"cyclic",
                    cx,cy,cz,cc);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],resize(nvalx,nvaly,nvalz,nvalc,interpolation,
                                                       boundary,cx,cy,cz,cc));
              ++position;
            } else if ((cx=cy=cz=cc=0, interpolation=1, boundary=0, true) &&
                       (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-]%c",
                                    argx,&end)==1 ||
                        std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                                    argx,argy,&end)==2 ||
                        std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
                                    "%255[][a-zA-Z0-9_.eE%+-]%c",
                                    argx,argy,argz,&end)==3 ||
                        std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
                                    "%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                                    argx,argy,argz,argc,&end)==4 ||
                        std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
                                    "%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],%d%c",
                                    argx,argy,argz,argc,&interpolation,&end)==5 ||
                        std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
                                    "%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],%d,%u%c",
                                    argx,argy,argz,argc,&interpolation,&boundary,&end)==6 ||
                        std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
                                    "%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],%d,%u,%f%c",
                                    argx,argy,argz,argc,&interpolation,&boundary,&cx,&end)==7 ||
                        std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
                                    "%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],%d,%u,%f,"
                                    "%f%c",
                                    argx,argy,argz,argc,&interpolation,&boundary,&cx,&cy,&end)==8||
                        std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
                                    "%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],%d,%u,%f,"
                                    "%f,%f%c",
                                    argx,argy,argz,argc,&interpolation,&boundary,
                                    &cx,&cy,&cz,&end)==9 ||
                        std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
                                    "%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],%d,%u,%f,"
                                    "%f,%f,%f%c",
                                    argx,argy,argz,argc,&interpolation,&boundary,
                                    &cx,&cy,&cz,&cc,&end)==10) &&
                       ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sepx,&end)==2 &&
                         sepx==']' &&
                         (indx=selection2cimg(indices,images.size(),images_names,"-resize",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        (sepx=0,std::sscanf(argx,"%f%c",&valx,&sepx)==1 && valx>=1) ||
                        (std::sscanf(argx,"%f%c%c",&valx,&sepx,&end)==2 && sepx=='%')) &&
                       (!*argy ||
                        (std::sscanf(argy,"[%255[a-zA-Z0-9_.%+-]%c%c",indicesy.data(),&sepy,&end)==2 &&
                         sepy==']' &&
                         (indy=selection2cimg(indicesy,images.size(),images_names,"-resize",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        (sepy=0,std::sscanf(argy,"%f%c",&valy,&sepy)==1 && valy>=1) ||
                        (std::sscanf(argy,"%f%c%c",&valy,&sepy,&end)==2 && sepy=='%')) &&
                       (!*argz ||
                        (std::sscanf(argz,"[%255[a-zA-Z0-9_.%+-]%c%c",indicesz.data(),&sepz,&end)==2 &&
                         sepz==']' &&
                         (indz=selection2cimg(indicesz,images.size(),images_names,"-resize",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        (sepz=0,std::sscanf(argz,"%f%c",&valz,&sepz)==1 && valz>=1) ||
                        (std::sscanf(argz,"%f%c%c",&valz,&sepz,&end)==2 && sepz=='%')) &&
                       (!*argc ||
                        (std::sscanf(argc,"[%255[a-zA-Z0-9_.%+-]%c%c",indicesc.data(),&sepc,&end)==2 &&
                         sepc==']' &&
                         (indc=selection2cimg(indicesc,images.size(),images_names,"-resize",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        (sepc=0,std::sscanf(argc,"%f%c",&valc,&sepc)==1 && valc>=1) ||
                        (std::sscanf(argc,"%f%c%c",&valc,&sepc,&end)==2 && sepc=='%')) &&
                     valx>0 && valy>0 && valz>0 && valc>0 &&
                       interpolation>=-1 && interpolation<=6 && boundary<=2 &&
                       cx>=0 && cx<=1 && cy>=0 && cy<=1 && cz>=0 && cz<=1 && cc>=0 && cc<=1) {
              if (indx) { valx = (float)images[*indx].width(); sepx = 0; }
              if (indy) { valy = (float)images[*indy].height(); sepy = 0; }
              if (indz) { valz = (float)images[*indz].depth(); sepz = 0; }
              if (indc) { valc = (float)images[*indc].spectrum(); sepc = 0; }
              print(images,
                    "Resize image%s to %g%s%g%s%g%s%g%s, with %s interpolation, "
                    "%s boundary conditions and alignment (%g,%g,%g,%g).",
                    gmic_selection,
                    valx,sepx=='%'?"%x":"x",
                    valy,sepy=='%'?"%x":"x",
                    valz,sepz=='%'?"%x":"x",
                    valc,sepc=='%'?"% ":"",
                    interpolation<=0?"no":interpolation==1?"nearest neighbor":
                    interpolation==2?"moving average":interpolation==3?"linear":
                    interpolation==4?"grid":interpolation==5?"cubic":"lanczos",
                    boundary<=0?"dirichlet":boundary==1?"neumann":"cyclic",
                    cx,cy,cz,cc);
              cimg_forY(selection,l) {
                CImg<T>& img = images[selection[l]];
                const int
                  _nvalx = (int)cimg::round(sepx=='%'?valx*img.width()/100:valx),
                  _nvaly = (int)cimg::round(sepy=='%'?valy*img.height()/100:valy),
                  _nvalz = (int)cimg::round(sepz=='%'?valz*img.depth()/100:valz),
                  _nvalc = (int)cimg::round(sepc=='%'?valc*img.spectrum()/100:valc),
                  nvalx = _nvalx?_nvalx:1,
                  nvaly = _nvaly?_nvaly:1,
                  nvalz = _nvalz?_nvalz:1,
                  nvalc = _nvalc?_nvalc:1;
                gmic_apply(img,resize(nvalx,nvaly,nvalz,nvalc,interpolation,boundary,cx,cy,cz,cc));
              }
              ++position;
            } else {
#if cimg_display==0
              print(images,"Resize image%s in interactive mode (skipped, no display support).",
                    gmic_selection);
#else // #if cimg_display==0
# 8946 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
              bool is_available_display = false;
              try {
                is_available_display = (bool)CImgDisplay::screen_width();
              } catch (CImgDisplayException&) {
                print(images,"Resize image%s in interactive mode (skipped, no display available).",
                      gmic_selection);
              }
              if (is_available_display) {
                print(images,"Resize image%s in interactive mode.",
                      gmic_selection);
                CImgDisplay _disp, &disp = instant_window[0]?instant_window[0]:_disp;
                cimg_forY(selection,l) {
                  CImg<T>& img = gmic_check(images[selection[l]]);
                  if (img) {
                    if (disp) disp.resize(cimg_fitscreen(img.width(),img.height(),1),false);
                    else disp.assign(cimg_fitscreen(img.width(),img.height(),1),0,1);
                    disp.set_title("%s: resize",gmic_basename(images_names[selection[l]].data()));
                    img.get_select(disp,0);
                    print(images,
                          "Resize image [%d] to %dx%d, with nearest-neighbor interpolation.",
                          selection[l],
                          disp.width(),
                          disp.height());
                    gmic_apply(img,resize(disp));
                  } else { gmic_apply(img,replace(img)); }
                }
              }
#endif // #if cimg_display==0
# 8974 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            }
            is_released = false; continue;
          }

          // Reverse positions.
          if (!std::strcmp("-reverse",command)) {
            print(images,"Reverse positions of image%s.",
                  gmic_selection);
            CImgList<T> _images, nimages(selection.height());
            CImgList<char> _images_names, nimages_names(selection.height());
            if (is_get_version) { _images.assign(images); _images_names.assign(images_names); }
            cimg_forY(selection,l) {
              nimages[l].swap(images[selection[l]]);
              nimages_names[l].swap(images_names[selection[l]]);
            }
            nimages.reverse(); nimages_names.reverse();
            cimg_forY(selection,l) {
              nimages[l].swap(images[selection[l]]);
              nimages_names[l].swap(images_names[selection[l]]);
            }
            if (is_get_version) {
              _images.move_to(images,0);
              _images_names.move_to(images_names,0);
            }
            is_released = false; continue;
          }

          // Return.
          if (!std::strcmp("-return",item)) {
            if (verbosity>0 || is_debug) print(images,"Return.");
            position = commands_line.size();
            while (scope && scope.back()[0]=='*') {
              const char c = scope.back()[1];
              if (c=='d') dowhiles.remove();
              else if (c=='r') repeatdones.remove();
              else if (c=='l' || c=='>' || c=='s') break;
              scope.remove();
            }
            is_return = true;
            break;
          }

          // Keep rows.
          if (!std::strcmp("-rows",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind0, ind1;
            float value0 = 0, value1 = 0;
            char sep0 = 0, sep1 = 0;
            *argx = *argy = 0;
            if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-]%c",
                            argx,&end)==1 &&
                ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c]",indices,&sep0,&end)==2 &&
                  sep0==']' &&
                  (ind0=selection2cimg(indices,images.size(),images_names,"-rows",true,
                                       false,CImg<char>::empty())).height()==1) ||
                 std::sscanf(argx,"%f%c",&value0,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&value0,&sep0,&end)==2 && sep0=='%'))) {
              if (ind0) { value0 = images[*ind0].height() - 1.0f; sep0 = 0; }
              print(images,"Keep rows %g%s of image%s.",
                    value0,sep0=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int nvalue0 = (int)cimg::round(sep0=='%'?value0*(img.height()-1)/100:value0);
                gmic_apply(img,row(nvalue0));
              }
            } else if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                                   argx,argy,&end)==2 &&
                       ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep0,&end)==2 &&
                         sep0==']' &&
                         (ind0=selection2cimg(indices,images.size(),images_names,"-rows",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        std::sscanf(argx,"%f%c",&value0,&end)==1 ||
                        (std::sscanf(argx,"%f%c%c",&value0,&sep0,&end)==2 && sep0=='%')) &&
                       ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",formula,&sep0,&end)==2 &&
                         sep0==']' &&
                         (ind1=selection2cimg(formula,images.size(),images_names,"-rows",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        std::sscanf(argy,"%f%c",&value1,&end)==1 ||
                        (std::sscanf(argy,"%f%c%c",&value1,&sep1,&end)==2 && sep1=='%'))) {
              if (ind0) { value0 = images[*ind0].height() - 1.0f; sep0 = 0; }
              if (ind1) { value1 = images[*ind1].height() - 1.0f; sep1 = 0; }
              print(images,"Keep rows %g%s..%g%s of image%s.",
                    value0,sep0=='%'?"%":"",
                    value1,sep1=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  nvalue0 = (int)cimg::round(sep0=='%'?value0*(img.height()-1)/100:value0),
                  nvalue1 = (int)cimg::round(sep1=='%'?value1*(img.height()-1)/100:value1);
                gmic_apply(img,rows(nvalue0,nvalue1));
              }
            } else arg_error("rows");
            is_released = false; ++position; continue;
          }

          // Rotate.
          if (!std::strcmp("-rotate",command)) {
            gmic_substitute_args();
            float angle = 0, zoom = 1, cx = 0, cy = 0;
            unsigned int interpolation = 1, boundary = 0;
            char sepx = 0, sepy = 0;
            *argx = *argy = 0;
            if ((std::sscanf(argument,"%f%c",
                             &angle,&end)==1 ||
                 std::sscanf(argument,"%f,%u%c",
                             &angle,&interpolation,&end)==2 ||
                 std::sscanf(argument,"%f,%u,%u%c",
                             &angle,&interpolation,&boundary,&end)==3 ||
                 std::sscanf(argument,"%f,%u,%u,%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             &angle,&interpolation,&boundary,argx,argy,&end)==5 ||
                 std::sscanf(argument,"%f,%u,%u,%255[0-9.eE%+-],%255[0-9.eE%+-],%f%c",
                             &angle,&interpolation,&boundary,argx,argy,&zoom,&end)==6) &&
                (!*argx ||
                 std::sscanf(argx,"%f%c",&cx,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&cx,&sepx,&end)==2 && sepx=='%')) &&
                (!*argy ||
                 std::sscanf(argy,"%f%c",&cy,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&cy,&sepy,&end)==2 && sepy=='%')) &&
                interpolation<=2 && boundary<=2) {
              if (*argx) {
                print(images,"Rotate image%s of %g°, %s interpolation, %s boundary conditions "
                      "with center at (%g%s,%g%s).",
                      gmic_selection,angle,
                      interpolation==0?"nearest-neighbor":interpolation==1?"linear":"cubic",
                      boundary==0?"dirichlet":boundary==1?"neumann":"cyclic",
                      cx,sepx=='%'?"%":"",cy,sepy=='%'?"%":"");
                cimg_forY(selection,l) {
                  CImg<T> &img = images[selection[l]];
                  const float
                    ncx = sepx=='%'?cx*(img.width()-1)/100:cx,
                    ncy = sepy=='%'?cy*(img.height()-1)/100:cy;
                  gmic_apply(img,rotate(angle,ncx,ncy,zoom,interpolation,boundary));
                }
              } else {
                print(images,"Rotate image%s of %g°, %s interpolation and %s boundary conditions.",
                      gmic_selection,angle,
                      interpolation==0?"nearest-neighbor":interpolation==1?"linear":"cubic",
                      boundary==0?"dirichlet":boundary==1?"neumann":"cyclic");
                cimg_forY(selection,l)
                  gmic_apply(images[selection[l]],rotate(angle,interpolation,boundary));
              }
            } else arg_error("rotate");
            is_released = false; ++position; continue;
          }

#ifdef gmic_float

          // Round.
          if (!std::strcmp("-round",command)) {
            gmic_substitute_args();
            double rounding_value = 1;
            int rounding_type = 0;
            if ((std::sscanf(argument,"%lf%c",
                             &rounding_value,&end)==1 ||
                 std::sscanf(argument,"%lf,%d%c",
                             &rounding_value,&rounding_type,&end)==2) &&
                rounding_value>=0 && rounding_type>=-1 && rounding_type<=1) ++position;
            else { rounding_value = 1; rounding_type = 0; }
            print(images,"Round values of image%s by %g and %s rounding.",
                  gmic_selection,
                  rounding_value,
                  rounding_type<0?"backward":rounding_type>0?"forward":"nearest");
            cimg_forY(selection,l)
              gmic_apply(images[selection[l]],round(rounding_value,rounding_type));
            is_released = false; continue;
          }

          // Fill with random values.
          if (!std::strcmp("-rand",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind0, ind1;
            double value0 = 0, value1 = 0;
            char sep0 = 0, sep1 = 0;
            *argx = *argy = 0;
            if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                            argx,argy,&end)==2 &&
                ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep0,&end)==2 &&
                  sep0==']' &&
                  (ind0=selection2cimg(indices,images.size(),images_names,"-rand",true,
                                       false,CImg<char>::empty())).height()==1) ||
                 (std::sscanf(argx,"%lf%c%c",&value0,&sep0,&end)==2 && sep0=='%') ||
                 std::sscanf(argx,"%lf%c",&value0,&end)==1) &&
                ((std::sscanf(argy,"[%255[a-zA-Z0-9_.%+-]%c%c",formula,&sep1,&end)==2 &&
                  sep1==']' &&
                  (ind1=selection2cimg(formula,images.size(),images_names,"-rand",true,
                                       false,CImg<char>::empty())).height()==1) ||
                 (std::sscanf(argy,"%lf%c%c",&value1,&sep1,&end)==2 && sep1=='%') ||
                 std::sscanf(argy,"%lf%c",&value1,&end)==1)) {
              if (ind0) { value0 = images[*ind0].min(); sep0 = 0; }
              if (ind1) { value1 = images[*ind1].max(); sep1 = 0; }
              print(images,"Fill image%s with random values, in range [%g%s,%g%s].",
                    gmic_selection,
                    value0,sep0=='%'?"%":"",
                    value1,sep1=='%'?"%":"");
              cimg_forY(selection,l) {
                CImg<T>& img = gmic_check(images[selection[l]]);
                double vmin = 0, vmax = 0, nvalue0 = value0, nvalue1 = value1;
                if (sep0=='%' || sep1=='%') {
                  if (img) vmax = (double)img.max_min(vmin);
                  if (sep0=='%') nvalue0 = vmin + (vmax-vmin)*value0/100;
                  if (sep1=='%') nvalue1 = vmin + (vmax-vmin)*value1/100;
                }
                gmic_apply(img,rand((T)nvalue0,(T)nvalue1));
              }
            } else if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep0,&end)==2 &&
                       sep0==']' &&
                       (ind0=selection2cimg(indices,images.size(),images_names,"-rand",true,
                                            false,CImg<char>::empty())).height()==1) {
              if (images[*ind0]) value1 = (double)images[*ind0].max_min(value0);
              print(images,"Fill image%s with random values, in range [%g,%g] from image [%d].",
                    gmic_selection,
                    value0,
                    value1,
                    *ind0);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],rand((T)value0,(T)value1));
            } else arg_error("rand");
            is_released = false; ++position; continue;
          }

          // Rotate 3d object.
          if (!std::strcmp("-rotate3d",command)) {
            gmic_substitute_args();
            float u = 0, v = 0, w = 1, angle = 0;
            if (std::sscanf(argument,"%f,%f,%f,%f%c",
                            &u,&v,&w,&angle,&end)==4) {
              print(images,"Rotate 3d object%s around axis (%g,%g,%g), with angle %g°.",
                    gmic_selection,
                    u,v,w,
                    angle);
              const CImg<float> rot = CImg<float>::rotation_matrix(u,v,w,
                                                                   (float)(angle*cimg::PI/180));
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                CImg<T>& img = gmic_check(images[ind]);
                try { gmic_apply(img,rotate_CImg3d(rot)); }
                catch (CImgException &e) {
                  if (!img.is_CImg3d(true,message))
                    error(images,"Command '-rotate3d': Invalid 3d object [%d], "
                          "in selected image%s (%s).",
                          ind,gmic_selection,message);
                  else throw e;
                }
              }
            } else arg_error("rotate3d");
            is_released = false; ++position; continue;
          }

          // RGB to other color base.
          gmic_simple_item("-rgb2hsi",RGBtoHSI,"Convert image%s from RGB to HSI color bases.");
          gmic_simple_item("-rgb2hsl",RGBtoHSL,"Convert image%s from RGB to HSL color bases.");
          gmic_simple_item("-rgb2hsv",RGBtoHSV,"Convert image%s from RGB to HSV color bases.");
          gmic_simple_item("-rgb2lab",RGBtoLab,"Convert image%s from RGB to Lab color bases.");
          gmic_simple_item("-rgb2srgb",RGBtosRGB,"Convert image%s from RGB to sRGB color bases.");

          // Bitwise left rotation.
          gmic_arithmetic_item("-rol",
                               rol,
                               "Compute bitwise left rotation of image%s by %g%s",
                               gmic_selection,value,ssep,unsigned int,
                               rol,
                               "Compute bitwise left rotation of image%s by image [%d]",
                               gmic_selection,ind[0],
                               "Compute bitwise left rotation of image%s by expression %s",
                               gmic_selection,argument_text,
                               "Compute sequential bitwise left rotation of image%s");

          // Bitwise right rotation.
          gmic_arithmetic_item("-ror",
                               ror,
                               "Compute bitwise right rotation of image%s by %g%s",
                               gmic_selection,value,ssep,unsigned int,
                               ror,
                               "Compute bitwise right rotation of image%s by image [%d]",
                               gmic_selection,ind[0],
                               "Compute bitwise left rotation of image%s by expression %s",
                               gmic_selection,argument_text,
                               "Compute sequential bitwise left rotation of image%s");

          // Reverse 3d object orientation.
          if (!std::strcmp("-reverse3d",command)) {
            print(images,"Reverse orientation of 3d object%s.",
                  gmic_selection);
            cimg_forY(selection,l) {
              const unsigned int ind = selection[l];
              CImg<T> &img = gmic_check(images[ind]);
              try { gmic_apply(img,reverse_CImg3d()); }
              catch (CImgException &e) {
                if (!img.is_CImg3d(true,message))
                  error(images,"Command '-reverse3d': Invalid 3d object [%d], "
                        "in selected image%s (%s).",
                        ind,gmic_selection,message);
                else throw e;
              }
            }
            is_released = false; continue;
          }

#endif // #ifdef gmic_float
# 9274 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='r'.

        //----------------------------
        // Commands starting by '-s..'
        //----------------------------
        else if (command1=='s') {

          // Set status.
          if (!std::strcmp("-status",item)) {
            gmic_substitute_args();
            print(images,"Set status to '%s'.",argument_text);
            CImg<char>::string(argument).move_to(status);
            ++position; continue;
          }

          // Skip argument.
          if (!std::strcmp("-skip",item)) {
            gmic_substitute_args();
            if (verbosity>0 || is_debug)
              print(images,"Skip argument '%s'.",
                    argument_text);
            ++position;
            continue;
          }

          // Set pixel value.
          if (!std::strcmp("-set",command)) {
            gmic_substitute_args();
            char sepx = 0, sepy = 0, sepz = 0, sepc = 0;
            float x = 0, y = 0, z = 0, c = 0;
            double value = 0;
            *argx = *argy = *argz = *argc = 0;
            if ((std::sscanf(argument,"%lf%c",
                             &value,&end)==1 ||
                 std::sscanf(argument,"%lf,%255[0-9.eE%+-]%c",
                             &value,argx,&end)==2 ||
                 std::sscanf(argument,"%lf,%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             &value,argx,argy,&end)==3 ||
                 std::sscanf(argument,"%lf,%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             &value,argx,argy,argz,&end)==4 ||
                 std::sscanf(argument,"%lf,%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-]%c",
                             &value,argx,argy,argz,argc,&end)==5) &&
                (!*argx ||
                 (std::sscanf(argx,"%f%c%c",&x,&sepx,&end)==2 && sepx=='%') ||
                 std::sscanf(argx,"%f%c",&x,&end)==1) &&
                (!*argy ||
                 (std::sscanf(argy,"%f%c%c",&y,&sepy,&end)==2 && sepy=='%') ||
                 std::sscanf(argy,"%f%c",&y,&end)==1) &&
                (!*argz ||
                 (std::sscanf(argz,"%f%c%c",&z,&sepz,&end)==2 && sepz=='%') ||
                 std::sscanf(argz,"%f%c",&z,&end)==1) &&
                (!*argc ||
                 (std::sscanf(argc,"%f%c%c",&c,&sepc,&end)==2 && sepc=='%') ||
                 std::sscanf(argc,"%f%c",&c,&end)==1)) {
              print(images,"Set value %g in image%s, at coordinates (%g%s,%g%s,%g%s,%g%s).",
                    value,
                    gmic_selection,
                    x,sepx=='%'?"%":"",
                    y,sepy=='%'?"%":"",
                    z,sepz=='%'?"%":"",
                    c,sepc=='%'?"%":"");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  nx = (int)cimg::round(sepx=='%'?x*(img.width()-1)/100:x),
                  ny = (int)cimg::round(sepy=='%'?y*(img.height()-1)/100:y),
                  nz = (int)cimg::round(sepz=='%'?z*(img.depth()-1)/100:z),
                  nc = (int)cimg::round(sepc=='%'?c*(img.spectrum()-1)/100:c);
                gmic_apply(images[selection[l]],gmic_set(value,nx,ny,nz,nc));
              }
            } else arg_error("set");
            is_released = false; ++position; continue;
          }

          // Split.
          if (!std::strcmp("-split",command)) {
            gmic_substitute_args();
            const char *axis_arg = 0;
            char keep_values = '+';
            CImgList<char> axes;
            float nb = 0;
            for (axis_arg = argument; *axis_arg && *axis_arg!=','; ++axis_arg) {
              const char _s = *axis_arg;
              if (_s!='x' && _s!='y' && _s!='z' && _s!='c') { axis_arg = 0; break; }
              CImg<char>::vector(_s).move_to(axes);
            }
            if (axis_arg && *axis_arg==',') {
              if (std::sscanf(++axis_arg,"%f%c",&nb,&end)!=1) axis_arg = 0;
              else nb = cimg::round(nb);
            }
            if (axes && axis_arg) {
              const CImg<char> _axes = (axes,CImg<char>::vector(0))>'x';
              axes.remove();
              if (nb>0)
                print(images,"Split image%s along the '%s'-ax%cs, into %g parts.",
                      gmic_selection,
                      _axes.data(),
                      axes.size()>1?'e':'i',
                      nb);
              else if (nb<0)
                print(images,"Split image%s along the '%s'-ax%cs, into blocs of %g pixels.",
                      gmic_selection,
                      _axes.data(),
                      axes.size()>1?'e':'i',
                      -nb);
              else
                print(images,"Split image%s along the '%s'-ax%cs.",
                      gmic_selection,
                      _axes.data(),
                      axes.size()>1?'e':'i');
              int off = 0;
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l] + off;
                const CImg<T>& img = gmic_check(images[ind]);
                if (!img) {
                  if (!is_get_version) { images.remove(ind); images_names.remove(ind); off-=1; }
                } else {
                  CImg<char> name = images_names[ind].get_mark();
                  CImgList<T> split(img,true);
                  cimglist_for(axes,i) {
                    const unsigned int N = split.size();
                    for (unsigned int l = 0; l<N; ++l) {
                      split[0].get_split(axes(i,0),(int)nb).move_to(split,~0U);
                      split.remove(0);
                    }
                  }
                  if (is_get_version) {
                    images_names.insert(split.size(),name.copymark());
                    split.move_to(images,~0U);
                  } else {
                    images.remove(ind); images_names.remove(ind);
                    off+=(int)split.size() - 1;
                    images_names.insert(split.size(),name.get_copymark(),ind);
                    name.move_to(images_names[ind]);
                    split.move_to(images,ind);
                  }
                }
              }
              ++position;
            } else if ((std::sscanf(argument,"%c,%c",
                                    &keep_values,&end)==2) &&
                       (keep_values=='+' || keep_values=='-')) {
              print(images,"Split image%s in %s mode, according to value sequence '%s'.",
                    gmic_selection,
                    keep_values=='-'?"discard":"keep",
                    argument_text+2);
              unsigned int nb_values = 1;
              int off = 0;
              for (const char *s = argument+2; *s; ++s) if (*s==',') ++nb_values;
              const CImg<T> values(nb_values,1,1,1,argument+2,true);
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l] + off;
                const CImg<T>& img = gmic_check(images[ind]);
                if (!img) {
                  if (!is_get_version) { images.remove(ind); images_names.remove(ind); off-=1; }
                } else {
                  CImg<char> name = images_names[ind].get_mark();
                  CImgList<T> split = img.get_split(values,keep_values=='+',false);
                  if (is_get_version) {
                    if (split) {
                      images_names.insert(split.size(),name.copymark());
                      split.move_to(images,~0U);
                    }
                  } else {
                    images.remove(ind);
                    images_names.remove(ind);
                    if (split) {
                      off+=(int)split.size() - 1;
                      images_names.insert(split.size(),name.get_copymark(),ind);
                      name.move_to(images_names[ind]);
                      split.move_to(images,ind);
                    }
                  }
                }
              }
              ++position;
            } else {
              print(images,"Split image%s as a set of constant sub-vectors.",
                    gmic_selection);
              int off = 0;
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l] + off;
                const CImg<T>& img = gmic_check(images[ind]);
                if (!img) {
                  if (!is_get_version) { images.remove(ind); images_names.remove(ind); off-=1; }
                } else {
                  CImg<char> name = images_names[ind].get_mark();
                  CImgList<T> split = img.get_split(false);
                  if (is_get_version) {
                    if (split) {
                      images_names.insert(split.size(),name.copymark());
                      split.move_to(images,~0U);
                    }
                  } else {
                    images.remove(ind);
                    images_names.remove(ind);
                    if (split) {
                      off+=(int)split.size() - 1;
                      images_names.insert(split.size(),name.get_copymark(),ind);
                      name.move_to(images_names[ind]);
                      split.move_to(images,ind);
                    }
                  }
                }
              }
            }
            is_released = false; continue;
          }

          // Shared input.
          if (!std::strcmp("-shared",command)) {
            gmic_substitute_args();
            CImg<char> st0(256), st1(256), st2(256), st3(256), st4(256);
            char sep0 = 0, sep1 = 0, sep2 = 0, sep3 = 0, sep4 = 0;
            float a0 = 0, a1 = 0, a2 = 0, a3 = 0, a4 = 0;
            *st0 = *st1 = *st2 = *st3 = *st4 = 0;
            if (std::sscanf(argument,
                            "%255[0-9.eE%+],%255[0-9.eE%+],%255[0-9.eE%+],%255[0-9.eE%+],"
                            "%255[0-9.eE%+]%c",
                            st0.data(),st1.data(),st2.data(),st3.data(),st4.data(),&end)==5 &&
                (std::sscanf(st0,"%f%c",&a0,&end)==1 ||
                 (std::sscanf(st0,"%f%c%c",&a0,&sep0,&end)==2 && sep0=='%')) &&
                (std::sscanf(st1,"%f%c",&a1,&end)==1 ||
                 (std::sscanf(st1,"%f%c%c",&a1,&sep1,&end)==2 && sep1=='%')) &&
                (std::sscanf(st2,"%f%c",&a2,&end)==1 ||
                 (std::sscanf(st2,"%f%c%c",&a2,&sep2,&end)==2 && sep2=='%')) &&
                (std::sscanf(st3,"%f%c",&a3,&end)==1 ||
                 (std::sscanf(st3,"%f%c%c",&a3,&sep3,&end)==2 && sep3=='%')) &&
                (std::sscanf(st4,"%f%c",&a4,&end)==1 ||
                 (std::sscanf(st4,"%f%c%c",&a4,&sep4,&end)==2 && sep4=='%'))) {
              print(images,
                    "Insert shared buffer%s from points (%g%s->%g%s,%g%s,%g%s,%g%s) of image%s.",
                    selection.height()>1?"s":"",
                    a0,sep0=='%'?"%":"",
                    a1,sep1=='%'?"%":"",
                    a2,sep2=='%'?"%":"",
                    a3,sep3=='%'?"%":"",
                    a4,sep4=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T>& img = images[selection[l]];
                const unsigned int
                  s0 = (unsigned int)cimg::round(sep0=='%'?a0*(img.width()-1)/100:a0),
                  s1 = (unsigned int)cimg::round(sep1=='%'?a1*(img.width()-1)/100:a1),
                  y =  (unsigned int)cimg::round(sep2=='%'?a2*(img.height()-1)/100:a2),
                  z =  (unsigned int)cimg::round(sep3=='%'?a3*(img.depth()-1)/100:a3),
                  c =  (unsigned int)cimg::round(sep4=='%'?a4*(img.spectrum()-1)/100:a4);
                images.insert(img.get_shared_points(s0,s1,y,z,c),~0U,true);
                images_names.insert(images_names[selection[l]].get_copymark());
              }
              ++position;
            } else if (std::sscanf(argument,
                                   "%255[0-9.eE%+],%255[0-9.eE%+],%255[0-9.eE%+],"
                                   "%255[0-9.eE%+],%c",
                                   st0.data(),st1.data(),st2.data(),st3.data(),&end)==4 &&
                       (std::sscanf(st0,"%f%c",&a0,&end)==1 ||
                        (std::sscanf(st0,"%f%c%c",&a0,&sep0,&end)==2 && sep0=='%')) &&
                       (std::sscanf(st1,"%f%c",&a1,&end)==1 ||
                        (std::sscanf(st1,"%f%c%c",&a1,&sep1,&end)==2 && sep1=='%')) &&
                       (std::sscanf(st2,"%f%c",&a2,&end)==1 ||
                        (std::sscanf(st2,"%f%c%c",&a2,&sep2,&end)==2 && sep2=='%')) &&
                       (std::sscanf(st3,"%f%c",&a3,&end)==1 ||
                        (std::sscanf(st3,"%f%c%c",&a3,&sep3,&end)==2 && sep3=='%'))) {
              print(images,"Insert shared buffer%s from lines (%g%s->%g%s,%g%s,%g%s) of image%s.",
                    selection.height()>1?"s":"",
                    a0,sep0=='%'?"%":"",
                    a1,sep1=='%'?"%":"",
                    a2,sep2=='%'?"%":"",
                    a3,sep3=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T>& img = images[selection[l]];
                const unsigned int
                  s0 = (unsigned int)cimg::round(sep0=='%'?a0*(img.height()-1)/100:a0),
                  s1 = (unsigned int)cimg::round(sep1=='%'?a1*(img.height()-1)/100:a1),
                  z =  (unsigned int)cimg::round(sep2=='%'?a2*(img.depth()-1)/100:a2),
                  c =  (unsigned int)cimg::round(sep3=='%'?a3*(img.spectrum()-1)/100:a3);
                images.insert(img.get_shared_rows(s0,s1,z,c),~0U,true);
                images_names.insert(images_names[selection[l]].get_copymark());
              }
              ++position;
            } else if (std::sscanf(argument,"%255[0-9.eE%+],%255[0-9.eE%+],%255[0-9.eE%+]%c",
                                   st0.data(),st1.data(),st2.data(),&end)==3 &&
                       (std::sscanf(st0,"%f%c",&a0,&end)==1 ||
                        (std::sscanf(st0,"%f%c%c",&a0,&sep0,&end)==2 && sep0=='%')) &&
                       (std::sscanf(st1,"%f%c",&a1,&end)==1 ||
                        (std::sscanf(st1,"%f%c%c",&a1,&sep1,&end)==2 && sep1=='%')) &&
                       (std::sscanf(st2,"%f%c",&a2,&end)==1 ||
                        (std::sscanf(st2,"%f%c%c",&a2,&sep2,&end)==2 && sep2=='%'))) {
              print(images,"Insert shared buffer%s from planes (%g%s->%g%s,%g%s) of image%s.",
                    selection.height()>1?"s":"",
                    a0,sep0=='%'?"%":"",
                    a1,sep1=='%'?"%":"",
                    a2,sep2=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T>& img = images[selection[l]];
                const unsigned int
                  s0 = (unsigned int)cimg::round(sep0=='%'?a0*(img.depth()-1)/100:a0),
                  s1 = (unsigned int)cimg::round(sep1=='%'?a1*(img.depth()-1)/100:a1),
                  c =  (unsigned int)cimg::round(sep2=='%'?a2*(img.spectrum()-1)/100:a2);
                images.insert(img.get_shared_slices(s0,s1,c),~0U,true);
                images_names.insert(images_names[selection[l]].get_copymark());
              }
              ++position;
            } else if (std::sscanf(argument,"%255[0-9.eE%+],%255[0-9.eE%+]%c",
                                   st0.data(),st1.data(),&end)==2 &&
                       (std::sscanf(st0,"%f%c",&a0,&end)==1 ||
                        (std::sscanf(st0,"%f%c%c",&a0,&sep0,&end)==2 && sep0=='%')) &&
                       (std::sscanf(st1,"%f%c",&a1,&end)==1 ||
                        (std::sscanf(st1,"%f%c%c",&a1,&sep1,&end)==2 && sep1=='%'))) {
              print(images,"Insert shared buffer%s from channels (%g%s->%g%s) of image%s.",
                    selection.height()>1?"s":"",
                    a0,sep0=='%'?"%":"",
                    a1,sep1=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T>& img = images[selection[l]];
                const unsigned int
                  s0 = (unsigned int)cimg::round(sep0=='%'?a0*(img.spectrum()-1)/100:a0),
                  s1 = (unsigned int)cimg::round(sep1=='%'?a1*(img.spectrum()-1)/100:a1);
                images.insert(img.get_shared_channels(s0,s1),~0U,true);
                images_names.insert(images_names[selection[l]].get_copymark());
              }
              ++position;
            } else {
              print(images,"Insert shared buffer%s from image%s.",
                    selection.height()>1?"s":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                images.insert(img,~0U,true);
                images_names.insert(images_names[selection[l]].get_copymark());
              }
            }
            is_released = false; continue;
          }

          // Shift.
          if (!std::strcmp("-shift",command)) {
            gmic_substitute_args();
            char sepx = 0, sepy = 0, sepz = 0, sepc = 0;
            float dx = 0, dy = 0, dz = 0, dc = 0;
            unsigned int boundary = 0;
            *argx = *argy = *argz = *argc = 0;
            if ((std::sscanf(argument,"%255[0-9.eE%+-]%c",
                             argx,&end)==1 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             argx,argy,&end)==2 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             argx,argy,argz,&end)==3 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-]%c",
                             argx,argy,argz,argc,&end)==4 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-],%u%c",
                             argx,argy,argz,argc,&boundary,&end)==5) &&
                (std::sscanf(argx,"%f%c",&dx,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&dx,&sepx,&end)==2 && sepx=='%')) &&
                (!*argy ||
                 std::sscanf(argy,"%f%c",&dy,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&dy,&sepy,&end)==2 && sepy=='%')) &&
                (!*argz ||
                 std::sscanf(argz,"%f%c",&dz,&end)==1 ||
                 (std::sscanf(argz,"%f%c%c",&dz,&sepz,&end)==2 && sepz=='%')) &&
                (!*argc ||
                 std::sscanf(argc,"%f%c",&dc,&end)==1 ||
                 (std::sscanf(argc,"%f%c%c",&dc,&sepc,&end)==2 && sepc=='%')) &&
                boundary<=2) {
              print(images,
                    "Shift image%s by displacement vector (%g%s,%g%s,%g%s,%g%s) and "
                    "%s boundary conditions.",
                    gmic_selection,
                    dx,sepx=='%'?"%":"",
                    dy,sepy=='%'?"%":"",
                    dz,sepz=='%'?"%":"",
                    dc,sepc=='%'?"%":"",
                    boundary==0?"dirichlet":boundary==1?"neumann":"cyclic");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  ndx = (int)cimg::round(sepx=='%'?dx*img.width()/100:dx),
                  ndy = (int)cimg::round(sepy=='%'?dy*img.height()/100:dy),
                  ndz = (int)cimg::round(sepz=='%'?dz*img.depth()/100:dz),
                  ndc = (int)cimg::round(sepc=='%'?dc*img.spectrum()/100:dc);
                gmic_apply(images[selection[l]],shift(ndx,ndy,ndz,ndc,boundary));
              }
            } else arg_error("shift");
            is_released = false; ++position; continue;
          }

          // Keep slices.
          if (!std::strcmp("-slices",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind0, ind1;
            float value0 = 0, value1 = 0;
            char sep0 = 0, sep1 = 0;
            *argx = *argy = 0;
            if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-]%c",
                            argx,&end)==1 &&
                ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c]",indices,&sep0,&end)==2 &&
                  sep0==']' &&
                  (ind0=selection2cimg(indices,images.size(),images_names,"-slices",true,
                                       false,CImg<char>::empty())).height()==1) ||
                 std::sscanf(argx,"%f%c",&value0,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&value0,&sep0,&end)==2 && sep0=='%'))) {
              if (ind0) { value0 = images[*ind0].depth() - 1.0f; sep0 = 0; }
              print(images,"Keep slice %g%s of image%s.",
                    value0,sep0=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int nvalue0 = (int)cimg::round(sep0=='%'?value0*(img.depth()-1)/100:value0);
                gmic_apply(img,slice(nvalue0));
              }
            } else if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                                   argx,argy,&end)==2 &&
                       ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep0,&end)==2 &&
                         sep0==']' &&
                         (ind0=selection2cimg(indices,images.size(),images_names,"-slices",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        std::sscanf(argx,"%f%c",&value0,&end)==1 ||
                        (std::sscanf(argx,"%f%c%c",&value0,&sep0,&end)==2 && sep0=='%')) &&
                       ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",formula,&sep0,&end)==2 &&
                         sep0==']' &&
                         (ind1=selection2cimg(formula,images.size(),images_names,"-slices",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        std::sscanf(argy,"%f%c",&value1,&end)==1 ||
                        (std::sscanf(argy,"%f%c%c",&value1,&sep1,&end)==2 && sep1=='%'))) {
              if (ind0) { value0 = images[*ind0].depth() - 1.0f; sep0 = 0; }
              if (ind1) { value1 = images[*ind1].depth() - 1.0f; sep1 = 0; }
              print(images,"Keep slices %g%s..%g%s of image%s.",
                    value0,sep0=='%'?"%":"",
                    value1,sep1=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  nvalue0 = (int)cimg::round(sep0=='%'?value0*(img.depth()-1)/100:value0),
                  nvalue1 = (int)cimg::round(sep1=='%'?value1*(img.depth()-1)/100:value1);
                gmic_apply(img,slices(nvalue0,nvalue1));
              }
            } else arg_error("slices");
            is_released = false; ++position; continue;
          }

          // Set random generator seed.
          if (!std::strcmp("-srand",item)) {
            gmic_substitute_args();
            double value = 0;
            if (std::sscanf(argument,"%lf%c",
                            &value,&end)==1) {
              value = cimg::round(value);
              print(images,"Set random generator seed to %u.",
                    (unsigned int)value);
              cimg::srand((unsigned int)value);
              ++position;
            } else {
              print(images,"Set random generator seed to random.");
              cimg::srand();
            }
            continue;
          }

#ifdef gmic_float

          // Sub.
          gmic_arithmetic_item("-sub",
                               operator-=,
                               "Subtract %g%s to image%s",
                               value,ssep,gmic_selection,Tfloat,
                               operator-=,
                               "Subtract image [%d] to image%s",
                               ind[0],gmic_selection,
                               "Subtract expression %s to image%s",
                               argument_text,gmic_selection,
                               "Subtract image%s");
          // Square root.
          gmic_simple_item("-sqrt",sqrt,"Compute pointwise square root of image%s.");

          // Square.
          gmic_simple_item("-sqr",sqr,"Compute pointwise square function of image%s.");

          // Sign.
          gmic_simple_item("-sign",sign,"Compute pointwise sign of image%s.");

          // Sine.
          gmic_simple_item("-sin",sin,"Compute pointwise sine of image%s.");

          // Sort.
          if (!std::strcmp("-sort",command)) {
            gmic_substitute_args();
            char order = '+', axis = 0;
            if ((std::sscanf(argument,"%c%c",&order,&end)==1 ||
                 (std::sscanf(argument,"%c,%c%c",&order,&axis,&end)==2 &&
                  (axis=='x' || axis=='y' || axis=='z' || axis=='c'))) &&
                (order=='+' || order=='-')) ++position;
            else { order = '+'; axis = 0; }
            if (axis) print(images,"Sort values of image%s in %s order, according to axis '%c'.",
                            gmic_selection,order=='+'?"ascending":"descending",axis);
            else print(images,"Sort values of image%s in %s order.",
                       gmic_selection,order=='+'?"ascending":"descending");
            cimg_forY(selection,l) gmic_apply(images[selection[l]],sort(order=='+',axis));
            is_released = false; continue;
          }

          // Solve.
          if (!std::strcmp("-solve",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind;
            char sep = 0;
            if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 &&
                sep==']' &&
                (ind=selection2cimg(indices,images.size(),images_names,"-solve",true,
                                    false,CImg<char>::empty())).height()==1) {
              print(images,"Solve linear system AX = B, with B-vector%s and A-matrix [%d].",
                    gmic_selection,*ind);
              const CImg<T> A = gmic_image_arg(*ind);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],solve(A));
            } else arg_error("solve");
            is_released = false; ++position; continue;
          }

          // Shift 3d object, with opposite displacement.
          if (!std::strcmp("-sub3d",command)) {
            gmic_substitute_args();
            float tx = 0, ty = 0, tz = 0;
            if (std::sscanf(argument,"%f%c",
                            &tx,&end)==1 ||
                std::sscanf(argument,"%f,%f%c",
                            &tx,&ty,&end)==2 ||
                std::sscanf(argument,"%f,%f,%f%c",
                            &tx,&ty,&tz,&end)==3) {
              print(images,"Shift 3d object%s with displacement -(%g,%g,%g).",
                    gmic_selection,
                    tx,ty,tz);
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                CImg<T>& img = gmic_check(images[ind]);
                try { gmic_apply(img,shift_CImg3d(-tx,-ty,-tz)); }
                catch (CImgException &e) {
                  if (!img.is_CImg3d(true,message))
                    error(images,
                          "Command '-sub3d': Invalid 3d object [%d], in selected image%s (%s).",
                          ind,gmic_selection,message);
                  else throw e;
                }
              }
            } else arg_error("sub3d");
            is_released = false; ++position; continue;
          }

          // Sharpen.
          if (!std::strcmp("-sharpen",command)) {
            gmic_substitute_args();
            float amplitude = 0, edge = -1, alpha = 0, sigma = 0;
            if ((std::sscanf(argument,"%f%c",
                             &amplitude,&end)==1 ||
                 std::sscanf(argument,"%f,%f%c",
                             &amplitude,&edge,&end)==2 ||
                 std::sscanf(argument,"%f,%f,%f%c",
                             &amplitude,&edge,&alpha,&end)==3 ||
                 std::sscanf(argument,"%f,%f,%f,%f%c",
                             &amplitude,&edge,&alpha,&sigma,&end)==4) &&
                amplitude>=0 && (edge==-1 || edge>=0)) {
              if (edge>=0)
                print(images,"Sharpen image%s with shock filters, amplitude %g, edge %g, "
                      "alpha %g and sigma %g.",
                      gmic_selection,
                      amplitude,
                      edge,
                      alpha,
                      sigma);
              else
                print(images,"Sharpen image%s with inverse diffusion and amplitude %g.",
                      gmic_selection,
                      amplitude);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],sharpen(amplitude,(bool)(edge>=0),
                                                        edge,alpha,sigma));
            } else arg_error("sharpen");
            is_released = false; ++position; continue;
          }

          // Anisotropic PDE-based smoothing.
          if (!std::strcmp("-smooth",command)) {
            gmic_substitute_args();
            float amplitude = 0, sharpness = 0.7f, anisotropy = 0.3f, alpha = 0.6f,
              sigma = 1.1f, dl =0.8f, da = 30.0f, gauss_prec = 2.0f;
            unsigned int interpolation = 0, is_fast_approximation = 1;
            CImg<unsigned int> ind;
            char sep = 0;
            if ((std::sscanf(argument,"%f%c",
                             &amplitude,&end)==1 ||
                 std::sscanf(argument,"%f,%f%c",
                             &amplitude,&sharpness,&end)==2 ||
                 std::sscanf(argument,"%f,%f,%f%c",
                             &amplitude,&sharpness,&anisotropy,&end)==3 ||
                 std::sscanf(argument,"%f,%f,%f,%f%c",
                             &amplitude,&sharpness,&anisotropy,&alpha,&end)==4 ||
                 std::sscanf(argument,"%f,%f,%f,%f,%f%c",
                             &amplitude,&sharpness,&anisotropy,&alpha,&sigma,&end)==5 ||
                 std::sscanf(argument,"%f,%f,%f,%f,%f,%f%c",
                             &amplitude,&sharpness,&anisotropy,&alpha,&sigma,&dl,&end)==6 ||
                 std::sscanf(argument,"%f,%f,%f,%f,%f,%f,%f%c",
                             &amplitude,&sharpness,&anisotropy,&alpha,&sigma,&dl,&da,&end)==7 ||
                 std::sscanf(argument,"%f,%f,%f,%f,%f,%f,%f,%f%c",
                             &amplitude,&sharpness,&anisotropy,&alpha,&sigma,&dl,&da,&gauss_prec,
                             &end)==8 ||
                 std::sscanf(argument,"%f,%f,%f,%f,%f,%f,%f,%f,%u%c",
                             &amplitude,&sharpness,&anisotropy,&alpha,&sigma,&dl,&da,&gauss_prec,
                             &interpolation,&end)==9 ||
                 std::sscanf(argument,"%f,%f,%f,%f,%f,%f,%f,%f,%u,%u%c",
                             &amplitude,&sharpness,&anisotropy,&alpha,&sigma,&dl,&da,&gauss_prec,
                             &interpolation,&is_fast_approximation,&end)==10) &&
                amplitude>=0 && sharpness>=0 && anisotropy>=0 && anisotropy<=1 && dl>0 &&
                da>=0 && gauss_prec>0 && interpolation<=2 && is_fast_approximation<=1) {
              if (da>0)
                print(images,"Smooth image%s anisotropically, with amplitude %g, sharpness %g, "
                      "anisotropy %g, alpha %g, sigma %g, dl %g, da %g, precision %g, "
                      "%s interpolation and fast approximation %s.",
                      gmic_selection,
                      amplitude,
                      sharpness,
                      anisotropy,
                      alpha,
                      sigma,
                      dl,
                      da,
                      gauss_prec,
                      interpolation==0?"nearest-neighbor":interpolation==1?"linear":"runge-kutta",
                      is_fast_approximation?"enabled":"disabled");
              else
                print(images,"Smooth image%s anisotropically, with %d iterations, sharpness %g, "
                      "anisotropy %g, alpha %g, sigma %g and dt %g.",
                      gmic_selection,
                      (int)amplitude,
                      sharpness,
                      anisotropy,
                      alpha,
                      sigma,
                      dl);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],blur_anisotropic(amplitude,sharpness,anisotropy,
                                                                 alpha,sigma,dl,da,gauss_prec,
                                                                 interpolation,
                                                                 (bool)is_fast_approximation));
            } else if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                                     indices,&sep,&end)==2 && sep==']') ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f%c",
                                    indices,&amplitude,&end)==2 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f%c",
                                    indices,&amplitude,&dl,&end)==3 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f%c",
                                    indices,&amplitude,&dl,&da,&end)==4 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f%c",
                                    indices,&amplitude,&dl,&da,&gauss_prec,&end)==5 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f,%u%c",
                                    indices,&amplitude,&dl,&da,&gauss_prec,
                                    &interpolation,&end)==6 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f,%u,%u%c",
                                    indices,&amplitude,&dl,&da,&gauss_prec,&interpolation,
                                    &is_fast_approximation,&end)==7) &&
                       (ind=selection2cimg(indices,images.size(),images_names,"-smooth",true,
                                           false,CImg<char>::empty())).height()==1 &&
                       amplitude>=0 && dl>0 && da>=0 && gauss_prec>0 && interpolation<=2 &&
                       is_fast_approximation<=1) {
              const CImg<T> tensors = gmic_image_arg(*ind);
              if (da>0)
                print(images,
                      "Smooth image%s anisotropically, with tensor field [%u], amplitude %g, "
                      "dl %g, da %g, precision %g, %s interpolation and fast approximation %s.",
                      gmic_selection,
                      *ind,
                      amplitude,
                      dl,
                      da,
                      gauss_prec,
                      interpolation==0?"nearest-neighbor":interpolation==1?"linear":"runge-kutta",
                      is_fast_approximation?"enabled":"disabled");
              else
                print(images,
                      "Smooth image%s anisotropically, with tensor field [%u], %d iterations "
                      "and dt %g.",
                      gmic_selection,
                      *ind,
                      (int)amplitude,
                      dl);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],blur_anisotropic(tensors,amplitude,dl,da,
                                                                 gauss_prec,interpolation,
                                                                 is_fast_approximation));
            } else arg_error("smooth");
            is_released = false; ++position; continue;
          }

          // Split 3d objects, into 6 vector images
          // { header,N,vertices,primitives,colors,opacities }
          if (!std::strcmp("-split3d",command)) {
            bool keep_shared = true;
            gmic_substitute_args();
            if ((*argument=='0' || *argument=='1') && !argument[1]) {
              keep_shared = *argument=='1';
              ++position;
            }
            print(images,"Split 3d object%s into 6 property vectors%s.",
                  gmic_selection,
                  keep_shared?"":" and clone shared data");
            unsigned int off = 0;
            cimg_forY(selection,l) {
              const unsigned int ind = selection[l] + off;
              const CImg<T> &img = gmic_check(images[ind]);
              CImg<char> name = images_names[ind].get_mark();
              CImgList<T> split;
              try {
                if (!keep_shared) {
                  CImg<T> vertices;
                  CImgList<unsigned int> primitives;
                  CImgList<T> colors, opacities;
                  img.get_CImg3dtoobject3d(primitives,colors,opacities,false).move_to(vertices);
                  CImgList<T> _colors(colors,false), _opacities(opacities,false);
                  _colors.move_to(colors.assign());
                  _opacities.move_to(opacities.assign());
                  vertices.object3dtoCImg3d(primitives,colors,opacities,false).get_split_CImg3d().
                    move_to(split);
                } else img.get_split_CImg3d().move_to(split);
              } catch (CImgException &e) {
                if (!img.is_CImg3d(true,message))
                  error(images,
                        "Command '-split3d': Invalid 3d object [%d], in selected image%s (%s).",
                        ind-off,gmic_selection,message);
                else throw e;
              }
              if (is_get_version) {
                images_names.insert(split.size(),name.copymark());
                split.move_to(images,~0U);
              } else {
                images.remove(ind);
                images_names.remove(ind);
                off+=split.size() - 1;
                images_names.insert(split.size(),name.get_copymark(),ind);
                name.move_to(images_names[ind]);
                split.move_to(images,ind);
              }
            }
            is_released = false; continue;
          }

          // SVD.
          if (!std::strcmp("-svd",command)) {
            print(images,"Compute SVD decomposition%s of matri%s%s.",
                  selection.height()>1?"s":"",selection.height()>1?"ce":"x",gmic_selection);
            CImg<float> U, S, V;
            unsigned int off = 0;
            cimg_forY(selection,l) {
              const unsigned int ind = selection[l] + off;
              const CImg<T>& img = gmic_check(images[ind]);
              CImg<char> name = images_names[ind].get_mark();
              img.SVD(U,S,V,true,100);
              if (is_get_version) {
                images_names.insert(2,name.copymark());
                name.move_to(images_names);
                U.move_to(images);
                S.move_to(images);
                V.move_to(images);
              } else {
                images_names.insert(2,name.get_copymark(),ind+1);
                name.move_to(images_names[ind]);
                U.move_to(images[ind].assign());
                images.insert(S,ind+1);
                images.insert(V,ind+2);
                off+=2;
              }
            }
            is_released = false; continue;
          }

          // Input 3d sphere.
          if (!std::strcmp("-sphere3d",item)) {
            gmic_substitute_args();
            float radius = 100, recursions = 3;
            if ((std::sscanf(argument,"%f%c",
                             &radius,&end)==1 ||
                 std::sscanf(argument,"%f,%f%c",
                             &radius,&recursions,&end)==2) &&
                recursions>=0) {
              recursions = cimg::round(recursions);
              print(images,"Input 3d sphere, with radius %g and %g recursions.",
                    radius,
                    recursions);
              CImgList<unsigned int> primitives;
              CImg<float> vertices = CImg<T>::sphere3d(primitives,radius,(unsigned int)recursions);
              vertices.object3dtoCImg3d(primitives,false).move_to(images);
              CImg<char>::string("[3d sphere]").move_to(images_names);
            } else arg_error("sphere3d");
            is_released = false; ++position; continue;
          }

          // Set 3d specular light parameters.
          if (!std::strcmp("-specl3d",item)) {
            gmic_substitute_args();
            float value = 0.15f;
            if (std::sscanf(argument,"%f%c",
                            &value,&end)==1 && value>=0) ++position;
            else value = 0.15f;
            specular_lightness3d = value;
            print(images,"Set lightness of 3d specular light to %g.",
                  specular_lightness3d);
            continue;
          }

          if (!std::strcmp("-specs3d",item)) {
            gmic_substitute_args();
            float value = 0.8f;
            if (std::sscanf(argument,"%f%c",
                            &value,&end)==1 && value>=0) ++position;
            else value = 0.8f;
            specular_shininess3d = value;
            print(images,"Set shininess of 3d specular light to %g.",
                  specular_shininess3d);
            continue;
          }

          // Sine-cardinal.
          gmic_simple_item("-sinc",sinc,"Compute pointwise sinc function of image%s.");

          // Hyperbolic sine.
          gmic_simple_item("-sinh",sinh,"Compute pointwise hyperpolic sine of image%s.");

          // sRGB to RGB.
          gmic_simple_item("-srgb2rgb",sRGBtoRGB,"Convert image%s from sRGB to RGB color bases.");

          // Extract 3d streamline.
          if (!std::strcmp("-streamline3d",command)) {
            gmic_substitute_args();
            unsigned int interp = 2, is_backward = 0, is_oriented_only = 0;
            float x = 0, y = 0, z = 0, L = 100, dl = 0.1f;
            char sepx = 0, sepy = 0, sepz = 0;
            *formula = 0;
            if ((std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             argx,argy,argz,&end)==3 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f%c",
                             argx,argy,argz,&L,&end)==4 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f,%f%c",
                             argx,argy,argz,&L,&dl,&end)==5 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f,%f,%u%c",
                             argx,argy,argz,&L,&dl,&interp,&end)==6 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f,%f,%u,"
                             "%u%c",
                             argx,argy,argz,&L,&dl,&interp,&is_backward,&end)==7 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f,%f,%u,"
                             "%u,%u%c",
                             argx,argy,argz,&L,&dl,&interp,&is_backward,
                             &is_oriented_only,&end)==8) &&
                (std::sscanf(argx,"%f%c",&x,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&x,&sepx,&end)==2 && sepx=='%')) &&
                (!*argy ||
                 std::sscanf(argy,"%f%c",&y,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&y,&sepy,&end)==2 && sepy=='%')) &&
                (!*argz ||
                 std::sscanf(argz,"%f%c",&z,&end)==1 ||
                 (std::sscanf(argz,"%f%c%c",&z,&sepz,&end)==2 && sepz=='%')) &&
                L>=0 && dl>0 && interp<4 && is_backward<=1 && is_oriented_only<=1) {
              print(images,"Extract 3d streamline from image%s, starting from (%g%s,%g%s,%g%s).",
                    gmic_selection,
                    x,sepx=='%'?"%":"",
                    y,sepy=='%'?"%":"",
                    z,sepz=='%'?"%":"");
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                CImg<T>& img = gmic_check(images[ind]);
                const float
                  nx = cimg::round(sepx=='%'?x*(img.width()-1)/100:x),
                  ny = cimg::round(sepy=='%'?y*(img.height()-1)/100:y),
                  nz = cimg::round(sepz=='%'?z*(img.depth()-1)/100:z);
                CImg<T> vertices = img.get_streamline(nx,ny,nz,L,dl,interp,
                                                      (bool)is_backward,(bool)is_oriented_only);
                CImgList<unsigned int> primitives;
                CImgList<unsigned char> colors;
                if (vertices.width()>1) {
                  primitives.assign(vertices.width()-1,1,2);
                  cimglist_for(primitives,l) { primitives(l,0) = l; primitives(l,1) = l+1; }
                  colors.assign(primitives.size(),1,3,1,1,200);
                } else {
                  vertices.assign();
                  warn(images,
                       "Command '-streamline3d': Empty streamline starting from "
                       "(%g%s,%g%s,%g%s) in image [%u].",
                       x,sepx=='%'?"%":"",
                       y,sepy=='%'?"%":"",
                       z,sepz=='%'?"%":"",
                       ind);
                }
                vertices.object3dtoCImg3d(primitives,colors,false);
                gmic_apply(img,replace(vertices));
              }
            } else if ((std::sscanf(argument,"'%4095[^']',%f,%f,%f%c",
                                    formula,&x,&y,&z,&end)==4 ||
                        std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f%c",
                                    formula,&x,&y,&z,&L,&end)==5 ||
                        std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f%c",
                                    formula,&x,&y,&z,&L,&dl,&end)==6 ||
                        std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%u%c",
                                    formula,&x,&y,&z,&L,&dl,&interp,&end)==7 ||
                        std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%u,%u%c",
                                    formula,&x,&y,&z,&L,&dl,&interp,&is_backward,&end)==8 ||
                        std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%u,%u,%u%c",
                                    formula,&x,&y,&z,&L,&dl,&interp,&is_backward,
                                    &is_oriented_only,&end)==9) &&
                       dl>0 && interp<4) {
              gmic_strreplace(formula);
              print(images,"Extract 3d streamline from formula '%s', starting from (%g,%g,%g).",
                    formula,
                    x,y,z);
              CImg<T> vertices = CImg<T>::streamline((const char *)formula,x,y,z,L,dl,interp,
                                                     (bool)is_backward,(bool)is_oriented_only);
              CImgList<unsigned int> primitives;
              CImgList<unsigned char> colors;
              if (vertices.width()>1) {
                primitives.assign(vertices.width()-1,1,2);
                cimglist_for(primitives,l) { primitives(l,0) = l; primitives(l,1) = l+1; }
                colors.assign(primitives.size(),1,3,1,1,200);
              } else {
                vertices.assign();
                warn(images,
                     "Command '-streamline3d': Empty streamline starting from (%g,%g,%g) "
                     "in expression '%s'.",
                     x,y,z,formula);
              }
              vertices.object3dtoCImg3d(primitives,colors,false).move_to(images);
              cimg_snprintf(title,_title.size(),"[3d streamline of '%s' at (%g,%g,%g)]",
                            formula,x,y,z);
              gmic_ellipsize(title,_title.size());
              CImg<char>::string(title).move_to(images_names);
            } else arg_error("streamline3d");
            is_released = false; ++position; continue;
          }

          // Compute structure tensor field.
          if (!std::strcmp("-structuretensors",command)) {
            gmic_substitute_args();
            unsigned int scheme = 0;
            if (std::sscanf(argument,"%u%c",&scheme,&end)==1 &&
                scheme<=2) ++position;
            else scheme = 2;
            print(images,"Compute structure tensor field of image%s, with %s scheme.",
                  gmic_selection,
                  scheme==0?"centered":scheme==1?"forward-backward1":"forward-backward2");
            cimg_forY(selection,l) gmic_apply(images[selection[l]],structure_tensors(scheme));
            is_released = false; continue;
          }

          // Select image feature.
          if (!std::strcmp("-select",command)) {
            gmic_substitute_args();
            unsigned int feature_type = 0, X=~0U, Y=~0U, Z=~0U;
            bool is_xyz = false;
            if ((std::sscanf(argument,"%u%c",&feature_type,&end)==1 ||
                 (is_xyz=std::sscanf(argument,"%u,%u,%u,%u%c",&feature_type,&X,&Y,&Z,&end)==4)) &&
                feature_type<=3) {
#if cimg_display==0
              print(images,"Select %s in image%s in interactive mode",
                    feature_type==0?"point":feature_type==1?"segment":feature_type==2?"rectangle":
                    "ellipse",gmic_selection);
              if (verbosity>=0 || is_debug) {
                if (is_xyz) std::fprintf(cimg::output(),", from point (%u,%u,%u)",X,Y,Z);
                std::fprintf(cimg::output()," (skipped, no display support).");
                std::fflush(cimg::output());
              }
#else // #if cimg_display==0
# 10246 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
              bool is_available_display = false;
              try {
                is_available_display = (bool)CImgDisplay::screen_width();
              } catch (CImgDisplayException&) {
                print(images,
                      "Select %s in image%s in interactive mode",
                      feature_type==0?"point":feature_type==1?"segment":
                      feature_type==2?"rectangle":"ellipse",gmic_selection);
                if (verbosity>=0 || is_debug) {
                  if (is_xyz) std::fprintf(cimg::output(),", from point (%u,%u,%u)",X,Y,Z);
                  std::fprintf(cimg::output()," (skipped, no display available).");
                  std::fflush(cimg::output());
                }
              }
              if (is_available_display) {
                print(images,"Select %s in image%s in interactive mode",
                      feature_type==0?"point":feature_type==1?"segment":
                      feature_type==2?"rectangle":"ellipse",gmic_selection);
                if (verbosity>=0 || is_debug) {
                  if (is_xyz) std::fprintf(cimg::output(),", from point (%u,%u,%u).",X,Y,Z);
                  else std::fprintf(cimg::output(),".");
                  std::fflush(cimg::output());
                }
                unsigned int XYZ[3];
                XYZ[0] = X; XYZ[1] = Y; XYZ[2] = Z;
                if (instant_window[0])
                  cimg_forY(selection,l) {
                    gmic_apply(images[selection[l]],select(instant_window[0],feature_type,
                                                           is_xyz?XYZ:0));
                  }
                else
                  cimg_forY(selection,l) {
                    gmic_apply(images[selection[l]],select(images_names[selection[l]].data(),
                                                           feature_type,is_xyz?XYZ:0));
                  }
              }
#endif // #if cimg_display==0
# 10283 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            } else arg_error("select");
            is_released = false; ++position; continue;
          }

#endif // #ifdef gmic_float
# 10288 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='s'.

        //----------------------------
        // Commands starting by '-t..'
        //----------------------------
        else if (command1=='t') {

          // Set datatype.
          if (!std::strcmp("-type",item)) {
            gmic_substitute_args();
#ifndef gmic_float_only
            typedef unsigned char uchar;
            typedef unsigned short ushort;
            typedef unsigned int uint;
            gmic_cast(bool,"bool");
            gmic_cast(uchar,"unsigned char");
            gmic_cast(char,"char");
            gmic_cast(ushort,"unsigned short");
            gmic_cast(short,"short");
            gmic_cast(uint,"unsigned int");
            gmic_cast(int,"int");
            gmic_cast(double,"double");
#endif // #ifndef gmic_float_only
# 10311 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            gmic_cast(float,"float");
            arg_error("type");
          }

#ifdef gmic_float

          // Threshold.
          if (!std::strcmp("-threshold",command)) {
            gmic_substitute_args();
            unsigned int is_soft = 0;
            double value = 0;
            char sep = 0;
            if ((std::sscanf(argument,"%lf%c",
                             &value,&end)==1 ||
                 (std::sscanf(argument,"%lf%c%c",
                              &value,&sep,&end)==2 && sep=='%') ||
                 std::sscanf(argument,"%lf,%u%c",
                             &value,&is_soft,&end)==2 ||
                 (std::sscanf(argument,"%lf%c,%u%c",
                              &value,&sep,&is_soft,&end)==3 && sep=='%')) &&
                is_soft<=1) {
              print(images,"%s-threshold image%s by %g%s.",
                    is_soft?"Soft":"Hard",
                    gmic_selection,
                    value,sep=='%'?"%":"");
              cimg_forY(selection,l) {
                CImg<T>& img = gmic_check(images[selection[l]]);
                double nvalue = value;
                if (sep=='%' && img) {
                  double vmin = 0, vmax = (double)img.max_min(vmin);
                  nvalue = vmin + (vmax-vmin)*value/100;
                }
                gmic_apply(img,threshold((T)nvalue,(bool)is_soft));
              }
              ++position;
            } else {
#if cimg_display==0
              print(images,
                    "Threshold image%s in interactive mode (skipped, no display support).",
                    gmic_selection);
#else // #if cimg_display==0
# 10352 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
              bool is_available_display = false;
              try {
                is_available_display = (bool)CImgDisplay::screen_width();
              } catch (CImgDisplayException&) {
                print(images,
                      "Threshold image%s in interactive mode (skipped, no display available).",
                      gmic_selection);
              }
              if (is_available_display) {
                print(images,"Threshold image%s in interactive mode.",
                      gmic_selection);
                CImgDisplay _disp, &disp = instant_window[0]?instant_window[0]:_disp;
                cimg_forY(selection,l) {
                  CImg<T>& img = gmic_check(images[selection[l]]);
                  if (img) {
                    CImg<T> visu = img.depth()>1?img.get_projections2d(img.width()/2,
                                                                       img.height()/2,
                                                                       img.depth()/2).
                      channels(0,cimg::min(3,img.spectrum())-1):
                      img.get_channels(0,cimg::min(3,img.spectrum()-1));
                    const unsigned int
                      w = CImgDisplay::_fitscreen(visu.width(),visu.height(),1,256,-85,false),
                      h = CImgDisplay::_fitscreen(visu.width(),visu.height(),1,256,-85,true);
                    if (disp) disp.resize(w,h,false); else disp.assign(w,h,0,0);
                    double vmin = 0, vmax = (double)img.max_min(vmin), percent = 50;
                    bool stopflag = false, is_clicked = false;
                    int omx = -1, omy = -1;
                    CImg<unsigned char> res;
                    for (disp.show().flush(); !stopflag; ) {
                      const unsigned char white[] = { 255,255,255 }, black[] = { 0,0,0 };
                      const unsigned int key = disp.key();
                      if (!res)
                        disp.display(((res=visu.get_threshold((T)(vmin + percent*(vmax-vmin)/100)).
                                       resize(disp))*=255).
                                     draw_text(0,0,"Threshold %g = %.3g%%",
                                               white,black,0.7f,13,
                                               (double)(vmin + percent*(vmax-vmin)/100),
                                               percent)).
                          set_title("%s (%dx%dx%dx%d)",
                                    gmic_basename(images_names[selection[l]].data()),
                                    img.width(),img.height(),img.depth(),img.spectrum()).wait();
                      const int mx = disp.mouse_x(), my = disp.mouse_y();
                      if (disp.button()) {
                        if (mx>=0 && my>=0 && (mx!=omx || my!=omy)) {
                          percent = (my-16)*100.0/(disp.height()-32);
                          if (percent<0) percent = 0; else if (percent>101) percent = 101;
                          omx = mx; omy = my; res.assign();
                        }
                        is_clicked = true;
                      } else if (is_clicked) break;
                      if (disp.is_closed() || (key && key!=cimg::keyCTRLLEFT)) stopflag = true;
                      if (key==cimg::keyD && disp.is_keyCTRLLEFT()) {
                        disp.resize(cimg_fitscreen(3*disp.width()/2,3*disp.height()/2,1),
                                    stopflag=false).set_key(cimg::keyD,false);
                        res.assign();
                      }
                      if (key==cimg::keyC && disp.is_keyCTRLLEFT()) {
                        disp.resize(cimg_fitscreen(2*disp.width()/3,2*disp.height()/3,1),
                                    stopflag=false).set_key(cimg::keyC,false);
                        res.assign();
                      }
                      if (disp.is_resized()) { disp.resize(false); res.assign(); }
                    }
                    print(images,"Hard-threshold image [%d] by %g = %.3g%%.",
                          selection[l],(double)(vmin + percent*(vmax-vmin)/100),percent);
                    gmic_apply(img,threshold((T)(vmin + percent*(vmax-vmin)/100)));
                  } else { gmic_apply(img,replace(img)); }
                }
              }

#endif // #if cimg_display==0
# 10423 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            }
            is_released = false; continue;
          }

          // Tangent.
          gmic_simple_item("-tan",tan,"Compute pointwise tangent of image%s.");

          // Draw text.
          if (!std::strcmp("-text",command)) {
            gmic_substitute_args();
            CImg<char> text(4096);
            *argx = *argy = *text = *color = 0;
            float x = 0, y = 0, opacity = 1, siz = 13;
            char sepx = 0, sepy = 0;
            if ((std::sscanf(argument,"%4095[^,]%c",
                             text.data(),&end)==1 ||
                 std::sscanf(argument,"%4095[^,],%255[0-9.eE%+-]%c",
                             text.data(),argx,&end)==2 ||
                 std::sscanf(argument,"%4095[^,],%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             text.data(),argx,argy,&end)==3 ||
                 std::sscanf(argument,"%4095[^,],%255[0-9.eE%+-],%255[0-9.eE%+-],%f%c",
                             text.data(),argx,argy,&siz,&end)==4 ||
                 std::sscanf(argument,"%4095[^,],%255[0-9.eE%+-],%255[0-9.eE%+-],%f,%f%c",
                             text.data(),argx,argy,&siz,&opacity,&end)==5 ||
                 std::sscanf(argument,"%4095[^,],%255[0-9.eE%+-],%255[0-9.eE%+-],%f,%f,"
                             "%4095[0-9.eE,+-]%c",
                             text.data(),argx,argy,&siz,&opacity,color,&end)==6) &&
                (!*argx ||
                 std::sscanf(argx,"%f%c",&x,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&x,&sepx,&end)==2 && sepx=='%')) &&
                (!*argy ||
                 std::sscanf(argy,"%f%c",&y,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&y,&sepy,&end)==2 && sepy=='%')) &&
                siz>=0) {
              siz = cimg::round(siz);
              gmic_strreplace(text);
              print(images,"Draw text '%s' at position (%g%s,%g%s) on image%s, with font "
                    "height %g, opacity %g and color (%s).",
                    text.data(),
                    x,sepx=='%'?"%":"",
                    y,sepy=='%'?"%":"",
                    gmic_selection,
                    siz,
                    opacity,
                    *color?color:"default");
              cimg::strunescape(text);
              unsigned int nb_cols = 1;
              for (const char *s = color; *s; ++s) if (*s==',') ++nb_cols;
              cimg_forY(selection,l) {
                CImg<T>
                  &img = images[selection[l]],
                  col(cimg::max(img.spectrum(),(int)nb_cols),1,1,1,0);
                col.fill(color,true);
                const int
                  nx = (int)cimg::round(sepx=='%'?x*(img.width()-1)/100:x),
                  ny = (int)cimg::round(sepy=='%'?y*(img.height()-1)/100:y);
                gmic_apply(img,gmic_draw_text(nx,ny,text,col,0,opacity,(unsigned int)siz,nb_cols));
              }
            } else arg_error("text");
            is_released = false; ++position; continue;
          }

          // Texturize 3d object.
          if (!std::strcmp("-texturize3d",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind_texture, ind_coords;
            char sep = 0;
            *argx = *argy = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                              argx,&sep,&end)==2 && sep==']') ||
                 (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],[%255[a-zA-Z0-9_.%+-]%c%c",
                              argx,argy,&sep,&end)==3 && sep==']')) &&
                (ind_texture=selection2cimg(argx,images.size(),images_names,"-texturize3d",true,
                                            false,CImg<char>::empty())).height()==1 &&
                (!*argy || (ind_coords=selection2cimg(argy,images.size(),images_names,
                                                      "-texturize3d",true,
                                                      false,CImg<char>::empty())).height()==1)) {
              if (ind_coords)
                print(images,
                      "Texturize 3d object%s with texture [%u] and texture coordinates [%u].",
                      gmic_selection,*ind_texture,*ind_coords);
              else
                print(images,"Texturize 3d object%s with texture [%u].",
                      gmic_selection,*ind_texture);
              const CImg<T>
                texture = gmic_image_arg(*ind_texture),
                coords = ind_coords?gmic_image_arg(*ind_coords):CImg<T>();
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                CImg<T>& img = gmic_check(images[ind]);
                try { gmic_apply(img,texturize_CImg3d(texture,coords)); }
                catch (CImgException &e) {
                  if (!img.is_CImg3d(true,message))
                    error(images,"Command '-texturize3d': Invalid 3d object [%d], "
                          "in selected image%s (%s).",
                          ind,gmic_selection,message);
                  else throw e;
                }
              }
            } else arg_error("texturize3d");
            is_released = false; ++position; continue;
          }

          // Tridiagonal solve.
          if (!std::strcmp("-trisolve",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind;
            char sep = 0;
            if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 &&
                sep==']' &&
                (ind=selection2cimg(indices,images.size(),images_names,"-trisolve",true,
                                    false,CImg<char>::empty())).height()==1) {
              print(images,"Solve tridiagonal system AX = B, with B-vector%s and tridiagonal "
                    "A-matrix [%d].",
                    gmic_selection,*ind);
              const CImg<T> A = gmic_image_arg(*ind);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],solve_tridiagonal(A));
            } else arg_error("trisolve");
            is_released = false; ++position; continue;
          }

          // Hyperbolic tangent.
          gmic_simple_item("-tanh",tanh,"Compute pointwise hyperbolic tangent of image%s.");

#endif // #ifdef gmic_float
# 10549 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='t'.

        //----------------------------
        // Commands starting by '-u..'
        //----------------------------
        else if (command1=='u') {

          // Unroll.
          if (!std::strcmp("-unroll",command)) {
            gmic_substitute_args();
            char axis = 'y';
            if ((*argument=='x' || *argument=='y' ||
                 *argument=='z' || *argument=='c') && !argument[1]) {
              axis = *argument;
              ++position;
            }
            else axis = 'y';
            print(images,"Unroll image%s along the '%c'-axis.",
                  gmic_selection,
                  axis);
            cimg_forY(selection,l) gmic_apply(images[selection[l]],unroll(axis));
            is_released = false; continue;
          }

          // Remove custom command.
          if (!std::strcmp("-uncommand",item)) {
            gmic_substitute_args();
            if (argument[0]=='*' && !argument[1]) { // Discard all custom commands.
              unsigned int nb_commands = 0;
              for (unsigned int i = 0; i<256; ++i) {
                nb_commands+=commands[i].size();
                commands[i].assign();
                commands_names[i].assign();
                commands_has_arguments[i].assign();
              }
              print(images,"Discard definitions of all custom commmands (%u command%s discarded).",
                    nb_commands,nb_commands>1?"s":"");
            } else { // Discard a single custom command.
              print(images,"Discard last definition of custom command '%s'",argument_text);
              CImg<char> arg_command(argument,std::strlen(argument)+1);
              gmic_strreplace(arg_command);
              bool is_removed = false;
              if (*arg_command) {
                const int ind = gmic_hashcode(arg_command,false);
                cimglist_for(commands_names[ind],l)
                  if (!std::strcmp(commands_names[ind][l],arg_command)) {
                    commands_names[ind].remove(l);
                    commands[ind].remove(l);
                    commands_has_arguments[ind].remove(l);
                    is_removed = true; break;
                  }
              }
              if (verbosity>=0 || is_debug) {
                unsigned int siz = 0;
                for (unsigned int l = 0; l<256; ++l) siz+=commands[l].size();
                std::fprintf(cimg::output()," (%s, %u command%s left).",
                             is_removed?"found":"not found",siz,siz>1?"s":"");
                std::fflush(cimg::output());
              }
            }
            ++position; continue;
          }

        } // command1=='u'.

        //----------------------------
        // Commands starting by '-v..'
        //----------------------------
        else if (command1=='v') {

          // Set verbosity
          // (actually only display a log message, since it has been already processed before).
          if (!std::strcmp("-verbose",item)) {
            if (*argument=='-' && !argument[1])
              print(images,"Decrement verbosity level (set to %d).",
                    verbosity);
            else if (*argument=='+' && !argument[1]) {
              if (verbosity>0) print(images,"Increment verbosity level (set to %d).",
                                     verbosity);
            } else if (verbosity>=0 && old_verbosity>=0)
              print(images,"Set verbosity level to %d.",
                    verbosity);
            if (is_verbose_argument) ++position;
            continue;
          }

          // Vanvliet filter.
          if (!std::strcmp("-vanvliet",command)) {
            gmic_substitute_args();
            unsigned int boundary = 1, order = 0;
            char sep = 0, axis = 0;
            float sigma = 0;
            if ((std::sscanf(argument,"%f,%u,%c%c",&sigma,&order,&axis,&end)==3 ||
                 (std::sscanf(argument,"%f%c,%u,%c%c",&sigma,&sep,&order,&axis,&end)==4 &&
                  sep=='%') ||
                 std::sscanf(argument,"%f,%u,%c,%u%c",&sigma,&order,&axis,&boundary,&end)==4 ||
                 (std::sscanf(argument,"%f%c,%u,%c,%u%c",
                              &sigma,&sep,&order,&axis,&boundary,&end)==5 && sep=='%')) &&
                sigma>=0 && order<=3 && (axis=='x' || axis=='y' || axis=='z' || axis=='c') &&
                boundary<=1) {
              print(images,"Apply Vanvliet filter on image%s, with standard "
                    "deviation %g%s, order %d, axis '%c' and %s boundary conditions.",
                    gmic_selection,
                    sigma,sep=='%'?"%":"",
                    order,axis,
                    boundary?"neumann":"dirichlet");
              if (sep=='%') sigma = -sigma;
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],vanvliet(sigma,order,axis,(bool)boundary));
            } else arg_error("vanvliet");
            is_released = false; ++position; continue;
          }

        } // command1=='v'.

        //----------------------------
        // Commands starting by '-w..'
        //----------------------------
        else if (command1=='w') {

          // While.
          if (!std::strcmp("-while",item)) {
            gmic_substitute_args();
            const CImg<char> &s = scope.back();
            if (s[0]!='*' || s[1]!='d')
              error(images,
                    "Command '-while': Not associated to a '-do' command within the same scope.");
            float _is_cond = 0;
            bool is_filename = false;
            if (std::sscanf(argument,"%f%c",&_is_cond,&end)!=1) {
              is_filename = true;
              CImg<char> arg_while(argument,std::strlen(argument)+1);
              gmic_strreplace(arg_while);
              _is_cond = (float)gmic_check_filename(arg_while);
            }
            const bool is_cond = (bool)_is_cond;
            if (verbosity>0 || is_debug) print(images,"Reach '-while' command -> %s '%s' %s.",
                                               is_filename?"file":"boolean",
                                               argument_text,
                                               is_filename?(is_cond?"exists":
                                                            "does not exist"):
                                               (is_cond?"is true":"is false"));
            if (is_cond) { position = dowhiles.back()(0); continue; }
            else {
              if (verbosity>0 || is_debug) print(images,"End 'do..while' block.");
              dowhiles.remove();
              scope.remove();
            }
            ++position; continue;
          }

          // Warning.
          if (!std::strcmp("-warn",command) && !is_get_version) {
            gmic_substitute_args();
            CImg<char> str(argument,std::strlen(argument)+1);
            cimg::strunescape(str);
            if (is_restriction) warn(images,selection,"%s",str.data());
            else warn(images,"%s",str.data());
            ++position; continue;
          }

#ifdef gmic_float

          // Display images in instant display window.
          unsigned int wind = 0;
          if ((!std::strcmp("-window",command) ||
               std::sscanf(command,"-window%u%c",&wind,&end)==1 ||
               std::sscanf(command,"-w%u%c",&wind,&end)==1) &&
              wind<10 && !is_get_version) {
            gmic_substitute_args();
            int norm = -1, fullscreen = -1;
            float dimw = -1, dimh = -1, posx = -1, posy = -1;
            char sepw = 0, seph = 0, sepx = 0, sepy = 0;
            *argx = *argy = *argz = *argc = *title = 0;
            if ((std::sscanf(argument,"%255[0-9.eE%+-]%c",
                             argx,&end)==1 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             argx,argy,&end)==2 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%d%c",
                             argx,argy,&norm,&end)==3 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%d,%d%c",
                             argx,argy,&norm,&fullscreen,&end)==4 ||
                 std::sscanf(argument,
                             "%255[0-9.eE%+-],%255[0-9.eE%+-],%d,%d,%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-]%c",
                             argx,argy,&norm,&fullscreen,argz,argc,&end)==6 ||
                 std::sscanf(argument,
                             "%255[0-9.eE%+-],%255[0-9.eE%+-],%d,%d,%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-],%255[^\n]",
                             argx,argy,&norm,&fullscreen,argz,argc,title)==7 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%d,%d,%255[^\n]",
                             &(*argx=*argz=*argc=0),argy,&norm,&fullscreen,title)==5 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%d,%255[^\n]",
                             argx,argy,&(norm=fullscreen=-1),title)==4 ||
                 (norm=fullscreen=-1,std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[^\n]",
                                                 argx,argy,title))==3) &&
                (std::sscanf(argx,"%f%c",&dimw,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&dimw,&sepw,&end)==2 && sepw=='%')) &&
                (!*argy ||
                 std::sscanf(argy,"%f%c",&dimh,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&dimh,&seph,&end)==2 && seph=='%')) &&
                (!*argz ||
                 std::sscanf(argz,"%f%c",&posx,&end)==1 ||
                 (std::sscanf(argz,"%f%c%c",&posx,&sepx,&end)==2 && sepx=='%')) &&
                (!*argc ||
                 std::sscanf(argc,"%f%c",&posy,&end)==1 ||
                 (std::sscanf(argc,"%f%c%c",&posy,&sepy,&end)==2 && sepy=='%')) &&
                (dimw>=0 || dimw==-1) &&
                (dimh>=0 || dimh==-1) &&
                norm>=-1 && norm<=3) ++position;
            else {
              dimw = dimh = -1;
              norm = fullscreen = -1;
              posx = posy = -1;
              sepw = seph = 0;
            }
            if (dimh==0) dimw = 0;
            gmic_strreplace(title);
            cimg::strunescape(title);

            // Get images to display and compute associated optimal size.
            unsigned int optw = 0, opth = 0;
            CImgList<T> subimages;
            if (dimw && dimh) cimg_forY(selection,l) {
                const CImg<T>& img = gmic_check(images[selection[l]]);
                if (img) {
                  subimages.insert(img,~0U,true);
                  optw+=img.width() + (img.depth()>1?img.depth():0);
                  if (img.height()>(int)opth) opth = img.height() + (img.depth()>1?img.depth():0);
                }
              }
            optw = optw?optw:sepw=='%'?CImgDisplay::screen_width():256;
            opth = opth?opth:seph=='%'?CImgDisplay::screen_height():256;
            dimw = dimw<0?-1:cimg::round(sepw=='%'?optw*dimw/100:dimw);
            dimh = dimh<0?-1:cimg::round(seph=='%'?opth*dimh/100:dimh);

#if cimg_display==0
            print(images,
                  "Display image%s in instant window [%d] (skipped, no display support).",
                  gmic_selection,
                  wind);
#else // #if cimg_display==0
# 10791 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            const bool is_move = posx!=-1 || posy!=-1;
            bool is_available_display = false;
            try {
              is_available_display = (bool)CImgDisplay::screen_width();
            } catch (CImgDisplayException&) {
              print(images,
                    "Display image%s in instant window [%d] (skipped, no display available).",
                    gmic_selection,
                    wind);
            }
            if (is_available_display) {

              if (!dimw || !dimh) { // Close.
                print(images,"Close instant window [%d].",
                      wind);
                instant_window[wind].assign();
              } else {
                if (instant_window[wind]) { // Update.
                  instant_window[wind].resize(dimw>0?(int)dimw:instant_window[wind].window_width(),
                                              dimh>0?(int)dimh:instant_window[wind].window_height(),
                                              false);
                  if (is_move) {
                    if (sepx=='%') posx*=(CImgDisplay::screen_width()-
                                          instant_window[wind].window_width())/100.0f;
                    if (sepy=='%') posy*=(CImgDisplay::screen_height()-
                                          instant_window[wind].window_height())/100.0f;
                    instant_window[wind].move((int)posx,(int)posy);
                  }
                  if (norm>=0) instant_window[wind]._normalization = norm;
                  if (*title && std::strcmp(instant_window[wind].title(),title))
                    instant_window[wind].set_title("%s",title);
                  if (fullscreen>=0 && (bool)fullscreen!=instant_window[wind].is_fullscreen())
                    instant_window[wind].toggle_fullscreen(false);
                } else { // Create.
                  instant_window[wind].assign(dimw>0?(int)dimw:optw,
                                              dimh>0?(int)dimh:opth,
                                              title,norm<0?3:norm,
                                              fullscreen<0?false:(bool)fullscreen,
                                              is_move);
                  if (is_move) {
                    if (sepx=='%') posx*=(CImgDisplay::screen_width()-
                                          instant_window[wind].window_width())/100.0f;
                    if (sepy=='%') posy*=(CImgDisplay::screen_height()-
                                          instant_window[wind].window_height())/100.0f;
                    instant_window[wind].move((int)posx,(int)posy);
                  }
                  if (norm==2) {
                    if (subimages)
                      instant_window[wind]._max =
                        (float)subimages.max_min(instant_window[wind]._min);
                    else { instant_window[wind]._min = 0; instant_window[wind]._max = 255; }
                  }
                }
                if (is_move) print(images,
                                   "Display image%s in %dx%d %sinstant window [%d], "
                                   "with%snormalization, "
                                   "%sfullscreen, at position (%s,%s) and title '%s'.",
                                   gmic_selection,
                                   instant_window[wind].width(),
                                   instant_window[wind].height(),
                                   instant_window[wind].is_fullscreen()?"fullscreen ":"",
                                   wind,
                                   instant_window[wind].normalization()==0?"out ":
                                   instant_window[wind].normalization()==1?" ":
                                   instant_window[wind].normalization()==2?" 1st-time ":" auto-",
                                   instant_window[wind].is_fullscreen()?"":"no ",
                                   argz,argc,
                                   instant_window[wind].title());
                else print(images,
                           "Display image%s in %dx%d %sinstant window [%d], with%snormalization, "
                           "%sfullscreen and title '%s'.",
                           gmic_selection,
                           instant_window[wind].width(),
                           instant_window[wind].height(),
                           instant_window[wind].is_fullscreen()?"fullscreen ":"",
                           wind,
                           instant_window[wind].normalization()==0?"out ":
                           instant_window[wind].normalization()==1?" ":
                           instant_window[wind].normalization()==2?" 1st-time ":" auto-",
                           instant_window[wind].is_fullscreen()?"":"no ",
                           instant_window[wind].title());
                if (subimages) subimages.display(instant_window[wind]);
              }
            }

#endif // #if cimg_display==0
# 10877 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            is_released = true; continue;
          }

          // Warp.
          if (!std::strcmp("-warp",command)) {
            gmic_substitute_args();
            unsigned int interpolation = 1, is_relative = 0, boundary = 1;
            CImg<unsigned int> ind;
            float nb_frames = 1;
            char sep = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                              indices,&sep,&end)==2 && sep==']')||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u%c",
                             indices,&is_relative,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u%c",
                             indices,&is_relative,&interpolation,&end)==3 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u,%u%c",
                             indices,&is_relative,&interpolation,&boundary,&end)==4 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u,%u,%f%c",
                             indices,&is_relative,&interpolation,&boundary,&nb_frames,&end)==5) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-warp",true,
                                    false,CImg<char>::empty())).height()==1 &&
                is_relative<=1 && interpolation<=2 && boundary<=2 && nb_frames>=0.5) {
              const CImg<T> warping_field = gmic_image_arg(*ind);
              nb_frames = cimg::round(nb_frames);
              if (nb_frames==1) {
                print(images,"Warp image%s with %s displacement field [%u], %s interpolation, "
                      "%s boundary conditions.",
                      gmic_selection,
                      is_relative?"relative":"absolute",*ind,
                      interpolation==2?"cubic":interpolation==1?"linear":"nearest-neighbor",
                      boundary==0?"dirichlet":boundary==1?"neumann":"cyclic");
                cimg_forY(selection,l)
                  gmic_apply(images[selection[l]],warp(warping_field,(bool)is_relative,
                                                       interpolation,boundary));
              } else {
                print(images,"Warp image%s with %s displacement field [%u], %s interpolation, "
                      "%s boundary conditions and %d frames.",
                      gmic_selection,
                      is_relative?"relative":"absolute",*ind,
                      interpolation==2?"cubic":interpolation==1?"linear":"nearest-neighbor",
                      boundary==0?"dirichlet":boundary==1?"neumann":"cyclic",
                      (int)nb_frames);
                unsigned int off = 0;
                cimg_forY(selection,l) {
                  const unsigned int _ind = selection[l] + off;
                  CImg<T>& img = gmic_check(images[_ind]);
                  CImg<char> name = images_names[_ind].get_mark();
                  CImgList<T> frames((int)nb_frames);
                  cimglist_for(frames,t)
                    frames[t] = img.get_warp(warping_field*((t+1.0f)/nb_frames),(bool)is_relative,
                                             interpolation,boundary);
                  if (is_get_version) {
                    images_names.insert((int)nb_frames,name.copymark());
                    frames.move_to(images,~0U);
                  } else {
                    off+=(int)nb_frames - 1;
                    images_names.insert((int)nb_frames - 1,name.get_copymark(),_ind);
                    images.remove(_ind); frames.move_to(images,_ind);
                  }
                }
              }
            } else arg_error("warp");
            is_released = false; ++position; continue;
          }

          // Watershed transform.
          if (!std::strcmp("-watershed",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind;
            unsigned int is_filled = 1;
            char sep = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 &&
                  sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u%c",
                             indices,&is_filled,&end)==2) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-watershed",true,
                                    false,CImg<char>::empty())).height()==1 &&
                is_filled<=1) {
              print(images,"Compute watershed transform of image%s with priority map [%u] and "
                    "%sfilling.",
                    gmic_selection,*ind,is_filled?"":"no ");
              const CImg<T> priority = gmic_image_arg(*ind);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],watershed(priority,(bool)is_filled));
            } else arg_error("watershed");
            is_released = false; ++position; continue;
          }

          // Wait for a given delay of for user events on instant window.
          if (!std::strcmp("-wait",command) && !is_get_version) {
            gmic_substitute_args();
            if (!is_restriction)
              CImg<unsigned int>::vector(0,1,2,3,4,5,6,7,8,9).move_to(selection);
            float delay = 0;
            if (std::sscanf(argument,"%f%c",
                            &delay,&end)==1) ++position;
            else delay = 0;
            delay = cimg::round(delay);
#if cimg_display==0
            if (!delay)
              print(images,
                    "Wait for user events on instant window%s (skipped, no display support).",
                    gmic_selection);
            else {
              print(images,
                    "%s for %g milliseconds according to instant window%s.",
                    delay<0?"Sleep":"Wait",delay,
                    gmic_selection);
              if (delay<0) cimg::sleep((unsigned int)-delay);
              else cimg::wait((unsigned int)delay);
            }
#else // #if cimg_display==0
# 10990 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            if (!delay) {
              print(images,"Wait for user events on instant window%s.",
                    gmic_selection);
              CImgDisplay *const iw = instant_window;
              switch (selection.height()) {
              case 1 : CImgDisplay::wait(iw[selection[0]]); break;
              case 2 : CImgDisplay::wait(iw[selection[0]],iw[selection[1]]); break;
              case 3 : CImgDisplay::wait(iw[selection[0]],iw[selection[1]],iw[selection[2]]);
                break;
              case 4 : CImgDisplay::wait(iw[selection[0]],iw[selection[1]],iw[selection[2]],
                                         iw[selection[3]]);
                break;
              case 5 : CImgDisplay::wait(iw[selection[0]],iw[selection[1]],iw[selection[2]],
                                         iw[selection[3]],iw[selection[4]]);
                break;
              case 6 : CImgDisplay::wait(iw[selection[0]],iw[selection[1]],iw[selection[2]],
                                         iw[selection[3]],iw[selection[4]],iw[selection[5]]);
                break;
              case 7 : CImgDisplay::wait(iw[selection[0]],iw[selection[1]],iw[selection[2]],
                                         iw[selection[3]],iw[selection[4]],iw[selection[5]],
                                         iw[selection[6]]);
                break;
              case 8 : CImgDisplay::wait(iw[selection[0]],iw[selection[1]],iw[selection[2]],
                                         iw[selection[3]],iw[selection[4]],iw[selection[5]],
                                         iw[selection[6]],iw[selection[7]]);
                break;
              case 9 : CImgDisplay::wait(iw[selection[0]],iw[selection[1]],iw[selection[2]],
                                         iw[selection[3]],iw[selection[4]],iw[selection[5]],
                                         iw[selection[6]],iw[selection[7]],iw[selection[8]]);
                break;
              case 10 : CImgDisplay::wait(iw[selection[0]],iw[selection[1]],iw[selection[2]],
                                          iw[selection[3]],iw[selection[4]],iw[selection[5]],
                                          iw[selection[6]],iw[selection[7]],iw[selection[8]],
                                          iw[selection[9]]);
                break;
              }
            } else if (delay<0) {
              print(images,
                    "Flush display events of instant window%s and wait for %g milliseconds.",
                    gmic_selection,-delay);
              cimg_forY(selection,l) instant_window[selection[l]].flush();
              if (selection && instant_window[selection[0]])
                instant_window[selection[0]].wait((unsigned int)-delay);
              else cimg::sleep((unsigned int)-delay);
            } else {
              print(images,"Wait for %g milliseconds according to instant window%s.",
                    delay,
                    gmic_selection);
              if (selection && instant_window[selection[0]])
                instant_window[selection[0]].wait((unsigned int)delay);
              else cimg::wait((unsigned int)delay);
            }
#endif // #if cimg_display==0
# 11043 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            continue;
          }

#endif // #ifdef gmic_float
# 11047 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='w'.

        //----------------------------
        // Commands starting by '-x..'
        //----------------------------
        else if (command1=='x') {

#ifdef gmic_float

          // Bitwise xor.
          gmic_arithmetic_item("-xor",
                               operator^=,
                               "Compute bitwise XOR of image%s by %g%s",
                               gmic_selection,value,ssep,Tlong,
                               operator^=,
                               "Compute bitwise XOR of image%s by image [%d]",
                               gmic_selection,ind[0],
                               "Compute bitwise XOR of image%s by expression %s",
                               gmic_selection,argument_text,
                               "Compute sequential bitwise XOR of image%s");

#endif // #ifdef gmic_float
# 11069 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='x'.

        //----------------------------
        // Other (special) commands.
        //----------------------------

        // If..[elif]..[else]..endif.
        if (!std::strcmp("-if",item) || (!std::strcmp("-elif",item) && check_elif)) {
          gmic_substitute_args();
          check_elif = false;
          float _is_cond = 0;
          bool is_filename = false;
          if (std::sscanf(argument,"%f%c",&_is_cond,&end)!=1) {
            is_filename = true;
            CImg<char> arg_if(argument,std::strlen(argument)+1);
            gmic_strreplace(arg_if);
            _is_cond = (float)gmic_check_filename(arg_if);
          }
          const bool is_cond = (bool)_is_cond;
          if (item[1]=='i') {
            CImg<char>::string("*if").move_to(scope);
            if (verbosity>0 || is_debug) print(images,"Start '-if..-endif' block -> %s '%s' %s.",
                                               is_filename?"file":"boolean",
                                               argument_text,
                                               is_filename?(is_cond?"exists":"does not exist"):
                                               (is_cond?"is true":"is false"));
          } else if (verbosity>0 || is_debug) print(images,"Reach '-elif' block -> %s '%s' %s.",
                                                    is_filename?"file":"boolean",
                                                    argument_text,
                                                    is_filename?(is_cond?"exists":
								 "does not exist"):
                                                    (is_cond?"is true":"is false"));
          if (!is_cond) {
            for (int nb_ifs = 1; nb_ifs && position<commands_line.size(); ++position) {
              const char *const it = commands_line[position].data();
              if (!std::strcmp("-if",it)) ++nb_ifs;
              else if (!std::strcmp("-endif",it)) { --nb_ifs; if (!nb_ifs) --position; }
              else if (nb_ifs==1) {
                if (!std::strcmp("-else",it)) --nb_ifs;
                else if (!std::strcmp("-elif",it)) { --nb_ifs; check_elif = true; --position;}
              }
            }
            continue;
          }
          ++position; continue;
        }

        // Break and continue.
        bool is_continue = false;
        if (!std::strcmp("-break",item) ||
            (!std::strcmp("-continue",item) && (is_continue=true)==true)) {
          const char
	    *const com = is_continue?"continue":"break",
	    *const Com = is_continue?"Continue":"Break";
          unsigned int scope_repeat = 0, scope_do = 0, scope_local = 0;
          for (unsigned int l = scope.size() - 1; l; --l) {
            const char *const s = scope[l].data();
            if (s[0]=='*' && s[1]=='r') { scope_repeat = l; break; }
            else if (s[0]=='*' && s[1]=='d') { scope_do = l; break; }
            else if (s[0]=='*' && s[1]=='l') { scope_local = l; break; }
            else if (s[0]!='*' || s[1]!='i') break;
          }
          const char *stb = 0, *ste = 0;
          unsigned int scope_ind = 0;
          int level = 0;
          if (scope_repeat) {
            print(images,"%s %scurrent 'repeat..done' block.",
                  Com,is_continue?"to next iteration of ":"");
            for (level = 1; level && position<commands_line.size(); ++position) {
              const char *it = commands_line[position].data();
              if (!std::strcmp("-repeat",it)) ++level;
              else if (!std::strcmp("-done",it)) --level;
            }
            scope_ind = scope_repeat;
            stb = "repeat"; ste = "done";
          } else if (scope_do) {
            print(images,"%s %scurrent 'do..while' block.",
                  Com,is_continue?"to next iteration of ":"");
            for (level = 1; level && position<commands_line.size(); ++position) {
              const char *it = commands_line[position].data();
              if (!std::strcmp("-do",it)) ++level;
              else if (!std::strcmp("-while",it)) --level;
            }
            scope_ind = scope_do;
            stb = "do"; ste = "while";
          } else if (scope_local) {
            print(images,"%s %scurrent local environment.",
                  Com,is_continue?"to end of ":"");
            for (level = 1; level && position<commands_line.size(); ++position) {
              const char *it = commands_line[position].data();
              if (!std::strcmp("-local",it) || !std::strcmp("-l",it) ||
                  !std::strcmp("--local",it) || !std::strcmp("--l",it) ||
                  !std::strncmp("-local[",it,7) || !std::strncmp("-l[",it,3) ||
                  !std::strncmp("--local[",it,8) || !std::strncmp("--l[",it,4)) ++level;
              else if (!std::strcmp("-endlocal",it) || !std::strcmp("-endl",it)) --level;
            }
            scope_ind = scope_local;
            stb = "local"; ste = "endlocal";
          } else {
            print(images,"%s",Com);
            error(images,"Command '-%s': There are no loops or local environment to %s.",com,com);
            continue;
          }
          if (level && position>=commands_line.size())
            error(images,"Command '-%s': Missing associated '-%s' command.",stb,ste);
          if (is_continue || scope_local) {
	    if (scope_ind<scope.size()-1) scope.remove(scope_ind+1,scope.size()-1);
	    --position;
	  } else {
            scope.remove(scope_ind,scope.size()-1);
            if (scope_do) { dowhiles.remove(); ++position; } else repeatdones.remove();
          }
          continue;
        }

        // Quit.
        if (!std::strcmp("-quit",item)) {
          print(images,"Quit G'MIC instance.\n");
          dowhiles.assign();
          repeatdones.assign();
          position = commands_line.size();
          is_released = is_quit = true;
          break;
        }

#ifdef gmic_float

        // Compute direct or inverse FFT.
        const bool inv_fft = !std::strcmp("-ifft",command);
        if (!std::strcmp("-fft",command) || inv_fft) {
          print(images,"Compute %sfourier transform of image%s with complex pair%s",
                inv_fft?"inverse ":"",
                gmic_selection,
                selection.height()>2?"s":"");
          cimg_forY(selection,l) {
            const unsigned int
	      ind0 = selection[l],
	      ind1 = l+1<selection.height()?selection[l+1]:~0U;
            CImg<T> &img0 = gmic_check(images[ind0]),
                    &img1 = ind1!=~0U?gmic_check(images[ind1]):CImg<T>::empty();
            CImg<char> name = images_names[ind0].get_mark();
            if (ind1!=~0U) { // Complex transform.
              if (verbosity>=0 || is_debug) {
                std::fprintf(cimg::output()," ([%u],[%u])%c",ind0,ind1,
			     l>=selection.height()-2?'.':',');
                std::fflush(cimg::output());
              }
              if (is_get_version) {
                CImgList<T> fft(img0,img1);
                fft.FFT(inv_fft);
                fft.move_to(images,~0U);
                images_names.insert(2,name.copymark());
              } else {
                CImgList<T> fft(2);
                fft[0].swap(img0);
                fft[1].swap(img1);
                fft.FFT(inv_fft);
                fft[0].swap(img0);
                fft[1].swap(img1);
                name.get_copymark().move_to(images_names[ind1]);
                name.move_to(images_names[ind0]);
              }
              ++l;
            } else { // Real transform.
              if (verbosity>=0 || is_debug) {
                std::fprintf(cimg::output()," ([%u],0)",ind0);
                std::fflush(cimg::output());
              }
              if (is_get_version) {
                CImgList<T> fft(img0);
                CImg<T>(fft[0].width(),fft[0].height(),fft[0].depth(),fft[0].spectrum(),0).
                  move_to(fft);
                fft.FFT(inv_fft);
                fft.move_to(images,~0U);
                images_names.insert(2,name.copymark());
              } else {
                CImgList<T> fft(1);
                fft[0].swap(img0);
                CImg<T>(fft[0].width(),fft[0].height(),fft[0].depth(),fft[0].spectrum(),0).
                  move_to(fft);
                fft.FFT(inv_fft);
                fft[0].swap(img0);
                fft[1].move_to(images,ind0+1);
                name.get_copymark().move_to(images_names,ind0+1);
                name.move_to(images_names[ind0]);
              }
            }
          }
          is_released = false; continue;
        }

        // Inverse scale of a 3d object.
        const bool divide3d = !std::strcmp("-div3d",command);
        if (!std::strcmp("-mul3d",command) || divide3d) {
          gmic_substitute_args();
          float sx = 0, sy = 1, sz = 1;
          if ((std::sscanf(argument,"%f%c",
                           &sx,&end)==1 && ((sz=sy=sx),1)) ||
              std::sscanf(argument,"%f,%f%c",
                          &sx,&sy,&end)==2 ||
              std::sscanf(argument,"%f,%f,%f%c",
                          &sx,&sy,&sz,&end)==3) {
            if (divide3d)
              print(images,"Scale 3d object%s with factors (1/%g,1/%g,1/%g).",
                    gmic_selection,
                    sx,sy,sz);
            else
              print(images,"Scale 3d object%s with factors (%g,%g,%g).",
                    gmic_selection,
                    sx,sy,sz);
            cimg_forY(selection,l) {
              const unsigned int ind = selection[l];
              CImg<T>& img = gmic_check(images[ind]);
              try {
                if (divide3d) { gmic_apply(img,scale_CImg3d(1/sx,1/sy,1/sz)); }
                else { gmic_apply(img,scale_CImg3d(sx,sy,sz)); }
              } catch (CImgException &e) {
                if (!img.is_CImg3d(true,message))
                  error(images,"Command '-%s3d': Invalid 3d object [%d], in selected image%s "
                        "(%s).",
                        divide3d?"div":"mul",ind,gmic_selection,message);
                else throw e;
              }
            }
          } else { if (divide3d) arg_error("div3d"); else arg_error("mul3d"); }
          is_released = false; ++position; continue;
        }

#endif // #ifdef gmic_float
# 11298 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

        // Check for a custom command, and execute it, if found.
        if (std::strcmp("-input",command)) {
          const char *custom_command = 0, cc = *(command+1);
          bool custom_command_found = false, has_arguments = false;
          CImg<char> substituted_command;
          if ((cc>='a' && cc<='z') || (cc>='A' && cc<='Z') || cc=='_') {
            const int ind = gmic_hashcode(command+1,false);
            cimglist_for(commands_names[ind],l) {
              custom_command = commands_names[ind][l].data();
              const char *const command_code = commands[ind][l].data();
              if (!std::strcmp(command+1,custom_command)) {
                custom_command_found = true;
                if (is_debug) {
                  CImg<char> command_code_text(264);
                  const unsigned int ls = std::strlen(command_code);
                  if (ls>=264) {
                    std::memcpy(command_code_text.data(),command_code,128);
                    std::memcpy(command_code_text.data()+128," ... ",5);
                    std::memcpy(command_code_text.data()+133,command_code+ls-130,131);
                  } else std::strcpy(command_code_text.data(),command_code);
                  for (char *ptrs = command_code_text, *ptrd = ptrs; *ptrs || (bool)(*ptrd=0); ++ptrs)
                    if (*ptrs==1) while (*ptrs!=' ') ++ptrs; else *(ptrd++) = *ptrs;
                  debug(images,"Found custom command '%s: %s' (%s).",
                        custom_command,command_code_text.data(),
                        commands_has_arguments[ind](l,0)?"takes arguments":"takes no arguments");
                }
                CImgList<char> arguments(32);
                // Set $0 to be the command name.
                CImg<char>::string(custom_command).move_to(arguments[0]);
                unsigned int nb_arguments = 0;

                if (commands_has_arguments[ind](l,0)) { // Command takes arguments.
                  gmic_substitute_args();

                  // Extract possible command arguments.
                  for (const char *ss = argument, *_ss = ss; _ss; ss =_ss+1)
                    if ((_ss=std::strchr(ss,','))!=0) {
                      if (ss==_ss) ++nb_arguments;
                      else {
                        if (++nb_arguments>=arguments.size())
                          arguments.insert(2+2*nb_arguments-arguments.size());
                        CImg<char> arg_item(ss,_ss-ss+1);
                        arg_item.back() = 0;
                        arg_item.move_to(arguments[nb_arguments]);
                      }
                    } else {
                      if (*ss) {
                        if (++nb_arguments>=arguments.size())
                          arguments.insert(1+nb_arguments-arguments.size());
                        if (*ss!=',') CImg<char>::string(ss).move_to(arguments[nb_arguments]);
                      }
                      break;
                    }

                  if (is_debug) {
                    debug(images,"Found %d given argument%s for command '%s'%s",
                          nb_arguments,nb_arguments!=1?"s":"",
                          custom_command,nb_arguments>0?":":".");
                    for (unsigned int i = 1; i<=nb_arguments; ++i)
                      if (arguments[i]) debug(images,"  $%d = '%s'",i,arguments[i].data());
                      else debug(images,"  $%d = (undefined)",i);
                  }
                }

                // Substitute arguments in custom command expression.
                CImgList<char> substituted_items;
                CImg<char> inbraces;
                for (const char *nsource = command_code; *nsource;)
                  if (*nsource!='$') {
                    // If not starting with '$'.
                    const char *const nsource0 = nsource;
                    nsource = std::strchr(nsource0,'$');
                    if (!nsource) nsource = &commands[ind][l].back();
                    CImg<char>(nsource0,nsource-nsource0).move_to(substituted_items);
                  } else { // '$' expression found.
                    CImg<char> substr(324);
                    inbraces.assign(1,1,1,1,0);
                    int ind = 0, ind1 = 0, l_inbraces = 0;
                    bool is_braces = false;
                    char sep = 0;

                    if (nsource[1]=='{') {
                      const char *const ptr_beg = nsource + 2, *ptr_end = ptr_beg;
                      unsigned int p = 0;
                      for (p = 1; p>0 && *ptr_end; ++ptr_end) {
                        if (*ptr_end=='{') ++p;
                        if (*ptr_end=='}') --p;
                      }
                      if (p) { CImg<char>(nsource++,1).move_to(substituted_items); continue; }
                      l_inbraces = ptr_end - ptr_beg - 1;
                      if (l_inbraces>0) inbraces.assign(ptr_beg,l_inbraces + 1).back() = 0;
                      is_braces = true;
                    }

                    // Substitute $? -> string describing image indices.
                    if (nsource[1]=='?') {
                      nsource+=2;
                      cimg_snprintf(substr,substr.width(),"%s",gmic_selection);
                      CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

                      // Substitute $# -> maximum indice of known arguments.
                    } else if (nsource[1]=='#') {
                      nsource+=2;
                      cimg_snprintf(substr,substr.width(),"%u",nb_arguments);
                      CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
                      has_arguments = true;

                      // Substitute $* -> copy of the specified arguments string.
                    } else if (nsource[1]=='*') {
                      nsource+=2;
                      CImg<char>(argument,std::strlen(argument)).move_to(substituted_items);
                      has_arguments = true;

                      // Substitute $"*" -> copy of the specified "quoted" arguments string.
                    } else if (nsource[1]=='\"' && nsource[2]=='*' && nsource[3]=='\"') {
                      nsource+=4;
                      for (unsigned int i = 1; i<=nb_arguments; ++i) {
                        CImg<char>(1,1,1,1,'\"').move_to(substituted_items);
                        CImg<char>(arguments[i].data(),arguments[i].width()-1).
                          move_to(substituted_items);
                        if (i==nb_arguments) CImg<char>(1,1,1,1,'\"').move_to(substituted_items);
                        else CImg<char>(2,1,1,1,'\"',',').move_to(substituted_items);
                      }
                      has_arguments = true;

                      // Substitute $= -> transfer (quoted) arguments to named variables.
                    } else if (nsource[1]=='=' &&
                               std::sscanf(nsource+2,"%255[a-zA-Z0-9_]",title)==1 &&
                               (*title<'0' || *title>'9')) {
                      nsource+=2+std::strlen(title);
                      for (unsigned int i = 0; i<=nb_arguments; ++i) {
                        cimg_snprintf(substr,substr.width()," %s%u=\"",title,i);
                        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
                        CImg<char>(arguments[i].data(),arguments[i].width()-1).
                          move_to(substituted_items);
                        CImg<char>(2,1,1,1,'\"',' ').move_to(substituted_items);
                      }
                      has_arguments = true;

                      // Substitute $i and ${i} -> value of the i^th argument.
                    } else if ((std::sscanf(nsource,"$%d",&ind)==1 ||
                                (std::sscanf(nsource,"${%d%c",&ind,&sep)==2 && sep=='}'))) {
                      const int nind = ind + (ind<0?(int)nb_arguments+1:0);
                      if ((nind<=0 && ind) || nind>=arguments.width() || !arguments[nind]) {
                        error(custom_command,images,
                              "Command '-%s': Undefined argument '$%d', in expression '$%s%d%s' "
                              "(for %u argument%s specified).",
                              custom_command,ind,sep=='}'?"{":"",ind,sep=='}'?"}":"",
                              nb_arguments,nb_arguments!=1?"s":"");
                      }
                      nsource+=cimg_snprintf(substr,substr.width(),"$%d",ind) + (sep=='}'?2:0);
                      if (arguments[nind].width()>1)
                        CImg<char>(arguments[nind].data(),arguments[nind].width()-1).
                          move_to(substituted_items);
                      if (nind!=0) has_arguments = true;

                      // Substitute ${i=$j} -> value of the i^th argument, or the default value,
                      // i.e. the value of another argument.
                    } else if (std::sscanf(nsource,"${%d=$%d%c",&ind,&ind1,&sep)==3 && sep=='}' &&
                               ind>0) {
                      const int nind1 = ind1 + (ind1<0?(int)nb_arguments+1:0);
                      if (nind1<=0 || nind1>=arguments.width() || !arguments[nind1])
                        error(custom_command,images,
                              "Command '-%s': Undefined argument '$%d', in expression '${%d=$%d}' "
                              "(for %u argument%s specified).",
                              custom_command,ind1,ind,ind1,
                              nb_arguments,nb_arguments!=1?"s":"");
                      nsource+=cimg_snprintf(substr,substr.width(),"${%d=$%d}",ind,ind1);
                      if (ind>=arguments.width()) arguments.insert(2+2*ind-arguments.size());
                      if (!arguments[ind]) {
                        arguments[ind] = arguments[nind1];
                        if (ind>(int)nb_arguments) nb_arguments = ind;
                      }
                      if (arguments[ind].width()>1)
                        CImg<char>(arguments[ind].data(),arguments[ind].width()-1).
                          move_to(substituted_items);
                      has_arguments = true;

                      // Substitute ${i=$#} -> value of the i^th argument, or the default value,
                      // i.e. the maximum indice of known arguments.
                    } else if (std::sscanf(nsource,"${%d=$#%c",&ind,&sep)==2 && sep=='}' &&
                               ind>0) {
                      if (ind>=arguments.width()) arguments.insert(2+2*ind-arguments.size());
                      if (!arguments[ind]) {
                        cimg_snprintf(substr,substr.width(),"%u",nb_arguments);
                        CImg<char>::string(substr).move_to(arguments[ind]);
                        if (ind>(int)nb_arguments) nb_arguments = ind;
                      }
                      nsource+=cimg_snprintf(substr,substr.width(),"${%d=$#}",ind);
                      if (arguments[ind].width()>1)
                        CImg<char>(arguments[ind].data(),arguments[ind].width()-1).
                          move_to(substituted_items);
                      has_arguments = true;

                      // Substitute ${i=default} -> value of the i^th argument,
                      // or the specified default value.
                    } else if (std::sscanf(inbraces,"%d%c",&ind,&sep)==2 && sep=='=' &&
                               ind>0) {
                      nsource+=l_inbraces + 3;
                      if (ind>=arguments.width()) arguments.insert(2+2*ind-arguments.size());
                      if (!arguments[ind]) {
                        CImg<char>::string(inbraces.data() +
                                           cimg_snprintf(substr,substr.width(),"%d=",ind)).
                          move_to(arguments[ind]);
                        if (ind>(int)nb_arguments) nb_arguments = ind;
                      }
                      if (arguments[ind].width()>1)
                        CImg<char>(arguments[ind].data(),arguments[ind].width()-1).
                          move_to(substituted_items);
                      has_arguments = true;

                      // Substitute any other expression starting by '$'.
                    } else {

                      // Substitute ${subset} -> values of the selected subset of arguments,
                      // separated by ','.
                      if (is_braces) {
                        if ((*inbraces>='a' && *inbraces<='z') ||
                            (*inbraces>='A' && *inbraces<='Z') ||
                            *inbraces=='_') {
                          CImg<char>(nsource++,1).move_to(substituted_items);
                        } else if (*inbraces) {
                          CImg<unsigned int> inds;
                          const int _verbosity = verbosity;
                          const bool _is_debug = is_debug;
                          bool is_valid_subset = true;
                          verbosity = -16384; is_debug = false;
                          try {
                            inds = selection2cimg(inbraces,nb_arguments+1,
                                                  CImgList<char>::empty(),"",false,
                                                  false,CImg<char>::empty());
                          } catch (...) { inds.assign(); is_valid_subset = false; }
                          verbosity = _verbosity; is_debug = _is_debug;
                          if (is_valid_subset) {
                            nsource+=l_inbraces + 3;
                            if (inds) {
                              cimg_forY(inds,j) {
                                const unsigned int ind = inds[j];
                                if (ind) has_arguments = true;
                                if (!arguments[ind])
                                  error(custom_command,images,
                                        "Command '-%s': Undefined argument '$%d', "
                                        "in expression '${%s}'.",
                                        custom_command,ind,inbraces.data());
                                substituted_items.insert(arguments[ind]);
                                substituted_items.back().back() = ',';
                              }
                              if (substituted_items.back().width()>1)
                                --(substituted_items.back()._width);
                              else substituted_items.remove();
                              has_arguments = true;
                            }
                          } else CImg<char>(nsource++,1).move_to(substituted_items);
                        } else nsource+=3; // Substitute '${}' by ''.
                      } else CImg<char>(nsource++,1).move_to(substituted_items);
                    }
                  }
                CImg<char>::vector(0).move_to(substituted_items);
                (substituted_items>'x').move_to(substituted_command);

                // Substitute special character codes appearing outside strings.
                bool is_dquoted = false;
                for (char *s = substituted_command.data(); *s; ++s) {
                  const char c = *s;
                  if (c=='\"') is_dquoted = !is_dquoted;
                  if (!is_dquoted) *s = c<' '?(c==_dollar?'$':c==_lbrace?'{':c==_rbrace?'}':
                                               c==_comma?',':c==_dquote?'\"':c==_arobace?'@':c):c;
                }

                if (is_debug) {
                  CImg<char> command_code_text(264);
                  const unsigned int l = std::strlen(substituted_command.data());
                  if (l>=264) {
                    std::memcpy(command_code_text.data(),substituted_command.data(),128);
                    std::memcpy(command_code_text.data()+128," ... ",5);
                    std::memcpy(command_code_text.data()+133,substituted_command.data()+l-130,131);
                  } else std::strcpy(command_code_text.data(),substituted_command.data());
                  for (char *ptrs = command_code_text, *ptrd = ptrs; *ptrs || (bool)(*ptrd=0); ++ptrs)
                    if (*ptrs==1) while (*ptrs!=' ') ++ptrs; else *(ptrd++) = *ptrs;
                  debug(images,"Expand command line for command '%s' to: '%s'.",
                        custom_command,command_code_text.data());
                }
                break;
              }
            }
          }

          if (custom_command_found) {
            const CImgList<char>
	      ncommands_line = commands_line_to_CImgList(substituted_command.data());
            unsigned int nvariables_sizes[256];
	    for (unsigned int l = 0; l<256; ++l) nvariables_sizes[l] = variables[l]->size();
            CImgList<char> nimages_names(selection.height());
            CImgList<T> nimages(selection.height());
            unsigned int nposition = 0;
            CImg<char>::string(custom_command).move_to(scope);
            if (is_get_version) {
              cimg_forY(selection,l) {
                nimages[l] = images[selection[l]];
                nimages_names[l] = images_names[selection[l]];
              }
              _parse(ncommands_line,nposition,nimages,nimages_names,nvariables_sizes);
              nimages.move_to(images,~0U);
              cimglist_for(nimages_names,l) nimages_names[l].copymark();
              nimages_names.move_to(images_names,~0U);
            } else {
              cimg_forY(selection,l) {
                if (images[selection[l]].is_shared())
                  nimages[l] = CImg<T>(images[selection[l]],true);
                else nimages[l].swap(images[selection[l]]);
                nimages_names[l].swap(images_names[selection[l]]);
              }
              _parse(ncommands_line,nposition,nimages,nimages_names,nvariables_sizes);
              const unsigned int nb = cimg::min((unsigned int)selection.height(),nimages.size());
              if (nb>0) {
                for (unsigned int i = 0; i<nb; ++i) {
                  if (images[selection[i]].is_shared()) {
                    images[selection[i]] = nimages[i];
                    nimages[i].assign();
                  } else images[selection[i]].swap(nimages[i]);
                  images_names[selection[i]].swap(nimages_names[i]);
                }
                nimages.remove(0,nb-1);
                nimages_names.remove(0,nb-1);
              }
              if (nb<(unsigned int)selection.height())
                remove_images(images,images_names,selection,nb,selection.height()-1);
              else if (nimages) {
                const unsigned int ind0 = selection?selection.back()+1:images.size();
                nimages_names.move_to(images_names,ind0);
                nimages.move_to(images,ind0);
              }
            }
	    for (unsigned int l = 0; l<255; ++l) if (variables[l]->size()>nvariables_sizes[l]) {
		variables_names[l]->remove(nvariables_sizes[l],variables[l]->size()-1);
		variables[l]->remove(nvariables_sizes[l],variables[l]->size()-1);
	      }
            scope.remove();
            is_return = false;
            if (has_arguments) ++position;
            continue;
          }
        }
      }  // if (*item=='-') {

      // Variable assignment.
      char sep = 0;
      if (std::strchr(item,'=') && std::sscanf(item,"%255[a-zA-Z0-9_]%c",title,&sep)==2 &&
          sep=='=' && (*title<'0' || *title>'9')) {
        CImg<char>
          name(title,std::strlen(title)+1),
          value = CImg<char>::string(item+name.width());
        int ind = 0; bool is_name_found = false;
        const bool is_global = *name=='_';
        const unsigned int sind = gmic_hashcode(name,true);
	const int lind = is_global?0:variables_sizes[sind];
        if (is_global) cimg::mutex(29);
        CImgList<char>
	  &__variables = *variables[sind],
	  &__variables_names = *variables_names[sind];
	for (int l = __variables.size()-1; l>=lind; --l)
	  if (!std::strcmp(__variables_names[l],name)) {
	    is_name_found = true; ind = l; break;
	  }
        print(images,"Set %s variable %s='%s'.",
              *name=='_'?"global":"local",
              name.data(),value.data());
        if (is_name_found) value.move_to(__variables[ind]);
        else { name.move_to(__variables_names); value.move_to(__variables); }
        if (is_global) cimg::mutex(29,0);
        continue;
      }

      // Input.
      if (!std::strcmp("-input",command) && !is_get_version) ++position;
      else { std::strcpy(command,"-input"); argument = item; *restriction = 0; }
      gmic_substitute_args();
      if (!is_restriction || !selection) selection.assign(1,1,1,1,images.size());
      CImg<char> indicesy(256), indicesz(256), indicesc(256);
      float dx = 0, dy = 1, dz = 1, dc = 1, nb = 1;
      char sepx = 0, sepy = 0, sepz = 0, sepc = 0;
      CImg<unsigned int> indx, indy, indz, indc;
      CImgList<char> input_images_names;
      CImgList<T> input_images;
      *indices = *indicesy = *indicesz = *indicesc = *argx = *argy = *argz = *argc = 0;

      CImg<char> arg_input(argument,std::strlen(argument)+1);
      gmic_strreplace(arg_input);

      if (*arg_input=='0' && !arg_input[1]) {

        // Empty image.
        print(images,"Input empty image at position%s",
              gmic_selection);
        input_images.assign(1);
        CImg<char>::string("[empty]").move_to(input_images_names);


      } else if ((std::sscanf(arg_input,"[%255[a-zA-Z_0-9%.eE%^,:+-]%c%c",indices,&sep,&end)==2 &&
                  sep==']') ||
                 std::sscanf(arg_input,"[%255[a-zA-Z_0-9%.eE%^,:+-]]x%f%c",indices,&nb,&end)==2) {

        // Nb copies of existing images.
        nb = cimg::round(nb);
        const CImg<unsigned int> inds = selection2cimg(indices,images.size(),images_names,
						       "-input",true,false,CImg<char>::empty());
        CImg<char> s_tmp(256);
        std::strncpy(s_tmp,selection2string(inds,images_names,true).data(),s_tmp.width()-1);
        s_tmp[s_tmp.width()-1] = 0;
        if (nb<=0) arg_error("input");
        if (nb!=1)
          print(images,"Input %u copies of image%s at position%s",
                (unsigned int)nb,
                s_tmp.data(),
                gmic_selection);
        else
          print(images,"Input copy of image%s at position%s",
                s_tmp.data(),
                gmic_selection);
        for (unsigned int i = 0; i<(unsigned int)nb; ++i) cimg_foroff(inds,l) {
            input_images.insert(gmic_check(images[inds[l]]));
            input_images_names.insert(images_names[inds[l]].get_copymark());
          }
      } else if ((sep=0,true) &&
                 (std::sscanf(arg_input,"%255[][a-zA-Z0-9_.eE%+-]%c",
                              argx,&end)==1 ||
                  std::sscanf(arg_input,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                              argx,argy,&end)==2 ||
                  std::sscanf(arg_input,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
			      "%255[][a-zA-Z0-9_.eE%+-]%c",
                              argx,argy,argz,&end)==3 ||
                  std::sscanf(arg_input,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
			      "%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                              argx,argy,argz,argc,&end)==4 ||
                  std::sscanf(arg_input,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
			      "%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],%c",
                              argx,argy,argz,argc,&sep)==5) &&
                 ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sepx,&end)==2 &&
		   sepx==']' &&
                   (indx=selection2cimg(indices,images.size(),images_names,"-input",true,
                                        false,CImg<char>::empty())).height()==1) ||
                  (std::sscanf(argx,"%f%c",&dx,&end)==1 && dx>=1) ||
                  (std::sscanf(argx,"%f%c%c",&dx,&sepx,&end)==2 && dx>0 && sepx=='%')) &&
                 (!*argy ||
                  (std::sscanf(argy,"[%255[a-zA-Z0-9_.%+-]%c%c",indicesy.data(),&sepy,&end)==2 &&
		   sepy==']' &&
                   (indy=selection2cimg(indicesy,images.size(),images_names,"-input",true,
                                        false,CImg<char>::empty())).height()==1) ||
                  (std::sscanf(argy,"%f%c",&dy,&end)==1 && dy>=1) ||
                  (std::sscanf(argy,"%f%c%c",&dy,&sepy,&end)==2 && dy>0 && sepy=='%')) &&
                 (!*argz ||
                  (std::sscanf(argz,"[%255[a-zA-Z0-9_.%+-]%c%c",indicesz.data(),&sepz,&end)==2 &&
		   sepz==']' &&
                   (indz=selection2cimg(indicesz,images.size(),images_names,"-input",true,
                                        false,CImg<char>::empty())).height()==1) ||
                  (std::sscanf(argz,"%f%c",&dz,&end)==1 && dz>=1) ||
                  (std::sscanf(argz,"%f%c%c",&dz,&sepz,&end)==2 && dz>0 && sepz=='%')) &&
                 (!*argc ||
                  (std::sscanf(argc,"[%255[a-zA-Z0-9_.%+-]%c%c",indicesc.data(),&sepc,&end)==2 &&
		   sepc==']' &&
                   (indc=selection2cimg(indicesc,images.size(),images_names,"-input",true,
                                        false,CImg<char>::empty())).height()==1) ||
                  (std::sscanf(argc,"%f%c",&dc,&end)==1 && dc>=1) ||
                  (std::sscanf(argc,"%f%c%c",&dc,&sepc,&end)==2 && dc>0 && sepc=='%'))) {

        // New image with specified dimensions and optionally values.
        if (indx) { dx = (float)gmic_check(images[*indx]).width(); sepx = 0; }
        if (indy) { dy = (float)gmic_check(images[*indy]).height(); sepy = 0; }
        if (indz) { dz = (float)gmic_check(images[*indz]).depth(); sepz = 0; }
        if (indc) { dc = (float)gmic_check(images[*indc]).spectrum(); sepc = 0; }
        int idx = 0, idy = 0, idz = 0, idc = 0;
        const CImg<T>& img = images.size()?gmic_check(images.back()):CImg<T>::empty();
        if (sepx=='%') { idx = (int)cimg::round(dx*img.width()/100); if (!idx) ++idx; }
        else idx = (int)cimg::round(dx);
        if (sepy=='%') { idy = (int)cimg::round(dy*img.height()/100); if (!idy) ++idy; }
        else idy = (int)cimg::round(dy);
        if (sepz=='%') { idz = (int)cimg::round(dz*img.depth()/100); if (!idz) ++idz; }
        else idz = (int)cimg::round(dz);
        if (sepc=='%') { idc = (int)cimg::round(dc*img.spectrum()/100); if (!idc) ++idc; }
        else idc = (int)cimg::round(dc);
        if (idx<=0 || idy<=0 || idz<=0 || idc<=0) arg_error("input");
        CImg<char> s_values;
        if (sep) {
          const char *_s_values = arg_input.data() + std::strlen(argx) + std::strlen(argy) +
            std::strlen(argz) + std::strlen(argc) + 4;
          s_values.assign(_s_values,std::strlen(_s_values)+1);
          cimg::strpare(s_values,'\'',true,false);
          gmic_strreplace(s_values);
          CImg<char> s_values_text(72);
          *s_values_text = 0;
          const unsigned int l = std::strlen(s_values);
          if (l>=72) {
            std::memcpy(s_values_text.data(),s_values.data(),32);
            std::memcpy(s_values_text.data()+32," ... ",5);
            std::memcpy(s_values_text.data()+37,s_values.data()+l-34,35);  // Last '\0' is included.
          } else std::strcpy(s_values_text,s_values);
          print(images,"Input image at position%s, with values '%s'",
                gmic_selection,s_values_text.data());
        } else
          print(images,"Input black image at position%s",
                gmic_selection);
        CImg<T> new_image(idx,idy,idz,idc,0);
        if (s_values) {
          new_image.fill(s_values.data(),true);
          cimg_snprintf(title,_title.size(),"[image of '%s']",s_values.data());
          gmic_ellipsize(title,_title.size());
          CImg<char>::string(title).move_to(input_images_names);
        } else CImg<char>::string("[unnamed]").move_to(input_images_names);
        new_image.move_to(input_images);

      } else if (*arg_input=='(' && arg_input[std::strlen(arg_input)-1]==')') {

        // New IxJxKxL image specified as array.
        unsigned int cx = 0, cy = 0, cz = 0, cc = 0, maxcx = 0, maxcy = 0, maxcz = 0;
        const char *nargument = 0;
        for (nargument = arg_input.data() + 1; *nargument; ) {
          CImg<char> s_value(256);
          *s_value = 0;
          char separator = 0;
          double value = 0;
          if (std::sscanf(nargument,"%255[0-9.eE+-]%c",s_value.data(),&separator)==2 &&
              std::sscanf(s_value,"%lf%c",&value,&end)==1) {
            if (cx>maxcx) maxcx = cx;
            if (cy>maxcy) maxcy = cy;
            if (cz>maxcz) maxcz = cz;
            switch (separator) {
            case '^' : cx = cy = cz = 0; ++cc; break;
            case '/' : cx = cy = 0; ++cz; break;
            case ';' : cx = 0; ++cy; break;
            case ',' : ++cx; break;
            case ')' : break;
            default : arg_error("input");
            }
            nargument+=std::strlen(s_value) + 1;
          } else break;
        }
        if (*nargument) arg_error("input");
        CImg<T> img(maxcx+1,maxcy+1,maxcz+1,cc+1,0);
        cx = cy = cz = cc = 0;
        for (nargument = arg_input.data() + 1; *nargument; ) {
          CImg<char> s_value(256);
          *s_value = 0;
          char separator = 0;
          double value = 0;
          if (std::sscanf(nargument,"%255[0-9.eE+-]%c",s_value.data(),&separator)==2 &&
              std::sscanf(s_value,"%lf%c",&value,&end)==1) {
            img(cx,cy,cz,cc) = (T)value;
            switch (separator) {
            case '^' : cx = cy = cz = 0; ++cc; break;
            case '/' : cx = cy = 0; ++cz; break;
            case ';' : cx = 0; ++cy; break;
            default : ++cx;
            }
            nargument+=std::strlen(s_value) + (separator?1:0);
          } else break;
        }
        print(images,"Input image at position%s, with values '%s'",
              gmic_selection,
              argument_text);
        img.move_to(input_images);
        arg_input.move_to(input_images_names);

      } else {

        // Input filename.
        char cext[8];
        CImg<char> _filename(4096), filename_tmp(512), options(256);
        *cext = *_filename = *filename_tmp = *options = 0;
        bool is_network_file = false;
        if (std::sscanf(argument,"%8[a-zA-Z]:%4095[^,],%255s",cext,_filename.data(),options.data())<2 ||
            !cext[1] || // length of 'ext' must be >=2 (avoid case 'C:\\..' on Windows).
            !cimg::strcasecmp(cext,"http") || !cimg::strcasecmp(cext,"https")) {
          *cext = *_filename = *options = 0;
          if (std::sscanf(argument,"%4095[^,],%255s",_filename.data(),options.data())!=2) {
            std::strncpy(_filename,argument,_filename.width()-1);
            _filename[_filename.width()-1] = 0;
          }
        }
        gmic_strreplace(_filename);
        gmic_strreplace(options);
        CImg<char> __filename0 = CImg<char>::string(_filename);
        const char *const _filename0 = __filename0.data();

        // Test for network file requests.
        if (!cimg::strncasecmp(_filename,"http://",7) ||
            !cimg::strncasecmp(_filename,"https://",8)) {
          cimg::load_network_external(_filename,filename_tmp);
          std::strncpy(_filename,filename_tmp,_filename.width()-1);
          _filename[_filename.width()-1] = 0;
          *filename_tmp = 0;
          is_network_file = true;
        }

        if (*cext) { // Force output to be read as a '.ext' file : generate random filename.
          if (*_filename=='-' && (!_filename[1] || _filename[1]=='.')) {
            // Simplify filename 'ext:-.foo' as '-.ext'.
            cimg_snprintf(_filename,_filename.width(),"-.%s",cext);
            *cext = 0;
          } else {
            std::FILE *file = 0;
            do {
              cimg_snprintf(filename_tmp,filename_tmp.width(),"%s%c%s.%s",
                            cimg::temporary_path(),cimg_file_separator,
                            cimg::filenamerand(),cext);
              if ((file=std::fopen(filename_tmp,"rb"))!=0) std::fclose(file);
            } while (file);

            // Make a temporary copy (or link) of the original file.
#if cimg_OS==1
            const char *const _filename_path = realpath(_filename,0);
            if (symlink(_filename_path,filename_tmp))
              CImg<unsigned char>::get_load_raw(_filename).save_raw(filename_tmp);
            std::free((void*)_filename_path);
#else // #if cimg_OS==1
# 11913 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            CImg<unsigned char>::get_load_raw(_filename).save_raw(filename_tmp);
#endif // #if cimg_OS==1
# 11915 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
          }
        }

        const char
          *const filename = *filename_tmp?filename_tmp:_filename,
          *const ext = cimg::split_filename(filename);

        std::FILE *const file = std::fopen(filename,"rb");
        long siz = 0;
        if (file) { std::fseek(file,0,SEEK_END); siz = std::ftell(file); std::fclose(file); }
        if (file && siz==0) { // Empty file -> Insert an empty image.
          input_images_names.insert(__filename0);
          input_images.insert(1);
        } else if (!cimg::strcasecmp("off",ext)) {

          // 3d object .off file.
          print(images,"Input 3d object '%s' at position%s",
                _filename0,gmic_selection);
          CImgList<unsigned int> primitives;
          CImgList<float> colors;
          CImg<float> vertices = CImg<float>::get_load_off(primitives,colors,filename);
          const CImg<float> opacities(1,primitives.size(),1,1,1);
          vertices.object3dtoCImg3d(primitives,colors,opacities,false).move_to(input_images);
          input_images_names.insert(__filename0);
        } else if (!cimg::strcasecmp(ext,"cimg") && *options) {

          // .cimg file (non-compressed).
          float
            n0 = -1, x0 = -1, y0 = -1, z0 = -1, c0 = -1,
            n1 = -1, x1 = -1, y1 = -1, z1 = -1, c1 = -1;
          if ((std::sscanf(options,"%f,%f%c",
                           &n0,&n1,&end)==2 ||
               std::sscanf(options,"%f,%f,%f,%f%c",
                           &n0,&n1,&x0,&x1,&end)==4 ||
               std::sscanf(options,"%f,%f,%f,%f,%f,%f%c",
                           &n0,&n1,&x0,&y0,&x1,&y1,&end)==6 ||
               std::sscanf(options,"%f,%f,%f,%f,%f,%f,%f,%f%c",
                           &n0,&n1,&x0,&y0,&z0,&x1,&y1,&z1,&end)==8 ||
               std::sscanf(options,"%f,%f,%f,%f,%f,%f,%f,%f,%f,%f%c",
                           &n0,&n1,&x0,&y0,&z0,&c0,&x1,&y1,&z1,&c1,&end)==10) &&
              (n0==-1 || n0>=0) && (n1==-1 || n1>=0) &&
              (x0==-1 || x0>=0) && (x1==-1 || x1>=0) &&
              (y0==-1 || y0>=0) && (y1==-1 || y1>=0) &&
              (z0==-1 || z0>=0) && (z1==-1 || z1>=0) &&
              (c0==-1 || c0>=0) && (c1==-1 || c1>=0)) {
            n0 = cimg::round(n0); n1 = cimg::round(n1);
            x0 = cimg::round(x0); x1 = cimg::round(x1);
            y0 = cimg::round(y0); y1 = cimg::round(y1);
            z0 = cimg::round(z0); z1 = cimg::round(z1);
            c0 = cimg::round(c0); c1 = cimg::round(c1);
            if (c0==-1 && c1==-1) {
              if (z0==-1 && z1==-1) {
                if (y0==-1 && y1==-1) {
                  if (x0==-1 && x1==-1) {
                    print(images,"Input crop [%d] -> [%d] of file '%s' at position%s",
                          (int)n0,(int)n1,
                          _filename0,gmic_selection);
                    input_images.load_cimg(filename,
                                           (unsigned int)n0,(unsigned int)n1,
                                           0U,0U,0U,0U,~0U,~0U,~0U,~0U);
                  } else {
                    print(images,"Input crop [%d](%d) -> [%d](%d) of file '%s' at position%s",
                          (int)n0,(int)x0,(int)n1,(int)x1,
                          _filename0,gmic_selection);
                    input_images.load_cimg(filename,
                                           (unsigned int)n0,(unsigned int)n1,
                                           (unsigned int)x0,0U,0U,0U,
                                           (unsigned int)x1,~0U,~0U,~0U);
                  }
                } else {
                  print(images,"Input crop [%d](%d,%d) -> [%d](%d,%d) of file '%s' at position%s",
                        (int)n0,(int)n1,(int)x0,(int)y0,(int)x1,(int)y1,
                        _filename0,gmic_selection);
                  input_images.load_cimg(filename,
                                         (unsigned int)n0,(unsigned int)n1,
                                         (unsigned int)x0,(unsigned int)y0,0U,0U,
                                         (unsigned int)x1,(unsigned int)y1,~0U,~0U);
                }
              } else {
                print(images,"Input crop [%d](%d,%d,%d) -> [%d](%d,%d,%d) of file '%s' at position%s",
                      (int)n0,(int)n1,(int)x0,(int)y0,(int)z0,(int)x1,(int)y1,(int)z1,
                      _filename0,gmic_selection);
                input_images.load_cimg(filename,
                                       (unsigned int)n0,(unsigned int)n1,
                                       (unsigned int)x0,(unsigned int)y0,(unsigned int)z0,0U,
                                       (unsigned int)x1,(unsigned int)y1,(unsigned int)z1,~0U);
              }
            } else {
                print(images,"Input crop [%d](%d,%d,%d,%d) -> [%d](%d,%d,%d,%d) of file '%s' at position%s",
                      (int)n0,(int)n1,(int)x0,(int)y0,(int)z0,(int)c0,(int)x1,(int)y1,(int)z1,(int)c1,
                      _filename0,gmic_selection);
                input_images.load_cimg(filename,
                                       (unsigned int)n0,(unsigned int)n1,
                                       (unsigned int)x0,(unsigned int)y0,(unsigned int)z0,(unsigned int)c0,
                                       (unsigned int)x1,(unsigned int)y1,(unsigned int)z1,(unsigned int)c1);
            }

            if (input_images) {
              input_images_names.insert(__filename0);
              if (input_images.size()>1)
                input_images_names.insert(input_images.size()-1,__filename0.copymark());
            }
          } else
            error(images,"Command '-input': .cimg file '%s', invalid file options '%s'.",
                  _filename0,options.data());

        } else if (!cimg::strcasecmp(ext,"avi") ||
                   !cimg::strcasecmp(ext,"mov") ||
                   !cimg::strcasecmp(ext,"asf") ||
                   !cimg::strcasecmp(ext,"divx") ||
                   !cimg::strcasecmp(ext,"flv") ||
                   !cimg::strcasecmp(ext,"mpg") ||
                   !cimg::strcasecmp(ext,"m1v") ||
                   !cimg::strcasecmp(ext,"m2v") ||
                   !cimg::strcasecmp(ext,"m4v") ||
                   !cimg::strcasecmp(ext,"mjp") ||
                   !cimg::strcasecmp(ext,"mkv") ||
                   !cimg::strcasecmp(ext,"mpe") ||
                   !cimg::strcasecmp(ext,"movie") ||
                   !cimg::strcasecmp(ext,"ogm") ||
                   !cimg::strcasecmp(ext,"ogg") ||
                   !cimg::strcasecmp(ext,"qt") ||
                   !cimg::strcasecmp(ext,"rm") ||
                   !cimg::strcasecmp(ext,"vob") ||
                   !cimg::strcasecmp(ext,"wmv") ||
                   !cimg::strcasecmp(ext,"xvid") ||
                   !cimg::strcasecmp(ext,"mpeg")) {

          // Image sequence file.
          float first_frame = 0, last_frame = 0, step = 1;
          char first_sep = 0, last_sep = 0;
          if ((std::sscanf(options,"%f%c,%f%c,%f%c",
                           &first_frame,&first_sep,&last_frame,&last_sep,&step,&end)==5 &&
               first_sep=='%' && last_sep=='%') ||
              (std::sscanf(options,"%f%c,%f,%f%c",
                           &first_frame,&first_sep,&last_frame,&step,&end)==4 &&
               first_sep=='%') ||
              (std::sscanf(options,"%f,%f%c,%f%c",
                           &first_frame,&last_frame,&last_sep,&step,&end)==4 &&
               last_sep=='%') ||
              std::sscanf(options,"%f,%f,%f%c",&first_frame,&last_frame,&step,&end)==3 ||
              (std::sscanf(options,"%f%c,%f%c%c",
                           &first_frame,&first_sep,&last_frame,&last_sep,&end)==4 &&
               first_sep=='%' && last_sep=='%') ||
              (std::sscanf(options,"%f%c,%f%c",&first_frame,&first_sep,&last_frame,&end)==3 &&
               first_sep=='%') ||
              (std::sscanf(options,"%f,%f%c%c",&first_frame,&last_frame,&last_sep,&end)==3 &&
               last_sep=='%') ||
              std::sscanf(options,"%f,%f%c",
                          &first_frame,&last_frame,&end)==2) { // Read several frames
            if (first_frame>last_frame) cimg::swap(first_frame,last_frame,first_sep,last_sep);
            step = cimg::round(step);
            print(images,"Input frames %g%s..%g%s with step %g of file '%s' at position%s",
                  first_frame,first_sep=='%'?"%":"",
                  last_frame,last_sep=='%'?"%":"",
                  step,
                  _filename0,
                  gmic_selection);
            if (first_sep=='%' || last_sep=='%') {
              const unsigned int
		nb_frames = CImg<unsigned int>::get_load_ffmpeg(filename,0,0,0)[0];
              first_frame = cimg::round(first_sep=='%'?first_frame*nb_frames/100:first_frame);
              last_frame = cimg::round(last_sep=='%'?last_frame*nb_frames/100:last_frame);
            }
            input_images.load_ffmpeg(filename,(unsigned int)first_frame,
                                     (unsigned int)last_frame,(unsigned int)step);
          } else if ((std::sscanf(options,"%f%c%c",&first_frame,&first_sep,&end)==2 &&
                      first_sep=='%') ||
                     std::sscanf(options,"%f%c",&first_frame,&end)==1) { // Read a single frame
            step = cimg::round(step);
            print(images,"Input frame %g%s of file '%s' at position%s",
                  first_frame,first_sep=='%'?"%":"",
                  _filename0,
                  gmic_selection);
            if (first_sep=='%') {
              const unsigned int
		nb_frames = CImg<unsigned int>::get_load_ffmpeg(filename,0,0,0)[0];
              first_frame = cimg::round(first_frame*nb_frames/100.0f);
            }
            input_images.load_ffmpeg(filename,(unsigned int)first_frame,(unsigned int)first_frame);
          } else { // Read all frames
            print(images,"Input all frames of file '%s' at position%s",
                  _filename0,
                  gmic_selection);
            input_images.load_ffmpeg(filename);
          }
          if (input_images) {
            input_images_names.insert(__filename0);
            if (input_images.size()>1)
              input_images_names.insert(input_images.size()-1,__filename0.copymark());
          }
        } else if (!cimg::strcasecmp("raw",ext)) {

          // Raw file.
          float dx = 0, dy = 1, dz = 1, dc = 1;
          unsigned long offset = 0;
          *argx = 0;
          if (!*options ||
              std::sscanf(options,"%f%c",&dx,&end)==1 ||
              std::sscanf(options,"%f,%f%c",&dx,&dy,&end)==2 ||
              std::sscanf(options,"%f,%f,%f%c",&dx,&dy,&dz,&end)==3 ||
              std::sscanf(options,"%f,%f,%f,%f%c",&dx,&dy,&dz,&dc,&end)==4 ||
              std::sscanf(options,"%f,%f,%f,%f,%lu%c",&dx,&dy,&dz,&dc,&offset,&end)==5 ||
              std::sscanf(options,"%255[a-zA-Z]%c",argx,&end)==1 ||
              std::sscanf(options,"%255[a-zA-Z],%f%c",argx,&dx,&end)==2 ||
              std::sscanf(options,"%255[a-zA-Z],%f,%f%c",argx,&dx,&dy,&end)==3 ||
              std::sscanf(options,"%255[a-zA-Z],%f,%f,%f%c",argx,&dx,&dy,&dz,&end)==4 ||
              std::sscanf(options,"%255[a-zA-Z],%f,%f,%f,%f%c",argx,&dx,&dy,&dz,&dc,&end)==5 ||
              std::sscanf(options,"%255[a-zA-Z],%f,%f,%f,%f,%lu%c",argx,&dx,&dy,&dz,&dc,&offset,&end)==6) {
            const char *const stype = *argx?argx:cimg::type<T>::string();
            dx = cimg::round(dx);
            dy = cimg::round(dy);
            dz = cimg::round(dz);
            dc = cimg::round(dc);
            if (dx<0 || dy<=0 || dz<=0 || dc<=0)
              error(images,"Command '-input': raw file '%s', invalid specified "
		    "dimensions %gx%gx%gx%g.",
                    _filename0,dx,dy,dz,dc);

            if (offset)
              print(images,"Input raw file '%s' (offset: %lu) with type '%s' at position%s",
                    _filename0,offset,stype,
                    gmic_selection);
            else
              print(images,"Input raw file '%s' with type '%s' at position%s",
                    _filename0,stype,
                    gmic_selection);

#define gmic_load_raw(value_type,svalue_type) \
            if (!cimg::strcasecmp(stype,svalue_type)) \
              CImg<value_type>::get_load_raw(filename,(unsigned int)dx,(unsigned int)dy,\
                                             (unsigned int)dz,(unsigned int)dc,false,false,offset). \
                move_to(input_images);
            gmic_load_raw(bool,"bool")
            else gmic_load_raw(unsigned char,"uchar")
              else gmic_load_raw(unsigned char,"unsigned char")
                else gmic_load_raw(char,"char")
                  else gmic_load_raw(unsigned short,"ushort")
                    else gmic_load_raw(unsigned short,"unsigned short")
                      else gmic_load_raw(short,"short")
                        else gmic_load_raw(unsigned int,"uint")
                          else gmic_load_raw(unsigned int,"unsigned int")
                            else gmic_load_raw(int,"int")
                              else gmic_load_raw(float,"float")
                                else gmic_load_raw(double,"double")
                                  else error(images,"Command '-input': raw file '%s', "
                                             "invalid specified pixel type '%s'.\n",
                                             _filename0,stype);
            input_images_names.insert(__filename0);
          } else
            error(images,"Command '-input': raw file '%s', invalid file options '%s'.",
                  _filename0,options.data());
        } else if (!cimg::strcasecmp("yuv",ext)) {

          // YUV file.
          float first_frame = 0, last_frame = 0, step = 1, dx = 0, dy = 1;
          int err = 0;
          if ((err=std::sscanf(options,"%f,%f,%f,%f,%f",
                               &dx,&dy,&first_frame,&last_frame,&step))>=1) {
            dx = cimg::round(dx);
            dy = cimg::round(dy);
            if (dx<=0 || dy<=0)
              error(images,"Command '-input': YUV file '%s', invalid specified dimensions %gx%g.",
                    _filename0,dx,dy);
            first_frame = cimg::round(first_frame);
            if (err>3) { // Load multiple frames.
              last_frame = cimg::round(last_frame);
              step = cimg::round(step);
              print(images,"Input frames %g..%g with step %g of YUV file '%s' at position%s",
                    first_frame,last_frame,step,
                    _filename0,
                    gmic_selection);
              input_images.load_yuv(filename,(unsigned int)dx,(unsigned int)dy,
                                    (unsigned int)first_frame,(unsigned int)last_frame,
                                    (unsigned int)step);
            } else if (err==3) { // Load a single frame.
              print(images,"Input frames %g of YUV file '%s' at position%s",
                    first_frame,
                    _filename0,
                    gmic_selection);
              input_images.load_yuv(filename,(unsigned int)dx,(unsigned int)dy,
                                    (unsigned int)first_frame,(unsigned int)first_frame);
            } else { // Load all frames.
              print(images,"Input all frames of YUV file '%s' at position%s",
                    _filename0,
                    gmic_selection);
              input_images.load_yuv(filename,(unsigned int)dx,(unsigned int)dy);
            }
            if (input_images) {
              input_images_names.insert(__filename0);
              if (input_images.size()>1)
                input_images_names.insert(input_images.size()-1,__filename0.copymark());
            }
          } else
            error(images,"Command '-input': YUV file '%s', invalid or missing file options '%s'.",
                  _filename0,options.data());

        } else if (!cimg::strcasecmp("tif",ext) || !cimg::strcasecmp("tiff",ext)) {

          // TIFF file.
          float first_frame = 0, last_frame = 0, step = 1;
          int err = 0;
#ifdef cimg_use_tiff
          static const TIFFErrorHandler default_handler = TIFFSetWarningHandler(0);
          if (verbosity>0 || is_debug) TIFFSetWarningHandler(default_handler);
          else TIFFSetWarningHandler(0);
#endif
# 12222 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
          if ((err=std::sscanf(options,"%f,%f,%f",&first_frame,&last_frame,&step))>0) {
            first_frame = cimg::round(first_frame);
            if (err>1) { // Load multiple frames.
              last_frame = cimg::round(last_frame);
              step = cimg::round(step);
              print(images,"Input frames %g..%g with step %g of TIFF file '%s' at position%s",
                    first_frame,last_frame,step,
                    _filename0,
                    gmic_selection);
              input_images.load_tiff(filename,(unsigned int)first_frame,(unsigned int)last_frame,
                                     (unsigned int)step);
            } else if (err==1) { // Load a single frame.
              print(images,"Input frames %g of TIFF file '%s' at position%s",
                    first_frame,
                    _filename0,
                    gmic_selection);
              input_images.load_tiff(filename,(unsigned int)first_frame,(unsigned int)first_frame);
            }
          } else { // Load all frames.
            if (*options) error(images,"Command '-input': TIFF file '%s', "
                                "invalid file options '%s'.",
                                _filename0,options.data());
            print(images,"Input all frames of TIFF file '%s' at position%s",
                  _filename0,
                  gmic_selection);
            input_images.load_tiff(filename);
          }
          if (input_images) {
            input_images_names.insert(__filename0);
            if (input_images.size()>1)
              input_images_names.insert(input_images.size()-1,__filename0.copymark());
          }
        } else if (!cimg::strcasecmp("gmic",ext)) {

          // G'MIC custom commands file
          const bool add_debug_infos = (*options!='0');
          print(images,"Input custom commands file '%s'%s",
                _filename0,!add_debug_infos?" without debug infos":"");
          unsigned int siz = 0;
          for (unsigned int l = 0; l<256; ++l) siz+=commands[l].size();
          std::FILE *const file = cimg::fopen(filename,"rb");
          add_commands(file,filename,commands_names,commands,commands_has_arguments,add_debug_infos);
          cimg::fclose(file);
          if (verbosity>=0 || is_debug) {
            unsigned int nb_added = 0;
            for (unsigned int l = 0; l<256; ++l) nb_added+=commands[l].size();
            nb_added-=siz;
            std::fprintf(cimg::output()," (added %u command%s, total %u).",
                         nb_added,nb_added>1?"s":"",siz+nb_added);
            std::fflush(cimg::output());
          }
          continue;
        } else {

          // Other file types.
          print(images,"Input file '%s' at position%s",
                _filename0,
                gmic_selection);
          try { input_images.load(filename); }
          catch (CImgException&) {
            std::FILE *file = 0;
            if (!(file=std::fopen(filename,"r"))) {
              if (cimg::type<T>::string()==cimg::type<float>::string() || *ext || *filename!='-') {
                if (*filename=='-' && filename[1]) { // Check for command misspelling.
                  const char *native_commands_names[] = {
                    "a","b","c","d","e","f","g","h","i","j","k","l","m","n","o","p","q","r","s",
                    "t","u","v","w","x","y","z",
                    "+","-","*","/",">","<","%","^","=","sh","mv","rm","rv","<<",">>","==",">=",
                    "<=","//","**","!=",
                    "d3d","+3d","b3d","/3d","f3d","l3d","m3d","*3d","o3d","p3d","r3d","s3d","-3d",
                    "t3d","db3d","md3d","rv3d","sl3d","ss3d","div3d",
                    "append","autocrop","add","add3d","abs","and","atan2","acos","asin","atan",
                    "axes",
                    "blur","bsr","bsl","bilateral","background3d","break",
                    "check","check3d","crop","channels","columns","command","camera","cut","cos",
                    "convolve","correlate","color3d","col3d","cosh","continue","cursor",
                    "done","do","debug","divide","distance","dilate","double3d","denoise",
                    "deriche","dijkstra","displacement","display","display3d",
                    "endif","else","elif","endlocal","endl","echo","exec","error","endian","exp",
                    "eq","ellipse","equalize","erode","elevation3d","eigen","eikonal",
                    "fill","flood","focale3d","fft",
                    "ge","gt","gradient","graph",
                    "histogram","hsi2rgb","hsl2rgb","hsv2rgb","hessian",
                    "input","if","image","index","invert","isoline3d","isosurface3d","inpaint",
                    "ifft",
                    "keep",
                    "local","le","lt","log","log2","log10","line","lab2rgb","label","light3d",
                    "move","mirror","mul","mutex","mod","max","min","mmul","mode3d","moded3d",
                    "map","median","mdiv","mse","mandelbrot","mul3d",
                    "name","normalize","neq","noise",
                    "output","onfail","object3d","or","opacity3d",
                    "parallel","permute","progress","print","pow","point","polygon","plasma",
                    "pose3d","primitives3d","plot",
                    "quiver","quit",
                    "remove","repeat","resize","reverse","return","rows","rotate",
                    "round","rand","rotate3d","rgb2hsi","rgb2hsl","rgb2hsv","rgb2lab",
                    "rgb2srgb","rol","ror","reverse3d",
                    "status","skip","set","split","shared","shift","slices","srand","sub","sqrt",
                    "sqr","sign","sin","sort","solve","sub3d","sharpen","smooth","split3d",
                    "svd","sphere3d","specl3d","specs3d","sinc","sinh","srgb2rgb","streamline3d",
                    "structuretensors","select",
                    "type","threshold","tan","text","texturize3d","trisolve","tanh",
                    "unroll","uncommand",
                    "vanvliet","verbose",
                    "while","warning","window","warp","watershed","wait",
                    "xor",0
                  };
                  const char *misspelled = 0;
                  const unsigned int foff = filename[1]=='-'?2:1;
                  int dmin = 4;
                  for (unsigned int l = 0; native_commands_names[l]; ++l) {
                    // Look in native commands.
                    const char *const c = native_commands_names[l];
                    const int d = gmic_levenshtein(c,filename+foff);
                    if (d<dmin) { dmin = d; misspelled = native_commands_names[l]; }
                  }
                  for (unsigned int i = 0; i<256; ++i)
                    // Look in custom commands.
                    cimglist_for(commands_names[i],l) {
                      const char *const c = commands_names[i][l].data();
                      const int d = gmic_levenshtein(c,filename+foff);
                      if (d<dmin) { dmin = d; misspelled = commands_names[i][l].data(); }
                    }
                  if (misspelled)
                    error(images,"Unknown command or filename '%s' (did you mean '-%s' ?).",
                          argument_text,misspelled);
                  else error(images,"Unknown command or filename '%s'.",
                             argument_text);
                } else error(images,"Unknown %s '%s'.",
                             *filename=='-'?"command or filename":"filename",
                             argument_text);
              } else
                error(images,"Unknown command '%s' in '%s' type mode "
                      "(command defined only in 'float' type mode ?).",
                      argument_text,cimg::type<T>::string());
            } else throw;
          }
          input_images_names.insert(__filename0);
          if (input_images.size()>1)
            input_images_names.insert(input_images.size()-1,__filename0.copymark());
        }

        if (*filename_tmp) std::remove(filename_tmp);  // Clean temporary file if used.
        if (is_network_file) std::remove(_filename);   // Clean temporary file if network input.
      }

      if (verbosity>=0 || is_debug) {
        if (input_images) {
          const unsigned int last = input_images.size() - 1;
          if (input_images.size()==1) {
            if (input_images[0].is_CImg3d(false))
              std::fprintf(cimg::output()," (%u vertices, %u primitives).",
                           cimg::float2uint((float)input_images(0,6)),
                           cimg::float2uint((float)input_images(0,7)));
            else
              std::fprintf(cimg::output()," (1 image %dx%dx%dx%d).",
                           input_images[0].width(),input_images[0].height(),
                           input_images[0].depth(),input_images[0].spectrum());
          } else
            std::fprintf(cimg::output()," (%u images [0] = %dx%dx%dx%d, %s[%u] = %dx%dx%dx%d).",
                         input_images.size(),
                         input_images[0].width(),input_images[0].height(),
                         input_images[0].depth(),input_images[0].spectrum(),
                         last==1?"":"..,",last,
                         input_images[last].width(),input_images[last].height(),
                         input_images[last].depth(),input_images[last].spectrum());
        } else {
          std::fprintf(cimg::output()," (no available data).");
          input_images_names.assign();
        }
        std::fflush(cimg::output());
      }

      for (unsigned int l = 0, siz = selection.height()-1U, off = 0; l<=siz; ++l) {
        const unsigned int ind = selection[l] + off;
        off+=input_images.size();
        if (l!=siz) {
          images.insert(input_images,ind);
          images_names.insert(input_images_names,ind);
        } else {
          input_images.move_to(images,ind);
          input_images_names.move_to(images_names,ind);
        }
      }

      if (new_name) new_name.move_to(images_names[selection[0]]);
      is_released = false;
    }

    // Wait for remaining threads to finish.
#ifdef gmic_is_parallel
    cimglist_for(threads_data,i) cimg_forY(threads_data[i],l) {
      if (!threads_data(i,l).wait_mode) {
        cimg::mutex(30);
        *(threads_data(i,l).gmic_instance.cancel) = 1;
        cimg::mutex(30,0);
      }
#if cimg_OS!=2
      pthread_join(threads_data(i,l).thread_id,0);
#else
# 12422 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
      WaitForSingleObject(threads_data(i,l).thread_id,INFINITE);
      CloseHandle(threads_data(i,l).thread_id);
#endif // #if cimg_OS!=2
# 12425 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
      is_released&=threads_data(i,l).gmic_instance.is_released;
    }
    // Check for possible exceptions thrown by threads.
    cimglist_for(threads_data,i) cimg_forY(threads_data[i],l)
      if (threads_data(i,l).exception._message)
        throw threads_data(i,l).exception;
#endif // #ifdef gmic_is_parallel
# 12432 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

    // Post-check global environment consistency.
    if (images_names.size()!=images.size())
      error(images,"Internal error: Images (%u) and images names (%u) have different size, "
	    "at return point.",
            images_names.size(),images.size());
    if (!scope)
      error(images,"Internal error: Scope is empty, at return point.");

    // Post-check local environment consistency.
    if (!is_quit && !is_return) {
      const CImg<char> &s = scope.back();
      if (is_default_type &&
          s[0]=='*' && (s[1]=='d' || s[1]=='i' || s[1]=='r' || (s[1]=='l' && !is_endlocal)))
        error(images,"A '-%s' command is missing, before return point.",
              s[1]=='d'?"while":s[1]=='i'?"endif":s[1]=='r'?"done":"endlocal");
    } else if (initial_scope_size<scope.size()) scope.remove(initial_scope_size,scope.size()-1);

    // Post-check validity of shared images.
    cimglist_for(images,l) gmic_check(images[l]);

    // Display or print result, if not 'released' before.
#if defined(gmic_float) && cimg_display!=0

    if (!is_released && scope.size()==1 && images) {
      CImgList<unsigned int> lselection, lselection3d;
      bool is_first3d = false;
#if cimg_display!=0
      instant_window[0].assign();
#endif
# 12462 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
      cimglist_for(images,l) {
        const bool is_3d = images[l].is_CImg3d(false);
        if (!l) is_first3d = is_3d;
        CImg<unsigned int>::vector(l).move_to(is_3d?lselection3d:lselection);
      }
      if (is_first3d) {
        display_objects3d(images,images_names,lselection3d>'y');
        if (lselection) display_images(images,images_names,lselection>'y',0);
      } else {
        if (lselection) display_images(images,images_names,lselection>'y',0);
        if (lselection3d) display_objects3d(images,images_names,lselection3d>'y');
      }
      is_released = true;
    }

#endif // #if defined(gmic_float)
# 12478 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

    if (is_debug) debug(images,"%sEnd G'MIC parser in scope '%s/' [%s].%s\n",
                        cimg::t_bold,scope.back().data(),CImg<T>::pixel_type(),cimg::t_normal);
    if (!is_debug && !is_quit && scope.size()==1 && is_default_type) {
      print(images,"End G'MIC parser.\n");
      is_quit = true;
    }
  } catch (CImgException &e) {
    CImg<char> error_message(e.what(),std::strlen(e.what())+1);
    for (char *cimg = std::strstr(error_message,"CImg"); cimg; cimg = std::strstr(cimg,"CImg")) {
      cimg[0] = 'g'; cimg[1] = 'm'; cimg[2] = 'i'; cimg[3] = 'c';
    }
    error(images,error_message);
  }
  debug_line = initial_debug_line;
  return *this;
}

// Small hack to separate the compilation of G'MIC for different pixel types.
// (only intended to save computer memory when compiling!)
//--------------------------------------------------------------------------
#if !defined(gmic_float_only) && (defined(gmic_bool) || !defined(gmic_split_compilation))
gmic& gmic::_parse_bool(const CImgList<char>& commands_line, unsigned int& position,
                        CImgList<bool>& images, CImgList<char>& images_names,
                        unsigned int variables_sizes[256]) {
  return _parse(commands_line,position,images,images_names,variables_sizes);
}
template gmic::gmic(const int, const char *const *const, CImgList<bool>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
template gmic::gmic(const char *const, CImgList<bool>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
#endif // #if !defined(gmic_float_only) && (defined(gmic_bool) || !defined(gmic_split_compilation))
# 12512 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#if !defined(gmic_float_only) && (defined(gmic_uchar) || !defined(gmic_split_compilation))
gmic& gmic::_parse_uchar(const CImgList<char>& commands_line, unsigned int& position,
                        CImgList<unsigned char>& images, CImgList<char>& images_names,
			unsigned int variables_sizes[256]) {
  return _parse(commands_line,position,images,images_names,variables_sizes);
}
template gmic::gmic(const int, const char *const *const, CImgList<unsigned char>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
template gmic::gmic(const char *const, CImgList<unsigned char>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
#endif // #if !defined(gmic_float_only) && (defined(gmic_uchar) || !defined(gmic_split_compilation))
# 12525 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#if !defined(gmic_float_only) && (defined(gmic_char) || !defined(gmic_split_compilation))
gmic& gmic::_parse_char(const CImgList<char>& commands_line, unsigned int& position,
                        CImgList<char>& images, CImgList<char>& images_names,
                        unsigned int variables_sizes[256]) {
  return _parse(commands_line,position,images,images_names,variables_sizes);
}
template gmic::gmic(const int, const char *const *const, CImgList<char>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
template gmic::gmic(const char *const, CImgList<char>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
#endif // #if !defined(gmic_float_only) && (defined(gmic_char) || !defined(gmic_split_compilation))
# 12538 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#if !defined(gmic_float_only) && (defined(gmic_ushort) || !defined(gmic_split_compilation))
gmic& gmic::_parse_ushort(const CImgList<char>& commands_line, unsigned int& position,
                          CImgList<unsigned short>& images, CImgList<char>& images_names,
                          unsigned int variables_sizes[256]) {
  return _parse(commands_line,position,images,images_names,variables_sizes);
}
template gmic::gmic(const int, const char *const *const, CImgList<unsigned short>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
template gmic::gmic(const char *const, CImgList<unsigned short>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
#endif // #if !defined(gmic_float_only) && (defined(gmic_ushort) || !defined(gmic_split_compilation))
# 12551 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#if !defined(gmic_float_only) && (defined(gmic_short) || !defined(gmic_split_compilation))
gmic& gmic::_parse_short(const CImgList<char>& commands_line, unsigned int& position,
                         CImgList<short>& images, CImgList<char>& images_names,
                         unsigned int variables_sizes[256]) {
  return _parse(commands_line,position,images,images_names,variables_sizes);
}
template gmic::gmic(const int, const char *const *const, CImgList<short>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
template gmic::gmic(const char *const, CImgList<short>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
#endif // #if !defined(gmic_float_only) && (defined(gmic_short) || !defined(gmic_split_compilation))
# 12564 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#if !defined(gmic_float_only) && (defined(gmic_uint) || !defined(gmic_split_compilation))
gmic& gmic::_parse_uint(const CImgList<char>& commands_line, unsigned int& position,
                        CImgList<unsigned int>& images, CImgList<char>& images_names,
                        unsigned int variables_sizes[256]) {
  return _parse(commands_line,position,images,images_names,variables_sizes);
}
template gmic::gmic(const int, const char *const *const, CImgList<unsigned int>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
template gmic::gmic(const char *const, CImgList<unsigned int>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
#endif // #if !defined(gmic_float_only) && (defined(gmic_uint) || !defined(gmic_split_compilation))
# 12577 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#if !defined(gmic_float_only) && (defined(gmic_int) || !defined(gmic_split_compilation))
gmic& gmic::_parse_int(const CImgList<char>& commands_line, unsigned int& position,
                       CImgList<int>& images, CImgList<char>& images_names,
                       unsigned int variables_sizes[256]) {
  return _parse(commands_line,position,images,images_names,variables_sizes);
}
template gmic::gmic(const int, const char *const *const, CImgList<int>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
template gmic::gmic(const char *const, CImgList<int>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
#endif // #if !defined(gmic_float_only) && (defined(gmic_int) || !defined(gmic_split_compilation))
# 12590 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#if defined(gmic_float) || !defined(gmic_split_compilation)
gmic& gmic::_parse_float(const CImgList<char>& commands_line, unsigned int& position,
                         CImgList<float>& images, CImgList<char>& images_names,
                         unsigned int variables_sizes[256]) {
  return _parse(commands_line,position,images,images_names,variables_sizes);
}
template gmic::gmic(const int, const char *const *const, CImgList<float>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
template gmic::gmic(const char *const, CImgList<float>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
#endif // #if defined(gmic_float) || !defined(gmic_split_compilation)
# 12603 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#if !defined(gmic_float_only) && (defined(gmic_double) || !defined(gmic_split_compilation))
gmic& gmic::_parse_double(const CImgList<char>& commands_line, unsigned int& position,
                          CImgList<double>& images, CImgList<char>& images_names,
                          unsigned int variables_sizes[256]) {
  return _parse(commands_line,position,images,images_names,variables_sizes);
}
template gmic::gmic(const int, const char *const *const, CImgList<double>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
template gmic::gmic(const char *const, CImgList<double>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
#endif // #if !defined(gmic_float_only) && (defined(gmic_double) || !defined(gmic_split_compilation))
# 12616 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

#ifdef gmic_main

//-----------------------
// Start main procedure.
//-----------------------
int main(int argc, char **argv) {

  cimg::output(stdout);
  if (argc==1) {
    std::fprintf(cimg::output(),
                 "[gmic] No commands, options or data provided (type '%s -h' to get help).\n",
                 cimg::basename(argv[0]));
    std::fflush(cimg::output());
    std::exit(0);
  }

  // Check if help has been requested.
  char command_line[256] = { 0 };
  const char
    *const is_help1 = cimg_option("-h",(char*)0,0),
    *const is_help2 = cimg_option("--h",(char*)0,0),
    *const is_help3 = cimg_option("-help",(char*)0,0),
    *const is_help4 = cimg_option("--help",(char*)0,0);
  if (is_help1 || is_help2 || is_help3 || is_help4) {

    // Load all specified commands definitions data.
    CImgList<> images;
    CImgList<char> images_names;
    CImg<unsigned char>(data_gmic_def,1,size_data_gmic_def,1,1).move_to(images);
    const unsigned int omode = cimg::exception_mode();
    cimg::exception_mode() = 0;
    for (int i = 1; i<argc; ++i) {
      std::FILE *file = 0;
      char filename_tmp[1024] = { 0 };
      if ((!std::strcmp("-m",argv[i]) || !std::strcmp("-command",argv[i])) && i<argc-1) {
        const char *const filename = argv[++i];
        if (!cimg::strncasecmp(filename,"http://",7) || !cimg::strncasecmp(filename,"https://",8))
          try {
            file = std::fopen(cimg::load_network_external(filename,filename_tmp),"r");
          } catch (CImgException&) { file = 0; }
        else file = std::fopen(filename,"r");
      } else if (!cimg::strcasecmp("gmic",cimg::split_filename(argv[i]))) {
        const char *const filename = argv[i];
        if (!cimg::strncasecmp(filename,"http://",7) || !cimg::strncasecmp(filename,"https://",8))
          try {
            file = std::fopen(cimg::load_network_external(filename,filename_tmp),"r");
          } catch (CImgException&) { file = 0; }
        else file = std::fopen(filename,"r");
      }
      if (file) {
        CImg<unsigned char>::get_load_raw(file).move_to(images,0);
        CImg<unsigned char>::vector('\n').move_to(images,1);
        cimg::fclose(file);
        if (*filename_tmp) std::remove(filename_tmp);
      }
    }
    cimg::exception_mode() = omode;

    const char
      *const is_help = is_help1?"-h":is_help2?"--h":is_help3?"-help":"--help",
      *const command = is_help1?is_help1:is_help2?is_help2:is_help3?is_help3:is_help4;
    if (!std::strcmp(is_help,command)) gmic("-v - -help",images,images_names); // Global help.
    else { // Help for a specified command.
      cimg_snprintf(command_line,sizeof(command_line),"-v - -help \"%s\",1",command);
      gmic(command_line,images,images_names);
    }
    std::exit(0);
  }

  // Launch G'MIC instance.
  const char *const is_debug = cimg_option("-debug",(char*)0,0);
  cimg::output(is_debug?stdout:stderr);
  CImgList<float> images;
  CImgList<char> images_names;
  try { gmic(argc,argv,images,images_names); }
  catch (gmic_exception &e) {
    std::fprintf(cimg::output(),"\n[gmic] %s%s%s%s",
                 cimg::t_red,cimg::t_bold,e.what(),cimg::t_normal);
    if (*e.command_help()) {
      std::fprintf(cimg::output(),"\n[gmic] Command '-%s' has the following description: \n",
		   e.command_help());
      images.assign(); images_names.assign();
      CImg<unsigned char>(data_gmic_def,1,size_data_gmic_def,1,1).move_to(images);
      cimg_snprintf(command_line,sizeof(command_line),"-v - -help \"%s\",0",e.command_help());
      gmic(command_line,images,images_names);
    } else { std::fprintf(cimg::output(),"\n\n"); std::fflush(cimg::output()); }
    return -1;
  }
  return 0;
}
#endif // #ifdef gmic_main
# 12708 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

#endif // #ifdef cimg_plugin
# 12710 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
# 9526 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h" 2
#endif
# 9527 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_plugin1
#if 0 /* expanded by -frewrite-includes */
#include cimg_plugin1
#endif /* expanded by -frewrite-includes */
# 9529 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 9530 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_plugin2
#if 0 /* expanded by -frewrite-includes */
#include cimg_plugin2
#endif /* expanded by -frewrite-includes */
# 9532 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 9533 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_plugin3
#if 0 /* expanded by -frewrite-includes */
#include cimg_plugin3
#endif /* expanded by -frewrite-includes */
# 9535 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 9536 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_plugin4
#if 0 /* expanded by -frewrite-includes */
#include cimg_plugin4
#endif /* expanded by -frewrite-includes */
# 9538 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 9539 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_plugin5
#if 0 /* expanded by -frewrite-includes */
#include cimg_plugin5
#endif /* expanded by -frewrite-includes */
# 9541 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 9542 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_plugin6
#if 0 /* expanded by -frewrite-includes */
#include cimg_plugin6
#endif /* expanded by -frewrite-includes */
# 9544 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 9545 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_plugin7
#if 0 /* expanded by -frewrite-includes */
#include cimg_plugin7
#endif /* expanded by -frewrite-includes */
# 9547 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 9548 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_plugin8
#if 0 /* expanded by -frewrite-includes */
#include cimg_plugin8
#endif /* expanded by -frewrite-includes */
# 9550 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 9551 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    //@}
    //---------------------------------------------------------
    //
    //! \name Constructors / Destructor / Instance Management
    //@{
    //---------------------------------------------------------

    //! Destroy image.
    /**
       \note
       - The pixel buffer data() is deallocated if necessary, e.g. for non-empty and non-shared image instances.
       - Destroying an empty or shared image does nothing actually.
       \warning
       - When destroying a non-shared image, make sure that you will \e not operate on a remaining shared image
         that shares its buffer with the destroyed instance, in order to avoid further invalid memory access (to a deallocated buffer).
    **/
    ~CImg() {
      if (!_is_shared) delete[] _data;
    }

    //! Construct empty image.
    /**
       \note
       - An empty image has no pixel data and all of its dimensions width(), height(), depth(), spectrum()
         are set to \c 0, as well as its pixel buffer pointer data().
       - An empty image may be re-assigned afterwards, e.g. with the family of assign(unsigned int,unsigned int,unsigned int,unsigned int) methods,
         or by operator=(const CImg<t>&). In all cases, the type of pixels stays \c T.
       - An empty image is never shared.
       \par Example
       \code
       CImg<float> img1, img2;      // Construct two empty images.
       img1.assign(256,256,1,3);    // Re-assign 'img1' to be a 256x256x1x3 (color) image.
       img2 = img1.get_rand(0,255); // Re-assign 'img2' to be a random-valued version of 'img1'.
       img2.assign();               // Re-assign 'img2' to be an empty image again.
       \endcode
    **/
    CImg():_width(0),_height(0),_depth(0),_spectrum(0),_is_shared(false),_data(0) {}

    //! Construct image with specified size.
    /**
       \param size_x Image width().
       \param size_y Image height().
       \param size_z Image depth().
       \param size_c Image spectrum() (number of channels).
       \note
       - It is able to create only \e non-shared images, and allocates thus a pixel buffer data() for each constructed image instance.
       - Setting one dimension \c size_x,\c size_y,\c size_z or \c size_c to \c 0 leads to the construction of an \e empty image.
       - A \c CImgInstanceException is thrown when the pixel buffer cannot be allocated (e.g. when requested size is too big for available memory).
       \warning
       - The allocated pixel buffer is \e not filled with a default value, and is likely to contain garbage values.
         In order to initialize pixel values during construction (e.g. with \c 0), use constructor
         CImg(unsigned int,unsigned int,unsigned int,unsigned int,T) instead.
       \par Example
       \code
       CImg<float> img1(256,256,1,3);   // Construct a 256x256x1x3 (color) image, filled with garbage values.
       CImg<float> img2(256,256,1,3,0); // Construct a 256x256x1x3 (color) image, filled with value '0'.
       \endcode
    **/
    explicit CImg(const unsigned int size_x, const unsigned int size_y=1, const unsigned int size_z=1, const unsigned int size_c=1):
      _is_shared(false) {
      const unsigned long siz = (unsigned long)size_x*size_y*size_z*size_c;
      if (siz) {
        _width = size_x; _height = size_y; _depth = size_z; _spectrum = size_c;
        try { _data = new T[siz]; } catch (...) {
          _width = _height = _depth = _spectrum = 0; _data = 0;
          throw CImgInstanceException(_cimg_instance
                                      "CImg(): Failed to allocate memory (%s) for image (%u,%u,%u,%u).",
                                      cimg_instance,
                                      cimg::strbuffersize(sizeof(T)*size_x*size_y*size_z*size_c),size_x,size_y,size_z,size_c);
        }
      } else { _width = _height = _depth = _spectrum = 0; _data = 0; }
    }

    //! Construct image with specified size and initialize pixel values.
    /**
       \param size_x Image width().
       \param size_y Image height().
       \param size_z Image depth().
       \param size_c Image spectrum() (number of channels).
       \param value Initialization value.
       \note
       - Similar to CImg(unsigned int,unsigned int,unsigned int,unsigned int),
         but it also fills the pixel buffer with the specified \c value.
       \warning
       - It cannot be used to construct a vector-valued image and initialize it with \e vector-valued pixels (e.g. RGB vector, for color images).
         For this task, you may use fillC() after construction.
    **/
    CImg(const unsigned int size_x, const unsigned int size_y, const unsigned int size_z, const unsigned int size_c, const T value):
      _is_shared(false) {
      const unsigned long siz = (unsigned long)size_x*size_y*size_z*size_c;
      if (siz) {
        _width = size_x; _height = size_y; _depth = size_z; _spectrum = size_c;
        try { _data = new T[siz]; } catch (...) {
          _width = _height = _depth = _spectrum = 0; _data = 0;
          throw CImgInstanceException(_cimg_instance
                                      "CImg(): Failed to allocate memory (%s) for image (%u,%u,%u,%u).",
                                      cimg_instance,
                                      cimg::strbuffersize(sizeof(T)*size_x*size_y*size_z*size_c),size_x,size_y,size_z,size_c);
        }
        fill(value);
      } else { _width = _height = _depth = _spectrum = 0; _data = 0; }
    }

    //! Construct image with specified size and initialize pixel values from a sequence of integers.
    /**
       Construct a new image instance of size \c size_x x \c size_y x \c size_z x \c size_c, with pixels of type \c T, and initialize pixel
       values from the specified sequence of integers \c value0,\c value1,\c ...
       \param size_x Image width().
       \param size_y Image height().
       \param size_z Image depth().
       \param size_c Image spectrum() (number of channels).
       \param value0 First value of the initialization sequence (must be an \e integer).
       \param value1 Second value of the initialization sequence (must be an \e integer).
       \param ...
       \note
       - Similar to CImg(unsigned int,unsigned int,unsigned int,unsigned int), but it also fills
         the pixel buffer with a sequence of specified integer values.
       \warning
       - You must specify \e exactly \c size_x*\c size_y*\c size_z*\c size_c integers in the initialization sequence.
         Otherwise, the constructor may crash or fill your image pixels with garbage.
       \par Example
       \code
       const CImg<float> img(2,2,1,3,      // Construct a 2x2 color (RGB) image.
                             0,255,0,255,  // Set the 4 values for the red component.
                             0,0,255,255,  // Set the 4 values for the green component.
                             64,64,64,64); // Set the 4 values for the blue component.
       img.resize(150,150).display();
       \endcode
       \image html ref_constructor1.jpg
     **/
    CImg(const unsigned int size_x, const unsigned int size_y, const unsigned int size_z, const unsigned int size_c,
         const int value0, const int value1, ...):_width(0),_height(0),_depth(0),_spectrum(0),_is_shared(false),_data(0) {
#define _CImg_stdarg(img,a0,a1,N,t) { \
	unsigned long _siz = (unsigned long)N; \
	if (_siz--) { \
	  va_list ap; \
	  va_start(ap,a1); \
	  T *ptrd = (img)._data; \
	  *(ptrd++) = (T)a0; \
	  if (_siz--) { \
	    *(ptrd++) = (T)a1; \
	    for (; _siz; --_siz) *(ptrd++) = (T)va_arg(ap,t); \
	  } \
	  va_end(ap); \
	} \
      }
      assign(size_x,size_y,size_z,size_c);
      _CImg_stdarg(*this,value0,value1,(unsigned long)size_x*size_y*size_z*size_c,int);
    }

    //! Construct image with specified size and initialize pixel values from a sequence of doubles.
    /**
       Construct a new image instance of size \c size_x x \c size_y x \c size_z x \c size_c, with pixels of type \c T, and initialize pixel
       values from the specified sequence of doubles \c value0,\c value1,\c ...
       \param size_x Image width().
       \param size_y Image height().
       \param size_z Image depth().
       \param size_c Image spectrum() (number of channels).
       \param value0 First value of the initialization sequence (must be a \e double).
       \param value1 Second value of the initialization sequence (must be a \e double).
       \param ...
       \note
       - Similar to CImg(unsigned int,unsigned int,unsigned int,unsigned int,int,int,...), but
         takes a sequence of double values instead of integers.
       \warning
       - You must specify \e exactly \c dx*\c dy*\c dz*\c dc doubles in the initialization sequence.
         Otherwise, the constructor may crash or fill your image with garbage.
         For instance, the code below will probably crash on most platforms:
         \code
         const CImg<float> img(2,2,1,1, 0.5,0.5,255,255); // FAIL: The two last arguments are 'int', not 'double'!
         \endcode
     **/
    CImg(const unsigned int size_x, const unsigned int size_y, const unsigned int size_z, const unsigned int size_c,
         const double value0, const double value1, ...):_width(0),_height(0),_depth(0),_spectrum(0),_is_shared(false),_data(0) {
      assign(size_x,size_y,size_z,size_c);
      _CImg_stdarg(*this,value0,value1,(unsigned long)size_x*size_y*size_z*size_c,double);
    }

    //! Construct image with specified size and initialize pixel values from a value string.
    /**
       Construct a new image instance of size \c size_x x \c size_y x \c size_z x \c size_c, with pixels of type \c T, and initializes pixel
       values from the specified string \c values.
       \param size_x Image width().
       \param size_y Image height().
       \param size_z Image depth().
       \param size_c Image spectrum() (number of channels).
       \param values Value string describing the way pixel values are set.
       \param repeat_values Tells if the value filling process is repeated over the image.
       \note
       - Similar to CImg(unsigned int,unsigned int,unsigned int,unsigned int), but it also fills
         the pixel buffer with values described in the value string \c values.
       - Value string \c values may describe two different filling processes:
         - Either \c values is a sequences of values assigned to the image pixels, as in <tt>"1,2,3,7,8,2"</tt>.
           In this case, set \c repeat_values to \c true to periodically fill the image with the value sequence.
         - Either, \c values is a formula, as in <tt>"cos(x/10)*sin(y/20)"</tt>. In this case, parameter \c repeat_values is pointless.
       - For both cases, specifying \c repeat_values is mandatory. It disambiguates the possible overloading of constructor
         CImg(unsigned int,unsigned int,unsigned int,unsigned int,T) with \c T being a <tt>const char*</tt>.
       - A \c CImgArgumentException is thrown when an invalid value string \c values is specified.
       \par Example
       \code
       const CImg<float> img1(129,129,1,3,"0,64,128,192,255",true),                   // Construct image filled from a value sequence.
                         img2(129,129,1,3,"if(c==0,255*abs(cos(x/10)),1.8*y)",false); // Construct image filled from a formula.
       (img1,img2).display();
       \endcode
       \image html ref_constructor2.jpg
     **/
    CImg(const unsigned int size_x, const unsigned int size_y, const unsigned int size_z, const unsigned int size_c,
	 const char *const values, const bool repeat_values):_is_shared(false) {
      const unsigned long siz = (unsigned long)size_x*size_y*size_z*size_c;
      if (siz) {
        _width = size_x; _height = size_y; _depth = size_z; _spectrum = size_c;
        try { _data = new T[siz]; } catch (...) {
          _width = _height = _depth = _spectrum = 0; _data = 0;
          throw CImgInstanceException(_cimg_instance
                                      "CImg(): Failed to allocate memory (%s) for image (%u,%u,%u,%u).",
                                      cimg_instance,
                                      cimg::strbuffersize(sizeof(T)*size_x*size_y*size_z*size_c),size_x,size_y,size_z,size_c);
        }
        fill(values,repeat_values);
      } else { _width = _height = _depth = _spectrum = 0; _data = 0; }
    }

    //! Construct image with specified size and initialize pixel values from a memory buffer.
    /**
       Construct a new image instance of size \c size_x x \c size_y x \c size_z x \c size_c, with pixels of type \c T, and initializes pixel
       values from the specified \c t* memory buffer.
       \param values Pointer to the input memory buffer.
       \param size_x Image width().
       \param size_y Image height().
       \param size_z Image depth().
       \param size_c Image spectrum() (number of channels).
       \param is_shared Tells if input memory buffer must be shared by the current instance.
       \note
       - If \c is_shared is \c false, the image instance allocates its own pixel buffer, and values from the specified input buffer
         are copied to the instance buffer. If buffer types \c T and \c t are different, a regular static cast is performed during buffer copy.
       - Otherwise, the image instance does \e not allocate a new buffer, and uses the input memory buffer as its own pixel buffer. This case
         requires that types \c T and \c t are the same. Later, destroying such a shared image will not deallocate the pixel buffer,
         this task being obviously charged to the initial buffer allocator.
       - A \c CImgInstanceException is thrown when the pixel buffer cannot be allocated (e.g. when requested size is too big for available memory).
       \warning
       - You must take care when operating on a shared image, since it may have an invalid pixel buffer pointer data() (e.g. already deallocated).
       \par Example
       \code
       unsigned char tab[256*256] = { 0 };
       CImg<unsigned char> img1(tab,256,256,1,1,false), // Construct new non-shared image from buffer 'tab'.
                           img2(tab,256,256,1,1,true);  // Construct new shared-image from buffer 'tab'.
       tab[1024] = 255;                                 // Here, 'img2' is indirectly modified, but not 'img1'.
       \endcode
    **/
    template<typename t>
    CImg(const t *const values, const unsigned int size_x, const unsigned int size_y=1,
         const unsigned int size_z=1, const unsigned int size_c=1, const bool is_shared=false):_is_shared(false) {
      if (is_shared) {
        _width = _height = _depth = _spectrum = 0; _data = 0;
        throw CImgArgumentException(_cimg_instance
                                    "CImg(): Invalid construction request of a (%u,%u,%u,%u) shared instance from a (%s*) buffer "
                                    "(pixel types are different).",
                                    cimg_instance,
                                    size_x,size_y,size_z,size_c,CImg<t>::pixel_type());
      }
      const unsigned long siz = (unsigned long)size_x*size_y*size_z*size_c;
      if (values && siz) {
        _width = size_x; _height = size_y; _depth = size_z; _spectrum = size_c;
        try { _data = new T[siz]; } catch (...) {
          _width = _height = _depth = _spectrum = 0; _data = 0;
          throw CImgInstanceException(_cimg_instance
                                      "CImg(): Failed to allocate memory (%s) for image (%u,%u,%u,%u).",
                                      cimg_instance,
                                      cimg::strbuffersize(sizeof(T)*size_x*size_y*size_z*size_c),size_x,size_y,size_z,size_c);

        }
        const t *ptrs = values; cimg_for(*this,ptrd,T) *ptrd = (T)*(ptrs++);
      } else { _width = _height = _depth = _spectrum = 0; _data = 0; }
    }

    //! Construct image with specified size and initialize pixel values from a memory buffer \specialization.
    CImg(const T *const values, const unsigned int size_x, const unsigned int size_y=1,
         const unsigned int size_z=1, const unsigned int size_c=1, const bool is_shared=false) {
      const unsigned long siz = (unsigned long)size_x*size_y*size_z*size_c;
      if (values && siz) {
        _width = size_x; _height = size_y; _depth = size_z; _spectrum = size_c; _is_shared = is_shared;
        if (_is_shared) _data = const_cast<T*>(values);
        else {
          try { _data = new T[siz]; } catch (...) {
            _width = _height = _depth = _spectrum = 0; _data = 0;
            throw CImgInstanceException(_cimg_instance
                                        "CImg(): Failed to allocate memory (%s) for image (%u,%u,%u,%u).",
                                        cimg_instance,
                                        cimg::strbuffersize(sizeof(T)*size_x*size_y*size_z*size_c),size_x,size_y,size_z,size_c);
          }
          std::memcpy(_data,values,siz*sizeof(T)); }
      } else { _width = _height = _depth = _spectrum = 0; _is_shared = false; _data = 0; }
    }

    //! Construct image from reading an image file.
    /**
       Construct a new image instance with pixels of type \c T, and initialize pixel values with the data read from an image file.
       \param filename Filename, as a C-string.
       \note
       - Similar to CImg(unsigned int,unsigned int,unsigned int,unsigned int), but it reads the image
         dimensions and pixel values from the specified image file.
       - The recognition of the image file format by %CImg higly depends on the tools installed on your system
         and on the external libraries you used to link your code against.
       - Considered pixel type \c T should better fit the file format specification, or data loss may occur during file load
         (e.g. constructing a \c CImg<unsigned char> from a float-valued image file).
       - A \c CImgIOException is thrown when the specified \c filename cannot be read, or if the file format is not recognized.
       \par Example
       \code
       const CImg<float> img("reference.jpg");
       img.display();
       \endcode
       \image html ref_image.jpg
    **/
    explicit CImg(const char *const filename):_width(0),_height(0),_depth(0),_spectrum(0),_is_shared(false),_data(0) {
      assign(filename);
    }

    //! Construct image copy.
    /**
       Construct a new image instance with pixels of type \c T, as a copy of an existing \c CImg<t> instance.
       \param img Input image to copy.
       \note
       - Constructed copy has the same size width() x height() x depth() x spectrum() and pixel values as the input image \c img.
       - If input image \c img is \e shared and if types \c T and \c t are the same, the constructed copy is also \e shared,
         and shares its pixel buffer with \c img.
         Modifying a pixel value in the constructed copy will thus also modifies it in the input image \c img.
         This behavior is needful to allow functions to return shared images.
       - Otherwise, the constructed copy allocates its own pixel buffer, and copies pixel values from the input image \c img
         into its buffer. The copied pixel values may be eventually statically casted if types \c T and \c t are different.
       - Constructing a copy from an image \c img when types \c t and \c T are the same is significantly faster than with different types.
       - A \c CImgInstanceException is thrown when the pixel buffer cannot be allocated (e.g. not enough available memory).
    **/
    template<typename t>
    CImg(const CImg<t>& img):_is_shared(false) {
      const unsigned long siz = img.size();
      if (img._data && siz) {
        _width = img._width; _height = img._height; _depth = img._depth; _spectrum = img._spectrum;
        try { _data = new T[siz]; } catch (...) {
          _width = _height = _depth = _spectrum = 0; _data = 0;
          throw CImgInstanceException(_cimg_instance
                                      "CImg(): Failed to allocate memory (%s) for image (%u,%u,%u,%u).",
                                      cimg_instance,
                                      cimg::strbuffersize(sizeof(T)*img._width*img._height*img._depth*img._spectrum),
                                      img._width,img._height,img._depth,img._spectrum);
        }
        const t *ptrs = img._data; cimg_for(*this,ptrd,T) *ptrd = (T)*(ptrs++);
      } else { _width = _height = _depth = _spectrum = 0; _data = 0; }
    }

    //! Construct image copy \specialization.
    CImg(const CImg<T>& img) {
      const unsigned long siz = img.size();
      if (img._data && siz) {
        _width = img._width; _height = img._height; _depth = img._depth; _spectrum = img._spectrum; _is_shared = img._is_shared;
        if (_is_shared) _data = const_cast<T*>(img._data);
        else {
          try { _data = new T[siz]; } catch (...) {
            _width = _height = _depth = _spectrum = 0; _data = 0;
            throw CImgInstanceException(_cimg_instance
                                        "CImg(): Failed to allocate memory (%s) for image (%u,%u,%u,%u).",
                                        cimg_instance,
                                        cimg::strbuffersize(sizeof(T)*img._width*img._height*img._depth*img._spectrum),
                                        img._width,img._height,img._depth,img._spectrum);

          }
          std::memcpy(_data,img._data,siz*sizeof(T));
        }
      } else { _width = _height = _depth = _spectrum = 0; _is_shared = false; _data = 0; }
    }

    //! Advanced copy constructor.
    /**
       Construct a new image instance with pixels of type \c T, as a copy of an existing \c CImg<t> instance,
       while forcing the shared state of the constructed copy.
       \param img Input image to copy.
       \param is_shared Tells about the shared state of the constructed copy.
       \note
       - Similar to CImg(const CImg<t>&), except that it allows to decide the shared state of
         the constructed image, which does not depend anymore on the shared state of the input image \c img:
         - If \c is_shared is \c true, the constructed copy will share its pixel buffer with the input image \c img.
           For that case, the pixel types \c T and \c t \e must be the same.
         - If \c is_shared is \c false, the constructed copy will allocate its own pixel buffer, whether the input image \c img is
           shared or not.
       - A \c CImgArgumentException is thrown when a shared copy is requested with different pixel types \c T and \c t.
    **/
    template<typename t>
    CImg(const CImg<t>& img, const bool is_shared):_is_shared(false) {
      if (is_shared) {
        _width = _height = _depth = _spectrum = 0; _data = 0;
        throw CImgArgumentException(_cimg_instance
                                    "CImg(): Invalid construction request of a shared instance from a "
                                    "CImg<%s> image (%u,%u,%u,%u,%p) (pixel types are different).",
                                    cimg_instance,
                                    CImg<t>::pixel_type(),img._width,img._height,img._depth,img._spectrum,img._data);
      }
      const unsigned long siz = img.size();
      if (img._data && siz) {
        _width = img._width; _height = img._height; _depth = img._depth; _spectrum = img._spectrum;
        try { _data = new T[siz]; } catch (...) {
          _width = _height = _depth = _spectrum = 0; _data = 0;
          throw CImgInstanceException(_cimg_instance
                                      "CImg(): Failed to allocate memory (%s) for image (%u,%u,%u,%u).",
                                      cimg_instance,
                                      cimg::strbuffersize(sizeof(T)*img._width*img._height*img._depth*img._spectrum),
                                      img._width,img._height,img._depth,img._spectrum);
        }
        const t *ptrs = img._data; cimg_for(*this,ptrd,T) *ptrd = (T)*(ptrs++);
      } else { _width = _height = _depth = _spectrum = 0; _data = 0; }
    }

    //! Advanced copy constructor \specialization.
    CImg(const CImg<T>& img, const bool is_shared) {
      const unsigned long siz = img.size();
      if (img._data && siz) {
        _width = img._width; _height = img._height; _depth = img._depth; _spectrum = img._spectrum; _is_shared = is_shared;
        if (_is_shared) _data = const_cast<T*>(img._data);
        else {
          try { _data = new T[siz]; } catch (...) {
            _width = _height = _depth = _spectrum = 0; _data = 0;
            throw CImgInstanceException(_cimg_instance
                                        "CImg(): Failed to allocate memory (%s) for image (%u,%u,%u,%u).",
                                        cimg_instance,
                                        cimg::strbuffersize(sizeof(T)*img._width*img._height*img._depth*img._spectrum),
                                        img._width,img._height,img._depth,img._spectrum);
          }
          std::memcpy(_data,img._data,siz*sizeof(T));
        }
      } else { _width = _height = _depth = _spectrum = 0; _is_shared = false; _data = 0; }
    }

    //! Construct image with dimensions borrowed from another image.
    /**
       Construct a new image instance with pixels of type \c T, and size get from some dimensions of an existing \c CImg<t> instance.
       \param img Input image from which dimensions are borrowed.
       \param dimensions C-string describing the image size along the X,Y,Z and C-dimensions.
       \note
       - Similar to CImg(unsigned int,unsigned int,unsigned int,unsigned int), but it takes the image dimensions
         (\e not its pixel values) from an existing \c CImg<t> instance.
       - The allocated pixel buffer is \e not filled with a default value, and is likely to contain garbage values.
         In order to initialize pixel values (e.g. with \c 0), use constructor CImg(const CImg<t>&,const char*,T) instead.
       \par Example
       \code
       const CImg<float> img1(256,128,1,3),      // 'img1' is a 256x128x1x3 image.
                         img2(img1,"xyzc"),      // 'img2' is a 256x128x1x3 image.
                         img3(img1,"y,x,z,c"),   // 'img3' is a 128x256x1x3 image.
                         img4(img1,"c,x,y,3",0), // 'img4' is a 3x128x256x3 image (with pixels initialized to '0').
       \endcode
     **/
    template<typename t>
    CImg(const CImg<t>& img, const char *const dimensions):_width(0),_height(0),_depth(0),_spectrum(0),_is_shared(false),_data(0) {
      assign(img,dimensions);
    }

    //! Construct image with dimensions borrowed from another image and initialize pixel values.
    /**
       Construct a new image instance with pixels of type \c T, and size get from the dimensions of an existing \c CImg<t> instance,
       and set all pixel values to specified \c value.
       \param img Input image from which dimensions are borrowed.
       \param dimensions String describing the image size along the X,Y,Z and V-dimensions.
       \param value Value used for initialization.
       \note
       - Similar to CImg(const CImg<t>&,const char*), but it also fills the pixel buffer with the specified \c value.
     **/
    template<typename t>
    CImg(const CImg<t>& img, const char *const dimensions, const T value):
      _width(0),_height(0),_depth(0),_spectrum(0),_is_shared(false),_data(0) {
      assign(img,dimensions).fill(value);
    }

    //! Construct image from a display window.
    /**
       Construct a new image instance with pixels of type \c T, as a snapshot of an existing \c CImgDisplay instance.
       \param disp Input display window.
       \note
       - The width() and height() of the constructed image instance are the same as the specified \c CImgDisplay.
       - The depth() and spectrum() of the constructed image instance are respectively set to \c 1 and \c 3 (i.e. a 2d color image).
       - The image pixels are read as 8-bits RGB values.
     **/
    explicit CImg(const CImgDisplay &disp):_width(0),_height(0),_depth(0),_spectrum(0),_is_shared(false),_data(0) {
      disp.snapshot(*this);
    }

    //! Construct empty image \inplace.
    /**
       In-place version of the default constructor CImg(). It simply resets the instance to an empty image.
    **/
    CImg<T>& assign() {
      if (!_is_shared) delete[] _data;
      _width = _height = _depth = _spectrum = 0; _is_shared = false; _data = 0;
      return *this;
    }

    //! Construct image with specified size \inplace.
    /**
       In-place version of the constructor CImg(unsigned int,unsigned int,unsigned int,unsigned int).
    **/
    CImg<T>& assign(const unsigned int size_x, const unsigned int size_y=1, const unsigned int size_z=1, const unsigned int size_c=1) {
      const unsigned long siz = (unsigned long)size_x*size_y*size_z*size_c;
      if (!siz) return assign();
      const unsigned long curr_siz = size();
      if (siz!=curr_siz) {
	if (_is_shared)
          throw CImgArgumentException(_cimg_instance
                                      "assign(): Invalid assignement request of shared instance from specified image (%u,%u,%u,%u).",
                                      cimg_instance,
                                      size_x,size_y,size_z,size_c);
	else {
          delete[] _data;
          try { _data = new T[siz]; } catch (...) {
            _width = _height = _depth = _spectrum = 0; _data = 0;
            throw CImgInstanceException(_cimg_instance
                                        "assign(): Failed to allocate memory (%s) for image (%u,%u,%u,%u).",
                                        cimg_instance,
                                        cimg::strbuffersize(sizeof(T)*size_x*size_y*size_z*size_c),size_x,size_y,size_z,size_c);
          }
        }
      }
      _width = size_x; _height = size_y; _depth = size_z; _spectrum = size_c;
      return *this;
    }

    //! Construct image with specified size and initialize pixel values \inplace.
    /**
       In-place version of the constructor CImg(unsigned int,unsigned int,unsigned int,unsigned int,T).
    **/
    CImg<T>& assign(const unsigned int size_x, const unsigned int size_y, const unsigned int size_z, const unsigned int size_c, const T value) {
      return assign(size_x,size_y,size_z,size_c).fill(value);
    }

    //! Construct image with specified size and initialize pixel values from a sequence of integers \inplace.
    /**
       In-place version of the constructor CImg(unsigned int,unsigned int,unsigned int,unsigned int,int,int,...).
    **/
    CImg<T>& assign(const unsigned int size_x, const unsigned int size_y, const unsigned int size_z, const unsigned int size_c,
                    const int value0, const int value1, ...) {
      assign(size_x,size_y,size_z,size_c);
      _CImg_stdarg(*this,value0,value1,(unsigned long)size_x*size_y*size_z*size_c,int);
      return *this;
    }

    //! Construct image with specified size and initialize pixel values from a sequence of doubles \inplace.
    /**
       In-place version of the constructor CImg(unsigned int,unsigned int,unsigned int,unsigned int,double,double,...).
    **/
    CImg<T>& assign(const unsigned int size_x, const unsigned int size_y, const unsigned int size_z, const unsigned int size_c,
                    const double value0, const double value1, ...) {
      assign(size_x,size_y,size_z,size_c);
      _CImg_stdarg(*this,value0,value1,(unsigned long)size_x*size_y*size_z*size_c,double);
      return *this;
    }

    //! Construct image with specified size and initialize pixel values from a value string \inplace.
    /**
       In-place version of the constructor CImg(unsigned int,unsigned int,unsigned int,unsigned int,const char*,bool).
    **/
    CImg<T>& assign(const unsigned int size_x, const unsigned int size_y, const unsigned int size_z, const unsigned int size_c,
                    const char *const values, const bool repeat_values) {
      return assign(size_x,size_y,size_z,size_c).fill(values,repeat_values);
    }

    //! Construct image with specified size and initialize pixel values from a memory buffer \inplace.
    /**
       In-place version of the constructor CImg(const t*,unsigned int,unsigned int,unsigned int,unsigned int).
    **/
    template<typename t>
    CImg<T>& assign(const t *const values, const unsigned int size_x, const unsigned int size_y=1,
                    const unsigned int size_z=1, const unsigned int size_c=1) {
      const unsigned long siz = (unsigned long)size_x*size_y*size_z*size_c;
      if (!values || !siz) return assign();
      assign(size_x,size_y,size_z,size_c);
      const t *ptrs = values; cimg_for(*this,ptrd,T) *ptrd = (T)*(ptrs++);
      return *this;
    }

    //! Construct image with specified size and initialize pixel values from a memory buffer \specialization.
    CImg<T>& assign(const T *const values, const unsigned int size_x, const unsigned int size_y=1,
                    const unsigned int size_z=1, const unsigned int size_c=1) {
      const unsigned long siz = (unsigned long)size_x*size_y*size_z*size_c;
      if (!values || !siz) return assign();
      const unsigned long curr_siz = size();
      if (values==_data && siz==curr_siz) return assign(size_x,size_y,size_z,size_c);
      if (_is_shared || values+siz<_data || values>=_data+size()) {
        assign(size_x,size_y,size_z,size_c);
        if (_is_shared) std::memmove(_data,values,siz*sizeof(T));
        else std::memcpy(_data,values,siz*sizeof(T));
      } else {
        T *new_data = 0;
        try { new_data = new T[siz]; } catch (...) {
          _width = _height = _depth = _spectrum = 0; _data = 0;
          throw CImgInstanceException(_cimg_instance
                                      "assign(): Failed to allocate memory (%s) for image (%u,%u,%u,%u).",
                                      cimg_instance,
                                      cimg::strbuffersize(sizeof(T)*size_x*size_y*size_z*size_c),size_x,size_y,size_z,size_c);
        }
        std::memcpy(new_data,values,siz*sizeof(T));
        delete[] _data; _data = new_data; _width = size_x; _height = size_y; _depth = size_z; _spectrum = size_c;
      }
      return *this;
    }

    //! Construct image with specified size and initialize pixel values from a memory buffer \overloading.
    template<typename t>
    CImg<T>& assign(const t *const values, const unsigned int size_x, const unsigned int size_y,
                    const unsigned int size_z, const unsigned int size_c, const bool is_shared) {
      if (is_shared)
        throw CImgArgumentException(_cimg_instance
                                    "assign(): Invalid assignment request of shared instance from (%s*) buffer"
                                    "(pixel types are different).",
                                    cimg_instance,
                                    CImg<t>::pixel_type());
      return assign(values,size_x,size_y,size_z,size_c);
    }

    //! Construct image with specified size and initialize pixel values from a memory buffer \overloading.
    CImg<T>& assign(const T *const values, const unsigned int size_x, const unsigned int size_y,
                    const unsigned int size_z, const unsigned int size_c, const bool is_shared) {
      const unsigned long siz = (unsigned long)size_x*size_y*size_z*size_c;
      if (!values || !siz) {
        if (is_shared)
          throw CImgArgumentException(_cimg_instance
                                      "assign(): Invalid assignment request of shared instance from (null) or empty buffer.",
                                      cimg_instance);
        else return assign();
      }
      if (!is_shared) { if (_is_shared) assign(); assign(values,size_x,size_y,size_z,size_c); }
      else {
	if (!_is_shared) {
	  if (values+siz<_data || values>=_data+size()) assign();
	  else cimg::warn(_cimg_instance
                          "assign(): Shared image instance has overlapping memory.",
                          cimg_instance);
	}
	_width = size_x; _height = size_y; _depth = size_z; _spectrum = size_c; _is_shared = true;
	_data = const_cast<T*>(values);
      }
      return *this;
    }

    //! Construct image from reading an image file \inplace.
    /**
       In-place version of the constructor CImg(const char*).
    **/
    CImg<T>& assign(const char *const filename) {
      return load(filename);
    }

    //! Construct image copy \inplace.
    /**
       In-place version of the constructor CImg(const CImg<t>&).
    **/
    template<typename t>
    CImg<T>& assign(const CImg<t>& img) {
      return assign(img._data,img._width,img._height,img._depth,img._spectrum);
    }

    //! In-place version of the advanced copy constructor.
    /**
       In-place version of the constructor CImg(const CImg<t>&,bool).
     **/
    template<typename t>
    CImg<T>& assign(const CImg<t>& img, const bool is_shared) {
      return assign(img._data,img._width,img._height,img._depth,img._spectrum,is_shared);
    }

    //! Construct image with dimensions borrowed from another image \inplace.
    /**
       In-place version of the constructor CImg(const CImg<t>&,const char*).
    **/
    template<typename t>
    CImg<T>& assign(const CImg<t>& img, const char *const dimensions) {
      if (!dimensions || !*dimensions) return assign(img._width,img._height,img._depth,img._spectrum);
      unsigned int siz[4] = { 0,1,1,1 }, k = 0;
      for (const char *s = dimensions; *s && k<4; ++k) {
        char item[256] = { 0 };
        if (std::sscanf(s,"%255[^0-9%xyzvwhdcXYZVWHDC]",item)>0) s+=std::strlen(item);
        if (*s) {
          unsigned int val = 0; char sep = 0;
          if (std::sscanf(s,"%u%c",&val,&sep)>0) {
            if (sep=='%') siz[k] = val*(k==0?_width:k==1?_height:k==2?_depth:_spectrum)/100;
            else siz[k] = val;
            while (*s>='0' && *s<='9') ++s; if (sep=='%') ++s;
          } else switch (cimg::uncase(*s)) {
          case 'x' : case 'w' : siz[k] = img._width; ++s; break;
          case 'y' : case 'h' : siz[k] = img._height; ++s; break;
          case 'z' : case 'd' : siz[k] = img._depth; ++s; break;
          case 'c' : case 's' : siz[k] = img._spectrum; ++s; break;
          default :
            throw CImgArgumentException(_cimg_instance
                                        "assign(): Invalid character '%c' detected in specified dimension string '%s'.",
                                        cimg_instance,
                                        *s,dimensions);
          }
        }
      }
      return assign(siz[0],siz[1],siz[2],siz[3]);
    }

    //! Construct image with dimensions borrowed from another image and initialize pixel values \inplace.
    /**
       In-place version of the constructor CImg(const CImg<t>&,const char*,T).
    **/
    template<typename t>
    CImg<T>& assign(const CImg<t>& img, const char *const dimensions, const T value) {
      return assign(img,dimensions).fill(value);
    }

    //! Construct image from a display window \inplace.
    /**
       In-place version of the constructor CImg(const CImgDisplay&).
    **/
    CImg<T>& assign(const CImgDisplay &disp) {
      disp.snapshot(*this);
      return *this;
    }

    //! Construct empty image \inplace.
    /**
       Equivalent to assign().
       \note
       - It has been defined for compatibility with STL naming conventions.
    **/
    CImg<T>& clear() {
      return assign();
    }

    //! Transfer content of an image instance into another one.
    /**
       Transfer the dimensions and the pixel buffer content of an image instance into another one,
       and replace instance by an empty image. It avoids the copy of the pixel buffer
       when possible.
       \param img Destination image.
       \note
       - Pixel types \c T and \c t of source and destination images can be different, though the process is designed to be
         instantaneous when \c T and \c t are the same.
       \par Example
       \code
       CImg<float> src(256,256,1,3,0), // Construct a 256x256x1x3 (color) image filled with value '0'.
                   dest(16,16);        // Construct a 16x16x1x1 (scalar) image.
       src.move_to(dest);              // Now, 'src' is empty and 'dest' is the 256x256x1x3 image.
       \endcode
    **/
    template<typename t>
    CImg<t>& move_to(CImg<t>& img) {
      img.assign(*this);
      assign();
      return img;
    }

    //! Transfer content of an image instance into another one \specialization.
    CImg<T>& move_to(CImg<T>& img) {
      if (_is_shared || img._is_shared) img.assign(*this);
      else swap(img);
      assign();
      return img;
    }

    //! Transfer content of an image instance into a new image in an image list.
    /**
       Transfer the dimensions and the pixel buffer content of an image instance
       into a newly inserted image at position \c pos in specified \c CImgList<t> instance.
       \param list Destination list.
       \param pos Position of the newly inserted image in the list.
       \note
       - When optionnal parameter \c pos is ommited, the image instance is transfered as a new
         image at the end of the specified \c list.
       - It is convenient to sequentially insert new images into image lists, with no
         additional copies of memory buffer.
       \par Example
       \code
       CImgList<float> list;             // Construct an empty image list.
       CImg<float> img("reference.jpg"); // Read image from filename.
       img.move_to(list);                // Transfer image content as a new item in the list (no buffer copy).
       \endcode
    **/
    template<typename t>
    CImgList<t>& move_to(CImgList<t>& list, const unsigned int pos=~0U) {
      const unsigned int npos = pos>list._width?list._width:pos;
      move_to(list.insert(1,npos)[npos]);
      return list;
    }

    //! Swap fields of two image instances.
    /**
      \param img Image to swap fields with.
      \note
      - It can be used to interchange the content of two images in a very fast way. Can be convenient when dealing
        with algorithms requiring two swapping buffers.
      \par Example
      \code
      CImg<float> img1("lena.jpg"),
                  img2("milla.jpg");
      img1.swap(img2);               // Now, 'img1' is 'milla' and 'img2' is 'lena'.
      \endcode
    **/
    CImg<T>& swap(CImg<T>& img) {
      cimg::swap(_width,img._width);
      cimg::swap(_height,img._height);
      cimg::swap(_depth,img._depth);
      cimg::swap(_spectrum,img._spectrum);
      cimg::swap(_data,img._data);
      cimg::swap(_is_shared,img._is_shared);
      return img;
    }

    //! Return a reference to an empty image.
    /**
       \note
       This function is useful mainly to declare optional parameters having type \c CImg<T> in functions prototypes, e.g.
       \code
       void f(const int x=0, const int y=0, const CImg<float>& img=CImg<float>::empty());
       \endcode
     **/
    static CImg<T>& empty() {
      static CImg<T> _empty;
      return _empty.assign();
    }

    //@}
    //------------------------------------------
    //
    //! \name Overloaded Operators
    //@{
    //------------------------------------------

    //! Access to a pixel value.
    /**
       Return a reference to a located pixel value of the image instance,
       being possibly \e const, whether the image instance is \e const or not.
       This is the standard method to get/set pixel values in \c CImg<T> images.
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \note
       - Range of pixel coordinates start from <tt>(0,0,0,0)</tt> to <tt>(width()-1,height()-1,depth()-1,spectrum()-1)</tt>.
       - Due to the particular arrangement of the pixel buffers defined in %CImg, you can omit one coordinate if the corresponding dimension
         is equal to \c 1.
         For instance, pixels of a 2d image (depth() equal to \c 1) can be accessed by <tt>img(x,y,c)</tt> instead of <tt>img(x,y,0,c)</tt>.
       \warning
       - There is \e no boundary checking done in this operator, to make it as fast as possible.
         You \e must take care of out-of-bounds access by yourself, if necessary.
         For debuging purposes, you may want to define macro \c 'cimg_verbosity'>=3 to enable additional boundary checking operations
         in this operator. In that case, warning messages will be printed on the error output when accessing out-of-bounds pixels.
       \par Example
       \code
       CImg<float> img(100,100,1,3,0);                   // Construct a 100x100x1x3 (color) image with pixels set to '0'.
       const float
          valR = img(10,10,0,0),                         // Read red value at coordinates (10,10).
          valG = img(10,10,0,1),                         // Read green value at coordinates (10,10)
          valB = img(10,10,2),                           // Read blue value at coordinates (10,10) (Z-coordinate can be omitted).
          avg = (valR + valG + valB)/3;                  // Compute average pixel value.
       img(10,10,0) = img(10,10,1) = img(10,10,2) = avg; // Replace the color pixel (10,10) by the average grey value.
       \endcode
    **/
#if cimg_verbosity>=3
    T& operator()(const unsigned int x, const unsigned int y=0, const unsigned int z=0, const unsigned int c=0) {
      const unsigned long off = (unsigned long)offset(x,y,z,c);
      if (!_data || off>=size()) {
        cimg::warn(_cimg_instance
                   "operator(): Invalid pixel request, at coordinates (%u,%u,%u,%u) [offset=%u].",
                   cimg_instance,
                   x,y,z,c,off);
        return *_data;
      }
      else return _data[off];
    }

    //! Access to a pixel value \const.
    const T& operator()(const unsigned int x, const unsigned int y=0, const unsigned int z=0, const unsigned int c=0) const {
      return const_cast<CImg<T>*>(this)->operator()(x,y,z,c);
    }

    //! Access to a pixel value.
    /**
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \param wh Precomputed offset, must be equal to <tt>width()*\ref height()</tt>.
       \param whd Precomputed offset, must be equal to <tt>width()*\ref height()*\ref depth()</tt>.
       \note
       - Similar to (but faster than) operator()().
         It uses precomputed offsets to optimize memory access. You may use it to optimize
         the reading/writing of several pixel values in the same image (e.g. in a loop).
     **/
    T& operator()(const unsigned int x, const unsigned int y, const unsigned int z, const unsigned int c,
                  const unsigned long wh, const unsigned long whd=0) {
      cimg::unused(wh,whd);
      return (*this)(x,y,z,c);
    }

    //! Access to a pixel value \const.
    const T& operator()(const unsigned int x, const unsigned int y, const unsigned int z, const unsigned int c,
                        const unsigned long wh, const unsigned long whd=0) const {
      cimg::unused(wh,whd);
      return (*this)(x,y,z,c);
    }
#else
# 10450 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    T& operator()(const unsigned int x) {
      return _data[x];
    }

    const T& operator()(const unsigned int x) const {
      return _data[x];
    }

    T& operator()(const unsigned int x, const unsigned int y) {
      return _data[x + y*_width];
    }

    const T& operator()(const unsigned int x, const unsigned int y) const {
      return _data[x + y*_width];
    }

    T& operator()(const unsigned int x, const unsigned int y, const unsigned int z) {
      return _data[x + y*(unsigned long)_width + z*(unsigned long)_width*_height];
   }

    const T& operator()(const unsigned int x, const unsigned int y, const unsigned int z) const {
      return _data[x + y*(unsigned long)_width + z*(unsigned long)_width*_height];
    }

    T& operator()(const unsigned int x, const unsigned int y, const unsigned int z, const unsigned int c) {
      return _data[x + y*(unsigned long)_width + z*(unsigned long)_width*_height + c*(unsigned long)_width*_height*_depth];
    }

    const T& operator()(const unsigned int x, const unsigned int y, const unsigned int z, const unsigned int c) const {
      return _data[x + y*(unsigned long)_width + z*(unsigned long)_width*_height + c*(unsigned long)_width*_height*_depth];
    }

    T& operator()(const unsigned int x, const unsigned int y, const unsigned int z, const unsigned int,
                  const unsigned long wh) {
      return _data[x + y*_width + z*wh];
    }

    const T& operator()(const unsigned int x, const unsigned int y, const unsigned int z, const unsigned int,
                        const unsigned long wh) const {
      return _data[x + y*_width + z*wh];
    }

    T& operator()(const unsigned int x, const unsigned int y, const unsigned int z, const unsigned int c,
                  const unsigned long wh, const unsigned long whd) {
      return _data[x + y*_width + z*wh + c*whd];
    }

    const T& operator()(const unsigned int x, const unsigned int y, const unsigned int z, const unsigned int c,
                        const unsigned long wh, const unsigned long whd) const {
      return _data[x + y*_width + z*wh + c*whd];
    }
#endif
# 10502 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    //! Implicitely cast an image into a \c T*.
    /**
       Implicitely cast a \c CImg<T> instance into a \c T* or \c const \c T* pointer, whether the image instance
       is \e const or not. The returned pointer points on the first value of the image pixel buffer.
       \note
       - It simply returns the pointer data() to the pixel buffer.
       - This implicit conversion is convenient to test the empty state of images (data() being \c 0 in this case), e.g.
       \code
       CImg<float> img1(100,100), img2; // 'img1' is a 100x100 image, 'img2' is an empty image.
       if (img1) {                      // Test succeeds, 'img1' is not an empty image.
         if (!img2) {                   // Test succeeds, 'img2' is an empty image.
           std::printf("'img1' is not empty, 'img2' is empty.");
         }
       }
       \endcode
       - It also allows to use brackets to access pixel values, without need for a \c CImg<T>::operator[](), e.g.
       \code
       CImg<float> img(100,100);
       const float value = img[99]; // Access to value of the last pixel on the first row.
       img[510] = 255;              // Set pixel value at (10,5).
       \endcode
    **/
    operator T*() {
      return _data;
    }

    //! Implicitely cast an image into a \c T* \const.
    operator const T*() const {
      return _data;
    }

    //! Assign a value to all image pixels.
    /**
       Assign specified \c value to each pixel value of the image instance.
       \param value Value that will be assigned to image pixels.
       \note
       - The image size is never modified.
       - The \c value may be casted to pixel type \c T if necessary.
       \par Example
       \code
       CImg<char> img(100,100); // Declare image (with garbage values).
       img = 0;                 // Set all pixel values to '0'.
       img = 1.2;               // Set all pixel values to '1' (cast of '1.2' as a 'char').
       \endcode
    **/
    CImg<T>& operator=(const T value) {
      return fill(value);
    }

    //! Assign pixels values from a specified expression.
    /**
       Initialize all pixel values from the specified string \c expression.
       \param expression Value string describing the way pixel values are set.
       \note
       - String parameter \c expression may describe different things:
         - If \c expression is a list of values (as in \c "1,2,3,8,3,2"), or a formula (as in \c "(x*y)%255"),
           the pixel values are set from specified \c expression and the image size is not modified.
         - If \c expression is a filename (as in \c "reference.jpg"), the corresponding image file is loaded and replace the image instance.
           The image size is modified if necessary.
       \par Example
       \code
       CImg<float> img1(100,100), img2(img1), img3(img1); // Declare three 100x100 scalar images with unitialized pixel values.
       img1 = "0,50,100,150,200,250,200,150,100,50";      // Set pixel values of 'img1' from a value sequence.
       img2 = "10*((x*y)%25)";                            // Set pixel values of 'img2' from a formula.
       img3 = "reference.jpg";                            // Set pixel values of 'img3' from a file (image size is modified).
       (img1,img2,img3).display();
       \endcode
       \image html ref_operator_eq.jpg
    **/
    CImg<T>& operator=(const char *const expression) {
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      try {
        fill(expression,true);
      } catch (CImgException&) {
        cimg::exception_mode() = omode;
        load(expression);
      }
      cimg::exception_mode() = omode;
      return *this;
    }

    //! Copy an image into the current image instance.
    /**
       Similar to the in-place copy constructor assign(const CImg<t>&).
    **/
    template<typename t>
    CImg<T>& operator=(const CImg<t>& img) {
      return assign(img);
    }

    //! Copy an image into the current image instance \specialization.
    CImg<T>& operator=(const CImg<T>& img) {
      return assign(img);
    }

    //! Copy the content of a display window to the current image instance.
    /**
       Similar to assign(const CImgDisplay&).
    **/
    CImg<T>& operator=(const CImgDisplay& disp) {
      disp.snapshot(*this);
      return *this;
    }

    //! In-place addition operator.
    /**
       Add specified \c value to all pixels of an image instance.
       \param value Value to add.
       \note
       - Resulting pixel values are casted to fit the pixel type \c T. For instance, adding \c 0.2 to a \c CImg<char> is possible but does nothing indeed.
       - Overflow values are treated as with standard C++ numeric types. For instance,
       \code
       CImg<unsigned char> img(100,100,1,1,255); // Construct a 100x100 image with pixel values '255'.
       img+=1;                                   // Add '1' to each pixels -> Overflow.
       // here all pixels of image 'img' are equal to '0'.
       \endcode
       - To prevent value overflow, you may want to consider pixel type \c T as \c float or \c double, and use cut() after addition.
       \par Example
       \code
       CImg<unsigned char> img1("reference.jpg");          // Load a 8-bits RGB image (values in [0,255]).
       CImg<float> img2(img1);                             // Construct a float-valued copy of 'img1'.
       img2+=100;                                          // Add '100' to pixel values -> goes out of [0,255] but no problems with floats.
       img2.cut(0,255);                                    // Cut values in [0,255] to fit the 'unsigned char' constraint.
       img1 = img2;                                        // Rewrite safe result in 'unsigned char' version 'img1'.
       const CImg<unsigned char> img3 = (img1 + 100).cut(0,255); // Do the same in a more simple and elegant way.
       (img1,img2,img3).display();
       \endcode
       \image html ref_operator_plus.jpg
     **/
    template<typename t>
    CImg<T>& operator+=(const t value) {
      cimg_for(*this,ptrd,T) *ptrd = (T)(*ptrd + value);
      return *this;
    }

    //! In-place addition operator.
    /**
       Add values to image pixels, according to the specified string \c expression.
       \param expression Value string describing the way pixel values are added.
       \note
       - Similar to operator=(const char*), except that it adds values to the pixels of the current image instance,
         instead of assigning them.
    **/
    CImg<T>& operator+=(const char *const expression) {
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      try {
        const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(), &base = _base?_base:*this;
        _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator+=");
        T *ptrd = *expression=='<'?end()-1:_data;
        if (*expression=='<') cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd + mp.eval(x,y,z,c)); --ptrd; }
        else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd + mp.eval(x,y,z,c)); ++ptrd; }
      } catch (CImgException&) {
        cimg::exception_mode() = omode;
        *this+=CImg<T>(_width,_height,_depth,_spectrum,expression,true);
      }
      cimg::exception_mode() = omode;
      return *this;
    }

    //! In-place addition operator.
    /**
       Add values to image pixels, according to the values of the input image \c img.
       \param img Input image to add.
       \note
       - The size of the image instance is never modified.
       - It is not mandatory that input image \c img has the same size as the image instance. If less values are available
         in \c img, then the values are added cyclically. For instance, adding one WxH scalar image (spectrum() equal to \c 1) to
         one WxH color image (spectrum() equal to \c 3) means each color channel will be incremented with the same values at the same
         locations.
       \par Example
       \code
       CImg<float> img1("reference.jpg");                                   // Load a RGB color image (img1.spectrum()==3)
       const CImg<float> img2(img1.width(),img.height(),1,1,"255*(x/w)^2"); // Construct a scalar shading (img2.spectrum()==1).
       img1+=img2;                                                          // Add shading to each channel of 'img1'.
       img1.cut(0,255);                                                     // Prevent [0,255] overflow.
       (img2,img1).display();
       \endcode
       \image html ref_operator_plus1.jpg
    **/
    template<typename t>
    CImg<T>& operator+=(const CImg<t>& img) {
      const unsigned long siz = size(), isiz = img.size();
      if (siz && isiz) {
        if (is_overlapped(img)) return *this+=+img;
        T *ptrd = _data, *const ptre = _data + siz;
        if (siz>isiz) for (unsigned long n = siz/isiz; n; --n)
          for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd) *ptrd = (T)(*ptrd + *(ptrs++));
        for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)(*ptrd + *(ptrs++));
      }
      return *this;
    }

    //! In-place increment operator (prefix).
    /**
       Add \c 1 to all image pixels, and return a reference to the current incremented image instance.
       \note
       - Writing \c ++img is equivalent to \c img+=1.
     **/
    CImg<T>& operator++() {
      cimg_for(*this,ptrd,T) ++*ptrd;
      return *this;
    }

    //! In-place increment operator (postfix).
    /**
       Add \c 1 to all image pixels, and return a new copy of the initial (pre-incremented) image instance.
       \note
       - Use the prefixed version operator++() if you don't need a copy of the initial (pre-incremented) image instance, since
         a useless image copy may be expensive in terms of memory usage.
     **/
    CImg<T> operator++(int) {
      const CImg<T> copy(*this,false);
      ++*this;
      return copy;
    }

    //! Return a non-shared copy of the image instance.
    /**
       \note
       - Use this operator to ensure you get a non-shared copy of an image instance with same pixel type \c T.
         Indeed, the usual copy constructor CImg<T>(const CImg<T>&) returns a shared copy of a shared input image, and it may be
         not desirable to work on a regular copy (e.g. for a resize operation) if you have no informations about the shared state
         of the input image.
       - Writing \c (+img) is equivalent to \c CImg<T>(img,false).
    **/
    CImg<T> operator+() const {
      return CImg<T>(*this,false);
    }

    //! Addition operator.
    /**
       Similar to operator+=(const t), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image may be a superset of the initial pixel type \c T, if necessary.
     **/
    template<typename t>
    CImg<_cimg_Tt> operator+(const t value) const {
      return CImg<_cimg_Tt>(*this,false)+=value;
    }

    //! Addition operator.
    /**
       Similar to operator+=(const char*), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image may be a superset of the initial pixel type \c T, if necessary.
     **/
    CImg<Tfloat> operator+(const char *const expression) const {
      return CImg<Tfloat>(*this,false)+=expression;
    }

    //! Addition operator.
    /**
       Similar to operator+=(const CImg<t>&), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image may be a superset of the initial pixel type \c T, if necessary.
     **/
    template<typename t>
    CImg<_cimg_Tt> operator+(const CImg<t>& img) const {
      return CImg<_cimg_Tt>(*this,false)+=img;
    }

    //! In-place substraction operator.
    /**
       Similar to operator+=(const t), except that it performs a substraction instead of an addition.
     **/
    template<typename t>
    CImg<T>& operator-=(const t value) {
      cimg_for(*this,ptrd,T) *ptrd = (T)(*ptrd - value);
      return *this;
    }

    //! In-place substraction operator.
    /**
       Similar to operator+=(const char*), except that it performs a substraction instead of an addition.
     **/
    CImg<T>& operator-=(const char *const expression) {
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      try {
        const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(), &base = _base?_base:*this;
        _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator-=");
        T *ptrd = *expression=='<'?end()-1:_data;
        if (*expression=='<') cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd - mp.eval(x,y,z,c)); --ptrd; }
        else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd - mp.eval(x,y,z,c)); ++ptrd; }
      } catch (CImgException&) {
        cimg::exception_mode() = omode;
        *this-=CImg<T>(_width,_height,_depth,_spectrum,expression,true);
      }
      cimg::exception_mode() = omode;
      return *this;
    }

    //! In-place substraction operator.
    /**
       Similar to operator+=(const CImg<t>&), except that it performs a substraction instead of an addition.
     **/
    template<typename t>
    CImg<T>& operator-=(const CImg<t>& img) {
      const unsigned long siz = size(), isiz = img.size();
      if (siz && isiz) {
        if (is_overlapped(img)) return *this-=+img;
        T *ptrd = _data, *const ptre = _data + siz;
        if (siz>isiz) for (unsigned long n = siz/isiz; n; --n)
          for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd) *ptrd = (T)(*ptrd - *(ptrs++));
        for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)(*ptrd - *(ptrs++));
      }
      return *this;
    }

    //! In-place decrement operator (prefix).
    /**
       Similar to operator++(), except that it performs a decrement instead of an increment.
    **/
    CImg<T>& operator--() {
      cimg_for(*this,ptrd,T) *ptrd = *ptrd-(T)1;
      return *this;
    }

    //! In-place decrement operator (postfix).
    /**
       Similar to operator++(int), except that it performs a decrement instead of an increment.
    **/
    CImg<T> operator--(int) {
      const CImg<T> copy(*this,false);
      --*this;
      return copy;
    }

    //! Replace each pixel by its opposite value.
    /**
       \note
       - If the computed opposite values are out-of-range, they are treated as with standard C++ numeric types. For instance,
         the \c unsigned \c char opposite of \c 1 is \c 255.
       \par Example
       \code
       const CImg<unsigned char>
         img1("reference.jpg"),   // Load a RGB color image.
         img2 = -img1;            // Compute its opposite (in 'unsigned char').
       (img1,img2).display();
       \endcode
       \image html ref_operator_minus.jpg
     **/
    CImg<T> operator-() const {
      return CImg<T>(_width,_height,_depth,_spectrum,(T)0)-=*this;
    }

    //! Substraction operator.
    /**
       Similar to operator-=(const t), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image may be a superset of the initial pixel type \c T, if necessary.
    **/
    template<typename t>
    CImg<_cimg_Tt> operator-(const t value) const {
      return CImg<_cimg_Tt>(*this,false)-=value;
    }

    //! Substraction operator.
    /**
       Similar to operator-=(const char*), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image may be a superset of the initial pixel type \c T, if necessary.
    **/
    CImg<Tfloat> operator-(const char *const expression) const {
      return CImg<Tfloat>(*this,false)-=expression;
    }

    //! Substraction operator.
    /**
       Similar to operator-=(const CImg<t>&), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image may be a superset of the initial pixel type \c T, if necessary.
    **/
    template<typename t>
    CImg<_cimg_Tt> operator-(const CImg<t>& img) const {
      return CImg<_cimg_Tt>(*this,false)-=img;
    }

    //! In-place multiplication operator.
    /**
       Similar to operator+=(const t), except that it performs a multiplication instead of an addition.
     **/
    template<typename t>
    CImg<T>& operator*=(const t value) {
      cimg_for(*this,ptrd,T) *ptrd = (T)(*ptrd * value);
      return *this;
    }

    //! In-place multiplication operator.
    /**
       Similar to operator+=(const char*), except that it performs a multiplication instead of an addition.
     **/
    CImg<T>& operator*=(const char *const expression) {
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      try {
        const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(), &base = _base?_base:*this;
        _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator*=");
        T *ptrd = *expression=='<'?end()-1:_data;
        if (*expression=='<') cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd * mp.eval(x,y,z,c)); --ptrd; }
        else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd * mp.eval(x,y,z,c)); ++ptrd; }
      } catch (CImgException&) {
        cimg::exception_mode() = omode;
        mul(CImg<T>(_width,_height,_depth,_spectrum,expression,true));
      }
      cimg::exception_mode() = omode;
      return *this;
    }

    //! In-place multiplication operator.
    /**
       Replace the image instance by the matrix multiplication between the image instance and the specified matrix \c img.
       \param img Second operand of the matrix multiplication.
       \note
       - It does \e not compute a pointwise multiplication between two images. For this purpose, use mul(const CImg<t>&) instead.
       - The size of the image instance can be modified by this operator.
       \par Example
       \code
       CImg<float> A(2,2,1,1, 1,2,3,4);   // Construct 2x2 matrix A = [1,2;3,4].
       const CImg<float> X(1,2,1,1, 1,2); // Construct 1x2 vector X = [1;2].
       A*=X;                              // Assign matrix multiplication A*X to 'A'.
       // 'A' is now a 1x2 vector whose values are [5;11].
       \endcode
    **/
    template<typename t>
    CImg<T>& operator*=(const CImg<t>& img) {
      return ((*this)*img).move_to(*this);
    }

    //! Multiplication operator.
    /**
       Similar to operator*=(const t), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image may be a superset of the initial pixel type \c T, if necessary.
    **/
    template<typename t>
    CImg<_cimg_Tt> operator*(const t value) const {
      return CImg<_cimg_Tt>(*this,false)*=value;
    }

    //! Multiplication operator.
    /**
       Similar to operator*=(const char*), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image may be a superset of the initial pixel type \c T, if necessary.
    **/
    CImg<Tfloat> operator*(const char *const expression) const {
      return CImg<Tfloat>(*this,false)*=expression;
    }

    //! Multiplication operator.
    /**
       Similar to operator*=(const CImg<t>&), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image may be a superset of the initial pixel type \c T, if necessary.
    **/
    template<typename t>
    CImg<_cimg_Tt> operator*(const CImg<t>& img) const {
      if (_width!=img._height || _depth!=1 || _spectrum!=1)
        throw CImgArgumentException(_cimg_instance
                                    "operator*(): Invalid multiplication of instance by specified matrix (%u,%u,%u,%u,%p)",
                                    cimg_instance,
                                    img._width,img._height,img._depth,img._spectrum,img._data);
      CImg<_cimg_Tt> res(img._width,_height);
      _cimg_Ttdouble value;
#ifdef cimg_use_openmp
#pragma omp parallel for if (size()>=1000 && img.size()>=1000) private(value)
      cimg_forXY(res,i,j) { value = 0; cimg_forX(*this,k) value+=(*this)(k,j)*img(i,k); res(i,j) = (_cimg_Tt)value; }
#else
# 10965 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      _cimg_Tt *ptrd = res._data;
      cimg_forXY(res,i,j) { value = 0; cimg_forX(*this,k) value+=(*this)(k,j)*img(i,k); *(ptrd++) = (_cimg_Tt)value; }
#endif
# 10968 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      return res;
    }

    //! In-place division operator.
    /**
       Similar to operator+=(const t), except that it performs a division instead of an addition.
     **/
    template<typename t>
    CImg<T>& operator/=(const t value) {
      cimg_for(*this,ptrd,T) *ptrd = (T)(*ptrd / value);
      return *this;
    }

    //! In-place division operator.
    /**
       Similar to operator+=(const char*), except that it performs a division instead of an addition.
     **/
    CImg<T>& operator/=(const char *const expression) {
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      try {
        const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(), &base = _base?_base:*this;
        _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator/=");
        T *ptrd = *expression=='<'?end()-1:_data;
        if (*expression=='<') cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd / mp.eval(x,y,z,c)); --ptrd; }
        else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)(*ptrd / mp.eval(x,y,z,c)); ++ptrd; }
      } catch (CImgException&) {
        cimg::exception_mode() = omode;
        div(CImg<T>(_width,_height,_depth,_spectrum,expression,true));
      }
      cimg::exception_mode() = omode;
      return *this;
    }

    //! In-place division operator.
    /**
       Replace the image instance by the (right) matrix division between the image instance and the specified matrix \c img.
       \param img Second operand of the matrix division.
       \note
       - It does \e not compute a pointwise division between two images. For this purpose, use div(const CImg<t>&) instead.
       - It returns the matrix operation \c A*inverse(img).
       - The size of the image instance can be modified by this operator.
     **/
    template<typename t>
    CImg<T>& operator/=(const CImg<t>& img) {
      return (*this*img.get_invert()).move_to(*this);
    }

    //! Division operator.
    /**
       Similar to operator/=(const t), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image may be a superset of the initial pixel type \c T, if necessary.
    **/
    template<typename t>
    CImg<_cimg_Tt> operator/(const t value) const {
      return CImg<_cimg_Tt>(*this,false)/=value;
    }

    //! Division operator.
    /**
       Similar to operator/=(const char*), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image may be a superset of the initial pixel type \c T, if necessary.
    **/
    CImg<Tfloat> operator/(const char *const expression) const {
      return CImg<Tfloat>(*this,false)/=expression;
    }

    //! Division operator.
    /**
       Similar to operator/=(const CImg<t>&), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image may be a superset of the initial pixel type \c T, if necessary.
    **/
    template<typename t>
    CImg<_cimg_Tt> operator/(const CImg<t>& img) const {
      return (*this)*img.get_invert();
    }

    //! In-place modulo operator.
    /**
       Similar to operator+=(const t), except that it performs a modulo operation instead of an addition.
    **/
    template<typename t>
    CImg<T>& operator%=(const t value) {
      cimg_for(*this,ptrd,T) *ptrd = (T)cimg::mod(*ptrd,(T)value);
      return *this;
    }

    //! In-place modulo operator.
    /**
       Similar to operator+=(const char*), except that it performs a modulo operation instead of an addition.
    **/
    CImg<T>& operator%=(const char *const expression) {
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      try {
        const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(), &base = _base?_base:*this;
        _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator%=");
        T *ptrd = *expression=='<'?end()-1:_data;
        if (*expression=='<') cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)cimg::mod(*ptrd,(T)mp.eval(x,y,z,c)); --ptrd; }
        else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)cimg::mod(*ptrd,(T)mp.eval(x,y,z,c)); ++ptrd; }
      } catch (CImgException&) {
        cimg::exception_mode() = omode;
        *this%=CImg<T>(_width,_height,_depth,_spectrum,expression,true);
      }
      cimg::exception_mode() = omode;
      return *this;
    }

    //! In-place modulo operator.
    /**
       Similar to operator+=(const CImg<t>&), except that it performs a modulo operation instead of an addition.
    **/
    template<typename t>
    CImg<T>& operator%=(const CImg<t>& img) {
      const unsigned long siz = size(), isiz = img.size();
      if (siz && isiz) {
        if (is_overlapped(img)) return *this%=+img;
        T *ptrd = _data, *const ptre = _data + siz;
        if (siz>isiz) for (unsigned long n = siz/isiz; n; --n)
          for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd) *ptrd = cimg::mod(*ptrd,(T)*(ptrs++));
        for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = cimg::mod(*ptrd,(T)*(ptrs++));
      }
      return *this;
    }

    //! Modulo operator.
    /**
       Similar to operator%=(const t), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image may be a superset of the initial pixel type \c T, if necessary.
    **/
    template<typename t>
    CImg<_cimg_Tt> operator%(const t value) const {
      return CImg<_cimg_Tt>(*this,false)%=value;
    }

    //! Modulo operator.
    /**
       Similar to operator%=(const char*), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image may be a superset of the initial pixel type \c T, if necessary.
    **/
    CImg<Tfloat> operator%(const char *const expression) const {
      return CImg<Tfloat>(*this,false)%=expression;
    }

    //! Modulo operator.
    /**
       Similar to operator%=(const CImg<t>&), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image may be a superset of the initial pixel type \c T, if necessary.
    **/
    template<typename t>
    CImg<_cimg_Tt> operator%(const CImg<t>& img) const {
      return CImg<_cimg_Tt>(*this,false)%=img;
    }

    //! In-place bitwise AND operator.
    /**
       Similar to operator+=(const t), except that it performs a bitwise AND operation instead of an addition.
    **/
    template<typename t>
    CImg<T>& operator&=(const t value) {
      cimg_for(*this,ptrd,T) *ptrd = (T)((unsigned long)*ptrd & (unsigned long)value);
      return *this;
    }

    //! In-place bitwise AND operator.
    /**
       Similar to operator+=(const char*), except that it performs a bitwise AND operation instead of an addition.
    **/
    CImg<T>& operator&=(const char *const expression) {
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      try {
        const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(), &base = _base?_base:*this;
        _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator&=");
        T *ptrd = *expression=='<'?end()-1:_data;
        if (*expression=='<') cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)((unsigned long)*ptrd & (unsigned long)mp.eval(x,y,z,c)); --ptrd; }
        else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)((unsigned long)*ptrd & (unsigned long)mp.eval(x,y,z,c)); ++ptrd; }
      } catch (CImgException&) {
        cimg::exception_mode() = omode;
        *this&=CImg<T>(_width,_height,_depth,_spectrum,expression,true);
      }
      cimg::exception_mode() = omode;
      return *this;
    }

    //! In-place bitwise AND operator.
    /**
       Similar to operator+=(const CImg<t>&), except that it performs a bitwise AND operation instead of an addition.
    **/
    template<typename t>
    CImg<T>& operator&=(const CImg<t>& img) {
      const unsigned long siz = size(), isiz = img.size();
      if (siz && isiz) {
        if (is_overlapped(img)) return *this&=+img;
        T *ptrd = _data, *const ptre = _data + siz;
        if (siz>isiz) for (unsigned long n = siz/isiz; n; --n)
          for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd) *ptrd = (T)((unsigned long)*ptrd & (unsigned long)*(ptrs++));
        for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)((unsigned long)*ptrd & (unsigned long)*(ptrs++));
      }
      return *this;
    }

    //! Bitwise AND operator.
    /**
       Similar to operator&=(const t), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image is \c T.
    **/
    template<typename t>
    CImg<T> operator&(const t value) const {
      return (+*this)&=value;
    }

    //! Bitwise AND operator.
    /**
       Similar to operator&=(const char*), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image is \c T.
    **/
    CImg<T> operator&(const char *const expression) const {
      return (+*this)&=expression;
    }

    //! Bitwise AND operator.
    /**
       Similar to operator&=(const CImg<t>&), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image is \c T.
    **/
    template<typename t>
    CImg<T> operator&(const CImg<t>& img) const {
      return (+*this)&=img;
    }

    //! In-place bitwise OR operator.
    /**
       Similar to operator+=(const t), except that it performs a bitwise OR operation instead of an addition.
    **/
    template<typename t>
    CImg<T>& operator|=(const t value) {
      cimg_for(*this,ptrd,T) *ptrd = (T)((unsigned long)*ptrd | (unsigned long)value);
      return *this;
    }

    //! In-place bitwise OR operator.
    /**
       Similar to operator+=(const char*), except that it performs a bitwise OR operation instead of an addition.
    **/
    CImg<T>& operator|=(const char *const expression) {
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      try {
        const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(), &base = _base?_base:*this;
        _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator|=");
        T *ptrd = *expression=='<'?end()-1:_data;
        if (*expression=='<') cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)((unsigned long)*ptrd | (unsigned long)mp.eval(x,y,z,c)); --ptrd; }
        else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)((unsigned long)*ptrd | (unsigned long)mp.eval(x,y,z,c)); ++ptrd; }
      } catch (CImgException&) {
        cimg::exception_mode() = omode;
        *this|=CImg<T>(_width,_height,_depth,_spectrum,expression,true);
      }
      cimg::exception_mode() = omode;
      return *this;
    }

    //! In-place bitwise OR operator.
    /**
       Similar to operator+=(const CImg<t>&), except that it performs a bitwise OR operation instead of an addition.
    **/
    template<typename t>
    CImg<T>& operator|=(const CImg<t>& img) {
      const unsigned long siz = size(), isiz = img.size();
      if (siz && isiz) {
        if (is_overlapped(img)) return *this|=+img;
        T *ptrd = _data, *const ptre = _data + siz;
        if (siz>isiz) for (unsigned long n = siz/isiz; n; --n)
          for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd) *ptrd = (T)((unsigned long)*ptrd | (unsigned long)*(ptrs++));
        for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)((unsigned long)*ptrd | (unsigned long)*(ptrs++));
      }
      return *this;
    }

    //! Bitwise OR operator.
    /**
       Similar to operator|=(const t), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image is \c T.
    **/
    template<typename t>
    CImg<T> operator|(const t value) const {
      return (+*this)|=value;
    }

    //! Bitwise OR operator.
    /**
       Similar to operator|=(const char*), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image is \c T.
    **/
    CImg<T> operator|(const char *const expression) const {
      return (+*this)|=expression;
    }

    //! Bitwise OR operator.
    /**
       Similar to operator|=(const CImg<t>&), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image is \c T.
    **/
    template<typename t>
    CImg<T> operator|(const CImg<t>& img) const {
      return (+*this)|=img;
    }

    //! In-place bitwise XOR operator.
    /**
       Similar to operator+=(const t), except that it performs a bitwise XOR operation instead of an addition.
       \warning
       - It does \e not compute the \e power of pixel values. For this purpose, use pow(const t) instead.
    **/
    template<typename t>
    CImg<T>& operator^=(const t value) {
      cimg_for(*this,ptrd,T) *ptrd = (T)((unsigned long)*ptrd ^ (unsigned long)value);
      return *this;
    }

    //! In-place bitwise XOR operator.
    /**
       Similar to operator+=(const char*), except that it performs a bitwise XOR operation instead of an addition.
       \warning
       - It does \e not compute the \e power of pixel values. For this purpose, use pow(const char*) instead.
    **/
    CImg<T>& operator^=(const char *const expression) {
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      try {
        const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(), &base = _base?_base:*this;
        _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator^=");
        T *ptrd = *expression=='<'?end()-1:_data;
        if (*expression=='<') cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)((unsigned long)*ptrd ^ (unsigned long)mp.eval(x,y,z,c)); --ptrd; }
        else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)((unsigned long)*ptrd ^ (unsigned long)mp.eval(x,y,z,c)); ++ptrd; }
      } catch (CImgException&) {
        cimg::exception_mode() = omode;
        *this^=CImg<T>(_width,_height,_depth,_spectrum,expression,true);
      }
      cimg::exception_mode() = omode;
      return *this;
    }

    //! In-place bitwise XOR operator.
    /**
       Similar to operator+=(const CImg<t>&), except that it performs a bitwise XOR operation instead of an addition.
       \warning
       - It does \e not compute the \e power of pixel values. For this purpose, use pow(const CImg<t>&) instead.
    **/
    template<typename t>
    CImg<T>& operator^=(const CImg<t>& img) {
      const unsigned long siz = size(), isiz = img.size();
      if (siz && isiz) {
        if (is_overlapped(img)) return *this^=+img;
        T *ptrd = _data, *const ptre = _data + siz;
        if (siz>isiz) for (unsigned long n = siz/isiz; n; --n)
          for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd) *ptrd = (T)((unsigned long)*ptrd ^ (unsigned long)*(ptrs++));
        for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)((unsigned long)*ptrd ^ (unsigned long)*(ptrs++));
      }
      return *this;
    }

    //! Bitwise XOR operator.
    /**
       Similar to operator^=(const t), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image is \c T.
    **/
    template<typename t>
    CImg<T> operator^(const t value) const {
      return (+*this)^=value;
    }

    //! Bitwise XOR operator.
    /**
       Similar to operator^=(const char*), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image is \c T.
    **/
    CImg<T> operator^(const char *const expression) const {
      return (+*this)^=expression;
    }

    //! Bitwise XOR operator.
    /**
       Similar to operator^=(const CImg<t>&), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image is \c T.
    **/
    template<typename t>
    CImg<T> operator^(const CImg<t>& img) const {
      return (+*this)^=img;
    }

    //! In-place bitwise left shift operator.
    /**
       Similar to operator+=(const t), except that it performs a bitwise left shift instead of an addition.
    **/
    template<typename t>
    CImg<T>& operator<<=(const t value) {
      cimg_for(*this,ptrd,T) *ptrd = (T)(((long)*ptrd) << (int)value);
      return *this;
    }

    //! In-place bitwise left shift operator.
    /**
       Similar to operator+=(const char*), except that it performs a bitwise left shift instead of an addition.
    **/
    CImg<T>& operator<<=(const char *const expression) {
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      try {
        const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(), &base = _base?_base:*this;
        _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator<<=");
        T *ptrd = *expression=='<'?end()-1:_data;
        if (*expression=='<') cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)((long)*ptrd << (int)mp.eval(x,y,z,c)); --ptrd; }
        else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)((long)*ptrd << (int)mp.eval(x,y,z,c)); ++ptrd; }
      } catch (CImgException&) {
        cimg::exception_mode() = omode;
        *this<<=CImg<T>(_width,_height,_depth,_spectrum,expression,true);
      }
      cimg::exception_mode() = omode;
      return *this;
    }

    //! In-place bitwise left shift operator.
    /**
       Similar to operator+=(const CImg<t>&), except that it performs a bitwise left shift instead of an addition.
    **/
    template<typename t>
    CImg<T>& operator<<=(const CImg<t>& img) {
      const unsigned long siz = size(), isiz = img.size();
      if (siz && isiz) {
        if (is_overlapped(img)) return *this^=+img;
        T *ptrd = _data, *const ptre = _data + siz;
        if (siz>isiz) for (unsigned long n = siz/isiz; n; --n)
          for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd) *ptrd = (T)((long)*ptrd << (int)*(ptrs++));
        for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)((long)*ptrd << (int)*(ptrs++));
      }
      return *this;
    }

    //! Bitwise left shift operator.
    /**
       Similar to operator<<=(const t), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image is \c T.
    **/
    template<typename t>
    CImg<T> operator<<(const t value) const {
      return (+*this)<<=value;
    }

    //! Bitwise left shift operator.
    /**
       Similar to operator<<=(const char*), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image is \c T.
    **/
    CImg<T> operator<<(const char *const expression) const {
      return (+*this)<<=expression;
    }

    //! Bitwise left shift operator.
    /**
       Similar to operator<<=(const CImg<t>&), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image is \c T.
    **/
    template<typename t>
    CImg<T> operator<<(const CImg<t>& img) const {
      return (+*this)<<=img;
    }

    //! In-place bitwise right shift operator.
    /**
       Similar to operator+=(const t), except that it performs a bitwise right shift instead of an addition.
    **/
    template<typename t>
    CImg<T>& operator>>=(const t value) {
      cimg_for(*this,ptrd,T) *ptrd = (T)(((long)*ptrd) >> (int)value);
      return *this;
    }

    //! In-place bitwise right shift operator.
    /**
       Similar to operator+=(const char*), except that it performs a bitwise right shift instead of an addition.
    **/
    CImg<T>& operator>>=(const char *const expression) {
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      try {
        const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(), &base = _base?_base:*this;
        _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator<<=");
        T *ptrd = *expression=='<'?end()-1:_data;
        if (*expression=='<') cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)((long)*ptrd >> (int)mp.eval(x,y,z,c)); --ptrd; }
        else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)((long)*ptrd >> (int)mp.eval(x,y,z,c)); ++ptrd; }
      } catch (CImgException&) {
        cimg::exception_mode() = omode;
        *this>>=CImg<T>(_width,_height,_depth,_spectrum,expression,true);
      }
      cimg::exception_mode() = omode;
      return *this;
    }

    //! In-place bitwise right shift operator.
    /**
       Similar to operator+=(const CImg<t>&), except that it performs a bitwise right shift instead of an addition.
    **/
    template<typename t>
    CImg<T>& operator>>=(const CImg<t>& img) {
      const unsigned long siz = size(), isiz = img.size();
      if (siz && isiz) {
        if (is_overlapped(img)) return *this^=+img;
        T *ptrd = _data, *const ptre = _data + siz;
        if (siz>isiz) for (unsigned long n = siz/isiz; n; --n)
          for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd) *ptrd = (T)((long)*ptrd >> (int)*(ptrs++));
        for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)((long)*ptrd >> (int)*(ptrs++));
      }
      return *this;
    }

    //! Bitwise right shift operator.
    /**
       Similar to operator>>=(const t), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image is \c T.
    **/
    template<typename t>
    CImg<T> operator>>(const t value) const {
      return (+*this)>>=value;
    }

    //! Bitwise right shift operator.
    /**
       Similar to operator>>=(const char*), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image is \c T.
    **/
    CImg<T> operator>>(const char *const expression) const {
      return (+*this)>>=expression;
    }

    //! Bitwise right shift operator.
    /**
       Similar to operator>>=(const CImg<t>&), except that it returns a new image instance instead of operating in-place.
       The pixel type of the returned image is \c T.
    **/
    template<typename t>
    CImg<T> operator>>(const CImg<t>& img) const {
      return (+*this)>>=img;
    }

    //! Bitwise inversion operator.
    /**
       Similar to operator-(), except that it compute the bitwise inverse instead of the opposite value.
    **/
    CImg<T> operator~() const {
      CImg<T> res(_width,_height,_depth,_spectrum);
      const T *ptrs = _data;
      cimg_for(res,ptrd,T) { const unsigned long value = (unsigned long)*(ptrs++); *ptrd = (T)~value; }
      return res;
    }

    //! Test if all pixels of an image have the same value.
    /**
       Return \c true is all pixels of the image instance are equal to the specified \c value.
       \param value Reference value to compare with.
    **/
    template<typename t>
    bool operator==(const t value) const {
      if (is_empty()) return false;
      typedef _cimg_Tt Tt;
      bool is_equal = true;
      for (T *ptrd = _data + size(); is_equal && ptrd>_data; is_equal = ((Tt)*(--ptrd)==(Tt)value)) {}
      return is_equal;
    }

    //! Test if all pixel values of an image follow a specified expression.
    /**
       Return \c true is all pixels of the image instance are equal to the specified \c expression.
       \param expression Value string describing the way pixel values are compared.
    **/
    bool operator==(const char *const expression) const {
      if (is_empty()) return !*expression;
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      bool is_equal = true;
      try {
        const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(), &base = _base?_base:*this;
        _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"operator<<=");
        const T *ptrs = _data;
        if (*expression=='<') cimg_rofXYZC(*this,x,y,z,c) { if (!is_equal) break; is_equal = ((double)*(ptrs--)==mp.eval(x,y,z,c)); }
        else cimg_forXYZC(*this,x,y,z,c) { if (!is_equal) break; is_equal = ((double)*(ptrs++)==mp.eval(x,y,z,c)); }
      } catch (CImgException&) {
        cimg::exception_mode() = omode;
        is_equal = (*this==CImg<T>(_width,_height,_depth,_spectrum,expression,true));
      }
      cimg::exception_mode() = omode;
      return is_equal;
    }

    //! Test if two images have the same size and values.
    /**
       Return \c true if the image instance and the input image \c img have the same dimensions and pixel values, and \c false otherwise.
       \param img Input image to compare with.
       \note
       - The pixel buffer pointers data() of the two compared images do not have to be the same for operator==() to return \c true.
         Only the dimensions and the pixel values matter. Thus, the comparison can be \c true even for different pixel types \c T and \c t.
       \par Example
       \code
       const CImg<float> img1(1,3,1,1, 0,1,2); // Construct a 1x3 vector [0;1;2] (with 'float' pixel values).
       const CImg<char> img2(1,3,1,1, 0,1,2);  // Construct a 1x3 vector [0;1;2] (with 'char' pixel values).
       if (img1==img2) {                       // Test succeeds, image dimensions and values are the same.
         std::printf("'img1' and 'img2' have same dimensions and values.");
       }
       \endcode
    **/
    template<typename t>
    bool operator==(const CImg<t>& img) const {
      typedef _cimg_Tt Tt;
      const unsigned long siz = size();
      bool is_equal = true;
      if (siz!=img.size()) return false;
      t *ptrs = img._data + siz;
      for (T *ptrd = _data + siz; is_equal && ptrd>_data; is_equal = ((Tt)*(--ptrd)==(Tt)*(--ptrs))) {}
      return is_equal;
    }

    //! Test if pixels of an image are all different from a value.
    /**
       Return \c true is all pixels of the image instance are different than the specified \c value.
       \param value Reference value to compare with.
    **/
    template<typename t>
    bool operator!=(const t value) const {
      return !((*this)==value);
    }

    //! Test if all pixel values of an image are different from a specified expression.
    /**
       Return \c true is all pixels of the image instance are different to the specified \c expression.
       \param expression Value string describing the way pixel values are compared.
    **/
    bool operator!=(const char *const expression) const {
      return !((*this)==expression);
    }

    //! Test if two images have different sizes or values.
    /**
       Return \c true if the image instance and the input image \c img have different dimensions or pixel values, and \c false otherwise.
       \param img Input image to compare with.
       \note
       - Writing \c img1!=img2 is equivalent to \c !(img1==img2).
    **/
    template<typename t>
    bool operator!=(const CImg<t>& img) const {
      return !((*this)==img);
    }

    //! Construct an image list from two images.
    /**
       Return a new list of image (\c CImgList instance) containing exactly two elements:
         - A copy of the image instance, at position [\c 0].
         - A copy of the specified image \c img, at position [\c 1].

       \param img Input image that will be the second image of the resulting list.
       \note
       - The family of operator,() is convenient to easily create list of images, but it is also \e quite \e slow in practice (see warning below).
       - Constructed lists contain no shared images. If image instance or input image \c img are shared, they are
         inserted as new non-shared copies in the resulting list.
       - The pixel type of the returned list may be a superset of the initial pixel type \c T, if necessary.
       \warning
       - Pipelining operator,() \c N times will perform \c N copies of the entire content of a (growing) image list.
         This may become very expensive in terms of speed and used memory. You should avoid using this technique to
         build a new CImgList instance from several images, if you are seeking for performance.
         Fast insertions of images in an image list are possible with CImgList<T>::insert(const CImg<t>&,unsigned int,bool) or
         move_to(CImgList<t>&,unsigned int).
       \par Example
       \code
       const CImg<float>
          img1("reference.jpg"),
          img2 = img1.get_mirror('x'),
          img3 = img2.get_blur(5);
       const CImgList<float> list = (img1,img2); // Create list of two elements from 'img1' and 'img2'.
       (list,img3).display();                    // Display image list containing copies of 'img1','img2' and 'img3'.
       \endcode
       \image html ref_operator_comma.jpg
    **/
    template<typename t>
    CImgList<_cimg_Tt> operator,(const CImg<t>& img) const {
      return CImgList<_cimg_Tt>(*this,img);
    }

    //! Construct an image list from image instance and an input image list.
    /**
       Return a new list of images (\c CImgList instance) containing exactly \c list.size() \c + \c 1 elements:
         - A copy of the image instance, at position [\c 0].
         - A copy of the specified image list \c list, from positions [\c 1] to [\c list.size()].

       \param list Input image list that will be appended to the image instance.
       \note
       - Similar to operator,(const CImg<t>&) const, except that it takes an image list as an argument.
    **/
    template<typename t>
    CImgList<_cimg_Tt> operator,(const CImgList<t>& list) const {
      return CImgList<_cimg_Tt>(list,false).insert(*this,0);
    }

    //! Split image along specified axis.
    /**
       Return a new list of images (\c CImgList instance) containing the splitted components
       of the instance image along the specified axis.
       \param axis Splitting axis (can be '\c x','\c y','\c z' or '\c c')
       \note
       - Similar to get_split(char,int) const, with default second argument.
       \par Example
       \code
       const CImg<unsigned char> img("reference.jpg"); // Load a RGB color image.
       const CImgList<unsigned char> list = (img<'c'); // Get a list of its three R,G,B channels.
       (img,list).display();
       \endcode
       \image html ref_operator_less.jpg
    **/
    CImgList<T> operator<(const char axis) const {
      return get_split(axis);
    }

    //@}
    //-------------------------------------
    //
    //! \name Instance Characteristics
    //@{
    //-------------------------------------

    //! Return the type of image pixel values as a C string.
    /**
       Return a \c char* string containing the usual type name of the image pixel values
       (i.e. a stringified version of the template parameter \c T).
       \note
       - The returned string may contain spaces (as in \c "unsigned char").
       - If the pixel type \c T does not correspond to a registered type, the string <tt>"unknown"</tt> is returned.
    **/
    static const char* pixel_type() {
      return cimg::type<T>::string();
    }

    //! Return the number of image columns.
    /**
       Return the image width, i.e. the image dimension along the X-axis.
       \note
       - The width() of an empty image is equal to \c 0.
       - width() is typically equal to \c 1 when considering images as \e vectors for matrix calculations.
       - width() returns an \c int, although the image width is internally stored as an \c unsigned \c int.
         Using an \c int is safer and prevents arithmetic traps possibly encountered when doing calculations involving
         \c unsigned \c int variables.
         Access to the initial \c unsigned \c int variable is possible (though not recommended) by <tt>(*this)._width</tt>.
    **/
    int width() const {
      return (int)_width;
    }

    //! Return the number of image rows.
    /**
       Return the image height, i.e. the image dimension along the Y-axis.
       \note
       - The height() of an empty image is equal to \c 0.
       - height() returns an \c int, although the image height is internally stored as an \c unsigned \c int.
         Using an \c int is safer and prevents arithmetic traps possibly encountered when doing calculations involving
         \c unsigned \c int variables.
         Access to the initial \c unsigned \c int variable is possible (though not recommended) by <tt>(*this)._height</tt>.
    **/
    int height() const {
      return (int)_height;
    }

    //! Return the number of image slices.
    /**
       Return the image depth, i.e. the image dimension along the Z-axis.
       \note
       - The depth() of an empty image is equal to \c 0.
       - depth() is typically equal to \c 1 when considering usual 2d images. When depth()\c > \c 1, the image
         is said to be \e volumetric.
       - depth() returns an \c int, although the image depth is internally stored as an \c unsigned \c int.
         Using an \c int is safer and prevents arithmetic traps possibly encountered when doing calculations involving
         \c unsigned \c int variables.
         Access to the initial \c unsigned \c int variable is possible (though not recommended) by <tt>(*this)._depth</tt>.
    **/
    int depth() const {
      return (int)_depth;
    }

    //! Return the number of image channels.
    /**
       Return the number of image channels, i.e. the image dimension along the C-axis.
       \note
       - The spectrum() of an empty image is equal to \c 0.
       - spectrum() is typically equal to \c 1 when considering scalar-valued images, to \c 3 for RGB-coded color images, and to
         \c 4 for RGBA-coded color images (with alpha-channel). The number of channels of an image instance
         is not limited. The meaning of the pixel values is not linked up to the number of channels
         (e.g. a 4-channel image may indifferently stands for a RGBA or CMYK color image).
       - spectrum() returns an \c int, although the image spectrum is internally stored as an \c unsigned \c int.
         Using an \c int is safer and prevents arithmetic traps possibly encountered when doing calculations involving
         \c unsigned \c int variables.
         Access to the initial \c unsigned \c int variable is possible (though not recommended) by <tt>(*this)._spectrum</tt>.
    **/
    int spectrum() const {
      return (int)_spectrum;
    }

    //! Return the total number of pixel values.
    /**
       Return <tt>width()*\ref height()*\ref depth()*\ref spectrum()</tt>,
       i.e. the total number of values of type \c T in the pixel buffer of the image instance.
       \note
       - The size() of an empty image is equal to \c 0.
       - The allocated memory size for a pixel buffer of a non-shared \c CImg<T> instance is equal to <tt>size()*sizeof(T)</tt>.
       \par Example
       \code
       const CImg<float> img(100,100,1,3);               // Construct new 100x100 color image.
       if (img.size()==30000)                            // Test succeeds.
         std::printf("Pixel buffer uses %lu bytes",
                     img.size()*sizeof(float));
       \endcode
    **/
    unsigned long size() const {
      return (unsigned long)_width*_height*_depth*_spectrum;
    }

    //! Return a pointer to the first pixel value.
    /**
       Return a \c T*, or a \c const \c T* pointer to the first value in the pixel buffer of the image instance,
       whether the instance is \c const or not.
       \note
       - The data() of an empty image is equal to \c 0 (null pointer).
       - The allocated pixel buffer for the image instance starts from \c data()
         and goes to <tt>data()+\ref size()-1</tt> (included).
       - To get the pointer to one particular location of the pixel buffer, use data(unsigned int,unsigned int,unsigned int,unsigned int) instead.
    **/
    T* data() {
      return _data;
    }

    //! Return a pointer to the first pixel value \const.
    const T* data() const {
      return _data;
    }

    //! Return a pointer to a located pixel value.
    /**
       Return a \c T*, or a \c const \c T* pointer to the value located at (\c x,\c y,\c z,\c c) in the pixel buffer of the image instance,
       whether the instance is \c const or not.
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \note
       - Writing \c img.data(x,y,z,c) is equivalent to <tt>&(img(x,y,z,c))</tt>. Thus, this method has the same properties as
         operator()(unsigned int,unsigned int,unsigned int,unsigned int).
     **/
#if cimg_verbosity>=3
    T *data(const unsigned int x, const unsigned int y=0, const unsigned int z=0, const unsigned int c=0) {
      const unsigned long off = (unsigned long)offset(x,y,z,c);
      if (off>=size())
        cimg::warn(_cimg_instance
                   "data(): Invalid pointer request, at coordinates (%u,%u,%u,%u) [offset=%u].",
                   cimg_instance,
                   x,y,z,c,off);
      return _data + off;
    }

    //! Return a pointer to a located pixel value \const.
    const T* data(const unsigned int x, const unsigned int y=0, const unsigned int z=0, const unsigned int c=0) const {
      return const_cast<CImg<T>*>(this)->data(x,y,z,c);
    }
#else
# 11836 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    T* data(const unsigned int x, const unsigned int y=0, const unsigned int z=0, const unsigned int c=0) {
      return _data + x + y*(unsigned long)_width + z*(unsigned long)_width*_height + c*(unsigned long)_width*_height*_depth;
    }

    const T* data(const unsigned int x, const unsigned int y=0, const unsigned int z=0, const unsigned int c=0) const {
      return _data + x + y*_width + z*(unsigned long)_width*_height + c*(unsigned long)_width*_height*_depth;
    }
#endif
# 11844 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    //! Return the offset to a located pixel value, with respect to the beginning of the pixel buffer.
    /**
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \note
       - Writing \c img.data(x,y,z,c) is equivalent to <tt>&(img(x,y,z,c)) - img.data()</tt>.
         Thus, this method has the same properties as operator()(unsigned int,unsigned int,unsigned int,unsigned int).
       \par Example
       \code
       const CImg<float> img(100,100,1,3);      // Define a 100x100 RGB-color image.
       const long off = img.offset(10,10,0,2);  // Get the offset of the blue value of the pixel located at (10,10).
       const float val = img[off];              // Get the blue value of this pixel.
       \endcode
    **/
    long offset(const int x, const int y=0, const int z=0, const int c=0) const {
      return x + y*(long)_width + z*(long)_width*_height + c*(long)_width*_height*_depth;
    }

    //! Return a CImg<T>::iterator pointing to the first pixel value.
    /**
       \note
       - Equivalent to data().
       - It has been mainly defined for compatibility with STL naming conventions.
     **/
    iterator begin() {
      return _data;
    }

    //! Return a CImg<T>::iterator pointing to the first value of the pixel buffer \const.
    const_iterator begin() const {
      return _data;
    }

    //! Return a CImg<T>::iterator pointing next to the last pixel value.
    /**
       \note
       - Writing \c img.end() is equivalent to <tt>img.data() + img.size()</tt>.
       - It has been mainly defined for compatibility with STL naming conventions.
       \warning
       - The returned iterator actually points to a value located \e outside the acceptable bounds of the pixel buffer. Trying
         to read or write the content of the returned iterator will probably result in a crash. Use it mainly as an
         strict upper bound for a CImg<T>::iterator.
       \par Example
       \code
       CImg<float> img(100,100,1,3);                                     // Define a 100x100 RGB color image.
       for (CImg<float>::iterator it = img.begin(); it<img.end(); ++it)  // 'img.end()' used here as an upper bound for the iterator.
         *it = 0;
       \endcode
    **/
    iterator end() {
      return _data + size();
    }

    //! Return a CImg<T>::iterator pointing next to the last pixel value \const.
    const_iterator end() const {
      return _data + size();
    }

    //! Return a reference to the first pixel value.
    /**
       \note
       - Writing \c img.front() is equivalent to <tt>img[0]</tt>, or <tt>img(0,0,0,0)</tt>.
       - It has been mainly defined for compatibility with STL naming conventions.
    **/
    T& front() {
      return *_data;
    }

    //! Return a reference to the first pixel value \const.
    const T& front() const {
      return *_data;
    }

    //! Return a reference to the last pixel value.
    /**
       \note
       - Writing \c img.end() is equivalent to <tt>img[img.size()-1]</tt>, or
         <tt>img(img.width()-1,img.height()-1,img.depth()-1,img.spectrum()-1)</tt>.
       - It has been mainly defined for compatibility with STL naming conventions.
    **/
    T& back() {
      return *(_data + size() - 1);
    }

    //! Return a reference to the last pixel value \const.
    const T& back() const {
      return *(_data + size() - 1);
    }

    //! Access to a pixel value at a specified offset, using Dirichlet boundary conditions.
    /**
       Return a reference to the pixel value of the image instance located at a specified \c offset,
       or to a specified default value in case of out-of-bounds access.
       \param offset Offset to the desired pixel value.
       \param out_value Default value returned if \c offset is outside image bounds.
       \note
       - Writing \c img.at(offset,out_value) is similar to <tt>img[offset]</tt>, except that if \c offset
         is outside bounds (e.g. \c offset<0 or \c offset>=img.size()), a reference to a value \c out_value
         is safely returned instead.
       - Due to the additional boundary checking operation, this method is slower than operator()(). Use it when
         you are \e not sure about the validity of the specified pixel offset.
    **/
    T& at(const int offset, const T out_value) {
      return (offset<0 || offset>=(int)size())?(cimg::temporary(out_value)=out_value):(*this)[offset];
    }

    //! Access to a pixel value at a specified offset, using Dirichlet boundary conditions \const.
    T at(const int offset, const T out_value) const {
      return (offset<0 || offset>=(int)size())?out_value:(*this)[offset];
    }

    //! Access to a pixel value at a specified offset, using Neumann boundary conditions.
    /**
       Return a reference to the pixel value of the image instance located at a specified \c offset,
       or to the nearest pixel location in the image instance in case of out-of-bounds access.
       \param offset Offset to the desired pixel value.
       \note
       - Similar to at(int,const T), except that an out-of-bounds access returns the value of the
         nearest pixel in the image instance, regarding the specified offset, i.e.
         - If \c offset<0, then \c img[0] is returned.
         - If \c offset>=img.size(), then \c img[img.size()-1] is returned.
       - Due to the additional boundary checking operation, this method is slower than operator()(). Use it when
         you are \e not sure about the validity of the specified pixel offset.
       - If you know your image instance is \e not empty, you may rather use the slightly faster method \c _at(int).
     **/
    T& at(const int offset) {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "at(): Empty instance.",
                                    cimg_instance);
      return _at(offset);
    }

    T& _at(const int offset) {
      const unsigned int siz = (unsigned int)size();
      return (*this)[offset<0?0:(unsigned int)offset>=siz?siz-1:offset];
    }

    //! Access to a pixel value at a specified offset, using Neumann boundary conditions \const.
    T at(const int offset) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "at(): Empty instance.",
                                    cimg_instance);
      return _at(offset);
    }

    T _at(const int offset) const {
      const unsigned int siz = (unsigned int)size();
      return (*this)[offset<0?0:(unsigned int)offset>=siz?siz-1:offset];
    }

    //! Access to a pixel value, using Dirichlet boundary conditions for the X-coordinate.
    /**
       Return a reference to the pixel value of the image instance located at (\c x,\c y,\c z,\c c),
       or to a specified default value in case of out-of-bounds access along the X-axis.
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \param out_value Default value returned if \c (\c x,\c y,\c z,\c c) is outside image bounds.
       \note
       - Similar to operator()(), except that an out-of-bounds access along the X-axis returns the specified value \c out_value.
       - Due to the additional boundary checking operation, this method is slower than operator()(). Use it when
         you are \e not sure about the validity of the specified pixel coordinates.
       \warning
       - There is \e no boundary checking performed for the Y,Z and C-coordinates, so they must be inside image bounds.
    **/
    T& atX(const int x, const int y, const int z, const int c, const T out_value) {
      return (x<0 || x>=width())?(cimg::temporary(out_value)=out_value):(*this)(x,y,z,c);
    }

    //! Access to a pixel value, using Dirichlet boundary conditions for the X-coordinate \const.
    T atX(const int x, const int y, const int z, const int c, const T out_value) const {
      return (x<0 || x>=width())?out_value:(*this)(x,y,z,c);
    }

    //! Access to a pixel value, using Neumann boundary conditions for the X-coordinate.
    /**
       Return a reference to the pixel value of the image instance located at (\c x,\c y,\c z,\c c),
       or to the nearest pixel location in the image instance in case of out-of-bounds access along the X-axis.
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \note
       - Similar to at(int,int,int,int,const T), except that an out-of-bounds access returns the value of the
         nearest pixel in the image instance, regarding the specified X-coordinate.
       - Due to the additional boundary checking operation, this method is slower than operator()(). Use it when
         you are \e not sure about the validity of the specified pixel coordinates.
       - If you know your image instance is \e not empty, you may rather use the slightly faster method \c _at(int,int,int,int).
       \warning
       - There is \e no boundary checking performed for the Y,Z and C-coordinates, so they must be inside image bounds.
     **/
    T& atX(const int x, const int y=0, const int z=0, const int c=0) {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "atX(): Empty instance.",
                                    cimg_instance);
      return _atX(x,y,z,c);
    }

    T& _atX(const int x, const int y=0, const int z=0, const int c=0) {
      return (*this)(x<0?0:(x>=width()?width()-1:x),y,z,c);
    }

    //! Access to a pixel value, using Neumann boundary conditions for the X-coordinate \const.
    T atX(const int x, const int y=0, const int z=0, const int c=0) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "atX(): Empty instance.",
                                    cimg_instance);
      return _atX(x,y,z,c);
    }

    T _atX(const int x, const int y=0, const int z=0, const int c=0) const {
      return (*this)(x<0?0:(x>=width()?width()-1:x),y,z,c);
    }

    //! Access to a pixel value, using Dirichlet boundary conditions for the X and Y-coordinates.
    /**
       Similar to atX(int,int,int,int,const T), except that boundary checking is performed both on X and Y-coordinates.
    **/
    T& atXY(const int x, const int y, const int z, const int c, const T out_value) {
      return (x<0 || y<0 || x>=width() || y>=height())?(cimg::temporary(out_value)=out_value):(*this)(x,y,z,c);
    }

    //! Access to a pixel value, using Dirichlet boundary conditions for the X and Y coordinates \const.
    T atXY(const int x, const int y, const int z, const int c, const T out_value) const {
      return (x<0 || y<0 || x>=width() || y>=height())?out_value:(*this)(x,y,z,c);
    }

    //! Access to a pixel value, using Neumann boundary conditions for the X and Y-coordinates.
    /**
       Similar to atX(int,int,int,int), except that boundary checking is performed both on X and Y-coordinates.
       \note
       - If you know your image instance is \e not empty, you may rather use the slightly faster method \c _atXY(int,int,int,int).
     **/
    T& atXY(const int x, const int y, const int z=0, const int c=0) {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "atXY(): Empty instance.",
                                    cimg_instance);
      return _atXY(x,y,z,c);
    }

    T& _atXY(const int x, const int y, const int z=0, const int c=0) {
      return (*this)(x<0?0:(x>=width()?width()-1:x), y<0?0:(y>=height()?height()-1:y),z,c);
    }

    //! Access to a pixel value, using Neumann boundary conditions for the X and Y-coordinates \const.
    T atXY(const int x, const int y, const int z=0, const int c=0) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "atXY(): Empty instance.",
                                    cimg_instance);
      return _atXY(x,y,z,c);
    }

    T _atXY(const int x, const int y, const int z=0, const int c=0) const {
      return (*this)(x<0?0:(x>=width()?width()-1:x), y<0?0:(y>=height()?height()-1:y),z,c);
    }

    //! Access to a pixel value, using Dirichlet boundary conditions for the X,Y and Z-coordinates.
    /**
       Similar to atX(int,int,int,int,const T), except that boundary checking is performed both on X,Y and Z-coordinates.
    **/
    T& atXYZ(const int x, const int y, const int z, const int c, const T out_value) {
      return (x<0 || y<0 || z<0 || x>=width() || y>=height() || z>=depth())?
        (cimg::temporary(out_value)=out_value):(*this)(x,y,z,c);
    }

    //! Access to a pixel value, using Dirichlet boundary conditions for the X,Y and Z-coordinates \const.
    T atXYZ(const int x, const int y, const int z, const int c, const T out_value) const {
      return (x<0 || y<0 || z<0 || x>=width() || y>=height() || z>=depth())?out_value:(*this)(x,y,z,c);
    }

    //! Access to a pixel value, using Neumann boundary conditions for the X,Y and Z-coordinates.
    /**
       Similar to atX(int,int,int,int), except that boundary checking is performed both on X,Y and Z-coordinates.
       \note
       - If you know your image instance is \e not empty, you may rather use the slightly faster method \c _atXYZ(int,int,int,int).
    **/
    T& atXYZ(const int x, const int y, const int z, const int c=0) {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "atXYZ(): Empty instance.",
                                    cimg_instance);
      return _atXYZ(x,y,z,c);
    }

    T& _atXYZ(const int x, const int y, const int z, const int c=0) {
      return (*this)(x<0?0:(x>=width()?width()-1:x),y<0?0:(y>=height()?height()-1:y),
                     z<0?0:(z>=depth()?depth()-1:z),c);
    }

    //! Access to a pixel value, using Neumann boundary conditions for the X,Y and Z-coordinates \const.
    T atXYZ(const int x, const int y, const int z, const int c=0) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "atXYZ(): Empty instance.",
                                    cimg_instance);
      return _atXYZ(x,y,z,c);
    }

    T _atXYZ(const int x, const int y, const int z, const int c=0) const {
      return (*this)(x<0?0:(x>=width()?width()-1:x),y<0?0:(y>=height()?height()-1:y),
                     z<0?0:(z>=depth()?depth()-1:z),c);
    }

    //! Access to a pixel value, using Dirichlet boundary conditions.
    /**
       Similar to atX(int,int,int,int,const T), except that boundary checking is performed on all X,Y,Z and C-coordinates.
    **/
    T& atXYZC(const int x, const int y, const int z, const int c, const T out_value) {
      return (x<0 || y<0 || z<0 || c<0 || x>=width() || y>=height() || z>=depth() || c>=spectrum())?
        (cimg::temporary(out_value)=out_value):(*this)(x,y,z,c);
    }

    //! Access to a pixel value, using Dirichlet boundary conditions \const.
    T atXYZC(const int x, const int y, const int z, const int c, const T out_value) const {
      return (x<0 || y<0 || z<0 || c<0 || x>=width() || y>=height() || z>=depth() || c>=spectrum())?out_value:(*this)(x,y,z,c);
    }

    //! Access to a pixel value, using Neumann boundary conditions.
    /**
       Similar to atX(int,int,int,int), except that boundary checking is performed on all X,Y,Z and C-coordinates.
       \note
       - If you know your image instance is \e not empty, you may rather use the slightly faster method \c _atXYZC(int,int,int,int).
    **/
    T& atXYZC(const int x, const int y, const int z, const int c) {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "atXYZC(): Empty instance.",
                                    cimg_instance);
      return _atXYZC(x,y,z,c);
    }

    T& _atXYZC(const int x, const int y, const int z, const int c) {
      return (*this)(x<0?0:(x>=width()?width()-1:x), y<0?0:(y>=height()?height()-1:y),
                     z<0?0:(z>=depth()?depth()-1:z), c<0?0:(c>=spectrum()?spectrum()-1:c));
    }

    //! Access to a pixel value, using Neumann boundary conditions \const.
    T atXYZC(const int x, const int y, const int z, const int c) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "atXYZC(): Empty instance.",
                                    cimg_instance);
      return _atXYZC(x,y,z,c);
    }

    T _atXYZC(const int x, const int y, const int z, const int c) const {
      return (*this)(x<0?0:(x>=width()?width()-1:x), y<0?0:(y>=height()?height()-1:y),
                     z<0?0:(z>=depth()?depth()-1:z), c<0?0:(c>=spectrum()?spectrum()-1:c));
    }

    //! Return pixel value, using linear interpolation and Dirichlet boundary conditions for the X-coordinate.
    /**
       Return a linearly-interpolated pixel value of the image instance located at (\c fx,\c y,\c z,\c c),
       or a specified default value in case of out-of-bounds access along the X-axis.
       \param fx X-coordinate of the pixel value (float-valued).
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \param out_value Default value returned if \c (\c fx,\c y,\c z,\c c) is outside image bounds.
       \note
       - Similar to atX(int,int,int,int,const T), except that the returned pixel value is approximated by a linear interpolation along the X-axis,
         if corresponding coordinates are not integers.
       - The type of the returned pixel value is extended to \c float, if the pixel type \c T is not float-valued.
       \warning
       - There is \e no boundary checking performed for the Y,Z and C-coordinates, so they must be inside image bounds.
    **/
    Tfloat linear_atX(const float fx, const int y, const int z, const int c, const T out_value) const {
      const int
	x = (int)fx - (fx>=0?0:1), nx = x + 1;
      const float
        dx = fx - x;
      const Tfloat
        Ic = (Tfloat)atX(x,y,z,c,out_value), In = (Tfloat)atXY(nx,y,z,c,out_value);
      return Ic + dx*(In-Ic);
    }

    //! Return pixel value, using linear interpolation and Neumann boundary conditions for the X-coordinate.
    /**
       Return a linearly-interpolated pixel value of the image instance located at (\c fx,\c y,\c z,\c c),
       or the value of the nearest pixel location in the image instance in case of out-of-bounds access along the X-axis.
       \param fx X-coordinate of the pixel value (float-valued).
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \note
       - Similar to linear_atX(float,int,int,int,const T) const, except that an out-of-bounds access returns the value of the
         nearest pixel in the image instance, regarding the specified X-coordinate.
       - If you know your image instance is \e not empty, you may rather use the slightly faster method \c _linear_atX(float,int,int,int).
       \warning
       - There is \e no boundary checking performed for the Y,Z and C-coordinates, so they must be inside image bounds.
    **/
    Tfloat linear_atX(const float fx, const int y=0, const int z=0, const int c=0) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "linear_atX(): Empty instance.",
                                    cimg_instance);

      return _linear_atX(fx,y,z,c);
    }

    Tfloat _linear_atX(const float fx, const int y=0, const int z=0, const int c=0) const {
      const float
        nfx = fx<0?0:(fx>_width-1?_width-1:fx);
      const unsigned int
        x = (unsigned int)nfx;
      const float
        dx = nfx - x;
      const unsigned int
        nx = dx>0?x+1:x;
      const Tfloat
        Ic = (Tfloat)(*this)(x,y,z,c), In = (Tfloat)(*this)(nx,y,z,c);
      return Ic + dx*(In-Ic);
    }

    //! Return pixel value, using linear interpolation and Dirichlet boundary conditions for the X and Y-coordinates.
    /**
       Similar to linear_atX(float,int,int,int,const T) const, except that the linear interpolation and the boundary checking
       are achieved both for X and Y-coordinates.
    **/
    Tfloat linear_atXY(const float fx, const float fy, const int z, const int c, const T out_value) const {
      const int
        x = (int)fx - (fx>=0?0:1), nx = x + 1,
        y = (int)fy - (fy>=0?0:1), ny = y + 1;
      const float
        dx = fx - x,
        dy = fy - y;
      const Tfloat
        Icc = (Tfloat)atXY(x,y,z,c,out_value),  Inc = (Tfloat)atXY(nx,y,z,c,out_value),
        Icn = (Tfloat)atXY(x,ny,z,c,out_value), Inn = (Tfloat)atXY(nx,ny,z,c,out_value);
      return Icc + dx*(Inc-Icc + dy*(Icc+Inn-Icn-Inc)) + dy*(Icn-Icc);
    }

    //! Return pixel value, using linear interpolation and Neumann boundary conditions for the X and Y-coordinates.
    /**
       Similar to linear_atX(float,int,int,int) const, except that the linear interpolation and the boundary checking
       are achieved both for X and Y-coordinates.
       \note
       - If you know your image instance is \e not empty, you may rather use the slightly faster method \c _linear_atXY(float,float,int,int).
    **/
    Tfloat linear_atXY(const float fx, const float fy, const int z=0, const int c=0) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "linear_atXY(): Empty instance.",
                                    cimg_instance);

      return _linear_atXY(fx,fy,z,c);
    }

    Tfloat _linear_atXY(const float fx, const float fy, const int z=0, const int c=0) const {
      const float
        nfx = fx<0?0:(fx>_width-1?_width-1:fx),
        nfy = fy<0?0:(fy>_height-1?_height-1:fy);
      const unsigned int
        x = (unsigned int)nfx,
        y = (unsigned int)nfy;
      const float
        dx = nfx - x,
        dy = nfy - y;
      const unsigned int
        nx = dx>0?x+1:x,
        ny = dy>0?y+1:y;
      const Tfloat
        Icc = (Tfloat)(*this)(x,y,z,c),  Inc = (Tfloat)(*this)(nx,y,z,c),
        Icn = (Tfloat)(*this)(x,ny,z,c), Inn = (Tfloat)(*this)(nx,ny,z,c);
      return Icc + dx*(Inc-Icc + dy*(Icc+Inn-Icn-Inc)) + dy*(Icn-Icc);
    }

    //! Return pixel value, using linear interpolation and Dirichlet boundary conditions for the X,Y and Z-coordinates.
    /**
       Similar to linear_atX(float,int,int,int,const T) const, except that the linear interpolation and the boundary checking
       are achieved both for X,Y and Z-coordinates.
    **/
    Tfloat linear_atXYZ(const float fx, const float fy, const float fz, const int c, const T out_value) const {
      const int
        x = (int)fx - (fx>=0?0:1), nx = x + 1,
        y = (int)fy - (fy>=0?0:1), ny = y + 1,
        z = (int)fz - (fz>=0?0:1), nz = z + 1;
      const float
        dx = fx - x,
        dy = fy - y,
        dz = fz - z;
      const Tfloat
        Iccc = (Tfloat)atXYZ(x,y,z,c,out_value), Incc = (Tfloat)atXYZ(nx,y,z,c,out_value),
        Icnc = (Tfloat)atXYZ(x,ny,z,c,out_value), Innc = (Tfloat)atXYZ(nx,ny,z,c,out_value),
        Iccn = (Tfloat)atXYZ(x,y,nz,c,out_value), Incn = (Tfloat)atXYZ(nx,y,nz,c,out_value),
        Icnn = (Tfloat)atXYZ(x,ny,nz,c,out_value), Innn = (Tfloat)atXYZ(nx,ny,nz,c,out_value);
      return Iccc +
        dx*(Incc-Iccc +
            dy*(Iccc+Innc-Icnc-Incc +
                dz*(Iccn+Innn+Icnc+Incc-Icnn-Incn-Iccc-Innc)) +
            dz*(Iccc+Incn-Iccn-Incc)) +
        dy*(Icnc-Iccc +
            dz*(Iccc+Icnn-Iccn-Icnc)) +
        dz*(Iccn-Iccc);
    }

    //! Return pixel value, using linear interpolation and Neumann boundary conditions for the X,Y and Z-coordinates.
    /**
       Similar to linear_atX(float,int,int,int) const, except that the linear interpolation and the boundary checking
       are achieved both for X,Y and Z-coordinates.
       \note
       - If you know your image instance is \e not empty, you may rather use the slightly faster method \c _linear_atXYZ(float,float,float,int).
    **/
    Tfloat linear_atXYZ(const float fx, const float fy=0, const float fz=0, const int c=0) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "linear_atXYZ(): Empty instance.",
                                    cimg_instance);

      return _linear_atXYZ(fx,fy,fz,c);
    }

    Tfloat _linear_atXYZ(const float fx, const float fy=0, const float fz=0, const int c=0) const {
      const float
        nfx = fx<0?0:(fx>_width-1?_width-1:fx),
        nfy = fy<0?0:(fy>_height-1?_height-1:fy),
        nfz = fz<0?0:(fz>_depth-1?_depth-1:fz);
      const unsigned int
        x = (unsigned int)nfx,
        y = (unsigned int)nfy,
        z = (unsigned int)nfz;
      const float
        dx = nfx - x,
        dy = nfy - y,
        dz = nfz - z;
      const unsigned int
        nx = dx>0?x+1:x,
        ny = dy>0?y+1:y,
        nz = dz>0?z+1:z;
      const Tfloat
        Iccc = (Tfloat)(*this)(x,y,z,c), Incc = (Tfloat)(*this)(nx,y,z,c),
        Icnc = (Tfloat)(*this)(x,ny,z,c), Innc = (Tfloat)(*this)(nx,ny,z,c),
        Iccn = (Tfloat)(*this)(x,y,nz,c), Incn = (Tfloat)(*this)(nx,y,nz,c),
        Icnn = (Tfloat)(*this)(x,ny,nz,c), Innn = (Tfloat)(*this)(nx,ny,nz,c);
      return Iccc +
        dx*(Incc-Iccc +
            dy*(Iccc+Innc-Icnc-Incc +
                dz*(Iccn+Innn+Icnc+Incc-Icnn-Incn-Iccc-Innc)) +
            dz*(Iccc+Incn-Iccn-Incc)) +
        dy*(Icnc-Iccc +
            dz*(Iccc+Icnn-Iccn-Icnc)) +
        dz*(Iccn-Iccc);
    }

    //! Return pixel value, using linear interpolation and Dirichlet boundary conditions for all X,Y,Z and C-coordinates.
    /**
       Similar to linear_atX(float,int,int,int,const T) const, except that the linear interpolation and the boundary checking
       are achieved for all X,Y,Z and C-coordinates.
    **/
    Tfloat linear_atXYZC(const float fx, const float fy, const float fz, const float fc, const T out_value) const {
      const int
        x = (int)fx - (fx>=0?0:1), nx = x + 1,
        y = (int)fy - (fy>=0?0:1), ny = y + 1,
        z = (int)fz - (fz>=0?0:1), nz = z + 1,
        c = (int)fc - (fc>=0?0:1), nc = c + 1;
      const float
        dx = fx - x,
        dy = fy - y,
        dz = fz - z,
        dc = fc - c;
      const Tfloat
        Icccc = (Tfloat)atXYZC(x,y,z,c,out_value), Inccc = (Tfloat)atXYZC(nx,y,z,c,out_value),
        Icncc = (Tfloat)atXYZC(x,ny,z,c,out_value), Inncc = (Tfloat)atXYZC(nx,ny,z,c,out_value),
        Iccnc = (Tfloat)atXYZC(x,y,nz,c,out_value), Incnc = (Tfloat)atXYZC(nx,y,nz,c,out_value),
        Icnnc = (Tfloat)atXYZC(x,ny,nz,c,out_value), Innnc = (Tfloat)atXYZC(nx,ny,nz,c,out_value),
        Icccn = (Tfloat)atXYZC(x,y,z,nc,out_value), Inccn = (Tfloat)atXYZC(nx,y,z,nc,out_value),
        Icncn = (Tfloat)atXYZC(x,ny,z,nc,out_value), Inncn = (Tfloat)atXYZC(nx,ny,z,nc,out_value),
        Iccnn = (Tfloat)atXYZC(x,y,nz,nc,out_value), Incnn = (Tfloat)atXYZC(nx,y,nz,nc,out_value),
        Icnnn = (Tfloat)atXYZC(x,ny,nz,nc,out_value), Innnn = (Tfloat)atXYZC(nx,ny,nz,nc,out_value);
      return Icccc +
        dx*(Inccc-Icccc +
            dy*(Icccc+Inncc-Icncc-Inccc +
                dz*(Iccnc+Innnc+Icncc+Inccc-Icnnc-Incnc-Icccc-Inncc +
                    dc*(Iccnn+Innnn+Icncn+Inccn+Icnnc+Incnc+Icccc+Inncc-Icnnn-Incnn-Icccn-Inncn-Iccnc-Innnc-Icncc-Inccc)) +
                dc*(Icccn+Inncn+Icncc+Inccc-Icncn-Inccn-Icccc-Inncc)) +
            dz*(Icccc+Incnc-Iccnc-Inccc +
                dc*(Icccn+Incnn+Iccnc+Inccc-Iccnn-Inccn-Icccc-Incnc)) +
            dc*(Icccc+Inccn-Inccc-Icccn)) +
        dy*(Icncc-Icccc +
            dz*(Icccc+Icnnc-Iccnc-Icncc +
                dc*(Icccn+Icnnn+Iccnc+Icncc-Iccnn-Icncn-Icccc-Icnnc)) +
            dc*(Icccc+Icncn-Icncc-Icccn)) +
        dz*(Iccnc-Icccc +
            dc*(Icccc+Iccnn-Iccnc-Icccn)) +
        dc*(Icccn-Icccc);
    }

    //! Return pixel value, using linear interpolation and Neumann boundary conditions for all X,Y,Z and C-coordinates.
    /**
       Similar to linear_atX(float,int,int,int) const, except that the linear interpolation and the boundary checking
       are achieved for all X,Y,Z and C-coordinates.
       \note
       - If you know your image instance is \e not empty, you may rather use the slightly faster method \c _linear_atXYZC(float,float,float,float).
    **/
    Tfloat linear_atXYZC(const float fx, const float fy=0, const float fz=0, const float fc=0) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "linear_atXYZC(): Empty instance.",
                                    cimg_instance);

      return _linear_atXYZC(fx,fy,fz,fc);
    }

    Tfloat _linear_atXYZC(const float fx, const float fy=0, const float fz=0, const float fc=0) const {
      const float
        nfx = fx<0?0:(fx>_width-1?_width-1:fx),
        nfy = fy<0?0:(fy>_height-1?_height-1:fy),
        nfz = fz<0?0:(fz>_depth-1?_depth-1:fz),
        nfc = fc<0?0:(fc>_spectrum-1?_spectrum-1:fc);
      const unsigned int
        x = (unsigned int)nfx,
        y = (unsigned int)nfy,
        z = (unsigned int)nfz,
        c = (unsigned int)nfc;
      const float
        dx = nfx - x,
        dy = nfy - y,
        dz = nfz - z,
        dc = nfc - c;
      const unsigned int
        nx = dx>0?x+1:x,
        ny = dy>0?y+1:y,
        nz = dz>0?z+1:z,
        nc = dc>0?c+1:c;
      const Tfloat
        Icccc = (Tfloat)(*this)(x,y,z,c), Inccc = (Tfloat)(*this)(nx,y,z,c),
        Icncc = (Tfloat)(*this)(x,ny,z,c), Inncc = (Tfloat)(*this)(nx,ny,z,c),
        Iccnc = (Tfloat)(*this)(x,y,nz,c), Incnc = (Tfloat)(*this)(nx,y,nz,c),
        Icnnc = (Tfloat)(*this)(x,ny,nz,c), Innnc = (Tfloat)(*this)(nx,ny,nz,c),
        Icccn = (Tfloat)(*this)(x,y,z,nc), Inccn = (Tfloat)(*this)(nx,y,z,nc),
        Icncn = (Tfloat)(*this)(x,ny,z,nc), Inncn = (Tfloat)(*this)(nx,ny,z,nc),
        Iccnn = (Tfloat)(*this)(x,y,nz,nc), Incnn = (Tfloat)(*this)(nx,y,nz,nc),
        Icnnn = (Tfloat)(*this)(x,ny,nz,nc), Innnn = (Tfloat)(*this)(nx,ny,nz,nc);
      return Icccc +
        dx*(Inccc-Icccc +
            dy*(Icccc+Inncc-Icncc-Inccc +
                dz*(Iccnc+Innnc+Icncc+Inccc-Icnnc-Incnc-Icccc-Inncc +
                    dc*(Iccnn+Innnn+Icncn+Inccn+Icnnc+Incnc+Icccc+Inncc-Icnnn-Incnn-Icccn-Inncn-Iccnc-Innnc-Icncc-Inccc)) +
                dc*(Icccn+Inncn+Icncc+Inccc-Icncn-Inccn-Icccc-Inncc)) +
            dz*(Icccc+Incnc-Iccnc-Inccc +
                dc*(Icccn+Incnn+Iccnc+Inccc-Iccnn-Inccn-Icccc-Incnc)) +
            dc*(Icccc+Inccn-Inccc-Icccn)) +
        dy*(Icncc-Icccc +
            dz*(Icccc+Icnnc-Iccnc-Icncc +
                dc*(Icccn+Icnnn+Iccnc+Icncc-Iccnn-Icncn-Icccc-Icnnc)) +
            dc*(Icccc+Icncn-Icncc-Icccn)) +
        dz*(Iccnc-Icccc +
            dc*(Icccc+Iccnn-Iccnc-Icccn)) +
        dc*(Icccn-Icccc);
    }

    //! Return pixel value, using cubic interpolation and Dirichlet boundary conditions for the X-coordinate.
    /**
       Return a cubicly-interpolated pixel value of the image instance located at (\c fx,\c y,\c z,\c c),
       or a specified default value in case of out-of-bounds access along the X-axis.
       \param fx d X-coordinate of the pixel value (float-valued).
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \param out_value Default value returned if \c (\c fx,\c y,\c z,\c c) is outside image bounds.
       \note
       - Similar to linear_atX(float,int,int,int,const T) const, except that the returned pixel value is approximated by a
         \e cubic interpolation along the X-axis.
       - The type of the returned pixel value is extended to \c float, if the pixel type \c T is not float-valued.
       \warning
       - There is \e no boundary checking performed for the Y,Z and C-coordinates, so they must be inside image bounds.
    **/
    Tfloat cubic_atX(const float fx, const int y, const int z, const int c, const T out_value) const {
      const int
        x = (int)fx - (fx>=0?0:1), px = x - 1, nx = x + 1, ax = x + 2;
      const float
        dx = fx - x;
      const Tfloat
        Ip = (Tfloat)atX(px,y,z,c,out_value), Ic = (Tfloat)atX(x,y,z,c,out_value),
        In = (Tfloat)atX(nx,y,z,c,out_value), Ia = (Tfloat)atX(ax,y,z,c,out_value);
      return Ic + 0.5f*(dx*(-Ip+In) + dx*dx*(2*Ip-5*Ic+4*In-Ia) + dx*dx*dx*(-Ip+3*Ic-3*In+Ia));
    }

    //! Return damped pixel value, using cubic interpolation and Dirichlet boundary conditions for the X-coordinate.
    /**
       Similar to cubic_atX(float,int,int,int,const T) const, except that you can specify the authorized minimum and maximum of the returned value.
    **/
    Tfloat cubic_atX(const float fx, const int y, const int z, const int c, const T out_value,
                     const Tfloat min_value, const Tfloat max_value) const {
      const Tfloat val = cubic_atX(fx,y,z,c,out_value);
      return val<min_value?min_value:val>max_value?max_value:val;
    }

    //! Return pixel value, using cubic interpolation and Neumann boundary conditions for the X-coordinate.
    /**
       Return a cubicly-interpolated pixel value of the image instance located at (\c fx,\c y,\c z,\c c),
       or the value of the nearest pixel location in the image instance in case of out-of-bounds access along the X-axis.
       \param fx X-coordinate of the pixel value (float-valued).
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \note
       - Similar to cubic_atX(float,int,int,int,const T) const, except that the returned pixel value is approximated by a cubic interpolation along the X-axis.
       - If you know your image instance is \e not empty, you may rather use the slightly faster method \c _cubic_atX(float,int,int,int).
       \warning
       - There is \e no boundary checking performed for the Y,Z and C-coordinates, so they must be inside image bounds.
    **/
    Tfloat cubic_atX(const float fx, const int y=0, const int z=0, const int c=0) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "cubic_atX(): Empty instance.",
                                    cimg_instance);
      return _cubic_atX(fx,y,z,c);
    }

    Tfloat _cubic_atX(const float fx, const int y=0, const int z=0, const int c=0) const {
      const float
        nfx = fx<0?0:(fx>_width-1?_width-1:fx);
      const int
        x = (int)nfx;
      const float
        dx = nfx - x;
      const int
        px = x-1<0?0:x-1, nx = dx>0?x+1:x, ax = x+2>=width()?width()-1:x+2;
      const Tfloat
        Ip = (Tfloat)(*this)(px,y,z,c), Ic = (Tfloat)(*this)(x,y,z,c),
        In = (Tfloat)(*this)(nx,y,z,c), Ia = (Tfloat)(*this)(ax,y,z,c);
      return Ic + 0.5f*(dx*(-Ip+In) + dx*dx*(2*Ip-5*Ic+4*In-Ia) + dx*dx*dx*(-Ip+3*Ic-3*In+Ia));
    }

    //! Return damped pixel value, using cubic interpolation and Neumann boundary conditions for the X-coordinate.
    /**
       Similar to cubic_atX(float,int,int,int) const, except that you can specify the authorized minimum and maximum of the returned value.
    **/
    Tfloat cubic_atX(const float fx, const int y, const int z, const int c,
                     const Tfloat min_value, const Tfloat max_value) const {
      const Tfloat val = cubic_atX(fx,y,z,c);
      return val<min_value?min_value:val>max_value?max_value:val;
    }

    Tfloat _cubic_atX(const float fx, const int y, const int z, const int c,
                      const Tfloat min_value, const Tfloat max_value) const {
      const Tfloat val = _cubic_atX(fx,y,z,c);
      return val<min_value?min_value:val>max_value?max_value:val;
    }

    //! Return pixel value, using cubic interpolation and Dirichlet boundary conditions for the X and Y-coordinates.
    /**
       Similar to cubic_atX(float,int,int,int,const T) const, except that the cubic interpolation and boundary checking
       are achieved both for X and Y-coordinates.
    **/
    Tfloat cubic_atXY(const float fx, const float fy, const int z, const int c, const T out_value) const {
      const int
        x = (int)fx - (fx>=0?0:1), px = x - 1, nx = x + 1, ax = x + 2,
        y = (int)fy - (fy>=0?0:1), py = y - 1, ny = y + 1, ay = y + 2;
      const float dx = fx - x, dy = fy - y;
      const Tfloat
        Ipp = (Tfloat)atXY(px,py,z,c,out_value), Icp = (Tfloat)atXY(x,py,z,c,out_value), Inp = (Tfloat)atXY(nx,py,z,c,out_value), Iap = (Tfloat)atXY(ax,py,z,c,out_value),
        Ip = Icp + 0.5f*(dx*(-Ipp+Inp) + dx*dx*(2*Ipp-5*Icp+4*Inp-Iap) + dx*dx*dx*(-Ipp+3*Icp-3*Inp+Iap)),
        Ipc = (Tfloat)atXY(px,y,z,c,out_value),  Icc = (Tfloat)atXY(x, y,z,c,out_value), Inc = (Tfloat)atXY(nx,y,z,c,out_value),  Iac = (Tfloat)atXY(ax,y,z,c,out_value),
        Ic = Icc + 0.5f*(dx*(-Ipc+Inc) + dx*dx*(2*Ipc-5*Icc+4*Inc-Iac) + dx*dx*dx*(-Ipc+3*Icc-3*Inc+Iac)),
        Ipn = (Tfloat)atXY(px,ny,z,c,out_value), Icn = (Tfloat)atXY(x,ny,z,c,out_value), Inn = (Tfloat)atXY(nx,ny,z,c,out_value), Ian = (Tfloat)atXY(ax,ny,z,c,out_value),
        In = Icn + 0.5f*(dx*(-Ipn+Inn) + dx*dx*(2*Ipn-5*Icn+4*Inn-Ian) + dx*dx*dx*(-Ipn+3*Icn-3*Inn+Ian)),
        Ipa = (Tfloat)atXY(px,ay,z,c,out_value), Ica = (Tfloat)atXY(x,ay,z,c,out_value), Ina = (Tfloat)atXY(nx,ay,z,c,out_value), Iaa = (Tfloat)atXY(ax,ay,z,c,out_value),
        Ia = Ica + 0.5f*(dx*(-Ipa+Ina) + dx*dx*(2*Ipa-5*Ica+4*Ina-Iaa) + dx*dx*dx*(-Ipa+3*Ica-3*Ina+Iaa));
      return Ic + 0.5f*(dy*(-Ip+In) + dy*dy*(2*Ip-5*Ic+4*In-Ia) + dy*dy*dy*(-Ip+3*Ic-3*In+Ia));
    }

    //! Return damped pixel value, using cubic interpolation and Dirichlet boundary conditions for the X and Y-coordinates.
    /**
       Similar to cubic_atXY(float,float,int,int,const T) const, except that you can specify the authorized minimum and maximum of the returned value.
    **/
    Tfloat cubic_atXY(const float fx, const float fy, const int z, const int c, const T out_value,
                      const Tfloat min_value, const Tfloat max_value) const {
      const Tfloat val = cubic_atXY(fx,fy,z,c,out_value);
      return val<min_value?min_value:val>max_value?max_value:val;
    }

    //! Return pixel value, using cubic interpolation and Neumann boundary conditions for the X and Y-coordinates.
    /**
       Similar to cubic_atX(float,int,int,int) const, except that the cubic interpolation and boundary checking
       are achieved for both X and Y-coordinates.
       \note
       - If you know your image instance is \e not empty, you may rather use the slightly faster method \c _cubic_atXY(float,float,int,int).
    **/
    Tfloat cubic_atXY(const float fx, const float fy, const int z=0, const int c=0) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "cubic_atXY(): Empty instance.",
                                    cimg_instance);
      return _cubic_atXY(fx,fy,z,c);
    }

    Tfloat _cubic_atXY(const float fx, const float fy, const int z=0, const int c=0) const {
      const float
        nfx = fx<0?0:(fx>_width-1?_width-1:fx),
        nfy = fy<0?0:(fy>_height-1?_height-1:fy);
      const int x = (int)nfx, y = (int)nfy;
      const float dx = nfx - x, dy = nfy - y;
      const int
        px = x-1<0?0:x-1, nx = dx>0?x+1:x, ax = x+2>=width()?width()-1:x+2,
        py = y-1<0?0:y-1, ny = dy>0?y+1:y, ay = y+2>=height()?height()-1:y+2;
      const Tfloat
        Ipp = (Tfloat)(*this)(px,py,z,c), Icp = (Tfloat)(*this)(x,py,z,c), Inp = (Tfloat)(*this)(nx,py,z,c), Iap = (Tfloat)(*this)(ax,py,z,c),
        Ip = Icp + 0.5f*(dx*(-Ipp+Inp) + dx*dx*(2*Ipp-5*Icp+4*Inp-Iap) + dx*dx*dx*(-Ipp+3*Icp-3*Inp+Iap)),
        Ipc = (Tfloat)(*this)(px,y,z,c),  Icc = (Tfloat)(*this)(x, y,z,c), Inc = (Tfloat)(*this)(nx,y,z,c),  Iac = (Tfloat)(*this)(ax,y,z,c),
        Ic = Icc + 0.5f*(dx*(-Ipc+Inc) + dx*dx*(2*Ipc-5*Icc+4*Inc-Iac) + dx*dx*dx*(-Ipc+3*Icc-3*Inc+Iac)),
        Ipn = (Tfloat)(*this)(px,ny,z,c), Icn = (Tfloat)(*this)(x,ny,z,c), Inn = (Tfloat)(*this)(nx,ny,z,c), Ian = (Tfloat)(*this)(ax,ny,z,c),
        In = Icn + 0.5f*(dx*(-Ipn+Inn) + dx*dx*(2*Ipn-5*Icn+4*Inn-Ian) + dx*dx*dx*(-Ipn+3*Icn-3*Inn+Ian)),
        Ipa = (Tfloat)(*this)(px,ay,z,c), Ica = (Tfloat)(*this)(x,ay,z,c), Ina = (Tfloat)(*this)(nx,ay,z,c), Iaa = (Tfloat)(*this)(ax,ay,z,c),
        Ia = Ica + 0.5f*(dx*(-Ipa+Ina) + dx*dx*(2*Ipa-5*Ica+4*Ina-Iaa) + dx*dx*dx*(-Ipa+3*Ica-3*Ina+Iaa));
      return Ic + 0.5f*(dy*(-Ip+In) + dy*dy*(2*Ip-5*Ic+4*In-Ia) + dy*dy*dy*(-Ip+3*Ic-3*In+Ia));
    }

    //! Return damped pixel value, using cubic interpolation and Neumann boundary conditions for the X and Y-coordinates.
    /**
       Similar to cubic_atXY(float,float,int,int) const, except that you can specify the authorized minimum and maximum of the returned value.
    **/
    Tfloat cubic_atXY(const float fx, const float fy, const int z, const int c,
                      const Tfloat min_value, const Tfloat max_value) const {
      const Tfloat val = cubic_atXY(fx,fy,z,c);
      return val<min_value?min_value:val>max_value?max_value:val;
    }

    Tfloat _cubic_atXY(const float fx, const float fy, const int z, const int c,
                       const Tfloat min_value, const Tfloat max_value) const {
      const Tfloat val = _cubic_atXY(fx,fy,z,c);
      return val<min_value?min_value:val>max_value?max_value:val;
    }

    //! Return pixel value, using cubic interpolation and Dirichlet boundary conditions for the X,Y and Z-coordinates.
    /**
       Similar to cubic_atX(float,int,int,int,const T) const, except that the cubic interpolation and boundary checking
       are achieved both for X,Y and Z-coordinates.
    **/
    Tfloat cubic_atXYZ(const float fx, const float fy, const float fz, const int c, const T out_value) const {
      const int
        x = (int)fx - (fx>=0?0:1), px = x - 1, nx = x + 1, ax = x + 2,
        y = (int)fy - (fy>=0?0:1), py = y - 1, ny = y + 1, ay = y + 2,
        z = (int)fz - (fz>=0?0:1), pz = z - 1, nz = z + 1, az = z + 2;
      const float dx = fx - x, dy = fy - y, dz = fz - z;
      const Tfloat
        Ippp = (Tfloat)atXYZ(px,py,pz,c,out_value), Icpp = (Tfloat)atXYZ(x,py,pz,c,out_value),
        Inpp = (Tfloat)atXYZ(nx,py,pz,c,out_value), Iapp = (Tfloat)atXYZ(ax,py,pz,c,out_value),
        Ipp = Icpp + 0.5f*(dx*(-Ippp+Inpp) + dx*dx*(2*Ippp-5*Icpp+4*Inpp-Iapp) + dx*dx*dx*(-Ippp+3*Icpp-3*Inpp+Iapp)),
        Ipcp = (Tfloat)atXYZ(px,y,pz,c,out_value),  Iccp = (Tfloat)atXYZ(x, y,pz,c,out_value),
        Incp = (Tfloat)atXYZ(nx,y,pz,c,out_value),  Iacp = (Tfloat)atXYZ(ax,y,pz,c,out_value),
        Icp = Iccp + 0.5f*(dx*(-Ipcp+Incp) + dx*dx*(2*Ipcp-5*Iccp+4*Incp-Iacp) + dx*dx*dx*(-Ipcp+3*Iccp-3*Incp+Iacp)),
        Ipnp = (Tfloat)atXYZ(px,ny,pz,c,out_value), Icnp = (Tfloat)atXYZ(x,ny,pz,c,out_value),
        Innp = (Tfloat)atXYZ(nx,ny,pz,c,out_value), Ianp = (Tfloat)atXYZ(ax,ny,pz,c,out_value),
        Inp = Icnp + 0.5f*(dx*(-Ipnp+Innp) + dx*dx*(2*Ipnp-5*Icnp+4*Innp-Ianp) + dx*dx*dx*(-Ipnp+3*Icnp-3*Innp+Ianp)),
        Ipap = (Tfloat)atXYZ(px,ay,pz,c,out_value), Icap = (Tfloat)atXYZ(x,ay,pz,c,out_value),
        Inap = (Tfloat)atXYZ(nx,ay,pz,c,out_value), Iaap = (Tfloat)atXYZ(ax,ay,pz,c,out_value),
        Iap = Icap + 0.5f*(dx*(-Ipap+Inap) + dx*dx*(2*Ipap-5*Icap+4*Inap-Iaap) + dx*dx*dx*(-Ipap+3*Icap-3*Inap+Iaap)),
        Ip = Icp + 0.5f*(dy*(-Ipp+Inp) + dy*dy*(2*Ipp-5*Icp+4*Inp-Iap) + dy*dy*dy*(-Ipp+3*Icp-3*Inp+Iap)),
        Ippc = (Tfloat)atXYZ(px,py,z,c,out_value), Icpc = (Tfloat)atXYZ(x,py,z,c,out_value),
        Inpc = (Tfloat)atXYZ(nx,py,z,c,out_value), Iapc = (Tfloat)atXYZ(ax,py,z,c,out_value),
        Ipc = Icpc + 0.5f*(dx*(-Ippc+Inpc) + dx*dx*(2*Ippc-5*Icpc+4*Inpc-Iapc) + dx*dx*dx*(-Ippc+3*Icpc-3*Inpc+Iapc)),
        Ipcc = (Tfloat)atXYZ(px,y,z,c,out_value),  Iccc = (Tfloat)atXYZ(x, y,z,c,out_value),
        Incc = (Tfloat)atXYZ(nx,y,z,c,out_value),  Iacc = (Tfloat)atXYZ(ax,y,z,c,out_value),
        Icc = Iccc + 0.5f*(dx*(-Ipcc+Incc) + dx*dx*(2*Ipcc-5*Iccc+4*Incc-Iacc) + dx*dx*dx*(-Ipcc+3*Iccc-3*Incc+Iacc)),
        Ipnc = (Tfloat)atXYZ(px,ny,z,c,out_value), Icnc = (Tfloat)atXYZ(x,ny,z,c,out_value),
        Innc = (Tfloat)atXYZ(nx,ny,z,c,out_value), Ianc = (Tfloat)atXYZ(ax,ny,z,c,out_value),
        Inc = Icnc + 0.5f*(dx*(-Ipnc+Innc) + dx*dx*(2*Ipnc-5*Icnc+4*Innc-Ianc) + dx*dx*dx*(-Ipnc+3*Icnc-3*Innc+Ianc)),
        Ipac = (Tfloat)atXYZ(px,ay,z,c,out_value), Icac = (Tfloat)atXYZ(x,ay,z,c,out_value),
        Inac = (Tfloat)atXYZ(nx,ay,z,c,out_value), Iaac = (Tfloat)atXYZ(ax,ay,z,c,out_value),
        Iac = Icac + 0.5f*(dx*(-Ipac+Inac) + dx*dx*(2*Ipac-5*Icac+4*Inac-Iaac) + dx*dx*dx*(-Ipac+3*Icac-3*Inac+Iaac)),
        Ic = Icc + 0.5f*(dy*(-Ipc+Inc) + dy*dy*(2*Ipc-5*Icc+4*Inc-Iac) + dy*dy*dy*(-Ipc+3*Icc-3*Inc+Iac)),
        Ippn = (Tfloat)atXYZ(px,py,nz,c,out_value), Icpn = (Tfloat)atXYZ(x,py,nz,c,out_value),
        Inpn = (Tfloat)atXYZ(nx,py,nz,c,out_value), Iapn = (Tfloat)atXYZ(ax,py,nz,c,out_value),
        Ipn = Icpn + 0.5f*(dx*(-Ippn+Inpn) + dx*dx*(2*Ippn-5*Icpn+4*Inpn-Iapn) + dx*dx*dx*(-Ippn+3*Icpn-3*Inpn+Iapn)),
        Ipcn = (Tfloat)atXYZ(px,y,nz,c,out_value),  Iccn = (Tfloat)atXYZ(x, y,nz,c,out_value),
        Incn = (Tfloat)atXYZ(nx,y,nz,c,out_value),  Iacn = (Tfloat)atXYZ(ax,y,nz,c,out_value),
        Icn = Iccn + 0.5f*(dx*(-Ipcn+Incn) + dx*dx*(2*Ipcn-5*Iccn+4*Incn-Iacn) + dx*dx*dx*(-Ipcn+3*Iccn-3*Incn+Iacn)),
        Ipnn = (Tfloat)atXYZ(px,ny,nz,c,out_value), Icnn = (Tfloat)atXYZ(x,ny,nz,c,out_value),
        Innn = (Tfloat)atXYZ(nx,ny,nz,c,out_value), Iann = (Tfloat)atXYZ(ax,ny,nz,c,out_value),
        Inn = Icnn + 0.5f*(dx*(-Ipnn+Innn) + dx*dx*(2*Ipnn-5*Icnn+4*Innn-Iann) + dx*dx*dx*(-Ipnn+3*Icnn-3*Innn+Iann)),
        Ipan = (Tfloat)atXYZ(px,ay,nz,c,out_value), Ican = (Tfloat)atXYZ(x,ay,nz,c,out_value),
        Inan = (Tfloat)atXYZ(nx,ay,nz,c,out_value), Iaan = (Tfloat)atXYZ(ax,ay,nz,c,out_value),
        Ian = Ican + 0.5f*(dx*(-Ipan+Inan) + dx*dx*(2*Ipan-5*Ican+4*Inan-Iaan) + dx*dx*dx*(-Ipan+3*Ican-3*Inan+Iaan)),
        In = Icn + 0.5f*(dy*(-Ipn+Inn) + dy*dy*(2*Ipn-5*Icn+4*Inn-Ian) + dy*dy*dy*(-Ipn+3*Icn-3*Inn+Ian)),
        Ippa = (Tfloat)atXYZ(px,py,az,c,out_value), Icpa = (Tfloat)atXYZ(x,py,az,c,out_value),
        Inpa = (Tfloat)atXYZ(nx,py,az,c,out_value), Iapa = (Tfloat)atXYZ(ax,py,az,c,out_value),
        Ipa = Icpa + 0.5f*(dx*(-Ippa+Inpa) + dx*dx*(2*Ippa-5*Icpa+4*Inpa-Iapa) + dx*dx*dx*(-Ippa+3*Icpa-3*Inpa+Iapa)),
        Ipca = (Tfloat)atXYZ(px,y,az,c,out_value),  Icca = (Tfloat)atXYZ(x, y,az,c,out_value),
        Inca = (Tfloat)atXYZ(nx,y,az,c,out_value),  Iaca = (Tfloat)atXYZ(ax,y,az,c,out_value),
        Ica = Icca + 0.5f*(dx*(-Ipca+Inca) + dx*dx*(2*Ipca-5*Icca+4*Inca-Iaca) + dx*dx*dx*(-Ipca+3*Icca-3*Inca+Iaca)),
        Ipna = (Tfloat)atXYZ(px,ny,az,c,out_value), Icna = (Tfloat)atXYZ(x,ny,az,c,out_value),
        Inna = (Tfloat)atXYZ(nx,ny,az,c,out_value), Iana = (Tfloat)atXYZ(ax,ny,az,c,out_value),
        Ina = Icna + 0.5f*(dx*(-Ipna+Inna) + dx*dx*(2*Ipna-5*Icna+4*Inna-Iana) + dx*dx*dx*(-Ipna+3*Icna-3*Inna+Iana)),
        Ipaa = (Tfloat)atXYZ(px,ay,az,c,out_value), Icaa = (Tfloat)atXYZ(x,ay,az,c,out_value),
        Inaa = (Tfloat)atXYZ(nx,ay,az,c,out_value), Iaaa = (Tfloat)atXYZ(ax,ay,az,c,out_value),
        Iaa = Icaa + 0.5f*(dx*(-Ipaa+Inaa) + dx*dx*(2*Ipaa-5*Icaa+4*Inaa-Iaaa) + dx*dx*dx*(-Ipaa+3*Icaa-3*Inaa+Iaaa)),
        Ia = Ica + 0.5f*(dy*(-Ipa+Ina) + dy*dy*(2*Ipa-5*Ica+4*Ina-Iaa) + dy*dy*dy*(-Ipa+3*Ica-3*Ina+Iaa));
      return Ic + 0.5f*(dz*(-Ip+In) + dz*dz*(2*Ip-5*Ic+4*In-Ia) + dz*dz*dz*(-Ip+3*Ic-3*In+Ia));
    }

    //! Return damped pixel value, using cubic interpolation and Dirichlet boundary conditions for the X,Y and Z-coordinates.
    /**
       Similar to cubic_atXYZ(float,float,float,int,const T) const, except that you can specify the authorized minimum and maximum of the returned value.
    **/
    Tfloat cubic_atXYZ(const float fx, const float fy, const float fz, const int c, const T out_value,
                       const Tfloat min_value, const Tfloat max_value) const {
      const Tfloat val = cubic_atXYZ(fx,fy,fz,c,out_value);
      return val<min_value?min_value:val>max_value?max_value:val;
    }

    //! Return pixel value, using cubic interpolation and Neumann boundary conditions for the X,Y and Z-coordinates.
    /**
       Similar to cubic_atX(float,int,int,int) const, except that the cubic interpolation and boundary checking
       are achieved both for X,Y and Z-coordinates.
       \note
       - If you know your image instance is \e not empty, you may rather use the slightly faster method \c _cubic_atXYZ(float,float,float,int).
    **/
    Tfloat cubic_atXYZ(const float fx, const float fy, const float fz, const int c=0) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "cubic_atXYZ(): Empty instance.",
                                    cimg_instance);
      return _cubic_atXYZ(fx,fy,fz,c);
    }

    Tfloat _cubic_atXYZ(const float fx, const float fy, const float fz, const int c=0) const {
      const float
        nfx = fx<0?0:(fx>_width-1?_width-1:fx),
        nfy = fy<0?0:(fy>_height-1?_height-1:fy),
        nfz = fz<0?0:(fz>_depth-1?_depth-1:fz);
      const int x = (int)nfx, y = (int)nfy, z = (int)nfz;
      const float dx = nfx - x, dy = nfy - y, dz = nfz - z;
      const int
        px = x-1<0?0:x-1, nx = dx>0?x+1:x, ax = x+2>=width()?width()-1:x+2,
        py = y-1<0?0:y-1, ny = dy>0?y+1:y, ay = y+2>=height()?height()-1:y+2,
        pz = z-1<0?0:z-1, nz = dz>0?z+1:z, az = z+2>=depth()?depth()-1:z+2;
      const Tfloat
        Ippp = (Tfloat)(*this)(px,py,pz,c), Icpp = (Tfloat)(*this)(x,py,pz,c),
        Inpp = (Tfloat)(*this)(nx,py,pz,c), Iapp = (Tfloat)(*this)(ax,py,pz,c),
        Ipp = Icpp + 0.5f*(dx*(-Ippp+Inpp) + dx*dx*(2*Ippp-5*Icpp+4*Inpp-Iapp) + dx*dx*dx*(-Ippp+3*Icpp-3*Inpp+Iapp)),
        Ipcp = (Tfloat)(*this)(px,y,pz,c),  Iccp = (Tfloat)(*this)(x, y,pz,c),
        Incp = (Tfloat)(*this)(nx,y,pz,c),  Iacp = (Tfloat)(*this)(ax,y,pz,c),
        Icp = Iccp + 0.5f*(dx*(-Ipcp+Incp) + dx*dx*(2*Ipcp-5*Iccp+4*Incp-Iacp) + dx*dx*dx*(-Ipcp+3*Iccp-3*Incp+Iacp)),
        Ipnp = (Tfloat)(*this)(px,ny,pz,c), Icnp = (Tfloat)(*this)(x,ny,pz,c),
        Innp = (Tfloat)(*this)(nx,ny,pz,c), Ianp = (Tfloat)(*this)(ax,ny,pz,c),
        Inp = Icnp + 0.5f*(dx*(-Ipnp+Innp) + dx*dx*(2*Ipnp-5*Icnp+4*Innp-Ianp) + dx*dx*dx*(-Ipnp+3*Icnp-3*Innp+Ianp)),
        Ipap = (Tfloat)(*this)(px,ay,pz,c), Icap = (Tfloat)(*this)(x,ay,pz,c),
        Inap = (Tfloat)(*this)(nx,ay,pz,c), Iaap = (Tfloat)(*this)(ax,ay,pz,c),
        Iap = Icap + 0.5f*(dx*(-Ipap+Inap) + dx*dx*(2*Ipap-5*Icap+4*Inap-Iaap) + dx*dx*dx*(-Ipap+3*Icap-3*Inap+Iaap)),
        Ip = Icp + 0.5f*(dy*(-Ipp+Inp) + dy*dy*(2*Ipp-5*Icp+4*Inp-Iap) + dy*dy*dy*(-Ipp+3*Icp-3*Inp+Iap)),
        Ippc = (Tfloat)(*this)(px,py,z,c), Icpc = (Tfloat)(*this)(x,py,z,c),
        Inpc = (Tfloat)(*this)(nx,py,z,c), Iapc = (Tfloat)(*this)(ax,py,z,c),
        Ipc = Icpc + 0.5f*(dx*(-Ippc+Inpc) + dx*dx*(2*Ippc-5*Icpc+4*Inpc-Iapc) + dx*dx*dx*(-Ippc+3*Icpc-3*Inpc+Iapc)),
        Ipcc = (Tfloat)(*this)(px,y,z,c),  Iccc = (Tfloat)(*this)(x, y,z,c),
        Incc = (Tfloat)(*this)(nx,y,z,c),  Iacc = (Tfloat)(*this)(ax,y,z,c),
        Icc = Iccc + 0.5f*(dx*(-Ipcc+Incc) + dx*dx*(2*Ipcc-5*Iccc+4*Incc-Iacc) + dx*dx*dx*(-Ipcc+3*Iccc-3*Incc+Iacc)),
        Ipnc = (Tfloat)(*this)(px,ny,z,c), Icnc = (Tfloat)(*this)(x,ny,z,c),
        Innc = (Tfloat)(*this)(nx,ny,z,c), Ianc = (Tfloat)(*this)(ax,ny,z,c),
        Inc = Icnc + 0.5f*(dx*(-Ipnc+Innc) + dx*dx*(2*Ipnc-5*Icnc+4*Innc-Ianc) + dx*dx*dx*(-Ipnc+3*Icnc-3*Innc+Ianc)),
        Ipac = (Tfloat)(*this)(px,ay,z,c), Icac = (Tfloat)(*this)(x,ay,z,c),
        Inac = (Tfloat)(*this)(nx,ay,z,c), Iaac = (Tfloat)(*this)(ax,ay,z,c),
        Iac = Icac + 0.5f*(dx*(-Ipac+Inac) + dx*dx*(2*Ipac-5*Icac+4*Inac-Iaac) + dx*dx*dx*(-Ipac+3*Icac-3*Inac+Iaac)),
        Ic = Icc + 0.5f*(dy*(-Ipc+Inc) + dy*dy*(2*Ipc-5*Icc+4*Inc-Iac) + dy*dy*dy*(-Ipc+3*Icc-3*Inc+Iac)),
        Ippn = (Tfloat)(*this)(px,py,nz,c), Icpn = (Tfloat)(*this)(x,py,nz,c),
        Inpn = (Tfloat)(*this)(nx,py,nz,c), Iapn = (Tfloat)(*this)(ax,py,nz,c),
        Ipn = Icpn + 0.5f*(dx*(-Ippn+Inpn) + dx*dx*(2*Ippn-5*Icpn+4*Inpn-Iapn) + dx*dx*dx*(-Ippn+3*Icpn-3*Inpn+Iapn)),
        Ipcn = (Tfloat)(*this)(px,y,nz,c),  Iccn = (Tfloat)(*this)(x, y,nz,c),
        Incn = (Tfloat)(*this)(nx,y,nz,c),  Iacn = (Tfloat)(*this)(ax,y,nz,c),
        Icn = Iccn + 0.5f*(dx*(-Ipcn+Incn) + dx*dx*(2*Ipcn-5*Iccn+4*Incn-Iacn) + dx*dx*dx*(-Ipcn+3*Iccn-3*Incn+Iacn)),
        Ipnn = (Tfloat)(*this)(px,ny,nz,c), Icnn = (Tfloat)(*this)(x,ny,nz,c),
        Innn = (Tfloat)(*this)(nx,ny,nz,c), Iann = (Tfloat)(*this)(ax,ny,nz,c),
        Inn = Icnn + 0.5f*(dx*(-Ipnn+Innn) + dx*dx*(2*Ipnn-5*Icnn+4*Innn-Iann) + dx*dx*dx*(-Ipnn+3*Icnn-3*Innn+Iann)),
        Ipan = (Tfloat)(*this)(px,ay,nz,c), Ican = (Tfloat)(*this)(x,ay,nz,c),
        Inan = (Tfloat)(*this)(nx,ay,nz,c), Iaan = (Tfloat)(*this)(ax,ay,nz,c),
        Ian = Ican + 0.5f*(dx*(-Ipan+Inan) + dx*dx*(2*Ipan-5*Ican+4*Inan-Iaan) + dx*dx*dx*(-Ipan+3*Ican-3*Inan+Iaan)),
        In = Icn + 0.5f*(dy*(-Ipn+Inn) + dy*dy*(2*Ipn-5*Icn+4*Inn-Ian) + dy*dy*dy*(-Ipn+3*Icn-3*Inn+Ian)),
        Ippa = (Tfloat)(*this)(px,py,az,c), Icpa = (Tfloat)(*this)(x,py,az,c),
        Inpa = (Tfloat)(*this)(nx,py,az,c), Iapa = (Tfloat)(*this)(ax,py,az,c),
        Ipa = Icpa + 0.5f*(dx*(-Ippa+Inpa) + dx*dx*(2*Ippa-5*Icpa+4*Inpa-Iapa) + dx*dx*dx*(-Ippa+3*Icpa-3*Inpa+Iapa)),
        Ipca = (Tfloat)(*this)(px,y,az,c),  Icca = (Tfloat)(*this)(x, y,az,c),
        Inca = (Tfloat)(*this)(nx,y,az,c),  Iaca = (Tfloat)(*this)(ax,y,az,c),
        Ica = Icca + 0.5f*(dx*(-Ipca+Inca) + dx*dx*(2*Ipca-5*Icca+4*Inca-Iaca) + dx*dx*dx*(-Ipca+3*Icca-3*Inca+Iaca)),
        Ipna = (Tfloat)(*this)(px,ny,az,c), Icna = (Tfloat)(*this)(x,ny,az,c),
        Inna = (Tfloat)(*this)(nx,ny,az,c), Iana = (Tfloat)(*this)(ax,ny,az,c),
        Ina = Icna + 0.5f*(dx*(-Ipna+Inna) + dx*dx*(2*Ipna-5*Icna+4*Inna-Iana) + dx*dx*dx*(-Ipna+3*Icna-3*Inna+Iana)),
        Ipaa = (Tfloat)(*this)(px,ay,az,c), Icaa = (Tfloat)(*this)(x,ay,az,c),
        Inaa = (Tfloat)(*this)(nx,ay,az,c), Iaaa = (Tfloat)(*this)(ax,ay,az,c),
        Iaa = Icaa + 0.5f*(dx*(-Ipaa+Inaa) + dx*dx*(2*Ipaa-5*Icaa+4*Inaa-Iaaa) + dx*dx*dx*(-Ipaa+3*Icaa-3*Inaa+Iaaa)),
        Ia = Ica + 0.5f*(dy*(-Ipa+Ina) + dy*dy*(2*Ipa-5*Ica+4*Ina-Iaa) + dy*dy*dy*(-Ipa+3*Ica-3*Ina+Iaa));
      return Ic + 0.5f*(dz*(-Ip+In) + dz*dz*(2*Ip-5*Ic+4*In-Ia) + dz*dz*dz*(-Ip+3*Ic-3*In+Ia));
    }

    //! Return damped pixel value, using cubic interpolation and Neumann boundary conditions for the X,Y and Z-coordinates.
    /**
       Similar to cubic_atXYZ(float,float,float,int) const, except that you can specify the authorized minimum and maximum of the returned value.
    **/
    Tfloat cubic_atXYZ(const float fx, const float fy, const float fz, const int c,
                       const Tfloat min_value, const Tfloat max_value) const {
      const Tfloat val = cubic_atXYZ(fx,fy,fz,c);
      return val<min_value?min_value:val>max_value?max_value:val;
    }

    Tfloat _cubic_atXYZ(const float fx, const float fy, const float fz, const int c,
                        const Tfloat min_value, const Tfloat max_value) const {
      const Tfloat val = _cubic_atXYZ(fx,fy,fz,c);
      return val<min_value?min_value:val>max_value?max_value:val;
    }

    //! Set pixel value, using linear interpolation for the X and Y-coordinates.
    /**
       Set pixel value at specified coordinates (\c fx,\c fy,\c z,\c c) in the image instance, in a way that the value is spread
       amongst several neighbors if the pixel coordinates are indeed float-valued.
       \param value Pixel value to set.
       \param fx X-coordinate of the pixel value (float-valued).
       \param fy Y-coordinate of the pixel value (float-valued).
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \param is_added Tells if the pixel value is added to (\c true), or simply replace (\c false) the current image pixel(s).
       \return A reference to the current image instance.
       \note
       - If specified coordinates are outside image bounds, no operations are performed.
    **/
    CImg<T>& set_linear_atXY(const T& value, const float fx, const float fy=0, const int z=0, const int c=0,
                             const bool is_added=false) {
      const int
        x = (int)fx - (fx>=0?0:1), nx = x + 1,
        y = (int)fy - (fy>=0?0:1), ny = y + 1;
      const float
        dx = fx - x,
        dy = fy - y;
      if (z>=0 && z<depth() && c>=0 && c<spectrum()) {
        if (y>=0 && y<height()) {
          if (x>=0 && x<width()) {
            const float w1 = (1-dx)*(1-dy), w2 = is_added?1:(1-w1);
            (*this)(x,y,z,c) = (T)(w1*value + w2*(*this)(x,y,z,c));
          }
          if (nx>=0 && nx<width()) {
            const float w1 = dx*(1-dy), w2 = is_added?1:(1-w1);
            (*this)(nx,y,z,c) = (T)(w1*value + w2*(*this)(nx,y,z,c));
          }
        }
        if (ny>=0 && ny<height()) {
          if (x>=0 && x<width()) {
            const float w1 = (1-dx)*dy, w2 = is_added?1:(1-w1);
            (*this)(x,ny,z,c) = (T)(w1*value + w2*(*this)(x,ny,z,c));
          }
          if (nx>=0 && nx<width()) {
            const float w1 = dx*dy, w2 = is_added?1:(1-w1);
            (*this)(nx,ny,z,c) = (T)(w1*value + w2*(*this)(nx,ny,z,c));
          }
        }
      }
      return *this;
    }

    //! Set pixel value, using linear interpolation for the X,Y and Z-coordinates.
    /**
       Similar to set_linear_atXY(const T&,float,float,int,int,bool), except that the linear interpolation
       is achieved both for X,Y and Z-coordinates.
    **/
    CImg<T>& set_linear_atXYZ(const T& value, const float fx, const float fy=0, const float fz=0, const int c=0,
                              const bool is_added=false) {
      const int
        x = (int)fx - (fx>=0?0:1), nx = x + 1,
        y = (int)fy - (fy>=0?0:1), ny = y + 1,
        z = (int)fz - (fz>=0?0:1), nz = z + 1;
      const float
        dx = fx - x,
        dy = fy - y,
        dz = fz - z;
      if (c>=0 && c<spectrum()) {
        if (z>=0 && z<depth()) {
          if (y>=0 && y<height()) {
            if (x>=0 && x<width()) {
              const float w1 = (1-dx)*(1-dy)*(1-dz), w2 = is_added?1:(1-w1);
              (*this)(x,y,z,c) = (T)(w1*value + w2*(*this)(x,y,z,c));
            }
            if (nx>=0 && nx<width()) {
              const float w1 = dx*(1-dy)*(1-dz), w2 = is_added?1:(1-w1);
              (*this)(nx,y,z,c) = (T)(w1*value + w2*(*this)(nx,y,z,c));
            }
          }
          if (ny>=0 && ny<height()) {
            if (x>=0 && x<width()) {
              const float w1 = (1-dx)*dy*(1-dz), w2 = is_added?1:(1-w1);
              (*this)(x,ny,z,c) = (T)(w1*value + w2*(*this)(x,ny,z,c));
            }
            if (nx>=0 && nx<width()) {
              const float w1 = dx*dy*(1-dz), w2 = is_added?1:(1-w1);
              (*this)(nx,ny,z,c) = (T)(w1*value + w2*(*this)(nx,ny,z,c));
            }
          }
        }
        if (nz>=0 && nz<depth()) {
          if (y>=0 && y<height()) {
            if (x>=0 && x<width()) {
              const float w1 = (1-dx)*(1-dy)*dz, w2 = is_added?1:(1-w1);
              (*this)(x,y,nz,c) = (T)(w1*value + w2*(*this)(x,y,nz,c));
            }
            if (nx>=0 && nx<width()) {
              const float w1 = dx*(1-dy)*dz, w2 = is_added?1:(1-w1);
              (*this)(nx,y,nz,c) = (T)(w1*value + w2*(*this)(nx,y,nz,c));
            }
          }
          if (ny>=0 && ny<height()) {
            if (x>=0 && x<width()) {
              const float w1 = (1-dx)*dy*dz, w2 = is_added?1:(1-w1);
              (*this)(x,ny,nz,c) = (T)(w1*value + w2*(*this)(x,ny,nz,c));
            }
            if (nx>=0 && nx<width()) {
              const float w1 = dx*dy*dz, w2 = is_added?1:(1-w1);
              (*this)(nx,ny,nz,c) = (T)(w1*value + w2*(*this)(nx,ny,nz,c));
            }
          }
        }
      }
      return *this;
    }

    //! Return a C-string containing a list of all values of the image instance.
    /**
       Return a new \c CImg<char> image whose buffer data() is a \c char* string describing the list of all pixel values
       of the image instance (written in base 10), separated by specified \c separator character.
       \param separator A \c char character which specifies the separator between values in the returned C-string.
       \param max_size Maximum size of the returned image.
       \note
       - The returned image is never empty.
       - For an empty image instance, the returned string is <tt>""</tt>.
       - If \c max_size is equal to \c 0, there are no limits on the size of the returned string.
       - Otherwise, if the maximum number of string characters is exceeded, the value string is cut off
         and terminated by character \c '\0'. In that case, the returned image size is <tt>max_size + 1</tt>.
    **/
    CImg<charT> value_string(const char separator=',', const unsigned int max_size=0) const {
      if (is_empty()) return CImg<charT>::string("");
      CImgList<charT> items;
      char s_item[256] = { 0 };
      const T *ptrs = _data;
      unsigned int string_size = 0;
      for (unsigned long off = 0, siz = (unsigned int)size(); off<siz && string_size<=max_size; ++off) {
        const unsigned int printed_size = 1U + cimg_snprintf(s_item,sizeof(s_item),cimg::type<T>::format(),cimg::type<T>::format(*(ptrs++)));
        CImg<charT> item(s_item,printed_size);
        item[printed_size-1] = separator;
        item.move_to(items);
        if (max_size) string_size+=printed_size;
      }
      CImg<charT> res;
      (items>'x').move_to(res);
      if (max_size && res._width>max_size) res.crop(0,max_size);
      res.back() = 0;
      return res;
    }

    //@}
    //-------------------------------------
    //
    //! \name Instance Checking
    //@{
    //-------------------------------------

    //! Test shared state of the pixel buffer.
    /**
       Return \c true if image instance has a shared memory buffer, and \c false otherwise.
       \note
       - A shared image do not own his pixel buffer data() and will not deallocate it on destruction.
       - Most of the time, a \c CImg<T> image instance will \e not be shared.
       - A shared image can only be obtained by a limited set of constructors and methods (see list below).
    **/
    bool is_shared() const {
      return _is_shared;
    }

    //! Test if image instance is empty.
    /**
       Return \c true, if image instance is empty, i.e. does \e not contain any pixel values, has dimensions \c 0 x \c 0 x \c 0 x \c 0
       and a pixel buffer pointer set to \c 0 (null pointer), and \c false otherwise.
    **/
    bool is_empty() const {
      return !(_data && _width && _height && _depth && _spectrum);
    }

    //! Test if image instance contains a 'inf' value.
    /**
       Return \c true, if image instance contains a 'inf' value, and \c false otherwise.
    **/
    bool is_inf() const {
      if (cimg::type<T>::is_float()) cimg_for(*this,p,T) if (cimg::type<T>::is_inf((float)*p)) return true;
      return false;
    }

    //! Test if image instance contains a 'nan' value.
    /**
       Return \c true, if image instance contains a 'nan' value, and \c false otherwise.
    **/
    bool is_nan() const {
      if (cimg::type<T>::is_float()) cimg_for(*this,p,T) if (cimg::type<T>::is_nan((float)*p)) return true;
      return false;
    }

    //! Test if image width is equal to specified value.
    bool is_sameX(const unsigned int size_x) const {
      return _width==size_x;
    }

    //! Test if image width is equal to specified value.
    template<typename t>
    bool is_sameX(const CImg<t>& img) const {
      return is_sameX(img._width);
    }

    //! Test if image width is equal to specified value.
    bool is_sameX(const CImgDisplay& disp) const {
      return is_sameX(disp._width);
    }

    //! Test if image height is equal to specified value.
    bool is_sameY(const unsigned int size_y) const {
      return _height==size_y;
    }

    //! Test if image height is equal to specified value.
    template<typename t>
    bool is_sameY(const CImg<t>& img) const {
      return is_sameY(img._height);
    }

    //! Test if image height is equal to specified value.
    bool is_sameY(const CImgDisplay& disp) const {
      return is_sameY(disp._height);
    }

    //! Test if image depth is equal to specified value.
    bool is_sameZ(const unsigned int size_z) const {
      return _depth==size_z;
    }

    //! Test if image depth is equal to specified value.
    template<typename t>
    bool is_sameZ(const CImg<t>& img) const {
      return is_sameZ(img._depth);
    }

    //! Test if image spectrum is equal to specified value.
    bool is_sameC(const unsigned int size_c) const {
      return _spectrum==size_c;
    }

    //! Test if image spectrum is equal to specified value.
    template<typename t>
    bool is_sameC(const CImg<t>& img) const {
      return is_sameC(img._spectrum);
    }

    //! Test if image width and height are equal to specified values.
    /**
       Test if is_sameX(unsigned int) const and is_sameY(unsigned int) const are both verified.
    **/
    bool is_sameXY(const unsigned int size_x, const unsigned int size_y) const {
      return _width==size_x && _height==size_y;
    }

    //! Test if image width and height are the same as that of another image.
    /**
       Test if is_sameX(const CImg<t>&) const and is_sameY(const CImg<t>&) const are both verified.
    **/
    template<typename t>
    bool is_sameXY(const CImg<t>& img) const {
      return is_sameXY(img._width,img._height);
    }

    //! Test if image width and height are the same as that of an existing display window.
    /**
       Test if is_sameX(const CImgDisplay&) const and is_sameY(const CImgDisplay&) const are both verified.
    **/
    bool is_sameXY(const CImgDisplay& disp) const {
      return is_sameXY(disp._width,disp._height);
    }

    //! Test if image width and depth are equal to specified values.
    /**
       Test if is_sameX(unsigned int) const and is_sameZ(unsigned int) const are both verified.
    **/
    bool is_sameXZ(const unsigned int size_x, const unsigned int size_z) const {
      return _width==size_x && _depth==size_z;
    }

    //! Test if image width and depth are the same as that of another image.
    /**
       Test if is_sameX(const CImg<t>&) const and is_sameZ(const CImg<t>&) const are both verified.
    **/
    template<typename t>
    bool is_sameXZ(const CImg<t>& img) const {
      return is_sameXZ(img._width,img._depth);
    }

    //! Test if image width and spectrum are equal to specified values.
    /**
       Test if is_sameX(unsigned int) const and is_sameC(unsigned int) const are both verified.
    **/
    bool is_sameXC(const unsigned int size_x, const unsigned int size_c) const {
      return _width==size_x && _spectrum==size_c;
    }

    //! Test if image width and spectrum are the same as that of another image.
    /**
       Test if is_sameX(const CImg<t>&) const and is_sameC(const CImg<t>&) const are both verified.
    **/
    template<typename t>
    bool is_sameXC(const CImg<t>& img) const {
      return is_sameXC(img._width,img._spectrum);
    }

    //! Test if image height and depth are equal to specified values.
    /**
       Test if is_sameY(unsigned int) const and is_sameZ(unsigned int) const are both verified.
    **/
    bool is_sameYZ(const unsigned int size_y, const unsigned int size_z) const {
      return _height==size_y && _depth==size_z;
    }

    //! Test if image height and depth are the same as that of another image.
    /**
       Test if is_sameY(const CImg<t>&) const and is_sameZ(const CImg<t>&) const are both verified.
    **/
    template<typename t>
    bool is_sameYZ(const CImg<t>& img) const {
      return is_sameYZ(img._height,img._depth);
    }

    //! Test if image height and spectrum are equal to specified values.
    /**
       Test if is_sameY(unsigned int) const and is_sameC(unsigned int) const are both verified.
    **/
    bool is_sameYC(const unsigned int size_y, const unsigned int size_c) const {
      return _height==size_y && _spectrum==size_c;
    }

    //! Test if image height and spectrum are the same as that of another image.
    /**
       Test if is_sameY(const CImg<t>&) const and is_sameC(const CImg<t>&) const are both verified.
    **/
    template<typename t>
    bool is_sameYC(const CImg<t>& img) const {
      return is_sameYC(img._height,img._spectrum);
    }

    //! Test if image depth and spectrum are equal to specified values.
    /**
       Test if is_sameZ(unsigned int) const and is_sameC(unsigned int) const are both verified.
    **/
    bool is_sameZC(const unsigned int size_z, const unsigned int size_c) const {
      return _depth==size_z && _spectrum==size_c;
    }

    //! Test if image depth and spectrum are the same as that of another image.
    /**
       Test if is_sameZ(const CImg<t>&) const and is_sameC(const CImg<t>&) const are both verified.
    **/
    template<typename t>
    bool is_sameZC(const CImg<t>& img) const {
      return is_sameZC(img._depth,img._spectrum);
    }

    //! Test if image width, height and depth are equal to specified values.
    /**
       Test if is_sameXY(unsigned int,unsigned int) const and is_sameZ(unsigned int) const are both verified.
    **/
    bool is_sameXYZ(const unsigned int size_x, const unsigned int size_y, const unsigned int size_z) const {
      return is_sameXY(size_x,size_y) && _depth==size_z;
    }

    //! Test if image width, height and depth are the same as that of another image.
    /**
       Test if is_sameXY(const CImg<t>&) const and is_sameZ(const CImg<t>&) const are both verified.
    **/
    template<typename t>
    bool is_sameXYZ(const CImg<t>& img) const {
      return is_sameXYZ(img._width,img._height,img._depth);
    }

    //! Test if image width, height and spectrum are equal to specified values.
    /**
       Test if is_sameXY(unsigned int,unsigned int) const and is_sameC(unsigned int) const are both verified.
    **/
    bool is_sameXYC(const unsigned int size_x, const unsigned int size_y, const unsigned int size_c) const {
      return is_sameXY(size_x,size_y) && _spectrum==size_c;
    }

    //! Test if image width, height and spectrum are the same as that of another image.
    /**
       Test if is_sameXY(const CImg<t>&) const and is_sameC(const CImg<t>&) const are both verified.
    **/
    template<typename t>
    bool is_sameXYC(const CImg<t>& img) const {
      return is_sameXYC(img._width,img._height,img._spectrum);
    }

    //! Test if image width, depth and spectrum are equal to specified values.
    /**
       Test if is_sameXZ(unsigned int,unsigned int) const and is_sameC(unsigned int) const are both verified.
    **/
    bool is_sameXZC(const unsigned int size_x, const unsigned int size_z, const unsigned int size_c) const {
      return is_sameXZ(size_x,size_z) && _spectrum==size_c;
    }

    //! Test if image width, depth and spectrum are the same as that of another image.
    /**
       Test if is_sameXZ(const CImg<t>&) const and is_sameC(const CImg<t>&) const are both verified.
    **/
    template<typename t>
    bool is_sameXZC(const CImg<t>& img) const {
      return is_sameXZC(img._width,img._depth,img._spectrum);
    }

    //! Test if image height, depth and spectrum are equal to specified values.
    /**
       Test if is_sameYZ(unsigned int,unsigned int) const and is_sameC(unsigned int) const are both verified.
    **/
    bool is_sameYZC(const unsigned int size_y, const unsigned int size_z, const unsigned int size_c) const {
      return is_sameYZ(size_y,size_z) && _spectrum==size_c;
    }

    //! Test if image height, depth and spectrum are the same as that of another image.
    /**
       Test if is_sameYZ(const CImg<t>&) const and is_sameC(const CImg<t>&) const are both verified.
    **/
    template<typename t>
    bool is_sameYZC(const CImg<t>& img) const {
      return is_sameYZC(img._height,img._depth,img._spectrum);
    }

    //! Test if image width, height, depth and spectrum are equal to specified values.
    /**
       Test if is_sameXYZ(unsigned int,unsigned int,unsigned int) const and is_sameC(unsigned int) const are both verified.
    **/
    bool is_sameXYZC(const unsigned int size_x, const unsigned int size_y, const unsigned int size_z, const unsigned int size_c) const {
      return is_sameXYZ(size_x,size_y,size_z) && _spectrum==size_c;
    }

    //! Test if image width, height, depth and spectrum are the same as that of another image.
    /**
       Test if is_sameXYZ(const CImg<t>&) const and is_sameC(const CImg<t>&) const are both verified.
    **/
    template<typename t>
    bool is_sameXYZC(const CImg<t>& img) const {
      return is_sameXYZC(img._width,img._height,img._depth,img._spectrum);
    }

    //! Test if specified coordinates are inside image bounds.
    /**
       Return \c true if pixel located at (\c x,\c y,\c z,\c c) is inside bounds of the image instance, and \c false otherwise.
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \note
       - Return \c true only if all these conditions are verified:
         - The image instance is \e not empty.
         - <tt>0<=x<=\ref width()-1</tt>.
         - <tt>0<=y<=\ref height()-1</tt>.
         - <tt>0<=z<=\ref depth()-1</tt>.
         - <tt>0<=c<=\ref spectrum()-1</tt>.
    **/
    bool containsXYZC(const int x, const int y=0, const int z=0, const int c=0) const {
      return !is_empty() && x>=0 && x<width() && y>=0 && y<height() && z>=0 && z<depth() && c>=0 && c<spectrum();
    }

    //! Test if pixel value is inside image bounds and get its X,Y,Z and C-coordinates.
    /**
       Return \c true, if specified reference refers to a pixel value inside bounds of the image instance, and \c false otherwise.
       \param pixel Reference to pixel value to test.
       \param[out] x X-coordinate of the pixel value, if test succeeds.
       \param[out] y Y-coordinate of the pixel value, if test succeeds.
       \param[out] z Z-coordinate of the pixel value, if test succeeds.
       \param[out] c C-coordinate of the pixel value, if test succeeds.
       \note
       - Useful to convert an offset to a buffer value into pixel value coordinates:
       \code
       const CImg<float> img(100,100,1,3);      // Construct a 100x100 RGB color image.
       const unsigned long offset = 1249;       // Offset to the pixel (49,12,0,0).
       unsigned int x,y,z,c;
       if (img.contains(img[offset],x,y,z,c)) { // Convert offset to (x,y,z,c) coordinates.
         std::printf("Offset %u refers to pixel located at (%u,%u,%u,%u).\n",
                     offset,x,y,z,c);
       }
       \endcode
    **/
    template<typename t>
    bool contains(const T& pixel, t& x, t& y, t& z, t& c) const {
      const unsigned long wh = (unsigned long)_width*_height, whd = wh*_depth, siz = whd*_spectrum;
      const T *const ppixel = &pixel;
      if (is_empty() || ppixel<_data || ppixel>=_data+siz) return false;
      unsigned long off = (unsigned long)(ppixel - _data);
      const unsigned long nc = off/whd;
      off%=whd;
      const unsigned long nz = off/wh;
      off%=wh;
      const unsigned long ny = off/_width, nx = off%_width;
      x = (t)nx; y = (t)ny; z = (t)nz; c = (t)nc;
      return true;
    }

    //! Test if pixel value is inside image bounds and get its X,Y and Z-coordinates.
    /**
       Similar to contains(const T&,t&,t&,t&,t&) const, except that only the X,Y and Z-coordinates are set.
    **/
    template<typename t>
    bool contains(const T& pixel, t& x, t& y, t& z) const {
      const unsigned long wh = (unsigned long)_width*_height, whd = wh*_depth, siz = whd*_spectrum;
      const T *const ppixel = &pixel;
      if (is_empty() || ppixel<_data || ppixel>=_data+siz) return false;
      unsigned long off = ((unsigned long)(ppixel - _data))%whd;
      const unsigned long nz = off/wh;
      off%=wh;
      const unsigned long ny = off/_width, nx = off%_width;
      x = (t)nx; y = (t)ny; z = (t)nz;
      return true;
    }

    //! Test if pixel value is inside image bounds and get its X and Y-coordinates.
    /**
       Similar to contains(const T&,t&,t&,t&,t&) const, except that only the X and Y-coordinates are set.
    **/
    template<typename t>
    bool contains(const T& pixel, t& x, t& y) const {
      const unsigned long wh = (unsigned long)_width*_height, siz = wh*_depth*_spectrum;
      const T *const ppixel = &pixel;
      if (is_empty() || ppixel<_data || ppixel>=_data+siz) return false;
      unsigned long off = ((unsigned int)(ppixel - _data))%wh;
      const unsigned long ny = off/_width, nx = off%_width;
      x = (t)nx; y = (t)ny;
      return true;
    }

    //! Test if pixel value is inside image bounds and get its X-coordinate.
    /**
       Similar to contains(const T&,t&,t&,t&,t&) const, except that only the X-coordinate is set.
    **/
    template<typename t>
    bool contains(const T& pixel, t& x) const {
      const T *const ppixel = &pixel;
      if (is_empty() || ppixel<_data || ppixel>=_data+size()) return false;
      x = (t)(((unsigned long)(ppixel - _data))%_width);
      return true;
    }

    //! Test if pixel value is inside image bounds.
    /**
       Similar to contains(const T&,t&,t&,t&,t&) const, except that no pixel coordinates are set.
    **/
    bool contains(const T& pixel) const {
      const T *const ppixel = &pixel;
      return !is_empty() && ppixel>=_data && ppixel<_data + size();
    }

    //! Test if pixel buffers of instance and input images overlap.
    /**
       Return \c true, if pixel buffers attached to image instance and input image \c img overlap, and \c false otherwise.
       \param img Input image to compare with.
       \note
       - Buffer overlapping may happen when manipulating \e shared images.
       - If two image buffers overlap, operating on one of the image will probably modify the other one.
       - Most of the time, \c CImg<T> instances are \e non-shared and do not overlap between each others.
       \par Example
       \code
       const CImg<float>
         img1("reference.jpg"),             // Load RGB-color image.
         img2 = img1.get_shared_channel(1); // Get shared version of the green channel.
       if (img1.is_overlapped(img2)) {      // Test succeeds, 'img1' and 'img2' overlaps.
         std::printf("Buffers overlap!\n");
       }
       \endcode
    **/
    template<typename t>
    bool is_overlapped(const CImg<t>& img) const {
      const unsigned long csiz = size(), isiz = img.size();
      return !((void*)(_data + csiz)<=(void*)img._data || (void*)_data>=(void*)(img._data + isiz));
    }

    //! Test if the set {\c *this,\c primitives,\c colors,\c opacities} defines a valid 3d object.
    /**
       Return \c true is the 3d object represented by the set {\c *this,\c primitives,\c colors,\c opacities} defines a
       valid 3d object, and \c false otherwise. The vertex coordinates are defined by the instance image.
       \param primitives List of primitives of the 3d object.
       \param colors List of colors of the 3d object.
       \param opacities List (or image) of opacities of the 3d object.
       \param full_check Tells if full checking of the 3d object must be performed.
       \param[out] error_message C-string to contain the error message, if the test does not succeed.
       \note
       - Set \c full_checking to \c false to speed-up the 3d object checking. In this case, only the size of
         each 3d object component is checked.
       - Size of the string \c error_message should be at least 128-bytes long, to be able to contain the error message.
    **/
    template<typename tp, typename tc, typename to>
    bool is_object3d(const CImgList<tp>& primitives,
                     const CImgList<tc>& colors,
                     const to& opacities,
                     const bool full_check=true,
                     char *const error_message=0) const {
      if (error_message) *error_message = 0;

      // Check consistency for the particular case of an empty 3d object.
      if (is_empty()) {
        if (primitives || colors || opacities) {
          if (error_message) std::sprintf(error_message,
                                          "3d object (%u,%u) defines no vertices but %u primitives, %u colors and %lu opacities",
                                          _width,primitives._width,primitives._width,colors._width,(unsigned long)opacities.size());
          return false;
        }
        return true;
      }

      // Check consistency of vertices.
      if (_height!=3 || _depth>1 || _spectrum>1) { // Check vertices dimensions.
        if (error_message) std::sprintf(error_message,
                                        "3d object (%u,%u) has invalid vertex dimensions (%u,%u,%u,%u)",
                                        _width,primitives._width,_width,_height,_depth,_spectrum);
        return false;
      }
      if (colors._width>primitives._width+1) {
        if (error_message) std::sprintf(error_message,
                                        "3d object (%u,%u) defines %u colors",
                                        _width,primitives._width,colors._width);
        return false;
      }
      if (opacities.size()>primitives._width) {
        if (error_message) std::sprintf(error_message,
                                        "3d object (%u,%u) defines %lu opacities",
                                        _width,primitives._width,(unsigned long)opacities.size());
        return false;
      }
      if (!full_check) return true;

      // Check consistency of primitives.
      cimglist_for(primitives,l) {
        const CImg<tp>& primitive = primitives[l];
        const unsigned long psiz = primitive.size();
        switch (psiz) {
        case 1 : { // Point.
          const unsigned int i0 = (unsigned int)primitive(0);
          if (i0>=_width) {
            if (error_message) std::sprintf(error_message,
                                            "3d object (%u,%u) refers to invalid vertex indice %u in point primitive [%u]",
                                            _width,primitives._width,i0,l);
            return false;
          }
        } break;
        case 5 : { // Sphere.
          const unsigned int
            i0 = (unsigned int)primitive(0),
            i1 = (unsigned int)primitive(1);
          if (i0>=_width || i1>=_width) {
            if (error_message) std::sprintf(error_message,
                                            "3d object (%u,%u) refers to invalid vertex indices (%u,%u) in sphere primitive [%u]",
                                            _width,primitives._width,i0,i1,l);
            return false;
          }
        } break;
        case 2 : // Segment.
        case 6 : {
          const unsigned int
            i0 = (unsigned int)primitive(0),
            i1 = (unsigned int)primitive(1);
          if (i0>=_width || i1>=_width) {
            if (error_message) std::sprintf(error_message,
                                            "3d object (%u,%u) refers to invalid vertex indices (%u,%u) in segment primitive [%u]",
                                            _width,primitives._width,i0,i1,l);
            return false;
          }
        } break;
        case 3 : // Triangle.
        case 9 : {
          const unsigned int
            i0 = (unsigned int)primitive(0),
            i1 = (unsigned int)primitive(1),
            i2 = (unsigned int)primitive(2);
          if (i0>=_width || i1>=_width || i2>=_width) {
            if (error_message) std::sprintf(error_message,
                                            "3d object (%u,%u) refers to invalid vertex indices (%u,%u,%u) in triangle primitive [%u]",
                                            _width,primitives._width,i0,i1,i2,l);
            return false;
          }
        } break;
        case 4 : // Quadrangle.
        case 12 : {
          const unsigned int
            i0 = (unsigned int)primitive(0),
            i1 = (unsigned int)primitive(1),
            i2 = (unsigned int)primitive(2),
            i3 = (unsigned int)primitive(3);
          if (i0>=_width || i1>=_width || i2>=_width || i3>=_width) {
            if (error_message) std::sprintf(error_message,
                                            "3d object (%u,%u) refers to invalid vertex indices (%u,%u,%u,%u) in quadrangle primitive [%u]",
                                            _width,primitives._width,i0,i1,i2,i3,l);
            return false;
          }
        } break;
        default :
          if (error_message) std::sprintf(error_message,
                                          "3d object (%u,%u) defines an invalid primitive [%u] of size %u",
                                          _width,primitives._width,l,(unsigned int)psiz);
          return false;
        }
      }

      // Check consistency of colors.
      cimglist_for(colors,c) {
        const CImg<tc>& color = colors[c];
        if (!color) {
          if (error_message) std::sprintf(error_message,
                                          "3d object (%u,%u) defines no color for primitive [%u]",
                                          _width,primitives._width,c);
          return false;
        }
      }

      // Check consistency of light texture.
      if (colors._width>primitives._width) {
        const CImg<tc> &light = colors.back();
        if (!light || light._depth>1) {
          if (error_message) std::sprintf(error_message,
                                          "3d object (%u,%u) defines an invalid light texture (%u,%u,%u,%u)",
                                          _width,primitives._width,light._width,light._height,light._depth,light._spectrum);
          return false;
        }
      }

      return true;
    }

    //! Test if image instance represents a valid serialization of a 3d object.
    /**
       Return \c true if the image instance represents a valid serialization of a 3d object, and \c false otherwise.
       \param full_check Tells if full checking of the instance must be performed.
       \param[out] error_message C-string to contain the error message, if the test does not succeed.
       \note
       - Set \c full_check to \c false to speed-up the 3d object checking. In this case, only the size of
         each 3d object component is checked.
       - Size of the string \c error_message should be at least 128-bytes long, to be able to contain the error message.
    **/
    bool is_CImg3d(const bool full_check=true, char *const error_message=0) const {
      if (error_message) *error_message = 0;

      // Check instance dimension and header.
      if (_width!=1 || _height<8 || _depth!=1 || _spectrum!=1) {
        if (error_message) std::sprintf(error_message,
                                        "CImg3d has invalid dimensions (%u,%u,%u,%u)",
                                        _width,_height,_depth,_spectrum);
        return false;
      }
      const T *ptrs = _data, *const ptre = end();
      if (!_is_CImg3d(*(ptrs++),'C') || !_is_CImg3d(*(ptrs++),'I') || !_is_CImg3d(*(ptrs++),'m') ||
          !_is_CImg3d(*(ptrs++),'g') || !_is_CImg3d(*(ptrs++),'3') || !_is_CImg3d(*(ptrs++),'d')) {
        if (error_message) std::sprintf(error_message,
                                        "CImg3d header not found");
        return false;
      }
      const unsigned int
        nb_points = cimg::float2uint((float)*(ptrs++)),
        nb_primitives = cimg::float2uint((float)*(ptrs++));

      // Check consistency of number of vertices / primitives.
      if (!full_check) {
        const unsigned long minimal_size = 8UL + 3*nb_points + 6*nb_primitives;
        if (_data + minimal_size>ptre) {
          if (error_message) std::sprintf(error_message,
                                          "CImg3d (%u,%u) has only %lu values, while at least %lu values were expected",
                                          nb_points,nb_primitives,size(),minimal_size);
          return false;
        }
      }

      // Check consistency of vertex data.
      if (!nb_points) {
        if (nb_primitives) {
          if (error_message) std::sprintf(error_message,
                                          "CImg3d (%u,%u) defines no vertices but %u primitives",
                                          nb_points,nb_primitives,nb_primitives);
          return false;
        }
        if (ptrs!=ptre) {
          if (error_message) std::sprintf(error_message,
                                          "CImg3d (%u,%u) is an empty object but contains %u value%s more than expected",
                                          nb_points,nb_primitives,(unsigned int)(ptre-ptrs),(ptre-ptrs)>1?"s":"");
          return false;
        }
        return true;
      }
      if (ptrs+3*nb_points>ptre) {
        if (error_message) std::sprintf(error_message,
                                        "CImg3d (%u,%u) defines only %u vertices data",
                                        nb_points,nb_primitives,(unsigned int)(ptre-ptrs)/3);
        return false;
      }
      ptrs+=3*nb_points;

      // Check consistency of primitive data.
      if (ptrs==ptre) {
        if (error_message) std::sprintf(error_message,
                                        "CImg3d (%u,%u) defines %u vertices but no primitive",
                                        nb_points,nb_primitives,nb_points);
        return false;
      }

      if (!full_check) return true;

      for (unsigned int p = 0; p<nb_primitives; ++p) {
        const unsigned int nb_inds = (unsigned int)*(ptrs++);
        switch (nb_inds) {
        case 1 : { // Point.
          const unsigned int i0 = cimg::float2uint((float)*(ptrs++));
          if (i0>=nb_points) {
            if (error_message) std::sprintf(error_message,
                                            "CImg3d (%u,%u) refers to invalid vertex indice %u in point primitive [%u]",
                                            nb_points,nb_primitives,i0,p);
            return false;
          }
        } break;
        case 5 : { // Sphere.
          const unsigned int
            i0 = cimg::float2uint((float)*(ptrs++)),
            i1 = cimg::float2uint((float)*(ptrs++));
          ptrs+=3;
          if (i0>=nb_points || i1>=nb_points) {
            if (error_message) std::sprintf(error_message,
                                            "CImg3d (%u,%u) refers to invalid vertex indices (%u,%u) in sphere primitive [%u]",
                                            nb_points,nb_primitives,i0,i1,p);
            return false;
          }
        } break;
        case 2 : case 6 : { // Segment.
          const unsigned int
            i0 = cimg::float2uint((float)*(ptrs++)),
            i1 = cimg::float2uint((float)*(ptrs++));
          if (nb_inds==6) ptrs+=4;
          if (i0>=nb_points || i1>=nb_points) {
            if (error_message) std::sprintf(error_message,
                                            "CImg3d (%u,%u) refers to invalid vertex indices (%u,%u) in segment primitive [%u]",
                                            nb_points,nb_primitives,i0,i1,p);
            return false;
          }
        } break;
        case 3 : case 9 : { // Triangle.
          const unsigned int
            i0 = cimg::float2uint((float)*(ptrs++)),
            i1 = cimg::float2uint((float)*(ptrs++)),
            i2 = cimg::float2uint((float)*(ptrs++));
          if (nb_inds==9) ptrs+=6;
          if (i0>=nb_points || i1>=nb_points || i2>=nb_points) {
            if (error_message) std::sprintf(error_message,
                                            "CImg3d (%u,%u) refers to invalid vertex indices (%u,%u,%u) in triangle primitive [%u]",
                                            nb_points,nb_primitives,i0,i1,i2,p);
            return false;
          }
        } break;
        case 4 : case 12 : { // Quadrangle.
          const unsigned int
            i0 = cimg::float2uint((float)*(ptrs++)),
            i1 = cimg::float2uint((float)*(ptrs++)),
            i2 = cimg::float2uint((float)*(ptrs++)),
            i3 = cimg::float2uint((float)*(ptrs++));
          if (nb_inds==12) ptrs+=8;
          if (i0>=nb_points || i1>=nb_points || i2>=nb_points || i3>=nb_points) {
            if (error_message) std::sprintf(error_message,
                                            "CImg3d (%u,%u) refers to invalid vertex indices (%u,%u,%u,%u) in quadrangle primitive [%u]",
                                            nb_points,nb_primitives,i0,i1,i2,i3,p);
            return false;
          }
        } break;
        default :
          if (error_message) std::sprintf(error_message,
                                          "CImg3d (%u,%u) defines an invalid primitive [%u] of size %u",
                                          nb_points,nb_primitives,p,nb_inds);
          return false;
        }
        if (ptrs>ptre) {
          if (error_message) std::sprintf(error_message,
                                          "CImg3d (%u,%u) has incomplete primitive data for primitive [%u], %u values missing",
                                          nb_points,nb_primitives,p,(unsigned int)(ptrs-ptre));
          return false;
        }
      }

      // Check consistency of color data.
      if (ptrs==ptre) {
        if (error_message) std::sprintf(error_message,
                                        "CImg3d (%u,%u) defines no color/texture data",
                                        nb_points,nb_primitives);
        return false;
      }
      for (unsigned int c = 0; c<nb_primitives; ++c) {
        if (*(ptrs++)!=(T)-128) ptrs+=2;
        else if ((ptrs+=3)<ptre) {
          const unsigned int w = (unsigned int)*(ptrs-3), h = (unsigned int)*(ptrs-2), s = (unsigned int)*(ptrs-1);
          if (!h && !s) {
            if (w>=c) {
              if (error_message) std::sprintf(error_message,
                                              "CImg3d (%u,%u) refers to invalid shared sprite/texture indice %u for primitive [%u]",
                                              nb_points,nb_primitives,w,c);
              return false;
            }
          } else ptrs+=w*h*s;
        }
        if (ptrs>ptre) {
          if (error_message) std::sprintf(error_message,
                                          "CImg3d (%u,%u) has incomplete color/texture data for primitive [%u], %u values missing",
                                          nb_points,nb_primitives,c,(unsigned int)(ptrs-ptre));
          return false;
        }
      }

      // Check consistency of opacity data.
      if (ptrs==ptre) {
        if (error_message) std::sprintf(error_message,
                                        "CImg3d (%u,%u) defines no opacity data",
                                        nb_points,nb_primitives);
        return false;
      }
      for (unsigned int o = 0; o<nb_primitives; ++o) {
        if (*(ptrs++)==(T)-128 && (ptrs+=3)<ptre) {
          const unsigned int w = (unsigned int)*(ptrs-3), h = (unsigned int)*(ptrs-2), s = (unsigned int)*(ptrs-1);
          if (!h && !s) {
            if (w>=o) {
              if (error_message) std::sprintf(error_message,
                                              "CImg3d (%u,%u) refers to invalid shared opacity indice %u for primitive [%u]",
                                              nb_points,nb_primitives,w,o);
              return false;
            }
          } else ptrs+=w*h*s;
        }
        if (ptrs>ptre) {
          if (error_message) std::sprintf(error_message,
                                          "CImg3d (%u,%u) has incomplete opacity data for primitive [%u]",
                                          nb_points,nb_primitives,o);
          return false;
        }
      }

      // Check end of data.
      if (ptrs<ptre) {
        if (error_message) std::sprintf(error_message,
                                        "CImg3d (%u,%u) contains %u value%s more than expected",
                                        nb_points,nb_primitives,(unsigned int)(ptre-ptrs),(ptre-ptrs)>1?"s":"");
        return false;
      }
      return true;
    }

    static bool _is_CImg3d(const T val, const char c) {
      return val>=(T)c && val<(T)(c+1);
    }

    //@}
    //-------------------------------------
    //
    //! \name Mathematical Functions
    //@{
    //-------------------------------------

    // Define the math formula parser/compiler and evaluator.
    struct _cimg_math_parser {
      CImgList<charT> labelM;
      CImgList<uintT> code;
      CImg<uintT> level, opcode, labelMpos, label1pos;
      const CImg<uintT>* p_code;
      CImg<doubleT> mem;
      CImg<charT> expr;
      const CImg<T>& reference;
      CImg<Tdouble> reference_stats;
      unsigned int mempos, result;
      const char *const calling_function;
      typedef double (_cimg_math_parser::*mp_func)();
      const mp_func *mp_funcs;

#define _cimg_mp_return(x) { *se = saved_char; return x; }
#define _cimg_mp_opcode0(op) _cimg_mp_return(opcode0(op));
#define _cimg_mp_opcode1(op,i1) _cimg_mp_return(opcode1(op,i1));
#define _cimg_mp_opcode2(op,i1,i2) { const unsigned int _i1 = i1, _i2 = i2; _cimg_mp_return(opcode2(op,_i1,_i2)); }
#define _cimg_mp_opcode3(op,i1,i2,i3) { const unsigned int _i1 = i1, _i2 = i2, _i3 = i3; _cimg_mp_return(opcode3(op,_i1,_i2,_i3)); }
#define _cimg_mp_opcode6(op,i1,i2,i3,i4,i5,i6) { const unsigned int _i1 = i1, _i2 = i2, _i3 = i3, _i4 = i4, _i5 = i5, _i6 = i6; \
        _cimg_mp_return(opcode6(op,_i1,_i2,_i3,_i4,_i5,_i6)); }

      // Constructor - Destructor.
      _cimg_math_parser(const CImg<T>& img, const char *const expression, const char *const funcname=0):
        reference(img),calling_function(funcname?funcname:"cimg_math_parser") {
        unsigned int l = 0;
        if (expression) {
          l = (unsigned int)std::strlen(expression);
          expr.assign(expression,l+1);
          if (*expr._data) {
            char *d = expr._data;
            for (const char *s = expr._data; *s || (bool)(*d=0); ++s) if (*s!=' ') *(d++) = *s;
            l = (unsigned int)(d - expr._data);
          }
        }
        if (!l) throw CImgArgumentException("[_cimg_math_parser] "
                                            "CImg<%s>::%s(): Empty specified expression.",
                                            pixel_type(),calling_function);

        int lv = 0; // Count parentheses/brackets level of expression.
        level.assign(l);
        unsigned int *pd = level._data;
        for (const char *ps = expr._data; *ps && lv>=0; ++ps) *(pd++) = (unsigned int)(*ps=='('||*ps=='['?lv++:*ps==')'||*ps==']'?--lv:lv);
        if (lv!=0) {
          throw CImgArgumentException("[_cimg_math_parser] "
                                      "CImg<%s>::%s(): Unbalanced parentheses/brackets in specified expression '%s'.",
                                      pixel_type(),calling_function,
                                      expr._data);
        }
        // Init constant values.
        mem.assign(512);
        mem[0] = 0;
        mem[1] = 1;
        mem[2] = 2;
        mem[3] = (double)reference._width;
        mem[4] = (double)reference._height;
        mem[5] = (double)reference._depth;
        mem[6] = (double)reference._spectrum;
        mem[7] = cimg::PI;
        mem[8] = std::exp(1.0); // Then [9] = x, [10] = y, [11] = z, [12] = c
        mempos = 13;
        labelMpos.assign(8);
        label1pos.assign(128,1,1,1,~0U);
        label1pos['w'] = 3;
        label1pos['h'] = 4;
        label1pos['d'] = 5;
        label1pos['s'] = 6;
        label1pos[0] = 7; // pi
        label1pos['e'] = 8;
        label1pos['x'] = 9;
        label1pos['y'] = 10;
        label1pos['z'] = 11;
        label1pos['c'] = 12;
        result = compile(expr._data,expr._data+l); // Compile formula into a serie of opcodes.
      }

      // Insert code instructions.
      unsigned int opcode0(const char op) {
        if (mempos>=mem._width) mem.resize(-200,1,1,1,0);
        const unsigned int pos = mempos++;
        CImg<uintT>::vector(op,pos).move_to(code);
        return pos;
      }

      unsigned int opcode1(const char op, const unsigned int arg1) {
        if (mempos>=mem._width) mem.resize(-200,1,1,1,0);
        const unsigned int pos = mempos++;
        CImg<uintT>::vector(op,pos,arg1).move_to(code);
        return pos;
      }

      unsigned int opcode2(const char op, const unsigned int arg1, const unsigned int arg2) {
        if (mempos>=mem._width) mem.resize(-200,1,1,1,0);
        const unsigned int pos = mempos++;
        CImg<uintT>::vector(op,pos,arg1,arg2).move_to(code);
        return pos;
      }

      unsigned int opcode3(const char op, const unsigned int arg1, const unsigned int arg2, const unsigned int arg3) {
        if (mempos>=mem._width) mem.resize(-200,1,1,1,0);
        const unsigned int pos = mempos++;
        CImg<uintT>::vector(op,pos,arg1,arg2,arg3).move_to(code);
        return pos;
      }

      unsigned int opcode6(const char op, const unsigned int arg1, const unsigned int arg2, const unsigned int arg3,
                           const unsigned int arg4, const unsigned int arg5, const unsigned int arg6) {
        if (mempos>=mem._width) mem.resize(-200,1,1,1,0);
        const unsigned int pos = mempos++;
        CImg<uintT>::vector(op,pos,arg1,arg2,arg3,arg4,arg5,arg6).move_to(code);
        return pos;
      }

      // Compilation procedure.
      unsigned int compile(char *const ss, char *const se) {
        if (!ss || se<=ss || !*ss) {
          throw CImgArgumentException("[_cimg_math_parser] "
                                      "CImg<%s>::%s(): Missing item in specified expression '%s'.",
                                      pixel_type(),calling_function,
                                      expr._data);
        }
        char
          *const se1 = se-1, *const se2 = se-2, *const se3 = se-3, *const se4 = se-4,
          *const ss1 = ss+1, *const ss2 = ss+2, *const ss3 = ss+3, *const ss4 = ss+4,
          *const ss5 = ss+5, *const ss6 = ss+6, *const ss7 = ss+7;
        const char saved_char = *se; *se = 0;
        const unsigned int clevel = level[ss-expr._data], clevel1 = clevel+1;
        if (*se1==';') return compile(ss,se1);

        // Look for a single value, variable or variable assignment.
        char end = 0, sep = 0; double val = 0;
        const int nb = std::sscanf(ss,"%lf%c%c",&val,&sep,&end);
        if (nb==1) {
          if (val==0 || val==1 || val==2) _cimg_mp_return((int)val);
          if (mempos>=mem._width) mem.resize(-200,1,1,1,0);
          const unsigned int pos = mempos++;
          mem[pos] = val;
          _cimg_mp_return(pos);
        }
        if (nb==2 && sep=='%') {
          if (val==0 || val==100 || val==200) _cimg_mp_return((int)(val/100));
          if (mempos>=mem._width) mem.resize(-200,1,1,1,0);
          const unsigned int pos = mempos++;
          mem[pos] = val/100;
          _cimg_mp_return(pos);
        }
        if (ss1==se) switch (*ss) {
          case 'w' : case 'h' : case 'd' : case 's' :
          case 'x' : case 'y' : case 'z' : case 'c' : case 'e' : _cimg_mp_return(label1pos[*ss]);
          case 'u' : if (label1pos['u']!=~0U) _cimg_mp_return(label1pos['u']); _cimg_mp_opcode2(0,0,1);
          case 'g' : if (label1pos['g']!=~0U) _cimg_mp_return(label1pos['g']); _cimg_mp_opcode0(1);
          case 'i' : if (label1pos['i']!=~0U) _cimg_mp_return(label1pos['i']); _cimg_mp_opcode0(2);
          case '?' : _cimg_mp_opcode2(0,0,1);
          }
        if (ss1==se1) {
          if (*ss=='p' && *ss1=='i') _cimg_mp_return(label1pos[0]); // pi
          if (*ss=='i') {
            if (*ss1=='m') { if (label1pos[1]!=~0U) _cimg_mp_return(label1pos[1]); _cimg_mp_opcode0(57); } // im
            if (*ss1=='M') { if (label1pos[2]!=~0U) _cimg_mp_return(label1pos[2]); _cimg_mp_opcode0(58); } // iM
            if (*ss1=='a') { if (label1pos[3]!=~0U) _cimg_mp_return(label1pos[3]); _cimg_mp_opcode0(59); } // ia
            if (*ss1=='v') { if (label1pos[4]!=~0U) _cimg_mp_return(label1pos[4]); _cimg_mp_opcode0(60); } // iv
          }
          if (*ss1=='m') {
            if (*ss=='x') { if (label1pos[5]!=~0U) _cimg_mp_return(label1pos[5]); _cimg_mp_opcode0(61); } // xm
            if (*ss=='y') { if (label1pos[6]!=~0U) _cimg_mp_return(label1pos[6]); _cimg_mp_opcode0(62); } // ym
            if (*ss=='z') { if (label1pos[7]!=~0U) _cimg_mp_return(label1pos[7]); _cimg_mp_opcode0(63); } // zm
            if (*ss=='c') { if (label1pos[8]!=~0U) _cimg_mp_return(label1pos[8]); _cimg_mp_opcode0(64); } // cm
          }
          if (*ss1=='M') {
            if (*ss=='x') { if (label1pos[9]!=~0U) _cimg_mp_return(label1pos[9]); _cimg_mp_opcode0(65); } // xM
            if (*ss=='y') { if (label1pos[10]!=~0U) _cimg_mp_return(label1pos[10]); _cimg_mp_opcode0(66); } // yM
            if (*ss=='z') { if (label1pos[11]!=~0U) _cimg_mp_return(label1pos[11]); _cimg_mp_opcode0(67); } // zM
            if (*ss=='c') { if (label1pos[12]!=~0U) _cimg_mp_return(label1pos[12]); _cimg_mp_opcode0(6); } // cM
          }
        }

        // Look for variable declarations.
        for (char *s = se2; s>ss; --s) if (*s==';' && level[s-expr._data]==clevel) { compile(ss,s); _cimg_mp_return(compile(s+1,se)); }
        for (char *s = ss1, *ps = ss, *ns = ss2; s<se1; ++s, ++ps, ++ns)
          if (*s=='=' && *ns!='=' && *ps!='=' && *ps!='>' && *ps!='<' && *ps!='!' && level[s-expr._data]==clevel) {
            CImg<charT> variable_name(ss,(unsigned int)(s-ss+1));
            variable_name.back() = 0;
            bool is_valid_name = true;
            if (*ss>='0' && *ss<='9') is_valid_name = false;
            else for (const char *ns = ss+1; ns<s; ++ns)
                   if ((*ns<'a' || *ns>'z') && (*ns<'A' || *ns>'Z') && (*ns<'0' || *ns>'9') && *ns!='_') {
                     is_valid_name = false; break;
                   }
            if (!is_valid_name) {
              *se = saved_char;
              throw CImgArgumentException("[_cimg_math_parser] "
                                          "CImg<%s>::%s(): Invalid variable name '%s' in specified expression '%s%s%s'.",
                                          pixel_type(),calling_function,
                                          variable_name._data,
                                          (ss-8)>expr._data?"...":"",
                                          (ss-8)>expr._data?ss-8:expr._data,
                                          se<&expr.back()?"...":"");
            }
            const unsigned int pos = compile(s+1,se);
            if (variable_name[0] && variable_name[1] && !variable_name[2]) { // Check for particular case of a reserved variable.
              const char c1 = variable_name[0], c2 = variable_name[1];
              if (c1=='p' && c2=='i') variable_name.fill((char)0,(char)0); // pi
              else if (c1=='i') {
                if (c2=='m') variable_name.fill(1,0); // im
                else if (c2=='M') variable_name.fill(2,0); // iM
                else if (c2=='a') variable_name.fill(3,0); // ia
                else if (c2=='v') variable_name.fill(4,0); // iv
              } else if (c2=='m') {
                if (c1=='x') variable_name.fill(5,0); // xm
                else if (c1=='y') variable_name.fill(6,0); // ym
                else if (c1=='z') variable_name.fill(7,0); // zm
                else if (c1=='c') variable_name.fill(8,0); // cm
              } else if (c2=='M') {
                if (c1=='x') variable_name.fill(9,0); // xM
                else if (c1=='y') variable_name.fill(10,0); // yM
                else if (c1=='z') variable_name.fill(11,0); // zM
                else if (c1=='c') variable_name.fill(12,0); // cM
              }
            }
            if (variable_name[1]) { // Multi-char variable.
              int label_pos = -1;
              cimglist_for(labelM,i) if (!std::strcmp(variable_name,labelM[i])) { label_pos = i; break; } // Check for existing variable with same name.
              if (label_pos<0) { // If new variable.
                if (labelM._width>=labelMpos._width) labelMpos.resize(-200,1,1,1,0);
                label_pos = labelM._width;
                variable_name.move_to(labelM);
              }
              labelMpos[label_pos] = pos;
            } else label1pos[*variable_name] = pos; // Single-char variable.
            _cimg_mp_return(pos);
          }

        // Look for unary/binary operators. The operator precedences is defined as in C++.
        for (char *s = se3, *ns = se2; s>ss; --s, --ns) if (*s=='|' && *ns=='|' && level[s-expr._data]==clevel) {
            const unsigned int mem_A = compile(ss,s), bp1 = code._width, mem_B = compile(s+2,se);
            if (mempos>=mem._width) mem.resize(-200,1,1,1,0);
            const unsigned int pos = mempos++;
            CImg<uintT>::vector(8,pos,mem_A,mem_B,code._width-bp1).move_to(code,bp1);
            _cimg_mp_return(pos);
          }
        for (char *s = se3, *ns = se2; s>ss; --s, --ns) if (*s=='&' && *ns=='&' && level[s-expr._data]==clevel) {
            const unsigned int mem_A = compile(ss,s), bp1 = code._width, mem_B = compile(s+2,se);
            if (mempos>=mem._width) mem.resize(-200,1,1,1,0);
            const unsigned int pos = mempos++;
            CImg<uintT>::vector(9,pos,mem_A,mem_B,code._width-bp1).move_to(code,bp1);
            _cimg_mp_return(pos);
          }
        for (char *s = se2; s>ss; --s) if (*s=='|' && level[s-expr._data]==clevel) _cimg_mp_opcode2(10,compile(ss,s),compile(s+1,se));
        for (char *s = se2; s>ss; --s) if (*s=='&' && level[s-expr._data]==clevel) _cimg_mp_opcode2(11,compile(ss,s),compile(s+1,se));
        for (char *s = se3, *ns = se2; s>ss; --s, --ns) if (*s=='!' && *ns=='=' && level[s-expr._data]==clevel) _cimg_mp_opcode2(12,compile(ss,s),compile(s+2,se));
        for (char *s = se3, *ns = se2; s>ss; --s, --ns) if (*s=='=' && *ns=='=' && level[s-expr._data]==clevel) _cimg_mp_opcode2(13,compile(ss,s),compile(s+2,se));
        for (char *s = se3, *ns = se2; s>ss; --s, --ns) if (*s=='<' && *ns=='=' && level[s-expr._data]==clevel) _cimg_mp_opcode2(14,compile(ss,s),compile(s+2,se));
        for (char *s = se3, *ns = se2; s>ss; --s, --ns) if (*s=='>' && *ns=='=' && level[s-expr._data]==clevel) _cimg_mp_opcode2(15,compile(ss,s),compile(s+2,se));
        for (char *s = se2, *ns = se1, *ps = se3; s>ss; --s, --ns, --ps)
          if (*s=='<' && *ns!='<' && *ps!='<' && level[s-expr._data]==clevel) _cimg_mp_opcode2(16,compile(ss,s),compile(s+1,se));
        for (char *s = se2, *ns = se1, *ps = se3; s>ss; --s, --ns, --ps)
          if (*s=='>' && *ns!='>' && *ps!='>' && level[s-expr._data]==clevel) _cimg_mp_opcode2(17,compile(ss,s),compile(s+1,se));
        for (char *s = se3, *ns = se2; s>ss; --s, --ns) if (*s=='<' && *ns=='<' && level[s-expr._data]==clevel) _cimg_mp_opcode2(18,compile(ss,s),compile(s+2,se));
        for (char *s = se3, *ns = se2; s>ss; --s, --ns) if (*s=='>' && *ns=='>' && level[s-expr._data]==clevel) _cimg_mp_opcode2(19,compile(ss,s),compile(s+2,se));
        for (char *s = se2, *ps = se3; s>ss; --s, --ps)
          if (*s=='+' && *ps!='-' && *ps!='+' && *ps!='*' && *ps!='/' && *ps!='%' && *ps!='&' && *ps!='|' && *ps!='^' && *ps!='!' && *ps!='~' &&
              (*ps!='e' || !(ps>ss && (*(ps-1)=='.' || (*(ps-1)>='0' && *(ps-1)<='9')))) && level[s-expr._data]==clevel)
            _cimg_mp_opcode2(21,compile(ss,s),compile(s+1,se));
        for (char *s = se2, *ps = se3; s>ss; --s, --ps)
          if (*s=='-' && *ps!='-' && *ps!='+' && *ps!='*' && *ps!='/' && *ps!='%' && *ps!='&' && *ps!='|' && *ps!='^' && *ps!='!' && *ps!='~' &&
              (*ps!='e' || !(ps>ss && (*(ps-1)=='.' || (*(ps-1)>='0' && *(ps-1)<='9')))) && level[s-expr._data]==clevel)
            _cimg_mp_opcode2(20,compile(ss,s),compile(s+1,se));
        for (char *s = se2; s>ss; --s) if (*s=='*' && level[s-expr._data]==clevel) {
            const unsigned int mem_A = compile(ss,s), bp1 = code._width, mem_B = compile(s+1,se);
            if (mempos>=mem._width) mem.resize(-200,1,1,1,0);
            const unsigned int pos = mempos++;
            CImg<uintT>::vector(22,pos,mem_A,mem_B,code._width-bp1).move_to(code,bp1);
            _cimg_mp_return(pos);
          }
        for (char *s = se2; s>ss; --s) if (*s=='/' && level[s-expr._data]==clevel) _cimg_mp_opcode2(23,compile(ss,s),compile(s+1,se));
        for (char *s = se2, *ns = se1; s>ss; --s, --ns)
          if (*s=='%' && *ns!='^' && level[s-expr._data]==clevel)
            _cimg_mp_opcode2(24,compile(ss,s),compile(s+1,se));
        if (ss<se1) {
          if (*ss=='+') _cimg_mp_return(compile(ss1,se));
          if (*ss=='-') _cimg_mp_opcode1(26,compile(ss1,se));
          if (*ss=='!') _cimg_mp_opcode1(27,compile(ss1,se));
          if (*ss=='~') _cimg_mp_opcode1(28,compile(ss1,se));
        }
        for (char *s = se2; s>ss; --s) if (*s=='^' && level[s-expr._data]==clevel) _cimg_mp_opcode2(25,compile(ss,s),compile(s+1,se));

        // Look for a function call or a parenthesis.
        if (*se1==']') {
          const bool is_relative = *ss=='j';
          if ((*ss=='i' || is_relative) && *ss1=='[') {
            if (*ss2==']') _cimg_mp_opcode0(2);
            _cimg_mp_opcode1(is_relative?69:68,compile(ss2,se1));
          }
        }
        if (*se1==')') {
          if (*ss=='(') _cimg_mp_return(compile(ss1,se1));
          if (!std::strncmp(ss,"sin(",4)) _cimg_mp_opcode1(29,compile(ss4,se1));
          if (!std::strncmp(ss,"cos(",4)) _cimg_mp_opcode1(30,compile(ss4,se1));
          if (!std::strncmp(ss,"tan(",4)) _cimg_mp_opcode1(31,compile(ss4,se1));
          if (!std::strncmp(ss,"asin(",5)) _cimg_mp_opcode1(32,compile(ss5,se1));
          if (!std::strncmp(ss,"acos(",5)) _cimg_mp_opcode1(33,compile(ss5,se1));
          if (!std::strncmp(ss,"atan(",5)) _cimg_mp_opcode1(34,compile(ss5,se1));
          if (!std::strncmp(ss,"sinh(",5)) _cimg_mp_opcode1(35,compile(ss5,se1));
          if (!std::strncmp(ss,"cosh(",5)) _cimg_mp_opcode1(36,compile(ss5,se1));
          if (!std::strncmp(ss,"tanh(",5)) _cimg_mp_opcode1(37,compile(ss5,se1));
          if (!std::strncmp(ss,"log10(",6)) _cimg_mp_opcode1(38,compile(ss6,se1));
          if (!std::strncmp(ss,"log2(",5)) _cimg_mp_opcode1(3,compile(ss5,se1));
          if (!std::strncmp(ss,"log(",4)) _cimg_mp_opcode1(39,compile(ss4,se1));
          if (!std::strncmp(ss,"exp(",4)) _cimg_mp_opcode1(40,compile(ss4,se1));
          if (!std::strncmp(ss,"sqrt(",5)) _cimg_mp_opcode1(41,compile(ss5,se1));
          if (!std::strncmp(ss,"sign(",5)) _cimg_mp_opcode1(42,compile(ss5,se1));
          if (!std::strncmp(ss,"abs(",4)) _cimg_mp_opcode1(43,compile(ss4,se1));
          if (!std::strncmp(ss,"atan2(",6)) {
            char *s1 = ss6; while (s1<se2 && (*s1!=',' || level[s1-expr._data]!=clevel1)) ++s1;
            _cimg_mp_opcode2(44,compile(ss6,s1),compile(s1+1,se1));
          }
          if (*ss=='i' && *ss1=='f' && *ss2=='(') {
            char *s1 = ss3; while (s1<se4 && (*s1!=',' || level[s1-expr._data]!=clevel1)) ++s1;
            char *s2 = s1+1; while (s2<se2 && (*s2!=',' || level[s2-expr._data]!=clevel1)) ++s2;
            const unsigned int mem_cond = compile(ss3,s1), bp1 = code._width, mem_A = compile(s1+1,s2),
              bp2 = code._width, mem_B = compile(s2+1,se1);
            if (mempos>=mem._width) mem.resize(-200,1,1,1,0);
            const unsigned int pos = mempos++;
            CImg<uintT>::vector(45,pos,mem_cond,mem_A,mem_B,bp2-bp1,code._width-bp2).move_to(code,bp1);
            _cimg_mp_return(pos);
          }
          if (!std::strncmp(ss,"round(",6)) {
            unsigned int value = 0, round = 1, direction = 0;
            char *s1 = ss6; while (s1<se2 && (*s1!=',' || level[s1-expr._data]!=clevel1)) ++s1;
            value = compile(ss6,s1==se2?++s1:s1);
            if (s1<se1) {
              char *s2 = s1+1; while (s2<se2 && (*s2!=',' || level[s2-expr._data]!=clevel1)) ++s2;
              round = compile(s1+1,s2==se2?++s2:s2);
              if (s2<se1) direction = compile(s2+1,se1);
            }
            _cimg_mp_opcode3(46,value,round,direction);
          }
          if ((*ss=='?' || *ss=='u') && *ss1=='(') {
            if (*ss2==')') _cimg_mp_opcode2(0,0,1);
            char *s1 = ss2; while (s1<se1 && (*s1!=',' || level[s1-expr._data]!=clevel1)) ++s1;
            if (s1<se1) _cimg_mp_opcode2(0,compile(ss2,s1),compile(s1+1,se1));
            _cimg_mp_opcode2(0,0,compile(ss2,s1));
          }
          const bool is_relative = *ss=='j';
          if ((*ss=='i' || is_relative) && *ss1=='(') {
            if (*ss2==')') _cimg_mp_opcode0(2);
            unsigned int
              indx = is_relative?0:9, indy = is_relative?0:10,
              indz = is_relative?0:11, indc = is_relative?0:12,
              borders = 0, interpolation = 0;
            if (ss2!=se1) {
              char *s1 = ss2; while (s1<se2 && (*s1!=',' || level[s1-expr._data]!=clevel1)) ++s1;
              indx = compile(ss2,s1==se2?++s1:s1);
              if (s1<se1) {
                char *s2 = s1+1; while (s2<se2 && (*s2!=',' || level[s2-expr._data]!=clevel1)) ++s2;
                indy = compile(s1+1,s2==se2?++s2:s2);
                if (s2<se1) {
                  char *s3 = s2+1; while (s3<se2 && (*s3!=',' || level[s3-expr._data]!=clevel1)) ++s3;
                  indz = compile(s2+1,s3==se2?++s3:s3);
                  if (s3<se1) {
                    char *s4 = s3+1; while (s4<se2 && (*s4!=',' || level[s4-expr._data]!=clevel1)) ++s4;
                    indc = compile(s3+1,s4==se2?++s4:s4);
                    if (s4<se1) {
                      char *s5 = s4+1; while (s5<se2 && (*s5!=',' || level[s5-expr._data]!=clevel1)) ++s5;
                      interpolation = compile(s4+1,s5==se2?++s5:s5);
                      if (s5<se1) borders = compile(s5+1,se1);
                    }
                  }
                }
              }
            }
            _cimg_mp_opcode6(is_relative?7:47,indx,indy,indz,indc,interpolation,borders);
          }
          if (!std::strncmp(ss,"min(",4) || !std::strncmp(ss,"max(",4)) {
            CImgList<uintT> opcode;
            if (mempos>=mem.size()) mem.resize(-200,1,1,1,0);
            const unsigned int pos = mempos++;
            CImg<uintT>::vector(ss[1]=='i'?48:49,pos).move_to(opcode);
            for (char *s = ss4; s<se; ++s) {
              char *ns = s; while (ns<se && (*ns!=',' || level[ns-expr._data]!=clevel1) && (*ns!=')' || level[ns-expr._data]!=clevel)) ++ns;
              CImg<uintT>::vector(compile(s,ns)).move_to(opcode);
              s = ns;
            }
            (opcode>'y').move_to(code);
            _cimg_mp_return(pos);
          }
          if (!std::strncmp(ss,"arg(",4)) {
            CImgList<uintT> opcode;
            if (mempos>=mem.size()) mem.resize(-200,1,1,1,0);
            const unsigned int pos = mempos++;
            CImg<uintT>::vector(5,pos).move_to(opcode);
            for (char *s = ss4; s<se; ++s) {
              char *ns = s; while (ns<se && (*ns!=',' || level[ns-expr._data]!=clevel1) && (*ns!=')' || level[ns-expr._data]!=clevel)) ++ns;
              CImg<uintT>::vector(compile(s,ns)).move_to(opcode);
              s = ns;
            }
            (opcode>'y').move_to(code);
            _cimg_mp_return(pos);
          }
          if (!std::strncmp(ss,"narg(",5)) {
            if (*ss5==')') _cimg_mp_return(0);
            unsigned int nb_args = 0;
            for (char *s = ss5; s<se; ++s) {
              char *ns = s; while (ns<se && (*ns!=',' || level[ns-expr._data]!=clevel1) && (*ns!=')' || level[ns-expr._data]!=clevel)) ++ns;
              ++nb_args; s = ns;
            }
            if (nb_args==0 || nb_args==1) _cimg_mp_return(nb_args);
            if (mempos>=mem.size()) mem.resize(-200,1,1,1,0);
            const unsigned int pos = mempos++;
            mem[pos] = nb_args;
            _cimg_mp_return(pos);
          }
          if (!std::strncmp(ss,"isval(",6)) {
            char sep = 0, end = 0; double val = 0;
            if (std::sscanf(ss6,"%lf%c%c",&val,&sep,&end)==2 && sep==')') _cimg_mp_return(1);
            _cimg_mp_return(0);
          }
          if (!std::strncmp(ss,"isnan(",6)) _cimg_mp_opcode1(50,compile(ss6,se1));
          if (!std::strncmp(ss,"isinf(",6)) _cimg_mp_opcode1(51,compile(ss6,se1));
          if (!std::strncmp(ss,"isint(",6)) _cimg_mp_opcode1(52,compile(ss6,se1));
          if (!std::strncmp(ss,"isbool(",7)) _cimg_mp_opcode1(53,compile(ss7,se1));
          if (!std::strncmp(ss,"rol(",4) || !std::strncmp(ss,"ror(",4)) {
            unsigned int value = 0, nb = 1;
            char *s1 = ss4; while (s1<se2 && (*s1!=',' || level[s1-expr._data]!=clevel1)) ++s1;
            value = compile(ss4,s1==se2?++s1:s1);
            if (s1<se1) {
              char *s2 = s1+1; while (s2<se2 && (*s2!=',' || level[s2-expr._data]!=clevel1)) ++s2;
              nb = compile(s1+1,se1);
            }
            _cimg_mp_opcode2(*ss2=='l'?54:55,value,nb);
          }

          if (!std::strncmp(ss,"sinc(",5)) _cimg_mp_opcode1(56,compile(ss5,se1));
          if (!std::strncmp(ss,"int(",4)) _cimg_mp_opcode1(4,compile(ss4,se1));
        }

        // No known item found, assuming this is an already initialized variable.
        CImg<charT> variable_name(ss,(unsigned int)(se-ss+1));
        variable_name.back() = 0;
        if (variable_name[1]) { cimglist_for(labelM,i) if (!std::strcmp(variable_name,labelM[i])) _cimg_mp_return(labelMpos[i]); } // Multi-char variable.
        else if (label1pos[*variable_name]!=~0U) _cimg_mp_return(label1pos[*variable_name]); // Single-char variable.
        *se = saved_char;
        throw CImgArgumentException("[_cimg_math_parser] "
                                    "CImg<%s>::%s(): Invalid item '%s' in specified expression '%s%s%s'.\n",
                                    pixel_type(),calling_function,
                                    variable_name._data,
                                    (ss-8)>expr._data?"...":"",
                                    (ss-8)>expr._data?ss-8:expr._data,
                                    se<&expr.back()?"...":"");
        return 0;
      }

      // Evaluation functions, known by the parser.
      double mp_u() {
        return mem[opcode(2)] + cimg::rand()*(mem[opcode(3)]-mem[opcode(2)]);
      }
      double mp_g() {
        return cimg::grand();
      }
      double mp_i() {
        return (double)reference.atXYZC((int)mem[9],(int)mem[10],(int)mem[11],(int)mem[12],0);
      }
      double mp_logical_and() {
        const bool is_A = (bool)mem[opcode(2)];
        const CImg<uintT> *const pE = ++p_code + opcode(4);
        if (!is_A) { p_code = pE - 1; return 0; }
        const unsigned int mem_B = opcode(3);
        for ( ; p_code<pE; ++p_code) {
          const CImg<uintT> &op = *p_code;
          opcode._data = op._data; opcode._height = op._height;
          const unsigned int target = opcode(1);
          mem[target] = (this->*mp_funcs[opcode[0]])();
        }
        --p_code;
        return (double)(bool)mem[mem_B];
      }
      double mp_logical_or() {
        const bool is_A = (bool)mem[opcode(2)];
        const CImg<uintT> *const pE = ++p_code + opcode(4);
        if (is_A) { p_code = pE - 1; return 1; }
        const unsigned int mem_B = opcode(3);
        for ( ; p_code<pE; ++p_code) {
          const CImg<uintT> &op = *p_code;
          opcode._data = op._data; opcode._height = op._height;
          const unsigned int target = opcode(1);
          mem[target] = (this->*mp_funcs[opcode[0]])();
        }
        --p_code;
        return (double)(bool)mem[mem_B];
      }
      double mp_infeq() {
        return (double)(mem[opcode(2)]<=mem[opcode(3)]);
      }
      double mp_supeq() {
        return (double)(mem[opcode(2)]>=mem[opcode(3)]);
      }
      double mp_noteq() {
        return (double)(mem[opcode(2)]!=mem[opcode(3)]);
      }
      double mp_eqeq() {
        return (double)(mem[opcode(2)]==mem[opcode(3)]);
      }
      double mp_inf() {
        return (double)(mem[opcode(2)]<mem[opcode(3)]);
      }
      double mp_sup() {
        return (double)(mem[opcode(2)]>mem[opcode(3)]);
      }
      double mp_add() {
        return mem[opcode(2)] + mem[opcode(3)];
      }
      double mp_sub() {
        return mem[opcode(2)] - mem[opcode(3)];
      }
      double mp_mul() {
        const double A = mem[opcode(2)];
        const CImg<uintT> *const pE = ++p_code + opcode(4);
        if (!A) { p_code = pE - 1; return 0; }
        const unsigned int mem_B = opcode(3);
        for ( ; p_code<pE; ++p_code) {
          const CImg<uintT> &op = *p_code;
          opcode._data = op._data; opcode._height = op._height;
          const unsigned int target = opcode(1);
          mem[target] = (this->*mp_funcs[opcode[0]])();
        }
        --p_code;
        return A*(double)mem[mem_B];
      }
      double mp_div() {
        return mem[opcode(2)] / mem[opcode(3)];
      }
      double mp_minus() {
        return -mem[opcode(2)];
      }
      double mp_not() {
        return !mem[opcode(2)];
      }
      double mp_logical_not() {
        return !mem[opcode(2)];
      }
      double mp_bitwise_not() {
        return ~(unsigned long)mem[opcode(2)];
      }
      double mp_modulo() {
        return cimg::mod(mem[opcode(2)],mem[opcode(3)]);
      }
      double mp_bitwise_and() {
        return ((unsigned long)mem[opcode(2)] & (unsigned long)mem[opcode(3)]);
      }
      double mp_bitwise_or() {
        return ((unsigned long)mem[opcode(2)] | (unsigned long)mem[opcode(3)]);
      }
      double mp_pow() {
        const double v = mem[opcode(2)], p = mem[opcode(3)];
        if (p==0) return 1;
        if (p==0.5) return std::sqrt(v);
        if (p==1) return v;
        if (p==2) return v*v;
        if (p==3) return v*v*v;
        if (p==4) return v*v*v*v;
        return std::pow(v,p);
      }
      double mp_sin() {
        return std::sin(mem[opcode(2)]);
      }
      double mp_cos() {
        return std::cos(mem[opcode(2)]);
      }
      double mp_tan() {
        return std::tan(mem[opcode(2)]);
      }
      double mp_asin() {
        return std::asin(mem[opcode(2)]);
      }
      double mp_acos() {
        return std::acos(mem[opcode(2)]);
      }
      double mp_atan() {
        return std::atan(mem[opcode(2)]);
      }
      double mp_sinh() {
        return std::sinh(mem[opcode(2)]);
      }
      double mp_cosh() {
        return std::cosh(mem[opcode(2)]);
      }
      double mp_tanh() {
        return std::tanh(mem[opcode(2)]);
      }
      double mp_log10() {
        return std::log10(mem[opcode(2)]);
      }
      double mp_log2() {
        return cimg::log2(mem[opcode(2)]);
      }
      double mp_log() {
        return std::log(mem[opcode(2)]);
      }
      double mp_exp() {
        return std::exp(mem[opcode(2)]);
      }
      double mp_sqrt() {
        return std::sqrt(mem[opcode(2)]);
      }
      double mp_sign() {
        return cimg::sign(mem[opcode(2)]);
      }
      double mp_abs() {
        return cimg::abs(mem[opcode(2)]);
      }
      double mp_atan2() {
        return std::atan2(mem[opcode(2)],mem[opcode(3)]);
      }
      double mp_if() {
        const bool is_cond = (bool)mem[opcode(2)];
        const unsigned int mem_A = opcode(3), mem_B = opcode(4);
        const CImg<uintT>
          *const pB = ++p_code + opcode(5),
          *const pE = pB + opcode(6);
        if (is_cond) { // Evaluate on-the-fly only the correct argument.
          for ( ; p_code<pB; ++p_code) {
            const CImg<uintT> &op = *p_code;
            opcode._data = op._data; opcode._height = op._height;
            const unsigned int target = opcode(1);
            mem[target] = (this->*mp_funcs[opcode[0]])();
          }
          p_code = pE - 1;
          return mem[mem_A];
        }
        for (p_code = pB; p_code<pE; ++p_code) {
          const CImg<uintT> &op = *p_code;
          opcode._data = op._data; opcode._height = op._height;
          const unsigned int target = opcode(1);
          mem[target] = (this->*mp_funcs[opcode[0]])();
        }
        --p_code;
        return mem[mem_B];
      }
      double mp_round() {
        return cimg::round(mem[opcode(2)],mem[opcode(3)],(int)mem[opcode(4)]);
      }
      double mp_ixyzc() {
        const int i = (int)mem[opcode(6)], b = (int)mem[opcode(7)];
        if (i==0) { // Nearest neighbor interpolation.
          if (b==2) return (double)reference.atXYZC(cimg::mod((int)mem[opcode(2)],reference.width()),
                                                    cimg::mod((int)mem[opcode(3)],reference.height()),
                                                    cimg::mod((int)mem[opcode(4)],reference.depth()),
                                                    cimg::mod((int)mem[opcode(5)],reference.spectrum()));
          if (b==1) return (double)reference.atXYZC((int)mem[opcode(2)],
                                                    (int)mem[opcode(3)],
                                                    (int)mem[opcode(4)],
                                                    (int)mem[opcode(5)]);
          return (double)reference.atXYZC((int)mem[opcode(2)],
                                          (int)mem[opcode(3)],
                                          (int)mem[opcode(4)],
                                          (int)mem[opcode(5)],0);
        } else { // Linear interpolation.
          if (b==2) return (double)reference.linear_atXYZC(cimg::mod((float)mem[opcode(2)],(float)reference.width()),
                                                           cimg::mod((float)mem[opcode(3)],(float)reference.height()),
                                                           cimg::mod((float)mem[opcode(4)],(float)reference.depth()),
                                                           cimg::mod((float)mem[opcode(5)],(float)reference.spectrum()));
          if (b==1) return (double)reference.linear_atXYZC((float)mem[opcode(2)],
                                                           (float)mem[opcode(3)],
                                                           (float)mem[opcode(4)],
                                                           (float)mem[opcode(5)]);
          return (double)reference.linear_atXYZC((float)mem[opcode(2)],
                                                 (float)mem[opcode(3)],
                                                 (float)mem[opcode(4)],
                                                 (float)mem[opcode(5)],0);
        }
      }
      double mp_jxyzc() {
        const double x = mem[9], y = mem[10], z = mem[11], c = mem[12];
        const int i = (int)mem[opcode(6)], b = (int)mem[opcode(7)];
        if (i==0) { // Nearest neighbor interpolation.
          if (b==2) return (double)reference.atXYZC(cimg::mod((int)(x+mem[opcode(2)]),reference.width()),
                                                    cimg::mod((int)(y+mem[opcode(3)]),reference.height()),
                                                    cimg::mod((int)(z+mem[opcode(4)]),reference.depth()),
                                                    cimg::mod((int)(c+mem[opcode(5)]),reference.spectrum()));
          if (b==1) return (double)reference.atXYZC((int)(x+mem[opcode(2)]),
                                                    (int)(y+mem[opcode(3)]),
                                                    (int)(z+mem[opcode(4)]),
                                                    (int)(c+mem[opcode(5)]));
          return (double)reference.atXYZC((int)(x+mem[opcode(2)]),
                                          (int)(y+mem[opcode(3)]),
                                          (int)(z+mem[opcode(4)]),
                                          (int)(c+mem[opcode(5)]),0);
        } else { // Linear interpolation.
          if (b==2) return (double)reference.linear_atXYZC(cimg::mod((float)(x+mem[opcode(2)]),(float)reference.width()),
                                                           cimg::mod((float)(y+mem[opcode(3)]),(float)reference.height()),
                                                           cimg::mod((float)(z+mem[opcode(4)]),(float)reference.depth()),
                                                           cimg::mod((float)(c+mem[opcode(5)]),(float)reference.spectrum()));
          if (b==1) return (double)reference.linear_atXYZC((float)(x+mem[opcode(2)]),
                                                           (float)(y+mem[opcode(3)]),
                                                           (float)(z+mem[opcode(4)]),
                                                           (float)(c+mem[opcode(5)]));
          return (double)reference.linear_atXYZC((float)(x+mem[opcode(2)]),
                                                 (float)(y+mem[opcode(3)]),
                                                 (float)(z+mem[opcode(4)]),
                                                 (float)(c+mem[opcode(5)]),0);
        }
      }
      double mp_min() {
        double val = mem[opcode(2)];
        for (unsigned int i = 3; i<opcode._height; ++i) val = cimg::min(val,mem[opcode(i)]);
        return val;
      }
      double mp_max() {
        double val = mem[opcode(2)];
        for (unsigned int i = 3; i<opcode._height; ++i) val = cimg::max(val,mem[opcode(i)]);
        return val;
      }
      double mp_isnan() {
        const double val = mem[opcode(2)];
        return cimg::type<double>::is_nan(val);
      }
      double mp_isinf() {
        const double val = mem[opcode(2)];
        return cimg::type<double>::is_inf(val);
      }
      double mp_isint() {
        const double val = mem[opcode(2)];
        return (double)(cimg::mod(val,1.0)==0);
      }
      double mp_isbool() {
        const double val = mem[opcode(2)];
        return (val==0.0 || val==1.0);
      }
      double mp_rol() {
        return cimg::rol(mem[opcode(2)],(unsigned int)mem[opcode(3)]);
      }
      double mp_ror() {
        return cimg::ror(mem[opcode(2)],(unsigned int)mem[opcode(3)]);
      }
      double mp_lsl() {
        return (long)mem[opcode(2)]<<(unsigned int)mem[opcode(3)];
      }
      double mp_lsr() {
        return (long)mem[opcode(2)]>>(unsigned int)mem[opcode(3)];
      }
      double mp_sinc() {
        return cimg::sinc(mem[opcode(2)]);
      }
      double mp_im() {
        if (!reference_stats) reference.get_stats().move_to(reference_stats);
        return reference_stats?reference_stats[0]:0;
      }
      double mp_iM() {
        if (!reference_stats) reference.get_stats().move_to(reference_stats);
        return reference_stats?reference_stats[1]:0;
      }
      double mp_ia() {
        if (!reference_stats) reference.get_stats().move_to(reference_stats);
        return reference_stats?reference_stats[2]:0;
      }
      double mp_iv() {
        if (!reference_stats) reference.get_stats().move_to(reference_stats);
        return reference_stats?reference_stats[3]:0;
      }
      double mp_xm() {
        if (!reference_stats) reference.get_stats().move_to(reference_stats);
        return reference_stats?reference_stats[4]:0;
      }
      double mp_ym() {
        if (!reference_stats) reference.get_stats().move_to(reference_stats);
        return reference_stats?reference_stats[5]:0;
      }
      double mp_zm() {
        if (!reference_stats) reference.get_stats().move_to(reference_stats);
        return reference_stats?reference_stats[6]:0;
      }
      double mp_cm() {
        if (!reference_stats) reference.get_stats().move_to(reference_stats);
        return reference_stats?reference_stats[7]:0;
      }
      double mp_xM() {
        if (!reference_stats) reference.get_stats().move_to(reference_stats);
        return reference_stats?reference_stats[8]:0;
      }
      double mp_yM() {
        if (!reference_stats) reference.get_stats().move_to(reference_stats);
        return reference_stats?reference_stats[9]:0;
      }
      double mp_zM() {
        if (!reference_stats) reference.get_stats().move_to(reference_stats);
        return reference_stats?reference_stats[10]:0;
      }
      double mp_cM() {
        if (!reference_stats) reference.get_stats().move_to(reference_stats);
        return reference_stats?reference_stats[11]:0;
      }
      double mp_arg() {
        const int _ind = (int)mem[opcode(2)];
        const unsigned int nb_args = opcode._height-2, ind = _ind<0?_ind+nb_args:(unsigned int)_ind;
        if (ind>=nb_args) return 0;
        return mem[opcode(ind+2)];
      }
      double mp_int() {
        return (double)(long)mem[opcode(2)];
      }
      double mp_ioff() {
        const unsigned long off = (unsigned long)mem[opcode(2)];
        if (off>=reference.size()) return 0;
        return (double)reference[off];
      }
      double mp_joff() {
        const double x = mem[9], y = mem[10], z = mem[11], c = mem[12];
        const unsigned long off = reference.offset(x,y,z,c) + (unsigned long)(mem[opcode(2)]);
        if (off>=reference.size()) return 0;
        return (double)reference[off];
      }

      // Evaluation procedure, with image data.
      double eval(const double x, const double y, const double z, const double c) {
        static const mp_func mp_funcs[] = {
          &_cimg_math_parser::mp_u,            // 0
          &_cimg_math_parser::mp_g,            // 1
          &_cimg_math_parser::mp_i,            // 2
          &_cimg_math_parser::mp_log2,         // 3
          &_cimg_math_parser::mp_int,          // 4
          &_cimg_math_parser::mp_arg,          // 5
          &_cimg_math_parser::mp_cM,           // 6
          &_cimg_math_parser::mp_jxyzc,        // 7
          &_cimg_math_parser::mp_logical_or,   // 8
          &_cimg_math_parser::mp_logical_and,  // 9
          &_cimg_math_parser::mp_bitwise_or,   // 10
          &_cimg_math_parser::mp_bitwise_and,  // 11
          &_cimg_math_parser::mp_noteq,        // 12
          &_cimg_math_parser::mp_eqeq,         // 13
          &_cimg_math_parser::mp_infeq,        // 14
          &_cimg_math_parser::mp_supeq,        // 15
          &_cimg_math_parser::mp_inf,          // 16
          &_cimg_math_parser::mp_sup,          // 17
          &_cimg_math_parser::mp_lsl,          // 18
          &_cimg_math_parser::mp_lsr,          // 19
          &_cimg_math_parser::mp_sub,          // 20
          &_cimg_math_parser::mp_add,          // 21
          &_cimg_math_parser::mp_mul,          // 22
          &_cimg_math_parser::mp_div,          // 23
          &_cimg_math_parser::mp_modulo,       // 24
          &_cimg_math_parser::mp_pow,          // 25
          &_cimg_math_parser::mp_minus,        // 26
          &_cimg_math_parser::mp_logical_not,  // 27
          &_cimg_math_parser::mp_bitwise_not,  // 28
          &_cimg_math_parser::mp_sin,          // 29
          &_cimg_math_parser::mp_cos,          // 30
          &_cimg_math_parser::mp_tan,          // 31
          &_cimg_math_parser::mp_asin,         // 32
          &_cimg_math_parser::mp_acos,         // 33
          &_cimg_math_parser::mp_atan,         // 34
          &_cimg_math_parser::mp_sinh,         // 35
          &_cimg_math_parser::mp_cosh,         // 36
          &_cimg_math_parser::mp_tanh,         // 37
          &_cimg_math_parser::mp_log10,        // 38
          &_cimg_math_parser::mp_log,          // 39
          &_cimg_math_parser::mp_exp,          // 40
          &_cimg_math_parser::mp_sqrt,         // 41
          &_cimg_math_parser::mp_sign,         // 42
          &_cimg_math_parser::mp_abs,          // 43
          &_cimg_math_parser::mp_atan2,        // 44
          &_cimg_math_parser::mp_if,           // 45
          &_cimg_math_parser::mp_round,        // 46
          &_cimg_math_parser::mp_ixyzc,        // 47
          &_cimg_math_parser::mp_min,          // 48
          &_cimg_math_parser::mp_max,          // 49
          &_cimg_math_parser::mp_isnan,        // 50
          &_cimg_math_parser::mp_isinf,        // 51
          &_cimg_math_parser::mp_isint,        // 52
          &_cimg_math_parser::mp_isbool,       // 53
          &_cimg_math_parser::mp_rol,          // 54
          &_cimg_math_parser::mp_ror,          // 55
          &_cimg_math_parser::mp_sinc,         // 56
          &_cimg_math_parser::mp_im,           // 57
          &_cimg_math_parser::mp_iM,           // 58
          &_cimg_math_parser::mp_ia,           // 59
          &_cimg_math_parser::mp_iv,           // 60
          &_cimg_math_parser::mp_xm,           // 61
          &_cimg_math_parser::mp_ym,           // 62
          &_cimg_math_parser::mp_zm,           // 63
          &_cimg_math_parser::mp_cm,           // 64
          &_cimg_math_parser::mp_xM,           // 65
          &_cimg_math_parser::mp_yM,           // 66
          &_cimg_math_parser::mp_zM,           // 67
          &_cimg_math_parser::mp_ioff,         // 68
          &_cimg_math_parser::mp_joff          // 69
        };
        if (!mem) return 0;
        this->mp_funcs = mp_funcs;
        mem[9] = x; mem[10] = y; mem[11] = z; mem[12] = c;
        opcode._is_shared = true; opcode._width = opcode._depth = opcode._spectrum = 1;

        for (p_code = code._data; p_code<code.end(); ++p_code) {
          const CImg<uintT> &op = *p_code;
          opcode._data = op._data; opcode._height = op._height;  // Allows to avoid parameter passing to evaluation functions.
          const unsigned int target = opcode(1);
          mem[target] = (this->*mp_funcs[opcode[0]])();
        }
        return mem[result];
      }
    };

    //! Compute the square value of each pixel value.
    /**
       Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by its square value \f$I_{(x,y,z,c)}^2\f$.
       \note
       - The \inplace of this method statically casts the computed values to the pixel type \c T.
       - The \newinstance returns a \c CImg<float> image, if the pixel type \c T is \e not float-valued.
       \par Example
       \code
       const CImg<float> img("reference.jpg");
       (img,img.get_sqr().normalize(0,255)).display();
       \endcode
       \image html ref_sqr.jpg
    **/
    CImg<T>& sqr() {
      cimg_for(*this,ptrd,T) { const T val = *ptrd; *ptrd = (T)(val*val); };
      return *this;
    }

    //! Compute the square value of each pixel value \newinstance.
    CImg<Tfloat> get_sqr() const {
      return CImg<Tfloat>(*this,false).sqr();
    }

    //! Compute the square root of each pixel value.
    /**
       Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by its square root \f$\sqrt{I_{(x,y,z,c)}}\f$.
       \note
       - The \inplace of this method statically casts the computed values to the pixel type \c T.
       - The \newinstance returns a \c CImg<float> image, if the pixel type \c T is \e not float-valued.
       \par Example
       \code
       const CImg<float> img("reference.jpg");
       (img,img.get_sqrt().normalize(0,255)).display();
       \endcode
       \image html ref_sqrt.jpg
    **/
    CImg<T>& sqrt() {
      cimg_for(*this,ptrd,T) *ptrd = (T)std::sqrt((double)*ptrd);
      return *this;
    }

    //! Compute the square root of each pixel value \newinstance.
    CImg<Tfloat> get_sqrt() const {
      return CImg<Tfloat>(*this,false).sqrt();
    }

    //! Compute the exponential of each pixel value.
    /**
       Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by its exponential \f$e^{I_{(x,y,z,c)}}\f$.
       \note
       - The \inplace of this method statically casts the computed values to the pixel type \c T.
       - The \newinstance returns a \c CImg<float> image, if the pixel type \c T is \e not float-valued.
    **/
    CImg<T>& exp() {
      cimg_for(*this,ptrd,T) *ptrd = (T)std::exp((double)*ptrd);
      return *this;
    }

    //! Compute the exponential of each pixel value \newinstance.
    CImg<Tfloat> get_exp() const {
      return CImg<Tfloat>(*this,false).exp();
    }

    //! Compute the logarithm of each pixel value.
    /**
       Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by its logarithm \f$\mathrm{log}_{e}(I_{(x,y,z,c)})\f$.
       \note
       - The \inplace of this method statically casts the computed values to the pixel type \c T.
       - The \newinstance returns a \c CImg<float> image, if the pixel type \c T is \e not float-valued.
    **/
    CImg<T>& log() {
      cimg_for(*this,ptrd,T) *ptrd = (T)std::log((double)*ptrd);
      return *this;
    }

    //! Compute the logarithm of each pixel value \newinstance.
    CImg<Tfloat> get_log() const {
      return CImg<Tfloat>(*this,false).log();
    }

    //! Compute the base-2 logarithm of each pixel value.
    /**
       Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by its base-2 logarithm \f$\mathrm{log}_{2}(I_{(x,y,z,c)})\f$.
       \note
       - The \inplace of this method statically casts the computed values to the pixel type \c T.
       - The \newinstance returns a \c CImg<float> image, if the pixel type \c T is \e not float-valued.
    **/
    CImg<T>& log2() {
      cimg_for(*this,ptrd,T) *ptrd = (T)cimg::log2((double)*ptrd);
      return *this;
    }

    //! Compute the base-10 logarithm of each pixel value \newinstance.
    CImg<Tfloat> get_log2() const {
      return CImg<Tfloat>(*this,false).log2();
    }

    //! Compute the base-10 logarithm of each pixel value.
    /**
       Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by its base-10 logarithm \f$\mathrm{log}_{10}(I_{(x,y,z,c)})\f$.
       \note
       - The \inplace of this method statically casts the computed values to the pixel type \c T.
       - The \newinstance returns a \c CImg<float> image, if the pixel type \c T is \e not float-valued.
    **/
    CImg<T>& log10() {
      cimg_for(*this,ptrd,T) *ptrd = (T)std::log10((double)*ptrd);
      return *this;
    }

    //! Compute the base-10 logarithm of each pixel value \newinstance.
    CImg<Tfloat> get_log10() const {
      return CImg<Tfloat>(*this,false).log10();
    }

    //! Compute the absolute value of each pixel value.
    /**
       Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by its absolute value \f$|I_{(x,y,z,c)}|\f$.
       \note
       - The \inplace of this method statically casts the computed values to the pixel type \c T.
       - The \newinstance returns a \c CImg<float> image, if the pixel type \c T is \e not float-valued.
    **/
    CImg<T>& abs() {
      cimg_for(*this,ptrd,T) *ptrd = cimg::abs(*ptrd);
      return *this;
    }

    //! Compute the absolute value of each pixel value \newinstance.
    CImg<Tfloat> get_abs() const {
      return CImg<Tfloat>(*this,false).abs();
    }

    //! Compute the sign of each pixel value.
    /**
       Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by its sign \f$\mathrm{sign}(I_{(x,y,z,c)})\f$.
       \note
       - The sign is set to:
         - \c 1 if pixel value is strictly positive.
         - \c -1 if pixel value is strictly negative.
         - \c 0 if pixel value is equal to \c 0.
       - The \inplace of this method statically casts the computed values to the pixel type \c T.
       - The \newinstance returns a \c CImg<float> image, if the pixel type \c T is \e not float-valued.
    **/
    CImg<T>& sign() {
      cimg_for(*this,ptrd,T) *ptrd = cimg::sign(*ptrd);
      return *this;
    }

    //! Compute the sign of each pixel value \newinstance.
    CImg<Tfloat> get_sign() const {
      return CImg<Tfloat>(*this,false).sign();
    }

    //! Compute the cosine of each pixel value.
    /**
       Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by its cosine \f$\cos(I_{(x,y,z,c)})\f$.
       \note
       - Pixel values are regarded as being in \e radian.
       - The \inplace of this method statically casts the computed values to the pixel type \c T.
       - The \newinstance returns a \c CImg<float> image, if the pixel type \c T is \e not float-valued.
    **/
    CImg<T>& cos() {
      cimg_for(*this,ptrd,T) *ptrd = (T)std::cos((double)*ptrd);
      return *this;
    }

    //! Compute the cosine of each pixel value \newinstance.
    CImg<Tfloat> get_cos() const {
      return CImg<Tfloat>(*this,false).cos();
    }

    //! Compute the sine of each pixel value.
    /**
       Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by its sine \f$\sin(I_{(x,y,z,c)})\f$.
       \note
       - Pixel values are regarded as being in \e radian.
       - The \inplace of this method statically casts the computed values to the pixel type \c T.
       - The \newinstance returns a \c CImg<float> image, if the pixel type \c T is \e not float-valued.
    **/
    CImg<T>& sin() {
      cimg_for(*this,ptrd,T) *ptrd = (T)std::sin((double)*ptrd);
      return *this;
    }

    //! Compute the sine of each pixel value \newinstance.
    CImg<Tfloat> get_sin() const {
      return CImg<Tfloat>(*this,false).sin();
    }

    //! Compute the sinc of each pixel value.
    /**
       Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by its sinc \f$\mathrm{sinc}(I_{(x,y,z,c)})\f$.
       \note
       - Pixel values are regarded as being exin \e radian.
       - The \inplace of this method statically casts the computed values to the pixel type \c T.
       - The \newinstance returns a \c CImg<float> image, if the pixel type \c T is \e not float-valued.
    **/
    CImg<T>& sinc() {
      cimg_for(*this,ptrd,T) *ptrd = (T)cimg::sinc((double)*ptrd);
      return *this;
    }

    //! Compute the sinc of each pixel value \newinstance.
    CImg<Tfloat> get_sinc() const {
      return CImg<Tfloat>(*this,false).sinc();
    }

    //! Compute the tangent of each pixel value.
    /**
       Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by its tangent \f$\tan(I_{(x,y,z,c)})\f$.
       \note
       - Pixel values are regarded as being exin \e radian.
       - The \inplace of this method statically casts the computed values to the pixel type \c T.
       - The \newinstance returns a \c CImg<float> image, if the pixel type \c T is \e not float-valued.
    **/
    CImg<T>& tan() {
      cimg_for(*this,ptrd,T) *ptrd = (T)std::tan((double)*ptrd);
      return *this;
    }

    //! Compute the tangent of each pixel value \newinstance.
    CImg<Tfloat> get_tan() const {
      return CImg<Tfloat>(*this,false).tan();
    }

    //! Compute the hyperbolic cosine of each pixel value.
    /**
       Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by its hyperbolic cosine \f$\mathrm{cosh}(I_{(x,y,z,c)})\f$.
       \note
       - The \inplace of this method statically casts the computed values to the pixel type \c T.
       - The \newinstance returns a \c CImg<float> image, if the pixel type \c T is \e not float-valued.
    **/
    CImg<T>& cosh() {
      cimg_for(*this,ptrd,T) *ptrd = (T)std::cosh((double)*ptrd);
      return *this;
    }

    //! Compute the hyperbolic cosine of each pixel value \newinstance.
    CImg<Tfloat> get_cosh() const {
      return CImg<Tfloat>(*this,false).cosh();
    }

    //! Compute the hyperbolic sine of each pixel value.
    /**
       Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by its hyperbolic sine \f$\mathrm{sinh}(I_{(x,y,z,c)})\f$.
       \note
       - The \inplace of this method statically casts the computed values to the pixel type \c T.
       - The \newinstance returns a \c CImg<float> image, if the pixel type \c T is \e not float-valued.
    **/
    CImg<T>& sinh() {
      cimg_for(*this,ptrd,T) *ptrd = (T)std::sinh((double)*ptrd);
      return *this;
    }

    //! Compute the hyperbolic sine of each pixel value \newinstance.
    CImg<Tfloat> get_sinh() const {
      return CImg<Tfloat>(*this,false).sinh();
    }

    //! Compute the hyperbolic tangent of each pixel value.
    /**
       Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by its hyperbolic tangent \f$\mathrm{tanh}(I_{(x,y,z,c)})\f$.
       \note
       - The \inplace of this method statically casts the computed values to the pixel type \c T.
       - The \newinstance returns a \c CImg<float> image, if the pixel type \c T is \e not float-valued.
    **/
    CImg<T>& tanh() {
      cimg_for(*this,ptrd,T) *ptrd = (T)std::tanh((double)*ptrd);
      return *this;
    }

    //! Compute the hyperbolic tangent of each pixel value \newinstance.
    CImg<Tfloat> get_tanh() const {
      return CImg<Tfloat>(*this,false).tanh();
    }

    //! Compute the arccosine of each pixel value.
    /**
       Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by its arccosine \f$\mathrm{acos}(I_{(x,y,z,c)})\f$.
       \note
       - The \inplace of this method statically casts the computed values to the pixel type \c T.
       - The \newinstance returns a \c CImg<float> image, if the pixel type \c T is \e not float-valued.
    **/
    CImg<T>& acos() {
      cimg_for(*this,ptrd,T) *ptrd = (T)std::acos((double)*ptrd);
      return *this;
    }

    //! Compute the arccosine of each pixel value \newinstance.
    CImg<Tfloat> get_acos() const {
      return CImg<Tfloat>(*this,false).acos();
    }

    //! Compute the arcsine of each pixel value.
    /**
       Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by its arcsine \f$\mathrm{asin}(I_{(x,y,z,c)})\f$.
       \note
       - The \inplace of this method statically casts the computed values to the pixel type \c T.
       - The \newinstance returns a \c CImg<float> image, if the pixel type \c T is \e not float-valued.
    **/
    CImg<T>& asin() {
      cimg_for(*this,ptrd,T) *ptrd = (T)std::asin((double)*ptrd);
      return *this;
    }

    //! Compute the arcsine of each pixel value \newinstance.
    CImg<Tfloat> get_asin() const {
      return CImg<Tfloat>(*this,false).asin();
    }

    //! Compute the arctangent of each pixel value.
    /**
       Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by its arctangent \f$\mathrm{atan}(I_{(x,y,z,c)})\f$.
       \note
       - The \inplace of this method statically casts the computed values to the pixel type \c T.
       - The \newinstance returns a \c CImg<float> image, if the pixel type \c T is \e not float-valued.
    **/
    CImg<T>& atan() {
      cimg_for(*this,ptrd,T) *ptrd = (T)std::atan((double)*ptrd);
      return *this;
    }

    //! Compute the arctangent of each pixel value \newinstance.
    CImg<Tfloat> get_atan() const {
      return CImg<Tfloat>(*this,false).atan();
    }

    //! Compute the arctangent2 of each pixel value.
    /**
       Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by its arctangent2 \f$\mathrm{atan2}(I_{(x,y,z,c)})\f$.
       \param img Image whose pixel values specify the second argument of the \c atan2() function.
       \note
       - The \inplace of this method statically casts the computed values to the pixel type \c T.
       - The \newinstance returns a \c CImg<float> image, if the pixel type \c T is \e not float-valued.
       \par Example
       \code
       const CImg<float>
          img_x(100,100,1,1,"x-w/2",false),   // Define an horizontal centered gradient, from '-width/2' to 'width/2'.
          img_y(100,100,1,1,"y-h/2",false),   // Define a vertical centered gradient, from '-height/2' to 'height/2'.
          img_atan2 = img_y.get_atan2(img_x); // Compute atan2(y,x) for each pixel value.
       (img_x,img_y,img_atan2).display();
       \endcode
    **/
    template<typename t>
    CImg<T>& atan2(const CImg<t>& img) {
      const unsigned long siz = size(), isiz = img.size();
      if (siz && isiz) {
        if (is_overlapped(img)) return atan2(+img);
        T *ptrd = _data, *const ptre = _data + siz;
        if (siz>isiz) for (unsigned long n = siz/isiz; n; --n)
          for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd) *ptrd = (T)std::atan2((double)*ptrd,(double)*(ptrs++));
        for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)std::atan2((double)*ptrd,(double)*(ptrs++));
      }
      return *this;
    }

    //! Compute the arctangent2 of each pixel value \newinstance.
    template<typename t>
    CImg<Tfloat> get_atan2(const CImg<t>& img) const {
      return CImg<Tfloat>(*this,false).atan2(img);
    }

    //! In-place pointwise multiplication.
    /**
       Compute the pointwise multiplication between the image instance and the specified input image \c img.
       \param img Input image, as the second operand of the multiplication.
       \note
       - Similar to operator+=(const CImg<t>&), except that it performs a pointwise multiplication instead of an addition.
       - It does \e not perform a \e matrix multiplication. For this purpose, use operator*=(const CImg<t>&) instead.
       \par Example
       \code
       CImg<float>
         img("reference.jpg"),
         shade(img.width,img.height(),1,1,"-(x-w/2)^2-(y-h/2)^2",false);
       shade.normalize(0,1);
       (img,shade,img.get_mul(shade)).display();
       \endcode
    **/
    template<typename t>
    CImg<T>& mul(const CImg<t>& img) {
      const unsigned long siz = size(), isiz = img.size();
      if (siz && isiz) {
        if (is_overlapped(img)) return mul(+img);
        T *ptrd = _data, *const ptre = _data + siz;
        if (siz>isiz) for (unsigned long n = siz/isiz; n; --n)
          for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd) *ptrd = (T)(*ptrd * *(ptrs++));
        for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)(*ptrd * *(ptrs++));
      }
      return *this;
    }

    //! In-place pointwise multiplication \newinstance.
    template<typename t>
    CImg<_cimg_Tt> get_mul(const CImg<t>& img) const {
      return CImg<_cimg_Tt>(*this,false).mul(img);
    }

    //! In-place pointwise division.
    /**
       Similar to mul(const CImg<t>&), except that it performs a pointwise division instead of a multiplication.
    **/
    template<typename t>
    CImg<T>& div(const CImg<t>& img) {
      const unsigned long siz = size(), isiz = img.size();
      if (siz && isiz) {
        if (is_overlapped(img)) return div(+img);
        T *ptrd = _data, *const ptre = _data + siz;
        if (siz>isiz) for (unsigned long n = siz/isiz; n; --n)
          for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd) *ptrd = (T)(*ptrd / *(ptrs++));
        for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)(*ptrd / *(ptrs++));
      }
      return *this;
    }

    //! In-place pointwise division \newinstance.
    template<typename t>
    CImg<_cimg_Tt> get_div(const CImg<t>& img) const {
      return CImg<_cimg_Tt>(*this,false).div(img);
    }

    //! Raise each pixel value to a specified power.
    /**
       Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by its power \f$I_{(x,y,z,c)}^p\f$.
       \param p Exponent value.
       \note
       - The \inplace of this method statically casts the computed values to the pixel type \c T.
       - The \newinstance returns a \c CImg<float> image, if the pixel type \c T is \e not float-valued.
       \par Example
       \code
       const CImg<float>
         img0("reference.jpg"),           // Load reference color image.
         img1 = (img0/255).pow(1.8)*=255, // Compute gamma correction, with gamma = 1.8.
         img2 = (img0/255).pow(0.5)*=255; // Compute gamma correction, with gamma = 0.5.
       (img0,img1,img2).display();
       \endcode
    **/
    CImg<T>& pow(const double p) {
      if (p==-4) { cimg_for(*this,ptrd,T) { const T val = *ptrd; *ptrd = (T)(1.0/(val*val*val*val)); } return *this; }
      if (p==-3) { cimg_for(*this,ptrd,T) { const T val = *ptrd; *ptrd = (T)(1.0/(val*val*val)); } return *this; }
      if (p==-2) { cimg_for(*this,ptrd,T) { const T val = *ptrd; *ptrd = (T)(1.0/(val*val)); } return *this; }
      if (p==-1) { cimg_for(*this,ptrd,T) { const T val = *ptrd; *ptrd = (T)(1.0/val); } return *this; }
      if (p==-0.5) { cimg_for(*this,ptrd,T) { const T val = *ptrd; *ptrd = (T)(1/std::sqrt((double)val)); } return *this; }
      if (p==0) return fill(1);
      if (p==0.5) { cimg_for(*this,ptrd,T) { const T val = *ptrd; *ptrd = (T)std::sqrt((double)val); } return *this; }
      if (p==1) return *this;
      if (p==2) { cimg_for(*this,ptrd,T) { const T val = *ptrd; *ptrd = val*val; } return *this; }
      if (p==3) { cimg_for(*this,ptrd,T) { const T val = *ptrd; *ptrd = val*val*val; } return *this; }
      if (p==4) { cimg_for(*this,ptrd,T) { const T val = *ptrd; *ptrd = val*val*val*val; } return *this; }
      cimg_for(*this,ptrd,T) *ptrd = (T)std::pow((double)*ptrd,p);
      return *this;
    }

    //! Raise each pixel value to a specified power \newinstance.
    CImg<Tfloat> get_pow(const double p) const {
      return CImg<Tfloat>(*this,false).pow(p);
    }

    //! Raise each pixel value to a power, specified from an expression.
    /**
       Similar to operator+=(const char*), except it performs a pointwise exponentiation instead of an addition.
    **/
    CImg<T>& pow(const char *const expression) {
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      try {
        const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(), &base = _base?_base:*this;
        _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"pow");
        T *ptrd = *expression=='<'?end()-1:_data;
        if (*expression=='<') cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)std::pow((double)*ptrd,mp.eval(x,y,z,c)); --ptrd; }
        else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)std::pow((double)*ptrd,mp.eval(x,y,z,c)); ++ptrd; }
      } catch (CImgException&) {
        CImg<Tfloat> values(_width,_height,_depth,_spectrum);
        try {
          values.fill(expression,true);
        } catch (CImgException&) {
          cimg::exception_mode() = omode;
          values.load(expression);
        }
        pow(values);
      }
      cimg::exception_mode() = omode;
      return *this;
    }

    //! Raise each pixel value to a power, specified from an expression \newinstance.
    CImg<Tfloat> get_pow(const char *const expression) const {
      return CImg<Tfloat>(*this,false).pow(expression);
    }

    //! Raise each pixel value to a power, pointwisely specified from another image.
    /**
       Similar to operator+=(const CImg<t>& img), except that it performs an exponentiation instead of an addition.
    **/
    template<typename t>
    CImg<T>& pow(const CImg<t>& img) {
      const unsigned long siz = size(), isiz = img.size();
      if (siz && isiz) {
        if (is_overlapped(img)) return pow(+img);
        T *ptrd = _data, *const ptre = _data + siz;
        if (siz>isiz) for (unsigned long n = siz/isiz; n; --n)
          for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd) *ptrd = (T)std::pow((double)*ptrd,(double)(*(ptrs++)));
        for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)std::pow((double)*ptrd,(double)(*(ptrs++)));
      }
      return *this;
    }

    //! Raise each pixel value to a power, pointwisely specified from another image \newinstance.
    template<typename t>
    CImg<Tfloat> get_pow(const CImg<t>& img) const {
      return CImg<Tfloat>(*this,false).pow(img);
    }

    //! Compute the bitwise left rotation of each pixel value.
    /**
       Similar to operator<<=(unsigned int), except that it performs a left rotation instead of a left shift.
    **/
    CImg<T>& rol(const unsigned int n=1) {
      cimg_for(*this,ptrd,T) *ptrd = (T)cimg::rol(*ptrd,n);
      return *this;
    }

    //! Compute the bitwise left rotation of each pixel value \newinstance.
    CImg<T> get_rol(const unsigned int n=1) const {
      return (+*this).rol(n);
    }

    //! Compute the bitwise left rotation of each pixel value.
    /**
       Similar to operator<<=(const char*), except that it performs a left rotation instead of a left shift.
    **/
    CImg<T>& rol(const char *const expression) {
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      try {
        const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(), &base = _base?_base:*this;
        _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"rol");
        T *ptrd = *expression=='<'?end()-1:_data;
        if (*expression=='<') cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)cimg::rol(*ptrd,(unsigned int)mp.eval(x,y,z,c)); --ptrd; }
        else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)cimg::rol(*ptrd,(unsigned int)mp.eval(x,y,z,c)); ++ptrd; }
      } catch (CImgException&) {
        CImg<Tfloat> values(_width,_height,_depth,_spectrum);
        try {
          values.fill(expression,true);
        } catch (CImgException&) {
          cimg::exception_mode() = omode;
          values.load(expression);
        }
        rol(values);
      }
      cimg::exception_mode() = omode;
      return *this;
    }

    //! Compute the bitwise left rotation of each pixel value \newinstance.
    CImg<T> get_rol(const char *const expression) const {
      return (+*this).rol(expression);
    }

    //! Compute the bitwise left rotation of each pixel value.
    /**
       Similar to operator<<=(const CImg<t>&), except that it performs a left rotation instead of a left shift.
    **/
    template<typename t>
    CImg<T>& rol(const CImg<t>& img) {
      const unsigned long siz = size(), isiz = img.size();
      if (siz && isiz) {
        if (is_overlapped(img)) return rol(+img);
        T *ptrd = _data, *const ptre = _data + siz;
        if (siz>isiz) for (unsigned long n = siz/isiz; n; --n)
          for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd) *ptrd = (T)cimg::rol(*ptrd,(unsigned int)(*(ptrs++)));
        for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)cimg::rol(*ptrd,(unsigned int)(*(ptrs++)));
      }
      return *this;
    }

    //! Compute the bitwise left rotation of each pixel value \newinstance.
    template<typename t>
    CImg<T> get_rol(const CImg<t>& img) const {
      return (+*this).rol(img);
    }

    //! Compute the bitwise right rotation of each pixel value.
    /**
       Similar to operator>>=(unsigned int), except that it performs a right rotation instead of a right shift.
    **/
    CImg<T>& ror(const unsigned int n=1) {
      cimg_for(*this,ptrd,T) *ptrd = (T)cimg::ror(*ptrd,n);
      return *this;
    }

    //! Compute the bitwise right rotation of each pixel value \newinstance.
    CImg<T> get_ror(const unsigned int n=1) const {
      return (+*this).ror(n);
    }

    //! Compute the bitwise right rotation of each pixel value.
    /**
       Similar to operator>>=(const char*), except that it performs a right rotation instead of a right shift.
    **/
    CImg<T>& ror(const char *const expression) {
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      try {
        const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(), &base = _base?_base:*this;
        _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"ror");
        T *ptrd = *expression=='<'?end()-1:_data;
        if (*expression=='<') cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)cimg::ror(*ptrd,(unsigned int)mp.eval(x,y,z,c)); --ptrd; }
        else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)cimg::ror(*ptrd,(unsigned int)mp.eval(x,y,z,c)); ++ptrd; }
      } catch (CImgException&) {
        CImg<Tfloat> values(_width,_height,_depth,_spectrum);
        try {
          values.fill(expression,true);
        } catch (CImgException&) {
          cimg::exception_mode() = omode;
          values.load(expression);
        }
        ror(values);
      }
      cimg::exception_mode() = omode;
      return *this;
    }

    //! Compute the bitwise right rotation of each pixel value \newinstance.
    CImg<T> get_ror(const char *const expression) const {
      return (+*this).ror(expression);
    }

    //! Compute the bitwise right rotation of each pixel value.
    /**
       Similar to operator>>=(const CImg<t>&), except that it performs a right rotation instead of a right shift.
    **/
    template<typename t>
    CImg<T>& ror(const CImg<t>& img) {
      const unsigned long siz = size(), isiz = img.size();
      if (siz && isiz) {
        if (is_overlapped(img)) return ror(+img);
        T *ptrd = _data, *const ptre = _data + siz;
        if (siz>isiz) for (unsigned long n = siz/isiz; n; --n)
          for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd) *ptrd = (T)cimg::ror(*ptrd,(unsigned int)(*(ptrs++)));
        for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = (T)cimg::ror(*ptrd,(unsigned int)(*(ptrs++)));
      }
      return *this;
    }

    //! Compute the bitwise right rotation of each pixel value \newinstance.
    template<typename t>
    CImg<T> get_ror(const CImg<t>& img) const {
      return (+*this).ror(img);
    }

    //! Pointwise min operator between instance image and a value.
    /**
       \param val Value used as the reference argument of the min operator.
       \note Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by \f$\mathrm{min}(I_{(x,y,z,c)},\mathrm{val})\f$.
     **/
    CImg<T>& min(const T val) {
      cimg_for(*this,ptrd,T) *ptrd = cimg::min(*ptrd,val);
      return *this;
    }

    //! Pointwise min operator between instance image and a value \newinstance.
    CImg<T> get_min(const T val) const {
      return (+*this).min(val);
    }

    //! Pointwise min operator between two images.
    /**
       \param img Image used as the reference argument of the min operator.
       \note Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by \f$\mathrm{min}(I_{(x,y,z,c)},\mathrm{img}_{(x,y,z,c)})\f$.
     **/
    template<typename t>
    CImg<T>& min(const CImg<t>& img) {
      const unsigned long siz = size(), isiz = img.size();
      if (siz && isiz) {
        if (is_overlapped(img)) return min(+img);
        T *ptrd = _data, *const ptre = _data + siz;
        if (siz>isiz) for (unsigned long n = siz/isiz; n; --n)
          for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd) *ptrd = cimg::min((T)*(ptrs++),*ptrd);
        for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = cimg::min((T)*(ptrs++),*ptrd);
      }
      return *this;
    }

    //! Pointwise min operator between two images \newinstance.
    template<typename t>
    CImg<_cimg_Tt> get_min(const CImg<t>& img) const {
      return CImg<_cimg_Tt>(*this,false).min(img);
    }

    //! Pointwise min operator between an image and an expression.
    /**
       \param expression Math formula as a C-string.
       \note Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by \f$\mathrm{min}(I_{(x,y,z,c)},\mathrm{expr}_{(x,y,z,c)})\f$.
    **/
    CImg<T>& min(const char *const expression) {
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      try {
        const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(), &base = _base?_base:*this;
        _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"min");
        T *ptrd = *expression=='<'?end()-1:_data;
        if (*expression=='<') cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)cimg::min(*ptrd,(T)mp.eval(x,y,z,c)); --ptrd; }
        else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)cimg::min(*ptrd,(T)mp.eval(x,y,z,c)); ++ptrd; }
      } catch (CImgException&) {
        CImg<T> values(_width,_height,_depth,_spectrum);
        try {
          values.fill(expression,true);
        } catch (CImgException&) {
          cimg::exception_mode() = omode;
          values.load(expression);
        }
        min(values);
      }
      cimg::exception_mode() = omode;
      return *this;
    }

    //! Pointwise min operator between an image and an expression \newinstance.
    CImg<Tfloat> get_min(const char *const expression) const {
      return CImg<Tfloat>(*this,false).min(expression);
    }

    //! Pointwise max operator between instance image and a value.
    /**
       \param val Value used as the reference argument of the max operator.
       \note Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by \f$\mathrm{max}(I_{(x,y,z,c)},\mathrm{val})\f$.
     **/
    CImg<T>& max(const T val) {
      cimg_for(*this,ptrd,T) *ptrd = cimg::max(*ptrd,val);
      return *this;
    }

    //! Pointwise max operator between instance image and a value \newinstance.
    CImg<T> get_max(const T val) const {
      return (+*this).max(val);
    }

    //! Pointwise max operator between two images.
    /**
       \param img Image used as the reference argument of the max operator.
       \note Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by \f$\mathrm{max}(I_{(x,y,z,c)},\mathrm{img}_{(x,y,z,c)})\f$.
     **/
    template<typename t>
    CImg<T>& max(const CImg<t>& img) {
      const unsigned long siz = size(), isiz = img.size();
      if (siz && isiz) {
        if (is_overlapped(img)) return max(+img);
        T *ptrd = _data, *const ptre = _data + siz;
        if (siz>isiz) for (unsigned long n = siz/isiz; n; --n)
          for (const t *ptrs = img._data, *ptrs_end = ptrs + isiz; ptrs<ptrs_end; ++ptrd) *ptrd = cimg::max((T)*(ptrs++),*ptrd);
        for (const t *ptrs = img._data; ptrd<ptre; ++ptrd) *ptrd = cimg::max((T)*(ptrs++),*ptrd);
      }
      return *this;
    }

    //! Pointwise max operator between two images \newinstance.
    template<typename t>
    CImg<_cimg_Tt> get_max(const CImg<t>& img) const {
      return CImg<_cimg_Tt>(*this,false).max(img);
    }

    //! Pointwise max operator between an image and an expression.
    /**
       \param expression Math formula as a C-string.
       \note Replace each pixel value \f$I_{(x,y,z,c)}\f$ of the image instance by \f$\mathrm{max}(I_{(x,y,z,c)},\mathrm{expr}_{(x,y,z,c)})\f$.
    **/
    CImg<T>& max(const char *const expression) {
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      try {
        const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(), &base = _base?_base:*this;
        _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"max");
        T *ptrd = *expression=='<'?end()-1:_data;
        if (*expression=='<') cimg_rofXYZC(*this,x,y,z,c) { *ptrd = (T)cimg::max(*ptrd,(T)mp.eval(x,y,z,c)); --ptrd; }
        else cimg_forXYZC(*this,x,y,z,c) { *ptrd = (T)cimg::max(*ptrd,(T)mp.eval(x,y,z,c)); ++ptrd; }
      } catch (CImgException&) {
        CImg<T> values(_width,_height,_depth,_spectrum);
        try {
          values.fill(expression,true);
        } catch (CImgException&) {
          cimg::exception_mode() = omode;
          values.load(expression);
        }
        max(values);
      }
      cimg::exception_mode() = omode;
      return *this;
    }

    //! Pointwise max operator between an image and an expression \newinstance.
    CImg<Tfloat> get_max(const char *const expression) const {
      return CImg<Tfloat>(*this,false).max(expression);
    }

    //! Return a reference to the minimum pixel value.
    /**
     **/
    T& min() {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "min(): Empty instance.",
                                    cimg_instance);
      T *ptr_min = _data;
      T min_value = *ptr_min;
      cimg_for(*this,ptrs,T) if (*ptrs<min_value) min_value = *(ptr_min=ptrs);
      return *ptr_min;
    }

    //! Return a reference to the minimum pixel value \const.
    const T& min() const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "min(): Empty instance.",
                                    cimg_instance);
      const T *ptr_min = _data;
      T min_value = *ptr_min;
      cimg_for(*this,ptrs,T) if (*ptrs<min_value) min_value = *(ptr_min=ptrs);
      return *ptr_min;
    }

    //! Return a reference to the maximum pixel value.
    /**
     **/
    T& max() {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "max(): Empty instance.",
                                    cimg_instance);
      T *ptr_max = _data;
      T max_value = *ptr_max;
      cimg_for(*this,ptrs,T) if (*ptrs>max_value) max_value = *(ptr_max=ptrs);
      return *ptr_max;
    }

    //! Return a reference to the maximum pixel value \const.
    const T& max() const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "max(): Empty instance.",
                                    cimg_instance);
      const T *ptr_max = _data;
      T max_value = *ptr_max;
      cimg_for(*this,ptrs,T) if (*ptrs>max_value) max_value = *(ptr_max=ptrs);
      return *ptr_max;
    }

    //! Return a reference to the minimum pixel value as well as the maximum pixel value.
    /**
       \param[out] max_val Maximum pixel value.
    **/
    template<typename t>
    T& min_max(t& max_val) {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "min_max(): Empty instance.",
                                    cimg_instance);
      T *ptr_min = _data;
      T min_value = *ptr_min, max_value = min_value;
      cimg_for(*this,ptrs,T) {
        const T val = *ptrs;
        if (val<min_value) { min_value = val; ptr_min = ptrs; }
        if (val>max_value) max_value = val;
      }
      max_val = (t)max_value;
      return *ptr_min;
    }

    //! Return a reference to the minimum pixel value as well as the maximum pixel value \const.
    template<typename t>
    const T& min_max(t& max_val) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "min_max(): Empty instance.",
                                    cimg_instance);
      const T *ptr_min = _data;
      T min_value = *ptr_min, max_value = min_value;
      cimg_for(*this,ptrs,T) {
        const T val = *ptrs;
        if (val<min_value) { min_value = val; ptr_min = ptrs; }
        if (val>max_value) max_value = val;
      }
      max_val = (t)max_value;
      return *ptr_min;
    }

    //! Return a reference to the maximum pixel value as well as the minimum pixel value.
    /**
       \param[out] min_val Minimum pixel value.
    **/
    template<typename t>
    T& max_min(t& min_val) {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "max_min(): Empty instance.",
                                    cimg_instance);
      T *ptr_max = _data;
      T max_value = *ptr_max, min_value = max_value;
      cimg_for(*this,ptrs,T) {
        const T val = *ptrs;
        if (val>max_value) { max_value = val; ptr_max = ptrs; }
        if (val<min_value) min_value = val;
      }
      min_val = (t)min_value;
      return *ptr_max;
    }

    //! Return a reference to the maximum pixel value as well as the minimum pixel value \const.
    template<typename t>
    const T& max_min(t& min_val) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "max_min(): Empty instance.",
                                    cimg_instance);
      const T *ptr_max = _data;
      T max_value = *ptr_max, min_value = max_value;
      cimg_for(*this,ptrs,T) {
        const T val = *ptrs;
        if (val>max_value) { max_value = val; ptr_max = ptrs; }
        if (val<min_value) min_value = val;
      }
      min_val = (t)min_value;
      return *ptr_max;
    }

    //! Return the kth smallest pixel value.
    /**
       \param k Rank of the search smallest element.
    **/
    T kth_smallest(const unsigned int k) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "kth_smallest(): Empty instance.",
                                    cimg_instance);
      CImg<T> arr(*this);
      unsigned int l = 0, ir = size() - 1;
      for (;;) {
        if (ir<=l+1) {
          if (ir==l+1 && arr[ir]<arr[l]) cimg::swap(arr[l],arr[ir]);
          return arr[k];
        } else {
          const unsigned int mid = (l + ir)>>1;
          cimg::swap(arr[mid],arr[l+1]);
          if (arr[l]>arr[ir]) cimg::swap(arr[l],arr[ir]);
          if (arr[l+1]>arr[ir]) cimg::swap(arr[l+1],arr[ir]);
          if (arr[l]>arr[l+1]) cimg::swap(arr[l],arr[l+1]);
          unsigned int i = l + 1, j = ir;
          const T pivot = arr[l+1];
          for (;;) {
            do ++i; while (arr[i]<pivot);
            do --j; while (arr[j]>pivot);
            if (j<i) break;
            cimg::swap(arr[i],arr[j]);
          }
          arr[l+1] = arr[j];
          arr[j] = pivot;
          if (j>=k) ir = j - 1;
          if (j<=k) l = i;
        }
      }
      return 0;
    }

    //! Return the median pixel value.
    /**
     **/
    T median() const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "median(): Empty instance.",
                                    cimg_instance);
      const unsigned int s = size();
      const T res = kth_smallest(s>>1);
      return (s%2)?res:((res+kth_smallest((s>>1)-1))/2);
    }

    //! Return the sum of all the pixel values.
    /**
     **/
    Tdouble sum() const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "sum(): Empty instance.",
                                    cimg_instance);
      Tdouble res = 0;
      cimg_for(*this,ptrs,T) res+=(Tdouble)*ptrs;
      return res;
    }

    //! Return the average pixel value.
    /**
     **/
    Tdouble mean() const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "mean(): Empty instance.",
                                    cimg_instance);
      Tdouble res = 0;
      cimg_for(*this,ptrs,T) res+=(Tdouble)*ptrs;
      return res/size();
    }

    //! Return the variance of the pixel values.
    /**
       \param variance_method Method used to estimate the variance. Can be:
       - \c 0: Second moment, computed as
       \f$1/N \sum\limits_{k=1}^{N} (x_k - \bar x)^2 = 1/N \left( \sum\limits_{k=1}^N x_k^2 - \left( \sum\limits_{k=1}^N x_k \right)^2 / N \right)\f$
       with \f$ \bar x = 1/N \sum\limits_{k=1}^N x_k \f$.
       - \c 1: Best unbiased estimator, computed as \f$\frac{1}{N-1} \sum\limits_{k=1}^{N} (x_k - \bar x)^2 \f$.
       - \c 2: Least median of squares.
       - \c 3: Least trimmed of squares.
    **/
    Tdouble variance(const unsigned int variance_method=1) const {
      Tdouble foo;
      return variance_mean(variance_method,foo);
    }

    //! Return the variance as well as the average of the pixel values.
    /**
       \param variance_method Method used to estimate the variance (see variance(const unsigned int) const).
       \param[out] mean Average pixel value.
    **/
    template<typename t>
    Tdouble variance_mean(const unsigned int variance_method, t& mean) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "variance_mean(): Empty instance.",
                                    cimg_instance);

      Tdouble variance = 0, average = 0;
      const unsigned long siz = size();
      switch (variance_method) {
      case 0 :{ // Least mean square (standard definition)
        Tdouble S = 0, S2 = 0;
        cimg_for(*this,ptrs,T) { const Tdouble val = (Tdouble)*ptrs; S+=val; S2+=val*val; }
        variance = (S2 - S*S/siz)/siz;
        average = S;
      } break;
      case 1 : { // Least mean square (robust definition)
        Tdouble S = 0, S2 = 0;
        cimg_for(*this,ptrs,T) { const Tdouble val = (Tdouble)*ptrs; S+=val; S2+=val*val; }
        variance = siz>1?(S2 - S*S/siz)/(siz - 1):0;
        average = S;
      } break;
      case 2 : { // Least Median of Squares (MAD)
        CImg<Tfloat> buf(*this,false);
        buf.sort();
        const unsigned long siz2 = siz>>1;
        const Tdouble med_i = (double)buf[siz2];
        cimg_for(buf,ptrs,Tfloat) { const Tdouble val = (Tdouble)*ptrs; *ptrs = (Tfloat)cimg::abs(val - med_i); average+=val; }
        buf.sort();
        const Tdouble sig = (Tdouble)(1.4828*buf[siz2]);
        variance = sig*sig;
      } break;
      default : { // Least trimmed of Squares
        CImg<Tfloat> buf(*this,false);
        const unsigned long siz2 = siz>>1;
        cimg_for(buf,ptrs,Tfloat) { const Tdouble val = (Tdouble)*ptrs; (*ptrs)=(Tfloat)((*ptrs)*val); average+=val; }
        buf.sort();
        Tdouble a = 0;
        const Tfloat *ptrs = buf._data;
        for (unsigned long j = 0; j<siz2; ++j) a+=(Tdouble)*(ptrs++);
        const Tdouble sig = (Tdouble)(2.6477*std::sqrt(a/siz2));
        variance = sig*sig;
      }
      }
      mean = (t)(average/siz);
      return variance>0?variance:0;
    }

    //! Return estimated variance of the noise.
    /**
       \param variance_method Method used to compute the variance (see variance(const unsigned int) const).
       \note Because of structures such as edges in images it is
       recommanded to use a robust variance estimation. The variance of the
       noise is estimated by computing the variance of the Laplacian \f$(\Delta
       I)^2 \f$ scaled by a factor \f$c\f$ insuring \f$ c E[(\Delta I)^2]=
       \sigma^2\f$ where \f$\sigma\f$ is the noise variance.
    **/
    Tdouble variance_noise(const unsigned int variance_method=2) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "variance_noise(): Empty instance.",
                                    cimg_instance);

      const unsigned long siz = size();
      if (!siz || !_data) return 0;
      if (variance_method>1) { // Compute a scaled version of the Laplacian.
        CImg<Tdouble> tmp(*this);
        if (_depth==1) {
          const Tdouble cste = 1.0/std::sqrt(20.0); // Depends on how the Laplacian is computed.
          CImg_3x3(I,T);
          cimg_forC(*this,c) cimg_for3x3(*this,x,y,0,c,I,T) {
            tmp(x,y,c) = cste*((Tdouble)Inc + (Tdouble)Ipc + (Tdouble)Icn +
                               (Tdouble)Icp - 4*(Tdouble)Icc);
          }
        } else {
          const Tdouble cste = 1.0/std::sqrt(42.0); // Depends on how the Laplacian is computed.
          CImg_3x3x3(I,T);
          cimg_forC(*this,c) cimg_for3x3x3(*this,x,y,z,c,I,T) {
            tmp(x,y,z,c) = cste*(
                                 (Tdouble)Incc + (Tdouble)Ipcc + (Tdouble)Icnc + (Tdouble)Icpc +
                                 (Tdouble)Iccn + (Tdouble)Iccp - 6*(Tdouble)Iccc);
          }
        }
        return tmp.variance(variance_method);
      }

      // Version that doesn't need intermediate images.
      Tdouble variance = 0, S = 0, S2 = 0;
      if (_depth==1) {
        const Tdouble cste = 1.0/std::sqrt(20.0);
        CImg_3x3(I,T);
        cimg_forC(*this,c) cimg_for3x3(*this,x,y,0,c,I,T) {
          const Tdouble val = cste*((Tdouble)Inc + (Tdouble)Ipc +
                                    (Tdouble)Icn + (Tdouble)Icp - 4*(Tdouble)Icc);
          S+=val; S2+=val*val;
        }
      } else {
        const Tdouble cste = 1.0/std::sqrt(42.0);
        CImg_3x3x3(I,T);
        cimg_forC(*this,c) cimg_for3x3x3(*this,x,y,z,c,I,T) {
          const Tdouble val = cste *
            ((Tdouble)Incc + (Tdouble)Ipcc + (Tdouble)Icnc +
             (Tdouble)Icpc +
             (Tdouble)Iccn + (Tdouble)Iccp - 6*(Tdouble)Iccc);
          S+=val; S2+=val*val;
        }
      }
      if (variance_method) variance = siz>1?(S2 - S*S/siz)/(siz - 1):0;
      else variance = (S2 - S*S/siz)/siz;
      return variance>0?variance:0;
    }

    //! Compute the MSE (Mean-Squared Error) between two images.
    /**
       \param img Image used as the second argument of the MSE operator.
    **/
    template<typename t>
    Tdouble MSE(const CImg<t>& img) const {
      if (img.size()!=size())
        throw CImgArgumentException(_cimg_instance
                                    "MSE(): Instance and specified image (%u,%u,%u,%u,%p) have different dimensions.",
                                    cimg_instance,
                                    img._width,img._height,img._depth,img._spectrum,img._data);
      Tdouble vMSE = 0;
      const t* ptr2 = img._data;
      cimg_for(*this,ptr1,T) {
        const Tdouble diff = (Tdouble)*ptr1 - (Tdouble)*(ptr2++);
        vMSE+=diff*diff;
      }
      const unsigned long siz = img.size();
      if (siz) vMSE/=siz;
      return vMSE;
    }

    //! Compute the PSNR (Peak Signal-to-Noise Ratio) between two images.
    /**
       \param img Image used as the second argument of the PSNR operator.
       \param max_value Maximum theoretical value of the signal.
     **/
    template<typename t>
    Tdouble PSNR(const CImg<t>& img, const Tdouble max_value=255) const {
      const Tdouble vMSE = (Tdouble)std::sqrt(MSE(img));
      return (vMSE!=0)?(Tdouble)(20*std::log10(max_value/vMSE)):(Tdouble)(cimg::type<Tdouble>::max());
    }

    //! Evaluate math formula.
    /**
       \param expression Math formula, as a C-string.
       \param x Value of the pre-defined variable \c x.
       \param y Value of the pre-defined variable \c y.
       \param z Value of the pre-defined variable \c z.
       \param c Value of the pre-defined variable \c c.
    **/
    double eval(const char *const expression, const double x=0, const double y=0, const double z=0, const double c=0) const {
      if (!expression) return 0;
      return _cimg_math_parser(*this,expression,"eval").eval(x,y,z,c);
    }

    //! Evaluate math formula on a set of variables.
    /**
       \param expression Math formula, as a C-string.
       \param xyzc Set of values (x,y,z,c) used for the evaluation.
    **/
    template<typename t>
    CImg<doubleT> eval(const char *const expression, const CImg<t>& xyzc) const {
      CImg<doubleT> res(1,xyzc.size()/4);
      if (!expression) return res.fill(0);
      _cimg_math_parser mp(*this,expression,"eval");
      const t *ps = xyzc._data;
      double x, y, z, c;
      cimg_for(res,pd,double) {
        x = (double)*(ps++); y = (double)*(ps++); z = (double)*(ps++); c = (double)*(ps++);
        *pd = mp.eval(x,y,z,c);
      }
      return res;
    }

    //! Compute statistics vector from the pixel values.
    /*
       \param variance_method Method used to compute the variance (see variance(const unsigned int) const).
       \return Statistics vector as <tt>[min; max; mean; variance; xmin; ymin; zmin; cmin; xmax; ymax; zmax; cmax]</tt>.
    **/
    CImg<Tdouble> get_stats(const unsigned int variance_method=1) const {
      if (is_empty()) return CImg<doubleT>();
      const unsigned long siz = size();
      const T *const odata = _data;
      const T *pm = odata, *pM = odata;
      Tdouble S = 0, S2 = 0;
      T m = *pm, M = m;
      cimg_for(*this,ptrs,T) {
        const T val = *ptrs;
        const Tdouble _val = (Tdouble)val;
        if (val<m) { m = val; pm = ptrs; }
        if (val>M) { M = val; pM = ptrs; }
        S+=_val;
        S2+=_val*_val;
      }
      const Tdouble
        mean_value = S/siz,
        _variance_value = variance_method==0?(S2 - S*S/siz)/siz:
        (variance_method==1?(siz>1?(S2 - S*S/siz)/(siz - 1):0):
         variance(variance_method)),
        variance_value = _variance_value>0?_variance_value:0;
      int
        xm = 0, ym = 0, zm = 0, cm = 0,
        xM = 0, yM = 0, zM = 0, cM = 0;
      contains(*pm,xm,ym,zm,cm);
      contains(*pM,xM,yM,zM,cM);
      return CImg<Tdouble>(1,12).fill((Tdouble)m,(Tdouble)M,mean_value,variance_value,
                                      (Tdouble)xm,(Tdouble)ym,(Tdouble)zm,(Tdouble)cm,
                                      (Tdouble)xM,(Tdouble)yM,(Tdouble)zM,(Tdouble)cM);
    }

    //! Compute statistics vector from the pixel values \inplace.
    CImg<T>& stats(const unsigned int variance_method=1) {
      return get_stats(variance_method).move_to(*this);
    }

    //@}
    //-------------------------------------
    //
    //! \name Vector / Matrix Operations
    //@{
    //-------------------------------------

    //! Compute norm of the image, viewed as a matrix.
    /**
       \param magnitude_type Norm type. Can be:
       - \c -1: Linf-norm
       - \c 0: L2-norm
       - \c 1: L1-norm
    **/
    Tdouble magnitude(const int magnitude_type=2) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "magnitude(): Empty instance.",
                                    cimg_instance);
      Tdouble res = 0;
      switch (magnitude_type) {
      case -1 : {
        cimg_for(*this,ptrs,T) { const Tdouble val = (Tdouble)cimg::abs(*ptrs); if (val>res) res = val; }
      } break;
      case 1 : {
        cimg_for(*this,ptrs,T) res+=(Tdouble)cimg::abs(*ptrs);
      } break;
      default : {
        cimg_for(*this,ptrs,T) res+=(Tdouble)cimg::sqr(*ptrs);
        res = (Tdouble)std::sqrt(res);
      }
      }
      return res;
    }

    //! Compute the trace of the image, viewed as a matrix.
    /**
     **/
    Tdouble trace() const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "trace(): Empty instance.",
                                    cimg_instance);
      Tdouble res = 0;
      cimg_forX(*this,k) res+=(Tdouble)(*this)(k,k);
      return res;
    }

    //! Compute the determinant of the image, viewed as a matrix.
    /**
     **/
    Tdouble det() const {
      if (is_empty() || _width!=_height || _depth!=1 || _spectrum!=1)
        throw CImgInstanceException(_cimg_instance
                                    "det(): Instance is not a square matrix.",
                                    cimg_instance);

      switch (_width) {
      case 1 : return (Tdouble)((*this)(0,0));
      case 2 : return (Tdouble)((*this)(0,0))*(Tdouble)((*this)(1,1)) - (Tdouble)((*this)(0,1))*(Tdouble)((*this)(1,0));
      case 3 : {
        const Tdouble
          a = (Tdouble)_data[0], d = (Tdouble)_data[1], g = (Tdouble)_data[2],
          b = (Tdouble)_data[3], e = (Tdouble)_data[4], h = (Tdouble)_data[5],
          c = (Tdouble)_data[6], f = (Tdouble)_data[7], i = (Tdouble)_data[8];
        return i*a*e - a*h*f - i*b*d + b*g*f + c*d*h - c*g*e;
      }
      default : {
        CImg<Tfloat> lu(*this);
        CImg<uintT> indx;
        bool d;
        lu._LU(indx,d);
        Tdouble res = d?(Tdouble)1:(Tdouble)-1;
        cimg_forX(lu,i) res*=lu(i,i);
        return res;
      }
      }
      return 0;
    }

    //! Compute the dot product between instance and argument, viewed as matrices.
    /**
       \param img Image used as a second argument of the dot product.
    **/
    template<typename t>
    Tdouble dot(const CImg<t>& img) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "dot(): Empty instance.",
                                    cimg_instance);
      if (!img)
        throw CImgArgumentException(_cimg_instance
                                    "dot(): Empty specified image.",
                                    cimg_instance);

      const unsigned int nb = cimg::min(size(),img.size());
      Tdouble res = 0;
      for (unsigned int off = 0; off<nb; ++off) res+=(Tdouble)_data[off]*(Tdouble)img[off];
      return res;
    }

    //! Get vector-valued pixel located at specified position.
    /**
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
    **/
    CImg<T> get_vector_at(const unsigned int x, const unsigned int y=0, const unsigned int z=0) const {
      CImg<T> res;
      if (res._height!=_spectrum) res.assign(1,_spectrum);
      const unsigned long whd = (unsigned long)_width*_height*_depth;
      const T *ptrs = data(x,y,z);
      T *ptrd = res._data;
      cimg_forC(*this,c) { *(ptrd++) = *ptrs; ptrs+=whd; }
      return res;
    }

    //! Get (square) matrix-valued pixel located at specified position.
    /**
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \note - The spectrum() of the image must be a square.
     **/
    CImg<T> get_matrix_at(const unsigned int x=0, const unsigned int y=0, const unsigned int z=0) const {
      const int n = (int)std::sqrt((double)_spectrum);
      const T *ptrs = data(x,y,z,0);
      const unsigned long whd = (unsigned long)_width*_height*_depth;
      CImg<T> res(n,n);
      T *ptrd = res._data;
      cimg_forC(*this,c) { *(ptrd++) = *ptrs; ptrs+=whd; }
      return res;
    }

    //! Get tensor-valued pixel located at specified position.
    /**
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
    **/
    CImg<T> get_tensor_at(const unsigned int x, const unsigned int y=0, const unsigned int z=0) const {
      const T *ptrs = data(x,y,z,0);
      const unsigned long whd = (unsigned long)_width*_height*_depth;
      if (_spectrum==6) return tensor(*ptrs,*(ptrs+whd),*(ptrs+2*whd),*(ptrs+3*whd),*(ptrs+4*whd),*(ptrs+5*whd));
      if (_spectrum==3) return tensor(*ptrs,*(ptrs+whd),*(ptrs+2*whd));
      return tensor(*ptrs);
    }

    //! Set vector-valued pixel at specified position.
    /**
       \param vec Vector to put on the instance image.
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
    **/
    template<typename t>
    CImg<T>& set_vector_at(const CImg<t>& vec, const unsigned int x, const unsigned int y=0, const unsigned int z=0) {
      if (x<_width && y<_height && z<_depth) {
        const t *ptrs = vec._data;
        const unsigned long whd = (unsigned long)_width*_height*_depth;
        T *ptrd = data(x,y,z);
        for (unsigned int k = cimg::min((unsigned int)vec.size(),_spectrum); k; --k) { *ptrd = (T)*(ptrs++); ptrd+=whd; }
      }
      return *this;
    }

    //! Set (square) matrix-valued pixel at specified position.
    /**
       \param mat Matrix to put on the instance image.
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
    **/
    template<typename t>
    CImg<T>& set_matrix_at(const CImg<t>& mat, const unsigned int x=0, const unsigned int y=0, const unsigned int z=0) {
      return set_vector_at(mat,x,y,z);
    }

    //! Set tensor-valued pixel at specified position.
    /**
       \param ten Tensor to put on the instance image.
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
    **/
    template<typename t>
    CImg<T>& set_tensor_at(const CImg<t>& ten, const unsigned int x=0, const unsigned int y=0, const unsigned int z=0) {
      T *ptrd = data(x,y,z,0);
      const unsigned long siz = (unsigned long)_width*_height*_depth;
      if (ten._height==2) {
        *ptrd = (T)ten[0]; ptrd+=siz;
        *ptrd = (T)ten[1]; ptrd+=siz;
        *ptrd = (T)ten[3];
      }
      else {
        *ptrd = (T)ten[0]; ptrd+=siz;
        *ptrd = (T)ten[1]; ptrd+=siz;
        *ptrd = (T)ten[2]; ptrd+=siz;
        *ptrd = (T)ten[4]; ptrd+=siz;
        *ptrd = (T)ten[5]; ptrd+=siz;
        *ptrd = (T)ten[8];
      }
      return *this;
    }

    //! Unroll pixel values along axis \c y.
    /**
       \note Equivalent to \code unroll('y'); \endcode.
    **/
    CImg<T>& vector() {
      return unroll('y');
    }

    //! Unroll pixel values along axis \c y \newinstance.
    CImg<T> get_vector() const {
      return get_unroll('y');
    }

    //! Resize image to become a scalar square matrix.
    /**
     **/
    CImg<T>& matrix() {
      const unsigned long siz = size();
      switch (siz) {
      case 1 : break;
      case 4 : _width = _height = 2; break;
      case 9 : _width = _height = 3; break;
      case 16 : _width = _height = 4; break;
      case 25 : _width = _height = 5; break;
      case 36 : _width = _height = 6; break;
      case 49 : _width = _height = 7; break;
      case 64 : _width = _height = 8; break;
      case 81 : _width = _height = 9; break;
      case 100 : _width = _height = 10; break;
      default : {
        unsigned long i = 11, i2 = i*i;
        while (i2<siz) { i2+=2*i + 1; ++i; }
        if (i2==siz) _width = _height = i;
        else throw CImgInstanceException(_cimg_instance
                                         "matrix(): Invalid instance size %u (should be a square integer).",
                                         cimg_instance,
                                         siz);
      }
      }
      return *this;
    }

    //! Resize image to become a scalar square matrix \newinstance.
    CImg<T> get_matrix() const {
      return (+*this).matrix();
    }

    //! Resize image to become a symmetric tensor.
    /**
     **/
    CImg<T>& tensor() {
      return get_tensor().move_to(*this);
    }

    //! Resize image to become a symmetric tensor \newinstance.
    CImg<T> get_tensor() const {
      CImg<T> res;
      const unsigned long siz = size();
      switch (siz) {
      case 1 : break;
      case 3 :
        res.assign(2,2);
        res(0,0) = (*this)(0);
        res(1,0) = res(0,1) = (*this)(1);
        res(1,1) = (*this)(2);
        break;
      case 6 :
        res.assign(3,3);
        res(0,0) = (*this)(0);
        res(1,0) = res(0,1) = (*this)(1);
        res(2,0) = res(0,2) = (*this)(2);
        res(1,1) = (*this)(3);
        res(2,1) = res(1,2) = (*this)(4);
        res(2,2) = (*this)(5);
        break;
      default :
        throw CImgInstanceException(_cimg_instance
                                    "tensor(): Invalid instance size (does not define a 1x1, 2x2 or 3x3 tensor).",
                                    cimg_instance);
      }
      return res;
    }

    //! Resize image to become a diagonal matrix.
    /**
       \note Transform the image as a diagonal matrix so that each of its initial value becomes a diagonal coefficient.
    **/
    CImg<T>& diagonal() {
      return get_diagonal().move_to(*this);
    }

    //! Resize image to become a diagonal matrix \newinstance.
    CImg<T> get_diagonal() const {
      if (is_empty()) return *this;
      CImg<T> res(size(),size(),1,1,0);
      cimg_foroff(*this,off) res(off,off) = (*this)(off);
      return res;
    }

    //! Replace the image by an identity matrix.
    /**
       \note If the instance image is not square, it is resized to a square matrix using its maximum dimension as a reference.
    **/
    CImg<T>& identity_matrix() {
      return identity_matrix(cimg::max(_width,_height)).move_to(*this);
    }

    //! Replace the image by an identity matrix \newinstance.
    CImg<T> get_identity_matrix() const {
      return identity_matrix(cimg::max(_width,_height));
    }

    //! Fill image with a linear sequence of values.
    /**
       \param a0 Starting value of the sequence.
       \param a1 Ending value of the sequence.
    **/
    CImg<T>& sequence(const T a0, const T a1) {
      if (is_empty()) return *this;
      const unsigned int siz = size() - 1;
      T* ptr = _data;
      if (siz) {
        const Tdouble delta = (Tdouble)a1 - (Tdouble)a0;
        cimg_foroff(*this,l) *(ptr++) = (T)(a0 + delta*l/siz);
      } else *ptr = a0;
      return *this;
    }

    //! Fill image with a linear sequence of values \newinstance.
    CImg<T> get_sequence(const T a0, const T a1) const {
      return (+*this).sequence(a0,a1);
    }

    //! Transpose the image, viewed as a matrix.
    /**
       \note Equivalent to \code permute_axes("yxzc"); \endcode
    **/
    CImg<T>& transpose() {
      if (_width==1) { _width = _height; _height = 1; return *this; }
      if (_height==1) { _height = _width; _width = 1; return *this; }
      if (_width==_height) {
        cimg_forYZC(*this,y,z,c) for (int x = y; x<width(); ++x) cimg::swap((*this)(x,y,z,c),(*this)(y,x,z,c));
        return *this;
      }
      return get_transpose().move_to(*this);
    }

    //! Transpose the image, viewed as a matrix \newinstance.
    CImg<T> get_transpose() const {
      return get_permute_axes("yxzc");
    }

    //! Compute the cross product between two \c 1x3 images, viewed as 3d vectors.
    /**
       \param img Image used as the second argument of the cross product.
       \note The first argument of the cross product is \c *this.
     **/
    template<typename t>
    CImg<T>& cross(const CImg<t>& img) {
      if (_width!=1 || _height<3 || img._width!=1 || img._height<3)
        throw CImgInstanceException(_cimg_instance
                                    "cross(): Instance and/or specified image (%u,%u,%u,%u,%p) are not 3d vectors.",
                                    cimg_instance,
                                    img._width,img._height,img._depth,img._spectrum,img._data);

      const T x = (*this)[0], y = (*this)[1], z = (*this)[2];
      (*this)[0] = (T)(y*img[2] - z*img[1]);
      (*this)[1] = (T)(z*img[0] - x*img[2]);
      (*this)[2] = (T)(x*img[1] - y*img[0]);
      return *this;
    }

    //! Compute the cross product between two \c 1x3 images, viewed as 3d vectors \newinstance.
    template<typename t>
    CImg<_cimg_Tt> get_cross(const CImg<t>& img) const {
      return CImg<_cimg_Tt>(*this).cross(img);
    }

    //! Invert the instance image, viewed as a matrix.
    /**
       \param use_LU Choose the inverting algorithm. Can be:
       - \c true: LU-based matrix inversion.
       - \c false: SVD-based matrix inversion.
    **/
    CImg<T>& invert(const bool use_LU=true) {
      if (_width!=_height || _depth!=1 || _spectrum!=1)
        throw CImgInstanceException(_cimg_instance
                                    "invert(): Instance is not a square matrix.",
                                    cimg_instance);
#ifdef cimg_use_lapack
      int INFO = (int)use_LU, N = _width, LWORK = 4*N, *const IPIV = new int[N];
      Tfloat
        *const lapA = new Tfloat[N*N],
        *const WORK = new Tfloat[LWORK];
      cimg_forXY(*this,k,l) lapA[k*N+l] = (Tfloat)((*this)(k,l));
      cimg::getrf(N,lapA,IPIV,INFO);
      if (INFO)
        cimg::warn(_cimg_instance
                   "invert(): LAPACK function dgetrf_() returned error code %d.",
                   cimg_instance,
                   INFO);
      else {
        cimg::getri(N,lapA,IPIV,WORK,LWORK,INFO);
        if (INFO)
          cimg::warn(_cimg_instance
                     "invert(): LAPACK function dgetri_() returned error code %d.",
                     cimg_instance,
                     INFO);
      }
      if (!INFO) cimg_forXY(*this,k,l) (*this)(k,l) = (T)(lapA[k*N+l]); else fill(0);
      delete[] IPIV; delete[] lapA; delete[] WORK;
#else
# 16361 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      const double dete = _width>3?-1.0:det();
      if (dete!=0.0 && _width==2) {
        const double
          a = _data[0], c = _data[1],
          b = _data[2], d = _data[3];
        _data[0] = (T)(d/dete); _data[1] = (T)(-c/dete);
        _data[2] = (T)(-b/dete); _data[3] = (T)(a/dete);
      } else if (dete!=0.0 && _width==3) {
        const double
          a = _data[0], d = _data[1], g = _data[2],
          b = _data[3], e = _data[4], h = _data[5],
          c = _data[6], f = _data[7], i = _data[8];
        _data[0] = (T)((i*e-f*h)/dete), _data[1] = (T)((g*f-i*d)/dete), _data[2] = (T)((d*h-g*e)/dete);
        _data[3] = (T)((h*c-i*b)/dete), _data[4] = (T)((i*a-c*g)/dete), _data[5] = (T)((g*b-a*h)/dete);
        _data[6] = (T)((b*f-e*c)/dete), _data[7] = (T)((d*c-a*f)/dete), _data[8] = (T)((a*e-d*b)/dete);
      } else {
        if (use_LU) { // LU-based inverse computation
          CImg<Tfloat> A(*this), indx, col(1,_width);
          bool d;
          A._LU(indx,d);
          cimg_forX(*this,j) {
            col.fill(0);
            col(j) = 1;
            col._solve(A,indx);
            cimg_forX(*this,i) (*this)(j,i) = (T)col(i);
          }
        } else { // SVD-based inverse computation
          CImg<Tfloat> U(_width,_width), S(1,_width), V(_width,_width);
          SVD(U,S,V,false);
          U.transpose();
          cimg_forY(S,k) if (S[k]!=0) S[k]=1/S[k];
          S.diagonal();
          *this = V*S*U;
        }
      }
#endif
# 16397 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      return *this;
    }

    //! Invert the instance image, viewed as a matrix \newinstance.
    CImg<Tfloat> get_invert(const bool use_LU=true) const {
      return CImg<Tfloat>(*this,false).invert(use_LU);
    }

    //! Compute the Moore-Penrose pseudo-inverse of the instance image, viewed as a matrix.
    /**
    **/
    CImg<T>& pseudoinvert() {
      return get_pseudoinvert().move_to(*this);
    }

    //! Compute the Moore-Penrose pseudo-inverse of the instance image, viewed as a matrix \newinstance.
    CImg<Tfloat> get_pseudoinvert() const {
      CImg<Tfloat> U, S, V;
      SVD(U,S,V);
      const Tfloat tolerance = (sizeof(Tfloat)<=4?5.96e-8f:1.11e-16f)*cimg::max(_width,_height)*S.max();
      cimg_forX(V,x) {
	const Tfloat s = S(x), invs = s>tolerance?1/s:(Tfloat)0;
	cimg_forY(V,y) V(x,y)*=invs;
      }
      return V*U.transpose();
    }

    //! Solve a system of linear equations.
    /**
       \param A Matrix of the linear system.
       \note Solve \c AX=B where \c B=*this.
    **/
    template<typename t>
    CImg<T>& solve(const CImg<t>& A) {
      if (_width!=1 || _depth!=1 || _spectrum!=1 || _height!=A._height || A._depth!=1 || A._spectrum!=1)
        throw CImgArgumentException(_cimg_instance
                                    "solve(): Instance and specified matrix (%u,%u,%u,%u,%p) have incompatible dimensions.",
                                    cimg_instance,
                                    A._width,A._height,A._depth,A._spectrum,A._data);
      typedef _cimg_Ttfloat Ttfloat;
      if (A._width==A._height) {
#ifdef cimg_use_lapack
        char TRANS = 'N';
        int INFO, N = _height, LWORK = 4*N, *const IPIV = new int[N];
        Ttfloat
          *const lapA = new Ttfloat[N*N],
          *const lapB = new Ttfloat[N],
          *const WORK = new Ttfloat[LWORK];
        cimg_forXY(A,k,l) lapA[k*N+l] = (Ttfloat)(A(k,l));
        cimg_forY(*this,i) lapB[i] = (Ttfloat)((*this)(i));
        cimg::getrf(N,lapA,IPIV,INFO);
        if (INFO)
          cimg::warn(_cimg_instance
                     "solve(): LAPACK library function dgetrf_() returned error code %d.",
                     cimg_instance,
                     INFO);

        if (!INFO) {
          cimg::getrs(TRANS,N,lapA,IPIV,lapB,INFO);
          if (INFO)
            cimg::warn(_cimg_instance
                       "solve(): LAPACK library function dgetrs_() returned error code %d.",
                       cimg_instance,
                       INFO);
        }
        if (!INFO) cimg_forY(*this,i) (*this)(i) = (T)(lapB[i]); else fill(0);
        delete[] IPIV; delete[] lapA; delete[] lapB; delete[] WORK;
#else
# 16465 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        CImg<Ttfloat> lu(A,false);
        CImg<Ttfloat> indx;
        bool d;
        lu._LU(indx,d);
        _solve(lu,indx);
#endif
# 16471 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      } else { // Least-square solution for non-square systems.
#ifdef cimg_use_lapack
	char TRANS = 'N';
        int INFO, N = A._width, M = A._height, LWORK = -1, LDA = M, LDB = M, NRHS = _width;
	Ttfloat WORK_QUERY;
	Ttfloat
	  * const lapA = new Ttfloat[M*N],
	  * const lapB = new Ttfloat[M*NRHS];
	cimg::sgels(TRANS, M, N, NRHS, lapA, LDA, lapB, LDB, &WORK_QUERY, LWORK, INFO);
	LWORK = (int) WORK_QUERY;
	Ttfloat *const WORK = new Ttfloat[LWORK];
        cimg_forXY(A,k,l) lapA[k*M+l] = (Ttfloat)(A(k,l));
        cimg_forXY(*this,k,l) lapB[k*M+l] = (Ttfloat)((*this)(k,l));
	cimg::sgels(TRANS, M, N, NRHS, lapA, LDA, lapB, LDB, WORK, LWORK, INFO);
        if (INFO != 0)
          cimg::warn(_cimg_instance
                     "solve(): LAPACK library function sgels() returned error code %d.",
                     cimg_instance,
                     INFO);
	assign(NRHS, N);
        if (!INFO != 0)
          cimg_forXY(*this,k,l) (*this)(k,l) = (T) lapB[k*M+l];
        else
          assign(A.get_pseudoinvert()*(*this));
        delete[] lapA; delete[] lapB; delete[] WORK;
#else
# 16497 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
	assign(A.get_pseudoinvert()*(*this));
#endif
# 16499 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      }
      return *this;
    }

    //! Solve a system of linear equations \newinstance.
    template<typename t>
    CImg<_cimg_Ttfloat> get_solve(const CImg<t>& A) const {
      return CImg<_cimg_Ttfloat>(*this,false).solve(A);
    }

    template<typename t, typename ti>
    CImg<T>& _solve(const CImg<t>& A, const CImg<ti>& indx) {
      typedef _cimg_Ttfloat Ttfloat;
      const int N = size();
      int ii = -1;
      Ttfloat sum;
      for (int i = 0; i<N; ++i) {
        const int ip = (int)indx[i];
        Ttfloat sum = (*this)(ip);
        (*this)(ip) = (*this)(i);
        if (ii>=0) for (int j = ii; j<=i-1; ++j) sum-=A(j,i)*(*this)(j);
        else if (sum!=0) ii = i;
        (*this)(i) = (T)sum;
      }
      for (int i = N - 1; i>=0; --i) {
        sum = (*this)(i);
        for (int j = i + 1; j<N; ++j) sum-=A(j,i)*(*this)(j);
        (*this)(i) = (T)(sum/A(i,i));
      }
      return *this;
    }

    //! Solve a tridiagonal system of linear equations.
    /**
       \param A Coefficients of the tridiagonal system.
       A is a tridiagonal matrix A = [ b0,c0,0,...; a1,b1,c1,0,... ; ... ; ...,0,aN,bN ],
       stored as a 3 columns matrix
       \note Solve AX=B where \c B=*this, using the Thomas algorithm.
    **/
    template<typename t>
    CImg<T>& solve_tridiagonal(const CImg<t>& A) {
      const unsigned int siz = (int)size();
      if (A._width!=3 || A._height!=siz)
        throw CImgArgumentException(_cimg_instance
                                    "solve_tridiagonal(): Instance and tridiagonal matrix "
                                    "(%u,%u,%u,%u,%p) have incompatible dimensions.",
                                    cimg_instance,
                                    A._width,A._height,A._depth,A._spectrum,A._data);
      typedef _cimg_Ttfloat Ttfloat;
      const Ttfloat epsilon = 1e-4f;
      CImg<Ttfloat> B = A.get_column(1), V(*this,false);
      for (int i = 1; i<(int)siz; ++i) {
        const Ttfloat m = A(0,i)/(B[i-1]?B[i-1]:epsilon);
        B[i] -= m*A(2,i-1);
        V[i] -= m*V[i-1];
      }
      (*this)[siz-1] = (T)(V[siz-1]/(B[siz-1]?B[siz-1]:epsilon));
      for (int i = (int)siz - 2; i>=0; --i) (*this)[i] = (T)((V[i] - A(2,i)*(*this)[i+1])/(B[i]?B[i]:epsilon));
      return *this;
    }

    //! Solve a tridiagonal system of linear equations \newinstance.
    template<typename t>
    CImg<_cimg_Ttfloat> get_solve_tridiagonal(const CImg<t>& A) const {
      return CImg<_cimg_Ttfloat>(*this,false).solve_tridiagonal(A);
    }

    //! Compute eigenvalues and eigenvectors of the instance image, viewed as a matrix.
    /**
       \param[out] val Vector of the estimated eigenvalues, in decreasing order.
       \param[out] vec Matrix of the estimated eigenvalues, sorted by columns.
    **/
    template<typename t>
    const CImg<T>& eigen(CImg<t>& val, CImg<t> &vec) const {
      if (is_empty()) { val.assign(); vec.assign(); }
      else {
        if (_width!=_height || _depth>1 || _spectrum>1)
          throw CImgInstanceException(_cimg_instance
                                      "eigen(): Instance is not a square matrix.",
                                      cimg_instance);

        if (val.size()<(unsigned long)_width) val.assign(1,_width);
        if (vec.size()<(unsigned long)_width*_width) vec.assign(_width,_width);
        switch (_width) {
        case 1 : { val[0] = (t)(*this)[0]; vec[0] = (t)1; } break;
        case 2 : {
          const double a = (*this)[0], b = (*this)[1], c = (*this)[2], d = (*this)[3], e = a + d;
          double f = e*e - 4*(a*d - b*c);
          if (f<0)
            cimg::warn(_cimg_instance
                       "eigen(): Complex eigenvalues found.",
                       cimg_instance);

          f = std::sqrt(f);
          const double l1 = 0.5*(e-f), l2 = 0.5*(e+f);
          const double theta1 = std::atan2(l2-a,b), theta2 = std::atan2(l1-a,b);
          val[0] = (t)l2;
          val[1] = (t)l1;
          vec(0,0) = (t)std::cos(theta1);
          vec(0,1) = (t)std::sin(theta1);
          vec(1,0) = (t)std::cos(theta2);
          vec(1,1) = (t)std::sin(theta2);
        } break;
        default :
          throw CImgInstanceException(_cimg_instance
                                      "eigen(): Eigenvalues computation of general matrices is limited to 2x2 matrices.",
                                      cimg_instance);
        }
      }
      return *this;
    }

    //! Compute eigenvalues and eigenvectors of the instance image, viewed as a matrix.
    /**
       \return A list of two images <tt>[val; vec]</tt>, whose meaning is similar as in eigen(CImg<t>&,CImg<t>&) const.
    **/
    CImgList<Tfloat> get_eigen() const {
      CImgList<Tfloat> res(2);
      eigen(res[0],res[1]);
      return res;
    }

    //! Compute eigenvalues and eigenvectors of the instance image, viewed as a symmetric matrix.
    /**
       \param[out] val Vector of the estimated eigenvalues, in decreasing order.
       \param[out] vec Matrix of the estimated eigenvalues, sorted by columns.
    **/
    template<typename t>
    const CImg<T>& symmetric_eigen(CImg<t>& val, CImg<t>& vec) const {
      if (is_empty()) { val.assign(); vec.assign(); }
      else {
#ifdef cimg_use_lapack
        char JOB = 'V', UPLO = 'U';
        int N = _width, LWORK = 4*N, INFO;
        Tfloat
          *const lapA = new Tfloat[N*N],
          *const lapW = new Tfloat[N],
          *const WORK = new Tfloat[LWORK];
        cimg_forXY(*this,k,l) lapA[k*N+l] = (Tfloat)((*this)(k,l));
        cimg::syev(JOB,UPLO,N,lapA,lapW,WORK,LWORK,INFO);
        if (INFO)
          cimg::warn(_cimg_instance
                     "symmetric_eigen(): LAPACK library function dsyev_() returned error code %d.",
                     cimg_instance,
                     INFO);

        val.assign(1,N);
	vec.assign(N,N);
        if (!INFO) {
          cimg_forY(val,i) val(i) = (T)lapW[N-1-i];
          cimg_forXY(vec,k,l) vec(k,l) = (T)(lapA[(N-1-k)*N+l]);
        } else { val.fill(0); vec.fill(0); }
        delete[] lapA; delete[] lapW; delete[] WORK;
#else
# 16653 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        if (_width!=_height || _depth>1 || _spectrum>1)
          throw CImgInstanceException(_cimg_instance
                                      "eigen(): Instance is not a square matrix.",
                                      cimg_instance);

	val.assign(1,_width);
	if (vec._data) vec.assign(_width,_width);
        if (_width<3) {
          eigen(val,vec);
          if (_width==2) { vec[1] = -vec[2]; vec[3] = vec[0]; } // Force orthogonality for 2x2 matrices.
          return *this;
        }
        CImg<t> V(_width,_width);
        SVD(vec,val,V,false);
	bool is_ambiguous = false;
	float eig = 0;
	cimg_forY(val,p) {       // check for ambiguous cases.
	  if (val[p]>eig) eig = (float)val[p];
          t scal = 0;
          cimg_forY(vec,y) scal+=vec(p,y)*V(p,y);
          if (cimg::abs(scal)<0.9f) is_ambiguous = true;
          if (scal<0) val[p] = -val[p];
        }
	if (is_ambiguous) {
	  ++(eig*=2);
	  SVD(vec,val,V,false,40,eig);
	  val-=eig;
	}
        CImg<intT> permutations;  // sort eigenvalues in decreasing order
        CImg<t> tmp(_width);
        val.sort(permutations,false);
        cimg_forY(vec,k) {
          cimg_forY(permutations,y) tmp(y) = vec(permutations(y),k);
          std::memcpy(vec.data(0,k),tmp._data,sizeof(t)*_width);
        }
#endif
# 16689 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      }
      return *this;
    }

    //! Compute eigenvalues and eigenvectors of the instance image, viewed as a symmetric matrix.
    /**
       \return A list of two images <tt>[val; vec]</tt>, whose meaning are similar as in symmetric_eigen(CImg<t>&,CImg<t>&) const.
    **/
    CImgList<Tfloat> get_symmetric_eigen() const {
      CImgList<Tfloat> res(2);
      symmetric_eigen(res[0],res[1]);
      return res;
    }

    //! Sort pixel values and get sorting permutations.
    /**
       \param[out] permutations Permutation map used for the sorting.
       \param is_increasing Tells if pixel values are sorted in an increasing (\c true) or decreasing (\c false) way.
    **/
    template<typename t>
    CImg<T>& sort(CImg<t>& permutations, const bool is_increasing=true) {
      permutations.assign(_width,_height,_depth,_spectrum);
      if (is_empty()) return *this;
      cimg_foroff(permutations,off) permutations[off] = (t)off;
      return _quicksort(0,size()-1,permutations,is_increasing,true);
    }

    //! Sort pixel values and get sorting permutations \newinstance.
    template<typename t>
    CImg<T> get_sort(CImg<t>& permutations, const bool is_increasing=true) const {
      return (+*this).sort(permutations,is_increasing);
    }

    //! Sort pixel values.
    /**
       \param is_increasing Tells if pixel values are sorted in an increasing (\c true) or decreasing (\c false) way.
       \param axis Tells if the value sorting must be done along a specific axis. Can be:
       - \c 0: All pixel values are sorted, independently on their initial position.
       - \c 'x': Image columns are sorted, according to the first value in each column.
       - \c 'y': Image rows are sorted, according to the first value in each row.
       - \c 'z': Image slices are sorted, according to the first value in each slice.
       - \c 'c': Image channels are sorted, according to the first value in each channel.
    **/
    CImg<T>& sort(const bool is_increasing=true, const char axis=0) {
      if (is_empty()) return *this;
      CImg<uintT> perm;
      switch (cimg::uncase(axis)) {
      case 0 :
        _quicksort(0,size()-1,perm,is_increasing,false);
        break;
      case 'x' : {
        perm.assign(_width);
        get_crop(0,0,0,0,_width-1,0,0,0).sort(perm,is_increasing);
        CImg<T> img(*this,false);
        cimg_forXYZC(*this,x,y,z,c) (*this)(x,y,z,c) = img(perm[x],y,z,c);
      } break;
      case 'y' : {
        perm.assign(_height);
        get_crop(0,0,0,0,0,_height-1,0,0).sort(perm,is_increasing);
        CImg<T> img(*this,false);
        cimg_forXYZC(*this,x,y,z,c) (*this)(x,y,z,c) = img(x,perm[y],z,c);
      } break;
      case 'z' : {
        perm.assign(_depth);
        get_crop(0,0,0,0,0,0,_depth-1,0).sort(perm,is_increasing);
        CImg<T> img(*this,false);
        cimg_forXYZC(*this,x,y,z,c) (*this)(x,y,z,c) = img(x,y,perm[z],c);
      } break;
      case 'c' : {
        perm.assign(_spectrum);
        get_crop(0,0,0,0,0,0,0,_spectrum-1).sort(perm,is_increasing);
        CImg<T> img(*this,false);
        cimg_forXYZC(*this,x,y,z,c) (*this)(x,y,z,c) = img(x,y,z,perm[c]);
      } break;
      default :
        throw CImgArgumentException(_cimg_instance
                                    "sort(): Invalid specified axis '%c' "
                                    "(should be { x | y | z | c }).",
                                    cimg_instance,axis);
      }
      return *this;
    }

    //! Sort pixel values \newinstance.
    CImg<T> get_sort(const bool is_increasing=true, const char axis=0) const {
      return (+*this).sort(is_increasing,axis);
    }

    template<typename t>
    CImg<T>& _quicksort(const int indm, const int indM, CImg<t>& permutations, const bool is_increasing, const bool is_permutations) {
      if (indm<indM) {
        const int mid = (indm + indM)/2;
        if (is_increasing) {
          if ((*this)[indm]>(*this)[mid]) {
            cimg::swap((*this)[indm],(*this)[mid]); if (is_permutations) cimg::swap(permutations[indm],permutations[mid]);
          }
          if ((*this)[mid]>(*this)[indM]) {
            cimg::swap((*this)[indM],(*this)[mid]); if (is_permutations) cimg::swap(permutations[indM],permutations[mid]);
          }
          if ((*this)[indm]>(*this)[mid]) {
            cimg::swap((*this)[indm],(*this)[mid]); if (is_permutations) cimg::swap(permutations[indm],permutations[mid]);
          }
        } else {
          if ((*this)[indm]<(*this)[mid]) {
            cimg::swap((*this)[indm],(*this)[mid]); if (is_permutations) cimg::swap(permutations[indm],permutations[mid]);
          }
          if ((*this)[mid]<(*this)[indM]) {
            cimg::swap((*this)[indM],(*this)[mid]); if (is_permutations) cimg::swap(permutations[indM],permutations[mid]);
          }
          if ((*this)[indm]<(*this)[mid]) {
            cimg::swap((*this)[indm],(*this)[mid]); if (is_permutations) cimg::swap(permutations[indm],permutations[mid]);
          }
        }
        if (indM - indm>=3) {
          const T pivot = (*this)[mid];
          int i = indm, j = indM;
          if (is_increasing) {
            do {
              while ((*this)[i]<pivot) ++i;
              while ((*this)[j]>pivot) --j;
              if (i<=j) {
                if (is_permutations) cimg::swap(permutations[i],permutations[j]);
                cimg::swap((*this)[i++],(*this)[j--]);
              }
            } while (i<=j);
          } else {
            do {
              while ((*this)[i]>pivot) ++i;
              while ((*this)[j]<pivot) --j;
              if (i<=j) {
                if (is_permutations) cimg::swap(permutations[i],permutations[j]);
                cimg::swap((*this)[i++],(*this)[j--]);
              }
            } while (i<=j);
          }
          if (indm<j) _quicksort(indm,j,permutations,is_increasing,is_permutations);
          if (i<indM) _quicksort(i,indM,permutations,is_increasing,is_permutations);
        }
      }
      return *this;
    }

    //! Compute the SVD of the instance image, viewed as a general matrix.
    /**
       Compute the SVD decomposition \c *this=U*S*V' where \c U and \c V are orthogonal matrices
       and \c S is a diagonal matrix. \c V' denotes the matrix transpose of \c V.
       \param[out] U First matrix of the SVD product.
       \param[out] S Coefficients of the second (diagonal) matrix of the SVD product. These coefficients are stored as a vector.
       \param[out] V Third matrix of the SVD product.
       \param sorting Tells if the diagonal coefficients are sorted (in decreasing order).
       \param max_iteration Maximum number of iterations considered for the algorithm convergence.
       \param lambda Epsilon used for the algorithm convergence.
       \note The instance matrix can be computed from \c U,\c S and \c V by
       \code
       const CImg<> A;  // Input matrix (assumed to contain some values).
       CImg<> U,S,V;
       A.SVD(U,S,V)
       \endcode
    **/
    template<typename t>
    const CImg<T>& SVD(CImg<t>& U, CImg<t>& S, CImg<t>& V, const bool sorting=true,
                       const unsigned int max_iteration=40, const float lambda=0) const {
      if (is_empty()) { U.assign(); S.assign(); V.assign(); }
      else {
        U = *this;
	if (lambda!=0) {
	  const unsigned int delta = cimg::min(U._width,U._height);
	  for (unsigned int i = 0; i<delta; ++i) U(i,i) = (t)(U(i,i) + lambda);
	}
        if (S.size()<_width) S.assign(1,_width);
        if (V._width<_width || V._height<_height) V.assign(_width,_width);
        CImg<t> rv1(_width);
        t anorm = 0, c, f, g = 0, h, s, scale = 0;
        int l = 0, nm = 0;

        cimg_forX(U,i) {
          l = i+1; rv1[i] = scale*g; g = s = scale = 0;
          if (i<height()) {
            for (int k = i; k<height(); ++k) scale+= cimg::abs(U(i,k));
            if (scale) {
              for (int k = i; k<height(); ++k) { U(i,k)/=scale; s+= U(i,k)*U(i,k); }
              f = U(i,i); g = (t)((f>=0?-1:1)*std::sqrt(s)); h=f*g-s; U(i,i) = f-g;
              for (int j = l; j<width(); ++j) {
                s = 0;
                for (int k=i; k<height(); ++k) s+= U(i,k)*U(j,k);
                f = s/h;
                for (int k = i; k<height(); ++k) U(j,k)+= f*U(i,k);
              }
              for (int k = i; k<height(); ++k) U(i,k)*= scale;
            }
          }
          S[i]=scale*g;

          g = s = scale = 0;
          if (i<height() && i!=width()-1) {
            for (int k = l; k<width(); ++k) scale+=cimg::abs(U(k,i));
            if (scale) {
              for (int k = l; k<width(); ++k) { U(k,i)/= scale; s+= U(k,i)*U(k,i); }
              f = U(l,i); g = (t)((f>=0?-1:1)*std::sqrt(s)); h = f*g-s; U(l,i) = f-g;
              for (int k = l; k<width(); ++k) rv1[k]=U(k,i)/h;
              for (int j = l; j<height(); ++j) {
                s = 0;
                for (int k = l; k<width(); ++k) s+= U(k,j)*U(k,i);
                for (int k = l; k<width(); ++k) U(k,j)+= s*rv1[k];
              }
              for (int k = l; k<width(); ++k) U(k,i)*= scale;
            }
          }
          anorm = (t)cimg::max((float)anorm,(float)(cimg::abs(S[i])+cimg::abs(rv1[i])));
        }

        for (int i = width()-1; i>=0; --i) {
          if (i<width()-1) {
            if (g) {
              for (int j = l; j<width(); ++j) V(i,j) =(U(j,i)/U(l,i))/g;
              for (int j = l; j<width(); ++j) {
                s = 0;
                for (int k = l; k<width(); ++k) s+= U(k,i)*V(j,k);
                for (int k = l; k<width(); ++k) V(j,k)+= s*V(i,k);
              }
            }
            for (int j = l; j<width(); ++j) V(j,i) = V(i,j) = (t)0.0;
          }
          V(i,i) = (t)1.0; g = rv1[i]; l = i;
        }

        for (int i = cimg::min(width(),height())-1; i>=0; --i) {
          l = i+1; g = S[i];
          for (int j = l; j<width(); ++j) U(j,i) = 0;
          if (g) {
            g = 1/g;
            for (int j = l; j<width(); ++j) {
              s = 0; for (int k = l; k<height(); ++k) s+= U(i,k)*U(j,k);
              f = (s/U(i,i))*g;
              for (int k = i; k<height(); ++k) U(j,k)+= f*U(i,k);
            }
            for (int j = i; j<height(); ++j) U(i,j)*= g;
          } else for (int j = i; j<height(); ++j) U(i,j) = 0;
          ++U(i,i);
        }

        for (int k = width()-1; k>=0; --k) {
          for (unsigned int its = 0; its<max_iteration; ++its) {
            bool flag = true;
            for (l = k; l>=1; --l) {
              nm = l-1;
              if ((cimg::abs(rv1[l])+anorm)==anorm) { flag = false; break; }
              if ((cimg::abs(S[nm])+anorm)==anorm) break;
            }
            if (flag) {
              c = 0; s = 1;
              for (int i = l; i<=k; ++i) {
                f = s*rv1[i]; rv1[i] = c*rv1[i];
                if ((cimg::abs(f)+anorm)==anorm) break;
                g = S[i]; h = (t)cimg::_pythagore(f,g); S[i] = h; h = 1/h; c = g*h; s = -f*h;
                cimg_forY(U,j) { const t y = U(nm,j), z = U(i,j); U(nm,j) = y*c + z*s; U(i,j) = z*c - y*s; }
              }
            }
            const t z = S[k];
            if (l==k) { if (z<0) { S[k] = -z; cimg_forX(U,j) V(k,j) = -V(k,j); } break; }
            nm = k-1;
            t x = S[l], y = S[nm];
            g = rv1[nm]; h = rv1[k];
            f = ((y-z)*(y+z)+(g-h)*(g+h))/(2*h*y);
            g = (t)cimg::_pythagore(f,1.0);
            f = ((x-z)*(x+z)+h*((y/(f+ (f>=0?g:-g)))-h))/x;
            c = s = 1;
            for (int j = l; j<=nm; ++j) {
              const int i = j+1;
              g = rv1[i]; h = s*g; g = c*g;
              t y = S[i];
              t z = (t)cimg::_pythagore(f,h);
              rv1[j] = z; c = f/z; s = h/z;
              f = x*c+g*s; g = g*c-x*s; h = y*s; y*=c;
              cimg_forX(U,jj) { const t x = V(j,jj), z = V(i,jj); V(j,jj) = x*c + z*s; V(i,jj) = z*c - x*s; }
              z = (t)cimg::_pythagore(f,h); S[j] = z;
              if (z) { z = 1/z; c = f*z; s = h*z; }
              f = c*g+s*y; x = c*y-s*g;
              cimg_forY(U,jj) { const t y = U(j,jj); z = U(i,jj); U(j,jj) = y*c + z*s; U(i,jj) = z*c - y*s; }
            }
            rv1[l] = 0; rv1[k]=f; S[k]=x;
          }
        }

        if (sorting) {
          CImg<intT> permutations;
          CImg<t> tmp(_width);
          S.sort(permutations,false);
          cimg_forY(U,k) {
            cimg_forY(permutations,y) tmp(y) = U(permutations(y),k);
            std::memcpy(U.data(0,k),tmp._data,sizeof(t)*_width);
          }
          cimg_forY(V,k) {
            cimg_forY(permutations,y) tmp(y) = V(permutations(y),k);
            std::memcpy(V.data(0,k),tmp._data,sizeof(t)*_width);
          }
        }
      }
      return *this;
    }

    //! Compute the SVD of the instance image, viewed as a general matrix.
    /**
       \return A list of three images <tt>[U; S; V]</tt>, whose meaning is similar as in SVD(CImg<t>&,CImg<t>&,CImg<t>&,bool,unsigned int,float) const.
    **/
    CImgList<Tfloat> get_SVD(const bool sorting=true,
                             const unsigned int max_iteration=40, const float lambda=0) const {
      CImgList<Tfloat> res(3);
      SVD(res[0],res[1],res[2],sorting,max_iteration,lambda);
      return res;
    }

    // [internal] Compute the LU decomposition of a permuted matrix.
    template<typename t>
    CImg<T>& _LU(CImg<t>& indx, bool& d) {
      const int N = width();
      int imax = 0;
      CImg<Tfloat> vv(N);
      indx.assign(N);
      d = true;
      cimg_forX(*this,i) {
        Tfloat vmax = 0;
        cimg_forX(*this,j) {
          const Tfloat tmp = cimg::abs((*this)(j,i));
          if (tmp>vmax) vmax = tmp;
        }
        if (vmax==0) { indx.fill(0); return fill(0); }
        vv[i] = 1/vmax;
      }
      cimg_forX(*this,j) {
        for (int i = 0; i<j; ++i) {
          Tfloat sum=(*this)(j,i);
          for (int k = 0; k<i; ++k) sum-=(*this)(k,i)*(*this)(j,k);
          (*this)(j,i) = (T)sum;
        }
        Tfloat vmax = 0;
        for (int i = j; i<width(); ++i) {
          Tfloat sum=(*this)(j,i);
          for (int k = 0; k<j; ++k) sum-=(*this)(k,i)*(*this)(j,k);
          (*this)(j,i) = (T)sum;
          const Tfloat tmp = vv[i]*cimg::abs(sum);
          if (tmp>=vmax) { vmax=tmp; imax=i; }
        }
        if (j!=imax) {
          cimg_forX(*this,k) cimg::swap((*this)(k,imax),(*this)(k,j));
          d =!d;
          vv[imax] = vv[j];
        }
        indx[j] = (t)imax;
        if ((*this)(j,j)==0) (*this)(j,j) = (T)1e-20;
        if (j<N) {
          const Tfloat tmp = 1/(Tfloat)(*this)(j,j);
          for (int i=j+1; i<N; ++i) (*this)(j,i) = (T)((*this)(j,i)*tmp);
        }
      }
      return *this;
    }

    //! Compute minimal path in a graph, using the Dijkstra algorithm.
    /**
       \param distance An object having operator()(unsigned int i, unsigned int j) which returns distance between two nodes (i,j).
       \param nb_nodes Number of graph nodes.
       \param starting_node Indice of the starting node.
       \param ending_node Indice of the ending node (set to ~0U to ignore ending node).
       \param previous_node Array that gives the previous node indice in the path to the starting node (optional parameter).
       \return Array of distances of each node to the starting node.
    **/
    template<typename tf, typename t>
    static CImg<T> dijkstra(const tf& distance, const unsigned int nb_nodes,
                            const unsigned int starting_node, const unsigned int ending_node,
                            CImg<t>& previous_node) {
      if (starting_node>=nb_nodes)
        throw CImgArgumentException("CImg<%s>::dijkstra(): Specified indice of starting node %u is higher than number of nodes %u.",
                                    pixel_type(),starting_node,nb_nodes);
      CImg<T> dist(1,nb_nodes,1,1,cimg::type<T>::max());
      dist(starting_node) = 0;
      previous_node.assign(1,nb_nodes,1,1,(t)-1);
      previous_node(starting_node) = (t)starting_node;
      CImg<uintT> Q(nb_nodes);
      cimg_forX(Q,u) Q(u) = u;
      cimg::swap(Q(starting_node),Q(0));
      unsigned int sizeQ = nb_nodes;
      while (sizeQ) {
        // Update neighbors from minimal vertex
        const unsigned int umin = Q(0);
        if (umin==ending_node) sizeQ = 0;
        else {
          const T dmin = dist(umin);
          const T infty = cimg::type<T>::max();
          for (unsigned int q = 1; q<sizeQ; ++q) {
            const unsigned int v = Q(q);
            const T d = (T)distance(v,umin);
            if (d<infty) {
              const T alt = dmin + d;
              if (alt<dist(v)) {
                dist(v) = alt;
                previous_node(v) = (t)umin;
                const T distpos = dist(Q(q));
                for (unsigned int pos = q, par = 0; pos && distpos<dist(Q(par=(pos+1)/2-1)); pos=par) cimg::swap(Q(pos),Q(par));
              }
            }
          }
          // Remove minimal vertex from queue
          Q(0) = Q(--sizeQ);
          const T distpos = dist(Q(0));
          for (unsigned int pos = 0, left = 0, right = 0;
               ((right=2*(pos+1),(left=right-1))<sizeQ && distpos>dist(Q(left))) || (right<sizeQ && distpos>dist(Q(right)));) {
            if (right<sizeQ) {
              if (dist(Q(left))<dist(Q(right))) { cimg::swap(Q(pos),Q(left)); pos = left; }
              else { cimg::swap(Q(pos),Q(right)); pos = right; }
            } else { cimg::swap(Q(pos),Q(left)); pos = left; }
          }
        }
      }
      return dist;
    }

    //! Return minimal path in a graph, using the Dijkstra algorithm.
    template<typename tf, typename t>
    static CImg<T> dijkstra(const tf& distance, const unsigned int nb_nodes,
                            const unsigned int starting_node, const unsigned int ending_node=~0U) {
      CImg<uintT> foo;
      return dijkstra(distance,nb_nodes,starting_node,ending_node,foo);
    }

    //! Return minimal path in a graph, using the Dijkstra algorithm.
    /**
       \param starting_node Indice of the starting node.
       \param ending_node Indice of the ending node.
       \param previous_node Array that gives the previous node indice in the path to the starting node (optional parameter).
       \return Array of distances of each node to the starting node.
       \note image instance corresponds to the adjacency matrix of the graph.
    **/
    template<typename t>
    CImg<T>& dijkstra(const unsigned int starting_node, const unsigned int ending_node, CImg<t>& previous_node) {
      return get_dijkstra(starting_node,ending_node,previous_node).move_to(*this);
    }

    //! Return minimal path in a graph, using the Dijkstra algorithm \newinstance.
    template<typename t>
    CImg<T> get_dijkstra(const unsigned int starting_node, const unsigned int ending_node, CImg<t>& previous_node) const {
      if (_width!=_height || _depth!=1 || _spectrum!=1)
        throw CImgInstanceException(_cimg_instance
                                    "dijkstra(): Instance is not a graph adjacency matrix.",
                                    cimg_instance);

      return dijkstra(*this,_width,starting_node,ending_node,previous_node);
    }

    //! Return minimal path in a graph, using the Dijkstra algorithm.
    CImg<T>& dijkstra(const unsigned int starting_node, const unsigned int ending_node=~0U) {
      return get_dijkstra(starting_node,ending_node).move_to(*this);
    }

    //! Return minimal path in a graph, using the Dijkstra algorithm \newinstance.
    CImg<Tfloat> get_dijkstra(const unsigned int starting_node, const unsigned int ending_node=~0U) const {
      CImg<uintT> foo;
      return get_dijkstra(starting_node,ending_node,foo);
    }

    //! Return an image containing the ascii codes of the specified  string.
    /**
       \param str input C-string to encode as an image.
       \param is_last_zero Tells if the ending \c '0' character appear in the resulting image.
    **/
    static CImg<T> string(const char *const str, const bool is_last_zero=true) {
      if (!str) return CImg<T>();
      return CImg<T>(str,std::strlen(str)+(is_last_zero?1:0));
    }

    //! Return a \c 1x1 image containing specified value.
    /**
       \param a0 First vector value.
    **/
    static CImg<T> vector(const T& a0) {
      CImg<T> r(1,1);
      r[0] = a0;
      return r;
    }

    //! Return a \c 1x2 image containing specified values.
    /**
       \param a0 First vector value.
       \param a1 Second vector value.
    **/
    static CImg<T> vector(const T& a0, const T& a1) {
      CImg<T> r(1,2); T *ptr = r._data;
      *(ptr++) = a0; *(ptr++) = a1;
      return r;
    }

    //! Return a \c 1x3 image containing specified values.
    /**
       \param a0 First vector value.
       \param a1 Second vector value.
       \param a2 Third vector value.
    **/
    static CImg<T> vector(const T& a0, const T& a1, const T& a2) {
      CImg<T> r(1,3); T *ptr = r._data;
      *(ptr++) = a0; *(ptr++) = a1; *(ptr++) = a2;
      return r;
    }

    //! Return a \c 1x4 image containing specified values.
    /**
       \param a0 First vector value.
       \param a1 Second vector value.
       \param a2 Third vector value.
       \param a3 Fourth vector value.
    **/
    static CImg<T> vector(const T& a0, const T& a1, const T& a2, const T& a3) {
      CImg<T> r(1,4); T *ptr = r._data;
      *(ptr++) = a0; *(ptr++) = a1; *(ptr++) = a2; *(ptr++) = a3;
      return r;
    }

    //! Return a \c 1x5 image containing specified values.
    static CImg<T> vector(const T& a0, const T& a1, const T& a2, const T& a3, const T& a4) {
      CImg<T> r(1,5); T *ptr = r._data;
      *(ptr++) = a0; *(ptr++) = a1; *(ptr++) = a2; *(ptr++) = a3; *(ptr++) = a4;
      return r;
    }

    //! Return a \c 1x6 image containing specified values.
    static CImg<T> vector(const T& a0, const T& a1, const T& a2, const T& a3, const T& a4, const T& a5) {
      CImg<T> r(1,6); T *ptr = r._data;
      *(ptr++) = a0; *(ptr++) = a1; *(ptr++) = a2; *(ptr++) = a3; *(ptr++) = a4; *(ptr++) = a5;
      return r;
    }

    //! Return a \c 1x7 image containing specified values.
    static CImg<T> vector(const T& a0, const T& a1, const T& a2, const T& a3,
			  const T& a4, const T& a5, const T& a6) {
      CImg<T> r(1,7); T *ptr = r._data;
      *(ptr++) = a0; *(ptr++) = a1; *(ptr++) = a2; *(ptr++) = a3;
      *(ptr++) = a4; *(ptr++) = a5; *(ptr++) = a6;
      return r;
    }

    //! Return a \c 1x8 image containing specified values.
    static CImg<T> vector(const T& a0, const T& a1, const T& a2, const T& a3,
			  const T& a4, const T& a5, const T& a6, const T& a7) {
      CImg<T> r(1,8); T *ptr = r._data;
      *(ptr++) = a0; *(ptr++) = a1; *(ptr++) = a2; *(ptr++) = a3;
      *(ptr++) = a4; *(ptr++) = a5; *(ptr++) = a6; *(ptr++) = a7;
      return r;
    }

    //! Return a \c 1x9 image containing specified values.
    static CImg<T> vector(const T& a0, const T& a1, const T& a2, const T& a3,
			  const T& a4, const T& a5, const T& a6, const T& a7,
			  const T& a8) {
      CImg<T> r(1,9); T *ptr = r._data;
      *(ptr++) = a0; *(ptr++) = a1; *(ptr++) = a2; *(ptr++) = a3;
      *(ptr++) = a4; *(ptr++) = a5; *(ptr++) = a6; *(ptr++) = a7;
      *(ptr++) = a8;
      return r;
    }

    //! Return a \c 1x10 image containing specified values.
    static CImg<T> vector(const T& a0, const T& a1, const T& a2, const T& a3,
                          const T& a4, const T& a5, const T& a6, const T& a7,
                          const T& a8, const T& a9) {
      CImg<T> r(1,10); T *ptr = r._data;
      *(ptr++) = a0; *(ptr++) = a1; *(ptr++) = a2; *(ptr++) = a3;
      *(ptr++) = a4; *(ptr++) = a5; *(ptr++) = a6; *(ptr++) = a7;
      *(ptr++) = a8; *(ptr++) = a9;
      return r;
    }

    //! Return a \c 1x11 image containing specified values.
    static CImg<T> vector(const T& a0, const T& a1, const T& a2, const T& a3,
                          const T& a4, const T& a5, const T& a6, const T& a7,
                          const T& a8, const T& a9, const T& a10) {
      CImg<T> r(1,11); T *ptr = r._data;
      *(ptr++) = a0; *(ptr++) = a1; *(ptr++) = a2; *(ptr++) = a3;
      *(ptr++) = a4; *(ptr++) = a5; *(ptr++) = a6; *(ptr++) = a7;
      *(ptr++) = a8; *(ptr++) = a9; *(ptr++) = a10;
      return r;
    }

    //! Return a \c 1x12 image containing specified values.
    static CImg<T> vector(const T& a0, const T& a1, const T& a2, const T& a3,
                          const T& a4, const T& a5, const T& a6, const T& a7,
                          const T& a8, const T& a9, const T& a10, const T& a11) {
      CImg<T> r(1,12); T *ptr = r._data;
      *(ptr++) = a0; *(ptr++) = a1; *(ptr++) = a2; *(ptr++) = a3;
      *(ptr++) = a4; *(ptr++) = a5; *(ptr++) = a6; *(ptr++) = a7;
      *(ptr++) = a8; *(ptr++) = a9; *(ptr++) = a10; *(ptr++) = a11;
      return r;
    }

    //! Return a \c 1x13 image containing specified values.
    static CImg<T> vector(const T& a0, const T& a1, const T& a2, const T& a3,
                          const T& a4, const T& a5, const T& a6, const T& a7,
                          const T& a8, const T& a9, const T& a10, const T& a11,
			  const T& a12) {
      CImg<T> r(1,13); T *ptr = r._data;
      *(ptr++) = a0; *(ptr++) = a1; *(ptr++) = a2; *(ptr++) = a3;
      *(ptr++) = a4; *(ptr++) = a5; *(ptr++) = a6; *(ptr++) = a7;
      *(ptr++) = a8; *(ptr++) = a9; *(ptr++) = a10; *(ptr++) = a11;
      *(ptr++) = a12;
      return r;
    }

    //! Return a \c 1x14 image containing specified values.
    static CImg<T> vector(const T& a0, const T& a1, const T& a2, const T& a3,
                          const T& a4, const T& a5, const T& a6, const T& a7,
                          const T& a8, const T& a9, const T& a10, const T& a11,
			  const T& a12, const T& a13) {
      CImg<T> r(1,14); T *ptr = r._data;
      *(ptr++) = a0; *(ptr++) = a1; *(ptr++) = a2; *(ptr++) = a3;
      *(ptr++) = a4; *(ptr++) = a5; *(ptr++) = a6; *(ptr++) = a7;
      *(ptr++) = a8; *(ptr++) = a9; *(ptr++) = a10; *(ptr++) = a11;
      *(ptr++) = a12; *(ptr++) = a13;
      return r;
    }

    //! Return a \c 1x15 image containing specified values.
    static CImg<T> vector(const T& a0, const T& a1, const T& a2, const T& a3,
                          const T& a4, const T& a5, const T& a6, const T& a7,
                          const T& a8, const T& a9, const T& a10, const T& a11,
			  const T& a12, const T& a13, const T& a14) {
      CImg<T> r(1,15); T *ptr = r._data;
      *(ptr++) = a0; *(ptr++) = a1; *(ptr++) = a2; *(ptr++) = a3;
      *(ptr++) = a4; *(ptr++) = a5; *(ptr++) = a6; *(ptr++) = a7;
      *(ptr++) = a8; *(ptr++) = a9; *(ptr++) = a10; *(ptr++) = a11;
      *(ptr++) = a12; *(ptr++) = a13; *(ptr++) = a14;
      return r;
    }

    //! Return a \c 1x16 image containing specified values.
    static CImg<T> vector(const T& a0, const T& a1, const T& a2, const T& a3,
                          const T& a4, const T& a5, const T& a6, const T& a7,
                          const T& a8, const T& a9, const T& a10, const T& a11,
			  const T& a12, const T& a13, const T& a14, const T& a15) {
      CImg<T> r(1,16); T *ptr = r._data;
      *(ptr++) = a0; *(ptr++) = a1; *(ptr++) = a2; *(ptr++) = a3;
      *(ptr++) = a4; *(ptr++) = a5; *(ptr++) = a6; *(ptr++) = a7;
      *(ptr++) = a8; *(ptr++) = a9; *(ptr++) = a10; *(ptr++) = a11;
      *(ptr++) = a12; *(ptr++) = a13; *(ptr++) = a14; *(ptr++) = a15;
      return r;
    }

    //! Return a 1x1 matrix containing specified coefficients.
    /**
       \param a0 First matrix value.
       \note Equivalent to vector(const T&).
    **/
    static CImg<T> matrix(const T& a0) {
      return vector(a0);
    }

    //! Return a 2x2 matrix containing specified coefficients.
    /**
       \param a0 First matrix value.
       \param a1 Second matrix value.
       \param a2 Third matrix value.
       \param a3 Fourth matrix value.
    **/
    static CImg<T> matrix(const T& a0, const T& a1,
			  const T& a2, const T& a3) {
      CImg<T> r(2,2); T *ptr = r._data;
      *(ptr++) = a0; *(ptr++) = a1;
      *(ptr++) = a2; *(ptr++) = a3;
      return r;
    }

    //! Return a 3x3 matrix containing specified coefficients.
    /**
       \param a0 First matrix value.
       \param a1 Second matrix value.
       \param a2 Third matrix value.
       \param a3 Fourth matrix value.
       \param a4 Fifth matrix value.
       \param a5 Sixth matrix value.
       \param a6 Seventh matrix value.
       \param a7 Eighth matrix value.
       \param a8 Nineth matrix value.
    **/
    static CImg<T> matrix(const T& a0, const T& a1, const T& a2,
			  const T& a3, const T& a4, const T& a5,
			  const T& a6, const T& a7, const T& a8) {
      CImg<T> r(3,3); T *ptr = r._data;
      *(ptr++) = a0; *(ptr++) = a1; *(ptr++) = a2;
      *(ptr++) = a3; *(ptr++) = a4; *(ptr++) = a5;
      *(ptr++) = a6; *(ptr++) = a7; *(ptr++) = a8;
      return r;
    }

    //! Return a 4x4 matrix containing specified coefficients.
    static CImg<T> matrix(const T& a0, const T& a1, const T& a2, const T& a3,
			  const T& a4, const T& a5, const T& a6, const T& a7,
			  const T& a8, const T& a9, const T& a10, const T& a11,
			  const T& a12, const T& a13, const T& a14, const T& a15) {
      CImg<T> r(4,4); T *ptr = r._data;
      *(ptr++) = a0; *(ptr++) = a1; *(ptr++) = a2; *(ptr++) = a3;
      *(ptr++) = a4; *(ptr++) = a5; *(ptr++) = a6; *(ptr++) = a7;
      *(ptr++) = a8; *(ptr++) = a9; *(ptr++) = a10; *(ptr++) = a11;
      *(ptr++) = a12; *(ptr++) = a13; *(ptr++) = a14; *(ptr++) = a15;
      return r;
    }

    //! Return a 5x5 matrix containing specified coefficients.
    static CImg<T> matrix(const T& a0, const T& a1, const T& a2, const T& a3, const T& a4,
                          const T& a5, const T& a6, const T& a7, const T& a8, const T& a9,
                          const T& a10, const T& a11, const T& a12, const T& a13, const T& a14,
                          const T& a15, const T& a16, const T& a17, const T& a18, const T& a19,
                          const T& a20, const T& a21, const T& a22, const T& a23, const T& a24) {
      CImg<T> r(5,5); T *ptr = r._data;
      *(ptr++) = a0; *(ptr++) = a1; *(ptr++) = a2; *(ptr++) = a3; *(ptr++) = a4;
      *(ptr++) = a5; *(ptr++) = a6; *(ptr++) = a7; *(ptr++) = a8; *(ptr++) = a9;
      *(ptr++) = a10; *(ptr++) = a11; *(ptr++) = a12; *(ptr++) = a13; *(ptr++) = a14;
      *(ptr++) = a15; *(ptr++) = a16; *(ptr++) = a17; *(ptr++) = a18; *(ptr++) = a19;
      *(ptr++) = a20; *(ptr++) = a21; *(ptr++) = a22; *(ptr++) = a23; *(ptr++) = a24;
      return r;
    }

    //! Return a 1x1 symmetric matrix containing specified coefficients.
    /**
       \param a0 First matrix value.
       \note Equivalent to vector(const T&).
    **/
    static CImg<T> tensor(const T& a0) {
      return matrix(a0);
    }

    //! Return a 2x2 symmetric matrix tensor containing specified coefficients.
    static CImg<T> tensor(const T& a0, const T& a1, const T& a2) {
      return matrix(a0,a1,a1,a2);
    }

    //! Return a 3x3 symmetric matrix containing specified coefficients.
    static CImg<T> tensor(const T& a0, const T& a1, const T& a2, const T& a3, const T& a4, const T& a5) {
      return matrix(a0,a1,a2,a1,a3,a4,a2,a4,a5);
    }

    //! Return a 1x1 diagonal matrix containing specified coefficients.
    static CImg<T> diagonal(const T& a0) {
      return matrix(a0);
    }

    //! Return a 2x2 diagonal matrix containing specified coefficients.
    static CImg<T> diagonal(const T& a0, const T& a1) {
      return matrix(a0,0,0,a1);
    }

    //! Return a 3x3 diagonal matrix containing specified coefficients.
    static CImg<T> diagonal(const T& a0, const T& a1, const T& a2) {
      return matrix(a0,0,0,0,a1,0,0,0,a2);
    }

    //! Return a 4x4 diagonal matrix containing specified coefficients.
    static CImg<T> diagonal(const T& a0, const T& a1, const T& a2, const T& a3) {
      return matrix(a0,0,0,0,0,a1,0,0,0,0,a2,0,0,0,0,a3);
    }

    //! Return a 5x5 diagonal matrix containing specified coefficients.
    static CImg<T> diagonal(const T& a0, const T& a1, const T& a2, const T& a3, const T& a4) {
      return matrix(a0,0,0,0,0,0,a1,0,0,0,0,0,a2,0,0,0,0,0,a3,0,0,0,0,0,a4);
    }

    //! Return a NxN identity matrix.
    /**
       \param N Dimension of the matrix.
    **/
    static CImg<T> identity_matrix(const unsigned int N) {
      CImg<T> res(N,N,1,1,0);
      cimg_forX(res,x) res(x,x) = 1;
      return res;
    }

    //! Return a N-numbered sequence vector from \p a0 to \p a1.
    /**
       \param N Size of the resulting vector.
       \param a0 Starting value of the sequence.
       \param a1 Ending value of the sequence.
     **/
    static CImg<T> sequence(const unsigned int N, const T a0, const T a1) {
      if (N) return CImg<T>(1,N).sequence(a0,a1);
      return CImg<T>();
    }

    //! Return a 3x3 rotation matrix along the (x,y,z)-axis with an angle w.
    /**
       \param x X-coordinate of the rotation axis, or first quaternion coordinate.
       \param y Y-coordinate of the rotation axis, or second quaternion coordinate.
       \param z Z-coordinate of the rotation axis, or third quaternion coordinate.
       \param w Angle of the rotation axis, or fourth quaternion coordinate.
       \param is_quaternion Tell is the four arguments denotes a set { axis + angle } or a quaternion.
     **/
    static CImg<T> rotation_matrix(const float x, const float y, const float z, const float w, const bool is_quaternion=false) {
      float X,Y,Z,W;
      if (!is_quaternion) {
        const float norm = (float)std::sqrt(x*x + y*y + z*z),
          nx = norm>0?x/norm:0,
          ny = norm>0?y/norm:0,
          nz = norm>0?z/norm:1,
          nw = norm>0?w:0,
          sina = (float)std::sin(nw/2),
          cosa = (float)std::cos(nw/2);
        X = nx*sina;
        Y = ny*sina;
        Z = nz*sina;
        W = cosa;
      } else {
        const float norm = (float)std::sqrt(x*x + y*y + z*z + w*w);
        if (norm>0) { X = x/norm; Y = y/norm; Z = z/norm; W = w/norm; }
        else { X = Y = Z = 0; W = 1; }
      }
      const float xx = X*X, xy = X*Y, xz = X*Z, xw = X*W, yy = Y*Y, yz = Y*Z, yw = Y*W, zz = Z*Z, zw = Z*W;
      return CImg<T>::matrix((T)(1-2*(yy+zz)), (T)(2*(xy+zw)),   (T)(2*(xz-yw)),
			     (T)(2*(xy-zw)),   (T)(1-2*(xx+zz)), (T)(2*(yz+xw)),
			     (T)(2*(xz+yw)),   (T)(2*(yz-xw)),   (T)(1-2*(xx+yy)));
    }

    //@}
    //-----------------------------------
    //
    //! \name Value Manipulation
    //@{
    //-----------------------------------

    //! Fill all pixel values with specified value.
    /**
       \param val Fill value.
    **/
    CImg<T>& fill(const T val) {
      if (is_empty()) return *this;
      if (val && sizeof(T)!=1) cimg_for(*this,ptrd,T) *ptrd = val;
      else std::memset(_data,(int)val,sizeof(T)*size());
      return *this;
    }

    //! Fill all pixel values with specified value \newinstance.
    CImg<T> get_fill(const T val) const {
      return CImg<T>(_width,_height,_depth,_spectrum).fill(val);
    }

    //! Fill sequentially all pixel values with specified values.
    /**
       \param val0 First fill value.
       \param val1 Second fill value.
    **/
    CImg<T>& fill(const T val0, const T val1) {
      if (is_empty()) return *this;
      T *ptrd, *ptre = end()-1;
      for (ptrd = _data; ptrd<ptre; ) { *(ptrd++) = val0; *(ptrd++) = val1; }
      if (ptrd!=ptre+1) *(ptrd++) = val0;
      return *this;
    }

    //! Fill sequentially all pixel values with specified values \newinstance.
    CImg<T> get_fill(const T val0, const T val1) const {
      return CImg<T>(_width,_height,_depth,_spectrum).fill(val0,val1);
    }

    //! Fill sequentially all pixel values with specified values \overloading.
    CImg<T>& fill(const T val0, const T val1, const T val2) {
      if (is_empty()) return *this;
      T *ptrd, *ptre = end()-2;
      for (ptrd = _data; ptrd<ptre; ) { *(ptrd++) = val0; *(ptrd++) = val1; *(ptrd++) = val2; }
      ptre+=2;
      switch (ptre - ptrd) {
      case 2 : *(--ptre) = val1;
      case 1 : *(--ptre) = val0;
      }
      return *this;
    }

    //! Fill sequentially all pixel values with specified values \newinstance.
    CImg<T> get_fill(const T val0, const T val1, const T val2) const {
      return CImg<T>(_width,_height,_depth,_spectrum).fill(val0,val1,val2);
    }

    //! Fill sequentially all pixel values with specified values \overloading.
    CImg<T>& fill(const T val0, const T val1, const T val2, const T val3) {
      if (is_empty()) return *this;
      T *ptrd, *ptre = end()-3;
      for (ptrd = _data; ptrd<ptre; ) { *(ptrd++) = val0; *(ptrd++) = val1; *(ptrd++) = val2; *(ptrd++) = val3; }
      ptre+=3;
      switch (ptre - ptrd) {
      case 3 : *(--ptre) = val2;
      case 2 : *(--ptre) = val1;
      case 1 : *(--ptre) = val0;
      }
      return *this;
    }

    //! Fill sequentially all pixel values with specified values \newinstance.
    CImg<T> get_fill(const T val0, const T val1, const T val2, const T val3) const {
      return CImg<T>(_width,_height,_depth,_spectrum).fill(val0,val1,val2,val3);
    }

    //! Fill sequentially all pixel values with specified values \overloading.
    CImg<T>& fill(const T val0, const T val1, const T val2, const T val3, const T val4) {
      if (is_empty()) return *this;
      T *ptrd, *ptre = end()-4;
      for (ptrd = _data; ptrd<ptre; ) { *(ptrd++) = val0; *(ptrd++) = val1; *(ptrd++) = val2; *(ptrd++) = val3; *(ptrd++) = val4; }
      ptre+=4;
      switch (ptre - ptrd) {
      case 4 : *(--ptre) = val3;
      case 3 : *(--ptre) = val2;
      case 2 : *(--ptre) = val1;
      case 1 : *(--ptre) = val0;
      }
      return *this;
    }

    //! Fill sequentially all pixel values with specified values \newinstance.
    CImg<T> get_fill(const T val0, const T val1, const T val2, const T val3, const T val4) const {
      return CImg<T>(_width,_height,_depth,_spectrum).fill(val0,val1,val2,val3,val4);
    }

    //! Fill sequentially all pixel values with specified values \overloading.
    CImg<T>& fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5) {
      if (is_empty()) return *this;
      T *ptrd, *ptre = end()-5;
      for (ptrd = _data; ptrd<ptre; ) {
        *(ptrd++) = val0; *(ptrd++) = val1; *(ptrd++) = val2; *(ptrd++) = val3; *(ptrd++) = val4; *(ptrd++) = val5;
      }
      ptre+=5;
      switch (ptre - ptrd) {
      case 5 : *(--ptre) = val4;
      case 4 : *(--ptre) = val3;
      case 3 : *(--ptre) = val2;
      case 2 : *(--ptre) = val1;
      case 1 : *(--ptre) = val0;
      }
      return *this;
    }

    //! Fill sequentially all pixel values with specified values \newinstance.
    CImg<T> get_fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5) const {
      return CImg<T>(_width,_height,_depth,_spectrum).fill(val0,val1,val2,val3,val4,val5);
    }

    //! Fill sequentially all pixel values with specified values \overloading.
    CImg<T>& fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5, const T val6) {
      if (is_empty()) return *this;
      T *ptrd, *ptre = end()-6;
      for (ptrd = _data; ptrd<ptre; ) {
        *(ptrd++) = val0; *(ptrd++) = val1; *(ptrd++) = val2; *(ptrd++) = val3; *(ptrd++) = val4; *(ptrd++) = val5; *(ptrd++) = val6;
      }
      ptre+=6;
      switch (ptre - ptrd) {
      case 6 : *(--ptre) = val5;
      case 5 : *(--ptre) = val4;
      case 4 : *(--ptre) = val3;
      case 3 : *(--ptre) = val2;
      case 2 : *(--ptre) = val1;
      case 1 : *(--ptre) = val0;
      }
      return *this;
    }

    //! Fill sequentially all pixel values with specified values \newinstance.
    CImg<T> get_fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5, const T val6) const {
      return CImg<T>(_width,_height,_depth,_spectrum).fill(val0,val1,val2,val3,val4,val5,val6);
    }

    //! Fill sequentially all pixel values with specified values \overloading.
    CImg<T>& fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5, const T val6,
                  const T val7) {
      if (is_empty()) return *this;
      T *ptrd, *ptre = end()-7;
      for (ptrd = _data; ptrd<ptre; ) {
        *(ptrd++) = val0; *(ptrd++) = val1; *(ptrd++) = val2; *(ptrd++) = val3;
        *(ptrd++) = val4; *(ptrd++) = val5; *(ptrd++) = val6; *(ptrd++) = val7;
      }
      ptre+=7;
      switch (ptre - ptrd) {
      case 7 : *(--ptre) = val6;
      case 6 : *(--ptre) = val5;
      case 5 : *(--ptre) = val4;
      case 4 : *(--ptre) = val3;
      case 3 : *(--ptre) = val2;
      case 2 : *(--ptre) = val1;
      case 1 : *(--ptre) = val0;
      }
      return *this;
    }

    //! Fill sequentially all pixel values with specified values \newinstance.
    CImg<T> get_fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5, const T val6,
                     const T val7) const {
      return CImg<T>(_width,_height,_depth,_spectrum).fill(val0,val1,val2,val3,val4,val5,val6,val7);
    }

    //! Fill sequentially all pixel values with specified values \overloading.
    CImg<T>& fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5, const T val6,
                  const T val7, const T val8) {
      if (is_empty()) return *this;
      T *ptrd, *ptre = end()-8;
      for (ptrd = _data; ptrd<ptre; ) {
        *(ptrd++) = val0; *(ptrd++) = val1; *(ptrd++) = val2;
        *(ptrd++) = val3; *(ptrd++) = val4; *(ptrd++) = val5;
        *(ptrd++) = val6; *(ptrd++) = val7; *(ptrd++) = val8;
      }
      ptre+=8;
      switch (ptre - ptrd) {
      case 8 : *(--ptre) = val7;
      case 7 : *(--ptre) = val6;
      case 6 : *(--ptre) = val5;
      case 5 : *(--ptre) = val4;
      case 4 : *(--ptre) = val3;
      case 3 : *(--ptre) = val2;
      case 2 : *(--ptre) = val1;
      case 1 : *(--ptre) = val0;
      }
      return *this;
    }

    //! Fill sequentially all pixel values with specified values \newinstance.
    CImg<T> get_fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5, const T val6,
                     const T val7, const T val8) const {
      return CImg<T>(_width,_height,_depth,_spectrum).fill(val0,val1,val2,val3,val4,val5,val6,val7,val8);
    }

    //! Fill sequentially all pixel values with specified values \overloading.
    CImg<T>& fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5, const T val6,
                  const T val7, const T val8, const T val9) {
      if (is_empty()) return *this;
      T *ptrd, *ptre = end()-9;
      for (ptrd = _data; ptrd<ptre; ) {
        *(ptrd++) = val0; *(ptrd++) = val1; *(ptrd++) = val2; *(ptrd++) = val3; *(ptrd++) = val4;
        *(ptrd++) = val5; *(ptrd++) = val6; *(ptrd++) = val7; *(ptrd++) = val8; *(ptrd++) = val9;
      }
      ptre+=9;
      switch (ptre - ptrd) {
      case 9 : *(--ptre) = val8;
      case 8 : *(--ptre) = val7;
      case 7 : *(--ptre) = val6;
      case 6 : *(--ptre) = val5;
      case 5 : *(--ptre) = val4;
      case 4 : *(--ptre) = val3;
      case 3 : *(--ptre) = val2;
      case 2 : *(--ptre) = val1;
      case 1 : *(--ptre) = val0;
      }
      return *this;
    }

    //! Fill sequentially all pixel values with specified values \newinstance.
    CImg<T> get_fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5, const T val6,
                     const T val7, const T val8, const T val9) const {
      return CImg<T>(_width,_height,_depth,_spectrum).fill(val0,val1,val2,val3,val4,val5,val6,val7,val8,val9);
    }

    //! Fill sequentially all pixel values with specified values \overloading.
    CImg<T>& fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5, const T val6,
                  const T val7, const T val8, const T val9, const T val10) {
      if (is_empty()) return *this;
      T *ptrd, *ptre = end()-10;
      for (ptrd = _data; ptrd<ptre; ) {
        *(ptrd++) = val0; *(ptrd++) = val1; *(ptrd++) = val2; *(ptrd++) = val3; *(ptrd++) = val4;
        *(ptrd++) = val5; *(ptrd++) = val6; *(ptrd++) = val7; *(ptrd++) = val8; *(ptrd++) = val9;
        *(ptrd++) = val10;
      }
      ptre+=10;
      switch (ptre - ptrd) {
      case 10 : *(--ptre) = val9;
      case 9 : *(--ptre) = val8;
      case 8 : *(--ptre) = val7;
      case 7 : *(--ptre) = val6;
      case 6 : *(--ptre) = val5;
      case 5 : *(--ptre) = val4;
      case 4 : *(--ptre) = val3;
      case 3 : *(--ptre) = val2;
      case 2 : *(--ptre) = val1;
      case 1 : *(--ptre) = val0;
      }
      return *this;
    }

    //! Fill sequentially all pixel values with specified values \newinstance.
    CImg<T> get_fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5, const T val6,
                     const T val7, const T val8, const T val9, const T val10) const {
      return CImg<T>(_width,_height,_depth,_spectrum).fill(val0,val1,val2,val3,val4,val5,val6,val7,val8,val9,val10);
    }

    //! Fill sequentially all pixel values with specified values \overloading.
    CImg<T>& fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5, const T val6,
                  const T val7, const T val8, const T val9, const T val10, const T val11) {
      if (is_empty()) return *this;
      T *ptrd, *ptre = end()-11;
      for (ptrd = _data; ptrd<ptre; ) {
        *(ptrd++) = val0; *(ptrd++) = val1; *(ptrd++) = val2; *(ptrd++) = val3; *(ptrd++) = val4; *(ptrd++) = val5;
        *(ptrd++) = val6; *(ptrd++) = val7; *(ptrd++) = val8; *(ptrd++) = val9; *(ptrd++) = val10; *(ptrd++) = val11;
      }
      ptre+=11;
      switch (ptre - ptrd) {
      case 11 : *(--ptre) = val10;
      case 10 : *(--ptre) = val9;
      case 9 : *(--ptre) = val8;
      case 8 : *(--ptre) = val7;
      case 7 : *(--ptre) = val6;
      case 6 : *(--ptre) = val5;
      case 5 : *(--ptre) = val4;
      case 4 : *(--ptre) = val3;
      case 3 : *(--ptre) = val2;
      case 2 : *(--ptre) = val1;
      case 1 : *(--ptre) = val0;
      }
      return *this;
    }

    //! Fill sequentially all pixel values with specified values \newinstance.
    CImg<T> get_fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5, const T val6,
                     const T val7, const T val8, const T val9, const T val10, const T val11) const {
      return CImg<T>(_width,_height,_depth,_spectrum).fill(val0,val1,val2,val3,val4,val5,val6,val7,val8,val9,val10,val11);
    }

    //! Fill sequentially all pixel values with specified values \overloading.
    CImg<T>& fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5, const T val6,
                  const T val7, const T val8, const T val9, const T val10, const T val11, const T val12) {
      if (is_empty()) return *this;
      T *ptrd, *ptre = end()-12;
      for (ptrd = _data; ptrd<ptre; ) {
        *(ptrd++) = val0; *(ptrd++) = val1; *(ptrd++) = val2; *(ptrd++) = val3; *(ptrd++) = val4; *(ptrd++) = val5;
        *(ptrd++) = val6; *(ptrd++) = val7; *(ptrd++) = val8; *(ptrd++) = val9; *(ptrd++) = val10; *(ptrd++) = val11;
        *(ptrd++) = val12;
      }
      ptre+=12;
      switch (ptre - ptrd) {
      case 12 : *(--ptre) = val11;
      case 11 : *(--ptre) = val10;
      case 10 : *(--ptre) = val9;
      case 9 : *(--ptre) = val8;
      case 8 : *(--ptre) = val7;
      case 7 : *(--ptre) = val6;
      case 6 : *(--ptre) = val5;
      case 5 : *(--ptre) = val4;
      case 4 : *(--ptre) = val3;
      case 3 : *(--ptre) = val2;
      case 2 : *(--ptre) = val1;
      case 1 : *(--ptre) = val0;
      }
      return *this;
    }

    //! Fill sequentially all pixel values with specified values \newinstance.
    CImg<T> get_fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5, const T val6,
                     const T val7, const T val8, const T val9, const T val10, const T val11, const T val12) const {
      return CImg<T>(_width,_height,_depth,_spectrum).fill(val0,val1,val2,val3,val4,val5,val6,val7,val8,val9,val10,val11,val12);
    }

    //! Fill sequentially all pixel values with specified values \overloading.
    CImg<T>& fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5, const T val6,
                  const T val7, const T val8, const T val9, const T val10, const T val11, const T val12,
                  const T val13) {
      if (is_empty()) return *this;
      T *ptrd, *ptre = end()-13;
      for (ptrd = _data; ptrd<ptre; ) {
        *(ptrd++) = val0; *(ptrd++) = val1; *(ptrd++) = val2; *(ptrd++) = val3; *(ptrd++) = val4; *(ptrd++) = val5;
        *(ptrd++) = val6; *(ptrd++) = val7; *(ptrd++) = val8; *(ptrd++) = val9; *(ptrd++) = val10; *(ptrd++) = val11;
        *(ptrd++) = val12; *(ptrd++) = val13;
      }
      ptre+=13;
      switch (ptre - ptrd) {
      case 13 : *(--ptre) = val12;
      case 12 : *(--ptre) = val11;
      case 11 : *(--ptre) = val10;
      case 10 : *(--ptre) = val9;
      case 9 : *(--ptre) = val8;
      case 8 : *(--ptre) = val7;
      case 7 : *(--ptre) = val6;
      case 6 : *(--ptre) = val5;
      case 5 : *(--ptre) = val4;
      case 4 : *(--ptre) = val3;
      case 3 : *(--ptre) = val2;
      case 2 : *(--ptre) = val1;
      case 1 : *(--ptre) = val0;
      }
      return *this;
    }

    //! Fill sequentially all pixel values with specified values \newinstance.
    CImg<T> get_fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5, const T val6,
                     const T val7, const T val8, const T val9, const T val10, const T val11, const T val12,
                     const T val13) const {
      return CImg<T>(_width,_height,_depth,_spectrum).fill(val0,val1,val2,val3,val4,val5,val6,val7,val8,val9,val10,val11,val12,
                                                  val13);
    }

    //! Fill sequentially all pixel values with specified values \overloading.
    CImg<T>& fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5, const T val6,
                  const T val7, const T val8, const T val9, const T val10, const T val11, const T val12,
                  const T val13, const T val14) {
      if (is_empty()) return *this;
      T *ptrd, *ptre = end()-14;
      for (ptrd = _data; ptrd<ptre; ) {
        *(ptrd++) = val0; *(ptrd++) = val1; *(ptrd++) = val2; *(ptrd++) = val3; *(ptrd++) = val4; *(ptrd++) = val5;
        *(ptrd++) = val6; *(ptrd++) = val7; *(ptrd++) = val8; *(ptrd++) = val9; *(ptrd++) = val10; *(ptrd++) = val11;
        *(ptrd++) = val12; *(ptrd++) = val13; *(ptrd++) = val14;
      }
      ptre+=14;
      switch (ptre - ptrd) {
      case 14 : *(--ptre) = val13;
      case 13 : *(--ptre) = val12;
      case 12 : *(--ptre) = val11;
      case 11 : *(--ptre) = val10;
      case 10 : *(--ptre) = val9;
      case 9 : *(--ptre) = val8;
      case 8 : *(--ptre) = val7;
      case 7 : *(--ptre) = val6;
      case 6 : *(--ptre) = val5;
      case 5 : *(--ptre) = val4;
      case 4 : *(--ptre) = val3;
      case 3 : *(--ptre) = val2;
      case 2 : *(--ptre) = val1;
      case 1 : *(--ptre) = val0;
      }
      return *this;
    }

    //! Fill sequentially all pixel values with specified values \newinstance.
    CImg<T> get_fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5, const T val6,
                     const T val7, const T val8, const T val9, const T val10, const T val11, const T val12,
                     const T val13, const T val14) const {
      return CImg<T>(_width,_height,_depth,_spectrum).fill(val0,val1,val2,val3,val4,val5,val6,val7,val8,val9,val10,val11,val12,
                                                  val13,val14);
    }

    //! Fill sequentially all pixel values with specified values \overloading.
    CImg<T>& fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5, const T val6,
                  const T val7, const T val8, const T val9, const T val10, const T val11, const T val12,
                  const T val13, const T val14, const T val15) {
      if (is_empty()) return *this;
      T *ptrd, *ptre = end()-15;
      for (ptrd = _data; ptrd<ptre; ) {
        *(ptrd++) = val0; *(ptrd++) = val1; *(ptrd++) = val2; *(ptrd++) = val3; *(ptrd++) = val4; *(ptrd++) = val5;
        *(ptrd++) = val6; *(ptrd++) = val7; *(ptrd++) = val8; *(ptrd++) = val9; *(ptrd++) = val10; *(ptrd++) = val11;
        *(ptrd++) = val12; *(ptrd++) = val13; *(ptrd++) = val14; *(ptrd++) = val15;
      }
      ptre+=15;
      switch (ptre - ptrd) {
      case 15 : *(--ptre) = val14;
      case 14 : *(--ptre) = val13;
      case 13 : *(--ptre) = val12;
      case 12 : *(--ptre) = val11;
      case 11 : *(--ptre) = val10;
      case 10 : *(--ptre) = val9;
      case 9 : *(--ptre) = val8;
      case 8 : *(--ptre) = val7;
      case 7 : *(--ptre) = val6;
      case 6 : *(--ptre) = val5;
      case 5 : *(--ptre) = val4;
      case 4 : *(--ptre) = val3;
      case 3 : *(--ptre) = val2;
      case 2 : *(--ptre) = val1;
      case 1 : *(--ptre) = val0;
      }
      return *this;
    }

    //! Fill sequentially all pixel values with specified values \newinstance.
    CImg<T> get_fill(const T val0, const T val1, const T val2, const T val3, const T val4, const T val5, const T val6,
                     const T val7, const T val8, const T val9, const T val10, const T val11, const T val12,
                     const T val13, const T val14, const T val15) const {
      return CImg<T>(_width,_height,_depth,_spectrum).fill(val0,val1,val2,val3,val4,val5,val6,val7,val8,val9,val10,val11,val12,
                                                  val13,val14,val15);
    }

    //! Fill sequentially pixel values according to a given expression.
    /**
       \param expression C-string describing a math formula, or a list of values.
       \param repeat_flag In case a list of values is provided, tells if this list must be repeated for the filling.
    **/
    CImg<T>& fill(const char *const expression, const bool repeat_flag) {
      if (is_empty() || !expression || !*expression) return *this;
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      try { // Try to fill values according to a formula.
        const CImg<T> _base = cimg::_is_self_expr(expression)?+*this:CImg<T>(), &base = _base?_base:*this;
        _cimg_math_parser mp(base,expression+(*expression=='>' || *expression=='<'?1:0),"fill");
        T *ptrd = *expression=='<'?end()-1:_data;
        if (*expression=='<') cimg_rofXYZC(*this,x,y,z,c) *(ptrd--) = (T)mp.eval((double)x,(double)y,(double)z,(double)c);
        else cimg_forXYZC(*this,x,y,z,c) *(ptrd++) = (T)mp.eval((double)x,(double)y,(double)z,(double)c);
      } catch (CImgException& e) { // If failed, try to recognize a list of values.
        char item[16384] = { 0 }, sep = 0;
        const char *nexpression = expression;
        unsigned long nb = 0;
        const unsigned long siz = size();
        T *ptrd = _data;
        for (double val = 0; *nexpression && nb<siz; ++nb) {
          sep = 0;
          const int err = std::sscanf(nexpression,"%4095[ \n\t0-9.e+-]%c",item,&sep);
          if (err>0 && std::sscanf(item,"%lf",&val)==1) {
            nexpression+=std::strlen(item) + (err>1?1:0);
            *(ptrd++) = (T)val;
          } else break;
        }
        cimg::exception_mode() = omode;
        if (nb<siz && (sep || *nexpression))
          throw CImgArgumentException(e.what(),pixel_type(),expression);
        if (repeat_flag && nb && nb<siz) for (T *ptrs = _data, *const ptre = _data + siz; ptrd<ptre; ++ptrs) *(ptrd++) = *ptrs;
      }
      cimg::exception_mode() = omode;
      return *this;
    }

    //! Fill sequentially pixel values according to a given expression \newinstance.
    CImg<T> get_fill(const char *const values, const bool repeat_values) const {
      return (+*this).fill(values,repeat_values);
    }

    //! Fill sequentially pixel values according to the values found in another image.
    /**
       \param values Image containing the values used for the filling.
       \param repeat_values In case there are less values than necessary in \c values, tells if these values must be repeated for the filling.
    **/
    template<typename t>
    CImg<T>& fill(const CImg<t>& values, const bool repeat_values=true) {
      if (is_empty() || !values) return *this;
      T *ptrd = _data, *ptre = ptrd + size();
      for (t *ptrs = values._data, *ptrs_end = ptrs + values.size(); ptrs<ptrs_end && ptrd<ptre; ++ptrs) *(ptrd++) = (T)*ptrs;
      if (repeat_values && ptrd<ptre) for (T *ptrs = _data; ptrd<ptre; ++ptrs) *(ptrd++) = *ptrs;
      return *this;
    }

    //! Fill sequentially pixel values according to the values found in another image \newinstance.
    template<typename t>
    CImg<T> get_fill(const CImg<t>& values, const bool repeat_values=true) const {
      return repeat_values?CImg<T>(_width,_height,_depth,_spectrum).fill(values,repeat_values):(+*this).fill(values,repeat_values);
    }

    //! Fill pixel values along the X-axis at a specified pixel position.
    /**
       \param y Y-coordinate of the filled column.
       \param z Z-coordinate of the filled column.
       \param c C-coordinate of the filled column.
       \param a0 First fill value.
    **/
    CImg<T>& fillX(const unsigned int y, const unsigned int z, const unsigned int c, const int a0, ...) {
#define _cimg_fill1(x,y,z,c,off,siz,t) { \
    va_list ap; va_start(ap,a0); T *ptrd = data(x,y,z,c); *ptrd = (T)a0; \
    for (unsigned long k = 1; k<siz; ++k) { ptrd+=off; *ptrd = (T)va_arg(ap,t); } \
    va_end(ap); }
      if (y<_height && z<_depth && c<_spectrum) _cimg_fill1(0,y,z,c,1,_width,int);
      return *this;
    }

    //! Fill pixel values along the X-axis at a specified pixel position \overloading.
    CImg<T>& fillX(const unsigned int y, const unsigned int z, const unsigned int c, const double a0, ...) {
      if (y<_height && z<_depth && c<_spectrum) _cimg_fill1(0,y,z,c,1,_width,double);
      return *this;
    }

    //! Fill pixel values along the Y-axis at a specified pixel position.
    /**
       \param x X-coordinate of the filled row.
       \param z Z-coordinate of the filled row.
       \param c C-coordinate of the filled row.
       \param a0 First fill value.
    **/
    CImg<T>& fillY(const unsigned int x, const unsigned int z, const unsigned int c, const int a0, ...) {
      if (x<_width && z<_depth && c<_spectrum) _cimg_fill1(x,0,z,c,_width,_height,int);
      return *this;
    }

    //! Fill pixel values along the Y-axis at a specified pixel position \overloading.
    CImg<T>& fillY(const unsigned int x, const unsigned int z, const unsigned int c, const double a0, ...) {
      if (x<_width && z<_depth && c<_spectrum) _cimg_fill1(x,0,z,c,_width,_height,double);
      return *this;
    }

    //! Fill pixel values along the Z-axis at a specified pixel position.
    /**
       \param x X-coordinate of the filled slice.
       \param y Y-coordinate of the filled slice.
       \param c C-coordinate of the filled slice.
       \param a0 First fill value.
    **/
    CImg<T>& fillZ(const unsigned int x, const unsigned int y, const unsigned int c, const int a0, ...) {
      const unsigned long wh = (unsigned long)_width*_height;
      if (x<_width && y<_height && c<_spectrum) _cimg_fill1(x,y,0,c,wh,_depth,int);
      return *this;
    }

    //! Fill pixel values along the Z-axis at a specified pixel position \overloading.
    CImg<T>& fillZ(const unsigned int x, const unsigned int y, const unsigned int c, const double a0, ...) {
      const unsigned long wh = (unsigned long)_width*_height;
      if (x<_width && y<_height && c<_spectrum) _cimg_fill1(x,y,0,c,wh,_depth,double);
      return *this;
    }

    //! Fill pixel values along the C-axis at a specified pixel position.
    /**
       \param x X-coordinate of the filled channel.
       \param y Y-coordinate of the filled channel.
       \param z Z-coordinate of the filled channel.
       \param a0 First filling value.
    **/
    CImg<T>& fillC(const unsigned int x, const unsigned int y, const unsigned int z, const int a0, ...) {
      const unsigned long whd = (unsigned long)_width*_height*_depth;
      if (x<_width && y<_height && z<_depth) _cimg_fill1(x,y,z,0,whd,_spectrum,int);
      return *this;
    }

    //! Fill pixel values along the C-axis at a specified pixel position \overloading.
    CImg<T>& fillC(const unsigned int x, const unsigned int y, const unsigned int z, const double a0, ...) {
      const unsigned long whd = (unsigned long)_width*_height*_depth;
      if (x<_width && y<_height && z<_depth) _cimg_fill1(x,y,z,0,whd,_spectrum,double);
      return *this;
    }

    //! Discard specified value in the image buffer.
    /**
       \param value Value to discard.
       \note Discarded values will change the image geometry, so the resulting image
       is returned as a one-column vector.
    **/
    CImg<T>& discard(const T value) {
      return get_discard(value).move_to(*this);
    }

    //! Discard specified value in the image buffer \newinstance.
    CImg<T> get_discard(const T value) const {
      CImg<T> res(1,size());
      T *pd = res._data;
      for (const T *ps = _data, *const pse = end(); ps<pse; ++ps)
        if (*ps!=value) *(pd++) = *ps;
      if (pd==res._data) return CImg<T>();
      return res.resize(1,pd-res._data,1,1,-1);
    }

    //! Discard specified sequence of values in the image buffer.
    /**
       \param values Sequence of values to discard.
       \note Discarded values will change the image geometry, so the resulting image
       is returned as a one-column vector.
    **/
    template<typename t>
    CImg<T>& discard(const CImg<t>& values) {
      return get_discard(values).move_to(*this);
    }

    //! Discard specified sequence of values in the image buffer \newinstance.
    template<typename t>
    CImg<T> get_discard(const CImg<t>& values) const {
      if (!values) return *this;
      if (values.size()==1) return get_discard(*values);
      CImg<T> res(1,size());
      T *pd = res._data;
      const t *const pve = values.end();
      for (const T *ps = _data, *const pse = end(); ps<pse; ) {
        const T *_ps = ps;
        const t *pv = values._data;
        while (_ps<pse && pv<pve) { if (*(_ps++)!=(T)*pv) break; ++pv; }
        if (pv!=pve) {
          const unsigned int l = _ps - ps;
          if (l==1) *(pd++) = *ps; else { std::memcpy(pd,ps,sizeof(T)*l); pd+=l; }
        }
        ps = _ps;
      }
      if (pd==res._data) return CImg<T>();
      return res.resize(1,pd-res._data,1,1,-1);
    }

    //! Invert endianness of all pixel values.
    /**
     **/
    CImg<T>& invert_endianness() {
      cimg::invert_endianness(_data,size());
      return *this;
    }

    //! Invert endianness of all pixel values \newinstance.
    CImg<T> get_invert_endianness() const {
      return (+*this).invert_endianness();
    }

    //! Fill image with random values in specified range.
    /**
       \param val_min Minimal random value.
       \param val_max Maximal random value.
       \note Random samples are following a uniform distribution.
     **/
    CImg<T>& rand(const T val_min, const T val_max) {
      const float delta = (float)val_max - (float)val_min;
      cimg_for(*this,ptrd,T) *ptrd = (T)(val_min + cimg::rand()*delta);
      return *this;
    }

    //! Fill image with random values in specified range \newinstance.
    CImg<T> get_rand(const T val_min, const T val_max) const {
      return (+*this).rand(val_min,val_max);
    }

    //! Round pixel values.
    /**
       \param y Rounding precision.
       \param rounding_type Rounding type. Can be:
       - \c -1: Backward.
       - \c 0: Nearest.
       - \c 1: Forward.
    **/
    CImg<T>& round(const double y=1, const int rounding_type=0) {
      if (y>0) cimg_for(*this,ptrd,T) *ptrd = cimg::round(*ptrd,y,rounding_type);
      return *this;
    }

    //! Round pixel values \newinstance.
    CImg<T> get_round(const double y=1, const unsigned int rounding_type=0) const {
      return (+*this).round(y,rounding_type);
    }

    //! Add random noise to pixel values.
    /**
       \param sigma Amplitude of the random additive noise. If \p sigma<0, it stands for a percentage of the global value range.
       \param noise_type Type of additive noise (can be \p 0=gaussian, \p 1=uniform, \p 2=Salt and Pepper, \p 3=Poisson or \p 4=Rician).
       \return A reference to the modified image instance.
       \note
       - For Poisson noise (\p noise_type=3), parameter \p sigma is ignored, as Poisson noise only depends on the image value itself.
       - Function \p CImg<T>::get_noise() is also defined. It returns a non-shared modified copy of the image instance.
       \par Example
       \code
       const CImg<float> img("reference.jpg"), res = img.get_noise(40);
       (img,res.normalize(0,255)).display();
       \endcode
       \image html ref_noise.jpg
    **/
    CImg<T>& noise(const double sigma, const unsigned int noise_type=0) {
      if (!is_empty()) {
        const Tfloat vmin = (Tfloat)cimg::type<T>::min(), vmax = (Tfloat)cimg::type<T>::max();
        Tfloat nsigma = (Tfloat)sigma, m = 0, M = 0;
        if (nsigma==0 && noise_type!=3) return *this;
        if (nsigma<0 || noise_type==2) m = (Tfloat)min_max(M);
        if (nsigma<0) nsigma = (Tfloat)(-nsigma*(M-m)/100.0);
        switch (noise_type) {
        case 0 : { // Gaussian noise
          cimg_for(*this,ptrd,T) {
            Tfloat val = (Tfloat)(*ptrd + nsigma*cimg::grand());
            if (val>vmax) val = vmax;
            if (val<vmin) val = vmin;
            *ptrd = (T)val;
          }
        } break;
        case 1 : { // Uniform noise
          cimg_for(*this,ptrd,T) {
            Tfloat val = (Tfloat)(*ptrd + nsigma*cimg::crand());
            if (val>vmax) val = vmax;
            if (val<vmin) val = vmin;
            *ptrd = (T)val;
          }
        } break;
        case 2 : { // Salt & Pepper noise
          if (nsigma<0) nsigma = -nsigma;
          if (M==m) { m = 0; M = (Tfloat)(cimg::type<T>::is_float()?1:cimg::type<T>::max()); }
          cimg_for(*this,ptrd,T) if (cimg::rand()*100<nsigma) *ptrd = (T)(cimg::rand()<0.5?M:m);
        } break;

        case 3 : { // Poisson Noise
          cimg_for(*this,ptrd,T) *ptrd = (T)cimg::prand(*ptrd);
        } break;

        case 4 : { // Rice noise
          const Tfloat sqrt2 = (Tfloat)std::sqrt(2.0);
          cimg_for(*this,ptrd,T) {
            const Tfloat
              val0 = (Tfloat)*ptrd/sqrt2,
              re = (Tfloat)(val0 + nsigma*cimg::grand()),
              im = (Tfloat)(val0 + nsigma*cimg::grand());
            Tfloat val = (Tfloat)std::sqrt(re*re + im*im);
            if (val>vmax) val = vmax;
            if (val<vmin) val = vmin;
            *ptrd = (T)val;
          }
        } break;
        default :
          throw CImgArgumentException(_cimg_instance
                                      "noise(): Invalid specified noise type %d "
                                      "(should be { 0=gaussian | 1=uniform | 2=salt&Pepper | 3=poisson }).",
                                      cimg_instance,
                                      noise_type);
        }
      }
      return *this;
    }

    //! Add random noise to pixel values \newinstance.
    CImg<T> get_noise(const double sigma, const unsigned int noise_type=0) const {
      return (+*this).noise(sigma,noise_type);
    }

    //! Linearly normalize pixel values.
    /**
       \param min_value Minimum desired value of the resulting image.
       \param max_value Maximum desired value of the resulting image.
       \par Example
       \code
       const CImg<float> img("reference.jpg"), res = img.get_normalize(160,220);
       (img,res).display();
       \endcode
       \image html ref_normalize2.jpg
    **/
    CImg<T>& normalize(const T min_value, const T max_value) {
      if (is_empty()) return *this;
      const T a = min_value<max_value?min_value:max_value, b = min_value<max_value?max_value:min_value;
      T m, M = max_min(m);
      const Tfloat fm = (Tfloat)m, fM = (Tfloat)M;
      if (m==M) return fill(min_value);
      if (m!=a || M!=b) cimg_for(*this,ptrd,T) *ptrd = (T)((*ptrd-fm)/(fM-fm)*(b-a)+a);
      return *this;
    }

    //! Linearly normalize pixel values \newinstance.
    CImg<Tfloat> get_normalize(const T min_value, const T max_value) const {
      return CImg<Tfloat>(*this,false).normalize((Tfloat)min_value,(Tfloat)max_value);
    }

    //! Normalize multi-valued pixels of the image instance, with respect to their L2-norm.
    /**
       \par Example
       \code
       const CImg<float> img("reference.jpg"), res = img.get_normalize();
       (img,res.normalize(0,255)).display();
       \endcode
       \image html ref_normalize.jpg
    **/
    CImg<T>& normalize() {
      T *ptrd = _data;
      const unsigned long whd = (unsigned long)_width*_height*_depth;
      cimg_forXYZ(*this,x,y,z) {
        const T *ptrs = ptrd;
        float n = 0;
        cimg_forC(*this,c) { n+=cimg::sqr((float)*ptrs); ptrs+=whd; }
        n = (float)std::sqrt(n);
        T *_ptrd = ptrd++;
        if (n>0) cimg_forC(*this,c) { *_ptrd = (T)(*_ptrd/n); _ptrd+=whd; }
        else cimg_forC(*this,c) { *_ptrd = (T)0; _ptrd+=whd; }
      }
      return *this;
    }

    //! Normalize multi-valued pixels of the image instance, with respect to their L2-norm \newinstance.
    CImg<Tfloat> get_normalize() const {
      return CImg<Tfloat>(*this,false).normalize();
    }

    //! Compute L2-norm of each multi-valued pixel of the image instance.
    /**
       \param norm_type Type of computed vector norm (can be \p 0=Linf, \p 1=L1 or \p 2=L2).
       \par Example
       \code
       const CImg<float> img("reference.jpg"), res = img.get_norm();
       (img,res.normalize(0,255)).display();
       \endcode
       \image html ref_norm.jpg
    **/
    CImg<T>& norm(const int norm_type=2) {
      if (_spectrum==1) return abs();
      return get_norm(norm_type).move_to(*this);
    }

    //! Compute L2-norm of each multi-valued pixel of the image instance \newinstance.
    CImg<Tfloat> get_norm(const int norm_type=2) const {
      if (is_empty()) return *this;
      if (_spectrum==1) return get_abs();
      const T *ptrs = _data;
      const unsigned long whd = (unsigned long)_width*_height*_depth;
      CImg<Tfloat> res(_width,_height,_depth);
      Tfloat *ptrd = res._data;
      switch (norm_type) {
      case -1 : {             // Linf norm
        cimg_forXYZ(*this,x,y,z) {
          Tfloat n = 0;
          const T *_ptrs = ptrs++;
          cimg_forC(*this,c) { const Tfloat val = (Tfloat)cimg::abs(*_ptrs); if (val>n) n = val; _ptrs+=whd; }
          *(ptrd++) = n;
        }
      } break;
      case 1 : {              // L1 norm
        cimg_forXYZ(*this,x,y,z) {
          Tfloat n = 0;
          const T *_ptrs = ptrs++;
          cimg_forC(*this,c) { n+=cimg::abs(*_ptrs); _ptrs+=whd; }
          *(ptrd++) = n;
        }
      } break;
      default : {             // L2 norm
        cimg_forXYZ(*this,x,y,z) {
          Tfloat n = 0;
          const T *_ptrs = ptrs++;
          cimg_forC(*this,c) { n+=cimg::sqr((Tfloat)*_ptrs); _ptrs+=whd; }
          *(ptrd++) = (Tfloat)std::sqrt((Tfloat)n);
        }
      }
      }
      return res;
    }

    //! Cut pixel values in specified range.
    /**
       \param min_value Minimum desired value of the resulting image.
       \param max_value Maximum desired value of the resulting image.
       \par Example
       \code
       const CImg<float> img("reference.jpg"), res = img.get_cut(160,220);
       (img,res).display();
       \endcode
       \image html ref_cut.jpg
    **/
    CImg<T>& cut(const T min_value, const T max_value) {
      if (is_empty()) return *this;
      const T a = min_value<max_value?min_value:max_value, b = min_value<max_value?max_value:min_value;
      cimg_for(*this,ptrd,T) *ptrd = (*ptrd<a)?a:((*ptrd>b)?b:*ptrd);
      return *this;
    }

    //! Cut pixel values in specified range \newinstance.
    CImg<T> get_cut(const T min_value, const T max_value) const {
      return (+*this).cut(min_value,max_value);
    }

    //! Uniformly quantize pixel values.
    /**
       \param nb_levels Number of quantization levels.
       \param keep_range Tells if resulting values keep the same range as the original ones.
       \par Example
       \code
       const CImg<float> img("reference.jpg"), res = img.get_quantize(4);
       (img,res).display();
       \endcode
       \image html ref_quantize.jpg
    **/
    CImg<T>& quantize(const unsigned int nb_levels, const bool keep_range=true) {
      if (!nb_levels)
        throw CImgArgumentException(_cimg_instance
                                    "quantize(): Invalid quantization request with 0 values.",
                                    cimg_instance);

      if (is_empty()) return *this;
      Tfloat m, M = (Tfloat)max_min(m), range = M - m;
      if (range>0) {
        if (keep_range) cimg_for(*this,ptrd,T) {
          const unsigned int val = (unsigned int)((*ptrd-m)*nb_levels/range);
          *ptrd = (T)(m + cimg::min(val,nb_levels-1)*range/nb_levels);
        } else cimg_for(*this,ptrd,T) {
          const unsigned int val = (unsigned int)((*ptrd-m)*nb_levels/range);
          *ptrd = (T)cimg::min(val,nb_levels-1);
        }
      }
      return *this;
    }

    //! Uniformly quantize pixel values \newinstance.
    CImg<T> get_quantize(const unsigned int n, const bool keep_range=true) const {
      return (+*this).quantize(n,keep_range);
    }

    //! Threshold pixel values.
    /**
       \param value Threshold value
       \param soft_threshold Tells if soft thresholding must be applied (instead of hard one).
       \param strict_threshold Tells if threshold value is strict.
       \par Example
       \code
       const CImg<float> img("reference.jpg"), res = img.get_threshold(128);
       (img,res.normalize(0,255)).display();
       \endcode
       \image html ref_threshold.jpg
    **/
    CImg<T>& threshold(const T value, const bool soft_threshold=false, const bool strict_threshold=false) {
      if (is_empty()) return *this;
      if (strict_threshold) {
        if (soft_threshold) cimg_for(*this,ptrd,T) { const T v = *ptrd; *ptrd = v>value?(T)(v-value):v<-(float)value?(T)(v+value):(T)0; }
        else cimg_for(*this,ptrd,T) *ptrd = *ptrd>value?(T)1:(T)0;
      } else {
        if (soft_threshold) cimg_for(*this,ptrd,T) { const T v = *ptrd; *ptrd = v>=value?(T)(v-value):v<=-(float)value?(T)(v+value):(T)0; }
        else cimg_for(*this,ptrd,T) *ptrd = *ptrd>=value?(T)1:(T)0;
      }
      return *this;
    }

    //! Threshold pixel values \newinstance.
    CImg<T> get_threshold(const T value, const bool soft_threshold=false, const bool strict_threshold=false) const {
      return (+*this).threshold(value,soft_threshold,strict_threshold);
    }

    //! Compute the histogram of pixel values.
    /**
       \param nb_levels Number of desired histogram levels.
       \param min_value Minimum pixel value considered for the histogram computation. All pixel values lower than \p min_value will not be counted.
       \param max_value Maximum pixel value considered for the histogram computation. All pixel values higher than \p max_value will not be counted.
       \note
       - The histogram H of an image I is the 1d function where H(x) counts the number of occurences of the value x in the image I.
       - If \p min_value==max_value==0 (default behavior), the function first estimates the whole range of pixel values
       then uses it to compute the histogram.
       - The resulting histogram is always defined in 1d. Histograms of multi-valued images are not multi-dimensional.
       \par Example
       \code
       const CImg<float> img = CImg<float>("reference.jpg").histogram(256);
       img.display_graph(0,3);
       \endcode
       \image html ref_histogram.jpg
    **/
    CImg<T>& histogram(const unsigned int nb_levels, const T min_value=(T)0, const T max_value=(T)0) {
      return get_histogram(nb_levels,min_value,max_value).move_to(*this);
    }

    //! Compute the histogram of pixel values \newinstance.
    CImg<ulongT> get_histogram(const unsigned int nb_levels, const T min_value=(T)0, const T max_value=(T)0) const {
      if (!nb_levels || is_empty()) return CImg<ulongT>();
      T vmin = min_value<max_value?min_value:max_value, vmax = min_value<max_value?max_value:min_value;
      if (vmin==vmax && vmin==0) vmin = min_max(vmax);
      CImg<ulongT> res(nb_levels,1,1,1,0);
      cimg_for(*this,ptrs,T) {
        const T val = *ptrs;
        if (val>=vmin && val<=vmax) ++res[val==vmax?nb_levels-1:(unsigned int)((val-vmin)*nb_levels/(vmax-vmin))];
      }
      return res;
    }

    //! Equalize histogram of pixel values.
    /**
       \param nb_levels Number of histogram levels used for the equalization.
       \param min_value Minimum pixel value considered for the histogram computation. All pixel values lower than \p min_value will not be counted.
       \param max_value Maximum pixel value considered for the histogram computation. All pixel values higher than \p max_value will not be counted.
       \note
       - If \p min_value==max_value==0 (default behavior), the function first estimates the whole range of pixel values
       then uses it to equalize the histogram.
       \par Example
       \code
       const CImg<float> img("reference.jpg"), res = img.get_equalize(256);
       (img,res).display();
       \endcode
       \image html ref_equalize.jpg
    **/
    CImg<T>& equalize(const unsigned int nb_levels, const T min_value=(T)0, const T max_value=(T)0) {
      if (is_empty()) return *this;
      T vmin = min_value, vmax = max_value;
      if (vmin==vmax && vmin==0) vmin = min_max(vmax);
      if (vmin<vmax) {
        CImg<ulongT> hist = get_histogram(nb_levels,vmin,vmax);
        unsigned long cumul = 0;
        cimg_forX(hist,pos) { cumul+=hist[pos]; hist[pos] = cumul; }
        cimg_for(*this,ptrd,T) {
          const int pos = (int)((*ptrd-vmin)*(nb_levels-1)/(vmax-vmin));
          if (pos>=0 && pos<(int)nb_levels) *ptrd = (T)(vmin + (vmax-vmin)*hist[pos]/size());
        }
      }
      return *this;
    }

    //! Equalize histogram of pixel values \newinstance.
    CImg<T> get_equalize(const unsigned int nblevels, const T val_min=(T)0, const T val_max=(T)0) const {
      return (+*this).equalize(nblevels,val_min,val_max);
    }

    //! Index multi-valued pixels regarding to a specified colormap.
    /**
       \param colormap Multi-valued colormap used as the basis for multi-valued pixel indexing.
       \param dithering Level of dithering (0=disable, 1=standard level).
       \param map_indexes Tell if the values of the resulting image are the colormap indices or the colormap vectors.
       \note
       - \p img.index(colormap,dithering,1) is equivalent to <tt>img.index(colormap,dithering,0).map(colormap)</tt>.
       \par Example
       \code
       const CImg<float> img("reference.jpg"), colormap(3,1,1,3, 0,128,255, 0,128,255, 0,128,255);
       const CImg<float> res = img.get_index(colormap,1,true);
       (img,res).display();
       \endcode
       \image html ref_index.jpg
    **/
    template<typename t>
    CImg<T>& index(const CImg<t>& colormap, const float dithering=1, const bool map_indexes=false) {
      return get_index(colormap,dithering,map_indexes).move_to(*this);
    }

    //! Index multi-valued pixels regarding to a specified colormap \newinstance.
    template<typename t>
    CImg<typename CImg<t>::Tuint>
    get_index(const CImg<t>& colormap, const float dithering=1, const bool map_indexes=true) const {
      if (colormap._spectrum!=_spectrum)
        throw CImgArgumentException(_cimg_instance
                                    "index(): Instance and specified colormap (%u,%u,%u,%u,%p) "
                                    "have incompatible dimensions.",
                                    cimg_instance,
                                    colormap._width,colormap._height,colormap._depth,colormap._spectrum,colormap._data);

      typedef typename CImg<t>::Tuint tuint;
      if (is_empty()) return CImg<tuint>();
      const unsigned long whd = (unsigned long)_width*_height*_depth, pwhd = (unsigned long)colormap._width*colormap._height*colormap._depth;
      CImg<tuint> res(_width,_height,_depth,map_indexes?_spectrum:1);
      tuint *ptrd = res._data;
      if (dithering>0) { // Dithered versions.
        const float ndithering = (dithering<0?0:dithering>1?1:dithering)/16;
        Tfloat valm = 0, valM = (Tfloat)max_min(valm);
        if (valm==valM && valm>=0 && valM<=255) { valm = 0; valM = 255; }
        CImg<Tfloat> cache = get_crop(-1,0,0,0,_width,1,0,_spectrum-1);
        Tfloat *cache_current = cache.data(1,0,0,0), *cache_next = cache.data(1,1,0,0);
        const unsigned long cwhd = (unsigned long)cache._width*cache._height*cache._depth;
        switch (_spectrum) {
        case 1 : { // Optimized for scalars.
          cimg_forYZ(*this,y,z) {
            if (y<height()-2) {
              Tfloat *ptrc0 = cache_next; const T *ptrs0 = data(0,y+1,z,0);
              cimg_forX(*this,x) *(ptrc0++) = (Tfloat)*(ptrs0++);
            }
            Tfloat *ptrs0 = cache_current, *ptrsn0 = cache_next;
            cimg_forX(*this,x) {
              const Tfloat _val0 = (Tfloat)*ptrs0, val0 = _val0<valm?valm:_val0>valM?valM:_val0;
              Tfloat distmin = cimg::type<Tfloat>::max(); const t *ptrmin0 = colormap._data;
              for (const t *ptrp0 = colormap._data, *ptrp_end = ptrp0 + pwhd; ptrp0<ptrp_end; ) {
                const Tfloat pval0 = (Tfloat)*(ptrp0++) - val0, dist = pval0*pval0;
                if (dist<distmin) { ptrmin0 = ptrp0 - 1; distmin = dist; }
              }
              const Tfloat err0 = ((*(ptrs0++)=val0) - (Tfloat)*ptrmin0)*ndithering;
              *ptrs0+=7*err0; *(ptrsn0-1)+=3*err0; *(ptrsn0++)+=5*err0; *ptrsn0+=err0;
              if (map_indexes) *(ptrd++) = (tuint)*ptrmin0; else *(ptrd++) = (tuint)(ptrmin0 - colormap._data);
            }
            cimg::swap(cache_current,cache_next);
          }
        } break;
        case 2 : { // Optimized for 2d vectors.
          tuint *ptrd1 = ptrd + whd;
          cimg_forYZ(*this,y,z) {
            if (y<height()-2) {
              Tfloat *ptrc0 = cache_next, *ptrc1 = ptrc0 + cwhd;
              const T *ptrs0 = data(0,y+1,z,0), *ptrs1 = ptrs0 + whd;
              cimg_forX(*this,x) { *(ptrc0++) = (Tfloat)*(ptrs0++); *(ptrc1++) = (Tfloat)*(ptrs1++); }
            }
            Tfloat
              *ptrs0 = cache_current, *ptrs1 = ptrs0 + cwhd,
              *ptrsn0 = cache_next, *ptrsn1 = ptrsn0 + cwhd;
            cimg_forX(*this,x) {
              const Tfloat
                _val0 = (Tfloat)*ptrs0, val0 = _val0<valm?valm:_val0>valM?valM:_val0,
                _val1 = (Tfloat)*ptrs1, val1 = _val1<valm?valm:_val1>valM?valM:_val1;
              Tfloat distmin = cimg::type<Tfloat>::max(); const t *ptrmin0 = colormap._data;
              for (const t *ptrp0 = colormap._data, *ptrp1 = ptrp0 + pwhd, *ptrp_end = ptrp1; ptrp0<ptrp_end; ) {
                const Tfloat
                  pval0 = (Tfloat)*(ptrp0++) - val0, pval1 = (Tfloat)*(ptrp1++) - val1,
                  dist = pval0*pval0 + pval1*pval1;
                if (dist<distmin) { ptrmin0 = ptrp0 - 1; distmin = dist; }
              }
              const t *const ptrmin1 = ptrmin0 + pwhd;
              const Tfloat
                err0 = ((*(ptrs0++)=val0) - (Tfloat)*ptrmin0)*ndithering,
                err1 = ((*(ptrs1++)=val1) - (Tfloat)*ptrmin1)*ndithering;
              *ptrs0+=7*err0; *ptrs1+=7*err1;
              *(ptrsn0-1)+=3*err0; *(ptrsn1-1)+=3*err1;
              *(ptrsn0++)+=5*err0; *(ptrsn1++)+=5*err1;
              *ptrsn0+=err0; *ptrsn1+=err1;
              if (map_indexes) { *(ptrd++) = (tuint)*ptrmin0; *(ptrd1++) = (tuint)*ptrmin1; }
              else *(ptrd++) = (tuint)(ptrmin0 - colormap._data);
            }
            cimg::swap(cache_current,cache_next);
          }
        } break;
        case 3 : { // Optimized for 3d vectors (colors).
          tuint *ptrd1 = ptrd + whd, *ptrd2 = ptrd1 + whd;
          cimg_forYZ(*this,y,z) {
            if (y<height()-2) {
              Tfloat *ptrc0 = cache_next, *ptrc1 = ptrc0 + cwhd, *ptrc2 = ptrc1 + cwhd;
              const T *ptrs0 = data(0,y+1,z,0), *ptrs1 = ptrs0 + whd, *ptrs2 = ptrs1 + whd;
              cimg_forX(*this,x) { *(ptrc0++) = (Tfloat)*(ptrs0++); *(ptrc1++) = (Tfloat)*(ptrs1++); *(ptrc2++) = (Tfloat)*(ptrs2++); }
            }
            Tfloat
              *ptrs0 = cache_current, *ptrs1 = ptrs0 + cwhd, *ptrs2 = ptrs1 + cwhd,
              *ptrsn0 = cache_next, *ptrsn1 = ptrsn0 + cwhd, *ptrsn2 = ptrsn1 + cwhd;
            cimg_forX(*this,x) {
              const Tfloat
                _val0 = (Tfloat)*ptrs0, val0 = _val0<valm?valm:_val0>valM?valM:_val0,
                _val1 = (Tfloat)*ptrs1, val1 = _val1<valm?valm:_val1>valM?valM:_val1,
                _val2 = (Tfloat)*ptrs2, val2 = _val2<valm?valm:_val2>valM?valM:_val2;
              Tfloat distmin = cimg::type<Tfloat>::max(); const t *ptrmin0 = colormap._data;
              for (const t *ptrp0 = colormap._data, *ptrp1 = ptrp0 + pwhd, *ptrp2 = ptrp1 + pwhd, *ptrp_end = ptrp1; ptrp0<ptrp_end; ) {
                const Tfloat
                  pval0 = (Tfloat)*(ptrp0++) - val0, pval1 = (Tfloat)*(ptrp1++) - val1, pval2 = (Tfloat)*(ptrp2++) - val2,
                  dist = pval0*pval0 + pval1*pval1 + pval2*pval2;
                if (dist<distmin) { ptrmin0 = ptrp0 - 1; distmin = dist; }
              }
              const t *const ptrmin1 = ptrmin0 + pwhd, *const ptrmin2 = ptrmin1 + pwhd;
              const Tfloat
                err0 = ((*(ptrs0++)=val0) - (Tfloat)*ptrmin0)*ndithering,
                err1 = ((*(ptrs1++)=val1) - (Tfloat)*ptrmin1)*ndithering,
                err2 = ((*(ptrs2++)=val2) - (Tfloat)*ptrmin2)*ndithering;

              *ptrs0+=7*err0; *ptrs1+=7*err1; *ptrs2+=7*err2;
              *(ptrsn0-1)+=3*err0; *(ptrsn1-1)+=3*err1; *(ptrsn2-1)+=3*err2;
              *(ptrsn0++)+=5*err0; *(ptrsn1++)+=5*err1; *(ptrsn2++)+=5*err2;
              *ptrsn0+=err0; *ptrsn1+=err1; *ptrsn2+=err2;

              if (map_indexes) { *(ptrd++) = (tuint)*ptrmin0; *(ptrd1++) = (tuint)*ptrmin1; *(ptrd2++) = (tuint)*ptrmin2; }
              else *(ptrd++) = (tuint)(ptrmin0 - colormap._data);
            }
            cimg::swap(cache_current,cache_next);
          }
        } break;
        default : // Generic version
          cimg_forYZ(*this,y,z) {
            if (y<height()-2) {
              Tfloat *ptrc = cache_next;
              cimg_forC(*this,c) {
                Tfloat *_ptrc = ptrc; const T *_ptrs = data(0,y+1,z,c);
                cimg_forX(*this,x) *(_ptrc++) = (Tfloat)*(_ptrs++);
                ptrc+=cwhd;
              }
            }
            Tfloat *ptrs = cache_current, *ptrsn = cache_next;
            cimg_forX(*this,x) {
              Tfloat distmin = cimg::type<Tfloat>::max(); const t *ptrmin = colormap._data;
              for (const t *ptrp = colormap._data, *ptrp_end = ptrp + pwhd; ptrp<ptrp_end; ++ptrp) {
                Tfloat dist = 0; Tfloat *_ptrs = ptrs; const t *_ptrp = ptrp;
                cimg_forC(*this,c) {
                  const Tfloat _val = *_ptrs, val = _val<valm?valm:_val>valM?valM:_val;
                  dist+=cimg::sqr((*_ptrs=val) - (Tfloat)*_ptrp); _ptrs+=cwhd; _ptrp+=pwhd;
                }
                if (dist<distmin) { ptrmin = ptrp; distmin = dist; }
              }
              const t *_ptrmin = ptrmin; Tfloat *_ptrs = ptrs++, *_ptrsn = (ptrsn++)-1;
              cimg_forC(*this,c) {
                const Tfloat err = (*(_ptrs++) - (Tfloat)*_ptrmin)*ndithering;
                *_ptrs+=7*err; *(_ptrsn++)+=3*err; *(_ptrsn++)+=5*err; *_ptrsn+=err;
                _ptrmin+=pwhd; _ptrs+=cwhd-1; _ptrsn+=cwhd-2;
              }
              if (map_indexes) {
                tuint *_ptrd = ptrd++;
                cimg_forC(*this,c) { *_ptrd = (tuint)*ptrmin; _ptrd+=whd; ptrmin+=pwhd; }
              }
              else *(ptrd++) = (tuint)(ptrmin - colormap._data);
            }
            cimg::swap(cache_current,cache_next);
          }
        }
      } else { // Non-dithered versions
        switch (_spectrum) {
        case 1 : { // Optimized for scalars.
          for (const T *ptrs0 = _data, *ptrs_end = ptrs0 + whd; ptrs0<ptrs_end; ) {
            const Tfloat val0 = (Tfloat)*(ptrs0++);
            Tfloat distmin = cimg::type<Tfloat>::max(); const t *ptrmin0 = colormap._data;
            for (const t *ptrp0 = colormap._data, *ptrp_end = ptrp0 + pwhd; ptrp0<ptrp_end; ) {
              const Tfloat pval0 = (Tfloat)*(ptrp0++) - val0, dist = pval0*pval0;
              if (dist<distmin) { ptrmin0 = ptrp0 - 1; distmin = dist; }
            }
            if (map_indexes) *(ptrd++) = (tuint)*ptrmin0; else *(ptrd++) = (tuint)(ptrmin0 - colormap._data);
          }
        } break;
        case 2 : { // Optimized for 2d vectors.
          tuint *ptrd1 = ptrd + whd;
          for (const T *ptrs0 = _data, *ptrs1 = ptrs0 + whd, *ptrs_end = ptrs1; ptrs0<ptrs_end; ) {
            const Tfloat val0 = (Tfloat)*(ptrs0++), val1 = (Tfloat)*(ptrs1++);
            Tfloat distmin = cimg::type<Tfloat>::max(); const t *ptrmin0 = colormap._data;
            for (const t *ptrp0 = colormap._data, *ptrp1 = ptrp0 + pwhd, *ptrp_end = ptrp1; ptrp0<ptrp_end; ) {
              const Tfloat
                pval0 = (Tfloat)*(ptrp0++) - val0, pval1 = (Tfloat)*(ptrp1++) - val1,
                dist = pval0*pval0 + pval1*pval1;
              if (dist<distmin) { ptrmin0 = ptrp0 - 1; distmin = dist; }
            }
            if (map_indexes) { *(ptrd++) = (tuint)*ptrmin0; *(ptrd1++) = (tuint)*(ptrmin0 + pwhd); }
            else *(ptrd++) = (tuint)(ptrmin0 - colormap._data);
          }
        } break;
        case 3 : { // Optimized for 3d vectors (colors).
          tuint *ptrd1 = ptrd + whd, *ptrd2 = ptrd1 + whd;
          for (const T *ptrs0 = _data, *ptrs1 = ptrs0 + whd, *ptrs2 = ptrs1 + whd, *ptrs_end = ptrs1; ptrs0<ptrs_end; ) {
            const Tfloat val0 = (Tfloat)*(ptrs0++), val1 = (Tfloat)*(ptrs1++), val2 = (Tfloat)*(ptrs2++);
            Tfloat distmin = cimg::type<Tfloat>::max(); const t *ptrmin0 = colormap._data;
            for (const t *ptrp0 = colormap._data, *ptrp1 = ptrp0 + pwhd, *ptrp2 = ptrp1 + pwhd, *ptrp_end = ptrp1; ptrp0<ptrp_end; ) {
              const Tfloat
                pval0 = (Tfloat)*(ptrp0++) - val0, pval1 = (Tfloat)*(ptrp1++) - val1, pval2 = (Tfloat)*(ptrp2++) - val2,
                dist = pval0*pval0 + pval1*pval1 + pval2*pval2;
              if (dist<distmin) { ptrmin0 = ptrp0 - 1; distmin = dist; }
            }
            if (map_indexes) { *(ptrd++) = (tuint)*ptrmin0; *(ptrd1++) = (tuint)*(ptrmin0 + pwhd); *(ptrd2++) = (tuint)*(ptrmin0 + 2*pwhd); }
            else *(ptrd++) = (tuint)(ptrmin0 - colormap._data);
          }
        } break;
        default : // Generic version.
          for (const T *ptrs = _data, *ptrs_end = ptrs + whd; ptrs<ptrs_end; ++ptrs) {
            Tfloat distmin = cimg::type<Tfloat>::max(); const t *ptrmin = colormap._data;
            for (const t *ptrp = colormap._data, *ptrp_end = ptrp + pwhd; ptrp<ptrp_end; ++ptrp) {
              Tfloat dist = 0; const T *_ptrs = ptrs; const t *_ptrp = ptrp;
              cimg_forC(*this,c) { dist+=cimg::sqr((Tfloat)*_ptrs - (Tfloat)*_ptrp); _ptrs+=whd; _ptrp+=pwhd; }
              if (dist<distmin) { ptrmin = ptrp; distmin = dist; }
            }
            if (map_indexes) {
              tuint *_ptrd = ptrd++;
              cimg_forC(*this,c) { *_ptrd = (tuint)*ptrmin; _ptrd+=whd; ptrmin+=pwhd; }
            }
            else *(ptrd++) = (tuint)(ptrmin - colormap._data);
          }
        }
      }
      return res;
    }

    //! Map predefined colormap on the scalar (indexed) image instance.
    /**
       \param colormap Multi-valued colormap used for mapping the indexes.
       \par Example
       \code
       const CImg<float> img("reference.jpg"),
                         colormap1(3,1,1,3, 0,128,255, 0,128,255, 0,128,255),
                         colormap2(3,1,1,3, 255,0,0, 0,255,0, 0,0,255),
                         res = img.get_index(colormap1,0).map(colormap2);
       (img,res).display();
       \endcode
       \image html ref_map.jpg
    **/
    template<typename t>
    CImg<T>& map(const CImg<t>& colormap) {
      return get_map(colormap).move_to(*this);
    }

    //! Map predefined colormap on the scalar (indexed) image instance \newinstance.
    template<typename t>
    CImg<t> get_map(const CImg<t>& colormap) const {
      if (_spectrum!=1 && colormap._spectrum!=1)
        throw CImgArgumentException(_cimg_instance
                                    "map(): Instance and specified colormap (%u,%u,%u,%u,%p) "
                                    "have incompatible dimensions.",
                                    cimg_instance,
                                    colormap._width,colormap._height,colormap._depth,colormap._spectrum,colormap._data);

      const unsigned long whd = (unsigned long)_width*_height*_depth, pwhd = (unsigned long)colormap._width*colormap._height*colormap._depth;
      CImg<t> res(_width,_height,_depth,colormap._spectrum==1?_spectrum:colormap._spectrum);
      switch (colormap._spectrum) {
      case 1 : { // Optimized for scalars.
        const T *ptrs = _data;
        cimg_for(res,ptrd,t) {
          const unsigned long _ind = (unsigned long)*(ptrs++), ind = _ind<pwhd?_ind:0;
          *ptrd = colormap[ind];
        }
      } break;
      case 2 : { // Optimized for 2d vectors.
        const t *const ptrp0 = colormap._data, *ptrp1 = ptrp0 + pwhd;
        t *ptrd0 = res._data, *ptrd1 = ptrd0 + whd;
        for (const T *ptrs = _data, *ptrs_end = ptrs + whd; ptrs<ptrs_end; ) {
          const unsigned long _ind = (unsigned long)*(ptrs++), ind = _ind<pwhd?_ind:0;
          *(ptrd0++) = ptrp0[ind]; *(ptrd1++) = ptrp1[ind];
        }
      } break;
      case 3 : { // Optimized for 3d vectors (colors).
        const t *const ptrp0 = colormap._data, *ptrp1 = ptrp0 + pwhd, *ptrp2 = ptrp1 + pwhd;
        t *ptrd0 = res._data, *ptrd1 = ptrd0 + whd, *ptrd2 = ptrd1 + whd;
        for (const T *ptrs = _data, *ptrs_end = ptrs + whd; ptrs<ptrs_end; ) {
          const unsigned long _ind = (unsigned long)*(ptrs++), ind = _ind<pwhd?_ind:0;
          *(ptrd0++) = ptrp0[ind]; *(ptrd1++) = ptrp1[ind]; *(ptrd2++) = ptrp2[ind];
        }
      } break;
      default : { // Generic version.
        t *ptrd = res._data;
        for (const T *ptrs = _data, *ptrs_end = ptrs + whd; ptrs<ptrs_end; ) {
          const unsigned long _ind = (unsigned long)*(ptrs++), ind = _ind<pwhd?_ind:0;
          const t *ptrp = colormap._data + ind;
          t *_ptrd = ptrd++; cimg_forC(res,c) { *_ptrd = *ptrp; _ptrd+=whd; ptrp+=pwhd; }
        }
      }
      }
      return res;
    }

    //! Label connected components.
    /**
       \param is_high_connectivity Boolean that choose between 4(false)- or 8(true)-connectivity
       in 2d case, and between 6(false)- or 26(true)-connectivity in 3d case.
       \param tolerance Tolerance used to determine if two neighboring pixels belong to the same region.
       \note The algorithm of connected components computation has been primarily done
       by A. Meijster, according to the publication:
       'W.H. Hesselink, A. Meijster, C. Bron, "Concurrent Determination of Connected Components.",
       In: Science of Computer Programming 41 (2001), pp. 173--194'.
       The submitted code has then been modified to fit CImg coding style and constraints.
    **/
    CImg<T>& label(const bool is_high_connectivity=false, const Tfloat tolerance=0) {
      return get_label(is_high_connectivity,tolerance).move_to(*this);
    }

    //! Label connected components \newinstance.
    CImg<unsigned long> get_label(const bool is_high_connectivity=false,
                                  const Tfloat tolerance=0) const {
      if (is_empty()) return CImg<unsigned long>();

      // Create neighborhood tables.
      int dx[13], dy[13], dz[13], nb = 0;
      dx[nb]=1; dy[nb] = 0; dz[nb++]=0;
      dx[nb]=0; dy[nb] = 1; dz[nb++]=0;
      if (is_high_connectivity) {
        dx[nb]=1; dy[nb] = 1; dz[nb++]=0;
        dx[nb]=1; dy[nb] = -1; dz[nb++]=0;
      }
      if (_depth>1) { // 3d version.
        dx[nb]=0; dy[nb] = 0; dz[nb++]=1;
        if (is_high_connectivity) {
          dx[nb]=1; dy[nb] = 1; dz[nb++]=-1;
          dx[nb]=1; dy[nb] = 0; dz[nb++]=-1;
          dx[nb]=1; dy[nb] = -1; dz[nb++]=-1;
          dx[nb]=0; dy[nb] = 1; dz[nb++]=-1;

          dx[nb]=0; dy[nb] = 1; dz[nb++]=1;
          dx[nb]=1; dy[nb] = -1; dz[nb++]=1;
          dx[nb]=1; dy[nb] = 0; dz[nb++]=1;
          dx[nb]=1; dy[nb] = 1; dz[nb++]=1;
        }
      }
      return _get_label(nb,dx,dy,dz,tolerance);
    }

    //! Label connected components \overloading.
    /**
       \param connectivity_mask Mask of the neighboring pixels.
       \param tolerance Tolerance used to determine if two neighboring pixels belong to the same region.
    **/
    template<typename t>
    CImg<T>& label(const CImg<t>& connectivity_mask, const Tfloat tolerance=0) {
      return get_label(connectivity_mask,tolerance).move_to(*this);
    }

    //! Label connected components \newinstance.
    template<typename t>
    CImg<unsigned long> get_label(const CImg<t>& connectivity_mask,
                                  const Tfloat tolerance=0) const {
      int nb = 0;
      cimg_for(connectivity_mask,ptr,t) if (*ptr) ++nb;
      CImg<intT> dx(nb,1,1,1,0), dy(nb,1,1,1,0), dz(nb,1,1,1,0);
      nb = 0;
      cimg_forXYZ(connectivity_mask,x,y,z) if ((x || y || z) &&
                                               connectivity_mask(x,y,z)) {
        dx[nb] = x; dy[nb] = y; dz[nb++] = z;
      }
      return _get_label(nb,dx,dy,dz,tolerance);
    }

    CImg<unsigned long> _get_label(const unsigned int nb, const int
                                   *const dx, const int *const dy, const int *const dz,
                                   const Tfloat tolerance) const {
      CImg<unsigned long> res(_width,_height,_depth,_spectrum);
      cimg_forC(*this,c) {
        CImg<unsigned long> _res = res.get_shared_channel(c);

        // Init label numbers.
        unsigned long *ptr = _res.data();
        cimg_foroff(_res,p) *(ptr++) = p;

        // For each neighbour-direction, label.
        for (unsigned int n = 0; n<nb; ++n) {
          const int _dx = dx[n], _dy = dy[n], _dz = dz[n];
          if (_dx || _dy || _dz) {
            const int
              x0 = _dx<0?-_dx:0,
              x1 = _dx<0?_width:_width - _dx,
              y0 = _dy<0?-_dy:0,
              y1 = _dy<0?_height:_height - _dy,
              z0 = _dz<0?-_dz:0,
              z1 = _dz<0?_depth:_depth - _dz;
            const long wh = (long)_width*_height, offset = (long)_dz*wh + (long)_dy*_width + _dx;
            for (long z = z0, nz = z0 + _dz, pz = z0*wh; z<z1; ++z, ++nz, pz+=wh) {
              for (long y = y0, ny = y0 + _dy, py = y0*_width + pz; y<y1; ++y, ++ny, py+=_width) {
                for (long x = x0, nx = x0 + _dx, p = x0 + py; x<x1; ++x, ++nx, ++p) {
                  if ((Tfloat)cimg::abs((*this)(x,y,z,c,wh)-(*this)(nx,ny,nz,c,wh))<=tolerance) {
                    const long q = p + offset;
                    unsigned long x, y;
                    for (x = p<q?q:p, y = p<q?p:q; x!=y && _res[x]!=x; ) { x = _res[x]; if (x<y) cimg::swap(x,y); }
                    if (x!=y) _res[x] = y;
                    for (unsigned long _p = p; _p!=y; ) { const unsigned long h = _res[_p]; _res[_p] = y; _p = h; }
                    for (unsigned long _q = q; _q!=y; ) { const unsigned long h = _res[_q]; _res[_q] = y; _q = h; }
                  }
                }
              }
            }
          }
        }

        // Resolve equivalences.
        unsigned long counter = 0;
        ptr = _res.data();
        cimg_foroff(_res,p) { *ptr = *ptr==p?counter++:_res[*ptr]; ++ptr; }
      }
      return res;
    }

    // [internal] Replace possibly malicious characters for commands to be called by system() by their escaped version.
    CImg<T>& _system_strescape() {
#define cimg_system_strescape(c,s) case c : if (p!=ptrs) CImg<T>(ptrs,p-ptrs,1,1,1,false).move_to(list); \
      CImg<T>(s,std::strlen(s),1,1,1,false).move_to(list); ptrs = p+1; break
      CImgList<T> list;
      const T *ptrs = _data;
      cimg_for(*this,p,T) switch ((int)*p) {
        cimg_system_strescape('\\',"\\\\");
        cimg_system_strescape('\"',"\\\"");
        cimg_system_strescape('!',"\"\\!\"");
        cimg_system_strescape('`',"\\`");
        cimg_system_strescape('$',"\\$");
      }
      if (ptrs<end()) CImg<T>(ptrs,end()-ptrs,1,1,1,false).move_to(list);
      return (list>'x').move_to(*this);
    }

    //@}
    //---------------------------------
    //
    //! \name Color Base Management
    //@{
    //---------------------------------

    //! Return colormap \e "default", containing 256 colors entries in RGB.
    /**
       \return The following \c 256x1x1x3 colormap is returned:
       \image html ref_colormap_default.jpg
    **/
    static const CImg<Tuchar>& default_LUT256() {
      static CImg<Tuchar> colormap;
      cimg::mutex(8);
      if (!colormap) {
        colormap.assign(1,256,1,3);
        for (unsigned int index = 0, r = 16; r<256; r+=32)
          for (unsigned int g = 16; g<256; g+=32)
            for (unsigned int b = 32; b<256; b+=64) {
              colormap(0,index,0) = (Tuchar)r;
              colormap(0,index,1) = (Tuchar)g;
              colormap(0,index++,2) = (Tuchar)b;
            }
      }
      cimg::mutex(8,0);
      return colormap;
    }

    //! Return colormap \e "HSV", containing 256 colors entries in RGB.
    /**
       \return The following \c 256x1x1x3 colormap is returned:
       \image html ref_colormap_hsv.jpg
    **/
    static const CImg<Tuchar>& HSV_LUT256() {
      static CImg<Tuchar> colormap;
      cimg::mutex(8);
      if (!colormap) {
        CImg<Tint> tmp(1,256,1,3,1);
        tmp.get_shared_channel(0).sequence(0,359);
        colormap = tmp.HSVtoRGB();
      }
      cimg::mutex(8,0);
      return colormap;
    }

    //! Return colormap \e "lines", containing 256 colors entries in RGB.
    /**
       \return The following \c 256x1x1x3 colormap is returned:
       \image html ref_colormap_lines.jpg
    **/
    static const CImg<Tuchar>& lines_LUT256() {
      static const unsigned char pal[] = {
        217,62,88,75,1,237,240,12,56,160,165,116,1,1,204,2,15,248,148,185,133,141,46,246,222,116,16,5,207,226,
        17,114,247,1,214,53,238,0,95,55,233,235,109,0,17,54,33,0,90,30,3,0,94,27,19,0,68,212,166,130,0,15,7,119,
        238,2,246,198,0,3,16,10,13,2,25,28,12,6,2,99,18,141,30,4,3,140,12,4,30,233,7,10,0,136,35,160,168,184,20,
        233,0,1,242,83,90,56,180,44,41,0,6,19,207,5,31,214,4,35,153,180,75,21,76,16,202,218,22,17,2,136,71,74,
        81,251,244,148,222,17,0,234,24,0,200,16,239,15,225,102,230,186,58,230,110,12,0,7,129,249,22,241,37,219,
        1,3,254,210,3,212,113,131,197,162,123,252,90,96,209,60,0,17,0,180,249,12,112,165,43,27,229,77,40,195,12,
        87,1,210,148,47,80,5,9,1,137,2,40,57,205,244,40,8,252,98,0,40,43,206,31,187,0,180,1,69,70,227,131,108,0,
        223,94,228,35,248,243,4,16,0,34,24,2,9,35,73,91,12,199,51,1,249,12,103,131,20,224,2,70,32,
        233,1,165,3,8,154,246,233,196,5,0,6,183,227,247,195,208,36,0,0,226,160,210,198,69,153,210,1,23,8,192,2,4,
        137,1,0,52,2,249,241,129,0,0,234,7,238,71,7,32,15,157,157,252,158,2,250,6,13,30,11,162,0,199,21,11,27,224,
        4,157,20,181,111,187,218,3,0,11,158,230,196,34,223,22,248,135,254,210,157,219,0,117,239,3,255,4,227,5,247,
        11,4,3,188,111,11,105,195,2,0,14,1,21,219,192,0,183,191,113,241,1,12,17,248,0,48,7,19,1,254,212,0,239,246,
        0,23,0,250,165,194,194,17,3,253,0,24,6,0,141,167,221,24,212,2,235,243,0,0,205,1,251,133,204,28,4,6,1,10,
        141,21,74,12,236,254,228,19,1,0,214,1,186,13,13,6,13,16,27,209,6,216,11,207,251,59,32,9,155,23,19,235,143,
        116,6,213,6,75,159,23,6,0,228,4,10,245,249,1,7,44,234,4,102,174,0,19,239,103,16,15,18,8,214,22,4,47,244,
        255,8,0,251,173,1,212,252,250,251,252,6,0,29,29,222,233,246,5,149,0,182,180,13,151,0,203,183,0,35,149,0,
        235,246,254,78,9,17,203,73,11,195,0,3,5,44,0,0,237,5,106,6,130,16,214,20,168,247,168,4,207,11,5,1,232,251,
        129,210,116,231,217,223,214,27,45,38,4,177,186,249,7,215,172,16,214,27,249,230,236,2,34,216,217,0,175,30,
        243,225,244,182,20,212,2,226,21,255,20,0,2,13,62,13,191,14,76,64,20,121,4,118,0,216,1,147,0,2,210,1,215,
        95,210,236,225,184,46,0,248,24,11,1,9,141,250,243,9,221,233,160,11,147,2,55,8,23,12,253,9,0,54,0,231,6,3,
        141,8,2,246,9,180,5,11,8,227,8,43,110,242,1,130,5,97,36,10,6,219,86,133,11,108,6,1,5,244,67,19,28,0,174,
        154,16,127,149,252,188,196,196,228,244,9,249,0,0,0,37,170,32,250,0,73,255,23,3,224,234,38,195,198,0,255,87,
        33,221,174,31,3,0,189,228,6,153,14,144,14,108,197,0,9,206,245,254,3,16,253,178,248,0,95,125,8,0,3,168,21,
        23,168,19,50,240,244,185,0,1,144,10,168,31,82,1,13 };
      static const CImg<Tuchar> colormap(pal,1,256,1,3,false);
      return colormap;
    }

    //! Return colormap \e "hot", containing 256 colors entries in RGB.
    /**
       \return The following \c 256x1x1x3 colormap is returned:
       \image html ref_colormap_hot.jpg
    **/
    static const CImg<Tuchar>& hot_LUT256() {
      static CImg<Tuchar> colormap;
      cimg::mutex(8);
      if (!colormap) {
        colormap.assign(1,4,1,3,0);
        colormap[1] = colormap[2] = colormap[3] = colormap[6] = colormap[7] = colormap[11] = 255;
        colormap.resize(1,256,1,3,3);
      }
      cimg::mutex(8,0);
      return colormap;
    }

    //! Return colormap \e "cool", containing 256 colors entries in RGB.
    /**
       \return The following \c 256x1x1x3 colormap is returned:
       \image html ref_colormap_cool.jpg
    **/
    static const CImg<Tuchar>& cool_LUT256() {
      static CImg<Tuchar> colormap;
      cimg::mutex(8);
      if (!colormap) colormap.assign(1,2,1,3).fill(0,255,255,0,255,255).resize(1,256,1,3,3);
      cimg::mutex(8,0);
      return colormap;
    }

    //! Return colormap \e "jet", containing 256 colors entries in RGB.
    /**
       \return The following \c 256x1x1x3 colormap is returned:
       \image html ref_colormap_jet.jpg
    **/
    static const CImg<Tuchar>& jet_LUT256() {
      static CImg<Tuchar> colormap;
      cimg::mutex(8);
      if (!colormap) {
        colormap.assign(1,4,1,3,0);
        colormap[2] = colormap[3] = colormap[5] = colormap[6] = colormap[8] = colormap[9] = 255;
        colormap.resize(1,256,1,3,3);
      }
      cimg::mutex(8,0);
      return colormap;
    }

    //! Return colormap \e "flag", containing 256 colors entries in RGB.
    /**
       \return The following \c 256x1x1x3 colormap is returned:
       \image html ref_colormap_flag.jpg
    **/
    static const CImg<Tuchar>& flag_LUT256() {
      static CImg<Tuchar> colormap;
      cimg::mutex(8);
      if (!colormap) {
        colormap.assign(1,4,1,3,0);
        colormap[0] = colormap[1] = colormap[5] = colormap[9] = colormap[10] = 255;
        colormap.resize(1,256,1,3,0,2);
      }
      cimg::mutex(8,0);
      return colormap;
    }

    //! Return colormap \e "cube", containing 256 colors entries in RGB.
    /**
       \return The following \c 256x1x1x3 colormap is returned:
       \image html ref_colormap_cube.jpg
    **/
    static const CImg<Tuchar>& cube_LUT256() {
      static CImg<Tuchar> colormap;
      cimg::mutex(8);
      if (!colormap) {
        colormap.assign(1,8,1,3,0);
        colormap[1] = colormap[3] = colormap[5] = colormap[7] =
          colormap[10] = colormap[11] = colormap[12] = colormap[13] =
          colormap[20] = colormap[21] = colormap[22] = colormap[23] = 255;
        colormap.resize(1,256,1,3,3);
      }
      cimg::mutex(8,0);
      return colormap;
    }

    //! Convert pixel values from sRGB to RGB color spaces.
    CImg<T>& sRGBtoRGB() {
      cimg_for(*this,ptr,T) {
        const Tfloat
          sval = (Tfloat)*ptr,
          nsval = (sval<0?0:sval>255?255:sval)/255,
          val = (Tfloat)(nsval<=0.04045f?nsval/12.92f:std::pow((nsval+0.055f)/(1.055f),2.4f));
        *ptr = (T)(val*255);
      }
      return *this;
    }

    //! Convert pixel values from sRGB to RGB color spaces \newinstance.
    CImg<Tfloat> get_sRGBtoRGB() const {
      return CImg<Tfloat>(*this,false).sRGBtoRGB();
    }

    //! Convert pixel values from RGB to sRGB color spaces.
    CImg<T>& RGBtosRGB() {
      cimg_for(*this,ptr,T) {
        const Tfloat
          val = (Tfloat)*ptr,
          nval = (val<0?0:val>255?255:val)/255,
          sval = (Tfloat)(nval<=0.0031308f?nval*12.92f:1.055f*std::pow(nval,0.416667f)-0.055f);
        *ptr = (T)(sval*255);
      }
      return *this;
    }

    //! Convert pixel values from RGB to sRGB color spaces \newinstance.
    CImg<Tfloat> get_RGBtosRGB() const {
      return CImg<Tfloat>(*this,false).RGBtosRGB();
    }

    //! Convert pixel values from RGB to HSV color spaces.
    CImg<T>& RGBtoHSV() {
      if (_spectrum!=3)
        throw CImgInstanceException(_cimg_instance
                                    "RGBtoHSV(): Instance is not a RGB image.",
                                    cimg_instance);

      T *p1 = data(0,0,0,0), *p2 = data(0,0,0,1), *p3 = data(0,0,0,2);
      for (unsigned long N = (unsigned long)_width*_height*_depth; N; --N) {
        const Tfloat
          R = (Tfloat)*p1,
          G = (Tfloat)*p2,
          B = (Tfloat)*p3,
          nR = (R<0?0:(R>255?255:R))/255,
          nG = (G<0?0:(G>255?255:G))/255,
          nB = (B<0?0:(B>255?255:B))/255,
          m = cimg::min(nR,nG,nB),
          M = cimg::max(nR,nG,nB);
        Tfloat H = 0, S = 0;
        if (M!=m) {
          const Tfloat
            f = (nR==m)?(nG-nB):((nG==m)?(nB-nR):(nR-nG)),
            i = (Tfloat)((nR==m)?3:((nG==m)?5:1));
          H = (i-f/(M-m));
          if (H>=6) H-=6;
          H*=60;
          S = (M-m)/M;
        }
        *(p1++) = (T)H;
        *(p2++) = (T)S;
        *(p3++) = (T)M;
      }
      return *this;
    }

    //! Convert pixel values from RGB to HSV color spaces \newinstance.
    CImg<Tfloat> get_RGBtoHSV() const {
      return CImg<Tfloat>(*this,false).RGBtoHSV();
    }

    //! Convert pixel values from HSV to RGB color spaces.
    CImg<T>& HSVtoRGB() {
      if (_spectrum!=3)
        throw CImgInstanceException(_cimg_instance
                                    "HSVtoRGB(): Instance is not a HSV image.",
                                    cimg_instance);

      T *p1 = data(0,0,0,0), *p2 = data(0,0,0,1), *p3 = data(0,0,0,2);
      for (unsigned long N = (unsigned long)_width*_height*_depth; N; --N) {
        Tfloat
          H = (Tfloat)*p1,
          S = (Tfloat)*p2,
          V = (Tfloat)*p3,
          R = 0, G = 0, B = 0;
        if (H==0 && S==0) R = G = B = V;
        else {
          H/=60;
          const int i = (int)std::floor(H);
          const Tfloat
            f = (i&1)?(H - i):(1 - H + i),
            m = V*(1 - S),
            n = V*(1 - S*f);
          switch (i) {
          case 6 :
          case 0 : R = V; G = n; B = m; break;
          case 1 : R = n; G = V; B = m; break;
          case 2 : R = m; G = V; B = n; break;
          case 3 : R = m; G = n; B = V; break;
          case 4 : R = n; G = m; B = V; break;
          case 5 : R = V; G = m; B = n; break;
          }
        }
        R*=255; G*=255; B*=255;
        *(p1++) = (T)(R<0?0:(R>255?255:R));
        *(p2++) = (T)(G<0?0:(G>255?255:G));
        *(p3++) = (T)(B<0?0:(B>255?255:B));
      }
      return *this;
    }

    //! Convert pixel values from HSV to RGB color spaces \newinstance.
    CImg<Tuchar> get_HSVtoRGB() const {
      return CImg<Tuchar>(*this,false).HSVtoRGB();
    }

    //! Convert pixel values from RGB to HSL color spaces.
    CImg<T>& RGBtoHSL() {
      if (_spectrum!=3)
        throw CImgInstanceException(_cimg_instance
                                    "RGBtoHSL(): Instance is not a RGB image.",
                                    cimg_instance);

      T *p1 = data(0,0,0,0), *p2 = data(0,0,0,1), *p3 = data(0,0,0,2);
      for (unsigned long N = (unsigned long)_width*_height*_depth; N; --N) {
        const Tfloat
          R = (Tfloat)*p1,
          G = (Tfloat)*p2,
          B = (Tfloat)*p3,
          nR = (R<0?0:(R>255?255:R))/255,
          nG = (G<0?0:(G>255?255:G))/255,
          nB = (B<0?0:(B>255?255:B))/255,
          m = cimg::min(nR,nG,nB),
          M = cimg::max(nR,nG,nB),
          L = (m + M)/2;
        Tfloat H = 0, S = 0;
        if (M==m) H = S = 0;
        else {
          const Tfloat
            f = (nR==m)?(nG-nB):((nG==m)?(nB-nR):(nR-nG)),
            i = (nR==m)?3.0f:((nG==m)?5.0f:1.0f);
          H = (i-f/(M-m));
          if (H>=6) H-=6;
          H*=60;
          S = (2*L<=1)?((M-m)/(M+m)):((M-m)/(2-M-m));
        }
        *(p1++) = (T)H;
        *(p2++) = (T)S;
        *(p3++) = (T)L;
      }
      return *this;
    }

    //! Convert pixel values from RGB to HSL color spaces \newinstance.
    CImg<Tfloat> get_RGBtoHSL() const {
      return CImg< Tfloat>(*this,false).RGBtoHSL();
    }

    //! Convert pixel values from HSL to RGB color spaces.
    CImg<T>& HSLtoRGB() {
      if (_spectrum!=3)
        throw CImgInstanceException(_cimg_instance
                                    "HSLtoRGB(): Instance is not a HSL image.",
                                    cimg_instance);

      T *p1 = data(0,0,0,0), *p2 = data(0,0,0,1), *p3 = data(0,0,0,2);
      for (unsigned long N = (unsigned long)_width*_height*_depth; N; --N) {
        const Tfloat
          H = (Tfloat)*p1,
          S = (Tfloat)*p2,
          L = (Tfloat)*p3,
          q = 2*L<1?L*(1+S):(L+S-L*S),
          p = 2*L-q,
          h = H/360,
          tr = h + 1.0f/3,
          tg = h,
          tb = h - 1.0f/3,
          ntr = tr<0?tr+1:(tr>1?tr-1:tr),
          ntg = tg<0?tg+1:(tg>1?tg-1:tg),
          ntb = tb<0?tb+1:(tb>1?tb-1:tb),
          R = 255*(6*ntr<1?p+(q-p)*6*ntr:(2*ntr<1?q:(3*ntr<2?p+(q-p)*6*(2.0f/3-ntr):p))),
          G = 255*(6*ntg<1?p+(q-p)*6*ntg:(2*ntg<1?q:(3*ntg<2?p+(q-p)*6*(2.0f/3-ntg):p))),
          B = 255*(6*ntb<1?p+(q-p)*6*ntb:(2*ntb<1?q:(3*ntb<2?p+(q-p)*6*(2.0f/3-ntb):p)));
        *(p1++) = (T)(R<0?0:(R>255?255:R));
        *(p2++) = (T)(G<0?0:(G>255?255:G));
        *(p3++) = (T)(B<0?0:(B>255?255:B));
      }
      return *this;
    }

    //! Convert pixel values from HSL to RGB color spaces \newinstance.
    CImg<Tuchar> get_HSLtoRGB() const {
      return CImg<Tuchar>(*this,false).HSLtoRGB();
    }

    //! Convert pixel values from RGB to HSI color spaces.
    CImg<T>& RGBtoHSI() {
      if (_spectrum!=3)
        throw CImgInstanceException(_cimg_instance
                                    "RGBtoHSI(): Instance is not a RGB image.",
                                    cimg_instance);

      T *p1 = data(0,0,0,0), *p2 = data(0,0,0,1), *p3 = data(0,0,0,2);
      for (unsigned long N = (unsigned long)_width*_height*_depth; N; --N) {
        const Tfloat
          R = (Tfloat)*p1,
          G = (Tfloat)*p2,
          B = (Tfloat)*p3,
          nR = (R<0?0:(R>255?255:R))/255,
          nG = (G<0?0:(G>255?255:G))/255,
          nB = (B<0?0:(B>255?255:B))/255,
          m = cimg::min(nR,nG,nB),
          theta = (Tfloat)(std::acos(0.5f*((nR-nG)+(nR-nB))/std::sqrt(std::pow(nR-nG,2)+(nR-nB)*(nG-nB)))*180/cimg::PI),
          sum = nR + nG + nB;
        Tfloat H = 0, S = 0, I = 0;
        if (theta>0) H = (nB<=nG)?theta:360-theta;
        if (sum>0) S = 1 - 3/sum*m;
        I = sum/3;
        *(p1++) = (T)H;
        *(p2++) = (T)S;
        *(p3++) = (T)I;
      }
      return *this;
    }

    //! Convert pixel values from RGB to HSI color spaces \newinstance.
    CImg<Tfloat> get_RGBtoHSI() const {
      return CImg<Tfloat>(*this,false).RGBtoHSI();
    }

    //! Convert pixel values from HSI to RGB color spaces.
    CImg<T>& HSItoRGB() {
      if (_spectrum!=3)
        throw CImgInstanceException(_cimg_instance
                                    "HSItoRGB(): Instance is not a HSI image.",
                                    cimg_instance);

      T *p1 = data(0,0,0,0), *p2 = data(0,0,0,1), *p3 = data(0,0,0,2);
      for (unsigned long N = (unsigned long)_width*_height*_depth; N; --N) {
        Tfloat
          H = (Tfloat)*p1,
          S = (Tfloat)*p2,
          I = (Tfloat)*p3,
          a = I*(1-S),
          R = 0, G = 0, B = 0;
        if (H<120) {
          B = a;
          R = (Tfloat)(I*(1+S*std::cos(H*cimg::PI/180)/std::cos((60-H)*cimg::PI/180)));
          G = 3*I-(R+B);
        } else if (H<240) {
          H-=120;
          R = a;
          G = (Tfloat)(I*(1+S*std::cos(H*cimg::PI/180)/std::cos((60-H)*cimg::PI/180)));
          B = 3*I-(R+G);
        } else {
          H-=240;
          G = a;
          B = (Tfloat)(I*(1+S*std::cos(H*cimg::PI/180)/std::cos((60-H)*cimg::PI/180)));
          R = 3*I-(G+B);
        }
        R*=255; G*=255; B*=255;
        *(p1++) = (T)(R<0?0:(R>255?255:R));
        *(p2++) = (T)(G<0?0:(G>255?255:G));
        *(p3++) = (T)(B<0?0:(B>255?255:B));
      }
      return *this;
    }

    //! Convert pixel values from HSI to RGB color spaces \newinstance.
    CImg<Tfloat> get_HSItoRGB() const {
      return CImg< Tuchar>(*this,false).HSItoRGB();
    }

    //! Convert pixel values from RGB to YCbCr color spaces.
    CImg<T>& RGBtoYCbCr() {
      if (_spectrum!=3)
        throw CImgInstanceException(_cimg_instance
                                    "RGBtoYCbCr(): Instance is not a RGB image.",
                                    cimg_instance);

      T *p1 = data(0,0,0,0), *p2 = data(0,0,0,1), *p3 = data(0,0,0,2);
      for (unsigned long N = (unsigned long)_width*_height*_depth; N; --N) {
        const Tfloat
          R = (Tfloat)*p1,
          G = (Tfloat)*p2,
          B = (Tfloat)*p3,
          Y = (66*R + 129*G + 25*B + 128)/256 + 16,
          Cb = (-38*R - 74*G + 112*B + 128)/256 + 128,
          Cr = (112*R - 94*G - 18*B + 128)/256 + 128;
        *(p1++) = (T)(Y<0?0:(Y>255?255:Y));
        *(p2++) = (T)(Cb<0?0:(Cb>255?255:Cb));
        *(p3++) = (T)(Cr<0?0:(Cr>255?255:Cr));
      }
      return *this;
    }

    //! Convert pixel values from RGB to YCbCr color spaces \newinstance.
    CImg<Tuchar> get_RGBtoYCbCr() const {
      return CImg<Tuchar>(*this,false).RGBtoYCbCr();
    }

    //! Convert pixel values from RGB to YCbCr color spaces.
    CImg<T>& YCbCrtoRGB() {
      if (_spectrum!=3)
        throw CImgInstanceException(_cimg_instance
                                    "YCbCrtoRGB(): Instance is not a YCbCr image.",
                                    cimg_instance);

      T *p1 = data(0,0,0,0), *p2 = data(0,0,0,1), *p3 = data(0,0,0,2);
      for (unsigned long N = (unsigned long)_width*_height*_depth; N; --N) {
        const Tfloat
          Y = (Tfloat)*p1 - 16,
          Cb = (Tfloat)*p2 - 128,
          Cr = (Tfloat)*p3 - 128,
          R = (298*Y + 409*Cr + 128)/256,
          G = (298*Y - 100*Cb - 208*Cr + 128)/256,
          B = (298*Y + 516*Cb + 128)/256;
        *(p1++) = (T)(R<0?0:(R>255?255:R));
        *(p2++) = (T)(G<0?0:(G>255?255:G));
        *(p3++) = (T)(B<0?0:(B>255?255:B));
      }
      return *this;
    }

    //! Convert pixel values from RGB to YCbCr color spaces \newinstance.
    CImg<Tuchar> get_YCbCrtoRGB() const {
      return CImg<Tuchar>(*this,false).YCbCrtoRGB();
    }

    //! Convert pixel values from RGB to YUV color spaces.
    CImg<T>& RGBtoYUV() {
      if (_spectrum!=3)
        throw CImgInstanceException(_cimg_instance
                                    "RGBtoYUV(): Instance is not a RGB image.",
                                    cimg_instance);

      T *p1 = data(0,0,0,0), *p2 = data(0,0,0,1), *p3 = data(0,0,0,2);
      for (unsigned long N = (unsigned long)_width*_height*_depth; N; --N) {
        const Tfloat
          R = (Tfloat)*p1/255,
          G = (Tfloat)*p2/255,
          B = (Tfloat)*p3/255,
          Y = 0.299f*R + 0.587f*G + 0.114f*B;
        *(p1++) = (T)Y;
        *(p2++) = (T)(0.492f*(B-Y));
        *(p3++) = (T)(0.877*(R-Y));
      }
      return *this;
    }

    //! Convert pixel values from RGB to YUV color spaces \newinstance.
    CImg<Tfloat> get_RGBtoYUV() const {
      return CImg<Tfloat>(*this,false).RGBtoYUV();
    }

    //! Convert pixel values from YUV to RGB color spaces.
    CImg<T>& YUVtoRGB() {
      if (_spectrum!=3)
        throw CImgInstanceException(_cimg_instance
                                    "YUVtoRGB(): Instance is not a YUV image.",
                                    cimg_instance);

      T *p1 = data(0,0,0,0), *p2 = data(0,0,0,1), *p3 = data(0,0,0,2);
      for (unsigned long N = (unsigned long)_width*_height*_depth; N; --N) {
        const Tfloat
          Y = (Tfloat)*p1,
          U = (Tfloat)*p2,
          V = (Tfloat)*p3,
          R = (Y + 1.140f*V)*255,
          G = (Y - 0.395f*U - 0.581f*V)*255,
          B = (Y + 2.032f*U)*255;
        *(p1++) = (T)(R<0?0:(R>255?255:R));
        *(p2++) = (T)(G<0?0:(G>255?255:G));
        *(p3++) = (T)(B<0?0:(B>255?255:B));
      }
      return *this;
    }

    //! Convert pixel values from YUV to RGB color spaces \newinstance.
    CImg<Tuchar> get_YUVtoRGB() const {
      return CImg< Tuchar>(*this,false).YUVtoRGB();
    }

    //! Convert pixel values from RGB to CMY color spaces.
    CImg<T>& RGBtoCMY() {
      if (_spectrum!=3)
        throw CImgInstanceException(_cimg_instance
                                    "RGBtoCMY(): Instance is not a RGB image.",
                                    cimg_instance);

      T *p1 = data(0,0,0,0), *p2 = data(0,0,0,1), *p3 = data(0,0,0,2);
      for (unsigned long N = (unsigned long)_width*_height*_depth; N; --N) {
        const Tfloat
          R = (Tfloat)*p1,
          G = (Tfloat)*p2,
          B = (Tfloat)*p3,
          C = 255 - R,
          M = 255 - G,
          Y = 255 - B;
        *(p1++) = (T)(C<0?0:(C>255?255:C));
        *(p2++) = (T)(M<0?0:(M>255?255:M));
        *(p3++) = (T)(Y<0?0:(Y>255?255:Y));
      }
      return *this;
    }

    //! Convert pixel values from RGB to CMY color spaces \newinstance.
    CImg<Tuchar> get_RGBtoCMY() const {
      return CImg<Tfloat>(*this,false).RGBtoCMY();
    }

    //! Convert pixel values from CMY to RGB color spaces.
    CImg<T>& CMYtoRGB() {
      if (_spectrum!=3)
        throw CImgInstanceException(_cimg_instance
                                    "CMYtoRGB(): Instance is not a CMY image.",
                                    cimg_instance);

      T *p1 = data(0,0,0,0), *p2 = data(0,0,0,1), *p3 = data(0,0,0,2);
      for (unsigned long N = (unsigned long)_width*_height*_depth; N; --N) {
        const Tfloat
          C = (Tfloat)*p1,
          M = (Tfloat)*p2,
          Y = (Tfloat)*p3,
          R = 255 - C,
          G = 255 - M,
          B = 255 - Y;
        *(p1++) = (T)(R<0?0:(R>255?255:R));
        *(p2++) = (T)(G<0?0:(G>255?255:G));
        *(p3++) = (T)(B<0?0:(B>255?255:B));
      }
      return *this;
    }

    //! Convert pixel values from CMY to RGB color spaces \newinstance.
    CImg<Tuchar> get_CMYtoRGB() const {
      return CImg<Tuchar>(*this,false).CMYtoRGB();
    }

    //! Convert pixel values from CMY to CMYK color spaces.
    CImg<T>& CMYtoCMYK() {
      return get_CMYtoCMYK().move_to(*this);
    }

    //! Convert pixel values from CMY to CMYK color spaces \newinstance.
    CImg<Tuchar> get_CMYtoCMYK() const {
      if (_spectrum!=3)
        throw CImgInstanceException(_cimg_instance
                                    "CMYtoCMYK(): Instance is not a CMY image.",
                                    cimg_instance);

      CImg<Tfloat> res(_width,_height,_depth,4);
      const T *ps1 = data(0,0,0,0), *ps2 = data(0,0,0,1), *ps3 = data(0,0,0,2);
      Tfloat *pd1 = res.data(0,0,0,0), *pd2 = res.data(0,0,0,1), *pd3 = res.data(0,0,0,2), *pd4 = res.data(0,0,0,3);
      for (unsigned long N = (unsigned long)_width*_height*_depth; N; --N) {
        Tfloat
	  C = (Tfloat)*(ps1++),
	  M = (Tfloat)*(ps2++),
	  Y = (Tfloat)*(ps3++),
	  K = cimg::min(C,M,Y);
	if (K>=255) C = M = Y = 0;
	else { const Tfloat K1 = 255 - K; C = 255*(C - K)/K1; M = 255*(M - K)/K1; Y = 255*(Y - K)/K1; }
        *(pd1++) = (Tfloat)(C<0?0:(C>255?255:C));
        *(pd2++) = (Tfloat)(M<0?0:(M>255?255:M));
        *(pd3++) = (Tfloat)(Y<0?0:(Y>255?255:Y));
        *(pd4++) = (Tfloat)(K<0?0:(K>255?255:K));
      }
      return res;
    }

    //! Convert pixel values from CMYK to CMY color spaces.
    CImg<T>& CMYKtoCMY() {
      return get_CMYKtoCMY().move_to(*this);
    }

    //! Convert pixel values from CMYK to CMY color spaces \newinstance.
    CImg<Tfloat> get_CMYKtoCMY() const {
      if (_spectrum!=4)
        throw CImgInstanceException(_cimg_instance
                                    "CMYKtoCMY(): Instance is not a CMYK image.",
                                    cimg_instance);

      CImg<Tfloat> res(_width,_height,_depth,3);
      const T *ps1 = data(0,0,0,0), *ps2 = data(0,0,0,1), *ps3 = data(0,0,0,2), *ps4 = data(0,0,0,3);
      Tfloat *pd1 = res.data(0,0,0,0), *pd2 = res.data(0,0,0,1), *pd3 = res.data(0,0,0,2);
      for (unsigned long N = (unsigned long)_width*_height*_depth; N; --N) {
        const Tfloat
	  C = (Tfloat)*(ps1++),
	  M = (Tfloat)*(ps2++),
	  Y = (Tfloat)*(ps3++),
	  K = (Tfloat)*(ps4++),
	  K1 = 1 - K/255,
          nC = C*K1 + K,
          nM = M*K1 + K,
          nY = Y*K1 + K;
        *(pd1++) = (Tfloat)(nC<0?0:(nC>255?255:nC));
        *(pd2++) = (Tfloat)(nM<0?0:(nM>255?255:nM));
        *(pd3++) = (Tfloat)(nY<0?0:(nY>255?255:nY));
      }
      return res;
    }

    //! Convert pixel values from RGB to XYZ_709 color spaces.
    /**
       \note Uses the standard D65 white point.
    **/
    CImg<T>& RGBtoXYZ() {
      if (_spectrum!=3)
        throw CImgInstanceException(_cimg_instance
                                    "RGBtoXYZ(): Instance is not a RGB image.",
                                    cimg_instance);

      T *p1 = data(0,0,0,0), *p2 = data(0,0,0,1), *p3 = data(0,0,0,2);
      for (unsigned long N = (unsigned long)_width*_height*_depth; N; --N) {
        const Tfloat
          R = (Tfloat)*p1/255,
          G = (Tfloat)*p2/255,
          B = (Tfloat)*p3/255;
        *(p1++) = (T)(0.412453f*R + 0.357580f*G + 0.180423f*B);
        *(p2++) = (T)(0.212671f*R + 0.715160f*G + 0.072169f*B);
        *(p3++) = (T)(0.019334f*R + 0.119193f*G + 0.950227f*B);
      }
      return *this;
    }

    //! Convert pixel values from RGB to XYZ_709 color spaces \newinstance.
    CImg<Tfloat> get_RGBtoXYZ() const {
      return CImg<Tfloat>(*this,false).RGBtoXYZ();
    }

    //! Convert pixel values from XYZ_709 to RGB color spaces.
    CImg<T>& XYZtoRGB() {
      if (_spectrum!=3)
        throw CImgInstanceException(_cimg_instance
                                    "XYZtoRGB(): Instance is not a XYZ image.",
                                    cimg_instance);

      T *p1 = data(0,0,0,0), *p2 = data(0,0,0,1), *p3 = data(0,0,0,2);
      for (unsigned long N = (unsigned long)_width*_height*_depth; N; --N) {
        const Tfloat
          X = (Tfloat)*p1*255,
          Y = (Tfloat)*p2*255,
          Z = (Tfloat)*p3*255,
          R = 3.240479f*X  - 1.537150f*Y - 0.498535f*Z,
          G = -0.969256f*X + 1.875992f*Y + 0.041556f*Z,
          B = 0.055648f*X  - 0.204043f*Y + 1.057311f*Z;
        *(p1++) = (T)(R<0?0:(R>255?255:R));
        *(p2++) = (T)(G<0?0:(G>255?255:G));
        *(p3++) = (T)(B<0?0:(B>255?255:B));
      }
      return *this;
    }

    //! Convert pixel values from XYZ_709 to RGB color spaces \newinstance.
    CImg<Tuchar> get_XYZtoRGB() const {
      return CImg<Tuchar>(*this,false).XYZtoRGB();
    }

    //! Convert pixel values from XYZ_709 to Lab color spaces.
    CImg<T>& XYZtoLab() {
#define _cimg_Labf(x) ((x)>=0.008856f?(std::pow(x,(Tfloat)1/3)):(7.787f*(x)+16.0f/116))

      if (_spectrum!=3)
        throw CImgInstanceException(_cimg_instance
                                    "XYZtoLab(): Instance is not a XYZ image.",
                                    cimg_instance);

      const Tfloat
        Xn = (Tfloat)(0.412453f + 0.357580f + 0.180423f),
        Yn = (Tfloat)(0.212671f + 0.715160f + 0.072169f),
        Zn = (Tfloat)(0.019334f + 0.119193f + 0.950227f);
      T *p1 = data(0,0,0,0), *p2 = data(0,0,0,1), *p3 = data(0,0,0,2);
      for (unsigned long N = (unsigned long)_width*_height*_depth; N; --N) {
        const Tfloat
          X = (Tfloat)*p1,
          Y = (Tfloat)*p2,
          Z = (Tfloat)*p3,
          XXn = X/Xn, YYn = Y/Yn, ZZn = Z/Zn,
          fX = (Tfloat)_cimg_Labf(XXn),
          fY = (Tfloat)_cimg_Labf(YYn),
          fZ = (Tfloat)_cimg_Labf(ZZn);
        *(p1++) = (T)cimg::max(0.0f,116*fY - 16);
        *(p2++) = (T)(500*(fX - fY));
        *(p3++) = (T)(200*(fY - fZ));
      }
      return *this;
    }

    //! Convert pixel values from XYZ_709 to Lab color spaces \newinstance.
    CImg<Tfloat> get_XYZtoLab() const {
      return CImg<Tfloat>(*this,false).XYZtoLab();
    }

    //! Convert pixel values from Lab to XYZ_709 color spaces.
    CImg<T>& LabtoXYZ() {
#define _cimg_Labfi(x) ((x)>=0.206893f?((x)*(x)*(x)):(((x)-16.0f/116)/7.787f))

      if (_spectrum!=3)
        throw CImgInstanceException(_cimg_instance
                                    "LabtoXYZ(): Instance is not a Lab image.",
                                    cimg_instance);

      const Tfloat
        Xn = (Tfloat)(0.412453f + 0.357580f + 0.180423f),
        Yn = (Tfloat)(0.212671f + 0.715160f + 0.072169f),
        Zn = (Tfloat)(0.019334f + 0.119193f + 0.950227f);
      T *p1 = data(0,0,0,0), *p2 = data(0,0,0,1), *p3 = data(0,0,0,2);
      for (unsigned long N = (unsigned long)_width*_height*_depth; N; --N) {
        const Tfloat
          L = (Tfloat)*p1,
          a = (Tfloat)*p2,
          b = (Tfloat)*p3,
          cY = (L + 16)/116,
          Y = (Tfloat)(Yn*_cimg_Labfi(cY)),
          pY = (Tfloat)std::pow(Y/Yn,(Tfloat)1/3),
          cX = a/500 + pY,
          X = Xn*cX*cX*cX,
          cZ = pY - b/200,
          Z = Zn*cZ*cZ*cZ;
        *(p1++) = (T)(X);
        *(p2++) = (T)(Y);
        *(p3++) = (T)(Z);
      }
      return *this;
    }

    //! Convert pixel values from Lab to XYZ_709 color spaces \newinstance.
    CImg<Tfloat> get_LabtoXYZ() const {
      return CImg<Tfloat>(*this,false).LabtoXYZ();
    }

    //! Convert pixel values from XYZ_709 to xyY color spaces.
    CImg<T>& XYZtoxyY() {
      if (_spectrum!=3)
        throw CImgInstanceException(_cimg_instance
                                    "XYZtoxyY(): Instance is not a XYZ image.",
                                    cimg_instance);

      T *p1 = data(0,0,0,0), *p2 = data(0,0,0,1), *p3 = data(0,0,0,2);
      for (unsigned long N = (unsigned long)_width*_height*_depth; N; --N) {
        const Tfloat
          X = (Tfloat)*p1,
          Y = (Tfloat)*p2,
          Z = (Tfloat)*p3,
          sum = (X+Y+Z),
          nsum = sum>0?sum:1;
        *(p1++) = (T)(X/nsum);
        *(p2++) = (T)(Y/nsum);
        *(p3++) = (T)Y;
      }
      return *this;
    }

    //! Convert pixel values from XYZ_709 to xyY color spaces \newinstance.
    CImg<Tfloat> get_XYZtoxyY() const {
      return CImg<Tfloat>(*this,false).XYZtoxyY();
    }

    //! Convert pixel values from xyY pixels to XYZ_709 color spaces.
    CImg<T>& xyYtoXYZ() {
      if (_spectrum!=3)
        throw CImgInstanceException(_cimg_instance
                                    "xyYtoXYZ(): Instance is not a xyY image.",
                                    cimg_instance);

      T *p1 = data(0,0,0,0), *p2 = data(0,0,0,1), *p3 = data(0,0,0,2);
      for (unsigned long N = (unsigned long)_width*_height*_depth; N; --N) {
        const Tfloat
         px = (Tfloat)*p1,
         py = (Tfloat)*p2,
         Y = (Tfloat)*p3,
         ny = py>0?py:1;
        *(p1++) = (T)(px*Y/ny);
        *(p2++) = (T)Y;
        *(p3++) = (T)((1-px-py)*Y/ny);
      }
      return *this;
    }

    //! Convert pixel values from xyY pixels to XYZ_709 color spaces \newinstance.
    CImg<Tfloat> get_xyYtoXYZ() const {
      return CImg<Tfloat>(*this,false).xyYtoXYZ();
    }

    //! Convert pixel values from RGB to Lab color spaces.
    CImg<T>& RGBtoLab() {
      return RGBtoXYZ().XYZtoLab();
    }

    //! Convert pixel values from RGB to Lab color spaces \newinstance.
    CImg<Tfloat> get_RGBtoLab() const {
      return CImg<Tfloat>(*this,false).RGBtoLab();
    }

    //! Convert pixel values from Lab to RGB color spaces.
    CImg<T>& LabtoRGB() {
      return LabtoXYZ().XYZtoRGB();
    }

    //! Convert pixel values from Lab to RGB color spaces \newinstance.
    CImg<Tuchar> get_LabtoRGB() const {
      return CImg<Tuchar>(*this,false).LabtoRGB();
    }

    //! Convert pixel values from RGB to xyY color spaces.
    CImg<T>& RGBtoxyY() {
      return RGBtoXYZ().XYZtoxyY();
    }

    //! Convert pixel values from RGB to xyY color spaces \newinstance.
    CImg<Tfloat> get_RGBtoxyY() const {
      return CImg<Tfloat>(*this,false).RGBtoxyY();
    }

    //! Convert pixel values from xyY to RGB color spaces.
    CImg<T>& xyYtoRGB() {
      return xyYtoXYZ().XYZtoRGB();
    }

    //! Convert pixel values from xyY to RGB color spaces \newinstance.
    CImg<Tuchar> get_xyYtoRGB() const {
      return CImg<Tuchar>(*this,false).xyYtoRGB();
    }

    //! Convert pixel values from RGB to CMYK color spaces.
    CImg<T>& RGBtoCMYK() {
      return RGBtoCMY().CMYtoCMYK();
    }

    //! Convert pixel values from RGB to CMYK color spaces \newinstance.
    CImg<Tfloat> get_RGBtoCMYK() const {
      return CImg<Tfloat>(*this,false).RGBtoCMYK();
    }

    //! Convert pixel values from CMYK to RGB color spaces.
    CImg<T>& CMYKtoRGB() {
      return CMYKtoCMY().CMYtoRGB();
    }

    //! Convert pixel values from CMYK to RGB color spaces \newinstance.
    CImg<Tuchar> get_CMYKtoRGB() const {
      return CImg<Tuchar>(*this,false).CMYKtoRGB();
    }

    //! Convert RGB color image to a Bayer-coded scalar image.
    /**
       \note First (upper-left) pixel if the red component of the pixel color.
    **/
    CImg<T>& RGBtoBayer() {
      return get_RGBtoBayer().move_to(*this);
    }

    //! Convert RGB color image to a Bayer-coded scalar image \newinstance.
    CImg<T> get_RGBtoBayer() const {
      if (_spectrum!=3)
        throw CImgInstanceException(_cimg_instance
                                    "RGBtoBayer(): Instance is not a RGB image.",
                                    cimg_instance);

      CImg<T> res(_width,_height,_depth,1);
      const T *ptr_r = data(0,0,0,0), *ptr_g = data(0,0,0,1), *ptr_b = data(0,0,0,2);
      T *ptrd = res._data;
      cimg_forXYZ(*this,x,y,z) {
        if (y%2) {
          if (x%2) *(ptrd++) = *ptr_b;
          else *(ptrd++) = *ptr_g;
        } else {
          if (x%2) *(ptrd++) = *ptr_g;
          else *(ptrd++) = *ptr_r;
        }
        ++ptr_r; ++ptr_g; ++ptr_b;
      }
      return res;
    }

    //! Convert Bayer-coded scalar image to a RGB color image.
    CImg<T>& BayertoRGB(const unsigned int interpolation_type=3) {
      return get_BayertoRGB(interpolation_type).move_to(*this);
    }

    //! Convert Bayer-coded scalar image to a RGB color image \newinstance.
    CImg<Tuchar> get_BayertoRGB(const unsigned int interpolation_type=3) const {
      if (_spectrum!=1)
        throw CImgInstanceException(_cimg_instance
                                    "BayertoRGB(): Instance is not a Bayer image.",
                                    cimg_instance);

      CImg<Tuchar> res(_width,_height,_depth,3);
      CImg_3x3(I,T);
      Tuchar *ptr_r = res.data(0,0,0,0), *ptr_g = res.data(0,0,0,1), *ptr_b = res.data(0,0,0,2);
      switch (interpolation_type) {
      case 3 : { // Edge-directed
        CImg_3x3(R,T);
        CImg_3x3(G,T);
        CImg_3x3(B,T);
        cimg_forXYZ(*this,x,y,z) {
          const int _p1x = x?x-1:1, _p1y = y?y-1:1, _n1x = x<width()-1?x+1:x-1, _n1y = y<height()-1?y+1:y-1;
          cimg_get3x3(*this,x,y,z,0,I,T);
          if (y%2) {
            if (x%2) {
              const Tfloat alpha = cimg::sqr((Tfloat)Inc - Ipc), beta = cimg::sqr((Tfloat)Icn - Icp), cx = 1/(1+alpha), cy = 1/(1+beta);
              *ptr_g = (Tuchar)((cx*(Inc+Ipc) + cy*(Icn+Icp))/(2*(cx+cy)));
            } else *ptr_g = (Tuchar)Icc;
          } else {
            if (x%2) *ptr_g = (Tuchar)Icc;
            else {
              const Tfloat alpha = cimg::sqr((Tfloat)Inc - Ipc), beta = cimg::sqr((Tfloat)Icn - Icp), cx = 1/(1+alpha), cy = 1/(1+beta);
              *ptr_g = (Tuchar)((cx*(Inc+Ipc) + cy*(Icn+Icp))/(2*(cx+cy)));
            }
          }
          ++ptr_g;
        }
        cimg_forXYZ(*this,x,y,z) {
          const int _p1x = x?x-1:1, _p1y = y?y-1:1, _n1x = x<width()-1?x+1:x-1, _n1y = y<height()-1?y+1:y-1;
          cimg_get3x3(*this,x,y,z,0,I,T);
          cimg_get3x3(res,x,y,z,1,G,T);
          if (y%2) {
            if (x%2) *ptr_b = (Tuchar)Icc;
            else { *ptr_r = (Tuchar)((Icn+Icp)/2); *ptr_b = (Tuchar)((Inc+Ipc)/2); }
          } else {
            if (x%2) { *ptr_r = (Tuchar)((Inc+Ipc)/2); *ptr_b = (Tuchar)((Icn+Icp)/2); }
            else *ptr_r = (Tuchar)Icc;
          }
          ++ptr_r; ++ptr_b;
        }
        ptr_r = res.data(0,0,0,0);
        ptr_g = res.data(0,0,0,1);
        ptr_b = res.data(0,0,0,2);
        cimg_forXYZ(*this,x,y,z) {
          const int _p1x = x?x-1:1, _p1y = y?y-1:1, _n1x = x<width()-1?x+1:x-1, _n1y = y<height()-1?y+1:y-1;
          cimg_get3x3(res,x,y,z,0,R,T);
          cimg_get3x3(res,x,y,z,1,G,T);
          cimg_get3x3(res,x,y,z,2,B,T);
          if (y%2) {
            if (x%2) {
              const float alpha = (float)cimg::sqr(Rnc-Rpc), beta = (float)cimg::sqr(Rcn-Rcp), cx = 1/(1+alpha), cy = 1/(1+beta);
              *ptr_r = (Tuchar)((cx*(Rnc+Rpc) + cy*(Rcn+Rcp))/(2*(cx+cy)));
            }
          } else {
            if (!(x%2)) {
              const float alpha = (float)cimg::sqr(Bnc-Bpc), beta = (float)cimg::sqr(Bcn-Bcp), cx = 1/(1+alpha), cy = 1/(1+beta);
              *ptr_b = (Tuchar)((cx*(Bnc+Bpc) + cy*(Bcn+Bcp))/(2*(cx+cy)));
            }
          }
          ++ptr_r; ++ptr_g; ++ptr_b;
        }
      } break;
      case 2 : { // Linear interpolation
        cimg_forXYZ(*this,x,y,z) {
          const int _p1x = x?x-1:1, _p1y = y?y-1:1, _n1x = x<width()-1?x+1:x-1, _n1y = y<height()-1?y+1:y-1;
          cimg_get3x3(*this,x,y,z,0,I,T);
          if (y%2) {
            if (x%2) { *ptr_r = (Tuchar)((Ipp+Inn+Ipn+Inp)/4); *ptr_g = (Tuchar)((Inc+Ipc+Icn+Icp)/4); *ptr_b = (Tuchar)Icc; }
            else { *ptr_r = (Tuchar)((Icp+Icn)/2); *ptr_g = (Tuchar)Icc; *ptr_b = (Tuchar)((Inc+Ipc)/2); }
          } else {
            if (x%2) { *ptr_r = (Tuchar)((Ipc+Inc)/2); *ptr_g = (Tuchar)Icc; *ptr_b = (Tuchar)((Icn+Icp)/2); }
            else { *ptr_r = (Tuchar)Icc; *ptr_g = (Tuchar)((Inc+Ipc+Icn+Icp)/4); *ptr_b = (Tuchar)((Ipp+Inn+Ipn+Inp)/4); }
          }
          ++ptr_r; ++ptr_g; ++ptr_b;
        }
      } break;
      case 1 : { // Nearest neighbor interpolation
        cimg_forXYZ(*this,x,y,z) {
          const int _p1x = x?x-1:1, _p1y = y?y-1:1, _n1x = x<width()-1?x+1:x-1, _n1y = y<height()-1?y+1:y-1;
          cimg_get3x3(*this,x,y,z,0,I,T);
          if (y%2) {
            if (x%2) { *ptr_r = (Tuchar)cimg::min(Ipp,Inn,Ipn,Inp); *ptr_g = (Tuchar)cimg::min(Inc,Ipc,Icn,Icp); *ptr_b = (Tuchar)Icc; }
            else { *ptr_r = (Tuchar)cimg::min(Icn,Icp); *ptr_g = (Tuchar)Icc; *ptr_b = (Tuchar)cimg::min(Inc,Ipc); }
          } else {
            if (x%2) { *ptr_r = (Tuchar)cimg::min(Inc,Ipc); *ptr_g = (Tuchar)Icc; *ptr_b = (Tuchar)cimg::min(Icn,Icp); }
            else { *ptr_r = (Tuchar)Icc; *ptr_g = (Tuchar)cimg::min(Inc,Ipc,Icn,Icp); *ptr_b = (Tuchar)cimg::min(Ipp,Inn,Ipn,Inp); }
          }
          ++ptr_r; ++ptr_g; ++ptr_b;
        }
      } break;
      default : { // 0-filling interpolation
        const T *ptrs = _data;
        res.fill(0);
        cimg_forXYZ(*this,x,y,z) {
          const T val = *(ptrs++);
          if (y%2) { if (x%2) *ptr_b = val; else *ptr_g = val; } else { if (x%2) *ptr_g = val; else *ptr_r = val; }
          ++ptr_r; ++ptr_g; ++ptr_b;
        }
      }
      }
      return res;
    }

    //@}
    //------------------------------------------
    //
    //! \name Geometric / Spatial Manipulation
    //@{
    //------------------------------------------

    static float _cimg_lanczos(const float x) {
      if (x<=-2 || x>=2) return 0;
      const float a = (float)cimg::PI*x, b = 0.5f*a;
      return (float)(x?std::sin(a)*std::sin(b)/(a*b):1);
    }

    //! Resize image to new dimensions.
    /**
       \param size_x Number of columns (new size along the X-axis).
       \param size_y Number of rows (new size along the Y-axis).
       \param size_z Number of slices (new size along the Z-axis).
       \param size_c Number of vector-channels (new size along the C-axis).
       \param interpolation_type Method of interpolation:
       - -1 = no interpolation: raw memory resizing.
       - 0 = no interpolation: additional space is filled according to \p boundary_conditions.
       - 1 = nearest-neighbor interpolation.
       - 2 = moving average interpolation.
       - 3 = linear interpolation.
       - 4 = grid interpolation.
       - 5 = cubic interpolation.
       - 6 = lanczos interpolation.
       \param boundary_conditions Border condition type.
       \param centering_x Set centering type (only if \p interpolation_type=0).
       \param centering_y Set centering type (only if \p interpolation_type=0).
       \param centering_z Set centering type (only if \p interpolation_type=0).
       \param centering_c Set centering type (only if \p interpolation_type=0).
       \note If pd[x,y,z,v]<0, it corresponds to a percentage of the original size (the default value is -100).
    **/
    CImg<T>& resize(const int size_x, const int size_y=-100,
                    const int size_z=-100, const int size_c=-100,
                    const int interpolation_type=1, const unsigned int boundary_conditions=0,
                    const float centering_x = 0, const float centering_y = 0,
                    const float centering_z = 0, const float centering_c = 0) {
      if (!size_x || !size_y || !size_z || !size_c) return assign();
      const unsigned int
        _sx = (unsigned int)(size_x<0?-size_x*width()/100:size_x),
        _sy = (unsigned int)(size_y<0?-size_y*height()/100:size_y),
        _sz = (unsigned int)(size_z<0?-size_z*depth()/100:size_z),
        _sc = (unsigned int)(size_c<0?-size_c*spectrum()/100:size_c),
        sx = _sx?_sx:1, sy = _sy?_sy:1, sz = _sz?_sz:1, sc = _sc?_sc:1;
      if (sx==_width && sy==_height && sz==_depth && sc==_spectrum) return *this;
      if (is_empty()) return assign(sx,sy,sz,sc,(T)0);
      if (interpolation_type==-1 && sx*sy*sz*sc==size()) {
	_width = sx; _height = sy; _depth = sz; _spectrum = sc;
	return *this;
      }
      return get_resize(sx,sy,sz,sc,interpolation_type,boundary_conditions,centering_x,centering_y,centering_z,centering_c).move_to(*this);
    }

    //! Resize image to new dimensions \newinstance.
    CImg<T> get_resize(const int size_x, const int size_y = -100,
                       const int size_z = -100, const int size_c = -100,
                       const int interpolation_type=1, const unsigned int boundary_conditions=0,
                       const float centering_x = 0, const float centering_y = 0,
                       const float centering_z = 0, const float centering_c = 0) const {
      if (centering_x<0 || centering_x>1 || centering_y<0 || centering_y>1 ||
          centering_z<0 || centering_z>1 || centering_c<0 || centering_c>1)
        throw CImgArgumentException(_cimg_instance
                                    "resize(): Specified centering arguments (%g,%g,%g,%g) are outside range [0,1].",
                                    cimg_instance,
                                    centering_x,centering_y,centering_z,centering_c);

      if (!size_x || !size_y || !size_z || !size_c) return CImg<T>();
      const unsigned int
        _sx = (unsigned int)(size_x<0?-size_x*width()/100:size_x),
        _sy = (unsigned int)(size_y<0?-size_y*height()/100:size_y),
        _sz = (unsigned int)(size_z<0?-size_z*depth()/100:size_z),
        _sc = (unsigned int)(size_c<0?-size_c*spectrum()/100:size_c),
        sx = _sx?_sx:1, sy = _sy?_sy:1, sz = _sz?_sz:1, sc = _sc?_sc:1;
      if (sx==_width && sy==_height && sz==_depth && sc==_spectrum) return +*this;
      if (is_empty()) return CImg<T>(sx,sy,sz,sc,0);

      CImg<T> res;
      switch (interpolation_type) {

        // Raw resizing.
        //
      case -1 :
        std::memcpy(res.assign(sx,sy,sz,sc,0)._data,_data,sizeof(T)*cimg::min(size(),sx*sy*sz*sc));
        break;

        // No interpolation.
        //
      case 0 : {
        const int
          xc = (int)(centering_x*((int)sx - width())),
          yc = (int)(centering_y*((int)sy - height())),
          zc = (int)(centering_z*((int)sz - depth())),
          cc = (int)(centering_c*((int)sc - spectrum()));

        switch (boundary_conditions) {
        case 2 : { // Cyclic borders.
          res.assign(sx,sy,sz,sc);
          const int
            x0 = ((int)xc%width()) - width(),
            y0 = ((int)yc%height()) - height(),
            z0 = ((int)zc%depth()) - depth(),
            c0 = ((int)cc%spectrum()) - spectrum();
          for (int c = c0; c<(int)sc; c+=spectrum())
            for (int z = z0; z<(int)sz; z+=depth())
              for (int y = y0; y<(int)sy; y+=height())
                for (int x = x0; x<(int)sx; x+=width())
                  res.draw_image(x,y,z,c,*this);
        } break;
        case 1 : { // Neumann borders.
          res.assign(sx,sy,sz,sc).draw_image(xc,yc,zc,cc,*this);
          CImg<T> sprite;
          if (xc>0) {  // X-backward
            res.get_crop(xc,yc,zc,cc,xc,yc+height()-1,zc+depth()-1,cc+spectrum()-1).move_to(sprite);
            for (int x = xc-1; x>=0; --x) res.draw_image(x,yc,zc,cc,sprite);
          }
          if (xc+width()<(int)sx) { // X-forward
            res.get_crop(xc+width()-1,yc,zc,cc,xc+width()-1,yc+height()-1,zc+depth()-1,cc+spectrum()-1).move_to(sprite);
            for (int x = xc+width(); x<(int)sx; ++x) res.draw_image(x,yc,zc,cc,sprite);
          }
          if (yc>0) {  // Y-backward
            res.get_crop(0,yc,zc,cc,sx-1,yc,zc+depth()-1,cc+spectrum()-1).move_to(sprite);
            for (int y = yc-1; y>=0; --y) res.draw_image(0,y,zc,cc,sprite);
          }
          if (yc+height()<(int)sy) { // Y-forward
            res.get_crop(0,yc+height()-1,zc,cc,sx-1,yc+height()-1,zc+depth()-1,cc+spectrum()-1).move_to(sprite);
            for (int y = yc+height(); y<(int)sy; ++y) res.draw_image(0,y,zc,cc,sprite);
          }
          if (zc>0) {  // Z-backward
            res.get_crop(0,0,zc,cc,sx-1,sy-1,zc,cc+spectrum()-1).move_to(sprite);
            for (int z = zc-1; z>=0; --z) res.draw_image(0,0,z,cc,sprite);
          }
          if (zc+depth()<(int)sz) { // Z-forward
            res.get_crop(0,0,zc+depth()-1,cc,sx-1,sy-1,zc+depth()-1,cc+spectrum()-1).move_to(sprite);
            for (int z = zc+depth(); z<(int)sz; ++z) res.draw_image(0,0,z,cc,sprite);
          }
          if (cc>0) {  // C-backward
            res.get_crop(0,0,0,cc,sx-1,sy-1,sz-1,cc).move_to(sprite);
            for (int c = cc-1; c>=0; --c) res.draw_image(0,0,0,c,sprite);
          }
          if (cc+spectrum()<(int)sc) { // C-forward
            res.get_crop(0,0,0,cc+spectrum()-1,sx-1,sy-1,sz-1,cc+spectrum()-1).move_to(sprite);
            for (int c = cc+spectrum(); c<(int)sc; ++c) res.draw_image(0,0,0,c,sprite);
          }
        } break;
        default : // Dirichlet borders.
          res.assign(sx,sy,sz,sc,0).draw_image(xc,yc,zc,cc,*this);
        }
        break;
      } break;

        // Nearest neighbor interpolation.
        //
      case 1 : {
        res.assign(sx,sy,sz,sc);
        CImg<ulongT> off_x(sx), off_y(sy+1), off_z(sz+1), off_c(sc+1);
        unsigned long *poff_x, *poff_y, *poff_z, *poff_c, curr, old;
        const unsigned long
          wh = (unsigned long)_width*_height,
          whd = (unsigned long)_width*_height*_depth,
          sxy = (unsigned long)sx*sy,
          sxyz = (unsigned long)sx*sy*sz;
        if (sx==_width) off_x.fill(1);
        else {
          poff_x = off_x._data; curr = 0;
          cimg_forX(res,x) { old = curr; curr = ((x+1LU)*_width/sx); *(poff_x++) = curr - old; }
        }
        if (sy==_height) off_y.fill(_width);
        else {
          poff_y = off_y._data; curr = 0;
          cimg_forY(res,y) { old = curr; curr = ((y+1LU)*_height/sy); *(poff_y++) = _width*(curr - old); } *poff_y = 0;
        }
        if (sz==_depth) off_z.fill(wh);
        else {
          poff_z = off_z._data; curr = 0;
          cimg_forZ(res,z) { old = curr; curr = ((z+1LU)*_depth/sz); *(poff_z++) = wh*(curr - old); } *poff_z = 0;
        }
        if (sc==_spectrum) off_c.fill(whd);
        else {
          poff_c = off_c._data; curr = 0;
          cimg_forC(res,c) { old = curr; curr = ((c+1LU)*_spectrum/sc); *(poff_c++) = whd*(curr - old); } *poff_c = 0;
        }

        T *ptrd = res._data;
        const T* ptrv = _data;
        poff_c = off_c._data;
        for (unsigned int c = 0; c<sc; ) {
          const T *ptrz = ptrv;
          poff_z = off_z._data;
          for (unsigned int z = 0; z<sz; ) {
            const T *ptry = ptrz;
            poff_y = off_y._data;
            for (unsigned int y = 0; y<sy; ) {
              const T *ptrx = ptry;
              poff_x = off_x._data;
              cimg_forX(res,x) { *(ptrd++) = *ptrx; ptrx+=*(poff_x++); }
              ++y;
              unsigned long dy = *(poff_y++);
              for (;!dy && y<dy; std::memcpy(ptrd,ptrd - sx,sizeof(T)*sx), ++y, ptrd+=sx, dy = *(poff_y++)) {}
              ptry+=dy;
            }
            ++z;
            unsigned long dz = *(poff_z++);
            for (;!dz && z<dz; std::memcpy(ptrd,ptrd-sxy,sizeof(T)*sxy), ++z, ptrd+=sxy, dz = *(poff_z++)) {}
            ptrz+=dz;
          }
          ++c;
          unsigned long dc = *(poff_c++);
          for (;!dc && c<dc; std::memcpy(ptrd,ptrd-sxyz,sizeof(T)*sxyz), ++c, ptrd+=sxyz, dc = *(poff_c++)) {}
          ptrv+=dc;
        }
      } break;

        // Moving average.
        //
      case 2 : {
        bool instance_first = true;
        if (sx!=_width) {
          CImg<Tfloat> tmp(sx,_height,_depth,_spectrum,0);
          for (unsigned int a = _width*sx, b = _width, c = sx, s = 0, t = 0; a; ) {
            const unsigned int d = cimg::min(b,c);
            a-=d; b-=d; c-=d;
            cimg_forYZC(tmp,y,z,v) tmp(t,y,z,v)+=(Tfloat)(*this)(s,y,z,v)*d;
            if (!b) { cimg_forYZC(tmp,y,z,v) tmp(t,y,z,v)/=_width; ++t; b = _width; }
            if (!c) { ++s; c = sx; }
          }
          tmp.move_to(res);
          instance_first = false;
        }
        if (sy!=_height) {
          CImg<Tfloat> tmp(sx,sy,_depth,_spectrum,0);
          for (unsigned int a = _height*sy, b = _height, c = sy, s = 0, t = 0; a; ) {
            const unsigned int d = cimg::min(b,c);
            a-=d; b-=d; c-=d;
            if (instance_first) cimg_forXZC(tmp,x,z,v) tmp(x,t,z,v)+=(Tfloat)(*this)(x,s,z,v)*d;
            else cimg_forXZC(tmp,x,z,v) tmp(x,t,z,v)+=(Tfloat)res(x,s,z,v)*d;
            if (!b) { cimg_forXZC(tmp,x,z,v) tmp(x,t,z,v)/=_height; ++t; b = _height; }
            if (!c) { ++s; c = sy; }
          }
          tmp.move_to(res);
          instance_first = false;
        }
        if (sz!=_depth) {
          CImg<Tfloat> tmp(sx,sy,sz,_spectrum,0);
          for (unsigned int a = _depth*sz, b = _depth, c = sz, s = 0, t = 0; a; ) {
            const unsigned int d = cimg::min(b,c);
            a-=d; b-=d; c-=d;
            if (instance_first) cimg_forXYC(tmp,x,y,v) tmp(x,y,t,v)+=(Tfloat)(*this)(x,y,s,v)*d;
            else cimg_forXYC(tmp,x,y,v) tmp(x,y,t,v)+=(Tfloat)res(x,y,s,v)*d;
            if (!b) { cimg_forXYC(tmp,x,y,v) tmp(x,y,t,v)/=_depth; ++t; b = _depth; }
            if (!c) { ++s; c = sz; }
          }
          tmp.move_to(res);
          instance_first = false;
        }
        if (sc!=_spectrum) {
          CImg<Tfloat> tmp(sx,sy,sz,sc,0);
          for (unsigned int a = _spectrum*sc, b = _spectrum, c = sc, s = 0, t = 0; a; ) {
            const unsigned int d = cimg::min(b,c);
            a-=d; b-=d; c-=d;
            if (instance_first) cimg_forXYZ(tmp,x,y,z) tmp(x,y,z,t)+=(Tfloat)(*this)(x,y,z,s)*d;
            else cimg_forXYZ(tmp,x,y,z) tmp(x,y,z,t)+=(Tfloat)res(x,y,z,s)*d;
            if (!b) { cimg_forXYZ(tmp,x,y,z) tmp(x,y,z,t)/=_spectrum; ++t; b = _spectrum; }
            if (!c) { ++s; c = sc; }
          }
          tmp.move_to(res);
          instance_first = false;
        }
      } break;

        // Linear interpolation.
        //
      case 3 : {
        CImg<uintT> off(cimg::max(sx,sy,sz,sc));
        CImg<floatT> foff(off._width);
        unsigned int *poff;
        float *pfoff, old, curr;
        CImg<T> resx, resy, resz, resc;
        T *ptrd;

        if (sx!=_width) {
          if (_width==1) get_resize(sx,_height,_depth,_spectrum,1).move_to(resx);
          else {
            if (_width>sx) get_resize(sx,_height,_depth,_spectrum,2).move_to(resx);
            else {
              const float fx = (!boundary_conditions && sx>_width)?(sx>1?(_width-1.0f)/(sx-1):0):(float)_width/sx;
              resx.assign(sx,_height,_depth,_spectrum);
              curr = old = 0; poff = off._data; pfoff = foff._data;
              cimg_forX(resx,x) { *(pfoff++) = curr - (unsigned int)curr; old = curr; curr+=fx; *(poff++) = (unsigned int)curr - (unsigned int)old; }
              ptrd = resx._data;
              const T *ptrs0 = _data;
              cimg_forYZC(resx,y,z,c) {
                poff = off._data; pfoff = foff._data;
                const T *ptrs = ptrs0, *const ptrsmax = ptrs0 + (_width-1);
                cimg_forX(resx,x) {
                  const float alpha = *(pfoff++);
                  const T val1 = *ptrs, val2 = ptrs<ptrsmax?*(ptrs+1):val1;
                  *(ptrd++) = (T)((1-alpha)*val1 + alpha*val2);
                  ptrs+=*(poff++);
                }
                ptrs0+=_width;
              }
            }
          }
        } else resx.assign(*this,true);

        if (sy!=_height) {
          if (_height==1) resx.get_resize(sx,sy,_depth,_spectrum,1).move_to(resy);
          else {
            if (_height>sy) resx.get_resize(sx,sy,_depth,_spectrum,2).move_to(resy);
            else {
              const float fy = (!boundary_conditions && sy>_height)?(sy>1?(_height-1.0f)/(sy-1):0):(float)_height/sy;
              resy.assign(sx,sy,_depth,_spectrum);
              curr = old = 0; poff = off._data; pfoff = foff._data;
              cimg_forY(resy,y) { *(pfoff++) = curr - (unsigned int)curr; old = curr; curr+=fy; *(poff++) = sx*((unsigned int)curr-(unsigned int)old); }
              cimg_forXZC(resy,x,z,c) {
                ptrd = resy.data(x,0,z,c);
                const T *ptrs = resx.data(x,0,z,c), *const ptrsmax = ptrs + (_height-1)*sx;
                poff = off._data; pfoff = foff._data;
                cimg_forY(resy,y) {
                  const float alpha = *(pfoff++);
                  const T val1 = *ptrs, val2 = ptrs<ptrsmax?*(ptrs+sx):val1;
                  *ptrd = (T)((1-alpha)*val1 + alpha*val2);
                  ptrd+=sx;
                  ptrs+=*(poff++);
                }
              }
            }
          }
          resx.assign();
        } else resy.assign(resx,true);

        if (sz!=_depth) {
          if (_depth==1) resy.get_resize(sx,sy,sz,_spectrum,1).move_to(resz);
          else {
            if (_depth>sz) resy.get_resize(sx,sy,sz,_spectrum,2).move_to(resz);
            else {
              const float fz = (!boundary_conditions && sz>_depth)?(sz>1?(_depth-1.0f)/(sz-1):0):(float)_depth/sz;
              const unsigned int sxy = sx*sy;
              resz.assign(sx,sy,sz,_spectrum);
              curr = old = 0; poff = off._data; pfoff = foff._data;
              cimg_forZ(resz,z) { *(pfoff++) = curr - (unsigned int)curr; old = curr; curr+=fz; *(poff++) = sxy*((unsigned int)curr - (unsigned int)old); }
              cimg_forXYC(resz,x,y,c) {
                ptrd = resz.data(x,y,0,c);
                const T *ptrs = resy.data(x,y,0,c), *const ptrsmax = ptrs + (_depth-1)*sxy;
                poff = off._data; pfoff = foff._data;
                cimg_forZ(resz,z) {
                  const float alpha = *(pfoff++);
                  const T val1 = *ptrs, val2 = ptrs<ptrsmax?*(ptrs+sxy):val1;
                  *ptrd = (T)((1-alpha)*val1 + alpha*val2);
                  ptrd+=sxy;
                  ptrs+=*(poff++);
                }
              }
            }
          }
          resy.assign();
        } else resz.assign(resy,true);

        if (sc!=_spectrum) {
          if (_spectrum==1) resz.get_resize(sx,sy,sz,sc,1).move_to(resc);
          else {
            if (_spectrum>sc) resz.get_resize(sx,sy,sz,sc,2).move_to(resc);
            else {
              const float fc = (!boundary_conditions && sc>_spectrum)?(sc>1?(_spectrum-1.0f)/(sc-1):0):(float)_spectrum/sc;
              const unsigned int sxyz = sx*sy*sz;
              resc.assign(sx,sy,sz,sc);
              curr = old = 0; poff = off._data; pfoff = foff._data;
              cimg_forC(resc,c) { *(pfoff++) = curr - (unsigned int)curr; old = curr; curr+=fc; *(poff++) = sxyz*((unsigned int)curr - (unsigned int)old); }
              cimg_forXYZ(resc,x,y,z) {
                ptrd = resc.data(x,y,z,0);
                const T *ptrs = resz.data(x,y,z,0), *const ptrsmax = ptrs + (_spectrum-1)*sxyz;
                poff = off._data; pfoff = foff._data;
                cimg_forC(resc,c) {
                  const float alpha = *(pfoff++);
                  const T val1 = *ptrs, val2 = ptrs<ptrsmax?*(ptrs+sxyz):val1;
                  *ptrd = (T)((1-alpha)*val1 + alpha*val2);
                  ptrd+=sxyz;
                  ptrs+=*(poff++);
                }
              }
            }
          }
          resz.assign();
        } else resc.assign(resz,true);
        return resc._is_shared?(resz._is_shared?(resy._is_shared?(resx._is_shared?(+(*this)):resx):resy):resz):resc;
      } break;

        // Grid interpolation.
        //
      case 4 : {
        CImg<T> resx, resy, resz, resc;
        if (sx!=_width) {
          if (sx<_width) get_resize(sx,_height,_depth,_spectrum,1).move_to(resx);
          else {
            resx.assign(sx,_height,_depth,_spectrum,0);
            const int dx = sx*2, dy = width()*2;
            int err = (int)(dy + centering_x*(sx*dy/width() - dy)), xs = 0;
            cimg_forX(resx,x) if ((err-=dy)<=0) {
              cimg_forYZC(resx,y,z,c) resx(x,y,z,c) = (*this)(xs,y,z,c);
              ++xs;
              err+=dx;
            }
          }
        } else resx.assign(*this,true);

        if (sy!=_height) {
          if (sy<_height) resx.get_resize(sx,sy,_depth,_spectrum,1).move_to(resy);
          else {
            resy.assign(sx,sy,_depth,_spectrum,0);
            const int dx = sy*2, dy = height()*2;
            int err = (int)(dy + centering_y*(sy*dy/height() - dy)), ys = 0;
            cimg_forY(resy,y) if ((err-=dy)<=0) {
              cimg_forXZC(resy,x,z,c) resy(x,y,z,c) = resx(x,ys,z,c);
              ++ys;
              err+=dx;
            }
          }
          resx.assign();
        } else resy.assign(resx,true);

        if (sz!=_depth) {
          if (sz<_depth) resy.get_resize(sx,sy,sz,_spectrum,1).move_to(resz);
          else {
            resz.assign(sx,sy,sz,_spectrum,0);
            const int dx = sz*2, dy = depth()*2;
            int err = (int)(dy + centering_z*(sz*dy/depth() - dy)), zs = 0;
            cimg_forZ(resz,z) if ((err-=dy)<=0) {
              cimg_forXYC(resz,x,y,c) resz(x,y,z,c) = resy(x,y,zs,c);
              ++zs;
              err+=dx;
            }
          }
          resy.assign();
        } else resz.assign(resy,true);

        if (sc!=_spectrum) {
          if (sc<_spectrum) resz.get_resize(sx,sy,sz,sc,1).move_to(resc);
          else {
            resc.assign(sx,sy,sz,sc,0);
            const int dx = sc*2, dy = spectrum()*2;
            int err = (int)(dy + centering_c*(sc*dy/spectrum() - dy)), cs = 0;
            cimg_forC(resc,c) if ((err-=dy)<=0) {
              cimg_forXYZ(resc,x,y,z) resc(x,y,z,c) = resz(x,y,z,cs);
              ++cs;
              err+=dx;
            }
          }
          resz.assign();
        } else resc.assign(resz,true);

        return resc._is_shared?(resz._is_shared?(resy._is_shared?(resx._is_shared?(+(*this)):resx):resy):resz):resc;
      } break;

        // Cubic interpolation.
        //
      case 5 : {
        const Tfloat vmin = (Tfloat)cimg::type<T>::min(), vmax = (Tfloat)cimg::type<T>::max();
        CImg<uintT> off(cimg::max(sx,sy,sz,sc));
        CImg<floatT> foff(off._width);
        unsigned int *poff;
        float *pfoff, old, curr;
        CImg<T> resx, resy, resz, resc;
        T *ptrd;

        if (sx!=_width) {
          if (_width==1) get_resize(sx,_height,_depth,_spectrum,1).move_to(resx);
          else {
            if (_width>sx) get_resize(sx,_height,_depth,_spectrum,2).move_to(resx);
            else {
              const float fx = (!boundary_conditions && sx>_width)?(sx>1?(_width-1.0f)/(sx-1):0):(float)_width/sx;
              resx.assign(sx,_height,_depth,_spectrum);
              curr = old = 0; poff = off._data; pfoff = foff._data;
              cimg_forX(resx,x) { *(pfoff++) = curr - (unsigned int)curr; old = curr; curr+=fx; *(poff++) = (unsigned int)curr - (unsigned int)old; }
              ptrd = resx._data;
              const T *ptrs0 = _data;
              cimg_forYZC(resx,y,z,c) {
                poff = off._data; pfoff = foff._data;
                const T *ptrs = ptrs0, *const ptrsmax = ptrs0 + (_width-2);
                cimg_forX(resx,x) {
                  const float t = *(pfoff++);
                  const Tfloat
                    val1 = (Tfloat)*ptrs,
                    val0 = ptrs>ptrs0?(Tfloat)*(ptrs-1):val1,
                    val2 = ptrs<=ptrsmax?(Tfloat)*(ptrs+1):val1,
                    val3 = ptrs<ptrsmax?(Tfloat)*(ptrs+2):val2,
                    val = val1 + 0.5f*(t*(-val0+val2) + t*t*(2*val0-5*val1+4*val2-val3) + t*t*t*(-val0+3*val1-3*val2+val3));
                  *(ptrd++) = (T)(val<vmin?vmin:val>vmax?vmax:val);
                  ptrs+=*(poff++);
                }
                ptrs0+=_width;
              }
            }
          }
        } else resx.assign(*this,true);

        if (sy!=_height) {
          if (_height==1) resx.get_resize(sx,sy,_depth,_spectrum,1).move_to(resy);
          else {
            if (_height>sy) resx.get_resize(sx,sy,_depth,_spectrum,2).move_to(resy);
            else {
              const float fy = (!boundary_conditions && sy>_height)?(sy>1?(_height-1.0f)/(sy-1):0):(float)_height/sy;
              resy.assign(sx,sy,_depth,_spectrum);
              curr = old = 0; poff = off._data; pfoff = foff._data;
              cimg_forY(resy,y) { *(pfoff++) = curr - (unsigned int)curr; old = curr; curr+=fy; *(poff++) = sx*((unsigned int)curr-(unsigned int)old); }
              cimg_forXZC(resy,x,z,c) {
                ptrd = resy.data(x,0,z,c);
                const T *const ptrs0 = resx.data(x,0,z,c), *ptrs = ptrs0, *const ptrsmax = ptrs0 + (_height-2)*sx;
                poff = off._data; pfoff = foff._data;
                cimg_forY(resy,y) {
                  const float t = *(pfoff++);
                  const Tfloat
                    val1 = (Tfloat)*ptrs,
                    val0 = ptrs>ptrs0?(Tfloat)*(ptrs-sx):val1,
                    val2 = ptrs<=ptrsmax?(Tfloat)*(ptrs+sx):val1,
                    val3 = ptrs<ptrsmax?(Tfloat)*(ptrs+2*sx):val2,
                    val = val1 + 0.5f*(t*(-val0+val2) + t*t*(2*val0-5*val1+4*val2-val3) + t*t*t*(-val0+3*val1-3*val2+val3));
                  *ptrd = (T)(val<vmin?vmin:val>vmax?vmax:val);
                  ptrd+=sx;
                  ptrs+=*(poff++);
                }
              }
            }
          }
          resx.assign();
        } else resy.assign(resx,true);

        if (sz!=_depth) {
          if (_depth==1) resy.get_resize(sx,sy,sz,_spectrum,1).move_to(resz);
          else {
            if (_depth>sz) resy.get_resize(sx,sy,sz,_spectrum,2).move_to(resz);
            else {
              const float fz = (!boundary_conditions && sz>_depth)?(sz>1?(_depth-1.0f)/(sz-1):0):(float)_depth/sz;
              const unsigned int sxy = sx*sy;
              resz.assign(sx,sy,sz,_spectrum);
              curr = old = 0; poff = off._data; pfoff = foff._data;
              cimg_forZ(resz,z) { *(pfoff++) = curr - (unsigned int)curr; old = curr; curr+=fz; *(poff++) = sxy*((unsigned int)curr - (unsigned int)old); }
              cimg_forXYC(resz,x,y,c) {
                ptrd = resz.data(x,y,0,c);
                const T *const ptrs0 = resy.data(x,y,0,c), *ptrs = ptrs0, *const ptrsmax = ptrs0 + (_depth-2)*sxy;
                poff = off._data; pfoff = foff._data;
                cimg_forZ(resz,z) {
                  const float t = *(pfoff++);
                  const Tfloat
                    val1 = (Tfloat)*ptrs,
                    val0 = ptrs>ptrs0?(Tfloat)*(ptrs-sxy):val1,
                    val2 = ptrs<=ptrsmax?(Tfloat)*(ptrs+sxy):val1,
                    val3 = ptrs<ptrsmax?(Tfloat)*(ptrs+2*sxy):val2,
                    val = val1 + 0.5f*(t*(-val0+val2) + t*t*(2*val0-5*val1+4*val2-val3) + t*t*t*(-val0+3*val1-3*val2+val3));
                  *ptrd = (T)(val<vmin?vmin:val>vmax?vmax:val);
                  ptrd+=sxy;
                  ptrs+=*(poff++);
                }
              }
            }
          }
          resy.assign();
        } else resz.assign(resy,true);

        if (sc!=_spectrum) {
          if (_spectrum==1) resz.get_resize(sx,sy,sz,sc,1).move_to(resc);
          else {
            if (_spectrum>sc) resz.get_resize(sx,sy,sz,sc,2).move_to(resc);
            else {
              const float fc = (!boundary_conditions && sc>_spectrum)?(sc>1?(_spectrum-1.0f)/(sc-1):0):(float)_spectrum/sc;
              const unsigned int sxyz = sx*sy*sz;
              resc.assign(sx,sy,sz,sc);
              curr = old = 0; poff = off._data; pfoff = foff._data;
              cimg_forC(resc,c) { *(pfoff++) = curr - (unsigned int)curr; old = curr; curr+=fc; *(poff++) = sxyz*((unsigned int)curr - (unsigned int)old); }
              cimg_forXYZ(resc,x,y,z) {
                ptrd = resc.data(x,y,z,0);
                const T *const ptrs0 = resz.data(x,y,z,0), *ptrs = ptrs0, *const ptrsmax = ptrs + (_spectrum-2)*sxyz;
                poff = off._data; pfoff = foff._data;
                cimg_forC(resc,c) {
                  const float t = *(pfoff++);
                  const Tfloat
                    val1 = (Tfloat)*ptrs,
                    val0 = ptrs>ptrs0?(Tfloat)*(ptrs-sxyz):val1,
                    val2 = ptrs<=ptrsmax?(Tfloat)*(ptrs+sxyz):val1,
                    val3 = ptrs<ptrsmax?(Tfloat)*(ptrs+2*sxyz):val2,
                    val = val1 + 0.5f*(t*(-val0+val2) + t*t*(2*val0-5*val1+4*val2-val3) + t*t*t*(-val0+3*val1-3*val2+val3));
                  *ptrd = (T)(val<vmin?vmin:val>vmax?vmax:val);
                  ptrd+=sxyz;
                  ptrs+=*(poff++);
                }
              }
            }
          }
          resz.assign();
        } else resc.assign(resz,true);

        return resc._is_shared?(resz._is_shared?(resy._is_shared?(resx._is_shared?(+(*this)):resx):resy):resz):resc;
      } break;

        // Lanczos interpolation.
        //
      case 6 : {
        const Tfloat vmin = (Tfloat)cimg::type<T>::min(), vmax = (Tfloat)cimg::type<T>::max();
        CImg<uintT> off(cimg::max(sx,sy,sz,sc));
        CImg<floatT> foff(off._width);
        unsigned int *poff;
        float *pfoff, old, curr;
        CImg<T> resx, resy, resz, resc;
        T *ptrd;

        if (sx!=_width) {
          if (_width==1) get_resize(sx,_height,_depth,_spectrum,1).move_to(resx);
          else {
            if (_width>sx) get_resize(sx,_height,_depth,_spectrum,2).move_to(resx);
            else {
              const float fx = (!boundary_conditions && sx>_width)?(sx>1?(_width-1.0f)/(sx-1):0):(float)_width/sx;
              resx.assign(sx,_height,_depth,_spectrum);
              curr = old = 0; poff = off._data; pfoff = foff._data;
              cimg_forX(resx,x) { *(pfoff++) = curr - (unsigned int)curr; old = curr; curr+=fx; *(poff++) = (unsigned int)curr - (unsigned int)old; }
              ptrd = resx._data;
              const T *ptrs0 = _data;
              cimg_forYZC(resx,y,z,c) {
                poff = off._data; pfoff = foff._data;
                const T *ptrs = ptrs0, *const ptrsmin = ptrs0 + 1, *const ptrsmax = ptrs0 + (_width-2);
                cimg_forX(resx,x) {
                  const float
                    t = *(pfoff++),
                    w0 = _cimg_lanczos(t+2),
                    w1 = _cimg_lanczos(t+1),
                    w2 = _cimg_lanczos(t),
                    w3 = _cimg_lanczos(t-1),
                    w4 = _cimg_lanczos(t-2);
                  const Tfloat
                    val2 = (Tfloat)*ptrs,
                    val1 = ptrs>=ptrsmin?(Tfloat)*(ptrs-1):val2,
                    val0 = ptrs>ptrsmin?(Tfloat)*(ptrs-2):val1,
                    val3 = ptrs<=ptrsmax?(Tfloat)*(ptrs+1):val2,
                    val4 = ptrs<ptrsmax?(Tfloat)*(ptrs+2):val3,
                    val = (val0*w0 + val1*w1 + val2*w2 + val3*w3 + val4*w4)/(w1 + w2 + w3 + w4);
                  *(ptrd++) = (T)(val<vmin?vmin:val>vmax?vmax:val);
                  ptrs+=*(poff++);
                }
                ptrs0+=_width;
              }
            }
          }
        } else resx.assign(*this,true);

        if (sy!=_height) {
          if (_height==1) resx.get_resize(sx,sy,_depth,_spectrum,1).move_to(resy);
          else {
            if (_height>sy) resx.get_resize(sx,sy,_depth,_spectrum,2).move_to(resy);
            else {
              const float fy = (!boundary_conditions && sy>_height)?(sy>1?(_height-1.0f)/(sy-1):0):(float)_height/sy;
              resy.assign(sx,sy,_depth,_spectrum);
              curr = old = 0; poff = off._data; pfoff = foff._data;
              cimg_forY(resy,y) { *(pfoff++) = curr - (unsigned int)curr; old = curr; curr+=fy; *(poff++) = sx*((unsigned int)curr-(unsigned int)old); }
              cimg_forXZC(resy,x,z,c) {
                ptrd = resy.data(x,0,z,c);
                const T *const ptrs0 = resx.data(x,0,z,c), *ptrs = ptrs0, *const ptrsmin = ptrs0 + sx, *const ptrsmax = ptrs0 + (_height-2)*sx;
                poff = off._data; pfoff = foff._data;
                cimg_forY(resy,y) {
                  const float
                    t = *(pfoff++),
                    w0 = _cimg_lanczos(t+2),
                    w1 = _cimg_lanczos(t+1),
                    w2 = _cimg_lanczos(t),
                    w3 = _cimg_lanczos(t-1),
                    w4 = _cimg_lanczos(t-2);
                  const Tfloat
                    val2 = (Tfloat)*ptrs,
                    val1 = ptrs>=ptrsmin?(Tfloat)*(ptrs-sx):val2,
                    val0 = ptrs>ptrsmin?(Tfloat)*(ptrs-2*sx):val1,
                    val3 = ptrs<=ptrsmax?(Tfloat)*(ptrs+sx):val2,
                    val4 = ptrs<ptrsmax?(Tfloat)*(ptrs+2*sx):val3,
                    val = (val0*w0 + val1*w1 + val2*w2 + val3*w3 + val4*w4)/(w1 + w2 + w3 + w4);
                  *ptrd = (T)(val<vmin?vmin:val>vmax?vmax:val);
                  ptrd+=sx;
                  ptrs+=*(poff++);
                }
              }
            }
          }
          resx.assign();
        } else resy.assign(resx,true);

        if (sz!=_depth) {
          if (_depth==1) resy.get_resize(sx,sy,sz,_spectrum,1).move_to(resz);
          else {
            if (_depth>sz) resy.get_resize(sx,sy,sz,_spectrum,2).move_to(resz);
            else {
              const float fz = (!boundary_conditions && sz>_depth)?(sz>1?(_depth-1.0f)/(sz-1):0):(float)_depth/sz;
              const unsigned int sxy = sx*sy;
              resz.assign(sx,sy,sz,_spectrum);
              curr = old = 0; poff = off._data; pfoff = foff._data;
              cimg_forZ(resz,z) { *(pfoff++) = curr - (unsigned int)curr; old = curr; curr+=fz; *(poff++) = sxy*((unsigned int)curr - (unsigned int)old); }
              cimg_forXYC(resz,x,y,c) {
                ptrd = resz.data(x,y,0,c);
                const T *const ptrs0 = resy.data(x,y,0,c), *ptrs = ptrs0, *const ptrsmin = ptrs0 + sxy, *const ptrsmax = ptrs0 + (_depth-2)*sxy;
                poff = off._data; pfoff = foff._data;
                cimg_forZ(resz,z) {
                  const float
                    t = *(pfoff++),
                    w0 = _cimg_lanczos(t+2),
                    w1 = _cimg_lanczos(t+1),
                    w2 = _cimg_lanczos(t),
                    w3 = _cimg_lanczos(t-1),
                    w4 = _cimg_lanczos(t-2);
                  const Tfloat
                    val2 = (Tfloat)*ptrs,
                    val1 = ptrs>=ptrsmin?(Tfloat)*(ptrs-sxy):val2,
                    val0 = ptrs>ptrsmin?(Tfloat)*(ptrs-2*sxy):val1,
                    val3 = ptrs<=ptrsmax?(Tfloat)*(ptrs+sxy):val2,
                    val4 = ptrs<ptrsmax?(Tfloat)*(ptrs+2*sxy):val3,
                    val = (val0*w0 + val1*w1 + val2*w2 + val3*w3 + val4*w4)/(w1 + w2 + w3 + w4);
                  *ptrd = (T)(val<vmin?vmin:val>vmax?vmax:val);
                  ptrd+=sxy;
                  ptrs+=*(poff++);
                }
              }
            }
          }
          resy.assign();
        } else resz.assign(resy,true);

        if (sc!=_spectrum) {
          if (_spectrum==1) resz.get_resize(sx,sy,sz,sc,1).move_to(resc);
          else {
            if (_spectrum>sc) resz.get_resize(sx,sy,sz,sc,2).move_to(resc);
            else {
              const float fc = (!boundary_conditions && sc>_spectrum)?(sc>1?(_spectrum-1.0f)/(sc-1):0):(float)_spectrum/sc;
              const unsigned int sxyz = sx*sy*sz;
              resc.assign(sx,sy,sz,sc);
              curr = old = 0; poff = off._data; pfoff = foff._data;
              cimg_forC(resc,c) { *(pfoff++) = curr - (unsigned int)curr; old = curr; curr+=fc; *(poff++) = sxyz*((unsigned int)curr - (unsigned int)old); }
              cimg_forXYZ(resc,x,y,z) {
                ptrd = resc.data(x,y,z,0);
                const T *const ptrs0 = resz.data(x,y,z,0), *ptrs = ptrs0, *const ptrsmin = ptrs0 + sxyz, *const ptrsmax = ptrs + (_spectrum-2)*sxyz;
                poff = off._data; pfoff = foff._data;
                cimg_forC(resc,c) {
                  const float
                    t = *(pfoff++),
                    w0 = _cimg_lanczos(t+2),
                    w1 = _cimg_lanczos(t+1),
                    w2 = _cimg_lanczos(t),
                    w3 = _cimg_lanczos(t-1),
                    w4 = _cimg_lanczos(t-2);
                  const Tfloat
                    val2 = (Tfloat)*ptrs,
                    val1 = ptrs>=ptrsmin?(Tfloat)*(ptrs-sxyz):val2,
                    val0 = ptrs>ptrsmin?(Tfloat)*(ptrs-2*sxyz):val1,
                    val3 = ptrs<=ptrsmax?(Tfloat)*(ptrs+sxyz):val2,
                    val4 = ptrs<ptrsmax?(Tfloat)*(ptrs+2*sxyz):val3,
                    val = (val0*w0 + val1*w1 + val2*w2 + val3*w3 + val4*w4)/(w1 + w2 + w3 + w4);
                  *ptrd = (T)(val<vmin?vmin:val>vmax?vmax:val);
                  ptrd+=sxyz;
                  ptrs+=*(poff++);
                }
              }
            }
          }
          resz.assign();
        } else resc.assign(resz,true);

        return resc._is_shared?(resz._is_shared?(resy._is_shared?(resx._is_shared?(+(*this)):resx):resy):resz):resc;
      } break;

        // Unknow interpolation.
        //
      default :
        throw CImgArgumentException(_cimg_instance
                                    "resize(): Invalid specified interpolation %d "
                                    "(should be { -1=raw | 0=none | 1=nearest | 2=average | 3=linear | 4=grid | 5=cubic | 6=lanczos }).",
                                    cimg_instance,
                                    interpolation_type);
      }
      return res;
    }

    //! Resize image to dimensions of another image.
    /**
       \param src Reference image used for dimensions.
       \param interpolation_type Interpolation method.
       \param boundary_conditions Boundary conditions.
       \param centering_x Set centering type (only if \p interpolation_type=0).
       \param centering_y Set centering type (only if \p interpolation_type=0).
       \param centering_z Set centering type (only if \p interpolation_type=0).
       \param centering_c Set centering type (only if \p interpolation_type=0).
     **/
    template<typename t>
    CImg<T>& resize(const CImg<t>& src,
                    const int interpolation_type=1, const unsigned int boundary_conditions=0,
                    const float centering_x = 0, const float centering_y = 0,
                    const float centering_z = 0, const float centering_c = 0) {
      return resize(src._width,src._height,src._depth,src._spectrum,interpolation_type,boundary_conditions,
                    centering_x,centering_y,centering_z,centering_c);
    }

    //! Resize image to dimensions of another image \newinstance.
    template<typename t>
    CImg<T> get_resize(const CImg<t>& src,
                       const int interpolation_type=1, const unsigned int boundary_conditions=0,
                       const float centering_x = 0, const float centering_y = 0,
                       const float centering_z = 0, const float centering_c = 0) const {
      return get_resize(src._width,src._height,src._depth,src._spectrum,interpolation_type,boundary_conditions,
                        centering_x,centering_y,centering_z,centering_c);
    }

    //! Resize image to dimensions of a display window.
    /**
       \param disp Reference display window used for dimensions.
       \param interpolation_type Interpolation method.
       \param boundary_conditions Boundary conditions.
       \param centering_x Set centering type (only if \p interpolation_type=0).
       \param centering_y Set centering type (only if \p interpolation_type=0).
       \param centering_z Set centering type (only if \p interpolation_type=0).
       \param centering_c Set centering type (only if \p interpolation_type=0).
     **/
    CImg<T>& resize(const CImgDisplay& disp,
                    const int interpolation_type=1, const unsigned int boundary_conditions=0,
                    const float centering_x = 0, const float centering_y = 0,
                    const float centering_z = 0, const float centering_c = 0) {
      return resize(disp.width(),disp.height(),_depth,_spectrum,interpolation_type,boundary_conditions,
                    centering_x,centering_y,centering_z,centering_c);
    }

    //! Resize image to dimensions of a display window \newinstance.
    CImg<T> get_resize(const CImgDisplay& disp,
                       const int interpolation_type=1, const unsigned int boundary_conditions=0,
                       const float centering_x = 0, const float centering_y = 0,
                       const float centering_z = 0, const float centering_c = 0) const {
      return get_resize(disp.width(),disp.height(),_depth,_spectrum,interpolation_type,boundary_conditions,
                        centering_x,centering_y,centering_z,centering_c);
    }

    //! Resize image to half-size along XY axes, using an optimized filter.
    CImg<T>& resize_halfXY() {
      return get_resize_halfXY().move_to(*this);
    }

    //! Resize image to half-size along XY axes, using an optimized filter \newinstance.
    CImg<T> get_resize_halfXY() const {
      if (is_empty()) return *this;
      const Tfloat mask[9] = { 0.07842776544f, 0.1231940459f, 0.07842776544f,
                              0.1231940459f,  0.1935127547f, 0.1231940459f,
                              0.07842776544f, 0.1231940459f, 0.07842776544f };
      T I[9] = { 0 };
      CImg<T> res(_width/2,_height/2,_depth,_spectrum);
      T *ptrd = res._data;
      cimg_forZC(*this,z,c) cimg_for3x3(*this,x,y,z,c,I,T)
        if (x%2 && y%2) *(ptrd++) = (T)
                          (I[0]*mask[0] + I[1]*mask[1] + I[2]*mask[2] +
                           I[3]*mask[3] + I[4]*mask[4] + I[5]*mask[5] +
                           I[6]*mask[6] + I[7]*mask[7] + I[8]*mask[8]);
      return res;
    }

    //! Resize image to double-size, using the Scale2X algorithm.
    /**
       \note Use anisotropic upscaling algorithm <a href="http://scale2x.sourceforge.net/algorithm.html">described here</a>.
    **/
    CImg<T>& resize_doubleXY() {
      return get_resize_doubleXY().move_to(*this);
    }

    //! Resize image to double-size, using the Scale2X algorithm \newinstance.
    CImg<T> get_resize_doubleXY() const {
#define _cimg_gs2x_for3(bound,i) \
 for (int i = 0, _p1##i = 0, \
      _n1##i = 1>=(bound)?(int)(bound)-1:1; \
      _n1##i<(int)(bound) || i==--_n1##i; \
      _p1##i = i++, ++_n1##i, ptrd1+=(res)._width, ptrd2+=(res)._width)

#define _cimg_gs2x_for3x3(img,x,y,z,c,I,T) \
  _cimg_gs2x_for3((img)._height,y) for (int x = 0, \
   _p1##x = 0, \
   _n1##x = (int)( \
   (I[1] = (T)(img)(_p1##x,_p1##y,z,c)), \
   (I[3] = I[4] = (T)(img)(0,y,z,c)), \
   (I[7] = (T)(img)(0,_n1##y,z,c)),	\
   1>=(img)._width?(img).width()-1:1); \
   (_n1##x<(img).width() && ( \
   (I[2] = (T)(img)(_n1##x,_p1##y,z,c)), \
   (I[5] = (T)(img)(_n1##x,y,z,c)), \
   (I[8] = (T)(img)(_n1##x,_n1##y,z,c)),1)) || \
   x==--_n1##x; \
   I[1] = I[2], \
   I[3] = I[4], I[4] = I[5], \
   I[7] = I[8], \
   _p1##x = x++, ++_n1##x)

      if (is_empty()) return *this;
      CImg<T> res(_width<<1,_height<<1,_depth,_spectrum);
      CImg_3x3(I,T);
      cimg_forZC(*this,z,c) {
        T
          *ptrd1 = res.data(0,0,z,c),
          *ptrd2 = ptrd1 + res._width;
        _cimg_gs2x_for3x3(*this,x,y,z,c,I,T) {
          if (Icp!=Icn && Ipc!=Inc) {
            *(ptrd1++) = Ipc==Icp?Ipc:Icc;
            *(ptrd1++) = Icp==Inc?Inc:Icc;
            *(ptrd2++) = Ipc==Icn?Ipc:Icc;
            *(ptrd2++) = Icn==Inc?Inc:Icc;
          } else { *(ptrd1++) = Icc; *(ptrd1++) = Icc; *(ptrd2++) = Icc; *(ptrd2++) = Icc; }
        }
      }
      return res;
    }

    //! Resize image to triple-size, using the Scale3X algorithm.
    /**
       \note Use anisotropic upscaling algorithm <a href="http://scale2x.sourceforge.net/algorithm.html">described here</a>.
    **/
    CImg<T>& resize_tripleXY() {
      return get_resize_tripleXY().move_to(*this);
    }

    //! Resize image to triple-size, using the Scale3X algorithm \newinstance.
    CImg<T> get_resize_tripleXY() const {
#define _cimg_gs3x_for3(bound,i) \
 for (int i = 0, _p1##i = 0, \
      _n1##i = 1>=(bound)?(int)(bound)-1:1; \
      _n1##i<(int)(bound) || i==--_n1##i; \
      _p1##i = i++, ++_n1##i, ptrd1+=2*(res)._width, ptrd2+=2*(res)._width, ptrd3+=2*(res)._width)

#define _cimg_gs3x_for3x3(img,x,y,z,c,I,T) \
  _cimg_gs3x_for3((img)._height,y) for (int x = 0, \
   _p1##x = 0, \
   _n1##x = (int)( \
   (I[0] = I[1] = (T)(img)(_p1##x,_p1##y,z,c)), \
   (I[3] = I[4] = (T)(img)(0,y,z,c)), \
   (I[6] = I[7] = (T)(img)(0,_n1##y,z,c)),	\
   1>=(img)._width?(img).width()-1:1); \
   (_n1##x<(img).width() && ( \
   (I[2] = (T)(img)(_n1##x,_p1##y,z,c)), \
   (I[5] = (T)(img)(_n1##x,y,z,c)), \
   (I[8] = (T)(img)(_n1##x,_n1##y,z,c)),1)) || \
   x==--_n1##x; \
   I[0] = I[1], I[1] = I[2], \
   I[3] = I[4], I[4] = I[5], \
   I[6] = I[7], I[7] = I[8], \
   _p1##x = x++, ++_n1##x)

      if (is_empty()) return *this;
      CImg<T> res(3*_width,3*_height,_depth,_spectrum);
      CImg_3x3(I,T);
      cimg_forZC(*this,z,c) {
        T
          *ptrd1 = res.data(0,0,z,c),
          *ptrd2 = ptrd1 + res._width,
          *ptrd3 = ptrd2 + res._width;
        _cimg_gs3x_for3x3(*this,x,y,z,c,I,T) {
          if (Icp != Icn && Ipc != Inc) {
            *(ptrd1++) = Ipc==Icp?Ipc:Icc;
            *(ptrd1++) = (Ipc==Icp && Icc!=Inp) || (Icp==Inc && Icc!=Ipp)?Icp:Icc;
            *(ptrd1++) = Icp==Inc?Inc:Icc;
            *(ptrd2++) = (Ipc==Icp && Icc!=Ipn) || (Ipc==Icn && Icc!=Ipp)?Ipc:Icc;
            *(ptrd2++) = Icc;
            *(ptrd2++) = (Icp==Inc && Icc!=Inn) || (Icn==Inc && Icc!=Inp)?Inc:Icc;
            *(ptrd3++) = Ipc==Icn?Ipc:Icc;
            *(ptrd3++) = (Ipc==Icn && Icc!=Inn) || (Icn==Inc && Icc!=Ipn)?Icn:Icc;
            *(ptrd3++) = Icn==Inc?Inc:Icc;
          } else {
            *(ptrd1++) = Icc; *(ptrd1++) = Icc; *(ptrd1++) = Icc;
            *(ptrd2++) = Icc; *(ptrd2++) = Icc; *(ptrd2++) = Icc;
            *(ptrd3++) = Icc; *(ptrd3++) = Icc; *(ptrd3++) = Icc;
          }
        }
      }
      return res;
    }

    //! Mirror image content along specified axis.
    /**
       \param axis Mirror axis
    **/
    CImg<T>& mirror(const char axis) {
      if (is_empty()) return *this;
      T *pf, *pb, *buf = 0;
      switch (cimg::uncase(axis)) {
      case 'x' : {
        pf = _data; pb = data(_width-1);
        const unsigned int width2 = _width/2;
        for (unsigned int yzv = 0; yzv<_height*_depth*_spectrum; ++yzv) {
          for (unsigned int x = 0; x<width2; ++x) { const T val = *pf; *(pf++) = *pb; *(pb--) = val; }
          pf+=_width - width2;
          pb+=_width + width2;
        }
      } break;
      case 'y' : {
        buf = new T[_width];
        pf = _data; pb = data(0,_height-1);
        const unsigned int height2 = _height/2;
        for (unsigned int zv = 0; zv<_depth*_spectrum; ++zv) {
          for (unsigned int y = 0; y<height2; ++y) {
            std::memcpy(buf,pf,_width*sizeof(T));
            std::memcpy(pf,pb,_width*sizeof(T));
            std::memcpy(pb,buf,_width*sizeof(T));
            pf+=_width;
            pb-=_width;
          }
          pf+=(unsigned long)_width*(_height - height2);
          pb+=(unsigned long)_width*(_height + height2);
        }
      } break;
      case 'z' : {
        buf = new T[(unsigned long)_width*_height];
        pf = _data; pb = data(0,0,_depth-1);
        const unsigned int depth2 = _depth/2;
        cimg_forC(*this,c) {
          for (unsigned int z = 0; z<depth2; ++z) {
            std::memcpy(buf,pf,_width*_height*sizeof(T));
            std::memcpy(pf,pb,_width*_height*sizeof(T));
            std::memcpy(pb,buf,_width*_height*sizeof(T));
            pf+=(unsigned long)_width*_height;
            pb-=(unsigned long)_width*_height;
          }
          pf+=(unsigned long)_width*_height*(_depth - depth2);
          pb+=(unsigned long)_width*_height*(_depth + depth2);
        }
      } break;
      case 'c' : {
        buf = new T[(unsigned long)_width*_height*_depth];
        pf = _data; pb = data(0,0,0,_spectrum-1);
        const unsigned int _spectrum2 = _spectrum/2;
        for (unsigned int v = 0; v<_spectrum2; ++v) {
          std::memcpy(buf,pf,_width*_height*_depth*sizeof(T));
          std::memcpy(pf,pb,_width*_height*_depth*sizeof(T));
          std::memcpy(pb,buf,_width*_height*_depth*sizeof(T));
          pf+=(unsigned long)_width*_height*_depth;
          pb-=(unsigned long)_width*_height*_depth;
        }
      } break;
      default :
        throw CImgArgumentException(_cimg_instance
                                    "mirror(): Invalid specified axis '%c'.",
                                    cimg_instance,
                                    axis);
      }
      delete[] buf;
      return *this;
    }

    //! Mirror image content along specified axis \newinstance.
    CImg<T> get_mirror(const char axis) const {
      return (+*this).mirror(axis);
    }

    //! Mirror image content along specified axes.
    /**
       \param axes Mirror axes, as a C-string.
       \note \c axes may contains multiple character, e.g. \c "xyz"
    **/
    CImg<T>& mirror(const char *const axes) {
      for (const char *s = axes; *s; s++) mirror(*s);
      return *this;
    }

    //! Mirror image content along specified axes \newinstance.
    CImg<T> get_mirror(const char *const axes) const {
      return (+*this).mirror(axes);
    }

    //! Shift image content.
    /**
       \param delta_x Amount of displacement along the X-axis.
       \param delta_y Amount of displacement along the Y-axis.
       \param delta_z Amount of displacement along the Z-axis.
       \param delta_c Amount of displacement along the C-axis.
       \param boundary_conditions Border condition.

       - \c boundary_conditions can be:
          - 0: Zero border condition (Dirichlet).
          - 1: Nearest neighbors (Neumann).
          - 2: Repeat Pattern (Fourier style).
    **/
    CImg<T>& shift(const int delta_x, const int delta_y=0, const int delta_z=0, const int delta_c=0,
                   const int boundary_conditions=0) {
      if (is_empty()) return *this;
      if (delta_x) // Shift along X-axis
        switch (boundary_conditions) {
        case 0 :
          if (cimg::abs(delta_x)>=width()) return fill(0);
          if (delta_x<0) cimg_forYZC(*this,y,z,c) {
            std::memmove(data(0,y,z,c),data(-delta_x,y,z,c),(_width+delta_x)*sizeof(T));
            std::memset(data(_width+delta_x,y,z,c),0,-delta_x*sizeof(T));
          } else cimg_forYZC(*this,y,z,c) {
            std::memmove(data(delta_x,y,z,c),data(0,y,z,c),(_width-delta_x)*sizeof(T));
            std::memset(data(0,y,z,c),0,delta_x*sizeof(T));
          }
          break;
        case 1 :
          if (delta_x<0) {
            const int ndelta_x = (-delta_x>=width())?width()-1:-delta_x;
            if (!ndelta_x) return *this;
            cimg_forYZC(*this,y,z,c) {
              std::memmove(data(0,y,z,c),data(ndelta_x,y,z,c),(_width-ndelta_x)*sizeof(T));
              T *ptrd = data(_width-1,y,z,c);
              const T val = *ptrd;
              for (int l = 0; l<ndelta_x-1; ++l) *(--ptrd) = val;
            }
          } else {
            const int ndelta_x = (delta_x>=width())?width()-1:delta_x;
            if (!ndelta_x) return *this;
            cimg_forYZC(*this,y,z,c) {
              std::memmove(data(ndelta_x,y,z,c),data(0,y,z,c),(_width-ndelta_x)*sizeof(T));
              T *ptrd = data(0,y,z,c);
              const T val = *ptrd;
              for (int l = 0; l<ndelta_x-1; ++l) *(++ptrd) = val;
            }
          }
          break;
        default : {
          const int ml = cimg::mod(-delta_x,width()), ndelta_x = (ml<=width()/2)?ml:(ml-width());
          if (!ndelta_x) return *this;
          T *const buf = new T[cimg::abs(ndelta_x)];
          if (ndelta_x>0) cimg_forYZC(*this,y,z,c) {
            std::memcpy(buf,data(0,y,z,c),ndelta_x*sizeof(T));
            std::memmove(data(0,y,z,c),data(ndelta_x,y,z,c),(_width-ndelta_x)*sizeof(T));
            std::memcpy(data(_width-ndelta_x,y,z,c),buf,ndelta_x*sizeof(T));
          } else cimg_forYZC(*this,y,z,c) {
            std::memcpy(buf,data(_width+ndelta_x,y,z,c),-ndelta_x*sizeof(T));
            std::memmove(data(-ndelta_x,y,z,c),data(0,y,z,c),(_width+ndelta_x)*sizeof(T));
            std::memcpy(data(0,y,z,c),buf,-ndelta_x*sizeof(T));
          }
          delete[] buf;
        }
        }

      if (delta_y) // Shift along Y-axis
        switch (boundary_conditions) {
        case 0 :
          if (cimg::abs(delta_y)>=height()) return fill(0);
          if (delta_y<0) cimg_forZC(*this,z,c) {
            std::memmove(data(0,0,z,c),data(0,-delta_y,z,c),_width*(_height+delta_y)*sizeof(T));
            std::memset(data(0,_height+delta_y,z,c),0,-delta_y*_width*sizeof(T));
          } else cimg_forZC(*this,z,c) {
            std::memmove(data(0,delta_y,z,c),data(0,0,z,c),_width*(_height-delta_y)*sizeof(T));
            std::memset(data(0,0,z,c),0,delta_y*_width*sizeof(T));
          }
          break;
        case 1 :
          if (delta_y<0) {
            const int ndelta_y = (-delta_y>=height())?height()-1:-delta_y;
            if (!ndelta_y) return *this;
            cimg_forZC(*this,z,c) {
              std::memmove(data(0,0,z,c),data(0,ndelta_y,z,c),_width*(_height-ndelta_y)*sizeof(T));
              T *ptrd = data(0,_height-ndelta_y,z,c), *ptrs = data(0,_height-1,z,c);
              for (int l = 0; l<ndelta_y-1; ++l) { std::memcpy(ptrd,ptrs,_width*sizeof(T)); ptrd+=_width; }
            }
          } else {
            const int ndelta_y = (delta_y>=height())?height()-1:delta_y;
            if (!ndelta_y) return *this;
            cimg_forZC(*this,z,c) {
              std::memmove(data(0,ndelta_y,z,c),data(0,0,z,c),_width*(_height-ndelta_y)*sizeof(T));
              T *ptrd = data(0,1,z,c), *ptrs = data(0,0,z,c);
              for (int l = 0; l<ndelta_y-1; ++l) { std::memcpy(ptrd,ptrs,_width*sizeof(T)); ptrd+=_width; }
            }
          }
          break;
        default : {
          const int ml = cimg::mod(-delta_y,height()), ndelta_y = (ml<=height()/2)?ml:(ml-height());
          if (!ndelta_y) return *this;
          T *const buf = new T[(unsigned long)_width*cimg::abs(ndelta_y)];
          if (ndelta_y>0) cimg_forZC(*this,z,c) {
            std::memcpy(buf,data(0,0,z,c),_width*ndelta_y*sizeof(T));
            std::memmove(data(0,0,z,c),data(0,ndelta_y,z,c),_width*(_height-ndelta_y)*sizeof(T));
            std::memcpy(data(0,_height-ndelta_y,z,c),buf,_width*ndelta_y*sizeof(T));
          } else cimg_forZC(*this,z,c) {
            std::memcpy(buf,data(0,_height+ndelta_y,z,c),-ndelta_y*_width*sizeof(T));
            std::memmove(data(0,-ndelta_y,z,c),data(0,0,z,c),_width*(_height+ndelta_y)*sizeof(T));
            std::memcpy(data(0,0,z,c),buf,-ndelta_y*_width*sizeof(T));
          }
          delete[] buf;
        }
        }

      if (delta_z) // Shift along Z-axis
        switch (boundary_conditions) {
        case 0 :
          if (cimg::abs(delta_z)>=depth()) return fill(0);
          if (delta_z<0) cimg_forC(*this,c) {
            std::memmove(data(0,0,0,c),data(0,0,-delta_z,c),_width*_height*(_depth+delta_z)*sizeof(T));
            std::memset(data(0,0,_depth+delta_z,c),0,_width*_height*(-delta_z)*sizeof(T));
          } else cimg_forC(*this,c) {
            std::memmove(data(0,0,delta_z,c),data(0,0,0,c),_width*_height*(_depth-delta_z)*sizeof(T));
            std::memset(data(0,0,0,c),0,delta_z*_width*_height*sizeof(T));
          }
          break;
        case 1 :
          if (delta_z<0) {
            const int ndelta_z = (-delta_z>=depth())?depth()-1:-delta_z;
            if (!ndelta_z) return *this;
            cimg_forC(*this,c) {
              std::memmove(data(0,0,0,c),data(0,0,ndelta_z,c),_width*_height*(_depth-ndelta_z)*sizeof(T));
              T *ptrd = data(0,0,_depth-ndelta_z,c), *ptrs = data(0,0,_depth-1,c);
              for (int l = 0; l<ndelta_z-1; ++l) { std::memcpy(ptrd,ptrs,_width*_height*sizeof(T)); ptrd+=(unsigned long)_width*_height; }
            }
          } else {
            const int ndelta_z = (delta_z>=depth())?depth()-1:delta_z;
            if (!ndelta_z) return *this;
            cimg_forC(*this,c) {
              std::memmove(data(0,0,ndelta_z,c),data(0,0,0,c),_width*_height*(_depth-ndelta_z)*sizeof(T));
              T *ptrd = data(0,0,1,c), *ptrs = data(0,0,0,c);
              for (int l = 0; l<ndelta_z-1; ++l) { std::memcpy(ptrd,ptrs,_width*_height*sizeof(T)); ptrd+=(unsigned long)_width*_height; }
            }
          }
          break;
        default : {
          const int ml = cimg::mod(-delta_z,depth()), ndelta_z = (ml<=depth()/2)?ml:(ml-depth());
          if (!ndelta_z) return *this;
          T *const buf = new T[(unsigned long)_width*_height*cimg::abs(ndelta_z)];
          if (ndelta_z>0) cimg_forC(*this,c) {
            std::memcpy(buf,data(0,0,0,c),_width*_height*ndelta_z*sizeof(T));
            std::memmove(data(0,0,0,c),data(0,0,ndelta_z,c),_width*_height*(_depth-ndelta_z)*sizeof(T));
            std::memcpy(data(0,0,_depth-ndelta_z,c),buf,_width*_height*ndelta_z*sizeof(T));
          } else cimg_forC(*this,c) {
            std::memcpy(buf,data(0,0,_depth+ndelta_z,c),-ndelta_z*_width*_height*sizeof(T));
            std::memmove(data(0,0,-ndelta_z,c),data(0,0,0,c),_width*_height*(_depth+ndelta_z)*sizeof(T));
            std::memcpy(data(0,0,0,c),buf,-ndelta_z*_width*_height*sizeof(T));
          }
          delete[] buf;
        }
        }

      if (delta_c) // Shift along C-axis
        switch (boundary_conditions) {
        case 0 :
          if (cimg::abs(delta_c)>=spectrum()) return fill(0);
          if (delta_c<0) {
            std::memmove(_data,data(0,0,0,-delta_c),_width*_height*_depth*(_spectrum+delta_c)*sizeof(T));
            std::memset(data(0,0,0,_spectrum+delta_c),0,_width*_height*_depth*(-delta_c)*sizeof(T));
          } else {
            std::memmove(data(0,0,0,delta_c),_data,_width*_height*_depth*(_spectrum-delta_c)*sizeof(T));
            std::memset(_data,0,delta_c*_width*_height*_depth*sizeof(T));
          }
          break;
        case 1 :
          if (delta_c<0) {
            const int ndelta_c = (-delta_c>=spectrum())?spectrum()-1:-delta_c;
            if (!ndelta_c) return *this;
            std::memmove(_data,data(0,0,0,ndelta_c),_width*_height*_depth*(_spectrum-ndelta_c)*sizeof(T));
            T *ptrd = data(0,0,0,_spectrum-ndelta_c), *ptrs = data(0,0,0,_spectrum-1);
            for (int l = 0; l<ndelta_c-1; ++l) { std::memcpy(ptrd,ptrs,_width*_height*_depth*sizeof(T)); ptrd+=(unsigned long)_width*_height*_depth; }
          } else {
            const int ndelta_c = (delta_c>=spectrum())?spectrum()-1:delta_c;
            if (!ndelta_c) return *this;
            std::memmove(data(0,0,0,ndelta_c),_data,_width*_height*_depth*(_spectrum-ndelta_c)*sizeof(T));
            T *ptrd = data(0,0,0,1);
            for (int l = 0; l<ndelta_c-1; ++l) { std::memcpy(ptrd,_data,_width*_height*_depth*sizeof(T)); ptrd+=(unsigned long)_width*_height*_depth; }
          }
          break;
        default : {
          const int ml = cimg::mod(-delta_c,spectrum()), ndelta_c = (ml<=spectrum()/2)?ml:(ml-spectrum());
          if (!ndelta_c) return *this;
          T *const buf = new T[(unsigned long)_width*_height*_depth*cimg::abs(ndelta_c)];
          if (ndelta_c>0) {
            std::memcpy(buf,_data,_width*_height*_depth*ndelta_c*sizeof(T));
            std::memmove(_data,data(0,0,0,ndelta_c),_width*_height*_depth*(_spectrum-ndelta_c)*sizeof(T));
            std::memcpy(data(0,0,0,_spectrum-ndelta_c),buf,_width*_height*_depth*ndelta_c*sizeof(T));
          } else {
            std::memcpy(buf,data(0,0,0,_spectrum+ndelta_c),-ndelta_c*_width*_height*_depth*sizeof(T));
            std::memmove(data(0,0,0,-ndelta_c),_data,_width*_height*_depth*(_spectrum+ndelta_c)*sizeof(T));
            std::memcpy(_data,buf,-ndelta_c*_width*_height*_depth*sizeof(T));
          }
          delete[] buf;
        }
        }
      return *this;
    }

    //! Shift image content \newinstance.
    CImg<T> get_shift(const int delta_x, const int delta_y=0, const int delta_z=0, const int delta_c=0,
                          const int boundary_conditions=0) const {
      return (+*this).shift(delta_x,delta_y,delta_z,delta_c,boundary_conditions);
    }

    //! Permute axes order.
    /**
       \param order Axes permutations, as a C-string of 4 characters.
       This function permutes image content regarding the specified axes permutation.
    **/
    CImg<T>& permute_axes(const char *const order) {
      return get_permute_axes(order).move_to(*this);
    }

    //! Permute axes order \newinstance.
    CImg<T> get_permute_axes(const char *const order) const {
      const T foo = (T)0;
      return _get_permute_axes(order,foo);
    }

    template<typename t>
    CImg<t> _get_permute_axes(const char *const permut, const t&) const {
      if (is_empty() || !permut) return CImg<t>(*this,false);
      CImg<t> res;
      const T* ptrs = _data;
      if (!cimg::strncasecmp(permut,"xyzc",4)) return +*this;
      if (!cimg::strncasecmp(permut,"xycz",4)) {
	res.assign(_width,_height,_spectrum,_depth);
        const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	cimg_forXYZC(*this,x,y,z,c) res(x,y,c,z,wh,whd) = (t)*(ptrs++);
      }
      if (!cimg::strncasecmp(permut,"xzyc",4)) {
	res.assign(_width,_depth,_height,_spectrum);
        const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	cimg_forXYZC(*this,x,y,z,c) res(x,z,y,c,wh,whd) = (t)*(ptrs++);
      }
      if (!cimg::strncasecmp(permut,"xzcy",4)) {
	res.assign(_width,_depth,_spectrum,_height);
        const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	cimg_forXYZC(*this,x,y,z,c) res(x,z,c,y,wh,whd) = (t)*(ptrs++);
      }
      if (!cimg::strncasecmp(permut,"xcyz",4)) {
	res.assign(_width,_spectrum,_height,_depth);
        const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	cimg_forXYZC(*this,x,y,z,c) res(x,c,y,z,wh,whd) = (t)*(ptrs++);
      }
      if (!cimg::strncasecmp(permut,"xczy",4)) {
	res.assign(_width,_spectrum,_depth,_height);
        const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	cimg_forXYZC(*this,x,y,z,c) res(x,c,z,y,wh,whd) = (t)*(ptrs++);
      }
      if (!cimg::strncasecmp(permut,"yxzc",4)) {
	res.assign(_height,_width,_depth,_spectrum);
        const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	cimg_forXYZC(*this,x,y,z,c) res(y,x,z,c,wh,whd) = (t)*(ptrs++);
      }
      if (!cimg::strncasecmp(permut,"yxcz",4)) {
	res.assign(_height,_width,_spectrum,_depth);
        const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	cimg_forXYZC(*this,x,y,z,c) res(y,x,c,z,wh,whd) = (t)*(ptrs++);
      }
      if (!cimg::strncasecmp(permut,"yzxc",4)) {
	res.assign(_height,_depth,_width,_spectrum);
        const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	cimg_forXYZC(*this,x,y,z,c) res(y,z,x,c,wh,whd) = (t)*(ptrs++);
      }
      if (!cimg::strncasecmp(permut,"yzcx",4)) {
	res.assign(_height,_depth,_spectrum,_width);
	switch (_width) {
	case 1 : {
	  t *ptr_r = res.data(0,0,0,0);
	  for (unsigned int siz = _height*_depth*_spectrum; siz; --siz) {
	    *(ptr_r++) = (t)*(ptrs++);
	  }
	} break;
	case 2 : {
	  t *ptr_r = res.data(0,0,0,0), *ptr_g = res.data(0,0,0,1);
	  for (unsigned int siz = _height*_depth*_spectrum; siz; --siz) {
	    *(ptr_r++) = (t)*(ptrs++); *(ptr_g++) = (t)*(ptrs++);
	  }
	} break;
	case 3 : { // Optimization for the classical conversion from interleaved RGB to planar RGB
	  t *ptr_r = res.data(0,0,0,0), *ptr_g = res.data(0,0,0,1), *ptr_b = res.data(0,0,0,2);
	  for (unsigned int siz = _height*_depth*_spectrum; siz; --siz) {
	    *(ptr_r++) = (t)*(ptrs++); *(ptr_g++) = (t)*(ptrs++); *(ptr_b++) = (t)*(ptrs++);
	  }
	} break;
	case 4 : { // Optimization for the classical conversion from interleaved RGBA to planar RGBA
	  t *ptr_r = res.data(0,0,0,0), *ptr_g = res.data(0,0,0,1), *ptr_b = res.data(0,0,0,2), *ptr_a = res.data(0,0,0,3);
	  for (unsigned int siz = _height*_depth*_spectrum; siz; --siz) {
	    *(ptr_r++) = (t)*(ptrs++); *(ptr_g++) = (t)*(ptrs++); *(ptr_b++) = (t)*(ptrs++); *(ptr_a++) = (t)*(ptrs++);
	  }
	} break;
	default : {
          const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	  cimg_forXYZC(*this,x,y,z,c) res(y,z,c,x,wh,whd) = *(ptrs++);
          return res;
	}
	}
      }
      if (!cimg::strncasecmp(permut,"ycxz",4)) {
	res.assign(_height,_spectrum,_width,_depth);
        const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	cimg_forXYZC(*this,x,y,z,c) res(y,c,x,z,wh,whd) = (t)*(ptrs++);
      }
      if (!cimg::strncasecmp(permut,"yczx",4)) {
	res.assign(_height,_spectrum,_depth,_width);
        const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	cimg_forXYZC(*this,x,y,z,c) res(y,c,z,x,wh,whd) = (t)*(ptrs++);
      }
      if (!cimg::strncasecmp(permut,"zxyc",4)) {
	res.assign(_depth,_width,_height,_spectrum);
        const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	cimg_forXYZC(*this,x,y,z,c) res(z,x,y,c,wh,whd) = (t)*(ptrs++);
      }
      if (!cimg::strncasecmp(permut,"zxcy",4)) {
	res.assign(_depth,_width,_spectrum,_height);
        const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	cimg_forXYZC(*this,x,y,z,c) res(z,x,c,y,wh,whd) = (t)*(ptrs++);
      }
      if (!cimg::strncasecmp(permut,"zyxc",4)) {
	res.assign(_depth,_height,_width,_spectrum);
        const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	cimg_forXYZC(*this,x,y,z,c) res(z,y,x,c,wh,whd) = (t)*(ptrs++);
      }
      if (!cimg::strncasecmp(permut,"zycx",4)) {
	res.assign(_depth,_height,_spectrum,_width);
        const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	cimg_forXYZC(*this,x,y,z,c) res(z,y,c,x,wh,whd) = (t)*(ptrs++);
      }
      if (!cimg::strncasecmp(permut,"zcxy",4)) {
	res.assign(_depth,_spectrum,_width,_height);
        const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	cimg_forXYZC(*this,x,y,z,c) res(z,c,x,y,wh,whd) = (t)*(ptrs++);
      }
      if (!cimg::strncasecmp(permut,"zcyx",4)) {
	res.assign(_depth,_spectrum,_height,_width);
        const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	cimg_forXYZC(*this,x,y,z,c) res(z,c,y,x,wh,whd) = (t)*(ptrs++);
      }
      if (!cimg::strncasecmp(permut,"cxyz",4)) {
	res.assign(_spectrum,_width,_height,_depth);
	switch (_spectrum) {
	case 1 : {
	  const T *ptr_r = data(0,0,0,0);
	  t *ptrd = res._data;
	  for (unsigned long siz = (unsigned long)_width*_height*_depth; siz; --siz) *(ptrd++) = (t)*(ptr_r++);
	} break;
	case 2 : {
	  const T *ptr_r = data(0,0,0,0), *ptr_g = data(0,0,0,1);
	  t *ptrd = res._data;
	  for (unsigned long siz = (unsigned long)_width*_height*_depth; siz; --siz) {
	    *(ptrd++) = (t)*(ptr_r++); *(ptrd++) = (t)*(ptr_g++);
	  }
	} break;
	case 3 : { // Optimization for the classical conversion from planar RGB to interleaved RGB
	  const T *ptr_r = data(0,0,0,0), *ptr_g = data(0,0,0,1), *ptr_b = data(0,0,0,2);
	  t *ptrd = res._data;
	  for (unsigned long siz = (unsigned long)_width*_height*_depth; siz; --siz) {
	    *(ptrd++) = (t)*(ptr_r++); *(ptrd++) = (t)*(ptr_g++); *(ptrd++) = (t)*(ptr_b++);
	  }
	} break;
	case 4 : { // Optimization for the classical conversion from planar RGBA to interleaved RGBA
	  const T *ptr_r = data(0,0,0,0), *ptr_g = data(0,0,0,1), *ptr_b = data(0,0,0,2), *ptr_a = data(0,0,0,3);
	  t *ptrd = res._data;
	  for (unsigned long siz = (unsigned long)_width*_height*_depth; siz; --siz) {
	    *(ptrd++) = (t)*(ptr_r++); *(ptrd++) = (t)*(ptr_g++); *(ptrd++) = (t)*(ptr_b++); *(ptrd++) = (t)*(ptr_a++);
	  }
	} break;
	default : {
          const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	  cimg_forXYZC(*this,x,y,z,c) res(c,x,y,z,wh,whd) = (t)*(ptrs++);
	}
	}
      }
      if (!cimg::strncasecmp(permut,"cxzy",4)) {
	res.assign(_spectrum,_width,_depth,_height);
        const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	cimg_forXYZC(*this,x,y,z,c) res(c,x,z,y,wh,whd) = (t)*(ptrs++);
      }
      if (!cimg::strncasecmp(permut,"cyxz",4)) {
	res.assign(_spectrum,_height,_width,_depth);
        const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	cimg_forXYZC(*this,x,y,z,c) res(c,y,x,z,wh,whd) = (t)*(ptrs++);
      }
      if (!cimg::strncasecmp(permut,"cyzx",4)) {
	res.assign(_spectrum,_height,_depth,_width);
        const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	cimg_forXYZC(*this,x,y,z,c) res(c,y,z,x,wh,whd) = (t)*(ptrs++);
      }
      if (!cimg::strncasecmp(permut,"czxy",4)) {
	res.assign(_spectrum,_depth,_width,_height);
        const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	cimg_forXYZC(*this,x,y,z,c) res(c,z,x,y,wh,whd) = (t)*(ptrs++);
      }
      if (!cimg::strncasecmp(permut,"czyx",4)) {
	res.assign(_spectrum,_depth,_height,_width);
        const unsigned long wh = (unsigned long)res._width*res._height, whd = wh*res._depth;
	cimg_forXYZC(*this,x,y,z,c) res(c,z,y,x,wh,whd) = (t)*(ptrs++);
      }
      if (!res)
        throw CImgArgumentException(_cimg_instance
                                    "permute_axes(): Invalid specified permutation '%s'.",
                                    cimg_instance,
                                    permut);
      return res;
    }

    //! Unroll pixel values along specified axis.
    /**
       \param axis Unroll axis (can be \c 'x', \c 'y', \c 'z' or c 'c').
    **/
    CImg<T>& unroll(const char axis) {
      const unsigned int siz = size();
      if (siz) switch (axis) {
      case 'x' : _width = siz; _height = _depth = _spectrum = 1; break;
      case 'y' : _height = siz; _width = _depth = _spectrum = 1; break;
      case 'z' : _depth = siz; _width = _height = _spectrum = 1; break;
      default : _spectrum = siz; _width = _height = _depth = 1;
      }
      return *this;
    }

    //! Unroll pixel values along specified axis \newinstance.
    CImg<T> get_unroll(const char axis) const {
      return (+*this).unroll(axis);
    }

    //! Rotate image with arbitrary angle.
    /**
       \param angle Rotation angle, in degrees.
       \param interpolation Type of interpolation. Can be <tt>{ 0=nearest | 1=linear | 2=cubic }</tt>.
       \param boundary Boundary conditions. Can be <tt>{  0=dirichlet | 1=neumann | 2=cyclic }</tt>.
       \note Most of the time, size of the image is modified.
    **/
    CImg<T>& rotate(const float angle, const unsigned int interpolation=1, const unsigned int boundary=0) {
      return get_rotate(angle,interpolation,boundary).move_to(*this);
    }

    //! Rotate image with arbitrary angle \newinstance.
    CImg<T> get_rotate(const float angle, const unsigned int interpolation=1, const unsigned int boundary=0) const {
      if (is_empty()) return *this;
      CImg<T> res;
      const float nangle = cimg::mod(angle,360.0f);
      if (boundary!=1 && cimg::mod(nangle,90.0f)==0) { // Optimized version for orthogonal angles.
        const int wm1 = width() - 1, hm1 = height() - 1;
        const int iangle = (int)nangle/90;
        switch (iangle) {
        case 1 : { // 90 deg.
          res.assign(_height,_width,_depth,_spectrum);
          T *ptrd = res._data;
          cimg_forXYZC(res,x,y,z,c) *(ptrd++) = (*this)(y,hm1-x,z,c);
        } break;
        case 2 : { // 180 deg.
          res.assign(_width,_height,_depth,_spectrum);
          T *ptrd = res._data;
          cimg_forXYZC(res,x,y,z,c) *(ptrd++) = (*this)(wm1-x,hm1-y,z,c);
        } break;
        case 3 : { // 270 deg.
          res.assign(_height,_width,_depth,_spectrum);
          T *ptrd = res._data;
          cimg_forXYZC(res,x,y,z,c) *(ptrd++) = (*this)(wm1-y,x,z,c);
        } break;
        default : // 0 deg.
          return *this;
        }
      } else { // Generic angle.
        const Tfloat vmin = (Tfloat)cimg::type<T>::min(), vmax = (Tfloat)cimg::type<T>::max();
        const float
          rad = (float)(nangle*cimg::PI/180.0),
          ca = (float)std::cos(rad),
          sa = (float)std::sin(rad),
          ux = cimg::abs(_width*ca), uy = cimg::abs(_width*sa),
          vx = cimg::abs(_height*sa), vy = cimg::abs(_height*ca),
          w2 = 0.5f*_width, h2 = 0.5f*_height,
          dw2 = 0.5f*(ux+vx), dh2 = 0.5f*(uy+vy);
        res.assign((int)(ux+vx),(int)(uy+vy),_depth,_spectrum);
        switch (boundary) {
        case 0 : { // Dirichlet boundaries.
          switch (interpolation) {
          case 2 : { // Cubic interpolation.
            cimg_forXY(res,x,y) cimg_forZC(*this,z,c) {
              const Tfloat val = cubic_atXY(w2 + (x-dw2)*ca + (y-dh2)*sa,h2 - (x-dw2)*sa + (y-dh2)*ca,z,c,0);
              res(x,y,z,c) = (T)(val<vmin?vmin:val>vmax?vmax:val);
            }
          } break;
          case 1 : { // Linear interpolation.
            cimg_forXY(res,x,y) cimg_forZC(*this,z,c)
              res(x,y,z,c) = (T)linear_atXY(w2 + (x-dw2)*ca + (y-dh2)*sa,h2 - (x-dw2)*sa + (y-dh2)*ca,z,c,0);
          } break;
          default : { // Nearest-neighbor interpolation.
            cimg_forXY(res,x,y) cimg_forZC(*this,z,c)
              res(x,y,z,c) = atXY((int)(w2 + (x-dw2)*ca + (y-dh2)*sa),(int)(h2 - (x-dw2)*sa + (y-dh2)*ca),z,c,0);
          }
          }
        } break;
        case 1 : { // Neumann boundaries.
          switch (interpolation) {
          case 2 : { // Cubic interpolation.
            cimg_forXY(res,x,y) cimg_forZC(*this,z,c) {
              const Tfloat val = _cubic_atXY(w2 + (x-dw2)*ca + (y-dh2)*sa,h2 - (x-dw2)*sa + (y-dh2)*ca,z,c);
              res(x,y,z,c) = (T)(val<vmin?vmin:val>vmax?vmax:val);
            }
          } break;
          case 1 : { // Linear interpolation.
            cimg_forXY(res,x,y) cimg_forZC(*this,z,c)
              res(x,y,z,c) = (T)_linear_atXY(w2 + (x-dw2)*ca + (y-dh2)*sa,h2 - (x-dw2)*sa + (y-dh2)*ca,z,c);
          } break;
          default : { // Nearest-neighbor interpolation.
            cimg_forXY(res,x,y) cimg_forZC(*this,z,c)
              res(x,y,z,c) = _atXY((int)(w2 + (x-dw2)*ca + (y-dh2)*sa),(int)(h2 - (x-dw2)*sa + (y-dh2)*ca),z,c);
          }
          }
        } break;
        case 2 : { // Cyclic boundaries.
          switch (interpolation) {
          case 2 : { // Cubic interpolation.
            cimg_forXY(res,x,y) cimg_forZC(*this,z,c) {
              const Tfloat val = _cubic_atXY(cimg::mod(w2 + (x-dw2)*ca + (y-dh2)*sa,(float)width()),
                                             cimg::mod(h2 - (x-dw2)*sa + (y-dh2)*ca,(float)height()),z,c);
              res(x,y,z,c) = (T)(val<vmin?vmin:val>vmax?vmax:val);
            }
          } break;
          case 1 : { // Linear interpolation.
            cimg_forXY(res,x,y) cimg_forZC(*this,z,c)
              res(x,y,z,c) = (T)_linear_atXY(cimg::mod(w2 + (x-dw2)*ca + (y-dh2)*sa,(float)width()),
                                             cimg::mod(h2 - (x-dw2)*sa + (y-dh2)*ca,(float)height()),z,c);
          } break;
          default : { // Nearest-neighbor interpolation.
            cimg_forXY(res,x,y) cimg_forZC(*this,z,c)
              res(x,y,z,c) = (*this)(cimg::mod((int)(w2 + (x-dw2)*ca + (y-dh2)*sa),width()),
                                      cimg::mod((int)(h2 - (x-dw2)*sa + (y-dh2)*ca),height()),z,c);
          }
          }
        } break;
	default :
	  throw CImgArgumentException(_cimg_instance
                                      "rotate(): Invalid specified border conditions %d "
                                      "(should be { 0=dirichlet | 1=neumann | 2=cyclic }).",
				      cimg_instance,
                                      boundary);
        }
      }
      return res;
    }

    //! Rotate image with arbitrary angle, around a center point.
    /**
       \param angle Rotation angle, in degrees.
       \param cx X-coordinate of the rotation center.
       \param cy Y-coordinate of the rotation center.
       \param zoom Zoom factor.
       \param boundary_conditions Boundary conditions. Can be <tt>{ 0=dirichlet | 1=neumann | 2=cyclic }</tt>.
       \param interpolation_type Type of interpolation. Can be <tt>{ 0=nearest | 1=linear | 2=cubic }</tt>.
    **/
    CImg<T>& rotate(const float angle, const float cx, const float cy, const float zoom,
                    const unsigned int interpolation=1, const unsigned int boundary=3) {
      return get_rotate(angle,cx,cy,zoom,interpolation,boundary).move_to(*this);
    }

    //! Rotate image with arbitrary angle, around a center point \newinstance.
    CImg<T> get_rotate(const float angle, const float cx, const float cy, const float zoom,
                       const unsigned int interpolation=1, const unsigned int boundary=3) const {
      if (interpolation>2)
        throw CImgArgumentException(_cimg_instance
                                    "rotate(): Invalid specified interpolation type %d "
                                    "(should be { 0=none | 1=linear | 2=cubic }).",
                                    cimg_instance,
                                    interpolation);
      if (is_empty()) return *this;
      CImg<T> res(_width,_height,_depth,_spectrum);
      const Tfloat vmin = (Tfloat)cimg::type<T>::min(), vmax = (Tfloat)cimg::type<T>::max();
      const float
        rad = (float)((angle*cimg::PI)/180.0),
        ca = (float)std::cos(rad)/zoom,
        sa = (float)std::sin(rad)/zoom;
      switch (boundary) {
      case 0 : {
        switch (interpolation) {
        case 2 : {
          cimg_forXY(res,x,y) cimg_forZC(*this,z,c) {
            const Tfloat val = cubic_atXY(cx + (x-cx)*ca + (y-cy)*sa,cy - (x-cx)*sa + (y-cy)*ca,z,c,0);
            res(x,y,z,c) = (T)(val<vmin?vmin:val>vmax?vmax:val);
          }
        } break;
        case 1 : {
          cimg_forXY(res,x,y) cimg_forZC(*this,z,c)
            res(x,y,z,c) = (T)linear_atXY(cx + (x-cx)*ca + (y-cy)*sa,cy - (x-cx)*sa + (y-cy)*ca,z,c,0);
        } break;
        default : {
          cimg_forXY(res,x,y) cimg_forZC(*this,z,c)
            res(x,y,z,c) = atXY((int)(cx + (x-cx)*ca + (y-cy)*sa),(int)(cy - (x-cx)*sa + (y-cy)*ca),z,c,0);
        }
        }
      } break;
      case 1 : {
        switch (interpolation) {
        case 2 : {
          cimg_forXY(res,x,y) cimg_forZC(*this,z,c) {
            const Tfloat val = _cubic_atXY(cx + (x-cx)*ca + (y-cy)*sa,cy - (x-cx)*sa + (y-cy)*ca,z,c);
            res(x,y,z,c) = (T)(val<vmin?vmin:val>vmax?vmax:val);
          }
        } break;
        case 1 : {
          cimg_forXY(res,x,y) cimg_forZC(*this,z,c)
            res(x,y,z,c) = (T)_linear_atXY(cx + (x-cx)*ca + (y-cy)*sa,cy - (x-cx)*sa + (y-cy)*ca,z,c);
        } break;
        default : {
          cimg_forXY(res,x,y) cimg_forZC(*this,z,c)
            res(x,y,z,c) = _atXY((int)(cx + (x-cx)*ca + (y-cy)*sa),(int)(cy - (x-cx)*sa + (y-cy)*ca),z,c);
        }
        }
      } break;
      case 2 : {
        switch (interpolation) {
        case 2 : {
          cimg_forXY(res,x,y) cimg_forZC(*this,z,c) {
            const Tfloat val = _cubic_atXY(cimg::mod(cx + (x-cx)*ca + (y-cy)*sa,(float)width()),
                                           cimg::mod(cy - (x-cx)*sa + (y-cy)*ca,(float)height()),z,c);
            res(x,y,z,c) = (T)(val<vmin?vmin:val>vmax?vmax:val);
          }
        } break;
        case 1 : {
          cimg_forXY(res,x,y) cimg_forZC(*this,z,c)
            res(x,y,z,c) = (T)_linear_atXY(cimg::mod(cx + (x-cx)*ca + (y-cy)*sa,(float)width()),
                                           cimg::mod(cy - (x-cx)*sa + (y-cy)*ca,(float)height()),z,c);
        } break;
        default : {
          cimg_forXY(res,x,y) cimg_forZC(*this,z,c)
            res(x,y,z,c) = (*this)(cimg::mod((int)(cx + (x-cx)*ca + (y-cy)*sa),width()),
                                    cimg::mod((int)(cy - (x-cx)*sa + (y-cy)*ca),height()),z,c);
        }
        }
      } break;
      default :
        throw CImgArgumentException(_cimg_instance
                                    "rotate(): Invalid specified border conditions %d "
                                    "(should be { 0=dirichlet | 1=neumann | 2=cyclic }).",
                                    cimg_instance,
                                    boundary);
      }
      return res;
    }

    //! Warp image content by a warping field.
    /**
       \param warp Warping field.
       \param is_relative Tells if warping field gives absolute or relative warping coordinates.
       \param interpolation Can be <tt>{ 0=nearest | 1=linear | 2=cubic }</tt>.
       \param boundary_conditions Boundary conditions. Can be <tt>{ 0=dirichlet | 1=neumann | 2=cyclic }</tt>.
     **/
    template<typename t>
    CImg<T>& warp(const CImg<t>& warp, const bool is_relative=false,
                  const unsigned int interpolation=1, const unsigned int boundary_conditions=0) {
      return get_warp(warp,is_relative,interpolation,boundary_conditions).move_to(*this);
    }

    //! Warp image content by a warping field \newinstance
    template<typename t>
    CImg<T> get_warp(const CImg<t>& warp, const bool is_relative=false,
                     const unsigned int interpolation=1, const unsigned int boundary_conditions=0) const {
      if (is_empty() || !warp) return *this;
      if (is_relative && !is_sameXYZ(warp))
        throw CImgArgumentException(_cimg_instance
                                    "warp(): Instance and specified relative warping field (%u,%u,%u,%u,%p) "
                                    "have different XYZ dimensions.",
                                    cimg_instance,
                                    warp._width,warp._height,warp._depth,warp._spectrum,warp._data);

      CImg<T> res(warp._width,warp._height,warp._depth,_spectrum);
      T *ptrd = res._data;

      if (warp._spectrum==1) { // 1d warping.
        if (is_relative) { // Relative warp.
          if (interpolation==2) { // Cubic interpolation.
            if (boundary_conditions==2) // Cyclic boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp._data;
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_cubic_atX(cimg::mod(x - (float)*(ptrs0++),(float)_width),y,z,c);
              }
            else if (boundary_conditions==1) // Neumann boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp._data;
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_cubic_atX(x - (float)*(ptrs0++),y,z,c);
              }
            else // Dirichlet boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp._data;
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)cubic_atX(x - (float)*(ptrs0++),y,z,c,0);
              }
          } else if (interpolation==1) { // Linear interpolation.
            if (boundary_conditions==2) // Cyclic boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp._data;
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_linear_atX(cimg::mod(x - (float)*(ptrs0++),(float)_width),y,z,c);
              }
            else if (boundary_conditions==1) // Neumann boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp._data;
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_linear_atX(x - (float)*(ptrs0++),y,z,c);
              }
            else // Dirichlet boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp._data;
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)linear_atX(x - (float)*(ptrs0++),y,z,c,0);
              }
          } else { // Nearest-neighbor interpolation.
            if (boundary_conditions==2) // Cyclic boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp._data;
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (*this)(cimg::mod(x - (int)*(ptrs0++),(int)_width),y,z,c);
              }
            else if (boundary_conditions==1) // Neumann boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp._data;
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = _atX(x - (int)*(ptrs0++),y,z,c);
              }
            else // Dirichlet boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp._data;
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = atX(x - (int)*(ptrs0++),y,z,c,0);
              }
          }
        } else { // Absolute warp.
          if (interpolation==2) { // Cubic interpolation.
            if (boundary_conditions==2) // Cyclic boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp._data;
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_cubic_atX(cimg::mod((float)*(ptrs0++),(float)_width),0,0,c);
              }
            else if (boundary_conditions==1) // Neumann boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp._data;
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_cubic_atX((float)*(ptrs0++),0,0,c);
              }
            else // Dirichlet boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp._data;
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)cubic_atX((float)*(ptrs0++),0,0,c,0);
              }
          } else if (interpolation==1) { // Linear interpolation.
            if (boundary_conditions==2) // Cyclic boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp._data;
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_linear_atX(cimg::mod((float)*(ptrs0++),(float)_width),0,0,c);
              }
            else if (boundary_conditions==1) // Neumann boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp._data;
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_linear_atX((float)*(ptrs0++),0,0,c);
              }
            else // Dirichlet boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp._data;
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)linear_atX((float)*(ptrs0++),0,0,c,0);
              }
          } else { // Nearest-neighbor interpolation.
            if (boundary_conditions==2) // Cyclic boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp._data;
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (*this)(cimg::mod((int)*(ptrs0++),(int)_width),0,0,c);
              }
            else if (boundary_conditions==1) // Neumann boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp._data;
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = _atX((int)*(ptrs0++),0,0,c);
              }
            else // Dirichlet boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp._data;
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = atX((int)*(ptrs0++),0,0,c,0);
              }
          }
        }

      } else if (warp._spectrum==2) { // 2d warping.
        if (is_relative) { // Relative warp.
          if (interpolation==2) { // Cubic interpolation.
            if (boundary_conditions==2) // Cyclic boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_cubic_atXY(cimg::mod(x - (float)*(ptrs0++),(float)_width),
                                             cimg::mod(y - (float)*(ptrs1++),(float)_height),z,c);
              }
            else if (boundary_conditions==1) // Neumann boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_cubic_atXY(x - (float)*(ptrs0++),y - (float)*(ptrs1++),z,c);
              }
            else // Dirichlet boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)cubic_atXY(x - (float)*(ptrs0++),y - (float)*(ptrs1++),z,c,0);
              }
          } else if (interpolation==1) { // Linear interpolation.
            if (boundary_conditions==2) // Cyclic boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_linear_atXY(cimg::mod(x - (float)*(ptrs0++),(float)_width),
                                              cimg::mod(y - (float)*(ptrs1++),(float)_height),z,c);
              }
            else if (boundary_conditions==1) // Neumann boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_linear_atXY(x - (float)*(ptrs0++),y - (float)*(ptrs1++),z,c);
              }
            else // Dirichlet boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)linear_atXY(x - (float)*(ptrs0++),y - (float)*(ptrs1++),z,c,0);
              }
          } else { // Nearest-neighbor interpolation.
            if (boundary_conditions==2) // Cyclic boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (*this)(cimg::mod(x - (int)*(ptrs0++),(int)_width),
                                      cimg::mod(y - (int)*(ptrs1++),(int)_height),z,c);
              }
            else if (boundary_conditions==1) // Neumann boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = _atXY(x - (int)*(ptrs0++),y - (int)*(ptrs1++),z,c);
              }
            else // Dirichlet boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = atXY(x - (int)*(ptrs0++),y - (int)*(ptrs1++),z,c,0);
              }
          }
        } else { // Absolute warp.
          if (interpolation==2) { // Cubic interpolation.
            if (boundary_conditions==2) // Cyclic boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_cubic_atXY(cimg::mod((float)*(ptrs0++),(float)_width),
                                             cimg::mod((float)*(ptrs1++),(float)_height),0,c);
              }
            else if (boundary_conditions==1) // Neumann boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_cubic_atXY((float)*(ptrs0++),(float)*(ptrs1++),0,c);
              }
            else // Dirichlet boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)cubic_atXY((float)*(ptrs0++),(float)*(ptrs1++),0,c,0);
              }
          } else if (interpolation==1) { // Linear interpolation.
            if (boundary_conditions==2) // Cyclic boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_linear_atXY(cimg::mod((float)*(ptrs0++),(float)_width),
                                              cimg::mod((float)*(ptrs1++),(float)_height),0,c);
              }
            else if (boundary_conditions==1) // Neumann boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_linear_atXY((float)*(ptrs0++),(float)*(ptrs1++),0,c);
              }
            else // Dirichlet boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)linear_atXY((float)*(ptrs0++),(float)*(ptrs1++),0,c,0);
              }
          } else { // Nearest-neighbor interpolation.
            if (boundary_conditions==2) // Cyclic boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (*this)(cimg::mod((int)*(ptrs0++),(int)_width),
                                      cimg::mod((int)*(ptrs1++),(int)_height),0,c);
              }
            else if (boundary_conditions==1) // Neumann boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = _atXY((int)*(ptrs0++),(int)*(ptrs1++),0,c);
              }
            else // Dirichlet boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = atXY((int)*(ptrs0++),(int)*(ptrs1++),0,c,0);
              }
          }
        }

      } else if (warp._spectrum==3) { // 3d warping.
        if (is_relative) { // Relative warp.
          if (interpolation==2) { // Cubic interpolation.
            if (boundary_conditions==2) // Cyclic boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1), *ptrs2 = warp.data(0,0,0,2);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_cubic_atXYZ(cimg::mod(x - (float)*(ptrs0++),(float)_width),
                                              cimg::mod(y - (float)*(ptrs1++),(float)_height),
                                              cimg::mod(z - (float)*(ptrs2++),(float)_depth),c);
              }
            else if (boundary_conditions==1) // Neumann boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1), *ptrs2 = warp.data(0,0,0,2);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_cubic_atXYZ(x - (float)*(ptrs0++),y - (float)*(ptrs1++),z - (float)*(ptrs2++),c);
              }
            else // Dirichlet boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1), *ptrs2 = warp.data(0,0,0,2);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)cubic_atXYZ(x - (float)*(ptrs0++),y - (float)*(ptrs1++),z - (float)*(ptrs2++),c,0);
              }
          } else if (interpolation==1) { // Linear interpolation.
            if (boundary_conditions==2) // Cyclic boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1), *ptrs2 = warp.data(0,0,0,2);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_linear_atXYZ(cimg::mod(x - (float)*(ptrs0++),(float)_width),
                                               cimg::mod(y - (float)*(ptrs1++),(float)_height),
                                               cimg::mod(z - (float)*(ptrs2++),(float)_depth),c);
              }
            else if (boundary_conditions==1) // Neumann boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1), *ptrs2 = warp.data(0,0,0,2);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_linear_atXYZ(x - (float)*(ptrs0++),y - (float)*(ptrs1++),z - (float)*(ptrs2++),c);
              }
            else // Dirichlet boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1), *ptrs2 = warp.data(0,0,0,2);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)linear_atXYZ(x - (float)*(ptrs0++),y - (float)*(ptrs1++),z - (float)*(ptrs2++),c,0);
              }
          } else { // Nearest neighbor interpolation.
            if (boundary_conditions==2) // Cyclic boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1), *ptrs2 = warp.data(0,0,0,2);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (*this)(cimg::mod(x - (int)*(ptrs0++),(int)_width),
                                      cimg::mod(y - (int)*(ptrs1++),(int)_height),
                                      cimg::mod(z - (int)*(ptrs2++),(int)_depth),c);
              }
            else if (boundary_conditions==1) // Neumann boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1), *ptrs2 = warp.data(0,0,0,2);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = _atXYZ(x - (int)*(ptrs0++),y - (int)*(ptrs1++),z - (int)*(ptrs2++),c);
              }
            else // Dirichlet boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1), *ptrs2 = warp.data(0,0,0,2);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = atXYZ(x - (int)*(ptrs0++),y - (int)*(ptrs1++),z - (int)*(ptrs2++),c,0);
              }
          }
        } else { // Absolute warp.
          if (interpolation==2) { // Cubic interpolation.
            if (boundary_conditions==2) // Cyclic boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1), *ptrs2 = warp.data(0,0,0,2);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_cubic_atXYZ(cimg::mod((float)*(ptrs0++),(float)_width),
                                              cimg::mod((float)*(ptrs1++),(float)_height),
                                              cimg::mod((float)*(ptrs2++),(float)_depth),c);
              }
            else if (boundary_conditions==1) // Neumann boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1), *ptrs2 = warp.data(0,0,0,2);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_cubic_atXYZ((float)*(ptrs0++),(float)*(ptrs1++),(float)*(ptrs2++),c);
              }
            else // Dirichlet boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1), *ptrs2 = warp.data(0,0,0,2);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)cubic_atXYZ((float)*(ptrs0++),(float)*(ptrs1++),(float)*(ptrs2++),c,0);
              }
          } else if (interpolation==1) { // Linear interpolation.
            if (boundary_conditions==2) // Cyclic boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1), *ptrs2 = warp.data(0,0,0,2);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_linear_atXYZ(cimg::mod((float)*(ptrs0++),(float)_width),
                                               cimg::mod((float)*(ptrs1++),(float)_height),
                                               cimg::mod((float)*(ptrs2++),(float)_depth),c);
              }
            else if (boundary_conditions==1) // Neumann boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1), *ptrs2 = warp.data(0,0,0,2);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)_linear_atXYZ((float)*(ptrs0++),(float)*(ptrs1++),(float)*(ptrs2++),c);
              }
            else // Dirichlet boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1), *ptrs2 = warp.data(0,0,0,2);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (T)linear_atXYZ((float)*(ptrs0++),(float)*(ptrs1++),(float)*(ptrs2++),c,0);
              }
          } else { // Nearest-neighbor interpolation.
            if (boundary_conditions==2) // Cyclic boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1), *ptrs2 = warp.data(0,0,0,2);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = (*this)(cimg::mod((int)*(ptrs0++),(int)_width),
                                      cimg::mod((int)*(ptrs1++),(int)_height),
                                      cimg::mod((int)*(ptrs2++),(int)_depth),c);
              }
            else if (boundary_conditions==1) // Neumann boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1), *ptrs2 = warp.data(0,0,0,2);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = _atXYZ((int)*(ptrs0++),(int)*(ptrs1++),(int)*(ptrs2++),c);
              }
            else // Dirichlet boundaries.
              cimg_forC(res,c) {
                const t *ptrs0 = warp.data(0,0,0,0), *ptrs1 = warp.data(0,0,0,1), *ptrs2 = warp.data(0,0,0,2);
                cimg_forXYZ(res,x,y,z)
                  *(ptrd++) = atXYZ((int)*(ptrs0++),(int)*(ptrs1++),(int)*(ptrs2++),c,0);
              }
          }
        }
      }
      return res;
    }

    //! Generate a 2d representation of a 3d image, with XY,XZ and YZ views.
    /**
       \param x0 X-coordinate of the projection point.
       \param y0 Y-coordinate of the projection point.
       \param z0 Z-coordinate of the projection point.
    **/
    CImg<T> get_projections2d(const unsigned int x0, const unsigned int y0, const unsigned int z0) const {
      if (is_empty() || _depth<2) return +*this;
      const unsigned int
        _x0 = (x0>=_width)?_width - 1:x0,
        _y0 = (y0>=_height)?_height - 1:y0,
        _z0 = (z0>=_depth)?_depth - 1:z0;
      const CImg<T>
        img_xy = get_crop(0,0,_z0,0,_width-1,_height-1,_z0,_spectrum-1),
        img_zy = get_crop(_x0,0,0,0,_x0,_height-1,_depth-1,_spectrum-1).permute_axes("xzyc").resize(_depth,_height,1,-100,-1),
        img_xz = get_crop(0,_y0,0,0,_width-1,_y0,_depth-1,_spectrum-1).resize(_width,_depth,1,-100,-1);
      return CImg<T>(_width + _depth,_height + _depth,1,_spectrum,cimg::min(img_xy.min(),img_zy.min(),img_xz.min())).
        draw_image(0,0,img_xy).draw_image(img_xy._width,0,img_zy).
        draw_image(0,img_xy._height,img_xz);
    }

    //! Construct a 2d representation of a 3d image, with XY,XZ and YZ views \inplace.
    CImg<T>& projections2d(const unsigned int x0, const unsigned int y0, const unsigned int z0) {
      if (_depth<2) return *this;
      return get_projections2d(x0,y0,z0).move_to(*this);
    }

    //! Crop image region.
    /**
       \param x0 = X-coordinate of the upper-left crop rectangle corner.
       \param y0 = Y-coordinate of the upper-left crop rectangle corner.
       \param z0 = Z-coordinate of the upper-left crop rectangle corner.
       \param c0 = C-coordinate of the upper-left crop rectangle corner.
       \param x1 = X-coordinate of the lower-right crop rectangle corner.
       \param y1 = Y-coordinate of the lower-right crop rectangle corner.
       \param z1 = Z-coordinate of the lower-right crop rectangle corner.
       \param c1 = C-coordinate of the lower-right crop rectangle corner.
       \param boundary_conditions = Dirichlet (false) or Neumann border conditions.
    **/
    CImg<T>& crop(const int x0, const int y0, const int z0, const int c0,
                  const int x1, const int y1, const int z1, const int c1,
                  const bool boundary_conditions=false) {
      return get_crop(x0,y0,z0,c0,x1,y1,z1,c1,boundary_conditions).move_to(*this);
    }

    //! Crop image region \newinstance.
    CImg<T> get_crop(const int x0, const int y0, const int z0, const int c0,
                     const int x1, const int y1, const int z1, const int c1,
                     const bool boundary_conditions=false) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "crop(): Empty instance.",
                                    cimg_instance);
      const int
        nx0 = x0<x1?x0:x1, nx1 = x0^x1^nx0,
        ny0 = y0<y1?y0:y1, ny1 = y0^y1^ny0,
        nz0 = z0<z1?z0:z1, nz1 = z0^z1^nz0,
        nc0 = c0<c1?c0:c1, nc1 = c0^c1^nc0;
      CImg<T> res(1U + nx1 - nx0,1U + ny1 - ny0,1U + nz1 - nz0,1U + nc1 - nc0);
      if (nx0<0 || nx1>=width() || ny0<0 || ny1>=height() || nz0<0 || nz1>=depth() || nc0<0 || nc1>=spectrum()) {
        if (boundary_conditions) cimg_forXYZC(res,x,y,z,c) res(x,y,z,c) = _atXYZC(nx0+x,ny0+y,nz0+z,nc0+c);
        else res.fill(0).draw_image(-nx0,-ny0,-nz0,-nc0,*this);
      } else res.draw_image(-nx0,-ny0,-nz0,-nc0,*this);
      return res;
    }

    //! Crop image region \overloading.
    CImg<T>& crop(const int x0, const int y0, const int z0,
                  const int x1, const int y1, const int z1,
                  const bool boundary_conditions=false) {
      return crop(x0,y0,z0,0,x1,y1,z1,_spectrum-1,boundary_conditions);
    }

    //! Crop image region \newinstance.
    CImg<T> get_crop(const int x0, const int y0, const int z0,
                     const int x1, const int y1, const int z1,
                     const bool boundary_conditions=false) const {
      return get_crop(x0,y0,z0,0,x1,y1,z1,_spectrum-1,boundary_conditions);
    }

    //! Crop image region \overloading.
    CImg<T>& crop(const int x0, const int y0,
                  const int x1, const int y1,
                  const bool boundary_conditions=false) {
      return crop(x0,y0,0,0,x1,y1,_depth - 1,_spectrum - 1,boundary_conditions);
    }

    //! Crop image region \newinstance.
    CImg<T> get_crop(const int x0, const int y0,
                     const int x1, const int y1,
                     const bool boundary_conditions=false) const {
      return get_crop(x0,y0,0,0,x1,y1,_depth - 1,_spectrum - 1,boundary_conditions);
    }

    //! Crop image region \overloading.
    CImg<T>& crop(const int x0, const int x1, const bool boundary_conditions=false) {
      return crop(x0,0,0,0,x1,_height-1,_depth-1,_spectrum-1,boundary_conditions);
    }

    //! Crop image region \newinstance.
    CImg<T> get_crop(const int x0, const int x1, const bool boundary_conditions=false) const {
      return get_crop(x0,0,0,0,x1,_height-1,_depth-1,_spectrum-1,boundary_conditions);
    }

    //! Autocrop image region, regarding the specified background value.
    CImg<T>& autocrop(const T value, const char *const axes="czyx") {
      if (is_empty()) return *this;
      for (const char *s = axes; *s; ++s) {
        const char axis = cimg::uncase(*s);
        const CImg<intT> coords = _autocrop(value,axis);
        if (coords[0]==-1 && coords[1]==-1) return assign(); // Image has only 'value' pixels.
        else switch (axis) {
        case 'x' : {
	  const int x0 = coords[0], x1 = coords[1];
	  if (x0>=0 && x1>=0) crop(x0,x1);
	} break;
        case 'y' : {
	  const int y0 = coords[0], y1 = coords[1];
	  if (y0>=0 && y1>=0) crop(0,y0,_width-1,y1);
	} break;
        case 'z' : {
	  const int z0 = coords[0], z1 = coords[1];
	  if (z0>=0 && z1>=0) crop(0,0,z0,_width-1,_height-1,z1);
	} break;
        default : {
	  const int c0 = coords[0], c1 = coords[1];
	  if (c0>=0 && c1>=0) crop(0,0,0,c0,_width-1,_height-1,_depth-1,c1);
	}
        }
      }
      return *this;
    }

    //! Autocrop image region, regarding the specified background value \newinstance.
    CImg<T> get_autocrop(const T value, const char *const axes="czyx") const {
      return (+*this).autocrop(value,axes);
    }

    //! Autocrop image region, regarding the specified background color.
    /**
       \param color Color used for the crop. If \c 0, color is guessed.
       \param axes Axes used for the crop.
    **/
    CImg<T>& autocrop(const T *const color=0, const char *const axes="zyx") {
      if (is_empty()) return *this;
      if (!color) { // Guess color.
        const CImg<T> col1 = get_vector_at(0,0,0);
        const unsigned int w = _width, h = _height, d = _depth, s = _spectrum;
        autocrop(col1,axes);
        if (_width==w && _height==h && _depth==d && _spectrum==s) {
          const CImg<T> col2 = get_vector_at(w-1,h-1,d-1);
          autocrop(col2,axes);
        }
        return *this;
      }
      for (const char *s = axes; *s; ++s) {
        const char axis = cimg::uncase(*s);
        switch (axis) {
        case 'x' : {
	  int x0 = width(), x1 = -1;
	  cimg_forC(*this,c) {
	    const CImg<intT> coords = get_shared_channel(c)._autocrop(color[c],'x');
	    const int nx0 = coords[0], nx1 = coords[1];
	    if (nx0>=0 && nx1>=0) { x0 = cimg::min(x0,nx0); x1 = cimg::max(x1,nx1); }
	  }
          if (x0==width() && x1==-1) return assign(); else crop(x0,x1);
	} break;
        case 'y' : {
	  int y0 = height(), y1 = -1;
	  cimg_forC(*this,c) {
	    const CImg<intT> coords = get_shared_channel(c)._autocrop(color[c],'y');
	    const int ny0 = coords[0], ny1 = coords[1];
	    if (ny0>=0 && ny1>=0) { y0 = cimg::min(y0,ny0); y1 = cimg::max(y1,ny1); }
	  }
          if (y0==height() && y1==-1) return assign(); else crop(0,y0,_width-1,y1);
	} break;
        default : {
	  int z0 = depth(), z1 = -1;
	  cimg_forC(*this,c) {
	    const CImg<intT> coords = get_shared_channel(c)._autocrop(color[c],'z');
	    const int nz0 = coords[0], nz1 = coords[1];
	    if (nz0>=0 && nz1>=0) { z0 = cimg::min(z0,nz0); z1 = cimg::max(z1,nz1); }
	  }
	  if (z0==depth() && z1==-1) return assign(); else crop(0,0,z0,_width-1,_height-1,z1);
	}
        }
      }
      return *this;
    }

    //! Autocrop image region, regarding the specified background color \newinstance.
    CImg<T> get_autocrop(const T *const color=0, const char *const axes="zyx") const {
      return (+*this).autocrop(color,axes);
    }

    //! Autocrop image region, regarding the specified background color \overloading.
    template<typename t> CImg<T>& autocrop(const CImg<t>& color, const char *const axes="zyx") {
      return get_autocrop(color,axes).move_to(*this);
    }

    //! Autocrop image region, regarding the specified background color \newinstance.
    template<typename t> CImg<T> get_autocrop(const CImg<t>& color, const char *const axes="zyx") const {
      return get_autocrop(color._data,axes);
    }

    CImg<intT> _autocrop(const T value, const char axis) const {
      CImg<intT> res;
      switch (cimg::uncase(axis)) {
      case 'x' : {
        int x0 = -1, x1 = -1;
        cimg_forX(*this,x) cimg_forYZC(*this,y,z,c)
          if ((*this)(x,y,z,c)!=value) { x0 = x; x = width(); y = height(); z = depth(); c = spectrum(); }
	if (x0>=0) {
          for (int x = width()-1; x>=0; --x) cimg_forYZC(*this,y,z,c)
            if ((*this)(x,y,z,c)!=value) { x1 = x; x = 0; y = height(); z = depth(); c = spectrum(); }
        }
	res = CImg<intT>::vector(x0,x1);
      } break;
      case 'y' : {
        int y0 = -1, y1 = -1;
        cimg_forY(*this,y) cimg_forXZC(*this,x,z,c)
          if ((*this)(x,y,z,c)!=value) { y0 = y; x = width(); y = height(); z = depth(); c = spectrum(); }
	if (y0>=0) {
          for (int y = height()-1; y>=0; --y) cimg_forXZC(*this,x,z,c)
            if ((*this)(x,y,z,c)!=value) { y1 = y; x = width(); y = 0; z = depth(); c = spectrum(); }
        }
  	res = CImg<intT>::vector(y0,y1);
      } break;
      case 'z' : {
        int z0 = -1, z1 = -1;
        cimg_forZ(*this,z) cimg_forXYC(*this,x,y,c)
          if ((*this)(x,y,z,c)!=value) { z0 = z; x = width(); y = height(); z = depth(); c = spectrum(); }
	if (z0>=0) {
          for (int z = depth()-1; z>=0; --z) cimg_forXYC(*this,x,y,c)
            if ((*this)(x,y,z,c)!=value) { z1 = z; x = width(); y = height(); z = 0; c = spectrum(); }
        }
  	res = CImg<intT>::vector(z0,z1);
      } break;
      default : {
        int c0 = -1, c1 = -1;
        cimg_forC(*this,c) cimg_forXYZ(*this,x,y,z)
          if ((*this)(x,y,z,c)!=value) { c0 = c; x = width(); y = height(); z = depth(); c = spectrum(); }
	if (c0>=0) {
          for (int c = spectrum()-1; c>=0; --c) cimg_forXYZ(*this,x,y,z)
            if ((*this)(x,y,z,c)!=value) { c1 = c; x = width(); y = height(); z = depth(); c = 0; }
        }
  	res = CImg<intT>::vector(c0,c1);
      }
      }
      return res;
    }

    //! Return specified image column.
    /**
       \param x0 Image column.
    **/
    CImg<T> get_column(const int x0) const {
      return get_columns(x0,x0);
    }

    //! Return specified image column \inplace.
    CImg<T>& column(const int x0) {
      return columns(x0,x0);
    }

    //! Return specified range of image columns.
    /**
       \param x0 Starting image column.
       \param x1 Ending image column.
    **/
    CImg<T>& columns(const int x0, const int x1) {
      return get_columns(x0,x1).move_to(*this);
    }

    //! Return specified range of image columns \inplace.
    CImg<T> get_columns(const int x0, const int x1) const {
      return get_crop(x0,0,0,0,x1,height()-1,depth()-1,spectrum()-1);
    }

    //! Return specified image row.
    CImg<T> get_row(const int y0) const {
      return get_rows(y0,y0);
    }

    //! Return specified image row \inplace.
    /**
       \param y0 Image row.
    **/
    CImg<T>& row(const int y0) {
      return rows(y0,y0);
    }

    //! Return specified range of image rows.
    /**
       \param y0 Starting image row.
       \param y1 Ending image row.
    **/
    CImg<T> get_rows(const int y0, const int y1) const {
      return get_crop(0,y0,0,0,width()-1,y1,depth()-1,spectrum()-1);
    }

    //! Return specified range of image rows \inplace.
    CImg<T>& rows(const int y0, const int y1) {
      return get_rows(y0,y1).move_to(*this);
    }

    //! Return specified image slice.
    /**
       \param z0 Image slice.
    **/
    CImg<T> get_slice(const int z0) const {
      return get_slices(z0,z0);
    }

    //! Return specified image slice \inplace.
    CImg<T>& slice(const int z0) {
      return slices(z0,z0);
    }

    //! Return specified range of image slices.
    /**
       \param z0 Starting image slice.
       \param z1 Ending image slice.
    **/
    CImg<T> get_slices(const int z0, const int z1) const {
      return get_crop(0,0,z0,0,width()-1,height()-1,z1,spectrum()-1);
    }

    //! Return specified range of image slices \inplace.
    CImg<T>& slices(const int z0, const int z1) {
      return get_slices(z0,z1).move_to(*this);
    }

    //! Return specified image channel.
    /**
       \param c0 Image channel.
    **/
    CImg<T> get_channel(const int c0) const {
      return get_channels(c0,c0);
    }

    //! Return specified image channel \inplace.
    CImg<T>& channel(const int c0) {
      return channels(c0,c0);
    }

    //! Return specified range of image channels.
    /**
       \param c0 Starting image channel.
       \param c1 Ending image channel.
    **/
    CImg<T> get_channels(const int c0, const int c1) const {
      return get_crop(0,0,0,c0,width()-1,height()-1,depth()-1,c1);
    }

    //! Return specified range of image channels \inplace.
    CImg<T>& channels(const int c0, const int c1) {
      return get_channels(c0,c1).move_to(*this);
    }

    //! Return stream line of a 2d or 3d vector field.
    CImg<floatT> get_streamline(const float x, const float y, const float z,
                                const float L=256, const float dl=0.1f,
                                const unsigned int interpolation_type=2, const bool is_backward_tracking=false,
                                const bool is_oriented_only=false) const {
      if (_spectrum!=2 && _spectrum!=3)
        throw CImgInstanceException(_cimg_instance
                                    "streamline(): Instance is not a 2d or 3d vector field.",
                                    cimg_instance);
      if (_spectrum==2) {
        if (is_oriented_only) {
          typename CImg<T>::_functor4d_streamline2d_oriented func(*this);
          return streamline(func,x,y,z,L,dl,interpolation_type,is_backward_tracking,true,0,0,0,_width-1.0f,_height-1.0f,0.0f);
        } else {
          typename CImg<T>::_functor4d_streamline2d_directed func(*this);
          return streamline(func,x,y,z,L,dl,interpolation_type,is_backward_tracking,false,0,0,0,_width-1.0f,_height-1.0f,0.0f);
        }
      }
      if (is_oriented_only) {
        typename CImg<T>::_functor4d_streamline3d_oriented func(*this);
        return streamline(func,x,y,z,L,dl,interpolation_type,is_backward_tracking,true,0,0,0,_width-1.0f,_height-1.0f,_depth-1.0f);
      }
      typename CImg<T>::_functor4d_streamline3d_directed func(*this);
      return streamline(func,x,y,z,L,dl,interpolation_type,is_backward_tracking,false,0,0,0,_width-1.0f,_height-1.0f,_depth-1.0f);
    }

    //! Return stream line of a 3d vector field.
    /**
       \param func Vector field function.
       \param x X-coordinate of the starting point of the streamline.
       \param y Y-coordinate of the starting point of the streamline.
       \param z Z-coordinate of the starting point of the streamline.
       \param L Streamline length.
       \param dl Streamline length increment.
       \param interpolation_type Type of interpolation. Can be <tt>{ 0=nearest int | 1=linear | 2=2nd-order RK | 3=4th-order RK. }</tt>.
       \param is_backward_tracking Tells if the streamline is estimated forward or backward.
       \param is_oriented_only Tells if the direction of the vectors must be ignored.
       \param x0 X-coordinate of the first bounding-box vertex.
       \param y0 Y-coordinate of the first bounding-box vertex.
       \param z0 Z-coordinate of the first bounding-box vertex.
       \param x1 X-coordinate of the second bounding-box vertex.
       \param y1 Y-coordinate of the second bounding-box vertex.
       \param z1 Z-coordinate of the second bounding-box vertex.
    **/
    template<typename tfunc>
    static CImg<floatT> streamline(const tfunc& func,
                                   const float x, const float y, const float z,
                                   const float L=256, const float dl=0.1f,
                                   const unsigned int interpolation_type=2, const bool is_backward_tracking=false,
                                   const bool is_oriented_only=false,
                                   const float x0=0, const float y0=0, const float z0=0,
                                   const float x1=0, const float y1=0, const float z1=0) {
      if (dl<=0)
        throw CImgArgumentException("CImg<%s>::streamline(): Invalid specified integration length %g "
                                    "(should be >0).",
                                    pixel_type(),
                                    dl);

      const bool is_bounded = (x0!=x1 || y0!=y1 || z0!=z1);
      if (L<=0 || (is_bounded && (x<x0 || x>x1 || y<y0 || y>y1 || z<z0 || z>z1))) return CImg<floatT>();
      const unsigned int size_L = (unsigned int)cimg::round(L/dl+1);
      CImg<floatT> coordinates(size_L,3);
      const float dl2 = dl/2;
      float
        *ptr_x = coordinates.data(0,0),
        *ptr_y = coordinates.data(0,1),
        *ptr_z = coordinates.data(0,2),
        pu = (float)(dl*func(x,y,z,0)),
        pv = (float)(dl*func(x,y,z,1)),
        pw = (float)(dl*func(x,y,z,2)),
        X = x, Y = y, Z = z;

      switch (interpolation_type) {
      case 0 : { // Nearest integer interpolation.
        cimg_forX(coordinates,l) {
          *(ptr_x++) = X; *(ptr_y++) = Y; *(ptr_z++) = Z;
          const int
            xi = (int)(X>0?X+0.5f:X-0.5f),
            yi = (int)(Y>0?Y+0.5f:Y-0.5f),
            zi = (int)(Z>0?Z+0.5f:Z-0.5f);
          float
            u = (float)(dl*func((float)xi,(float)yi,(float)zi,0)),
            v = (float)(dl*func((float)xi,(float)yi,(float)zi,1)),
            w = (float)(dl*func((float)xi,(float)yi,(float)zi,2));
          if (is_oriented_only && u*pu + v*pv + w*pw<0) { u = -u; v = -v; w = -w; }
          if (is_backward_tracking) { X-=(pu=u); Y-=(pv=v); Z-=(pw=w); } else { X+=(pu=u); Y+=(pv=v); Z+=(pw=w); }
          if (is_bounded && (X<x0 || X>x1 || Y<y0 || Y>y1 || Z<z0 || Z>z1)) break;
        }
      } break;
      case 1 : { // First-order interpolation.
        cimg_forX(coordinates,l) {
          *(ptr_x++) = X; *(ptr_y++) = Y; *(ptr_z++) = Z;
          float
            u = (float)(dl*func(X,Y,Z,0)),
            v = (float)(dl*func(X,Y,Z,1)),
            w = (float)(dl*func(X,Y,Z,2));
          if (is_oriented_only && u*pu + v*pv + w*pw<0) { u = -u; v = -v; w = -w; }
          if (is_backward_tracking) { X-=(pu=u); Y-=(pv=v); Z-=(pw=w); } else { X+=(pu=u); Y+=(pv=v); Z+=(pw=w); }
          if (is_bounded && (X<x0 || X>x1 || Y<y0 || Y>y1 || Z<z0 || Z>z1)) break;
        }
      } break;
      case 2 : { // Second order interpolation.
        cimg_forX(coordinates,l) {
          *(ptr_x++) = X; *(ptr_y++) = Y; *(ptr_z++) = Z;
          float
            u0 = (float)(dl2*func(X,Y,Z,0)),
            v0 = (float)(dl2*func(X,Y,Z,1)),
            w0 = (float)(dl2*func(X,Y,Z,2));
          if (is_oriented_only && u0*pu + v0*pv + w0*pw<0) { u0 = -u0; v0 = -v0; w0 = -w0; }
          float
            u = (float)(dl*func(X+u0,Y+v0,Z+w0,0)),
            v = (float)(dl*func(X+u0,Y+v0,Z+w0,1)),
            w = (float)(dl*func(X+u0,Y+v0,Z+w0,2));
          if (is_oriented_only && u*pu + v*pv + w*pw<0) { u = -u; v = -v; w = -w; }
          if (is_backward_tracking) { X-=(pu=u); Y-=(pv=v); Z-=(pw=w); } else { X+=(pu=u); Y+=(pv=v); Z+=(pw=w); }
          if (is_bounded && (X<x0 || X>x1 || Y<y0 || Y>y1 || Z<z0 || Z>z1)) break;
        }
      } break;
      default : { // Fourth order interpolation.
        cimg_forX(coordinates,x) {
          *(ptr_x++) = X; *(ptr_y++) = Y; *(ptr_z++) = Z;
          float
            u0 = (float)(dl2*func(X,Y,Z,0)),
            v0 = (float)(dl2*func(X,Y,Z,1)),
            w0 = (float)(dl2*func(X,Y,Z,2));
          if (is_oriented_only && u0*pu + v0*pv + w0*pw<0) { u0 = -u0; v0 = -v0; w0 = -w0; }
          float
            u1 = (float)(dl2*func(X+u0,Y+v0,Z+w0,0)),
            v1 = (float)(dl2*func(X+u0,Y+v0,Z+w0,1)),
            w1 = (float)(dl2*func(X+u0,Y+v0,Z+w0,2));
          if (is_oriented_only && u1*pu + v1*pv + w1*pw<0) { u1 = -u1; v1 = -v1; w1 = -w1; }
          float
            u2 = (float)(dl2*func(X+u1,Y+v1,Z+w1,0)),
            v2 = (float)(dl2*func(X+u1,Y+v1,Z+w1,1)),
            w2 = (float)(dl2*func(X+u1,Y+v1,Z+w1,2));
          if (is_oriented_only && u2*pu + v2*pv + w2*pw<0) { u2 = -u2; v2 = -v2; w2 = -w2; }
          float
            u3 = (float)(dl2*func(X+u2,Y+v2,Z+w2,0)),
            v3 = (float)(dl2*func(X+u2,Y+v2,Z+w2,1)),
            w3 = (float)(dl2*func(X+u2,Y+v2,Z+w2,2));
          if (is_oriented_only && u2*pu + v2*pv + w2*pw<0) { u3 = -u3; v3 = -v3; w3 = -w3; }
          const float
            u = (u0 + u3)/3 + (u1 + u2)/1.5f,
            v = (v0 + v3)/3 + (v1 + v2)/1.5f,
            w = (w0 + w3)/3 + (w1 + w2)/1.5f;
          if (is_backward_tracking) { X-=(pu=u); Y-=(pv=v); Z-=(pw=w); } else { X+=(pu=u); Y+=(pv=v); Z+=(pw=w); }
          if (is_bounded && (X<x0 || X>x1 || Y<y0 || Y>y1 || Z<z0 || Z>z1)) break;
        }
      }
      }
      if (ptr_x!=coordinates.data(0,1)) coordinates.resize((int)(ptr_x-coordinates.data()),3,1,1,0);
      return coordinates;
    }

    //! Return stream line of a 3d vector field \overloading.
    static CImg<floatT> streamline(const char *const expression,
                                   const float x, const float y, const float z,
                                   const float L=256, const float dl=0.1f,
                                   const unsigned int interpolation_type=2, const bool is_backward_tracking=true,
                                   const bool is_oriented_only=false,
                                   const float x0=0, const float y0=0, const float z0=0,
                                   const float x1=0, const float y1=0, const float z1=0) {
      _functor4d_streamline_expr func(expression);
      return streamline(func,x,y,z,L,dl,interpolation_type,is_backward_tracking,is_oriented_only,x0,y0,z0,x1,y1,z1);
    }

    struct _functor4d_streamline2d_directed {
      const CImg<T>& ref;
      _functor4d_streamline2d_directed(const CImg<T>& pref):ref(pref) {}
      float operator()(const float x, const float y, const float z, const unsigned int c) const {
        return c<2?(float)ref._linear_atXY(x,y,(int)z,c):0;
      }
    };

    struct _functor4d_streamline3d_directed {
      const CImg<T>& ref;
      _functor4d_streamline3d_directed(const CImg<T>& pref):ref(pref) {}
      float operator()(const float x, const float y, const float z, const unsigned int c) const {
        return (float)ref._linear_atXYZ(x,y,z,c);
      }
    };

    struct _functor4d_streamline2d_oriented {
      const CImg<T>& ref;
      CImg<floatT> *pI;
      _functor4d_streamline2d_oriented(const CImg<T>& pref):ref(pref),pI(0) { pI = new CImg<floatT>(2,2,1,2); }
      ~_functor4d_streamline2d_oriented() { delete pI; }
      float operator()(const float x, const float y, const float z, const unsigned int c) const {
#define _cimg_vecalign2d(i,j) if (I(i,j,0)*I(0,0,0)+I(i,j,1)*I(0,0,1)<0) { I(i,j,0) = -I(i,j,0); I(i,j,1) = -I(i,j,1); }
        int
          xi = (int)x - (x>=0?0:1), nxi = xi + 1,
          yi = (int)y - (y>=0?0:1), nyi = yi + 1,
          zi = (int)z;
        const float
          dx = x - xi,
          dy = y - yi;
        if (c==0) {
          CImg<floatT>& I = *pI;
          if (xi<0) xi = 0; if (nxi<0) nxi = 0;
          if (xi>=ref.width()) xi = ref.width()-1; if (nxi>=ref.width()) nxi = ref.width()-1;
          if (yi<0) yi = 0; if (nyi<0) nyi = 0;
          if (yi>=ref.height()) yi = ref.height()-1; if (nyi>=ref.height()) nyi = ref.height()-1;
          I(0,0,0) = (float)ref(xi,yi,zi,0);   I(0,0,1) = (float)ref(xi,yi,zi,1);
          I(1,0,0) = (float)ref(nxi,yi,zi,0);  I(1,0,1) = (float)ref(nxi,yi,zi,1);
          I(1,1,0) = (float)ref(nxi,nyi,zi,0); I(1,1,1) = (float)ref(nxi,nyi,zi,1);
          I(0,1,0) = (float)ref(xi,nyi,zi,0);  I(0,1,1) = (float)ref(xi,nyi,zi,1);
          _cimg_vecalign2d(1,0); _cimg_vecalign2d(1,1); _cimg_vecalign2d(0,1);
        }
        return c<2?(float)pI->_linear_atXY(dx,dy,0,c):0;
      }
    };

    struct _functor4d_streamline3d_oriented {
      const CImg<T>& ref;
      CImg<floatT> *pI;
      _functor4d_streamline3d_oriented(const CImg<T>& pref):ref(pref),pI(0) { pI = new CImg<floatT>(2,2,2,3); }
      ~_functor4d_streamline3d_oriented() { delete pI; }
      float operator()(const float x, const float y, const float z, const unsigned int c) const {
#define _cimg_vecalign3d(i,j,k) if (I(i,j,k,0)*I(0,0,0,0)+I(i,j,k,1)*I(0,0,0,1)+I(i,j,k,2)*I(0,0,0,2)<0) { \
  I(i,j,k,0) = -I(i,j,k,0); I(i,j,k,1) = -I(i,j,k,1); I(i,j,k,2) = -I(i,j,k,2); }
        int
          xi = (int)x - (x>=0?0:1), nxi = xi + 1,
          yi = (int)y - (y>=0?0:1), nyi = yi + 1,
          zi = (int)z - (z>=0?0:1), nzi = zi + 1;
        const float
          dx = x - xi,
          dy = y - yi,
          dz = z - zi;
        if (c==0) {
          CImg<floatT>& I = *pI;
          if (xi<0) xi = 0; if (nxi<0) nxi = 0;
          if (xi>=ref.width()) xi = ref.width()-1; if (nxi>=ref.width()) nxi = ref.width()-1;
          if (yi<0) yi = 0; if (nyi<0) nyi = 0;
          if (yi>=ref.height()) yi = ref.height()-1; if (nyi>=ref.height()) nyi = ref.height()-1;
          if (zi<0) zi = 0; if (nzi<0) nzi = 0;
          if (zi>=ref.depth()) zi = ref.depth()-1; if (nzi>=ref.depth()) nzi = ref.depth()-1;
          I(0,0,0,0) = (float)ref(xi,yi,zi,0);   I(0,0,0,1) = (float)ref(xi,yi,zi,1);   I(0,0,0,2) = (float)ref(xi,yi,zi,2);
          I(1,0,0,0) = (float)ref(nxi,yi,zi,0);  I(1,0,0,1) = (float)ref(nxi,yi,zi,1);  I(1,0,0,2) = (float)ref(nxi,yi,zi,2);
          I(1,1,0,0) = (float)ref(nxi,nyi,zi,0); I(1,1,0,1) = (float)ref(nxi,nyi,zi,1); I(1,1,0,2) = (float)ref(nxi,nyi,zi,2);
          I(0,1,0,0) = (float)ref(xi,nyi,zi,0);  I(0,1,0,1) = (float)ref(xi,nyi,zi,1);  I(0,1,0,2) = (float)ref(xi,nyi,zi,2);
          I(0,0,1,0) = (float)ref(xi,yi,nzi,0);   I(0,0,1,1) = (float)ref(xi,yi,nzi,1);   I(0,0,1,2) = (float)ref(xi,yi,nzi,2);
          I(1,0,1,0) = (float)ref(nxi,yi,nzi,0);  I(1,0,1,1) = (float)ref(nxi,yi,nzi,1);  I(1,0,1,2) = (float)ref(nxi,yi,nzi,2);
          I(1,1,1,0) = (float)ref(nxi,nyi,nzi,0); I(1,1,1,1) = (float)ref(nxi,nyi,nzi,1); I(1,1,1,2) = (float)ref(nxi,nyi,nzi,2);
          I(0,1,1,0) = (float)ref(xi,nyi,nzi,0);  I(0,1,1,1) = (float)ref(xi,nyi,nzi,1);  I(0,1,1,2) = (float)ref(xi,nyi,nzi,2);
          _cimg_vecalign3d(1,0,0); _cimg_vecalign3d(1,1,0); _cimg_vecalign3d(0,1,0);
          _cimg_vecalign3d(0,0,1); _cimg_vecalign3d(1,0,1); _cimg_vecalign3d(1,1,1); _cimg_vecalign3d(0,1,1);
        }
        return (float)pI->_linear_atXYZ(dx,dy,dz,c);
      }
    };

    struct _functor4d_streamline_expr {
      _cimg_math_parser *mp;
      ~_functor4d_streamline_expr() { delete mp; }
      _functor4d_streamline_expr(const char *const expr):mp(0) { mp = new _cimg_math_parser(CImg<T>::empty(),expr,"streamline"); }
      float operator()(const float x, const float y, const float z, const unsigned int c) const {
        return (float)mp->eval(x,y,z,c);
      }
    };

    //! Return a shared-memory image referencing a range of pixels of the image instance.
    /**
       \param x0 X-coordinate of the starting pixel.
       \param x1 X-coordinate of the ending pixel.
       \param y0 Y-coordinate.
       \param z0 Z-coordinate.
       \param c0 C-coordinate.
     **/
    CImg<T> get_shared_points(const unsigned int x0, const unsigned int x1,
                              const unsigned int y0=0, const unsigned int z0=0, const unsigned int c0=0) {
      const unsigned int beg = (unsigned int)offset(x0,y0,z0,c0), end = offset(x1,y0,z0,c0);
      if (beg>end || beg>=size() || end>=size())
        throw CImgArgumentException(_cimg_instance
                                    "get_shared_points(): Invalid request of a shared-memory subset (%u->%u,%u,%u,%u).",
                                    cimg_instance,
                                    x0,x1,y0,z0,c0);

      return CImg<T>(_data+beg,x1-x0+1,1,1,1,true);
    }

    //! Return a shared-memory image referencing a range of pixels of the image instance \const.
    const CImg<T> get_shared_points(const unsigned int x0, const unsigned int x1,
                                    const unsigned int y0=0, const unsigned int z0=0, const unsigned int c0=0) const {
      const unsigned int beg = (unsigned int)offset(x0,y0,z0,c0), end = offset(x1,y0,z0,c0);
      if (beg>end || beg>=size() || end>=size())
        throw CImgArgumentException(_cimg_instance
                                    "get_shared_points(): Invalid request of a shared-memory subset (%u->%u,%u,%u,%u).",
                                    cimg_instance,
                                    x0,x1,y0,z0,c0);

      return CImg<T>(_data+beg,x1-x0+1,1,1,1,true);
    }

    //! Return a shared-memory image referencing a range of rows of the image instance.
    /**
       \param y0 Y-coordinate of the starting row.
       \param y1 Y-coordinate of the ending row.
       \param z0 Z-coordinate.
       \param c0 C-coordinate.
    **/
    CImg<T> get_shared_rows(const unsigned int y0, const unsigned int y1,
                             const unsigned int z0=0, const unsigned int c0=0) {
      const unsigned int beg = offset(0,y0,z0,c0), end = offset(0,y1,z0,c0);
      if (beg>end || beg>=size() || end>=size())
        throw CImgArgumentException(_cimg_instance
                                    "get_shared_rows(): Invalid request of a shared-memory subset (0->%u,%u->%u,%u,%u).",
                                    cimg_instance,
                                    _width-1,y0,y1,z0,c0);

      return CImg<T>(_data+beg,_width,y1-y0+1,1,1,true);
    }

    //! Return a shared-memory image referencing a range of rows of the image instance \const.
    const CImg<T> get_shared_rows(const unsigned int y0, const unsigned int y1,
                                   const unsigned int z0=0, const unsigned int c0=0) const {
      const unsigned int beg = offset(0,y0,z0,c0), end = offset(0,y1,z0,c0);
      if (beg>end || beg>=size() || end>=size())
        throw CImgArgumentException(_cimg_instance
                                    "get_shared_rows(): Invalid request of a shared-memory subset (0->%u,%u->%u,%u,%u).",
                                    cimg_instance,
                                    _width-1,y0,y1,z0,c0);

      return CImg<T>(_data+beg,_width,y1-y0+1,1,1,true);
    }

    //! Return a shared-memory image referencing one row of the image instance.
    /**
       \param y0 Y-coordinate.
       \param z0 Z-coordinate.
       \param c0 C-coordinate.
    **/
    CImg<T> get_shared_row(const unsigned int y0, const unsigned int z0=0, const unsigned int c0=0) {
      return get_shared_rows(y0,y0,z0,c0);
    }

    //! Return a shared-memory image referencing one row of the image instance \const.
    const CImg<T> get_shared_row(const unsigned int y0, const unsigned int z0=0, const unsigned int c0=0) const {
      return get_shared_rows(y0,y0,z0,c0);
    }

    //! Return a shared memory image referencing a range of slices of the image instance.
    /**
       \param z0 Z-coordinate of the starting slice.
       \param z1 Z-coordinate of the ending slice.
       \param c0 C-coordinate.
    **/
    CImg<T> get_shared_slices(const unsigned int z0, const unsigned int z1, const unsigned int c0=0) {
      const unsigned int beg = offset(0,0,z0,c0), end = offset(0,0,z1,c0);
      if (beg>end || beg>=size() || end>=size())
        throw CImgArgumentException(_cimg_instance
                                    "get_shared_slices(): Invalid request of a shared-memory subset (0->%u,0->%u,%u->%u,%u).",
                                    cimg_instance,
                                    _width-1,_height-1,z0,z1,c0);

      return CImg<T>(_data+beg,_width,_height,z1-z0+1,1,true);
    }

    //! Return a shared memory image referencing a range of slices of the image instance \const.
    const CImg<T> get_shared_slices(const unsigned int z0, const unsigned int z1, const unsigned int c0=0) const {
      const unsigned int beg = offset(0,0,z0,c0), end = offset(0,0,z1,c0);
      if (beg>end || beg>=size() || end>=size())
        throw CImgArgumentException(_cimg_instance
                                    "get_shared_slices(): Invalid request of a shared-memory subset (0->%u,0->%u,%u->%u,%u).",
                                    cimg_instance,
                                    _width-1,_height-1,z0,z1,c0);

      return CImg<T>(_data+beg,_width,_height,z1-z0+1,1,true);
    }

    //! Return a shared-memory image referencing one slice of the image instance.
    /**
       \param z0 Z-coordinate.
       \param c0 C-coordinate.
    **/
    CImg<T> get_shared_slice(const unsigned int z0, const unsigned int c0=0) {
      return get_shared_slices(z0,z0,c0);
    }

    //! Return a shared-memory image referencing one slice of the image instance \const.
    const CImg<T> get_shared_slice(const unsigned int z0, const unsigned int c0=0) const {
      return get_shared_slices(z0,z0,c0);
    }

    //! Return a shared-memory image referencing a range of channels of the image instance.
    /**
       \param c0 C-coordinate of the starting channel.
       \param c1 C-coordinate of the ending channel.
    **/
    CImg<T> get_shared_channels(const unsigned int c0, const unsigned int c1) {
      const unsigned int beg = offset(0,0,0,c0), end = offset(0,0,0,c1);
      if (beg>end || beg>=size() || end>=size())
        throw CImgArgumentException(_cimg_instance
                                    "get_shared_channels(): Invalid request of a shared-memory subset (0->%u,0->%u,0->%u,%u->%u).",
                                    cimg_instance,
                                    _width-1,_height-1,_depth-1,c0,c1);

      return CImg<T>(_data+beg,_width,_height,_depth,c1-c0+1,true);
    }

    //! Return a shared-memory image referencing a range of channels of the image instance \const.
    const CImg<T> get_shared_channels(const unsigned int c0, const unsigned int c1) const {
      const unsigned int beg = offset(0,0,0,c0), end = offset(0,0,0,c1);
      if (beg>end || beg>=size() || end>=size())
        throw CImgArgumentException(_cimg_instance
                                    "get_shared_channels(): Invalid request of a shared-memory subset (0->%u,0->%u,0->%u,%u->%u).",
                                    cimg_instance,
                                    _width-1,_height-1,_depth-1,c0,c1);

      return CImg<T>(_data+beg,_width,_height,_depth,c1-c0+1,true);
    }

    //! Return a shared-memory image referencing one channel of the image instance.
    /**
       \param c0 C-coordinate.
    **/
    CImg<T> get_shared_channel(const unsigned int c0) {
      return get_shared_channels(c0,c0);
    }

    //! Return a shared-memory image referencing one channel of the image instance \const.
    const CImg<T> get_shared_channel(const unsigned int c0) const {
      return get_shared_channels(c0,c0);
    }

    //! Return a shared-memory version of the image instance.
    CImg<T> get_shared() {
      return CImg<T>(_data,_width,_height,_depth,_spectrum,true);
    }

    //! Return a shared-memory version of the image instance \const.
    const CImg<T> get_shared() const {
      return CImg<T>(_data,_width,_height,_depth,_spectrum,true);
    }

    //! Split image into a list along specified axis.
    /**
       \param axis Splitting axis. Can be <tt>{ 'x' | 'y' | 'z' | 'c' }</tt>.
       \param nb Number of splitted parts.
       \note
       - If \c nb==0, there are as much splitted parts as the image size along the specified axis.
       - If \c nb<=0, instance image is splitted into blocs of -\c nb pixel wide.
       - If \c nb>0, instance image is splitted into \c nb blocs.
    **/
    CImgList<T> get_split(const char axis, const int nb=0) const {
      CImgList<T> res;
      if (is_empty()) return res;
      const char _axis = cimg::uncase(axis);

      if (nb<=0) { // Split by bloc size.
        const unsigned int dp = (unsigned int)(nb?-nb:1);
        int p = 0;
        switch (_axis) {
        case 'x': {
          for (int pe=_width-dp; p<pe; p+=dp) get_crop(p,0,0,0,p+dp-1,_height-1,_depth-1,_spectrum-1).move_to(res);
          get_crop(p,0,0,0,_width-1,_height-1,_depth-1,_spectrum-1).move_to(res);
        } break;
        case 'y': {
          for (int pe=_height-dp; p<pe; p+=dp) get_crop(0,p,0,0,_width-1,p+dp-1,_depth-1,_spectrum-1).move_to(res);
          get_crop(0,p,0,0,_width-1,_height-1,_depth-1,_spectrum-1).move_to(res);
        } break;
        case 'z': {
          for (int pe=_depth-dp; p<pe; p+=dp) get_crop(0,0,p,0,_width-1,_height-1,p+dp-1,_spectrum-1).move_to(res);
          get_crop(0,0,p,0,_width-1,_height-1,_depth-1,_spectrum-1).move_to(res);
        } break;
        default : {
          for (int pe=_spectrum-dp; p<pe; p+=dp) get_crop(0,0,0,p,_width-1,_height-1,_depth-1,p+dp-1).move_to(res);
          get_crop(0,0,0,p,_width-1,_height-1,_depth-1,_spectrum-1).move_to(res);
        }
        }

      } else { // Split by number of (non-homogeneous) blocs.
        const unsigned int siz = _axis=='x'?_width:_axis=='y'?_height:_axis=='z'?_depth:_axis=='c'?_spectrum:0;
        if ((unsigned int)nb>siz)
          throw CImgArgumentException(_cimg_instance
                                      "get_split(): Instance cannot be split along %c-axis into %u blocs.",
                                      cimg_instance,
                                      axis,nb);
        int err = (int)siz;
        unsigned int _p = 0;
        switch (_axis) {
        case 'x' : {
          cimg_forX(*this,p) if ((err-=nb)<=0) {
            get_crop(_p,0,0,0,p,_height-1,_depth-1,_spectrum-1).move_to(res);
            err+=(int)siz;
            _p=p+1;
          }
        } break;
        case 'y' : {
          cimg_forY(*this,p) if ((err-=nb)<=0) {
            get_crop(0,_p,0,0,_width-1,p,_depth-1,_spectrum-1).move_to(res);
            err+=(int)siz;
            _p=p+1;
          }
        } break;
        case 'z' : {
          cimg_forZ(*this,p) if ((err-=nb)<=0) {
            get_crop(0,0,_p,0,_width-1,_height-1,p,_spectrum-1).move_to(res);
            err+=(int)siz;
            _p=p+1;
          }
        } break;
        default : {
          cimg_forC(*this,p) if ((err-=nb)<=0) {
            get_crop(0,0,0,_p,_width-1,_height-1,_depth-1,p).move_to(res);
            err+=(int)siz;
            _p=p+1;
          }
        }
        }
      }
      return res;
    }

    //! Split image into a list of one-column vectors, according to a specified splitting value.
    /**
       \param value Splitting value.
       \param keep_values Tells if the splitting value must be kept in the splitted blocs.
       \param is_shared Tells if the splitted blocs have shared memory buffers.
    **/
    CImgList<T> get_split(const T value, const bool keep_values, const bool is_shared) const {
      CImgList<T> res;
      if (is_empty()) return res;
      for (const T *ps = _data, *_ps = ps, *const pe = end(); ps<pe; ) {
        while (_ps<pe && *_ps==value) ++_ps;
        unsigned int siz = _ps - ps;
        if (siz && keep_values) res.insert(CImg<T>(ps,1,siz,1,1,is_shared),~0U,is_shared);
        ps = _ps;
        while (_ps<pe && *_ps!=value) ++_ps;
        siz = _ps - ps;
        if (siz) res.insert(CImg<T>(ps,1,siz,1,1,is_shared),~0U,is_shared);
        ps = _ps;
      }
      return res;
    }

    //! Split image into a list of one-column vectors, according to a specified splitting value sequence.
    /**
       \param values Splitting value sequence.
       \param keep_values Tells if the splitting sequence must be kept in the splitted blocs.
       \param is_shared Tells if the splitted blocs have shared memory buffers.
     **/
    template<typename t>
    CImgList<T> get_split(const CImg<t>& values, const bool keep_values, const bool is_shared) const {
      CImgList<T> res;
      if (is_empty()) return res;
      if (!values) return CImgList<T>(*this);
      if (values.size()==1) return get_split(*values,keep_values,is_shared);
      const t *pve = values.end();
      for (const T *ps = _data, *_ps = ps, *const pe = end(); ps<pe; ) {

        // Try to find match from current position.
        const t *pv = 0;
        do {
          pv = values._data;
          const T *__ps = _ps;
          while (__ps<pe && pv<pve && *__ps==(T)*pv) { ++__ps; ++pv; }
          if (pv==pve) _ps = __ps;
        } while (pv==pve);
        unsigned int siz = _ps - ps;
        if (siz && keep_values) res.insert(CImg<T>(ps,1,siz,1,1,is_shared),~0U,is_shared); // If match found.
        ps = _ps;

        // Try to find non-match from current position.
        do {
          pv = values._data;
          while (_ps<pe && *_ps!=(T)*pv) ++_ps;
          if (_ps<pe) {
            const T *__ps = _ps + 1;
            ++pv;
            while (__ps<pe && pv<pve && *__ps==(T)*pv) { ++__ps; ++pv; }
            if (pv!=pve) _ps = __ps;
          }
        } while (_ps<pe && pv!=pve);

        // Here, EOF of match found.
        siz = _ps - ps;
        if (siz) res.insert(CImg<T>(ps,1,siz,1,1,is_shared),~0U,is_shared);
        ps = _ps;
      }
      return res;
    }

    //! Split the image into a list of one-column vectors each having same values.
    CImgList<T> get_split(const bool is_shared) const {
      CImgList<T> res;
      if (is_empty()) return res;
      T *p0 = _data, current = *p0;
      cimg_for(*this,p,T) if (*p!=current) { res.insert(CImg<T>(p0,1,p-p0,1,1,is_shared),~0U,is_shared); p0 = p; current = *p; }
      res.insert(CImg<T>(p0,1,end()-p0,1,1,is_shared),~0U,is_shared);
      return res;
    }

    //! Append two images along specified axis.
    /**
       \param img Image to append with instance image.
       \param axis Appending axis. Can be <tt>{ 'x' | 'y' | 'z' | 'c' }</tt>.
       \param align Append alignment in \c [0,1].
    **/
    template<typename t>
    CImg<T>& append(const CImg<t>& img, const char axis='x', const float align=0) {
      if (is_empty()) return assign(img,false);
      if (!img) return *this;
      return CImgList<T>(*this,true).insert(img).get_append(axis,align).move_to(*this);
    }

    //! Append two images along specified axis \specialization.
    CImg<T>& append(const CImg<T>& img, const char axis='x', const float align=0) {
      if (is_empty()) return assign(img,false);
      if (!img) return *this;
      return CImgList<T>(*this,img,true).get_append(axis,align).move_to(*this);
    }

    //! Append two images along specified axis \const.
    template<typename t>
    CImg<_cimg_Tt> get_append(const CImg<T>& img, const char axis='x', const float align=0) const {
      if (is_empty()) return +img;
      if (!img) return +*this;
      return CImgList<_cimg_Tt>(*this,true).insert(img).get_append(axis,align);
    }

    //! Append two images along specified axis \specialization.
    CImg<T> get_append(const CImg<T>& img, const char axis='x', const float align=0) const {
      if (is_empty()) return +img;
      if (!img) return +*this;
      return CImgList<T>(*this,img,true).get_append(axis,align);
    }

    //@}
    //---------------------------------------
    //
    //! \name Filtering / Transforms
    //@{
    //---------------------------------------

    //! Correlate image by a mask.
    /**
       \param mask = the correlation kernel.
       \param boundary_conditions = the border condition type (0=zero, 1=dirichlet)
       \param is_normalized = enable local normalization.
       \note
       - The correlation of the image instance \p *this by the mask \p mask is defined to be:
       res(x,y,z) = sum_{i,j,k} (*this)(x+i,y+j,z+k)*mask(i,j,k).
    **/
    template<typename t>
    CImg<T>& correlate(const CImg<t>& mask, const unsigned int boundary_conditions=1, const bool is_normalized=false) {
      if (is_empty() || !mask) return *this;
      return get_correlate(mask,boundary_conditions,is_normalized).move_to(*this);
    }

    //! Correlate image by a mask \newinstance.
    template<typename t>
    CImg<_cimg_Ttfloat> get_correlate(const CImg<t>& mask, const unsigned int boundary_conditions=1,
                                      const bool is_normalized=false) const {
      if (is_empty() || !mask) return *this;
      typedef _cimg_Ttfloat Ttfloat;
      CImg<Ttfloat> res(_width,_height,_depth,cimg::max(_spectrum,mask._spectrum));
      if (boundary_conditions && mask._width==mask._height && ((mask._depth==1 && mask._width<=5) || (mask._depth==mask._width && mask._width<=3))) {
        // A special optimization is done for 2x2, 3x3, 4x4, 5x5, 2x2x2 and 3x3x3 mask (with boundary_conditions=1)
        Ttfloat *ptrd = res._data;
        switch (mask._depth) {
        case 3 : {
          T I[27] = { 0 };
          cimg_forC(res,c) {
            const CImg<T> _img = get_shared_channel(c%_spectrum);
            const CImg<t> _mask = mask.get_shared_channel(c%mask._spectrum);
            if (is_normalized) {
              const Ttfloat _M = (Ttfloat)_mask.magnitude(2), M = _M*_M;
              cimg_for3x3x3(_img,x,y,z,0,I,T) {
                const Ttfloat N = M*(I[ 0]*I[ 0] + I[ 1]*I[ 1] + I[ 2]*I[ 2] +
                                     I[ 3]*I[ 3] + I[ 4]*I[ 4] + I[ 5]*I[ 5] +
                                     I[ 6]*I[ 6] + I[ 7]*I[ 7] + I[ 8]*I[ 8] +
                                     I[ 9]*I[ 9] + I[10]*I[10] + I[11]*I[11] +
                                     I[12]*I[12] + I[13]*I[13] + I[14]*I[14] +
                                     I[15]*I[15] + I[16]*I[16] + I[17]*I[17] +
                                     I[18]*I[18] + I[19]*I[19] + I[20]*I[20] +
                                     I[21]*I[21] + I[22]*I[22] + I[23]*I[23] +
                                     I[24]*I[24] + I[25]*I[25] + I[26]*I[26]);
                *(ptrd++) = (Ttfloat)(N?(I[ 0]*_mask[ 0] + I[ 1]*_mask[ 1] + I[ 2]*_mask[ 2] +
                                         I[ 3]*_mask[ 3] + I[ 4]*_mask[ 4] + I[ 5]*_mask[ 5] +
                                         I[ 6]*_mask[ 6] + I[ 7]*_mask[ 7] + I[ 8]*_mask[ 8] +
                                         I[ 9]*_mask[ 9] + I[10]*_mask[10] + I[11]*_mask[11] +
                                         I[12]*_mask[12] + I[13]*_mask[13] + I[14]*_mask[14] +
                                         I[15]*_mask[15] + I[16]*_mask[16] + I[17]*_mask[17] +
                                         I[18]*_mask[18] + I[19]*_mask[19] + I[20]*_mask[20] +
                                         I[21]*_mask[21] + I[22]*_mask[22] + I[23]*_mask[23] +
                                         I[24]*_mask[24] + I[25]*_mask[25] + I[26]*_mask[26])/std::sqrt(N):0);
              }
            } else cimg_for3x3x3(_img,x,y,z,0,I,T)
                     *(ptrd++) = (Ttfloat)(I[ 0]*_mask[ 0] + I[ 1]*_mask[ 1] + I[ 2]*_mask[ 2] +
                                           I[ 3]*_mask[ 3] + I[ 4]*_mask[ 4] + I[ 5]*_mask[ 5] +
                                           I[ 6]*_mask[ 6] + I[ 7]*_mask[ 7] + I[ 8]*_mask[ 8] +
                                           I[ 9]*_mask[ 9] + I[10]*_mask[10] + I[11]*_mask[11] +
                                           I[12]*_mask[12] + I[13]*_mask[13] + I[14]*_mask[14] +
                                           I[15]*_mask[15] + I[16]*_mask[16] + I[17]*_mask[17] +
                                           I[18]*_mask[18] + I[19]*_mask[19] + I[20]*_mask[20] +
                                           I[21]*_mask[21] + I[22]*_mask[22] + I[23]*_mask[23] +
                                           I[24]*_mask[24] + I[25]*_mask[25] + I[26]*_mask[26]);
          }
        } break;
        case 2 : {
          T I[8] = { 0 };
          cimg_forC(res,c) {
            const CImg<T> _img = get_shared_channel(c%_spectrum);
            const CImg<t> _mask = mask.get_shared_channel(c%mask._spectrum);
            if (is_normalized) {
              const Ttfloat _M = (Ttfloat)_mask.magnitude(2), M = _M*_M;
              cimg_for2x2x2(_img,x,y,z,0,I,T) {
                const Ttfloat N = M*(I[0]*I[0] + I[1]*I[1] +
                                     I[2]*I[2] + I[3]*I[3] +
                                     I[4]*I[4] + I[5]*I[5] +
                                     I[6]*I[6] + I[7]*I[7]);
                *(ptrd++) = (Ttfloat)(N?(I[0]*_mask[0] + I[1]*_mask[1] +
                                         I[2]*_mask[2] + I[3]*_mask[3] +
                                         I[4]*_mask[4] + I[5]*_mask[5] +
                                         I[6]*_mask[6] + I[7]*_mask[7])/std::sqrt(N):0);
              }
            } else cimg_for2x2x2(_img,x,y,z,0,I,T)
                     *(ptrd++) = (Ttfloat)(I[0]*_mask[0] + I[1]*_mask[1] +
                                           I[2]*_mask[2] + I[3]*_mask[3] +
                                           I[4]*_mask[4] + I[5]*_mask[5] +
                                           I[6]*_mask[6] + I[7]*_mask[7]);
          }
        } break;
        default :
        case 1 :
          switch (mask._width) {
          case 6 : {
            T I[36] = { 0 };
            cimg_forC(res,c) {
              const CImg<T> _img = get_shared_channel(c%_spectrum);
              const CImg<t> _mask = mask.get_shared_channel(c%mask._spectrum);
              if (is_normalized) {
                const Ttfloat _M = (Ttfloat)_mask.magnitude(2), M = _M*_M;
                cimg_forZ(_img,z) cimg_for6x6(_img,x,y,z,0,I,T) {
                  const Ttfloat N = M*(I[ 0]*I[ 0] + I[ 1]*I[ 1] + I[ 2]*I[ 2] + I[ 3]*I[ 3] + I[ 4]*I[ 4] + I[ 5]*I[ 5] +
                                       I[ 6]*I[ 6] + I[ 7]*I[ 7] + I[ 8]*I[ 8] + I[ 9]*I[ 9] + I[10]*I[10] + I[11]*I[11] +
                                       I[12]*I[12] + I[13]*I[13] + I[14]*I[14] + I[15]*I[15] + I[16]*I[16] + I[17]*I[17] +
                                       I[18]*I[18] + I[19]*I[19] + I[20]*I[20] + I[21]*I[21] + I[22]*I[22] + I[23]*I[23] +
                                       I[24]*I[24] + I[25]*I[25] + I[26]*I[26] + I[27]*I[27] + I[28]*I[28] + I[29]*I[29] +
                                       I[30]*I[30] + I[31]*I[31] + I[32]*I[32] + I[33]*I[33] + I[34]*I[34] + I[35]*I[35]);
                  *(ptrd++) = (Ttfloat)(N?(I[ 0]*_mask[ 0] + I[ 1]*_mask[ 1] + I[ 2]*_mask[ 2] + I[ 3]*_mask[ 3] + I[ 4]*_mask[ 4] + I[ 5]*_mask[ 5] +
                                           I[ 6]*_mask[ 6] + I[ 7]*_mask[ 7] + I[ 8]*_mask[ 8] + I[ 9]*_mask[ 9] + I[10]*_mask[10] + I[11]*_mask[11] +
                                           I[12]*_mask[12] + I[13]*_mask[13] + I[14]*_mask[14] + I[15]*_mask[15] + I[16]*_mask[16] + I[17]*_mask[17] +
                                           I[18]*_mask[18] + I[19]*_mask[19] + I[20]*_mask[20] + I[21]*_mask[21] + I[22]*_mask[22] + I[23]*_mask[23] +
                                           I[24]*_mask[24] + I[25]*_mask[25] + I[26]*_mask[26] + I[27]*_mask[27] + I[28]*_mask[28] + I[29]*_mask[29] +
                                           I[30]*_mask[30] + I[31]*_mask[31] + I[32]*_mask[32] + I[33]*_mask[33] + I[34]*_mask[34] + I[35]*_mask[35])/std::sqrt(N):0);
                }
              } else cimg_forZ(_img,z) cimg_for6x6(_img,x,y,z,0,I,T)
                       *(ptrd++) = (Ttfloat)(I[ 0]*_mask[ 0] + I[ 1]*_mask[ 1] + I[ 2]*_mask[ 2] + I[ 3]*_mask[ 3] + I[ 4]*_mask[ 4] + I[ 5]*_mask[ 5] +
                                             I[ 6]*_mask[ 6] + I[ 7]*_mask[ 7] + I[ 8]*_mask[ 8] + I[ 9]*_mask[ 9] + I[10]*_mask[10] + I[11]*_mask[11] +
                                             I[12]*_mask[12] + I[13]*_mask[13] + I[14]*_mask[14] + I[15]*_mask[15] + I[16]*_mask[16] + I[17]*_mask[17] +
                                             I[18]*_mask[18] + I[19]*_mask[19] + I[20]*_mask[20] + I[21]*_mask[21] + I[22]*_mask[22] + I[23]*_mask[23] +
                                             I[24]*_mask[24] + I[25]*_mask[25] + I[26]*_mask[26] + I[27]*_mask[27] + I[28]*_mask[28] + I[29]*_mask[29] +
                                             I[30]*_mask[30] + I[31]*_mask[31] + I[32]*_mask[32] + I[33]*_mask[33] + I[34]*_mask[34] + I[35]*_mask[35]);
            }
          } break;
          case 5 : {
            T I[25] = { 0 };
            cimg_forC(res,c) {
              const CImg<T> _img = get_shared_channel(c%_spectrum);
              const CImg<t> _mask = mask.get_shared_channel(c%mask._spectrum);
              if (is_normalized) {
                const Ttfloat _M = (Ttfloat)_mask.magnitude(2), M = _M*_M;
                cimg_forZ(_img,z) cimg_for5x5(_img,x,y,z,0,I,T) {
                  const Ttfloat N = M*(I[ 0]*I[ 0] + I[ 1]*I[ 1] + I[ 2]*I[ 2] + I[ 3]*I[ 3] + I[ 4]*I[ 4] +
                                       I[ 5]*I[ 5] + I[ 6]*I[ 6] + I[ 7]*I[ 7] + I[ 8]*I[ 8] + I[ 9]*I[ 9] +
                                       I[10]*I[10] + I[11]*I[11] + I[12]*I[12] + I[13]*I[13] + I[14]*I[14] +
                                       I[15]*I[15] + I[16]*I[16] + I[17]*I[17] + I[18]*I[18] + I[19]*I[19] +
                                       I[20]*I[20] + I[21]*I[21] + I[22]*I[22] + I[23]*I[23] + I[24]*I[24]);
                  *(ptrd++) = (Ttfloat)(N?(I[ 0]*_mask[ 0] + I[ 1]*_mask[ 1] + I[ 2]*_mask[ 2] + I[ 3]*_mask[ 3] + I[ 4]*_mask[ 4] +
                                           I[ 5]*_mask[ 5] + I[ 6]*_mask[ 6] + I[ 7]*_mask[ 7] + I[ 8]*_mask[ 8] + I[ 9]*_mask[ 9] +
                                           I[10]*_mask[10] + I[11]*_mask[11] + I[12]*_mask[12] + I[13]*_mask[13] + I[14]*_mask[14] +
                                           I[15]*_mask[15] + I[16]*_mask[16] + I[17]*_mask[17] + I[18]*_mask[18] + I[19]*_mask[19] +
                                           I[20]*_mask[20] + I[21]*_mask[21] + I[22]*_mask[22] + I[23]*_mask[23] + I[24]*_mask[24])/std::sqrt(N):0);
                }
              } else cimg_forZ(_img,z) cimg_for5x5(_img,x,y,z,0,I,T)
                       *(ptrd++) = (Ttfloat)(I[ 0]*_mask[ 0] + I[ 1]*_mask[ 1] + I[ 2]*_mask[ 2] + I[ 3]*_mask[ 3] + I[ 4]*_mask[ 4] +
                                             I[ 5]*_mask[ 5] + I[ 6]*_mask[ 6] + I[ 7]*_mask[ 7] + I[ 8]*_mask[ 8] + I[ 9]*_mask[ 9] +
                                             I[10]*_mask[10] + I[11]*_mask[11] + I[12]*_mask[12] + I[13]*_mask[13] + I[14]*_mask[14] +
                                             I[15]*_mask[15] + I[16]*_mask[16] + I[17]*_mask[17] + I[18]*_mask[18] + I[19]*_mask[19] +
                                             I[20]*_mask[20] + I[21]*_mask[21] + I[22]*_mask[22] + I[23]*_mask[23] + I[24]*_mask[24]);
            }
          } break;
          case 4 : {
            T I[16] = { 0 };
            cimg_forC(res,c) {
              const CImg<T> _img = get_shared_channel(c%_spectrum);
              const CImg<t> _mask = mask.get_shared_channel(c%mask._spectrum);
              if (is_normalized) {
                const Ttfloat _M = (Ttfloat)_mask.magnitude(2), M = _M*_M;
                cimg_forZ(_img,z) cimg_for4x4(_img,x,y,z,0,I,T) {
                  const Ttfloat N = M*(I[ 0]*I[ 0] + I[ 1]*I[ 1] + I[ 2]*I[ 2] + I[ 3]*I[ 3] +
                                       I[ 4]*I[ 4] + I[ 5]*I[ 5] + I[ 6]*I[ 6] + I[ 7]*I[ 7] +
                                       I[ 8]*I[ 8] + I[ 9]*I[ 9] + I[10]*I[10] + I[11]*I[11] +
                                       I[12]*I[12] + I[13]*I[13] + I[14]*I[14] + I[15]*I[15]);
                  *(ptrd++) = (Ttfloat)(N?(I[ 0]*_mask[ 0] + I[ 1]*_mask[ 1] + I[ 2]*_mask[ 2] + I[ 3]*_mask[ 3] +
                                           I[ 4]*_mask[ 4] + I[ 5]*_mask[ 5] + I[ 6]*_mask[ 6] + I[ 7]*_mask[ 7] +
                                           I[ 8]*_mask[ 8] + I[ 9]*_mask[ 9] + I[10]*_mask[10] + I[11]*_mask[11] +
                                           I[12]*_mask[12] + I[13]*_mask[13] + I[14]*_mask[14] + I[15]*_mask[15])/std::sqrt(N):0);
                }
              } else cimg_forZ(_img,z) cimg_for4x4(_img,x,y,z,0,I,T)
                       *(ptrd++) = (Ttfloat)(I[ 0]*_mask[ 0] + I[ 1]*_mask[ 1] + I[ 2]*_mask[ 2] + I[ 3]*_mask[ 3] +
                                             I[ 4]*_mask[ 4] + I[ 5]*_mask[ 5] + I[ 6]*_mask[ 6] + I[ 7]*_mask[ 7] +
                                             I[ 8]*_mask[ 8] + I[ 9]*_mask[ 9] + I[10]*_mask[10] + I[11]*_mask[11] +
                                             I[12]*_mask[12] + I[13]*_mask[13] + I[14]*_mask[14] + I[15]*_mask[15]);
            }
          } break;
          case 3 : {
            T I[9] = { 0 };
            cimg_forC(res,c) {
              const CImg<T> _img = get_shared_channel(c%_spectrum);
              const CImg<t> _mask = mask.get_shared_channel(c%mask._spectrum);
              if (is_normalized) {
                const Ttfloat _M = (Ttfloat)_mask.magnitude(2), M = _M*_M;
                cimg_forZ(_img,z) cimg_for3x3(_img,x,y,z,0,I,T) {
                  const Ttfloat N = M*(I[0]*I[0] + I[1]*I[1] + I[2]*I[2] +
                                       I[3]*I[3] + I[4]*I[4] + I[5]*I[5] +
                                       I[6]*I[6] + I[7]*I[7] + I[8]*I[8]);
                  *(ptrd++) = (Ttfloat)(N?(I[0]*_mask[0] + I[1]*_mask[1] + I[2]*_mask[2] +
                                           I[3]*_mask[3] + I[4]*_mask[4] + I[5]*_mask[5] +
                                           I[6]*_mask[6] + I[7]*_mask[7] + I[8]*_mask[8])/std::sqrt(N):0);
                }
              } else cimg_forZ(_img,z) cimg_for3x3(_img,x,y,z,0,I,T)
                       *(ptrd++) = (Ttfloat)(I[0]*_mask[0] + I[1]*_mask[1] + I[2]*_mask[2] +
                                             I[3]*_mask[3] + I[4]*_mask[4] + I[5]*_mask[5] +
                                             I[6]*_mask[6] + I[7]*_mask[7] + I[8]*_mask[8]);
            }
          } break;
          case 2 : {
            T I[4] = { 0 };
            cimg_forC(res,c) {
              const CImg<T> _img = get_shared_channel(c%_spectrum);
              const CImg<t> _mask = mask.get_shared_channel(c%mask._spectrum);
              if (is_normalized) {
                const Ttfloat _M = (Ttfloat)_mask.magnitude(2), M = _M*_M;
                cimg_forZ(_img,z) cimg_for2x2(_img,x,y,z,0,I,T) {
                  const Ttfloat N = M*(I[0]*I[0] + I[1]*I[1] +
                                       I[2]*I[2] + I[3]*I[3]);
                  *(ptrd++) = (Ttfloat)(N?(I[0]*_mask[0] + I[1]*_mask[1] +
                                           I[2]*_mask[2] + I[3]*_mask[3])/std::sqrt(N):0);
                }
              } else cimg_forZ(_img,z) cimg_for2x2(_img,x,y,z,0,I,T)
                       *(ptrd++) = (Ttfloat)(I[0]*_mask[0] + I[1]*_mask[1] +
                                             I[2]*_mask[2] + I[3]*_mask[3]);
            }
          } break;
          case 1 :
            if (is_normalized) res.fill(1);
            else cimg_forC(res,c) {
                const CImg<T> _img = get_shared_channel(c%_spectrum);
                const CImg<t> _mask = mask.get_shared_channel(c%mask._spectrum);
                res.get_shared_channel(c).assign(_img)*=_mask[0];
              }
            break;
          }
        }
      } else { // Generic version for other masks and borders conditions.
        const int
          mx2 = mask.width()/2, my2 = mask.height()/2, mz2 = mask.depth()/2,
          mx1 = mx2 - 1 + (mask.width()%2), my1 = my2 - 1 + (mask.height()%2), mz1 = mz2 - 1 + (mask.depth()%2),
          mxe = width() - mx2, mye = height() - my2, mze = depth() - mz2;
        cimg_forC(res,c) {
          const CImg<T> _img = get_shared_channel(c%_spectrum);
          const CImg<t> _mask = mask.get_shared_channel(c%mask._spectrum);
          if (is_normalized) { // Normalized correlation.
            const Ttfloat _M = (Ttfloat)_mask.magnitude(2), M = _M*_M;
            for (int z = mz1; z<mze; ++z)
              for (int y = my1; y<mye; ++y)
                for (int x = mx1; x<mxe; ++x) {
                  Ttfloat val = 0, N = 0;
                  for (int zm = -mz1; zm<=mz2; ++zm)
                    for (int ym = -my1; ym<=my2; ++ym)
                      for (int xm = -mx1; xm<=mx2; ++xm) {
                        const Ttfloat _val = (Ttfloat)_img(x+xm,y+ym,z+zm);
                        val+=_val*_mask(mx1+xm,my1+ym,mz1+zm);
                        N+=_val*_val;
                      }
                  N*=M;
                  res(x,y,z,c) = (Ttfloat)(N?val/std::sqrt(N):0);
                }
            if (boundary_conditions)
              cimg_forYZ(res,y,z)
                for (int x = 0; x<width(); (y<my1 || y>=mye || z<mz1 || z>=mze)?++x:((x<mx1-1 || x>=mxe)?++x:(x=mxe))) {
                  Ttfloat val = 0, N = 0;
                  for (int zm = -mz1; zm<=mz2; ++zm)
                    for (int ym = -my1; ym<=my2; ++ym)
                      for (int xm = -mx1; xm<=mx2; ++xm) {
                        const Ttfloat _val = (Ttfloat)_img._atXYZ(x+xm,y+ym,z+zm);
                        val+=_val*_mask(mx1+xm,my1+ym,mz1+zm);
                        N+=_val*_val;
                      }
                  N*=M;
                  res(x,y,z,c) = (Ttfloat)(N?val/std::sqrt(N):0);
                }
            else
              cimg_forYZ(res,y,z)
                for (int x = 0; x<width(); (y<my1 || y>=mye || z<mz1 || z>=mze)?++x:((x<mx1-1 || x>=mxe)?++x:(x=mxe))) {
                  Ttfloat val = 0, N = 0;
                  for (int zm = -mz1; zm<=mz2; ++zm)
                    for (int ym = -my1; ym<=my2; ++ym)
                      for (int xm = -mx1; xm<=mx2; ++xm) {
                        const Ttfloat _val = (Ttfloat)_img.atXYZ(x+xm,y+ym,z+zm,0,0);
                        val+=_val*_mask(mx1+xm,my1+ym,mz1+zm);
                        N+=_val*_val;
                      }
                  N*=M;
                  res(x,y,z,c) = (Ttfloat)(N?val/std::sqrt(N):0);
                }
          } else { // Classical correlation.
            for (int z = mz1; z<mze; ++z)
              for (int y = my1; y<mye; ++y)
                for (int x = mx1; x<mxe; ++x) {
                  Ttfloat val = 0;
                  for (int zm = -mz1; zm<=mz2; ++zm)
                    for (int ym = -my1; ym<=my2; ++ym)
                      for (int xm = -mx1; xm<=mx2; ++xm)
                        val+=_img(x+xm,y+ym,z+zm)*_mask(mx1+xm,my1+ym,mz1+zm);
                  res(x,y,z,c) = (Ttfloat)val;
                }
            if (boundary_conditions)
              cimg_forYZ(res,y,z)
                for (int x = 0; x<width(); (y<my1 || y>=mye || z<mz1 || z>=mze)?++x:((x<mx1-1 || x>=mxe)?++x:(x=mxe))) {
                  Ttfloat val = 0;
                  for (int zm = -mz1; zm<=mz2; ++zm)
                    for (int ym = -my1; ym<=my2; ++ym)
                      for (int xm = -mx1; xm<=mx2; ++xm)
                        val+=_img._atXYZ(x+xm,y+ym,z+zm)*_mask(mx1+xm,my1+ym,mz1+zm);
                  res(x,y,z,c) = (Ttfloat)val;
                }
            else
              cimg_forYZ(res,y,z)
                for (int x = 0; x<width(); (y<my1 || y>=mye || z<mz1 || z>=mze)?++x:((x<mx1-1 || x>=mxe)?++x:(x=mxe))) {
                  Ttfloat val = 0;
                  for (int zm = -mz1; zm<=mz2; ++zm)
                    for (int ym = -my1; ym<=my2; ++ym)
                      for (int xm = -mx1; xm<=mx2; ++xm)
                        val+=_img.atXYZ(x+xm,y+ym,z+zm,0,0)*_mask(mx1+xm,my1+ym,mz1+zm);
                  res(x,y,z,c) = (Ttfloat)val;
                }
          }
        }
      }
      return res;
    }

    //! Convolve image by a mask.
    /**
       \param mask = the correlation kernel.
       \param boundary_conditions = the border condition type (0=zero, 1=dirichlet)
       \param is_normalized = enable local normalization.
       \note
       - The result \p res of the convolution of an image \p img by a mask \p mask is defined to be:
       res(x,y,z) = sum_{i,j,k} img(x-i,y-j,z-k)*mask(i,j,k)
    **/
    template<typename t>
    CImg<T>& convolve(const CImg<t>& mask, const unsigned int boundary_conditions=1, const bool is_normalized=false) {
      if (is_empty() || !mask) return *this;
      return get_convolve(mask,boundary_conditions,is_normalized).move_to(*this);
    }

    //! Convolve image by a mask \newinstance.
    template<typename t>
    CImg<_cimg_Ttfloat> get_convolve(const CImg<t>& mask, const unsigned int boundary_conditions=1,
                                     const bool is_normalized=false) const {
      if (is_empty() || !mask) return *this;
      return get_correlate(CImg<t>(mask._data,mask.size(),1,1,1,true).get_mirror('x').resize(mask,-1),boundary_conditions,is_normalized);
    }

    //! Erode image by a structuring element.
    /**
       \param mask Structuring element.
       \param boundary_conditions Boundary conditions.
       \param is_normalized Tells if the erosion is locally normalized.
    **/
    template<typename t>
    CImg<T>& erode(const CImg<t>& mask, const unsigned int boundary_conditions=1, const bool is_normalized=false) {
      if (is_empty() || !mask) return *this;
      return get_erode(mask,boundary_conditions,is_normalized).move_to(*this);
    }

    //! Erode image by a structuring element \newinstance.
    template<typename t>
    CImg<_cimg_Tt> get_erode(const CImg<t>& mask, const unsigned int boundary_conditions=1,
                             const bool is_normalized=false) const {
      if (is_empty() || !mask) return *this;
      typedef _cimg_Tt Tt;
      CImg<Tt> res(_width,_height,_depth,cimg::max(_spectrum,mask._spectrum));
      const int
        mx2 = mask.width()/2, my2 = mask.height()/2, mz2 = mask.depth()/2,
        mx1 = mx2 - 1 + (mask.width()%2), my1 = my2 - 1 + (mask.height()%2), mz1 = mz2 - 1 + (mask.depth()%2),
        mxe = width() - mx2, mye = height() - my2, mze = depth() - mz2;
      cimg_forC(*this,c) {
        const CImg<T> _img = get_shared_channel(c%_spectrum);
        const CImg<t> _mask = mask.get_shared_channel(c%mask._spectrum);
        if (is_normalized) { // Normalized erosion.
          for (int z = mz1; z<mze; ++z)
            for (int y = my1; y<mye; ++y)
              for (int x = mx1; x<mxe; ++x) {
                Tt min_val = cimg::type<Tt>::max();
                for (int zm = -mz1; zm<=mz2; ++zm)
                  for (int ym = -my1; ym<=my2; ++ym)
                    for (int xm = -mx1; xm<=mx2; ++xm) {
                      const t mval = _mask(mx1+xm,my1+ym,mz1+zm);
                      const Tt cval = (Tt)(_img(x+xm,y+ym,z+zm) + mval);
                      if (mval && cval<min_val) min_val = cval;
                    }
                res(x,y,z,c) = min_val;
              }
          if (boundary_conditions)
            cimg_forYZ(res,y,z)
              for (int x = 0; x<width(); (y<my1 || y>=mye || z<mz1 || z>=mze)?++x:((x<mx1-1 || x>=mxe)?++x:(x=mxe))) {
                Tt min_val = cimg::type<Tt>::max();
                for (int zm = -mz1; zm<=mz2; ++zm)
                  for (int ym = -my1; ym<=my2; ++ym)
                    for (int xm = -mx1; xm<=mx2; ++xm) {
                      const t mval = _mask(mx1+xm,my1+ym,mz1+zm);
                      const Tt cval = (Tt)(_img._atXYZ(x+xm,y+ym,z+zm) + mval);
                      if (mval && cval<min_val) min_val = cval;
                    }
                res(x,y,z,c) = min_val;
              }
          else
            cimg_forYZ(res,y,z)
              for (int x = 0; x<width(); (y<my1 || y>=mye || z<mz1 || z>=mze)?++x:((x<mx1-1 || x>=mxe)?++x:(x=mxe))) {
                Tt min_val = cimg::type<Tt>::max();
                for (int zm = -mz1; zm<=mz2; ++zm)
                  for (int ym = -my1; ym<=my2; ++ym)
                    for (int xm = -mx1; xm<=mx2; ++xm) {
                      const t mval = _mask(mx1+xm,my1+ym,mz1+zm);
                      const Tt cval = (Tt)(_img.atXYZ(x+xm,y+ym,z+zm,0,0) + mval);
                      if (mval && cval<min_val) min_val = cval;
                    }
                res(x,y,z,c) = min_val;
              }
        } else { // Classical erosion.
          for (int z = mz1; z<mze; ++z)
            for (int y = my1; y<mye; ++y)
              for (int x = mx1; x<mxe; ++x) {
                Tt min_val = cimg::type<Tt>::max();
                for (int zm = -mz1; zm<=mz2; ++zm)
                  for (int ym = -my1; ym<=my2; ++ym)
                    for (int xm = -mx1; xm<=mx2; ++xm) {
                      const Tt cval = (Tt)_img(x+xm,y+ym,z+zm);
                      if (_mask(mx1+xm,my1+ym,mz1+zm) && cval<min_val) min_val = cval;
                    }
                res(x,y,z,c) = min_val;
              }
          if (boundary_conditions)
            cimg_forYZ(res,y,z)
              for (int x = 0; x<width(); (y<my1 || y>=mye || z<mz1 || z>=mze)?++x:((x<mx1-1 || x>=mxe)?++x:(x=mxe))) {
                Tt min_val = cimg::type<Tt>::max();
                for (int zm = -mz1; zm<=mz2; ++zm)
                  for (int ym = -my1; ym<=my2; ++ym)
                    for (int xm = -mx1; xm<=mx2; ++xm) {
                      const T cval = (Tt)_img._atXYZ(x+xm,y+ym,z+zm);
                      if (_mask(mx1+xm,my1+ym,mz1+zm) && cval<min_val) min_val = cval;
                    }
                res(x,y,z,c) = min_val;
              }
          else
            cimg_forYZ(res,y,z)
              for (int x = 0; x<width(); (y<my1 || y>=mye || z<mz1 || z>=mze)?++x:((x<mx1-1 || x>=mxe)?++x:(x=mxe))) {
                Tt min_val = cimg::type<Tt>::max();
                for (int zm = -mz1; zm<=mz2; ++zm)
                  for (int ym = -my1; ym<=my2; ++ym)
                    for (int xm = -mx1; xm<=mx2; ++xm) {
                      const T cval = (Tt)_img.atXYZ(x+xm,y+ym,z+zm,0,0);
                      if (_mask(mx1+xm,my1+ym,mz1+zm) && cval<min_val) min_val = cval;
                    }
                res(x,y,z,c) = min_val;
              }
        }
      }
      return res;
    }

    //! Erode image by a rectangular structuring element of specified size.
    /**
       \param sx Width of the structuring element.
       \param sy Height of the structuring element.
       \param sz Depth of the structuring element.
    **/
    CImg<T>& erode(const unsigned int sx, const unsigned int sy, const unsigned int sz=1) {
      if (is_empty() || (sx==1 && sy==1 && sz==1)) return *this;
      if (sx>1 && _width>1) { // Along X-axis.
        const int L = width(), off = 1, s = (int)sx, _s1 = s/2, _s2 = s - _s1, s1 = _s1>L?L:_s1, s2 = _s2>L?L:_s2;
        CImg<T> buf(L);
        T *const ptrdb = buf._data, *ptrd = ptrdb, *const ptrde = buf._data + L - 1;
        cimg_forYZC(*this,y,z,c) {
          const T *const ptrsb = data(0,y,z,c), *ptrs = ptrsb, *const ptrse = ptrs + L*off - off;
          ptrd = buf._data; T cur = *ptrs; ptrs+=off; bool is_first = true;
          for (int p = s2-1; p>0 && ptrs<=ptrse; --p) { const T val = *ptrs; ptrs+=off; if (val<=cur) { cur = val; is_first = false; }} *(ptrd++) = cur;
          for (int p = s1; p>0 && ptrd<=ptrde; --p) { const T val = *ptrs; if (ptrs<ptrse) ptrs+=off; if (val<=cur) { cur = val; is_first = false; } *(ptrd++) = cur; }
          for (int p = L - s - 1; p>0; --p) {
            const T val = *ptrs; ptrs+=off;
            if (is_first) {
              const T *nptrs = ptrs - off; cur = val;
              for (int q = s - 2; q>0; --q) { nptrs-=off; const T nval = *nptrs; if (nval<cur) cur = nval; }
              nptrs-=off; const T nval = *nptrs; if (nval<cur) { cur = nval; is_first = true; } else is_first = false;
            } else { if (val<=cur) cur = val; else if (cur==*(ptrs-s*off)) is_first = true; }
            *(ptrd++) = cur;
          }
          ptrd = ptrde; ptrs = ptrse; cur = *ptrs; ptrs-=off;
          for (int p = s1; p>0 && ptrs>=ptrsb; --p) { const T val = *ptrs; ptrs-=off; if (val<cur) cur = val; } *(ptrd--) = cur;
          for (int p = s2-1; p>0 && ptrd>=ptrdb; --p) { const T val = *ptrs; if (ptrs>ptrsb) ptrs-=off; if (val<cur) cur = val; *(ptrd--) = cur; }
          T *pd = data(0,y,z,c); cimg_for(buf,ps,T) { *pd = *ps; pd+=off; }
        }
      }

      if (sy>1 && _height>1) { // Along Y-axis.
        const int L = height(), off = width(), s = (int)sy, _s1 = s/2, _s2 = s - _s1, s1 = _s1>L?L:_s1, s2 = _s2>L?L:_s2;
        CImg<T> buf(L);
        T *const ptrdb = buf._data, *ptrd = ptrdb, *const ptrde = buf._data + L - 1;
        cimg_forXZC(*this,x,z,c) {
          const T *const ptrsb = data(x,0,z,c), *ptrs = ptrsb, *const ptrse = ptrs + L*off - off;
          ptrd = buf._data; T cur = *ptrs; ptrs+=off; bool is_first = true;
          for (int p = s2-1; p>0 && ptrs<=ptrse; --p) { const T val = *ptrs; ptrs+=off; if (val<=cur) { cur = val; is_first = false; }} *(ptrd++) = cur;
          for (int p = s1; p>0 && ptrd<=ptrde; --p) { const T val = *ptrs; if (ptrs<ptrse) ptrs+=off; if (val<=cur) { cur = val; is_first = false; } *(ptrd++) = cur; }
          for (int p = L - s - 1; p>0; --p) {
            const T val = *ptrs; ptrs+=off;
            if (is_first) {
              const T *nptrs = ptrs - off; cur = val;
              for (int q = s - 2; q>0; --q) { nptrs-=off; const T nval = *nptrs; if (nval<cur) cur = nval; }
              nptrs-=off; const T nval = *nptrs; if (nval<cur) { cur = nval; is_first = true; } else is_first = false;
            } else { if (val<=cur) cur = val; else if (cur==*(ptrs-s*off)) is_first = true; }
            *(ptrd++) = cur;
          }
          ptrd = ptrde; ptrs = ptrse; cur = *ptrs; ptrs-=off;
          for (int p = s1; p>0 && ptrs>=ptrsb; --p) { const T val = *ptrs; ptrs-=off; if (val<cur) cur = val; } *(ptrd--) = cur;
          for (int p = s2-1; p>0 && ptrd>=ptrdb; --p) { const T val = *ptrs; if (ptrs>ptrsb) ptrs-=off; if (val<cur) cur = val; *(ptrd--) = cur; }
          T *pd = data(x,0,z,c); cimg_for(buf,ps,T) { *pd = *ps; pd+=off; }
        }
      }

      if (sz>1 && _depth>1) { // Along Z-axis.
        const int L = depth(), off = width()*height(), s = (int)sz, _s1 = s/2, _s2 = s - _s1, s1 = _s1>L?L:_s1, s2 = _s2>L?L:_s2;
        CImg<T> buf(L);
        T *const ptrdb = buf._data, *ptrd = ptrdb, *const ptrde = buf._data + L - 1;
        cimg_forXYC(*this,x,y,c) {
          const T *const ptrsb = data(x,y,0,c), *ptrs = ptrsb, *const ptrse = ptrs + L*off - off;
          ptrd = buf._data; T cur = *ptrs; ptrs+=off; bool is_first = true;
          for (int p = s2-1; p>0 && ptrs<=ptrse; --p) { const T val = *ptrs; ptrs+=off; if (val<=cur) { cur = val; is_first = false; }} *(ptrd++) = cur;
          for (int p = s1; p>0 && ptrd<=ptrde; --p) { const T val = *ptrs; if (ptrs<ptrse) ptrs+=off; if (val<=cur) { cur = val; is_first = false; } *(ptrd++) = cur; }
          for (int p = L - s - 1; p>0; --p) {
            const T val = *ptrs; ptrs+=off;
            if (is_first) {
              const T *nptrs = ptrs - off; cur = val;
              for (int q = s - 2; q>0; --q) { nptrs-=off; const T nval = *nptrs; if (nval<cur) cur = nval; }
              nptrs-=off; const T nval = *nptrs; if (nval<cur) { cur = nval; is_first = true; } else is_first = false;
            } else { if (val<=cur) cur = val; else if (cur==*(ptrs-s*off)) is_first = true; }
            *(ptrd++) = cur;
          }
          ptrd = ptrde; ptrs = ptrse; cur = *ptrs; ptrs-=off;
          for (int p = s1; p>0 && ptrs>=ptrsb; --p) { const T val = *ptrs; ptrs-=off; if (val<cur) cur = val; } *(ptrd--) = cur;
          for (int p = s2-1; p>0 && ptrd>=ptrdb; --p) { const T val = *ptrs; if (ptrs>ptrsb) ptrs-=off; if (val<cur) cur = val; *(ptrd--) = cur; }
          T *pd = data(x,y,0,c); cimg_for(buf,ps,T) { *pd = *ps; pd+=off; }
        }
      }
      return *this;
    }

    //! Erode image by a rectangular structuring element of specified size \newinstance.
    CImg<T> get_erode(const unsigned int sx, const unsigned int sy, const unsigned int sz=1) const {
      return (+*this).erode(sx,sy,sz);
    }

    //! Erode the image by a square structuring element of specified size.
    /**
       \param s Size of the structuring element.
    **/
    CImg<T>& erode(const unsigned int s) {
      return erode(s,s,s);
    }

    //! Erode the image by a square structuring element of specified size \newinstance.
    CImg<T> get_erode(const unsigned int s) const {
      return (+*this).erode(s);
    }

    //! Dilate image by a structuring element.
    /**
       \param mask Structuring element.
       \param boundary_conditions Boundary conditions.
       \param is_normalized Tells if the erosion is locally normalized.
    **/
    template<typename t>
    CImg<T>& dilate(const CImg<t>& mask, const unsigned int boundary_conditions=1, const bool is_normalized=false) {
      if (is_empty() || !mask) return *this;
      return get_dilate(mask,boundary_conditions,is_normalized).move_to(*this);
    }

    //! Dilate image by a structuring element \newinstance.
    template<typename t>
    CImg<_cimg_Tt> get_dilate(const CImg<t>& mask, const unsigned int boundary_conditions=1,
                              const bool is_normalized=false) const {
      if (is_empty() || !mask) return *this;
      typedef _cimg_Tt Tt;
      CImg<Tt> res(_width,_height,_depth,_spectrum);
      const int
        mx2 = mask.width()/2, my2 = mask.height()/2, mz2 = mask.depth()/2,
        mx1 = mx2 - 1 + (mask.width()%2), my1 = my2 - 1 + (mask.height()%2), mz1 = mz2 - 1 + (mask.depth()%2),
        mxe = width() - mx2, mye = height() - my2, mze = depth() - mz2;
      cimg_forC(*this,c) {
        const CImg<T> _img = get_shared_channel(c%_spectrum);
        const CImg<t> _mask = mask.get_shared_channel(c%mask._spectrum);
        if (is_normalized) { // Normalized dilation.
          for (int z = mz1; z<mze; ++z)
            for (int y = my1; y<mye; ++y)
              for (int x = mx1; x<mxe; ++x) {
                Tt max_val = cimg::type<Tt>::min();
                for (int zm = -mz1; zm<=mz2; ++zm)
                  for (int ym = -my1; ym<=my2; ++ym)
                    for (int xm = -mx1; xm<=mx2; ++xm) {
                      const t mval = _mask(mx1+xm,my1+ym,mz1+zm);
                      const Tt cval = (Tt)(_img(x+xm,y+ym,z+zm) - mval);
                      if (mval && cval>max_val) max_val = cval;
                    }
                res(x,y,z,c) = max_val;
              }
          if (boundary_conditions)
            cimg_forYZ(res,y,z)
              for (int x = 0; x<width(); (y<my1 || y>=mye || z<mz1 || z>=mze)?++x:((x<mx1-1 || x>=mxe)?++x:(x=mxe))) {
                Tt max_val = cimg::type<Tt>::min();
                for (int zm = -mz1; zm<=mz2; ++zm)
                  for (int ym = -my1; ym<=my2; ++ym)
                    for (int xm = -mx1; xm<=mx2; ++xm) {
                      const t mval = _mask(mx1+xm,my1+ym,mz1+zm);
                      const Tt cval = (Tt)(_img._atXYZ(x+xm,y+ym,z+zm) - mval);
                      if (mval && cval>max_val) max_val = cval;
                    }
                res(x,y,z,c) = max_val;
              }
          else
            cimg_forYZ(*this,y,z)
              for (int x = 0; x<width(); (y<my1 || y>=mye || z<mz1 || z>=mze)?++x:((x<mx1-1 || x>=mxe)?++x:(x=mxe))) {
                Tt max_val = cimg::type<Tt>::min();
                for (int zm = -mz1; zm<=mz2; ++zm)
                  for (int ym = -my1; ym<=my2; ++ym)
                    for (int xm = -mx1; xm<=mx2; ++xm) {
                      const t mval = _mask(mx1+xm,my1+ym,mz1+zm);
                      const Tt cval = (Tt)(_img.atXYZ(x+xm,y+ym,z+zm,0,0) - mval);
                      if (mval && cval>max_val) max_val = cval;
                    }
                res(x,y,z,c) = max_val;
              }
        } else { // Classical dilation.
          for (int z = mz1; z<mze; ++z)
            for (int y = my1; y<mye; ++y)
              for (int x = mx1; x<mxe; ++x) {
                Tt max_val = cimg::type<Tt>::min();
                for (int zm = -mz1; zm<=mz2; ++zm)
                  for (int ym = -my1; ym<=my2; ++ym)
                    for (int xm = -mx1; xm<=mx2; ++xm) {
                      const Tt cval = (Tt)_img(x+xm,y+ym,z+zm);
                      if (_mask(mx1+xm,my1+ym,mz1+zm) && cval>max_val) max_val = cval;
                    }
                res(x,y,z,c) = max_val;
              }
          if (boundary_conditions)
            cimg_forYZ(res,y,z)
              for (int x = 0; x<width(); (y<my1 || y>=mye || z<mz1 || z>=mze)?++x:((x<mx1-1 || x>=mxe)?++x:(x=mxe))) {
                Tt max_val = cimg::type<Tt>::min();
                for (int zm = -mz1; zm<=mz2; ++zm)
                  for (int ym = -my1; ym<=my2; ++ym)
                    for (int xm = -mx1; xm<=mx2; ++xm) {
                      const T cval = (Tt)_img._atXYZ(x+xm,y+ym,z+zm);
                      if (_mask(mx1+xm,my1+ym,mz1+zm) && cval>max_val) max_val = cval;
                    }
                res(x,y,z,c) = max_val;
              }
          else
            cimg_forYZ(res,y,z)
              for (int x = 0; x<width(); (y<my1 || y>=mye || z<mz1 || z>=mze)?++x:((x<mx1-1 || x>=mxe)?++x:(x=mxe))) {
                Tt max_val = cimg::type<Tt>::min();
                for (int zm = -mz1; zm<=mz2; ++zm)
                  for (int ym = -my1; ym<=my2; ++ym)
                    for (int xm = -mx1; xm<=mx2; ++xm) {
                      const T cval = (Tt)_img.atXYZ(x+xm,y+ym,z+zm,0,0);
                      if (_mask(mx1+xm,my1+ym,mz1+zm) && cval>max_val) max_val = cval;
                    }
                res(x,y,z,c) = max_val;
              }
        }
      }
      return res;
    }

    //! Dilate image by a rectangular structuring element of specified size.
    /**
       \param sx Width of the structuring element.
       \param sy Height of the structuring element.
       \param sz Depth of the structuring element.
    **/
    CImg<T>& dilate(const unsigned int sx, const unsigned int sy, const unsigned int sz=1) {
      if (is_empty() || (sx==1 && sy==1 && sz==1)) return *this;
      if (sx>1 && _width>1) { // Along X-axis.
        const int L = width(), off = 1, s = (int)sx, _s2 = s/2 + 1, _s1 = s - _s2, s1 = _s1>L?L:_s1, s2 = _s2>L?L:_s2;
        CImg<T> buf(L);
        T *const ptrdb = buf._data, *ptrd = ptrdb, *const ptrde = buf._data + L - 1;
        cimg_forYZC(*this,y,z,c) {
          const T *const ptrsb = data(0,y,z,c), *ptrs = ptrsb, *const ptrse = ptrs + L*off - off;
          ptrd = buf._data; T cur = *ptrs; ptrs+=off; bool is_first = true;
          for (int p = s2-1; p>0 && ptrs<=ptrse; --p) { const T val = *ptrs; ptrs+=off; if (val>=cur) { cur = val; is_first = false; }} *(ptrd++) = cur;
          for (int p = s1; p>0 && ptrd<=ptrde; --p) { const T val = *ptrs; if (ptrs<ptrse) ptrs+=off; if (val>=cur) { cur = val; is_first = false; } *(ptrd++) = cur; }
          for (int p = L - s - 1; p>0; --p) {
            const T val = *ptrs; ptrs+=off;
            if (is_first) {
              const T *nptrs = ptrs - off; cur = val;
              for (int q = s - 2; q>0; --q) { nptrs-=off; const T nval = *nptrs; if (nval>cur) cur = nval; }
              nptrs-=off; const T nval = *nptrs; if (nval>cur) { cur = nval; is_first = true; } else is_first = false;
            } else { if (val>=cur) cur = val; else if (cur==*(ptrs-s*off)) is_first = true; }
            *(ptrd++) = cur;
          }
          ptrd = ptrde; ptrs = ptrse; cur = *ptrs; ptrs-=off;
          for (int p = s1; p>0 && ptrs>=ptrsb; --p) { const T val = *ptrs; ptrs-=off; if (val>cur) cur = val; } *(ptrd--) = cur;
          for (int p = s2-1; p>0 && ptrd>=ptrdb; --p) { const T val = *ptrs; if (ptrs>ptrsb) ptrs-=off; if (val>cur) cur = val; *(ptrd--) = cur; }
          T *pd = data(0,y,z,c); cimg_for(buf,ps,T) { *pd = *ps; pd+=off; }
        }
      }

      if (sy>1 && _height>1) { // Along Y-axis.
        const int L = height(), off = width(), s = (int)sy, _s2 = s/2 + 1, _s1 = s - _s2, s1 = _s1>L?L:_s1, s2 = _s2>L?L:_s2;
        CImg<T> buf(L);
        T *const ptrdb = buf._data, *ptrd = ptrdb, *const ptrde = buf._data + L - 1;
        cimg_forXZC(*this,x,z,c) {
          const T *const ptrsb = data(x,0,z,c), *ptrs = ptrsb, *const ptrse = ptrs + L*off - off;
          ptrd = buf._data; T cur = *ptrs; ptrs+=off; bool is_first = true;
          for (int p = s2-1; p>0 && ptrs<=ptrse; --p) { const T val = *ptrs; ptrs+=off; if (val>=cur) { cur = val; is_first = false; }} *(ptrd++) = cur;
          for (int p = s1; p>0 && ptrd<=ptrde; --p) { const T val = *ptrs; if (ptrs<ptrse) ptrs+=off; if (val>=cur) { cur = val; is_first = false; } *(ptrd++) = cur; }
          for (int p = L - s - 1; p>0; --p) {
            const T val = *ptrs; ptrs+=off;
            if (is_first) {
              const T *nptrs = ptrs - off; cur = val;
              for (int q = s - 2; q>0; --q) { nptrs-=off; const T nval = *nptrs; if (nval>cur) cur = nval; }
              nptrs-=off; const T nval = *nptrs; if (nval>cur) { cur = nval; is_first = true; } else is_first = false;
            } else { if (val>=cur) cur = val; else if (cur==*(ptrs-s*off)) is_first = true; }
            *(ptrd++) = cur;
          }
          ptrd = ptrde; ptrs = ptrse; cur = *ptrs; ptrs-=off;
          for (int p = s1; p>0 && ptrs>=ptrsb; --p) { const T val = *ptrs; ptrs-=off; if (val>cur) cur = val; } *(ptrd--) = cur;
          for (int p = s2-1; p>0 && ptrd>=ptrdb; --p) { const T val = *ptrs; if (ptrs>ptrsb) ptrs-=off; if (val>cur) cur = val; *(ptrd--) = cur; }
          T *pd = data(x,0,z,c); cimg_for(buf,ps,T) { *pd = *ps; pd+=off; }
        }
      }

      if (sz>1 && _depth>1) { // Along Z-axis.
        const int L = depth(), off = width()*height(), s = (int)sz, _s2 = s/2 + 1, _s1 = s - _s2, s1 = _s1>L?L:_s1, s2 = _s2>L?L:_s2;
        CImg<T> buf(L);
        T *const ptrdb = buf._data, *ptrd = ptrdb, *const ptrde = buf._data + L - 1;
        cimg_forXYC(*this,x,y,c) {
          const T *const ptrsb = data(x,y,0,c), *ptrs = ptrsb, *const ptrse = ptrs + L*off - off;
          ptrd = buf._data; T cur = *ptrs; ptrs+=off; bool is_first = true;
          for (int p = s2-1; p>0 && ptrs<=ptrse; --p) { const T val = *ptrs; ptrs+=off; if (val>=cur) { cur = val; is_first = false; }} *(ptrd++) = cur;
          for (int p = s1; p>0 && ptrd<=ptrde; --p) { const T val = *ptrs; if (ptrs<ptrse) ptrs+=off; if (val>=cur) { cur = val; is_first = false; } *(ptrd++) = cur; }
          for (int p = L - s - 1; p>0; --p) {
            const T val = *ptrs; ptrs+=off;
            if (is_first) {
              const T *nptrs = ptrs - off; cur = val;
              for (int q = s - 2; q>0; --q) { nptrs-=off; const T nval = *nptrs; if (nval>cur) cur = nval; }
              nptrs-=off; const T nval = *nptrs; if (nval>cur) { cur = nval; is_first = true; } else is_first = false;
            } else { if (val>=cur) cur = val; else if (cur==*(ptrs-s*off)) is_first = true; }
            *(ptrd++) = cur;
          }
          ptrd = ptrde; ptrs = ptrse; cur = *ptrs; ptrs-=off;
          for (int p = s1; p>0 && ptrs>=ptrsb; --p) { const T val = *ptrs; ptrs-=off; if (val>cur) cur = val; } *(ptrd--) = cur;
          for (int p = s2-1; p>0 && ptrd>=ptrdb; --p) { const T val = *ptrs; if (ptrs>ptrsb) ptrs-=off; if (val>cur) cur = val; *(ptrd--) = cur; }
          T *pd = data(x,y,0,c); cimg_for(buf,ps,T) { *pd = *ps; pd+=off; }
        }
      }
      return *this;
    }

    //! Dilate image by a rectangular structuring element of specified size \newinstance.
    CImg<T> get_dilate(const unsigned int sx, const unsigned int sy, const unsigned int sz=1) const {
      return (+*this).dilate(sx,sy,sz);
    }

    //! Dilate image by a square structuring element of specified size.
    /**
       \param s Size of the structuring element.
    **/
    CImg<T>& dilate(const unsigned int s) {
      return dilate(s,s,s);
    }

    //! Dilate image by a square structuring element of specified size \newinstance.
    CImg<T> get_dilate(const unsigned int s) const {
      return (+*this).dilate(s);
    }

    //! Compute watershed transform.
    /**
       \param priority Priority map.
       \param fill_lines Tells if watershed lines must be filled or not.
       \note Non-zero values of the instance instance are propagated to zero-valued ones according to specified the priority map.
    **/
    template<typename t>
    CImg<T>& watershed(const CImg<t>& priority, const bool fill_lines=true) {
      if (is_empty()) return *this;
      if (!is_sameXYZ(priority))
        throw CImgArgumentException(_cimg_instance
                                    "watershed(): image instance and specified priority (%u,%u,%u,%u,%p) have different dimensions.",
                                    cimg_instance,priority._width,priority._height,priority._depth,priority._spectrum,priority._data);
      if (_spectrum!=1) { cimg_forC(*this,c) get_shared_channel(c).watershed(priority.get_shared_channel(c%priority._spectrum),fill_lines); return *this; }

      CImg<boolT> is_queued(_width,_height,_depth,1,0);
      CImg<typename cimg::superset2<T,t,int>::type> Q;
      unsigned int sizeQ = 0;

      // Find seed points and insert them in priority queue.
      const T *ptrs = _data;
      cimg_forXYZ(*this,x,y,z) if (*(ptrs++)) {
        if (x-1>=0 && !(*this)(x-1,y,z))       Q._priority_queue_insert(is_queued,sizeQ,priority(x-1,y,z),x-1,y,z);
        if (x+1<width() && !(*this)(x+1,y,z))  Q._priority_queue_insert(is_queued,sizeQ,priority(x+1,y,z),x+1,y,z);
        if (y-1>=0 && !(*this)(x,y-1,z))       Q._priority_queue_insert(is_queued,sizeQ,priority(x,y-1,z),x,y-1,z);
        if (y+1<height() && !(*this)(x,y+1,z)) Q._priority_queue_insert(is_queued,sizeQ,priority(x,y+1,z),x,y+1,z);
        if (z-1>=0 && !(*this)(x,y,z-1))       Q._priority_queue_insert(is_queued,sizeQ,priority(x,y,z-1),x,y,z-1);
        if (z+1<depth() && !(*this)(x,y,z+1))  Q._priority_queue_insert(is_queued,sizeQ,priority(x,y,z+1),x,y,z+1);
      }

      // Start watershed computation.
      while (sizeQ) {

        // Get and remove point with maximal priority from the queue.
        const int x = (int)Q(0,1), y = (int)Q(0,2), z = (int)Q(0,3);
        Q._priority_queue_remove(sizeQ);

        // Check labels of the neighbors.
        bool is_same_label = true;
        unsigned int label = 0;
        if (x-1>=0) {
          if ((*this)(x-1,y,z)) { if (!label) label = (unsigned int)(*this)(x-1,y,z); else if (label!=(*this)(x-1,y,z)) is_same_label = false; }
          else Q._priority_queue_insert(is_queued,sizeQ,priority(x-1,y,z),x-1,y,z);
        }
        if (x+1<width()) {
          if ((*this)(x+1,y,z)) { if (!label) label = (unsigned int)(*this)(x+1,y,z); else if (label!=(*this)(x+1,y,z)) is_same_label = false; }
          else Q._priority_queue_insert(is_queued,sizeQ,priority(x+1,y,z),x+1,y,z);
        }
        if (y-1>=0) {
          if ((*this)(x,y-1,z)) { if (!label) label = (unsigned int)(*this)(x,y-1,z); else if (label!=(*this)(x,y-1,z)) is_same_label = false; }
          else Q._priority_queue_insert(is_queued,sizeQ,priority(x,y-1,z),x,y-1,z);
        }
        if (y+1<height()) {
          if ((*this)(x,y+1,z)) { if (!label) label = (unsigned int)(*this)(x,y+1,z); else if (label!=(*this)(x,y+1,z)) is_same_label = false; }
          else Q._priority_queue_insert(is_queued,sizeQ,priority(x,y+1,z),x,y+1,z);
        }
        if (z-1>=0) {
          if ((*this)(x,y,z-1)) { if (!label) label = (unsigned int)(*this)(x,y,z-1); else if (label!=(*this)(x,y,z-1)) is_same_label = false; }
          else Q._priority_queue_insert(is_queued,sizeQ,priority(x,y,z-1),x,y,z-1);
        }
        if (z+1<depth()) {
          if ((*this)(x,y,z+1)) { if (!label) label = (unsigned int)(*this)(x,y,z+1); else if (label!=(*this)(x,y,z+1)) is_same_label = false; }
          else Q._priority_queue_insert(is_queued,sizeQ,priority(x,y,z+1),x,y,z+1);
        }
        if (is_same_label) (*this)(x,y,z) = (T)label;
      }

      // Fill lines.
      if (fill_lines) {

        // Sort all non-labeled pixels with labeled neighbors.
        is_queued = false;
        const T *ptrs = _data;
        cimg_forXYZ(*this,x,y,z) if (!*(ptrs++) &&
                                     ((x-1>=0 && (*this)(x-1,y,z)) || (x+1<width() && (*this)(x+1,y,z)) ||
                                      (y-1>=0 && (*this)(x,y-1,z)) || (y+1<height() && (*this)(x,y+1,z)) ||
                                      (z-1>=0 && (*this)(x,y,z-1)) || (z+1>depth() && (*this)(x,y,z+1))))
          Q._priority_queue_insert(is_queued,sizeQ,priority(x,y,z),x,y,z);

        // Start line filling process.
        while (sizeQ) {
          const int x = (int)Q(0,1), y = (int)Q(0,2), z = (int)Q(0,3);
          Q._priority_queue_remove(sizeQ);
          t pmax = cimg::type<t>::min();
          int xmax = 0, ymax = 0, zmax = 0;
          if (x-1>=0) {
            if ((*this)(x-1,y,z)) { if (priority(x-1,y,z)>pmax) { pmax = priority(x-1,y,z); xmax = x-1; ymax = y; zmax = z; }}
            else Q._priority_queue_insert(is_queued,sizeQ,priority(x-1,y,z),x-1,y,z);
          }
          if (x+1<width()) {
            if ((*this)(x+1,y,z)) { if (priority(x+1,y,z)>pmax) { pmax = priority(x+1,y,z); xmax = x+1; ymax = y; zmax = z; }}
            else Q._priority_queue_insert(is_queued,sizeQ,priority(x+1,y,z),x+1,y,z);
          }
          if (y-1>=0) {
            if ((*this)(x,y-1,z)) { if (priority(x,y-1,z)>pmax) { pmax = priority(x,y-1,z); xmax = x; ymax = y-1; zmax = z; }}
            else Q._priority_queue_insert(is_queued,sizeQ,priority(x,y-1,z),x,y-1,z);
          }
          if (y+1<height()) {
            if ((*this)(x,y+1,z)) { if (priority(x,y+1,z)>pmax) { pmax = priority(x,y+1,z); xmax = x; ymax = y+1; zmax = z; }}
            else Q._priority_queue_insert(is_queued,sizeQ,priority(x,y+1,z),x,y+1,z);
          }
          if (z-1>=0) {
            if ((*this)(x,y,z-1)) { if (priority(x,y,z-1)>pmax) { pmax = priority(x,y,z-1); xmax = x; ymax = y; zmax = z-1; }}
            else Q._priority_queue_insert(is_queued,sizeQ,priority(x,y,z-1),x,y,z-1);
          }
          if (z+1<depth()) {
            if ((*this)(x,y,z+1)) { if (priority(x,y,z+1)>pmax) { pmax = priority(x,y,z+1); xmax = x; ymax = y; zmax = z+1; }}
            else Q._priority_queue_insert(is_queued,sizeQ,priority(x,y,z+1),x,y,z+1);
          }
          (*this)(x,y,z) = (*this)(xmax,ymax,zmax);
        }
      }
      return *this;
    }

    //! Compute watershed transform \newinstance.
    template<typename t>
    CImg<T> get_watershed(const CImg<t>& priority, const bool fill_lines=true) const {
      return (+*this).watershed(priority,fill_lines);
    }

    // [internal] Insert/Remove items in priority queue, for watershed/distance transforms.
    template<typename t>
    bool _priority_queue_insert(CImg<boolT>& is_queued, unsigned int& siz, const t value, const unsigned int x, const unsigned int y, const unsigned int z) {
      if (is_queued(x,y,z)) return false;
      is_queued(x,y,z) = true;
      if (++siz>=_width) { if (!is_empty()) resize(_width*2,4,1,1,0); else assign(64,4); }
      (*this)(siz-1,0) = (T)value; (*this)(siz-1,1) = (T)x; (*this)(siz-1,2) = (T)y; (*this)(siz-1,3) = (T)z;
      for (unsigned int pos = siz - 1, par = 0; pos && value>(*this)(par=(pos+1)/2-1,0); pos = par) {
        cimg::swap((*this)(pos,0),(*this)(par,0)); cimg::swap((*this)(pos,1),(*this)(par,1));
        cimg::swap((*this)(pos,2),(*this)(par,2)); cimg::swap((*this)(pos,3),(*this)(par,3));
      }
      return true;
    }

    CImg<T>& _priority_queue_remove(unsigned int& siz) {
      (*this)(0,0) = (*this)(--siz,0); (*this)(0,1) = (*this)(siz,1); (*this)(0,2) = (*this)(siz,2); (*this)(0,3) = (*this)(siz,3);
      const float value = (*this)(0,0);
      for (unsigned int pos = 0, left = 0, right = 0;
           ((right=2*(pos+1),(left=right-1))<siz && value<(*this)(left,0)) || (right<siz && value<(*this)(right,0));) {
        if (right<siz) {
          if ((*this)(left,0)>(*this)(right,0)) {
            cimg::swap((*this)(pos,0),(*this)(left,0)); cimg::swap((*this)(pos,1),(*this)(left,1));
            cimg::swap((*this)(pos,2),(*this)(left,2)); cimg::swap((*this)(pos,3),(*this)(left,3));
            pos = left;
          } else {
            cimg::swap((*this)(pos,0),(*this)(right,0)); cimg::swap((*this)(pos,1),(*this)(right,1));
            cimg::swap((*this)(pos,2),(*this)(right,2)); cimg::swap((*this)(pos,3),(*this)(right,3));
            pos = right;
          }
        } else {
          cimg::swap((*this)(pos,0),(*this)(left,0)); cimg::swap((*this)(pos,1),(*this)(left,1));
          cimg::swap((*this)(pos,2),(*this)(left,2)); cimg::swap((*this)(pos,3),(*this)(left,3));
          pos = left;
        }
      }
      return *this;
    }

    //! Apply recursive Deriche filter.
    /**
       \param sigma Standard deviation of the filter.
       \param order Order of the filter. Can be <tt>{ 0=smooth-filter | 1=1st-derivative | 2=2nd-derivative }</tt>.
       \param axis Axis along which the filter is computed. Can be <tt>{ 'x' | 'y' | 'z' | 'c' }</tt>.
       \param boundary_conditions Boundary conditions. Can be <tt>{ 0=dirichlet | 1=neumann }</tt>.
    **/
    CImg<T>& deriche(const float sigma, const int order=0, const char axis='x', const bool boundary_conditions=true) {
#define _cimg_deriche_apply \
  Tfloat *ptrY = Y._data, yb = 0, yp = 0; \
  T xp = (T)0; \
  if (boundary_conditions) { xp = *ptrX; yb = yp = (Tfloat)(coefp*xp); } \
  for (int m = 0; m<N; ++m) { \
    const T xc = *ptrX; ptrX+=off; \
    const Tfloat yc = *(ptrY++) = (Tfloat)(a0*xc + a1*xp - b1*yp - b2*yb); \
    xp = xc; yb = yp; yp = yc; \
  } \
  T xn = (T)0, xa = (T)0; \
  Tfloat yn = 0, ya = 0; \
  if (boundary_conditions) { xn = xa = *(ptrX-off); yn = ya = (Tfloat)coefn*xn; } \
  for (int n = N-1; n>=0; --n) { \
    const T xc = *(ptrX-=off); \
    const Tfloat yc = (Tfloat)(a2*xn + a3*xa - b1*yn - b2*ya); \
    xa = xn; xn = xc; ya = yn; yn = yc; \
    *ptrX = (T)(*(--ptrY)+yc); \
  }
      const char naxis = cimg::uncase(axis);
      const float nsigma = sigma>=0?sigma:-sigma*(naxis=='x'?_width:naxis=='y'?_height:naxis=='z'?_depth:_spectrum)/100;
      if (is_empty() || (nsigma<0.1f && !order)) return *this;
      const float
        nnsigma = nsigma<0.1f?0.1f:nsigma,
        alpha = 1.695f/nnsigma,
        ema = (float)std::exp(-alpha),
        ema2 = (float)std::exp(-2*alpha),
        b1 = -2*ema,
        b2 = ema2;
      float a0 = 0, a1 = 0, a2 = 0, a3 = 0, coefp = 0, coefn = 0;
      switch (order) {
      case 0 : {
        const float k = (1-ema)*(1-ema)/(1+2*alpha*ema-ema2);
        a0 = k;
        a1 = k*(alpha-1)*ema;
        a2 = k*(alpha+1)*ema;
        a3 = -k*ema2;
      } break;
      case 1 : {
        const float k = -(1-ema)*(1-ema)*(1-ema)/(2*(ema+1)*ema);
	a0 = a3 = 0;
	a1 = k*ema;
        a2 = -a1;
      } break;
      case 2 : {
        const float
          ea = (float)std::exp(-alpha),
          k = -(ema2-1)/(2*alpha*ema),
          kn = (-2*(-1+3*ea-3*ea*ea+ea*ea*ea)/(3*ea+1+3*ea*ea+ea*ea*ea));
        a0 = kn;
        a1 = -kn*(1+k*alpha)*ema;
        a2 = kn*(1-k*alpha)*ema;
        a3 = -kn*ema2;
      } break;
      default :
        throw CImgArgumentException(_cimg_instance
                                    "deriche(): Invalid specified filter order %u "
                                    "(should be { 0=smoothing | 1=1st-derivative | 2=2nd-derivative }).",
                                    cimg_instance,
                                    order);
      }
      coefp = (a0+a1)/(1+b1+b2);
      coefn = (a2+a3)/(1+b1+b2);
      switch (naxis) {
      case 'x' : {
        const int N = _width;
        const unsigned long off = 1U;
        CImg<Tfloat> Y(N);
        cimg_forYZC(*this,y,z,c) { T *ptrX = data(0,y,z,c); _cimg_deriche_apply; }
      } break;
      case 'y' : {
        const int N = _height;
        const unsigned long off = (unsigned long)_width;
        CImg<Tfloat> Y(N);
        cimg_forXZC(*this,x,z,c) { T *ptrX = data(x,0,z,c); _cimg_deriche_apply; }
      } break;
      case 'z' : {
        const int N = _depth;
        const unsigned long off = (unsigned long)_width*_height;
        CImg<Tfloat> Y(N);
        cimg_forXYC(*this,x,y,c) { T *ptrX = data(x,y,0,c); _cimg_deriche_apply; }
      } break;
      default : {
        const int N = _spectrum;
        const unsigned long off = (unsigned long)_width*_height*_depth;
        CImg<Tfloat> Y(N);
        cimg_forXYZ(*this,x,y,z) { T *ptrX = data(x,y,z,0); _cimg_deriche_apply; }
      }
      }
      return *this;
    }

    //! Apply recursive Deriche filter \newinstance.
    CImg<Tfloat> get_deriche(const float sigma, const int order=0, const char axis='x', const bool boundary_conditions=true) const {
      return CImg<Tfloat>(*this,false).deriche(sigma,order,axis,boundary_conditions);
    }

    // [internal] Apply a recursive filter (used by CImg<T>::vanvliet()).
    /**
       \param ptr the pointer of the data
       \param filter the coefficient of the filter in the following order [n,n-1,n-2,n-3].
       \param N size of the data
       \param off the offset between two data point
       \param order the order of the filter 0 (smoothing), 1st derivtive, 2nd derivative, 3rd derivative
       \param boundary_conditions Boundary conditions. Can be <tt>{ 0=dirichlet | 1=neumann }</tt>.
       \note dirichlet boundary conditions have a strange behavior. And
       boundary condition should be corrected using Bill Triggs method (IEEE trans on Sig Proc 2005).
    **/
    template <int K>
    static void _cimg_recursive_apply(T *data, const Tfloat filter[], const int N, const unsigned long off, const int order, const bool boundary_conditions) {
      Tfloat val[K];  // res[n,n-1,n-2,n-3,..] or res[n,n+1,n+2,n+3,..]
      switch (order) {
      case 0 : {
        for (int pass = 0; pass<2; ++pass) {
          for (int k = 1; k<K; ++k) val[k] = (Tfloat)(boundary_conditions?*data:0);
          for (int n = 0; n<N; ++n) {
            val[0] = (Tfloat)(*data)*filter[0];
            for (int k = 1; k<K; ++k) val[0]+=val[k]*filter[k];
            *data = (T)val[0];
            if (!pass) data+=off; else data-=off;
            for (int k = K-1; k>0; --k) val[k] = val[k-1];
          }
          if (!pass) data-=off;
        }
      } break;
      case 1 : {
        Tfloat x[3]; // [front,center,back]
        for (int pass = 0; pass<2; ++pass) {
          for (int k = 0; k<3; ++k) x[k] = (Tfloat)(boundary_conditions?*data:0);
          for (int k = 0; k<K; ++k) val[k] = 0;
          for (int n = 0; n<N-1; ++n) {
            if (!pass) {
              x[0] = (Tfloat)*(data+off);
              val[0] = 0.5f * (x[0] - x[2])*filter[0];
            } else val[0] = (Tfloat)(*data)*filter[0];
            for (int k = 1; k<K; ++k) val[0]+=val[k]*filter[k];
            *data = (T)val[0];
            if (!pass) {
              data+=off;
              for (int k = 2; k>0; --k) x[k] = x[k-1];
            } else data-=off;
            for (int k = K-1; k>0; --k) val[k] = val[k-1];
          }
          *data = (T)0;
        }
      } break;
      case 2: {
        Tfloat x[3]; // [front,center,back]
        for (int pass = 0; pass<2; ++pass) {
          for (int k = 0; k<3; ++k) x[k] = (Tfloat)(boundary_conditions?*data:0);
          for (int k = 0; k<K; ++k) val[k] = 0;
          for (int n = 0; n<N-1; ++n) {
            if (!pass) { x[0] = (Tfloat)*(data+off); val[0] = (x[1] - x[2])*filter[0]; }
            else { x[0] = (Tfloat)*(data-off); val[0] = (x[2] - x[1])*filter[0]; }
            for (int k = 1; k<K; ++k) val[0]+=val[k]*filter[k];
            *data = (T)val[0];
            if (!pass) data+=off; else data-=off;
            for (int k = 2; k>0; --k) x[k] = x[k-1];
            for (int k = K-1; k>0; --k) val[k] = val[k-1];
          }
          *data = (T)0;
        }
      } break;
      case 3: {
        Tfloat x[3]; // [front,center,back]
        for (int pass = 0; pass<2; ++pass) {
          for (int k = 0; k<3; ++k) x[k] = (Tfloat)(boundary_conditions?*data:0);
          for (int k = 0; k<K; ++k) val[k] = 0;
          for (int n = 0; n<N-1; ++n) {
            if (!pass) { x[0] = (Tfloat)*(data+off); val[0] = (x[0] - 2*x[1] + x[2])*filter[0]; }
            else { x[0] = (Tfloat)*(data-off); val[0] = 0.5f*(x[2] - x[0])*filter[0]; }
            for (int k = 1; k<K; ++k) val[0]+=val[k]*filter[k];
            *data = (T)val[0];
            if (!pass) data+=off; else data-=off;
            for (int k = 2; k>0; --k) x[k] = x[k-1];
            for (int k = K-1; k>0; --k) val[k] = val[k-1];
          }
          *data = (T)0;
        }
      } break;
      }
    }

    //! Van Vliet recursive Gaussian filter.
    /**
       \param sigma standard deviation of the Gaussian filter
       \param order the order of the filter 0,1,2,3
       \param axis  Axis along which the filter is computed. Can be <tt>{ 'x' | 'y' | 'z' | 'c' }</tt>.
       \param boundary_conditions Boundary conditions. Can be <tt>{ 0=dirichlet | 1=neumann }</tt>.
       \note dirichlet boundary condition has a strange behavior

       Ian T. Young, Lucas J. van Vliet, Recursive implementation of the
       Gaussian filter, Signal Processing, Volume 44, Issue 2, June 1995,
       Pages 139-151,
    **/
    CImg<T>& vanvliet(const float sigma, const int order, const char axis='x', const bool boundary_conditions=true) {
      if (is_empty()) return *this;
      const char naxis = cimg::uncase(axis);
      const float nsigma = sigma>=0?sigma:-sigma*(naxis=='x'?_width:naxis=='y'?_height:naxis=='z'?_depth:_spectrum)/100;
      if (is_empty() || (nsigma<0.1f && !order)) return *this;
      const Tfloat
        nnsigma = nsigma<0.1f?0.1f:nsigma,
        q = (Tfloat)(nnsigma<2.5?3.97156-4.14554*std::sqrt(1-0.2689*nnsigma):0.98711*nnsigma-0.96330),
        b0 = 1.57825f + 2.44413f*q + 1.4281f*q*q + 0.4222205f*q*q*q,
        b1 = (2.44413f*q + 2.85619f*q*q + 1.26661f*q*q*q),
        b2 = -(1.4281f*q*q + 1.26661f*q*q*q),
        b3 = 0.4222205f*q*q*q,
        B = 1.f - (b1 + b2 + b3)/b0;
      Tfloat filter[4];
      filter[0] = B; filter[1] = b1/b0; filter[2] = b2/b0; filter[3] = b3/b0;

      switch (naxis) {
      case 'x' : {
#ifdef cimg_use_openmp
#pragma omp parallel for collapse(3)
#endif
# 24293 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        cimg_forYZC(*this,y,z,c) _cimg_recursive_apply<4>(data(0,y,z,c),filter,_width,1U,order,boundary_conditions);
      } break;
      case 'y' : {
#ifdef cimg_use_openmp
#pragma omp parallel for collapse(3)
#endif
# 24299 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        cimg_forXZC(*this,x,z,c) _cimg_recursive_apply<4>(data(x,0,z,c),filter,_height,(unsigned long)_width,order,boundary_conditions);
      } break;
      case 'z' : {
#ifdef cimg_use_openmp
#pragma omp parallel for collapse(3)
#endif
# 24305 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        cimg_forXYC(*this,x,y,c) _cimg_recursive_apply<4>(data(x,y,0,c),filter,_depth,(unsigned long)(_width*_height),order,boundary_conditions);
      } break;
      default : {
#ifdef cimg_use_openmp
#pragma omp parallel for collapse(3)
#endif
# 24311 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        cimg_forXYZ(*this,x,y,z) _cimg_recursive_apply<4>(data(x,y,z,0),filter,_spectrum,(unsigned long)(_width*_height*_depth),order,boundary_conditions);
      }
      }
      return *this;
    }

    //! Blur image using Van Vliet recursive Gaussian filter. \newinstance.
    CImg<Tfloat> get_vanvliet(const float sigma, const int order, const char axis='x', const bool boundary_conditions=true) const {
      return CImg<Tfloat>(*this,false).vanvliet(sigma,order,axis,boundary_conditions);
    }

    //! Blur image.
    /**
       \param sigma_x Standard deviation of the blur, along the X-axis.
       \param sigma_y Standard deviation of the blur, along the Y-axis.
       \param sigma_z Standard deviation of the blur, along the Z-axis.
       \param boundary_conditions Boundary conditions. Can be <tt>{ false=dirichlet | true=neumann }</tt>.
       \param is_gaussian Tells if the blur uses a gaussian (\c true) or quasi-gaussian (\c false) kernel.
       \note
       - The blur is computed as a 0-order Deriche filter. This is not a gaussian blur.
       - This is a recursive algorithm, not depending on the values of the standard deviations.
       \see deriche(), vanvliet().
    **/
    CImg<T>& blur(const float sigma_x, const float sigma_y, const float sigma_z,
                  const bool boundary_conditions=true, const bool is_gaussian=false) {
      if (!is_empty()) {
        if (is_gaussian) {
          if (_width>1) vanvliet(sigma_x,0,'x',boundary_conditions);
          if (_height>1) vanvliet(sigma_y,0,'y',boundary_conditions);
          if (_depth>1) vanvliet(sigma_z,0,'z',boundary_conditions);
        } else {
          if (_width>1) deriche(sigma_x,0,'x',boundary_conditions);
          if (_height>1) deriche(sigma_y,0,'y',boundary_conditions);
          if (_depth>1) deriche(sigma_z,0,'z',boundary_conditions);
        }
      }
      return *this;
    }

    //! Blur image \newinstance.
    CImg<Tfloat> get_blur(const float sigma_x, const float sigma_y, const float sigma_z,
                          const bool boundary_conditions=true, const bool is_gaussian=false) const {
      return CImg<Tfloat>(*this,false).blur(sigma_x,sigma_y,sigma_z,boundary_conditions,is_gaussian);
    }

    //! Blur image isotropically.
    /**
       \param sigma Standard deviation of the blur.
       \param boundary_conditions Boundary conditions. Can be <tt>{ 0=dirichlet | 1=neumann }</tt>.a
       \see deriche(), vanvliet().
    **/
    CImg<T>& blur(const float sigma, const bool boundary_conditions=true, const bool is_gaussian=false) {
      const float nsigma = sigma>=0?sigma:-sigma*cimg::max(_width,_height,_depth)/100;
      return blur(nsigma,nsigma,nsigma,boundary_conditions,is_gaussian);
    }

    //! Blur image isotropically \newinstance.
    CImg<Tfloat> get_blur(const float sigma, const bool boundary_conditions=true, const bool is_gaussian=false) const {
      return CImg<Tfloat>(*this,false).blur(sigma,boundary_conditions,is_gaussian);
    }

    //! Blur image anisotropically, directed by a field of diffusion tensors.
    /**
       \param G Field of square roots of diffusion tensors/vectors used to drive the smoothing.
       \param amplitude Amplitude of the smoothing.
       \param dl Spatial discretization.
       \param da Angular discretization.
       \param gauss_prec Precision of the diffusion process.
       \param interpolation_type Interpolation scheme. Can be <tt>{ 0=nearest-neighbor | 1=linear | 2=Runge-Kutta }</tt>.
       \param is_fast_approx Tells if a fast approximation of the gaussian function is used or not.
    **/
    template<typename t>
    CImg<T>& blur_anisotropic(const CImg<t>& G,
                              const float amplitude=60, const float dl=0.8f, const float da=30,
                              const float gauss_prec=2, const unsigned int interpolation_type=0,
                              const bool is_fast_approx=1) {

      // Check arguments and init variables
      if (!is_sameXYZ(G) || (G._spectrum!=3 && G._spectrum!=6))
        throw CImgArgumentException(_cimg_instance
                                    "blur_anisotropic(): Invalid specified diffusion tensor field (%u,%u,%u,%u,%p).",
                                    cimg_instance,
                                    G._width,G._height,G._depth,G._spectrum,G._data);

      if (is_empty() || amplitude<=0 || dl<0) return *this;
      const bool is_3d = (G._spectrum==6);
      T val_min, val_max = max_min(val_min);

      if (da<=0) {  // Iterated oriented Laplacians
        CImg<Tfloat> velocity(_width,_height,_depth,_spectrum);
        for (unsigned int iteration = 0; iteration<(unsigned int)amplitude; ++iteration) {
          Tfloat *ptrd = velocity._data, veloc_max = 0;
          if (is_3d) { // 3d version
            CImg_3x3x3(I,Tfloat);
            cimg_forC(*this,c) cimg_for3x3x3(*this,x,y,z,c,I,Tfloat) {
              const Tfloat
                ixx = Incc + Ipcc - 2*Iccc,
                ixy = (Innc + Ippc - Inpc - Ipnc)/4,
                ixz = (Incn + Ipcp - Incp - Ipcn)/4,
                iyy = Icnc + Icpc - 2*Iccc,
                iyz = (Icnn + Icpp - Icnp - Icpn)/4,
                izz = Iccn + Iccp - 2*Iccc,
                veloc = (Tfloat)(G(x,y,z,0)*ixx + 2*G(x,y,z,1)*ixy + 2*G(x,y,z,2)*ixz + G(x,y,z,3)*iyy + 2*G(x,y,z,4)*iyz + G(x,y,z,5)*izz);
              *(ptrd++) = veloc;
              if (veloc>veloc_max) veloc_max = veloc; else if (-veloc>veloc_max) veloc_max = -veloc;
            }
          } else { // 2d version
            CImg_3x3(I,Tfloat);
            cimg_forZC(*this,z,c) cimg_for3x3(*this,x,y,z,c,I,Tfloat) {
              const Tfloat
                ixx = Inc + Ipc - 2*Icc,
                ixy = (Inn + Ipp - Inp - Ipn)/4,
                iyy = Icn + Icp - 2*Icc,
                veloc = (Tfloat)(G(x,y,0,0)*ixx + 2*G(x,y,0,1)*ixy + G(x,y,0,2)*iyy);
              *(ptrd++) = veloc;
              if (veloc>veloc_max) veloc_max = veloc; else if (-veloc>veloc_max) veloc_max = -veloc;
            }
          }
          if (veloc_max>0) *this+=(velocity*=dl/veloc_max);
        }
      } else { // LIC-based smoothing.
        const unsigned long whd = (unsigned long)_width*_height*_depth;
        const float sqrt2amplitude = (float)std::sqrt(2*amplitude);
        const int dx1 = width() - 1, dy1 = height() - 1, dz1 = depth() - 1;
        CImg<Tfloat> res(_width,_height,_depth,_spectrum,0), W(_width,_height,_depth,is_3d?4:3), val(_spectrum);
        int N = 0;
        if (is_3d) { // 3d version
          for (float phi = (180%(int)da)/2.0f; phi<=180; phi+=da) {
            const float phir = (float)(phi*cimg::PI/180), datmp = (float)(da/std::cos(phir)), da2 = datmp<1?360.0f:datmp;
            for (float theta = 0; theta<360; (theta+=da2),++N) {
              const float
                thetar = (float)(theta*cimg::PI/180),
                vx = (float)(std::cos(thetar)*std::cos(phir)),
                vy = (float)(std::sin(thetar)*std::cos(phir)),
                vz = (float)std::sin(phir);
              const t
                *pa = G.data(0,0,0,0), *pb = G.data(0,0,0,1), *pc = G.data(0,0,0,2),
                *pd = G.data(0,0,0,3), *pe = G.data(0,0,0,4), *pf = G.data(0,0,0,5);
              Tfloat *pd0 = W.data(0,0,0,0), *pd1 = W.data(0,0,0,1), *pd2 = W.data(0,0,0,2), *pd3 = W.data(0,0,0,3);
              cimg_forXYZ(G,xg,yg,zg) {
                const t a = *(pa++), b = *(pb++), c = *(pc++), d = *(pd++), e = *(pe++), f = *(pf++);
                const float
                  u = (float)(a*vx + b*vy + c*vz),
                  v = (float)(b*vx + d*vy + e*vz),
                  w = (float)(c*vx + e*vy + f*vz),
                  n = (float)std::sqrt(1e-5+u*u+v*v+w*w),
                  dln = dl/n;
                *(pd0++) = (Tfloat)(u*dln);
                *(pd1++) = (Tfloat)(v*dln);
                *(pd2++) = (Tfloat)(w*dln);
                *(pd3++) = (Tfloat)n;
              }

              Tfloat *ptrd = res._data;
              cimg_forXYZ(*this,x,y,z) {
                val.fill(0);
                const float
                  n = (float)W(x,y,z,3),
                  fsigma = (float)(n*sqrt2amplitude),
                  fsigma2 = 2*fsigma*fsigma,
                  length = gauss_prec*fsigma;
                float
                  S = 0,
                  X = (float)x,
                  Y = (float)y,
                  Z = (float)z;
                switch (interpolation_type) {
                case 0 : { // Nearest neighbor
                  for (float l = 0; l<length && X>=0 && X<=dx1 && Y>=0 && Y<=dy1 && Z>=0 && Z<=dz1; l+=dl) {
                    const int
                      cx = (int)(X+0.5f),
                      cy = (int)(Y+0.5f),
                      cz = (int)(Z+0.5f);
                    const float
                      u = (float)W(cx,cy,cz,0),
                      v = (float)W(cx,cy,cz,1),
                      w = (float)W(cx,cy,cz,2);
                    if (is_fast_approx) { cimg_forC(*this,c) val[c]+=(Tfloat)(*this)(cx,cy,cz,c); ++S; }
                    else {
                      const float coef = (float)std::exp(-l*l/fsigma2);
                      cimg_forC(*this,c) val[c]+=(Tfloat)(coef*(*this)(cx,cy,cz,c));
                      S+=coef;
                    }
                    X+=u; Y+=v; Z+=w;
                  }
                } break;
                case 1 : { // Linear interpolation
                  for (float l = 0; l<length && X>=0 && X<=dx1 && Y>=0 && Y<=dy1 && Z>=0 && Z<=dz1; l+=dl) {
                    const float
                      u = (float)(W._linear_atXYZ(X,Y,Z,0)),
                      v = (float)(W._linear_atXYZ(X,Y,Z,1)),
                      w = (float)(W._linear_atXYZ(X,Y,Z,2));
                    if (is_fast_approx) { cimg_forC(*this,c) val[c]+=(Tfloat)_linear_atXYZ(X,Y,Z,c); ++S; }
                    else {
                      const float coef = (float)std::exp(-l*l/fsigma2);
                      cimg_forC(*this,c) val[c]+=(Tfloat)(coef*_linear_atXYZ(X,Y,Z,c));
                      S+=coef;
                    }
                    X+=u; Y+=v; Z+=w;
                  }
                } break;
                default : { // 2nd order Runge Kutta
                  for (float l = 0; l<length && X>=0 && X<=dx1 && Y>=0 && Y<=dy1 && Z>=0 && Z<=dz1; l+=dl) {
                    const float
                      u0 = (float)(0.5f*W._linear_atXYZ(X,Y,Z,0)),
                      v0 = (float)(0.5f*W._linear_atXYZ(X,Y,Z,1)),
                      w0 = (float)(0.5f*W._linear_atXYZ(X,Y,Z,2)),
                      u = (float)(W._linear_atXYZ(X+u0,Y+v0,Z+w0,0)),
                      v = (float)(W._linear_atXYZ(X+u0,Y+v0,Z+w0,1)),
                      w = (float)(W._linear_atXYZ(X+u0,Y+v0,Z+w0,2));
                    if (is_fast_approx) { cimg_forC(*this,c) val[c]+=(Tfloat)_linear_atXYZ(X,Y,Z,c); ++S; }
                    else {
                      const float coef = (float)std::exp(-l*l/fsigma2);
                      cimg_forC(*this,c) val[c]+=(Tfloat)(coef*_linear_atXYZ(X,Y,Z,c));
                      S+=coef;
                    }
                    X+=u; Y+=v; Z+=w;
                  }
                } break;
                }
                Tfloat *_ptrd = ptrd++;
                if (S>0) cimg_forC(res,c) { *_ptrd+=val[c]/S; _ptrd+=whd; }
                else cimg_forC(res,c) { *_ptrd+=(Tfloat)((*this)(x,y,z,c)); _ptrd+=whd; }
              }
            }
          }
        } else { // 2d LIC algorithm
          for (float theta = (360%(int)da)/2.0f; theta<360; (theta+=da),++N) {
            const float thetar = (float)(theta*cimg::PI/180), vx = (float)(std::cos(thetar)), vy = (float)(std::sin(thetar));
            const t *pa = G.data(0,0,0,0), *pb = G.data(0,0,0,1), *pc = G.data(0,0,0,2);
            Tfloat *pd0 = W.data(0,0,0,0), *pd1 = W.data(0,0,0,1), *pd2 = W.data(0,0,0,2);
            cimg_forXY(G,xg,yg) {
              const t a = *(pa++), b = *(pb++), c = *(pc++);
              const float
                u = (float)(a*vx + b*vy),
                v = (float)(b*vx + c*vy),
                n = (float)std::sqrt(1e-5+u*u+v*v),
                dln = dl/n;
              *(pd0++) = (Tfloat)(u*dln);
              *(pd1++) = (Tfloat)(v*dln);
              *(pd2++) = (Tfloat)n;
            }
            Tfloat *ptrd = res._data;
            cimg_forXY(*this,x,y) {
              val.fill(0);
              const float
                n = (float)W(x,y,0,2),
                fsigma = (float)(n*sqrt2amplitude),
                fsigma2 = 2*fsigma*fsigma,
                length = gauss_prec*fsigma;
              float
                S = 0,
                X = (float)x,
                Y = (float)y;
              switch (interpolation_type) {
              case 0 : { // Nearest-neighbor
                for (float l = 0; l<length && X>=0 && X<=dx1 && Y>=0 && Y<=dy1; l+=dl) {
                  const int
                    cx = (int)(X+0.5f),
                    cy = (int)(Y+0.5f);
                  const float
                    u = (float)W(cx,cy,0,0),
                    v = (float)W(cx,cy,0,1);
                  if (is_fast_approx) { cimg_forC(*this,c) val[c]+=(Tfloat)(*this)(cx,cy,0,c); ++S; }
                  else {
                    const float coef = (float)std::exp(-l*l/fsigma2);
                    cimg_forC(*this,c) val[c]+=(Tfloat)(coef*(*this)(cx,cy,0,c));
                    S+=coef;
                  }
                  X+=u; Y+=v;
                }
              } break;
              case 1 : { // Linear interpolation
                for (float l = 0; l<length && X>=0 && X<=dx1 && Y>=0 && Y<=dy1; l+=dl) {
                  const float
                    u = (float)(W._linear_atXY(X,Y,0,0)),
                    v = (float)(W._linear_atXY(X,Y,0,1));
                  if (is_fast_approx) { cimg_forC(*this,c) val[c]+=(Tfloat)_linear_atXY(X,Y,0,c); ++S; }
                  else {
                    const float coef = (float)std::exp(-l*l/fsigma2);
                    cimg_forC(*this,c) val[c]+=(Tfloat)(coef*_linear_atXY(X,Y,0,c));
                    S+=coef;
                  }
                  X+=u; Y+=v;
                }
              } break;
              default : { // 2nd-order Runge-kutta interpolation
                for (float l = 0; l<length && X>=0 && X<=dx1 && Y>=0 && Y<=dy1; l+=dl) {
                  const float
                    u0 = (float)(0.5f*W._linear_atXY(X,Y,0,0)),
                    v0 = (float)(0.5f*W._linear_atXY(X,Y,0,1)),
                    u = (float)(W._linear_atXY(X+u0,Y+v0,0,0)),
                    v = (float)(W._linear_atXY(X+u0,Y+v0,0,1));
                  if (is_fast_approx) { cimg_forC(*this,c) val[c]+=(Tfloat)_linear_atXY(X,Y,0,c); ++S; }
                  else {
                    const float coef = (float)std::exp(-l*l/fsigma2);
                    cimg_forC(*this,c) val[c]+=(Tfloat)(coef*_linear_atXY(X,Y,0,c));
                    S+=coef;
                  }
                  X+=u; Y+=v;
                }
              }
              }
              Tfloat *_ptrd = ptrd++;
              if (S>0) cimg_forC(res,c) { *_ptrd+=val[c]/S; _ptrd+=whd; }
              else cimg_forC(res,c) { *_ptrd+=(Tfloat)((*this)(x,y,0,c)); _ptrd+=whd; }
            }
          }
        }
        const Tfloat *ptrs = res._data;
        cimg_for(*this,ptrd,T) { const Tfloat val = *(ptrs++)/N; *ptrd = val<val_min?val_min:(val>val_max?val_max:(T)val); }
      }
      return *this;
    }

    //! Blur image anisotropically, directed by a field of diffusion tensors \newinstance.
    template<typename t>
    CImg<T> get_blur_anisotropic(const CImg<t>& G,
                                 const float amplitude=60, const float dl=0.8f, const float da=30,
                                 const float gauss_prec=2, const unsigned int interpolation_type=0,
                                 const bool is_fast_approx=true) const {
      return (+*this).blur_anisotropic(G,amplitude,dl,da,gauss_prec,interpolation_type,is_fast_approx);
    }

    //! Blur image anisotropically, in an edge-preserving way.
    /**
       \param amplitude Amplitude of the smoothing.
       \param sharpness Sharpness.
       \param anisotropy Anisotropy.
       \param alpha Standard deviation of the gradient blur.
       \param sigma Standard deviation of the structure tensor blur.
       \param dl Spatial discretization.
       \param da Angular discretization.
       \param gauss_prec Precision of the diffusion process.
       \param interpolation_type Interpolation scheme. Can be <tt>{ 0=nearest-neighbor | 1=linear | 2=Runge-Kutta }</tt>.
       \param is_fast_approx Tells if a fast approximation of the gaussian function is used or not.
     **/
    CImg<T>& blur_anisotropic(const float amplitude, const float sharpness=0.7f, const float anisotropy=0.6f,
                              const float alpha=0.6f, const float sigma=1.1f, const float dl=0.8f, const float da=30,
                              const float gauss_prec=2, const unsigned int interpolation_type=0,
                              const bool is_fast_approx=true) {
      return blur_anisotropic(get_diffusion_tensors(sharpness,anisotropy,alpha,sigma,interpolation_type!=3),
                              amplitude,dl,da,gauss_prec,interpolation_type,is_fast_approx);
    }

    //! Blur image anisotropically, in an edge-preserving way \newinstance.
    CImg<T> get_blur_anisotropic(const float amplitude, const float sharpness=0.7f, const float anisotropy=0.6f,
                                 const float alpha=0.6f, const float sigma=1.1f, const float dl=0.8f,
                                 const float da=30, const float gauss_prec=2, const unsigned int interpolation_type=0,
                                 const bool is_fast_approx=true) const {
      return (+*this).blur_anisotropic(amplitude,sharpness,anisotropy,alpha,sigma,dl,da,gauss_prec,interpolation_type,is_fast_approx);
    }

    //! Blur image, with the joint bilateral filter.
    /**
       \param guide Image used to model the smoothing weights.
       \param sigma_x Amount of blur along the X-axis.
       \param sigma_y Amount of blur along the Y-axis.
       \param sigma_z Amount of blur along the Z-axis.
       \param sigma_r Amount of blur along the value axis.
       \param bgrid_x Size of the bilateral grid along the X-axis.
       \param bgrid_y Size of the bilateral grid along the Y-axis.
       \param bgrid_z Size of the bilateral grid along the Z-axis.
       \param bgrid_r Size of the bilateral grid along the value axis.
       \param interpolation_type Use interpolation for image slicing.
       \note This algorithm uses the optimisation technique proposed by S. Paris and F. Durand, in ECCV'2006
       (extended for 3d volumetric images).
    **/
    template<typename t>
    CImg<T>& blur_bilateral(const CImg<t>& guide, const float sigma_x, const float sigma_y, const float sigma_z, const float sigma_r,
                            const int bgrid_x, const int bgrid_y, const int bgrid_z, const int bgrid_r,
                            const bool interpolation_type=true) {
      if (!is_sameXYZ(guide))
        throw CImgArgumentException(_cimg_instance
                                    "blur_bilateral(): Invalid size for specified guide image (%u,%u,%u,%u,%p).",
                                    cimg_instance,
                                    guide._width,guide._height,guide._depth,guide._spectrum,guide._data);
      if (is_empty()) return *this;
      T m, M = guide.max_min(m);
      if (m==M) return *this;
      const float range = (float)(M - m);
      const unsigned int
        bx0 = bgrid_x>=0?bgrid_x:_width*-bgrid_x/100,
        by0 = bgrid_y>=0?bgrid_y:_height*-bgrid_y/100,
        bz0 = bgrid_z>=0?bgrid_z:_depth*-bgrid_z/100,
        br0 = bgrid_r>=0?bgrid_r:(int)(-range*bgrid_r/100),
        bx = bx0>0?bx0:1,
        by = by0>0?by0:1,
        bz = bz0>0?bz0:1,
        br = br0>0?br0:1;
      const float
        _sigma_x = sigma_x>=0?sigma_x:-sigma_x*_width/100,
        _sigma_y = sigma_y>=0?sigma_y:-sigma_y*_height/100,
        _sigma_z = sigma_z>=0?sigma_z:-sigma_z*_depth/100,
        _sigma_r = sigma_r>=0?sigma_r:-sigma_r*range/100,
        nsigma_x = _sigma_x*bx/_width,
        nsigma_y = _sigma_y*by/_height,
        nsigma_z = _sigma_z*bz/_depth,
        nsigma_r = _sigma_r*br/range;
      if (nsigma_x>0 || nsigma_y>0 || nsigma_z>0 || nsigma_r>0) {
        const bool is_3d = (_depth>1);
        if (is_3d) { // 3d version of the algorithm
          CImg<floatT> bgrid(bx,by,bz,br), bgridw(bx,by,bz,br);
          cimg_forC(*this,c) {
            const CImg<t> _guide = guide.get_shared_channel(c%guide._spectrum);
            bgrid.fill(0); bgridw.fill(0);
            cimg_forXYZ(*this,x,y,z) {
              const T val = (*this)(x,y,z,c);
              const float gval = (float)_guide(x,y,z);
              const int X = x*bx/_width, Y = y*by/_height, Z = z*bz/_depth, R = (int)cimg::min(br-1.0f,(gval-m)*br/range);
              bgrid(X,Y,Z,R) += (float)val;
              bgridw(X,Y,Z,R) += 1;
            }
            bgrid.blur(nsigma_x,nsigma_y,nsigma_z,true).deriche(nsigma_r,0,'c',false);
            bgridw.blur(nsigma_x,nsigma_y,nsigma_z,true).deriche(nsigma_r,0,'c',false);
            if (interpolation_type) cimg_forXYZ(*this,x,y,z) {
              const float gval = (float)_guide(x,y,z),
                X = (float)x*bx/_width, Y = (float)y*by/_height, Z = (float)z*bz/_depth, R = (float)cimg::min(br-1.0f,(gval-m)*br/range),
                bval0 = bgrid._linear_atXYZC(X,Y,Z,R), bval1 = bgridw._linear_atXYZC(X,Y,Z,R);
              (*this)(x,y,z,c) = (T)(bval0/bval1);
            } else cimg_forXYZ(*this,x,y,z) {
              const float gval = (float)_guide(x,y,z);
              const int X = x*bx/_width, Y = y*by/_height, Z = z*bz/_depth, R = (int)cimg::min(br-1.0f,(gval-m)*br/range);
              const float bval0 = bgrid(X,Y,Z,R), bval1 = bgridw(X,Y,Z,R);
              (*this)(x,y,z,c) = (T)(bval0/bval1);
            }
          }
        } else { // 2d version of the algorithm
          CImg<floatT> bgrid(bx,by,br,2);
          cimg_forC(*this,c) {
            const CImg<t> _guide = guide.get_shared_channel(c%guide._spectrum);
            bgrid.fill(0);
            cimg_forXY(*this,x,y) {
              const T val = (*this)(x,y,c);
              const float gval = (float)_guide(x,y);
              const int X = x*bx/_width, Y = y*by/_height, R = (int)cimg::min(br-1.0f,(gval-m)*br/range);
              bgrid(X,Y,R,0) += (float)val;
              bgrid(X,Y,R,1) += 1;
            }
            bgrid.blur(nsigma_x,nsigma_y,0,true).blur(0,0,nsigma_r,false);
            if (interpolation_type) cimg_forXY(*this,x,y) {
              const float gval = (float)_guide(x,y),
                X = (float)x*bx/_width, Y = (float)y*by/_height, R = (float)cimg::min(br-1.0f,(gval-m)*br/range),
                bval0 = bgrid._linear_atXYZ(X,Y,R,0), bval1 = bgrid._linear_atXYZ(X,Y,R,1);
              (*this)(x,y,c) = (T)(bval0/bval1);
            } else cimg_forXY(*this,x,y) {
              const float gval = (float)_guide(x,y);
              const int X = x*bx/_width, Y = y*by/_height, R = (int)cimg::min(br-1.0f,(gval-m)*br/range);
              const float bval0 = bgrid(X,Y,R,0), bval1 = bgrid(X,Y,R,1);
              (*this)(x,y,c) = (T)(bval0/bval1);
            }
          }
        }
      }
      return *this;
    }

    //! Blur image, with the joint bilateral filter \newinstance.
    template<typename t>
    CImg<T> get_blur_bilateral(const CImg<t>& guide, const float sigma_x, const float sigma_y, const float sigma_z, const float sigma_r,
                               const int bgrid_x, const int bgrid_y, const int bgrid_z, const int bgrid_r,
                               const bool interpolation_type=true) const {
      return (+*this).blur_bilateral(guide,sigma_x,sigma_y,sigma_z,sigma_r,bgrid_x,bgrid_y,bgrid_z,bgrid_r,interpolation_type);
    }

    //! Blur image using the joint bilateral filter.
    /**
       \param guide Image used to model the smoothing weights.
       \param sigma_s Amount of blur along the XYZ-axes.
       \param sigma_r Amount of blur along the value axis.
       \param bgrid_s Size of the bilateral grid along the XYZ-axes.
       \param bgrid_r Size of the bilateral grid along the value axis.
       \param interpolation_type Use interpolation for image slicing.
    **/
    template<typename t>
    CImg<T>& blur_bilateral(const CImg<t>& guide, const float sigma_s, const float sigma_r, const int bgrid_s=-33, const int bgrid_r=32,
                            const bool interpolation_type=true) {
      const float nsigma_s = sigma_s>=0?sigma_s:-sigma_s*cimg::max(_width,_height,_depth)/100;
      return blur_bilateral(guide,nsigma_s,nsigma_s,nsigma_s,sigma_r,bgrid_s,bgrid_s,bgrid_s,bgrid_r,interpolation_type);
    }

    //! Blur image using the bilateral filter \newinstance.
    template<typename t>
    CImg<T> get_blur_bilateral(const CImg<t>& guide, const float sigma_s, const float sigma_r, const int bgrid_s=-33, const int bgrid_r=32,
                               const bool interpolation_type=true) const {
      return (+*this).blur_bilateral(guide,sigma_s,sigma_s,sigma_s,sigma_r,bgrid_s,bgrid_s,bgrid_s,bgrid_r,interpolation_type);
    }

    //! Blur image using patch-based space.
    /**
       \param sigma_s Amount of blur along the XYZ-axes.
       \param sigma_p Amount of blur along the value axis.
       \param patch_size Size of the patchs.
       \param lookup_size Size of the window to search similar patchs.
       \param smoothness Smoothness for the patch comparison.
       \param is_fast_approx Tells if a fast approximation of the gaussian function is used or not.
    **/
    CImg<T>& blur_patch(const float sigma_s, const float sigma_p, const unsigned int patch_size=3,
                        const unsigned int lookup_size=4, const float smoothness=0, const bool is_fast_approx=true) {
      if (is_empty() || !patch_size || !lookup_size) return *this;
      return get_blur_patch(sigma_s,sigma_p,patch_size,lookup_size,smoothness,is_fast_approx).move_to(*this);
    }

    //! Blur image using patch-based space \newinstance.
    CImg<T> get_blur_patch(const float sigma_s, const float sigma_p, const unsigned int patch_size=3,
                           const unsigned int lookup_size=4, const float smoothness=0, const bool is_fast_approx=true) const {

#define _cimg_blur_patch3d_fast(N) \
      cimg_for##N##XYZ(res,x,y,z) { \
        T *pP = P._data; cimg_forC(res,c) { cimg_get##N##x##N##x##N(img,x,y,z,c,pP,T); pP+=N3; } \
        const int x0 = x - rsize1, y0 = y - rsize1, z0 = z - rsize1, x1 = x + rsize2, y1 = y + rsize2, z1 = z + rsize2; \
        float sum_weights = 0; \
        cimg_for_in##N##XYZ(res,x0,y0,z0,x1,y1,z1,p,q,r) if (cimg::abs(img(x,y,z,0) - img(p,q,r,0))<sigma_p3) { \
          T *pQ = Q._data; cimg_forC(res,c) { cimg_get##N##x##N##x##N(img,p,q,r,c,pQ,T); pQ+=N3; } \
          float distance2 = 0; \
          pQ = Q._data; cimg_for(P,pP,T) { const float dI = (float)*pP - (float)*(pQ++); distance2+=dI*dI; } \
          distance2/=Pnorm; \
          const float dx = (float)p - x, dy = (float)q - y, dz = (float)r - z, \
            alldist = distance2 + (dx*dx + dy*dy + dz*dz)/sigma_s2, weight = alldist>3?0.0f:1.0f; \
          sum_weights+=weight; \
          cimg_forC(res,c) res(x,y,z,c)+=weight*(*this)(p,q,r,c); \
        } \
        if (sum_weights>0) cimg_forC(res,c) res(x,y,z,c)/=sum_weights; \
        else cimg_forC(res,c) res(x,y,z,c) = (Tfloat)((*this)(x,y,z,c)); \
    }

#define _cimg_blur_patch3d(N) \
      cimg_for##N##XYZ(res,x,y,z) { \
        T *pP = P._data; cimg_forC(res,c) { cimg_get##N##x##N##x##N(img,x,y,z,c,pP,T); pP+=N3; } \
        const int x0 = x - rsize1, y0 = y - rsize1, z0 = z - rsize1, x1 = x + rsize2, y1 = y + rsize2, z1 = z + rsize2; \
        float sum_weights = 0, weight_max = 0; \
        cimg_for_in##N##XYZ(res,x0,y0,z0,x1,y1,z1,p,q,r) if (p!=x || q!=y || r!=z) { \
          T *pQ = Q._data; cimg_forC(res,c) { cimg_get##N##x##N##x##N(img,p,q,r,c,pQ,T); pQ+=N3; } \
          float distance2 = 0; \
          pQ = Q._data; cimg_for(P,pP,T) { const float dI = (float)*pP - (float)*(pQ++); distance2+=dI*dI; } \
          distance2/=Pnorm; \
          const float dx = (float)p - x, dy = (float)q - y, dz = (float)r - z, \
            alldist = distance2 + (dx*dx + dy*dy + dz*dz)/sigma_s2, weight = (float)std::exp(-alldist); \
          if (weight>weight_max) weight_max = weight; \
          sum_weights+=weight; \
          cimg_forC(res,c) res(x,y,z,c)+=weight*(*this)(p,q,r,c); \
        } \
        sum_weights+=weight_max; cimg_forC(res,c) res(x,y,z,c)+=weight_max*(*this)(x,y,z,c); \
        if (sum_weights>0) cimg_forC(res,c) res(x,y,z,c)/=sum_weights; \
        else cimg_forC(res,c) res(x,y,z,c) = (Tfloat)((*this)(x,y,z,c)); \
      }

#define _cimg_blur_patch2d_fast(N) \
        cimg_for##N##XY(res,x,y) { \
          T *pP = P._data; cimg_forC(res,c) { cimg_get##N##x##N(img,x,y,0,c,pP,T); pP+=N2; } \
          const int x0 = x - rsize1, y0 = y - rsize1, x1 = x + rsize2, y1 = y + rsize2; \
          float sum_weights = 0; \
          cimg_for_in##N##XY(res,x0,y0,x1,y1,p,q) if (cimg::abs(img(x,y,0,0) - img(p,q,0,0))<sigma_p3) { \
            T *pQ = Q._data; cimg_forC(res,c) { cimg_get##N##x##N(img,p,q,0,c,pQ,T); pQ+=N2; } \
            float distance2 = 0; \
            pQ = Q._data; cimg_for(P,pP,T) { const float dI = (float)*pP - (float)*(pQ++); distance2+=dI*dI; } \
            distance2/=Pnorm; \
            const float dx = (float)p - x, dy = (float)q - y, \
              alldist = distance2 + (dx*dx+dy*dy)/sigma_s2, weight = alldist>3?0.0f:1.0f; \
            sum_weights+=weight; \
            cimg_forC(res,c) res(x,y,c)+=weight*(*this)(p,q,c); \
          } \
          if (sum_weights>0) cimg_forC(res,c) res(x,y,c)/=sum_weights; \
          else cimg_forC(res,c) res(x,y,c) = (Tfloat)((*this)(x,y,c)); \
        }

#define _cimg_blur_patch2d(N) \
        cimg_for##N##XY(res,x,y) { \
          T *pP = P._data; cimg_forC(res,c) { cimg_get##N##x##N(img,x,y,0,c,pP,T); pP+=N2; } \
          const int x0 = x - rsize1, y0 = y - rsize1, x1 = x + rsize2, y1 = y + rsize2; \
          float sum_weights = 0, weight_max = 0; \
          cimg_for_in##N##XY(res,x0,y0,x1,y1,p,q) if (p!=x || q!=y) { \
            T *pQ = Q._data; cimg_forC(res,c) { cimg_get##N##x##N(img,p,q,0,c,pQ,T); pQ+=N2; } \
            float distance2 = 0; \
            pQ = Q._data; cimg_for(P,pP,T) { const float dI = (float)*pP - (float)*(pQ++); distance2+=dI*dI; } \
            distance2/=Pnorm; \
            const float dx = (float)p - x, dy = (float)q - y, \
              alldist = distance2 + (dx*dx+dy*dy)/sigma_s2, weight = (float)std::exp(-alldist); \
            if (weight>weight_max) weight_max = weight; \
            sum_weights+=weight; \
            cimg_forC(res,c) res(x,y,c)+=weight*(*this)(p,q,c); \
          } \
          sum_weights+=weight_max; cimg_forC(res,c) res(x,y,c)+=weight_max*(*this)(x,y,c); \
          if (sum_weights>0) cimg_forC(res,c) res(x,y,c)/=sum_weights; \
          else cimg_forC(res,c) res(x,y,c) = (Tfloat)((*this)(x,y,c)); \
    }

      if (is_empty() || !patch_size || !lookup_size) return +*this;
      CImg<Tfloat> res(_width,_height,_depth,_spectrum,0);
      const CImg<T> _img = smoothness>0?get_blur(smoothness):CImg<Tfloat>(),&img = smoothness>0?_img:*this;
      CImg<T> P(patch_size*patch_size*_spectrum), Q(P);
      const float
        nsigma_s = sigma_s>=0?sigma_s:-sigma_s*cimg::max(_width,_height,_depth)/100,
        sigma_s2 = nsigma_s*nsigma_s, sigma_p2 = sigma_p*sigma_p, sigma_p3 = 3*sigma_p,
        Pnorm = P.size()*sigma_p2;
      const int rsize2 = (int)lookup_size/2, rsize1 = (int)lookup_size - rsize2 - 1;
      const unsigned int N2 = patch_size*patch_size, N3 = N2*patch_size;
      if (_depth>1) switch (patch_size) { // 3d
      case 2 : if (is_fast_approx) _cimg_blur_patch3d_fast(2) else _cimg_blur_patch3d(2) break;
      case 3 : if (is_fast_approx) _cimg_blur_patch3d_fast(3) else _cimg_blur_patch3d(3) break;
      default : {
        const int psize2 = (int)patch_size/2, psize1 = (int)patch_size - psize2 - 1;
        if (is_fast_approx) cimg_forXYZ(res,x,y,z) { // Fast
          P = img.get_crop(x - psize1,y - psize1,z - psize1,x + psize2,y + psize2,z + psize2,true);
          const int x0 = x - rsize1, y0 = y - rsize1, z0 = z - rsize1, x1 = x + rsize2, y1 = y + rsize2, z1 = z + rsize2;
          float sum_weights = 0;
          cimg_for_inXYZ(res,x0,y0,z0,x1,y1,z1,p,q,r) if (cimg::abs(img(x,y,z,0)-img(p,q,r,0))<sigma_p3) {
            (Q = img.get_crop(p - psize1,q - psize1,r - psize1,p + psize2,q + psize2,r + psize2,true))-=P;
            const float
              dx = (float)x - p, dy = (float)y - q, dz = (float)z - r,
              distance2 = (float)(Q.pow(2).sum()/Pnorm + (dx*dx + dy*dy + dz*dz)/sigma_s2),
              weight = distance2>3?0.0f:1.0f;
            sum_weights+=weight;
            cimg_forC(res,c) res(x,y,z,c)+=weight*(*this)(p,q,r,c);
          }
          if (sum_weights>0) cimg_forC(res,c) res(x,y,z,c)/=sum_weights;
          else cimg_forC(res,c) res(x,y,z,c) = (Tfloat)((*this)(x,y,z,c));
        } else cimg_forXYZ(res,x,y,z) { // Exact
          P = img.get_crop(x - psize1,y - psize1,z - psize1,x + psize2,y + psize2,z + psize2,true);
          const int x0 = x - rsize1, y0 = y - rsize1, z0 = z - rsize1, x1 = x + rsize2, y1 = y + rsize2, z1 = z + rsize2;
          float sum_weights = 0, weight_max = 0;
          cimg_for_inXYZ(res,x0,y0,z0,x1,y1,z1,p,q,r) if (p!=x || q!=y || r!=z) {
            (Q = img.get_crop(p - psize1,q - psize1,r - psize1,p + psize2,q + psize2,r + psize2,true))-=P;
            const float
              dx = (float)x - p, dy = (float)y - q, dz = (float)z - r,
              distance2 = (float)(Q.pow(2).sum()/Pnorm + (dx*dx + dy*dy + dz*dz)/sigma_s2),
              weight = (float)std::exp(-distance2);
            if (weight>weight_max) weight_max = weight;
            sum_weights+=weight;
            cimg_forC(res,c) res(x,y,z,c)+=weight*(*this)(p,q,r,c);
          }
          sum_weights+=weight_max; cimg_forC(res,c) res(x,y,z,c)+=weight_max*(*this)(x,y,z,c);
          if (sum_weights>0) cimg_forC(res,c) res(x,y,z,c)/=sum_weights;
          else cimg_forC(res,c) res(x,y,z,c) = (Tfloat)((*this)(x,y,z,c));
        }
      }
      } else switch (patch_size) { // 2d
      case 2 : if (is_fast_approx) _cimg_blur_patch2d_fast(2) else _cimg_blur_patch2d(2) break;
      case 3 : if (is_fast_approx) _cimg_blur_patch2d_fast(3) else _cimg_blur_patch2d(3) break;
      case 4 : if (is_fast_approx) _cimg_blur_patch2d_fast(4) else _cimg_blur_patch2d(4) break;
      case 5 : if (is_fast_approx) _cimg_blur_patch2d_fast(5) else _cimg_blur_patch2d(5) break;
      case 6 : if (is_fast_approx) _cimg_blur_patch2d_fast(6) else _cimg_blur_patch2d(6) break;
      case 7 : if (is_fast_approx) _cimg_blur_patch2d_fast(7) else _cimg_blur_patch2d(7) break;
      case 8 : if (is_fast_approx) _cimg_blur_patch2d_fast(8) else _cimg_blur_patch2d(8) break;
      case 9 : if (is_fast_approx) _cimg_blur_patch2d_fast(9) else _cimg_blur_patch2d(9) break;
      default : { // Fast
        const int psize2 = (int)patch_size/2, psize1 = (int)patch_size - psize2 - 1;
        if (is_fast_approx) cimg_forXY(res,x,y) { // 2d fast approximation.
          P = img.get_crop(x - psize1,y - psize1,x + psize2,y + psize2,true);
          const int x0 = x - rsize1, y0 = y - rsize1, x1 = x + rsize2, y1 = y + rsize2;
          float sum_weights = 0;
          cimg_for_inXY(res,x0,y0,x1,y1,p,q) if (cimg::abs(img(x,y,0)-img(p,q,0))<sigma_p3) {
            (Q = img.get_crop(p - psize1,q - psize1,p + psize2,q + psize2,true))-=P;
            const float
              dx = (float)x - p, dy = (float)y - q,
              distance2 = (float)(Q.pow(2).sum()/Pnorm + (dx*dx + dy*dy)/sigma_s2),
              weight = distance2>3?0.0f:1.0f;
            sum_weights+=weight;
            cimg_forC(res,c) res(x,y,c)+=weight*(*this)(p,q,c);
          }
          if (sum_weights>0) cimg_forC(res,c) res(x,y,c)/=sum_weights;
          else cimg_forC(res,c) res(x,y,c) = (Tfloat)((*this)(x,y,c));
        } else cimg_forXY(res,x,y) { // 2d exact algorithm.
          P = img.get_crop(x - psize1,y - psize1,x + psize2,y + psize2,true);
          const int x0 = x - rsize1, y0 = y - rsize1, x1 = x + rsize2, y1 = y + rsize2;
          float sum_weights = 0, weight_max = 0;
          cimg_for_inXY(res,x0,y0,x1,y1,p,q) if (p!=x || q!=y) {
            (Q = img.get_crop(p - psize1,q - psize1,p + psize2,q + psize2,true))-=P;
            const float
              dx = (float)x - p, dy = (float)y - q,
              distance2 = (float)(Q.pow(2).sum()/Pnorm + (dx*dx + dy*dy)/sigma_s2),
              weight = (float)std::exp(-distance2);
            if (weight>weight_max) weight_max = weight;
            sum_weights+=weight;
            cimg_forC(res,c) res(x,y,c)+=weight*(*this)(p,q,c);
          }
          sum_weights+=weight_max; cimg_forC(res,c) res(x,y,c)+=weight_max*(*this)(x,y,c);
          if (sum_weights>0) cimg_forC(res,c) res(x,y,c)/=sum_weights;
          else cimg_forC(res,c) res(x,y,0,c) = (Tfloat)((*this)(x,y,c));
        }
      }
      }
      return res;
    }

    //! Blur image with the median filter.
    /**
       \param n Size of the median filter.
    **/
    CImg<T>& blur_median(const unsigned int n) {
      if (!n) return *this;
      return get_blur_median(n).move_to(*this);
    }

    //! Blur image with the median filter \newinstance.
    CImg<T> get_blur_median(const unsigned int n) const {
      if (is_empty() || n<=1) return +*this;
      CImg<T> res(_width,_height,_depth,_spectrum);
      T *ptrd = res._data;
      const int hl = n/2, hr = hl - 1 + n%2;
      if (res._depth!=1) cimg_forXYZC(*this,x,y,z,c) { // 3d
        const int
          x0 = x - hl, y0 = y - hl, z0 = z-hl, x1 = x + hr, y1 = y + hr, z1 = z+hr,
          nx0 = x0<0?0:x0, ny0 = y0<0?0:y0, nz0 = z0<0?0:z0,
          nx1 = x1>=width()?width()-1:x1, ny1 = y1>=height()?height()-1:y1, nz1 = z1>=depth()?depth()-1:z1;
        *(ptrd++) = get_crop(nx0,ny0,nz0,c,nx1,ny1,nz1,c).median();
      } else {
#define _cimg_median_sort(a,b) if ((a)>(b)) cimg::swap(a,b)
        if (res._height!=1) switch (n) { // 2d
        case 3 : {
          T I[9] = { 0 };
          CImg_3x3(J,T);
          cimg_forC(*this,c) cimg_for3x3(*this,x,y,0,c,I,T) {
            std::memcpy(J,I,9*sizeof(T));
            _cimg_median_sort(Jcp, Jnp); _cimg_median_sort(Jcc, Jnc); _cimg_median_sort(Jcn, Jnn);
            _cimg_median_sort(Jpp, Jcp); _cimg_median_sort(Jpc, Jcc); _cimg_median_sort(Jpn, Jcn);
            _cimg_median_sort(Jcp, Jnp); _cimg_median_sort(Jcc, Jnc); _cimg_median_sort(Jcn, Jnn);
            _cimg_median_sort(Jpp, Jpc); _cimg_median_sort(Jnc, Jnn); _cimg_median_sort(Jcc, Jcn);
            _cimg_median_sort(Jpc, Jpn); _cimg_median_sort(Jcp, Jcc); _cimg_median_sort(Jnp, Jnc);
            _cimg_median_sort(Jcc, Jcn); _cimg_median_sort(Jcc, Jnp); _cimg_median_sort(Jpn, Jcc);
            _cimg_median_sort(Jcc, Jnp);
            *(ptrd++) = Jcc;
          }
        } break;
        case 5 : {
          T I[25] = { 0 };
          CImg_5x5(J,T);
          cimg_forC(*this,c) cimg_for5x5(*this,x,y,0,c,I,T) {
            std::memcpy(J,I,25*sizeof(T));
            _cimg_median_sort(Jbb, Jpb); _cimg_median_sort(Jnb, Jab); _cimg_median_sort(Jcb, Jab); _cimg_median_sort(Jcb, Jnb);
            _cimg_median_sort(Jpp, Jcp); _cimg_median_sort(Jbp, Jcp); _cimg_median_sort(Jbp, Jpp); _cimg_median_sort(Jap, Jbc);
            _cimg_median_sort(Jnp, Jbc); _cimg_median_sort(Jnp, Jap); _cimg_median_sort(Jcc, Jnc); _cimg_median_sort(Jpc, Jnc);
            _cimg_median_sort(Jpc, Jcc); _cimg_median_sort(Jbn, Jpn); _cimg_median_sort(Jac, Jpn); _cimg_median_sort(Jac, Jbn);
            _cimg_median_sort(Jnn, Jan); _cimg_median_sort(Jcn, Jan); _cimg_median_sort(Jcn, Jnn); _cimg_median_sort(Jpa, Jca);
            _cimg_median_sort(Jba, Jca); _cimg_median_sort(Jba, Jpa); _cimg_median_sort(Jna, Jaa); _cimg_median_sort(Jcb, Jbp);
            _cimg_median_sort(Jnb, Jpp); _cimg_median_sort(Jbb, Jpp); _cimg_median_sort(Jbb, Jnb); _cimg_median_sort(Jab, Jcp);
            _cimg_median_sort(Jpb, Jcp); _cimg_median_sort(Jpb, Jab); _cimg_median_sort(Jpc, Jac); _cimg_median_sort(Jnp, Jac);
            _cimg_median_sort(Jnp, Jpc); _cimg_median_sort(Jcc, Jbn); _cimg_median_sort(Jap, Jbn); _cimg_median_sort(Jap, Jcc);
            _cimg_median_sort(Jnc, Jpn); _cimg_median_sort(Jbc, Jpn); _cimg_median_sort(Jbc, Jnc); _cimg_median_sort(Jba, Jna);
            _cimg_median_sort(Jcn, Jna); _cimg_median_sort(Jcn, Jba); _cimg_median_sort(Jpa, Jaa); _cimg_median_sort(Jnn, Jaa);
            _cimg_median_sort(Jnn, Jpa); _cimg_median_sort(Jan, Jca); _cimg_median_sort(Jnp, Jcn); _cimg_median_sort(Jap, Jnn);
            _cimg_median_sort(Jbb, Jnn); _cimg_median_sort(Jbb, Jap); _cimg_median_sort(Jbc, Jan); _cimg_median_sort(Jpb, Jan);
            _cimg_median_sort(Jpb, Jbc); _cimg_median_sort(Jpc, Jba); _cimg_median_sort(Jcb, Jba); _cimg_median_sort(Jcb, Jpc);
            _cimg_median_sort(Jcc, Jpa); _cimg_median_sort(Jnb, Jpa); _cimg_median_sort(Jnb, Jcc); _cimg_median_sort(Jnc, Jca);
            _cimg_median_sort(Jab, Jca); _cimg_median_sort(Jab, Jnc); _cimg_median_sort(Jac, Jna); _cimg_median_sort(Jbp, Jna);
            _cimg_median_sort(Jbp, Jac); _cimg_median_sort(Jbn, Jaa); _cimg_median_sort(Jpp, Jaa); _cimg_median_sort(Jpp, Jbn);
            _cimg_median_sort(Jcp, Jpn); _cimg_median_sort(Jcp, Jan); _cimg_median_sort(Jnc, Jpa); _cimg_median_sort(Jbn, Jna);
            _cimg_median_sort(Jcp, Jnc); _cimg_median_sort(Jcp, Jbn); _cimg_median_sort(Jpb, Jap); _cimg_median_sort(Jnb, Jpc);
            _cimg_median_sort(Jbp, Jcn); _cimg_median_sort(Jpc, Jcn); _cimg_median_sort(Jap, Jcn); _cimg_median_sort(Jab, Jbc);
            _cimg_median_sort(Jpp, Jcc); _cimg_median_sort(Jcp, Jac); _cimg_median_sort(Jab, Jpp); _cimg_median_sort(Jab, Jcp);
            _cimg_median_sort(Jcc, Jac); _cimg_median_sort(Jbc, Jac); _cimg_median_sort(Jpp, Jcp); _cimg_median_sort(Jbc, Jcc);
            _cimg_median_sort(Jpp, Jbc); _cimg_median_sort(Jpp, Jcn); _cimg_median_sort(Jcc, Jcn); _cimg_median_sort(Jcp, Jcn);
            _cimg_median_sort(Jcp, Jbc); _cimg_median_sort(Jcc, Jnn); _cimg_median_sort(Jcp, Jcc); _cimg_median_sort(Jbc, Jnn);
            _cimg_median_sort(Jcc, Jba); _cimg_median_sort(Jbc, Jba); _cimg_median_sort(Jbc, Jcc);
            *(ptrd++) = Jcc;
          }
        } break;
        default : {
          cimg_forXYC(*this,x,y,c) {
            const int
              x0 = x - hl, y0 = y - hl, x1 = x + hr, y1 = y + hr,
              nx0 = x0<0?0:x0, ny0 = y0<0?0:y0,
              nx1 = x1>=width()?width()-1:x1, ny1 = y1>=height()?height()-1:y1;
            *(ptrd++) = get_crop(nx0,ny0,0,c,nx1,ny1,0,c).median();
          }
        }
        } else switch (n) { // 1d
        case 2 : {
          T I[4] = { 0 };
          cimg_forC(*this,c) cimg_for2x2(*this,x,y,0,c,I,T) *(ptrd++) = (T)(0.5f*(I[0]+I[1]));
        } break;
        case 3 : {
          T I[9] = { 0 };
          cimg_forC(*this,c) cimg_for3x3(*this,x,y,0,c,I,T)
            *(ptrd++) = I[3]<I[4]?(I[4]<I[5]?I[4]:(I[3]<I[5]?I[5]:I[3])):(I[3]<I[5]?I[3]:(I[4]<I[5]?I[5]:I[4]));
        } break;
        default : {
          cimg_forXC(*this,x,c) {
            const int
              x0 = x - hl, x1 = x + hr,
              nx0 = x0<0?0:x0, nx1 = x1>=width()?width()-1:x1;
            *(ptrd++) = get_crop(nx0,0,0,c,nx1,0,0,c).median();
          }
        }
        }
      }
      return res;
    }

    //! Sharpen image.
    /**
       \param amplitude Sharpening amplitude
       \param sharpen_type Select sharpening method. Can be <tt>{ false=inverse diffusion | true=shock filters }</tt>.
       \param edge Edge threshold (shock filters only).
       \param alpha Gradient smoothness (shock filters only).
       \param sigma Tensor smoothness (shock filters only).
    **/
    CImg<T>& sharpen(const float amplitude, const bool sharpen_type=false, const float edge=1, const float alpha=0, const float sigma=0) {
      if (is_empty()) return *this;
      T val_min, val_max = max_min(val_min);
      const float nedge = edge/2;
      CImg<Tfloat> val, vec, velocity(_width,_height,_depth,_spectrum);
      Tfloat *ptrd = velocity._data, veloc_max = 0;

      if (_depth>1) { // 3d
        CImg_3x3x3(I,Tfloat);
        if (sharpen_type) { // Shock filters.
          CImg<Tfloat> G = (alpha>0?get_blur(alpha).get_structure_tensors():get_structure_tensors());
          if (sigma>0) G.blur(sigma);
          Tfloat *ptrG0 = G.data(0,0,0,0), *ptrG1 = G.data(0,0,0,1), *ptrG2 = G.data(0,0,0,2), *ptrG3 = G.data(0,0,0,3);
          cimg_forXYZ(G,x,y,z) {
            G.get_tensor_at(x,y,z).symmetric_eigen(val,vec);
            if (val[0]<0) val[0] = 0;
            if (val[1]<0) val[1] = 0;
            if (val[2]<0) val[2] = 0;
            *(ptrG0++) = vec(0,0);
            *(ptrG1++) = vec(0,1);
            *(ptrG2++) = vec(0,2);
            *(ptrG3++) = 1 - (Tfloat)std::pow(1+val[0]+val[1]+val[2],-(Tfloat)nedge);
          }
          cimg_forC(*this,c) cimg_for3x3x3(*this,x,y,z,c,I,Tfloat) {
            const Tfloat
              u = G(x,y,z,0),
              v = G(x,y,z,1),
              w = G(x,y,z,2),
              amp = G(x,y,z,3),
              ixx = Incc + Ipcc - 2*Iccc,
              ixy = (Innc + Ippc - Inpc - Ipnc)/4,
              ixz = (Incn + Ipcp - Incp - Ipcn)/4,
              iyy = Icnc + Icpc - 2*Iccc,
              iyz = (Icnn + Icpp - Icnp - Icpn)/4,
              izz = Iccn + Iccp - 2*Iccc,
              ixf = Incc - Iccc,
              ixb = Iccc - Ipcc,
              iyf = Icnc - Iccc,
              iyb = Iccc - Icpc,
              izf = Iccn - Iccc,
              izb = Iccc - Iccp,
              itt = u*u*ixx + v*v*iyy + w*w*izz + 2*u*v*ixy + 2*u*w*ixz + 2*v*w*iyz,
              it = u*cimg::minmod(ixf,ixb) + v*cimg::minmod(iyf,iyb) + w*cimg::minmod(izf,izb),
              veloc = -amp*cimg::sign(itt)*cimg::abs(it);
            *(ptrd++) = veloc;
            if (veloc>veloc_max) veloc_max = veloc; else if (-veloc>veloc_max) veloc_max = -veloc;
          }
        } else cimg_forC(*this,c) cimg_for3x3x3(*this,x,y,z,c,I,Tfloat) { // Inverse diffusion.
          const Tfloat veloc = -Ipcc - Incc - Icpc - Icnc - Iccp - Iccn + 6*Iccc;
          *(ptrd++) = veloc;
          if (veloc>veloc_max) veloc_max = veloc; else if (-veloc>veloc_max) veloc_max = -veloc;
        }
      } else {
        CImg_3x3(I,Tfloat);
        if (sharpen_type) { // Shock filters.
          CImg<Tfloat> G = (alpha>0?get_blur(alpha).get_structure_tensors():get_structure_tensors());
          if (sigma>0) G.blur(sigma);
          Tfloat *ptrG0 = G.data(0,0,0,0), *ptrG1 = G.data(0,0,0,1), *ptrG2 = G.data(0,0,0,2);
          cimg_forXY(G,x,y) {
            G.get_tensor_at(x,y).symmetric_eigen(val,vec);
            if (val[0]<0) val[0] = 0;
            if (val[1]<0) val[1] = 0;
            *(ptrG0++) = vec(0,0);
            *(ptrG1++) = vec(0,1);
            *(ptrG2++) = 1 - (Tfloat)std::pow(1 + val[0] + val[1],-(Tfloat)nedge);
          }
          cimg_forC(*this,c) cimg_for3x3(*this,x,y,0,c,I,Tfloat) {
            const Tfloat
              u = G(x,y,0),
              v = G(x,y,1),
              amp = G(x,y,2),
              ixx = Inc + Ipc - 2*Icc,
              ixy = (Inn + Ipp - Inp - Ipn)/4,
              iyy = Icn + Icp - 2*Icc,
              ixf = Inc - Icc,
              ixb = Icc - Ipc,
              iyf = Icn - Icc,
              iyb = Icc - Icp,
              itt = u*u*ixx + v*v*iyy + 2*u*v*ixy,
              it = u*cimg::minmod(ixf,ixb) + v*cimg::minmod(iyf,iyb),
              veloc = -amp*cimg::sign(itt)*cimg::abs(it);
            *(ptrd++) = veloc;
            if (veloc>veloc_max) veloc_max = veloc; else if (-veloc>veloc_max) veloc_max = -veloc;
          }
        } else cimg_forC(*this,c) cimg_for3x3(*this,x,y,0,c,I,Tfloat) { // Inverse diffusion.
          const Tfloat veloc = -Ipc - Inc - Icp - Icn + 4*Icc;
          *(ptrd++) = veloc;
          if (veloc>veloc_max) veloc_max = veloc; else if (-veloc>veloc_max) veloc_max = -veloc;
        }
      }
      if (veloc_max<=0) return *this;
      return ((velocity*=amplitude/veloc_max)+=*this).cut(val_min,val_max).move_to(*this);
    }

    //! Sharpen image \newinstance.
    CImg<T> get_sharpen(const float amplitude, const bool sharpen_type=false, const float edge=1, const float alpha=0, const float sigma=0) const {
      return (+*this).sharpen(amplitude,sharpen_type,edge,alpha,sigma);
    }

    //! Return image gradient.
    /**
       \param axes Axes considered for the gradient computation, as a C-string (e.g "xy").
       \param scheme = Numerical scheme used for the gradient computation:
       - -1 = Backward finite differences
       - 0 = Centered finite differences
       - 1 = Forward finite differences
       - 2 = Using Sobel masks
       - 3 = Using rotation invariant masks
       - 4 = Using Deriche recusrsive filter.
       - 5 = Using Van Vliet recusrsive filter.
    **/
    CImgList<Tfloat> get_gradient(const char *const axes=0, const int scheme=3) const {
      CImgList<Tfloat> grad(2,_width,_height,_depth,_spectrum);
      Tfloat *ptrd0 = grad[0]._data, *ptrd1 = grad[1]._data;
      bool is_3d = false;
      if (axes) {
        for (unsigned int a = 0; axes[a]; ++a) {
          const char axis = cimg::uncase(axes[a]);
          switch (axis) {
          case 'x' : case 'y' : break;
          case 'z' : is_3d = true; break;
          default :
            throw CImgArgumentException(_cimg_instance
                                        "get_gradient(): Invalid specified axis '%c'.",
                                        cimg_instance,
                                        axis);
          }
        }
      } else is_3d = (_depth>1);
      if (is_3d) {
        CImg<Tfloat>(_width,_height,_depth,_spectrum).move_to(grad);
        Tfloat *ptrd2 = grad[2]._data;
        switch (scheme) { // 3d.
        case -1 : { // Backward finite differences.
          CImg_3x3x3(I,Tfloat);
          cimg_forC(*this,c) cimg_for3x3x3(*this,x,y,z,c,I,Tfloat) {
            *(ptrd0++) = Iccc - Ipcc;
            *(ptrd1++) = Iccc - Icpc;
            *(ptrd2++) = Iccc - Iccp;
          }
        } break;
        case 1 : { // Forward finite differences.
          CImg_2x2x2(I,Tfloat);
          cimg_forC(*this,c) cimg_for2x2x2(*this,x,y,z,c,I,Tfloat) {
            *(ptrd0++) = Incc - Iccc;
            *(ptrd1++) = Icnc - Iccc;
            *(ptrd2++) = Iccn - Iccc;
          }
        } break;
        case 4 : { // Using Deriche filter with low standard variation.
          grad[0] = get_deriche(0,1,'x');
          grad[1] = get_deriche(0,1,'y');
          grad[2] = get_deriche(0,1,'z');
        } break;
        case 5 : { // Using Van Vliet filter with low standard variation.
          grad[0] = get_vanvliet(0,1,'x');
          grad[1] = get_vanvliet(0,1,'y');
          grad[2] = get_vanvliet(0,1,'z');
        } break;
        default : { // Central finite differences.
          CImg_3x3x3(I,Tfloat);
          cimg_forC(*this,c) cimg_for3x3x3(*this,x,y,z,c,I,Tfloat) {
            *(ptrd0++) = (Incc - Ipcc)/2;
            *(ptrd1++) = (Icnc - Icpc)/2;
            *(ptrd2++) = (Iccn - Iccp)/2;
          }
        }
        }
      } else switch (scheme) { // 2d.
      case -1 : { // Backward finite differences.
        CImg_3x3(I,Tfloat);
        cimg_forZC(*this,z,c) cimg_for3x3(*this,x,y,z,c,I,Tfloat) {
          *(ptrd0++) = Icc - Ipc;
          *(ptrd1++) = Icc - Icp;
        }
      } break;
      case 1 : { // Forward finite differences.
        CImg_2x2(I,Tfloat);
        cimg_forZC(*this,z,c) cimg_for2x2(*this,x,y,z,c,I,Tfloat) {
          *(ptrd0++) = Inc - Icc;
          *(ptrd1++) = Icn - Icc;
        }
      } break;
      case 2 : { // Sobel scheme.
        CImg_3x3(I,Tfloat);
        cimg_forZC(*this,z,c) cimg_for3x3(*this,x,y,z,c,I,Tfloat) {
          *(ptrd0++) = -Ipp - 2*Ipc - Ipn + Inp + 2*Inc + Inn;
          *(ptrd1++) = -Ipp - 2*Icp - Inp + Ipn + 2*Icn + Inn;
        }
      } break;
      case 3 : { // Rotation invariant mask.
        CImg_3x3(I,Tfloat);
        const Tfloat a = (Tfloat)(0.25f*(2-std::sqrt(2.0f))), b = (Tfloat)(0.5f*(std::sqrt(2.0f)-1));
        cimg_forZC(*this,z,c) cimg_for3x3(*this,x,y,z,c,I,Tfloat) {
          *(ptrd0++) = -a*Ipp - b*Ipc - a*Ipn + a*Inp + b*Inc + a*Inn;
          *(ptrd1++) = -a*Ipp - b*Icp - a*Inp + a*Ipn + b*Icn + a*Inn;
        }
      } break;
      case 4 : { // using Van Vliet filter with low standard variation
        grad[0] = get_deriche(0,1,'x');
        grad[1] = get_deriche(0,1,'y');
      } break;
      case 5 : { // using Deriche filter with low standard variation
        grad[0] = get_vanvliet(0,1,'x');
        grad[1] = get_vanvliet(0,1,'y');
      } break;
      default : { // central finite differences
        CImg_3x3(I,Tfloat);
        cimg_forZC(*this,z,c) cimg_for3x3(*this,x,y,z,c,I,Tfloat) {
          *(ptrd0++) = (Inc - Ipc)/2;
          *(ptrd1++) = (Icn - Icp)/2;
        }
      }
      }
      if (!axes) return grad;
      CImgList<Tfloat> res;
      for (unsigned int l = 0; axes[l]; ++l) {
        const char axis = cimg::uncase(axes[l]);
        switch (axis) {
        case 'x' : res.insert(grad[0]); break;
        case 'y' : res.insert(grad[1]); break;
        case 'z' : res.insert(grad[2]); break;
        }
      }
      grad.assign();
      return res;
    }

    //! Return image hessian.
    /**
       \param axes Axes considered for the hessian computation, as a C-string (e.g "xy").
    **/
    CImgList<Tfloat> get_hessian(const char *const axes=0) const {
      CImgList<Tfloat> res;
      const char *naxes = axes, *const def_axes2d = "xxxyyy", *const def_axes3d = "xxxyxzyyyzzz";
      if (!axes) naxes = _depth>1?def_axes3d:def_axes2d;
      const unsigned int lmax = std::strlen(naxes);
      if (lmax%2)
        throw CImgArgumentException(_cimg_instance
                                    "get_hessian(): Invalid specified axes '%s'.",
                                    cimg_instance,
                                    naxes);

      res.assign(lmax/2,_width,_height,_depth,_spectrum);
      if (!cimg::strcasecmp(naxes,def_axes3d)) { // 3d
        Tfloat
          *ptrd0 = res[0]._data, *ptrd1 = res[1]._data, *ptrd2 = res[2]._data,
          *ptrd3 = res[3]._data, *ptrd4 = res[4]._data, *ptrd5 = res[5]._data;
        CImg_3x3x3(I,Tfloat);
        cimg_forC(*this,c) cimg_for3x3x3(*this,x,y,z,c,I,Tfloat) {
          *(ptrd0++) = Ipcc + Incc - 2*Iccc;          // Ixx
          *(ptrd1++) = (Ippc + Innc - Ipnc - Inpc)/4; // Ixy
          *(ptrd2++) = (Ipcp + Incn - Ipcn - Incp)/4; // Ixz
          *(ptrd3++) = Icpc + Icnc - 2*Iccc;          // Iyy
          *(ptrd4++) = (Icpp + Icnn - Icpn - Icnp)/4; // Iyz
          *(ptrd5++) = Iccn + Iccp - 2*Iccc;          // Izz
        }
      } else if (!cimg::strcasecmp(naxes,def_axes2d)) { // 2d
        Tfloat *ptrd0 = res[0]._data, *ptrd1 = res[1]._data, *ptrd2 = res[2]._data;
        CImg_3x3(I,Tfloat);
        cimg_forC(*this,c) cimg_for3x3(*this,x,y,0,c,I,Tfloat) {
          *(ptrd0++) = Ipc + Inc - 2*Icc;         // Ixx
          *(ptrd1++) = (Ipp + Inn - Ipn - Inp)/4; // Ixy
          *(ptrd2++) = Icp + Icn - 2*Icc;         // Iyy
        }
      } else for (unsigned int l = 0; l<lmax; ) { // Version with custom axes.
        const unsigned int l2 = l/2;
          char axis1 = naxes[l++], axis2 = naxes[l++];
          if (axis1>axis2) cimg::swap(axis1,axis2);
          bool valid_axis = false;
          Tfloat *ptrd = res[l2]._data;
          if (axis1=='x' && axis2=='x') { // Ixx
            valid_axis = true; CImg_3x3(I,Tfloat);
            cimg_forZC(*this,z,c) cimg_for3x3(*this,x,y,z,c,I,Tfloat) *(ptrd++) = Ipc + Inc - 2*Icc;
          }
          else if (axis1=='x' && axis2=='y') { // Ixy
            valid_axis = true; CImg_3x3(I,Tfloat);
            cimg_forZC(*this,z,c) cimg_for3x3(*this,x,y,z,c,I,Tfloat) *(ptrd++) = (Ipp + Inn - Ipn - Inp)/4;
          }
          else if (axis1=='x' && axis2=='z') { // Ixz
            valid_axis = true; CImg_3x3x3(I,Tfloat);
            cimg_forC(*this,c) cimg_for3x3x3(*this,x,y,z,c,I,Tfloat) *(ptrd++) = (Ipcp + Incn - Ipcn - Incp)/4;
          }
          else if (axis1=='y' && axis2=='y') { // Iyy
            valid_axis = true; CImg_3x3(I,Tfloat);
            cimg_forZC(*this,z,c) cimg_for3x3(*this,x,y,z,c,I,Tfloat) *(ptrd++) = Icp + Icn - 2*Icc;
          }
          else if (axis1=='y' && axis2=='z') { // Iyz
            valid_axis = true; CImg_3x3x3(I,Tfloat);
            cimg_forC(*this,c) cimg_for3x3x3(*this,x,y,z,c,I,Tfloat) *(ptrd++) = (Icpp + Icnn - Icpn - Icnp)/4;
          }
          else if (axis1=='z' && axis2=='z') { // Izz
            valid_axis = true; CImg_3x3x3(I,Tfloat);
            cimg_forC(*this,c) cimg_for3x3x3(*this,x,y,z,c,I,Tfloat) *(ptrd++) = Iccn + Iccp - 2*Iccc;
          }
          else if (!valid_axis)
            throw CImgArgumentException(_cimg_instance
                                        "get_hessian(): Invalid specified axes '%s'.",
                                        cimg_instance,
                                        naxes);
        }
      return res;
    }

    //! Compute image laplacian.
    CImg<T>& laplacian() {
      return get_laplacian().move_to(*this);
    }

    //! Compute image laplacian \newinstance.
    CImg<Tfloat> get_laplacian() const {
      if (is_empty()) return CImg<Tfloat>();
      CImg<Tfloat> res(_width,_height,_depth,_spectrum);
      Tfloat *ptrd = res._data;
      if (_depth>1) { // 3d
        CImg_3x3x3(I,Tfloat);
        cimg_forC(*this,c) cimg_for3x3x3(*this,x,y,z,c,I,Tfloat)
          *(ptrd++) = Incc + Ipcc + Icnc + Icpc + Iccn + Iccp - 6*Iccc;
      } else if (_height>1) { // 2d
        CImg_3x3(I,Tfloat);
        cimg_forC(*this,c) cimg_for3x3(*this,x,y,0,c,I,Tfloat)
          *(ptrd++) = Inc + Ipc + Icn + Icp - 4*Icc;
      } else { // 1d
        CImg_3x3(I,Tfloat);
        cimg_forC(*this,c) cimg_for3x3(*this,x,y,0,c,I,Tfloat)
          *(ptrd++) = Inc + Ipc - 2*Icc;
      }
      return res;
    }

    //! Compute the structure tensor field of an image.
    /**
       \param scheme Numerical scheme. Can be <tt>{ 0=central | 1=fwd/bwd1 | 2=fwd/bwd2 }</tt>
    **/
    CImg<T>& structure_tensors(const unsigned int scheme=2) {
      return get_structure_tensors(scheme).move_to(*this);
    }

    //! Compute the structure tensor field of an image \newinstance.
    CImg<Tfloat> get_structure_tensors(const unsigned int scheme=2) const {
      if (is_empty()) return *this;
      CImg<Tfloat> res;
      if (_depth>1) { // 3d
        res.assign(_width,_height,_depth,6,0);
        CImg_3x3x3(I,Tfloat);
        switch (scheme) {
        case 0 : { // classical central finite differences
          cimg_forC(*this,c) {
            Tfloat
              *ptrd0 = res.data(0,0,0,0), *ptrd1 = res.data(0,0,0,1), *ptrd2 = res.data(0,0,0,2),
              *ptrd3 = res.data(0,0,0,3), *ptrd4 = res.data(0,0,0,4), *ptrd5 = res.data(0,0,0,5);
            cimg_for3x3x3(*this,x,y,z,c,I,Tfloat) {
              const Tfloat
                ix = (Incc - Ipcc)/2,
                iy = (Icnc - Icpc)/2,
                iz = (Iccn - Iccp)/2;
              *(ptrd0++)+=ix*ix;
              *(ptrd1++)+=ix*iy;
              *(ptrd2++)+=ix*iz;
              *(ptrd3++)+=iy*iy;
              *(ptrd4++)+=iy*iz;
              *(ptrd5++)+=iz*iz;
            }
          }
        } break;
        case 1 : { // Forward/backward finite differences (version 1).
          cimg_forC(*this,c) {
            Tfloat
              *ptrd0 = res.data(0,0,0,0), *ptrd1 = res.data(0,0,0,1), *ptrd2 = res.data(0,0,0,2),
              *ptrd3 = res.data(0,0,0,3), *ptrd4 = res.data(0,0,0,4), *ptrd5 = res.data(0,0,0,5);
            cimg_for3x3x3(*this,x,y,z,c,I,Tfloat) {
              const Tfloat
                ixf = Incc - Iccc, ixb = Iccc - Ipcc,
                iyf = Icnc - Iccc, iyb = Iccc - Icpc,
                izf = Iccn - Iccc, izb = Iccc - Iccp;
              *(ptrd0++)+=(ixf*ixf + ixf*ixb + ixb*ixf + ixb*ixb)/4;
              *(ptrd1++)+=(ixf*iyf + ixf*iyb + ixb*iyf + ixb*iyb)/4;
              *(ptrd2++)+=(ixf*izf + ixf*izb + ixb*izf + ixb*izb)/4;
              *(ptrd3++)+=(iyf*iyf + iyf*iyb + iyb*iyf + iyb*iyb)/4;
              *(ptrd4++)+=(iyf*izf + iyf*izb + iyb*izf + iyb*izb)/4;
              *(ptrd5++)+=(izf*izf + izf*izb + izb*izf + izb*izb)/4;
            }
          }
        } break;
        default : { // Forward/backward finite differences (version 2).
          cimg_forC(*this,c) {
            Tfloat
              *ptrd0 = res.data(0,0,0,0), *ptrd1 = res.data(0,0,0,1), *ptrd2 = res.data(0,0,0,2),
              *ptrd3 = res.data(0,0,0,3), *ptrd4 = res.data(0,0,0,4), *ptrd5 = res.data(0,0,0,5);
            cimg_for3x3x3(*this,x,y,z,c,I,Tfloat) {
              const Tfloat
                ixf = Incc - Iccc, ixb = Iccc - Ipcc,
                iyf = Icnc - Iccc, iyb = Iccc - Icpc,
                izf = Iccn - Iccc, izb = Iccc - Iccp;
              *(ptrd0++)+=(ixf*ixf + ixb*ixb)/2;
              *(ptrd1++)+=(ixf*iyf + ixf*iyb + ixb*iyf + ixb*iyb)/4;
              *(ptrd2++)+=(ixf*izf + ixf*izb + ixb*izf + ixb*izb)/4;
              *(ptrd3++)+=(iyf*iyf + iyb*iyb)/2;
              *(ptrd4++)+=(iyf*izf + iyf*izb + iyb*izf + iyb*izb)/4;
              *(ptrd5++)+=(izf*izf + izb*izb)/2;
            }
          }
        } break;
        }
      } else { // 2d
        res.assign(_width,_height,_depth,3,0);
        CImg_3x3(I,Tfloat);
        switch (scheme) {
        case 0 : { // classical central finite differences
          cimg_forC(*this,c) {
            Tfloat *ptrd0 = res.data(0,0,0,0), *ptrd1 = res.data(0,0,0,1), *ptrd2 = res.data(0,0,0,2);
            cimg_for3x3(*this,x,y,0,c,I,Tfloat) {
              const Tfloat
                ix = (Inc - Ipc)/2,
                iy = (Icn - Icp)/2;
              *(ptrd0++)+=ix*ix;
              *(ptrd1++)+=ix*iy;
              *(ptrd2++)+=iy*iy;
            }
          }
        } break;
        case 1 : { // Forward/backward finite differences (version 1).
          cimg_forC(*this,c) {
            Tfloat *ptrd0 = res.data(0,0,0,0), *ptrd1 = res.data(0,0,0,1), *ptrd2 = res.data(0,0,0,2);
            cimg_for3x3(*this,x,y,0,c,I,Tfloat) {
              const Tfloat
                ixf = Inc - Icc, ixb = Icc - Ipc,
                iyf = Icn - Icc, iyb = Icc - Icp;
              *(ptrd0++)+=(ixf*ixf + ixf*ixb + ixb*iyf + ixb*ixb)/4;
              *(ptrd1++)+=(ixf*iyf + ixf*iyb + ixb*iyf + ixb*iyb)/4;
              *(ptrd2++)+=(iyf*iyf + iyf*iyb + iyb*iyf + iyb*iyb)/4;
            }
          }
        } break;
        default : { // Forward/backward finite differences (version 2).
          cimg_forC(*this,c) {
            Tfloat *ptrd0 = res.data(0,0,0,0), *ptrd1 = res.data(0,0,0,1), *ptrd2 = res.data(0,0,0,2);
            cimg_for3x3(*this,x,y,0,c,I,Tfloat) {
              const Tfloat
                ixf = Inc - Icc, ixb = Icc - Ipc,
                iyf = Icn - Icc, iyb = Icc - Icp;
              *(ptrd0++)+=(ixf*ixf + ixb*ixb)/2;
              *(ptrd1++)+=(ixf*iyf + ixf*iyb + ixb*iyf + ixb*iyb)/4;
              *(ptrd2++)+=(iyf*iyf + iyb*iyb)/2;
            }
          }
        } break;
        }
      }
      return res;
    }

    //! Compute field of diffusion tensors for edge-preserving smoothing.
    /**
       \param sharpness Sharpness
       \param anisotropy Anisotropy
       \param alpha Standard deviation of the gradient blur.
       \param sigma Standard deviation of the structure tensor blur.
       \param is_sqrt Tells if the square root of the tensor field is computed instead.
    **/
    CImg<T>& diffusion_tensors(const float sharpness=0.7f, const float anisotropy=0.6f,
                               const float alpha=0.6f, const float sigma=1.1f, const bool is_sqrt=false) {
      CImg<Tfloat> res;
      const float nsharpness = cimg::max(sharpness,1e-5f), power1 = (is_sqrt?0.5f:1)*nsharpness, power2 = power1/(1e-7f+1-anisotropy);
      blur(alpha).normalize(0,(T)255);

      if (_depth>1) { // 3d
        CImg<floatT> val(3), vec(3,3);
        get_structure_tensors().move_to(res).blur(sigma);
        Tfloat
          *ptrd0 = res.data(0,0,0,0), *ptrd1 = res.data(0,0,0,1), *ptrd2 = res.data(0,0,0,2),
          *ptrd3 = res.data(0,0,0,3), *ptrd4 = res.data(0,0,0,4), *ptrd5 = res.data(0,0,0,5);
        cimg_forXYZ(*this,x,y,z) {
          res.get_tensor_at(x,y,z).symmetric_eigen(val,vec);
          const float
            _l1 = val[2], _l2 = val[1], _l3 = val[0],
            l1 = _l1>0?_l1:0, l2 = _l2>0?_l2:0, l3 = _l3>0?_l3:0,
            ux = vec(0,0), uy = vec(0,1), uz = vec(0,2),
            vx = vec(1,0), vy = vec(1,1), vz = vec(1,2),
            wx = vec(2,0), wy = vec(2,1), wz = vec(2,2),
            n1 = (float)std::pow(1+l1+l2+l3,-power1),
            n2 = (float)std::pow(1+l1+l2+l3,-power2);
          *(ptrd0++) = n1*(ux*ux + vx*vx) + n2*wx*wx;
          *(ptrd1++) = n1*(ux*uy + vx*vy) + n2*wx*wy;
          *(ptrd2++) = n1*(ux*uz + vx*vz) + n2*wx*wz;
          *(ptrd3++) = n1*(uy*uy + vy*vy) + n2*wy*wy;
          *(ptrd4++) = n1*(uy*uz + vy*vz) + n2*wy*wz;
          *(ptrd5++) = n1*(uz*uz + vz*vz) + n2*wz*wz;
        }
      } else { // for 2d images
        CImg<floatT> val(2), vec(2,2);
        get_structure_tensors().move_to(res).blur(sigma);
        Tfloat *ptrd0 = res.data(0,0,0,0), *ptrd1 = res.data(0,0,0,1), *ptrd2 = res.data(0,0,0,2);
        cimg_forXY(*this,x,y) {
          res.get_tensor_at(x,y).symmetric_eigen(val,vec);
          const float
            _l1 = val[1], _l2 = val[0],
            l1 = _l1>0?_l1:0, l2 = _l2>0?_l2:0,
            ux = vec(1,0), uy = vec(1,1),
            vx = vec(0,0), vy = vec(0,1),
            n1 = (float)std::pow(1+l1+l2,-power1),
            n2 = (float)std::pow(1+l1+l2,-power2);
          *(ptrd0++) = n1*ux*ux + n2*vx*vx;
          *(ptrd1++) = n1*ux*uy + n2*vx*vy;
          *(ptrd2++) = n1*uy*uy + n2*vy*vy;
        }
      }
      return res.move_to(*this);
    }

    //! Compute field of diffusion tensors for edge-preserving smoothing \newinstance.
    CImg<Tfloat> get_diffusion_tensors(const float sharpness=0.7f, const float anisotropy=0.6f,
                                       const float alpha=0.6f, const float sigma=1.1f, const bool is_sqrt=false) const {
      return CImg<Tfloat>(*this,false).diffusion_tensors(sharpness,anisotropy,alpha,sigma,is_sqrt);
    }

    //! Estimate displacement field between two images.
    /**
       \param source Reference image.
       \param smoothness Smoothness of estimated displacement field.
       \param precision Precision required for algorithm convergence.
       \param nb_scales Number of scales used to estimate the displacement field.
       \param iteration_max Maximum number of iterations allowed for one scale.
       \param is_backward If false, match I2(X+U(X)) = I1(X), else match I2(X) = I1(X-U(X)).
    **/
    CImg<T>& displacement(const CImg<T>& source, const float smoothness=0.1f, const float precision=5.0f,
                          const unsigned int nb_scales=0, const unsigned int iteration_max=10000,
                          const bool is_backward=false) {
      return get_displacement(source,smoothness,precision,nb_scales,iteration_max,is_backward).move_to(*this);
    }

    //! Estimate displacement field between two images \newinstance.
    CImg<Tfloat> get_displacement(const CImg<T>& source,
                                  const float smoothness=0.1f, const float precision=5.0f,
                                  const unsigned int nb_scales=0, const unsigned int iteration_max=10000,
                                  const bool is_backward=false) const {
      if (is_empty() || !source) return +*this;
      if (!is_sameXYZC(source))
        throw CImgArgumentException(_cimg_instance
                                    "displacement(): Instance and source image (%u,%u,%u,%u,%p) have different dimensions.",
                                    cimg_instance,
                                    source._width,source._height,source._depth,source._spectrum,source._data);
      if (precision<0)
        throw CImgArgumentException(_cimg_instance
                                    "displacement(): Invalid specified precision %g "
                                    "(should be >=0)",
                                    cimg_instance,
                                    precision);
      const unsigned int _nb_scales = nb_scales>0?nb_scales:(unsigned int)(2*std::log((double)(cimg::max(_width,_height))));
      const float _precision = (float)std::pow(10.0,-(double)precision);
      float sm, sM = source.max_min(sm), tm, tM = max_min(tm);
      const float sdelta = sm==sM?1:(sM - sm), tdelta = tm==tM?1:(tM - tm);
      const bool is_3d = source._depth>1;
      CImg<floatT> U;

      for (int scale = _nb_scales-1; scale>=0; --scale) {
        const float factor = (float)std::pow(1.5,(double)scale);
        const unsigned int
          _sw = (unsigned int)(_width/factor), sw = _sw?_sw:1,
          _sh = (unsigned int)(_height/factor), sh = _sh?_sh:1,
          _sd = (unsigned int)(_depth/factor), sd = _sd?_sd:1;
        if (sw<5 && sh<5 && (!is_3d || sd<5)) continue;  // skip too small scales.
        const CImg<Tfloat>
          I1 = (source.get_resize(sw,sh,sd,-100,2)-=sm)/=sdelta,
          I2 = (get_resize(I1,2)-=tm)/=tdelta;
        if (U) (U*=1.5f).resize(I2._width,I2._height,I2._depth,-100,3);
        else U.assign(I2._width,I2._height,I2._depth,is_3d?3:2,0);
        float dt = 2, energy = cimg::type<float>::max();
        const CImgList<Tfloat> dI = is_backward?I1.get_gradient():I2.get_gradient();

        for (unsigned int iteration = 0; iteration<iteration_max; ++iteration) {
          float _energy = 0;
          if (is_3d) { // 3d version.
            if (smoothness>=0) cimg_for3XYZ(U,x,y,z) { // Isotropic regularization.
                const float
                  X = is_backward?x - U(x,y,z,0):x + U(x,y,z,0),
                  Y = is_backward?y - U(x,y,z,1):y + U(x,y,z,1),
                  Z = is_backward?z - U(x,y,z,2):z + U(x,y,z,2);
                float delta_I = 0, _energy_regul = 0;
                if (is_backward) cimg_forC(I2,c) delta_I+=(float)(I1.linear_atXYZ(X,Y,Z,c) - I2(x,y,z,c));
                else cimg_forC(I2,c) delta_I+=(float)(I1(x,y,z,c) - I2.linear_atXYZ(X,Y,Z,c));
                cimg_forC(U,c) {
                  const float
                    Ux = 0.5f*(U(_n1x,y,z,c) - U(_p1x,y,z,c)),
                    Uy = 0.5f*(U(x,_n1y,z,c) - U(x,_p1y,z,c)),
                    Uz = 0.5f*(U(x,y,_n1z,c) - U(x,y,_p1z,c)),
                    Uxx = U(_n1x,y,z,c) + U(_p1x,y,z,c),
                    Uyy = U(x,_n1y,z,c) + U(x,_p1y,z,c),
                    Uzz = U(x,y,_n1z,c) + U(x,y,_p1z,c);
                  U(x,y,z,c) = (float)(U(x,y,z,c) + dt*(delta_I*dI[c].linear_atXYZ(X,Y,Z) + smoothness* ( Uxx + Uyy + Uzz)))/(1+6*smoothness*dt);
                  _energy_regul+=Ux*Ux + Uy*Uy + Uz*Uz;
                }
                _energy+=delta_I*delta_I + smoothness*_energy_regul;
              } else {
              const float nsmoothness = -smoothness;
              cimg_for3XYZ(U,x,y,z) { // Anisotropic regularization.
                const float
                  X = is_backward?x - U(x,y,z,0):x + U(x,y,z,0),
                  Y = is_backward?y - U(x,y,z,1):y + U(x,y,z,1),
                  Z = is_backward?z - U(x,y,z,2):z + U(x,y,z,2);
                float delta_I = 0, _energy_regul = 0;
                if (is_backward) cimg_forC(I2,c) delta_I+=(float)(I1.linear_atXYZ(X,Y,Z,c) - I2(x,y,z,c));
                else cimg_forC(I2,c) delta_I+=(float)(I1(x,y,z,c) - I2.linear_atXYZ(X,Y,Z,c));
                cimg_forC(U,c) {
                  const float
                    Ux = 0.5f*(U(_n1x,y,z,c) - U(_p1x,y,z,c)),
                    Uy = 0.5f*(U(x,_n1y,z,c) - U(x,_p1y,z,c)),
                    Uz = 0.5f*(U(x,y,_n1z,c) - U(x,y,_p1z,c)),
                    N2 = Ux*Ux + Uy*Uy + Uz*Uz,
                    N = std::sqrt(N2),
                    N3 = 1e-5f + N2*N,
                    coef_a = (1 - Ux*Ux/N2)/N,
                    coef_b = -2*Ux*Uy/N3,
                    coef_c = -2*Ux*Uz/N3,
                    coef_d = (1 - Uy*Uy/N2)/N,
                    coef_e = -2*Uy*Uz/N3,
                    coef_f = (1 - Uz*Uz/N2)/N,
                    Uxx = U(_n1x,y,z,c) + U(_p1x,y,z,c),
                    Uyy = U(x,_n1y,z,c) + U(x,_p1y,z,c),
                    Uzz = U(x,y,_n1z,c) + U(x,y,_p1z,c),
                    Uxy = 0.25f*(U(_n1x,_n1y,z,c) + U(_p1x,_p1y,z,c) - U(_n1x,_p1y,z,c) - U(_n1x,_p1y,z,c)),
                    Uxz = 0.25f*(U(_n1x,y,_n1z,c) + U(_p1x,y,_p1z,c) - U(_n1x,y,_p1z,c) - U(_n1x,y,_p1z,c)),
                    Uyz = 0.25f*(U(x,_n1y,_n1z,c) + U(x,_p1y,_p1z,c) - U(x,_n1y,_p1z,c) - U(x,_n1y,_p1z,c));
                  U(x,y,z,c) = (float)(U(x,y,z,c) + dt*(delta_I*dI[c].linear_atXYZ(X,Y,Z) +
                                                        nsmoothness* ( coef_a*Uxx + coef_b*Uxy + coef_c*Uxz + coef_d*Uyy + coef_e*Uyz + coef_f*Uzz ))
                                       )/(1+2*(coef_a+coef_d+coef_f)*nsmoothness*dt);
                  _energy_regul+=N;
                }
                _energy+=delta_I*delta_I + nsmoothness*_energy_regul;
              }
            }
          } else { // 2d version.
            if (smoothness>=0) cimg_for3XY(U,x,y) { // Isotropic regularization.
                const float
                  X = is_backward?x - U(x,y,0):x + U(x,y,0),
                  Y = is_backward?y - U(x,y,1):y + U(x,y,1);
                float delta_I = 0, _energy_regul = 0;
                if (is_backward) cimg_forC(I2,c) delta_I+=(float)(I1.linear_atXY(X,Y,c) - I2(x,y,c));
                else cimg_forC(I2,c) delta_I+=(float)(I1(x,y,c) - I2.linear_atXY(X,Y,c));
                cimg_forC(U,c) {
                  const float
                    Ux = 0.5f*(U(_n1x,y,c) - U(_p1x,y,c)),
                    Uy = 0.5f*(U(x,_n1y,c) - U(x,_p1y,c)),
                    Uxx = U(_n1x,y,c) + U(_p1x,y,c),
                    Uyy = U(x,_n1y,c) + U(x,_p1y,c);
                  U(x,y,c) = (float)(U(x,y,c) + dt*(delta_I*dI[c].linear_atXY(X,Y) + smoothness*( Uxx + Uyy )))/(1+4*smoothness*dt);
                  _energy_regul+=Ux*Ux + Uy*Uy;
                }
                _energy+=delta_I*delta_I + smoothness*_energy_regul;
              } else {
              const float nsmoothness = -smoothness;
              cimg_for3XY(U,x,y) { // Anisotropic regularization.
                const float
                  X = is_backward?x - U(x,y,0):x + U(x,y,0),
                  Y = is_backward?y - U(x,y,1):y + U(x,y,1);
                float delta_I = 0, _energy_regul = 0;
                if (is_backward) cimg_forC(I2,c) delta_I+=(float)(I1.linear_atXY(X,Y,c) - I2(x,y,c));
                else cimg_forC(I2,c) delta_I+=(float)(I1(x,y,c) - I2.linear_atXY(X,Y,c));
                cimg_forC(U,c) {
                  const float
                    Ux = 0.5f*(U(_n1x,y,c) - U(_p1x,y,c)),
                    Uy = 0.5f*(U(x,_n1y,c) - U(x,_p1y,c)),
                    N2 = Ux*Ux + Uy*Uy,
                    N = std::sqrt(N2),
                    N3 = 1e-5f + N2*N,
                    coef_a = Uy*Uy/N3,
                    coef_b = -2*Ux*Uy/N3,
                    coef_c = Ux*Ux/N3,
                    Uxx = U(_n1x,y,c) + U(_p1x,y,c),
                    Uyy = U(x,_n1y,c) + U(x,_p1y,c),
                    Uxy = 0.25f*(U(_n1x,_n1y,c) + U(_p1x,_p1y,c) - U(_n1x,_p1y,c) - U(_n1x,_p1y,c));
                  U(x,y,c) = (float)(U(x,y,c) + dt*(delta_I*dI[c].linear_atXY(X,Y) + nsmoothness*( coef_a*Uxx + coef_b*Uxy + coef_c*Uyy )))/(1+2*(coef_a+coef_c)*nsmoothness*dt);
                  _energy_regul+=N;
                }
                _energy+=delta_I*delta_I + nsmoothness*_energy_regul;
              }
            }
          }
          const float d_energy = (_energy - energy)/(sw*sh*sd);
          if (d_energy<=0 && -d_energy<_precision) break;
          if (d_energy>0) dt*=0.5f;
          energy = _energy;
        }
      }
      return U;
    }

    //! Compute Euclidean distance function to a specified value.
    /**
        \param value Reference value.
        \param metric Type of metric. Can be <tt>{ 0=Chebyshev | 1=Manhattan | 2=Euclidean | 3=Squared-euclidean }</tt>.
        \note
        The distance transform implementation has been submitted by A. Meijster, and implements
        the article 'W.H. Hesselink, A. Meijster, J.B.T.M. Roerdink,
                     "A general algorithm for computing distance transforms in linear time.",
                     In: Mathematical Morphology and its Applications to Image and Signal Processing,
                     J. Goutsias, L. Vincent, and D.S. Bloomberg (eds.), Kluwer, 2000, pp. 331-340.'
         The submitted code has then been modified to fit CImg coding style and constraints.
    **/
    CImg<T>& distance(const T value, const unsigned int metric=2) {
      if (is_empty()) return *this;
      bool is_value = false;
      cimg_for(*this,ptr,T) *ptr = *ptr==value?is_value=true,0:(T)999999999;
      if (!is_value) return fill(cimg::type<T>::max());
      switch (metric) {
      case 0 : return _distance_core(_distance_sep_cdt,_distance_dist_cdt);          // Chebyshev.
      case 1 : return _distance_core(_distance_sep_mdt,_distance_dist_mdt);          // Manhattan.
      case 3 : return _distance_core(_distance_sep_edt,_distance_dist_edt);          // Squared Euclidean.
      default : return _distance_core(_distance_sep_edt,_distance_dist_edt).sqrt();  // Euclidean.
      }
      return *this;
    }

    //! Compute distance to a specified value \newinstance.
    CImg<Tfloat> get_distance(const T value, const unsigned int metric=2) const {
      return CImg<Tfloat>(*this,false).distance((Tfloat)value,metric);
    }

    static long _distance_sep_edt(const long i, const long u, const long *const g) {
      return (u*u-i*i+g[u]-g[i])/(2*(u-i));
    }

    static long _distance_dist_edt(const long x, const long i, const long *const g) {
      return (x-i)*(x-i) + g[i];
    }

    static long _distance_sep_mdt(const long i, const long u, const long *const g) {
      return (u-i<=g[u]-g[i]?999999999:(g[u]-g[i]+u+i)/2);
    }

    static long _distance_dist_mdt(const long x, const long i, const long *const g) {
      return (x<i?i-x:x-i) + g[i];
    }

    static long _distance_sep_cdt(const long i, const long u, const long *const g) {
      const long h = (i+u)/2;
      if (g[i]<=g[u]) { return h<i+g[u]?i+g[u]:h; }
      return h<u-g[i]?h:u-g[i];
    }

    static long _distance_dist_cdt(const long x, const long i, const long *const g) {
      const long d = x<i?i-x:x-i;
      return d<g[i]?g[i]:d;
    }

    static void _distance_scan(const unsigned int len,
                               const long *const g,
                               long (*const sep)(const long, const long, const long *const),
                               long (*const f)(const long, const long, const long *const),
                               long *const s,
                               long *const t,
                               long *const dt) {
      long q = s[0] = t[0] = 0;
      for (int u = 1; u<(int)len; ++u) { // Forward scan.
        while ((q>=0) && f(t[q],s[q],g)>f(t[q],u,g)) { --q; }
        if (q<0) { q = 0; s[0] = u; }
        else { const long w = 1 + sep(s[q], u, g); if (w<(long)len) { ++q; s[q] = u; t[q] = w; }}
      }
      for (int u = (int)len-1; u>=0; --u) { dt[u] = f(u,s[q],g); if (u==t[q]) --q; } // Backward scan.
    }

    CImg<T>& _distance_core(long (*const sep)(const long, const long, const long *const),
                            long (*const f)(const long, const long, const long *const)) {
      const unsigned long wh = (unsigned long)_width*_height;
      cimg_forC(*this,c) {
        CImg<longT> g(_width), dt(_width), s(_width), t(_width);
        CImg<T> img = get_shared_channel(c);
        cimg_forYZ(*this,y,z) { // Over X-direction.
          cimg_forX(*this,x) g[x] = (long)img(x,y,z,0,wh);
          _distance_scan(_width,g,sep,f,s,t,dt);
          cimg_forX(*this,x) img(x,y,z,0,wh) = (T)dt[x];
        }
        g.assign(_height); dt.assign(_height); s.assign(_height); t.assign(_height);
        cimg_forXZ(*this,x,z) { // Over Y-direction.
          cimg_forY(*this,y) g[y] = (long)img(x,y,z,0,wh);
          _distance_scan(_height,g,sep,f,s,t,dt);
          cimg_forY(*this,y) img(x,y,z,0,wh) = (T)dt[y];
        }
        if (_depth>1) {
          g.assign(_depth); dt.assign(_depth); s.assign(_depth); t.assign(_depth);
          cimg_forXY(*this,x,y) { // Over Z-direction.
            cimg_forZ(*this,z) g[z] = (long)img(x,y,z,0,wh);
            _distance_scan(_depth,g,sep,f,s,t,dt);
            cimg_forZ(*this,z) img(x,y,z,0,wh) = (T)dt[z];
          }
        }
      }
      return *this;
    }

    //! Compute chamfer distance to a specified value, with a custom metric.
    /**
       \param value Reference value.
       \param metric_mask Metric mask.
       \note The algorithm code has been initially proposed by A. Meijster, and modified by D. Tschumperlé.
    **/
    template<typename t>
    CImg<T>& distance(const T value, const CImg<t>& metric_mask) {
      if (is_empty()) return *this;
      bool is_value = false;
      cimg_for(*this,ptr,T) *ptr = *ptr==value?is_value=true,0:(T)999999999;
      if (!is_value) return fill(cimg::type<T>::max());
      const unsigned long wh = (unsigned long)_width*_height;
      cimg_forC(*this,c) {
        CImg<T> img = get_shared_channel(c);
        cimg_forXYZ(metric_mask,dx,dy,dz) {
          const t weight = metric_mask(dx,dy,dz);
          if (weight) {
            for (int z = dz, nz = 0; z<depth(); ++z,++nz) { // Forward scan.
              for (int y = dy , ny = 0; y<height(); ++y,++ny) {
                for (int x = dx, nx = 0; x<width(); ++x,++nx) {
                  const T dd = img(nx,ny,nz,0,wh) + weight;
                  if (dd<img(x,y,z,0,wh)) img(x,y,z,0,wh) = dd;
                }
              }
            }
            for (int z = depth() - 1 - dz, nz = depth() - 1; z>=0; --z,--nz) { // Backward scan.
              for (int y = height() - 1 - dy, ny = height() - 1; y>=0; --y,--ny) {
                for (int x = width() - 1 - dx, nx = width() - 1; x>=0; --x,--nx) {
                  const T dd = img(nx,ny,nz,0,wh) + weight;
                  if (dd<img(x,y,z,0,wh)) img(x,y,z,0,wh) = dd;
                }
              }
            }
          }
        }
      }
      return *this;
    }

    //! Compute chamfer distance to a specified value, with a custom metric \newinstance.
    template<typename t>
    CImg<Tfloat> get_distance(const T value, const CImg<t>& metric_mask) const {
      return CImg<Tfloat>(*this,false).distance(value,metric_mask);
    }

    //! Compute distance to a specified value, according to a custom metric (use dijkstra algorithm).
    /**
       \param value Reference value.
       \param metric Field of distance potentials.
       \param is_high_connectivity Tells if the algorithm uses low or high connectivity.
     **/
    template<typename t, typename to>
    CImg<T>& distance_dijkstra(const T value, const CImg<t>& metric, const bool is_high_connectivity, CImg<to>& return_path) {
      return get_distance_dijkstra(value,metric,is_high_connectivity,return_path).move_to(*this);
    }

    //! Compute distance map to a specified value, according to a custom metric (use dijkstra algorithm). \newinstance.
    template<typename t, typename to>
    CImg<Tfloat> get_distance_dijkstra(const T value, const CImg<t>& metric, const bool is_high_connectivity, CImg<to>& return_path) const {
      if (is_empty()) return return_path.assign();
      if (!is_sameXYZ(metric))
        throw CImgArgumentException(_cimg_instance
                                    "distance_dijkstra(): image instance and metric map (%u,%u,%u,%u) have incompatible dimensions.",
                                    cimg_instance,
                                    metric._width,metric._height,metric._depth,metric._spectrum);
      CImg<Tfloat> result(_width,_height,_depth,_spectrum);
      CImg<boolT> is_queued(_width,_height,_depth,1);
      CImg<Tint> Q;
      if (return_path) return_path.assign(_width,_height,_depth,_spectrum);

      cimg_forC(*this,c) {
        const CImg<T> img = get_shared_channel(c);
        const CImg<t> met = metric.get_shared_channel(c%metric._spectrum);
        CImg<Tfloat> res = result.get_shared_channel(c);
        CImg<to> path = return_path?return_path.get_shared_channel(c):CImg<to>();
        unsigned int sizeQ = 0;

        // Detect initial seeds.
        is_queued.fill(0);
        cimg_forXYZ(img,x,y,z) if (img(x,y,z)==value) {
          Q._priority_queue_insert(is_queued,sizeQ,0,x,y,z);
          res(x,y,z) = 0;
          if (path) path(x,y,z) = (to)0;
        }

        // Start distance propagation.
        while (sizeQ) {

          // Get and remove point with minimal potential from the queue.
          const int x = (int)Q(0,1), y = (int)Q(0,2), z = (int)Q(0,3);
          const Tfloat P = (Tfloat)-Q(0,0);
          Q._priority_queue_remove(sizeQ);

          // Update neighbors.
          Tfloat npot = 0;
          if (x-1>=0 && Q._priority_queue_insert(is_queued,sizeQ,-(npot=met(x-1,y,z)+P),x-1,y,z)) {
            res(x-1,y,z) = npot; if (path) path(x-1,y,z) = (to)2;
          }
          if (x+1<width() && Q._priority_queue_insert(is_queued,sizeQ,-(npot=met(x+1,y,z)+P),x+1,y,z)) {
            res(x+1,y,z) = npot; if (path) path(x+1,y,z) = (to)1;
          }
          if (y-1>=0 && Q._priority_queue_insert(is_queued,sizeQ,-(npot=met(x,y-1,z)+P),x,y-1,z)) {
            res(x,y-1,z) = npot; if (path) path(x,y-1,z) = (to)8;
          }
          if (y+1<height() && Q._priority_queue_insert(is_queued,sizeQ,-(npot=met(x,y+1,z)+P),x,y+1,z)) {
            res(x,y+1,z) = npot; if (path) path(x,y+1,z) = (to)4;
          }
          if (z-1>=0 && Q._priority_queue_insert(is_queued,sizeQ,-(npot=met(x,y,z-1)+P),x,y,z-1)) {
            res(x,y,z-1) = npot; if (path) path(x,y,z-1) = (to)32;
          }
          if (z+1<depth() && Q._priority_queue_insert(is_queued,sizeQ,-(npot=met(x,y,z+1)+P),x,y,z+1)) {
            res(x,y,z+1) = npot; if (path) path(x,y,z+1) = (to)16;
          }

          if (is_high_connectivity) {
            const float sqrt2 = std::sqrt(2.0f), sqrt3 = std::sqrt(3.0f);

            // Diagonal neighbors on slice z.
            if (x-1>=0 && y-1>=0 && Q._priority_queue_insert(is_queued,sizeQ,-(npot=sqrt2*met(x-1,y-1,z)+P),x-1,y-1,z)) {
              res(x-1,y-1,z) = npot; if (path) path(x-1,y-1,z) = (to)10;
            }
            if (x+1<width() && y-1>=0 && Q._priority_queue_insert(is_queued,sizeQ,-(npot=sqrt2*met(x+1,y-1,z)+P),x+1,y-1,z)) {
              res(x+1,y-1,z) = npot; if (path) path(x+1,y-1,z) = (to)9;
            }
            if (x-1>=0 && y+1<height() && Q._priority_queue_insert(is_queued,sizeQ,-(npot=sqrt2*met(x-1,y+1,z)+P),x-1,y+1,z)) {
              res(x-1,y+1,z) = npot; if (path) path(x-1,y+1,z) = (to)6;
            }
            if (x+1<width() && y+1<height() && Q._priority_queue_insert(is_queued,sizeQ,-(npot=sqrt2*met(x+1,y+1,z)+P),x+1,y+1,z)) {
              res(x+1,y+1,z) = npot; if (path) path(x+1,y+1,z) = (to)5;
            }

            if (z-1>=0) { // Diagonal neighbors on slice z-1.
              if (x-1>=0 && Q._priority_queue_insert(is_queued,sizeQ,-(npot=sqrt2*met(x-1,y,z-1)+P),x-1,y,z-1)) {
                res(x-1,y,z-1) = npot; if (path) path(x-1,y,z-1) = (to)34;
              }
              if (x+1<width() && Q._priority_queue_insert(is_queued,sizeQ,-(npot=sqrt2*met(x+1,y,z-1)+P),x+1,y,z-1)) {
                res(x+1,y,z-1) = npot; if (path) path(x+1,y,z-1) = (to)33;
              }
              if (y-1>=0 && Q._priority_queue_insert(is_queued,sizeQ,-(npot=sqrt2*met(x,y-1,z-1)+P),x,y-1,z-1)) {
                res(x,y-1,z-1) = npot; if (path) path(x,y-1,z-1) = (to)40;
              }
              if (y+1<height() && Q._priority_queue_insert(is_queued,sizeQ,-(npot=sqrt2*met(x,y+1,z-1)+P),x,y+1,z-1)) {
                res(x,y+1,z-1) = npot; if (path) path(x,y+1,z-1) = (to)36;
              }
              if (x-1>=0 && y-1>=0 && Q._priority_queue_insert(is_queued,sizeQ,-(npot=sqrt3*met(x-1,y-1,z-1)+P),x-1,y-1,z-1)) {
                res(x-1,y-1,z-1) = npot; if (path) path(x-1,y-1,z-1) = (to)42;
              }
              if (x+1<width() && y-1>=0 && Q._priority_queue_insert(is_queued,sizeQ,-(npot=sqrt3*met(x+1,y-1,z-1)+P),x+1,y-1,z-1)) {
                res(x+1,y-1,z-1) = npot; if (path) path(x+1,y-1,z-1) = (to)41;
              }
              if (x-1>=0 && y+1<height() && Q._priority_queue_insert(is_queued,sizeQ,-(npot=sqrt3*met(x-1,y+1,z-1)+P),x-1,y+1,z-1)) {
                res(x-1,y+1,z-1) = npot; if (path) path(x-1,y+1,z-1) = (to)38;
              }
              if (x+1<width() && y+1<height() && Q._priority_queue_insert(is_queued,sizeQ,-(npot=sqrt3*met(x+1,y+1,z-1)+P),x+1,y+1,z-1)) {
                res(x+1,y+1,z-1) = npot; if (path) path(x+1,y+1,z-1) = (to)37;
              }
            }

            if (z+1<depth()) { // Diagonal neighbors on slice z+1.
              if (x-1>=0 && Q._priority_queue_insert(is_queued,sizeQ,-(npot=sqrt2*met(x-1,y,z+1)+P),x-1,y,z+1)) {
                res(x-1,y,z+1) = npot; if (path) path(x-1,y,z+1) = (to)18;
              }
              if (x+1<width() && Q._priority_queue_insert(is_queued,sizeQ,-(npot=sqrt2*met(x+1,y,z+1)+P),x+1,y,z+1)) {
                res(x+1,y,z+1) = npot; if (path) path(x+1,y,z+1) = (to)17;
              }
              if (y-1>=0 && Q._priority_queue_insert(is_queued,sizeQ,-(npot=sqrt2*met(x,y-1,z+1)+P),x,y-1,z+1)) {
                res(x,y-1,z+1) = npot; if (path) path(x,y-1,z+1) = (to)24;
              }
              if (y+1<height() && Q._priority_queue_insert(is_queued,sizeQ,-(npot=sqrt2*met(x,y+1,z+1)+P),x,y+1,z+1)) {
                res(x,y+1,z+1) = npot; if (path) path(x,y+1,z+1) = (to)20;
              }
              if (x-1>=0 && y-1>=0 && Q._priority_queue_insert(is_queued,sizeQ,-(npot=sqrt3*met(x-1,y-1,z+1)+P),x-1,y-1,z+1)) {
                res(x-1,y-1,z+1) = npot; if (path) path(x-1,y-1,z+1) = (to)26;
              }
              if (x+1<width() && y-1>=0 && Q._priority_queue_insert(is_queued,sizeQ,-(npot=sqrt3*met(x+1,y-1,z+1)+P),x+1,y-1,z+1)) {
                res(x+1,y-1,z+1) = npot; if (path) path(x+1,y-1,z+1) = (to)25;
              }
              if (x-1>=0 && y+1<height() && Q._priority_queue_insert(is_queued,sizeQ,-(npot=sqrt3*met(x-1,y+1,z+1)+P),x-1,y+1,z+1)) {
                res(x-1,y+1,z+1) = npot; if (path) path(x-1,y+1,z+1) = (to)22;
              }
              if (x+1<width() && y+1<height() && Q._priority_queue_insert(is_queued,sizeQ,-(npot=sqrt3*met(x+1,y+1,z+1)+P),x+1,y+1,z+1)) {
                res(x+1,y+1,z+1) = npot; if (path) path(x+1,y+1,z+1) = (to)21;
              }
            }
          }
        }
      }
      return result;
    }

    //! Compute distance map to a specified value, according to a custom metric (use dijkstra algorithm). \overloading.
    template<typename t>
    CImg<T>& distance_dijkstra(const T value, const CImg<t>& metric, const bool is_high_connectivity=false) {
      return get_distance_dijkstra(value,metric,is_high_connectivity).move_to(*this);
    }

    //! Compute distance map to a specified value, according to a custom metric (use dijkstra algorithm). \newinstance.
    template<typename t>
    CImg<Tfloat> get_distance_dijkstra(const T value, const CImg<t>& metric, const bool is_high_connectivity=false) const {
      CImg<T> return_path;
      return get_distance_dijkstra(value,metric,is_high_connectivity,return_path);
    }

    //! Compute distance map to one source point, according to a custom metric (use fast marching algorithm).
    /**
       \param value Reference value.
       \param metric Field of distance potentials.
     **/
    template<typename t>
    CImg& distance_eikonal(const T value, const CImg<t>& metric) {
      return get_distance_eikonal(value,metric).move_to(*this);
    }

    //! Compute distance map to one source point, according to a custom metric (use fast marching algorithm).
    template<typename t>
    CImg<Tfloat> get_distance_eikonal(const T value, const CImg<t>& metric) const {
      if (is_empty()) return *this;
      if (!is_sameXYZ(metric))
        throw CImgArgumentException(_cimg_instance
                                    "distance_eikonal(): image instance and metric map (%u,%u,%u,%u) have incompatible dimensions.",
                                    cimg_instance,
                                    metric._width,metric._height,metric._depth,metric._spectrum);
      CImg<Tfloat> result(_width,_height,_depth,_spectrum,cimg::type<Tfloat>::max()),Q;
      CImg<charT> state(_width,_height,_depth); // -1=far away, 0=narrow, 1=frozen.

      cimg_forC(*this,c) {
        const CImg<T> img = get_shared_channel(c);
        const CImg<t> met = metric.get_shared_channel(c%metric._spectrum);
        CImg<Tfloat> res = result.get_shared_channel(c);
        unsigned int sizeQ = 0;
        state.fill(-1);

        // Detect initial seeds.
        Tfloat *ptr1 = res._data; char *ptr2 = state._data;
        cimg_for(img,ptr0,T) { if (*ptr0==value) { *ptr1 = 0; *ptr2 = 1; } ++ptr1; ++ptr2; }

        // Initialize seeds neighbors.
        ptr2 = state._data;
        cimg_forXYZ(img,x,y,z) if (*(ptr2++)==1) {
          if (x-1>=0 && state(x-1,y,z)==-1) {
            const Tfloat dist = res(x-1,y,z) = __distance_eikonal(res,met(x-1,y,z),x-1,y,z);
            Q._eik_priority_queue_insert(state,sizeQ,-dist,x-1,y,z);
          }
          if (x+1<width() && state(x+1,y,z)==-1) {
            const Tfloat dist = res(x+1,y,z) = __distance_eikonal(res,met(x+1,y,z),x+1,y,z);
            Q._eik_priority_queue_insert(state,sizeQ,-dist,x+1,y,z);
          }
          if (y-1>=0 && state(x,y-1,z)==-1) {
            const Tfloat dist = res(x,y-1,z) = __distance_eikonal(res,met(x,y-1,z),x,y-1,z);
            Q._eik_priority_queue_insert(state,sizeQ,-dist,x,y-1,z);
          }
          if (y+1<height() && state(x,y+1,z)==-1) {
            const Tfloat dist = res(x,y+1,z) = __distance_eikonal(res,met(x,y+1,z),x,y+1,z);
            Q._eik_priority_queue_insert(state,sizeQ,-dist,x,y+1,z);
          }
          if (z-1>=0 && state(x,y,z-1)==-1) {
            const Tfloat dist = res(x,y,z-1) = __distance_eikonal(res,met(x,y,z-1),x,y,z-1);
            Q._eik_priority_queue_insert(state,sizeQ,-dist,x,y,z-1);
          }
          if (z+1<depth() && state(x,y,z+1)==-1) {
            const Tfloat dist = res(x,y,z+1) = __distance_eikonal(res,met(x,y,z+1),x,y,z+1);
            Q._eik_priority_queue_insert(state,sizeQ,-dist,x,y,z+1);
          }
        }

        // Propagate front.
        while (sizeQ) {
          int x = -1, y = -1, z = -1;
          while (sizeQ && x<0) {
            x = (int)Q(0,1); y = (int)Q(0,2); z = (int)Q(0,3);
            Q._priority_queue_remove(sizeQ);
            if (state(x,y,z)==1) x = -1; else state(x,y,z) = 1;
          }
          if (x>=0) {
            if (x-1>=0 && state(x-1,y,z)!=1) {
              const Tfloat dist = __distance_eikonal(res,met(x-1,y,z),x-1,y,z);
              if (dist<res(x-1,y,z)) { res(x-1,y,z) = dist; Q._eik_priority_queue_insert(state,sizeQ,-dist,x-1,y,z); }
            }
            if (x+1<width() && state(x+1,y,z)!=1) {
              const Tfloat dist = __distance_eikonal(res,met(x+1,y,z),x+1,y,z);
              if (dist<res(x+1,y,z)) { res(x+1,y,z) = dist; Q._eik_priority_queue_insert(state,sizeQ,-dist,x+1,y,z); }
            }
            if (y-1>=0 && state(x,y-1,z)!=1) {
              const Tfloat dist = __distance_eikonal(res,met(x,y-1,z),x,y-1,z);
              if (dist<res(x,y-1,z)) { res(x,y-1,z) = dist; Q._eik_priority_queue_insert(state,sizeQ,-dist,x,y-1,z); }
            }
            if (y+1<height() && state(x,y+1,z)!=1) {
              const Tfloat dist = __distance_eikonal(res,met(x,y+1,z),x,y+1,z);
              if (dist<res(x,y+1,z)) { res(x,y+1,z) = dist; Q._eik_priority_queue_insert(state,sizeQ,-dist,x,y+1,z); }
            }
            if (z-1>=0 && state(x,y,z-1)!=1) {
              const Tfloat dist = __distance_eikonal(res,met(x,y,z-1),x,y,z-1);
              if (dist<res(x,y,z-1)) { res(x,y,z-1) = dist; Q._eik_priority_queue_insert(state,sizeQ,-dist,x,y,z-1); }
            }
            if (z+1<depth() && state(x,y,z+1)!=1) {
              const Tfloat dist = __distance_eikonal(res,met(x,y,z+1),x,y,z+1);
              if (dist<res(x,y,z+1)) { res(x,y,z+1) = dist; Q._eik_priority_queue_insert(state,sizeQ,-dist,x,y,z+1); }
            }
          }
        }
      }
      return result;
    }

    // Locally solve eikonal equation.
    Tfloat __distance_eikonal(const CImg<Tfloat>& res, const Tfloat P, const int x=0, const int y=0, const int z=0) const {
      const T M = cimg::type<T>::max();
      T T1 = cimg::min(x-1>=0?res(x-1,y,z):M,x+1<width()?res(x+1,y,z):M);
      Tfloat root = 0;
      if (_depth>1) { // 3d.
        T
          T2 = cimg::min(y-1>=0?res(x,y-1,z):M,y+1<height()?res(x,y+1,z):M),
          T3 = cimg::min(z-1>=0?res(x,y,z-1):M,z+1<depth()?res(x,y,z+1):M);
        if (T1>T2) cimg::swap(T1,T2);
        if (T2>T3) cimg::swap(T2,T3);
        if (T1>T2) cimg::swap(T1,T2);
        if (P<=0) return (Tfloat)T1;
        if (T3<M && ___distance_eikonal(3,-2*(T1+T2+T3),T1*T1+T2*T2+T3*T3-P*P,root)) return cimg::max((Tfloat)T3,root);
        if (T2<M && ___distance_eikonal(2,-2*(T1+T2),T1*T1+T2*T2-P*P,root)) return cimg::max((Tfloat)T2,root);
        return P + T1;
      } else if (_height>1) { // 2d.
        T T2 = cimg::min(y-1>=0?res(x,y-1,z):M,y+1<height()?res(x,y+1,z):M);
        if (T1>T2) cimg::swap(T1,T2);
        if (P<=0) return (Tfloat)T1;
        if (T2<M && ___distance_eikonal(2,-2*(T1+T2),T1*T1+T2*T2-P*P,root)) return cimg::max((Tfloat)T2,root);
        return P + T1;
      } else { // 1d.
        if (P<=0) return (Tfloat)T1;
        return P + T1;
      }
      return 0;
    }

    // Find max root of a 2nd-order polynomial.
    static bool ___distance_eikonal(const Tfloat a, const Tfloat b, const Tfloat c, Tfloat &root) {
      const Tfloat delta = b*b - 4*a*c;
      if (delta<0) return false;
      root = 0.5f*(-b + std::sqrt(delta))/a;
      return true;
    }

    // Insert new point in heap.
    template<typename t>
    void _eik_priority_queue_insert(CImg<charT>& state, unsigned int& siz, const t value, const unsigned int x, const unsigned int y, const unsigned int z) {
      if (state(x,y,z)>0) return;
      state(x,y,z) = 0;
      if (++siz>=_width) { if (!is_empty()) resize(_width*2,4,1,1,0); else assign(64,4); }
      (*this)(siz-1,0) = (T)value; (*this)(siz-1,1) = (T)x; (*this)(siz-1,2) = (T)y; (*this)(siz-1,3) = (T)z;
      for (unsigned int pos = siz - 1, par = 0; pos && value>(*this)(par=(pos+1)/2-1,0); pos = par) {
        cimg::swap((*this)(pos,0),(*this)(par,0)); cimg::swap((*this)(pos,1),(*this)(par,1));
        cimg::swap((*this)(pos,2),(*this)(par,2)); cimg::swap((*this)(pos,3),(*this)(par,3));
      }
    }

    //! Compute distance function to 0-valued isophotes, using the Eikonal PDE.
    /**
       \param nb_iterations Number of PDE iterations.
       \param band_size Size of the narrow band.
       \param time_step Time step of the PDE iterations.
    **/
    CImg<T>& distance_eikonal(const unsigned int nb_iterations, const float band_size=0, const float time_step=0.5f) {
      if (is_empty()) return *this;
      CImg<Tfloat> velocity(*this);
      for (unsigned int iteration = 0; iteration<nb_iterations; ++iteration) {
        Tfloat *ptrd = velocity._data, veloc_max = 0;
        if (_depth>1) { // 3d
          CImg_3x3x3(I,Tfloat);
          cimg_forC(*this,c) cimg_for3x3x3(*this,x,y,z,c,I,Tfloat) if (band_size<=0 || cimg::abs(Iccc)<band_size) {
            const Tfloat
              gx = (Incc - Ipcc)/2,
              gy = (Icnc - Icpc)/2,
              gz = (Iccn - Iccp)/2,
              sgn = -cimg::sign(Iccc),
              ix = gx*sgn>0?(Incc - Iccc):(Iccc - Ipcc),
              iy = gy*sgn>0?(Icnc - Iccc):(Iccc - Icpc),
              iz = gz*sgn>0?(Iccn - Iccc):(Iccc - Iccp),
              ng = (Tfloat)(1e-5f + std::sqrt(gx*gx + gy*gy + gz*gz)),
              ngx = gx/ng,
              ngy = gy/ng,
              ngz = gz/ng,
              veloc = sgn*(ngx*ix + ngy*iy + ngz*iz - 1);
            *(ptrd++) = veloc;
            if (veloc>veloc_max) veloc_max = veloc; else if (-veloc>veloc_max) veloc_max = -veloc;
          } else *(ptrd++) = 0;
        } else { // 2d version
          CImg_3x3(I,Tfloat);
          cimg_forC(*this,c) cimg_for3x3(*this,x,y,0,c,I,Tfloat) if (band_size<=0 || cimg::abs(Icc)<band_size) {
            const Tfloat
              gx = (Inc - Ipc)/2,
              gy = (Icn - Icp)/2,
              sgn = -cimg::sign(Icc),
              ix = gx*sgn>0?(Inc - Icc):(Icc - Ipc),
              iy = gy*sgn>0?(Icn - Icc):(Icc - Icp),
              ng = (Tfloat)(1e-5f + std::sqrt(gx*gx + gy*gy)),
              ngx = gx/ng,
              ngy = gy/ng,
              veloc = sgn*(ngx*ix + ngy*iy - 1);
            *(ptrd++) = veloc;
            if (veloc>veloc_max) veloc_max = veloc; else if (-veloc>veloc_max) veloc_max = -veloc;
          } else *(ptrd++) = 0;
        }
        if (veloc_max>0) *this+=(velocity*=time_step/veloc_max);
      }
      return *this;
    }

    //! Compute distance function to 0-valued isophotes, using the Eikonal PDE \newinstance.
    CImg<Tfloat> get_distance_eikonal(const unsigned int nb_iterations, const float band_size=0, const float time_step=0.5f) const {
      return CImg<Tfloat>(*this,false).distance_eikonal(nb_iterations,band_size,time_step);
    }

    //! Compute Haar multiscale wavelet transform.
    /**
       \param axis Axis considered for the transform.
       \param invert Set inverse of direct transform.
       \param nb_scales Number of scales used for the transform.
    **/
    CImg<T>& haar(const char axis, const bool invert=false, const unsigned int nb_scales=1) {
      return get_haar(axis,invert,nb_scales).move_to(*this);
    }

    //! Compute Haar multiscale wavelet transform \newinstance.
    CImg<Tfloat> get_haar(const char axis, const bool invert=false, const unsigned int nb_scales=1) const {
      if (is_empty() || !nb_scales) return +*this;
      CImg<Tfloat> res;
      const Tfloat sqrt2 = std::sqrt(2);
      if (nb_scales==1) {
        switch (cimg::uncase(axis)) { // Single scale transform
        case 'x' : {
          const unsigned int w = _width/2;
          if (w) {
            if ((w%2) && w!=1)
              throw CImgInstanceException(_cimg_instance
                                          "haar(): Sub-image width %u is not even.",
                                          cimg_instance,
                                          w);

            res.assign(_width,_height,_depth,_spectrum);
            if (invert) cimg_forYZC(*this,y,z,c) { // Inverse transform along X
              for (unsigned int x = 0, xw = w, x2 = 0; x<w; ++x, ++xw) {
                const Tfloat val0 = (Tfloat)(*this)(x,y,z,c), val1 = (Tfloat)(*this)(xw,y,z,c);
                res(x2++,y,z,c) = (val0 - val1)/sqrt2;
                res(x2++,y,z,c) = (val0 + val1)/sqrt2;
              }
            } else cimg_forYZC(*this,y,z,c) { // Direct transform along X
              for (unsigned int x = 0, xw = w, x2 = 0; x<w; ++x, ++xw) {
                const Tfloat val0 = (Tfloat)(*this)(x2++,y,z,c), val1 = (Tfloat)(*this)(x2++,y,z,c);
                res(x,y,z,c) = (val0 + val1)/sqrt2;
                res(xw,y,z,c) = (val1 - val0)/sqrt2;
              }
            }
          } else return *this;
        } break;
        case 'y' : {
          const unsigned int h = _height/2;
          if (h) {
            if ((h%2) && h!=1)
              throw CImgInstanceException(_cimg_instance
                                          "haar(): Sub-image height %u is not even.",
                                          cimg_instance,
                                          h);

            res.assign(_width,_height,_depth,_spectrum);
            if (invert) cimg_forXZC(*this,x,z,c) { // Inverse transform along Y
              for (unsigned int y = 0, yh = h, y2 = 0; y<h; ++y, ++yh) {
                const Tfloat val0 = (Tfloat)(*this)(x,y,z,c), val1 = (Tfloat)(*this)(x,yh,z,c);
                res(x,y2++,z,c) = (val0 - val1)/sqrt2;
                res(x,y2++,z,c) = (val0 + val1)/sqrt2;
              }
            } else cimg_forXZC(*this,x,z,c) {
              for (unsigned int y = 0, yh = h, y2 = 0; y<h; ++y, ++yh) { // Direct transform along Y
                const Tfloat val0 = (Tfloat)(*this)(x,y2++,z,c), val1 = (Tfloat)(*this)(x,y2++,z,c);
                res(x,y,z,c)  = (val0 + val1)/sqrt2;
                res(x,yh,z,c) = (val1 - val0)/sqrt2;
              }
            }
          } else return *this;
        } break;
        case 'z' : {
          const unsigned int d = _depth/2;
          if (d) {
            if ((d%2) && d!=1)
              throw CImgInstanceException(_cimg_instance
                                          "haar(): Sub-image depth %u is not even.",
                                          cimg_instance,
                                          d);

            res.assign(_width,_height,_depth,_spectrum);
            if (invert) cimg_forXYC(*this,x,y,c) { // Inverse transform along Z
              for (unsigned int z = 0, zd = d, z2 = 0; z<d; ++z, ++zd) {
                const Tfloat val0 = (Tfloat)(*this)(x,y,z,c), val1 = (Tfloat)(*this)(x,y,zd,c);
                res(x,y,z2++,c) = (val0 - val1)/sqrt2;
                res(x,y,z2++,c) = (val0 + val1)/sqrt2;
              }
            } else cimg_forXYC(*this,x,y,c) {
              for (unsigned int z = 0, zd = d, z2 = 0; z<d; ++z, ++zd) { // Direct transform along Z
                const Tfloat val0 = (Tfloat)(*this)(x,y,z2++,c), val1 = (Tfloat)(*this)(x,y,z2++,c);
                res(x,y,z,c)  = (val0 + val1)/sqrt2;
                res(x,y,zd,c) = (val1 - val0)/sqrt2;
              }
            }
          } else return *this;
        } break;
        default :
          throw CImgArgumentException(_cimg_instance
                                      "haar(): Invalid specified axis '%c' "
                                      "(should be { x | y | z }).",
                                      cimg_instance,
                                      axis);
        }
      } else { // Multi-scale version
        if (invert) {
          res.assign(*this);
          switch (cimg::uncase(axis)) {
          case 'x' : {
            unsigned int w = _width;
            for (unsigned int s = 1; w && s<nb_scales; ++s) w/=2;
            for (w = w?w:1; w<=_width; w*=2) res.draw_image(res.get_crop(0,w-1).get_haar('x',true,1));
          } break;
          case 'y' : {
            unsigned int h = _width;
            for (unsigned int s = 1; h && s<nb_scales; ++s) h/=2;
            for (h = h?h:1; h<=_height; h*=2) res.draw_image(res.get_crop(0,0,_width-1,h-1).get_haar('y',true,1));
          } break;
          case 'z' : {
            unsigned int d = _depth;
            for (unsigned int s = 1; d && s<nb_scales; ++s) d/=2;
            for (d = d?d:1; d<=_depth; d*=2) res.draw_image(res.get_crop(0,0,0,_width-1,_height-1,d-1).get_haar('z',true,1));
          } break;
          default :
            throw CImgArgumentException(_cimg_instance
                                        "haar(): Invalid specified axis '%c' "
                                        "(should be { x | y | z }).",
                                        cimg_instance,
                                        axis);
          }
        } else { // Direct transform
          res = get_haar(axis,false,1);
          switch (cimg::uncase(axis)) {
          case 'x' : {
            for (unsigned int s = 1, w = _width/2; w && s<nb_scales; ++s, w/=2) res.draw_image(res.get_crop(0,w-1).get_haar('x',false,1));
          } break;
          case 'y' : {
            for (unsigned int s = 1, h = _height/2; h && s<nb_scales; ++s, h/=2) res.draw_image(res.get_crop(0,0,_width-1,h-1).get_haar('y',false,1));
          } break;
          case 'z' : {
            for (unsigned int s = 1, d = _depth/2; d && s<nb_scales; ++s, d/=2) res.draw_image(res.get_crop(0,0,0,_width-1,_height-1,d-1).get_haar('z',false,1));
          } break;
          default :
            throw CImgArgumentException(_cimg_instance
                                        "haar(): Invalid specified axis '%c' "
                                        "(should be { x | y | z }).",
                                        cimg_instance,
                                        axis);
          }
        }
      }
      return res;
    }

    //! Compute Haar multiscale wavelet transform \overloading.
    /**
       \param invert Set inverse of direct transform.
       \param nb_scales Number of scales used for the transform.
    **/
    CImg<T>& haar(const bool invert=false, const unsigned int nb_scales=1) {
      return get_haar(invert,nb_scales).move_to(*this);
    }

    //! Compute Haar multiscale wavelet transform \newinstance.
    CImg<Tfloat> get_haar(const bool invert=false, const unsigned int nb_scales=1) const {
      CImg<Tfloat> res;
      if (nb_scales==1) { // Single scale transform
        if (_width>1) get_haar('x',invert,1).move_to(res);
        if (_height>1) { if (res) res.haar('y',invert,1); else get_haar('y',invert,1).move_to(res); }
        if (_depth>1) { if (res) res.haar('z',invert,1); else get_haar('z',invert,1).move_to(res); }
        if (res) return res;
      } else { // Multi-scale transform
        if (invert) { // Inverse transform
          res.assign(*this);
          if (_width>1) {
            if (_height>1) {
              if (_depth>1) {
                unsigned int w = _width, h = _height, d = _depth; for (unsigned int s = 1; w && h && d && s<nb_scales; ++s) { w/=2; h/=2; d/=2; }
                for (w = w?w:1, h = h?h:1, d = d?d:1; w<=_width && h<=_height && d<=_depth; w*=2, h*=2, d*=2)
                  res.draw_image(res.get_crop(0,0,0,w-1,h-1,d-1).get_haar(true,1));
              } else {
                unsigned int w = _width, h = _height; for (unsigned int s = 1; w && h && s<nb_scales; ++s) { w/=2; h/=2; }
                for (w = w?w:1, h = h?h:1; w<=_width && h<=_height; w*=2, h*=2)
                  res.draw_image(res.get_crop(0,0,0,w-1,h-1,0).get_haar(true,1));
              }
            } else {
              if (_depth>1) {
                unsigned int w = _width, d = _depth; for (unsigned int s = 1; w && d && s<nb_scales; ++s) { w/=2; d/=2; }
                for (w = w?w:1, d = d?d:1; w<=_width && d<=_depth; w*=2, d*=2)
                  res.draw_image(res.get_crop(0,0,0,w-1,0,d-1).get_haar(true,1));
              } else {
                unsigned int w = _width; for (unsigned int s = 1; w && s<nb_scales; ++s) w/=2;
                for (w = w?w:1; w<=_width; w*=2)
                  res.draw_image(res.get_crop(0,0,0,w-1,0,0).get_haar(true,1));
              }
            }
          } else {
            if (_height>1) {
              if (_depth>1) {
                unsigned int h = _height, d = _depth; for (unsigned int s = 1; h && d && s<nb_scales; ++s) { h/=2; d/=2; }
                for (h = h?h:1, d = d?d:1; h<=_height && d<=_depth; h*=2, d*=2)
                  res.draw_image(res.get_crop(0,0,0,0,h-1,d-1).get_haar(true,1));
              } else {
                unsigned int h = _height; for (unsigned int s = 1; h && s<nb_scales; ++s) h/=2;
                for (h = h?h:1; h<=_height; h*=2)
                  res.draw_image(res.get_crop(0,0,0,0,h-1,0).get_haar(true,1));
              }
            } else {
              if (_depth>1) {
                unsigned int d = _depth; for (unsigned int s = 1; d && s<nb_scales; ++s) d/=2;
                for (d = d?d:1; d<=_depth; d*=2)
                  res.draw_image(res.get_crop(0,0,0,0,0,d-1).get_haar(true,1));
              } else return *this;
            }
          }
        } else { // Direct transform
          res = get_haar(false,1);
          if (_width>1) {
            if (_height>1) {
              if (_depth>1) for (unsigned int s = 1, w = _width/2, h = _height/2, d = _depth/2; w && h && d && s<nb_scales; ++s, w/=2, h/=2, d/=2)
                res.draw_image(res.get_crop(0,0,0,w-1,h-1,d-1).haar(false,1));
              else for (unsigned int s = 1, w = _width/2, h = _height/2; w && h && s<nb_scales; ++s, w/=2, h/=2)
                res.draw_image(res.get_crop(0,0,0,w-1,h-1,0).haar(false,1));
            } else {
              if (_depth>1) for (unsigned int s = 1, w = _width/2, d = _depth/2; w && d && s<nb_scales; ++s, w/=2, d/=2)
                res.draw_image(res.get_crop(0,0,0,w-1,0,d-1).haar(false,1));
              else for (unsigned int s = 1, w = _width/2; w && s<nb_scales; ++s, w/=2)
                res.draw_image(res.get_crop(0,0,0,w-1,0,0).haar(false,1));
            }
          } else {
            if (_height>1) {
              if (_depth>1) for (unsigned int s = 1, h = _height/2, d = _depth/2; h && d && s<nb_scales; ++s, h/=2, d/=2)
                res.draw_image(res.get_crop(0,0,0,0,h-1,d-1).haar(false,1));
              else for (unsigned int s = 1, h = _height/2; h && s<nb_scales; ++s, h/=2)
                res.draw_image(res.get_crop(0,0,0,0,h-1,0).haar(false,1));
            } else {
              if (_depth>1) for (unsigned int s = 1, d = _depth/2; d && s<nb_scales; ++s, d/=2)
                res.draw_image(res.get_crop(0,0,0,0,0,d-1).haar(false,1));
              else return *this;
            }
          }
        }
        return res;
      }
      return *this;
    }

    //! Compute 1d Fast Fourier Transform, along a specified axis.
    /**
       \param axis Axis along which the FFT is computed.
       \param is_invert Tells if the forward (\c false) or inverse (\c true) FFT is computed.
    **/
    CImgList<Tfloat> get_FFT(const char axis, const bool is_invert=false) const {
      CImgList<Tfloat> res(*this,CImg<Tfloat>());
      CImg<Tfloat>::FFT(res[0],res[1],axis,is_invert);
      return res;
    }

    //! Compute n-d Fast Fourier Transform.
    /*
      \param is_invert Tells if the forward (\c false) or inverse (\c true) FFT is computed.
    **/
    CImgList<Tfloat> get_FFT(const bool is_invert=false) const {
      CImgList<Tfloat> res(*this,CImg<Tfloat>());
      CImg<Tfloat>::FFT(res[0],res[1],is_invert);
      return res;
    }

    //! Compute 1d Fast Fourier Transform, along a specified axis.
    /**
       \param[in,out] real Real part of the pixel values.
       \param[in,out] imag Imaginary part of the pixel values.
       \param axis Axis along which the FFT is computed.
       \param is_invert Tells if the forward (\c false) or inverse (\c true) FFT is computed.
    **/
    static void FFT(CImg<T>& real, CImg<T>& imag, const char axis, const bool is_invert=false) {
      if (!real)
        throw CImgInstanceException("CImg<%s>::FFT(): Specified real part is empty.",
                                    pixel_type());

      if (!imag) imag.assign(real._width,real._height,real._depth,real._spectrum,0);
      if (!real.is_sameXYZC(imag))
        throw CImgInstanceException("CImg<%s>::FFT(): Specified real part (%u,%u,%u,%u,%p) and imaginary part (%u,%u,%u,%u,%p) have different dimensions.",
                                    pixel_type(),
                                    real._width,real._height,real._depth,real._spectrum,real._data,
                                    imag._width,imag._height,imag._depth,imag._spectrum,imag._data);
#ifdef cimg_use_fftw3
      cimg::mutex(12);
      fftw_complex *data_in;
      fftw_plan data_plan;

      switch (cimg::uncase(axis)) {
      case 'x' : { // Fourier along X, using FFTW library.
        data_in = (fftw_complex*)fftw_malloc(sizeof(fftw_complex)*real._width);
        if (!data_in) throw CImgInstanceException("CImgList<%s>::FFT(): Failed to allocate memory (%s) for computing FFT of image (%u,%u,%u,%u) along the X-axis.",
                                                  pixel_type(),
                                                  cimg::strbuffersize(sizeof(fftw_complex)*real._width),
                                                  real._width,real._height,real._depth,real._spectrum);

        data_plan = fftw_plan_dft_1d(real._width,data_in,data_in,is_invert?FFTW_BACKWARD:FFTW_FORWARD,FFTW_ESTIMATE);
        cimg_forYZC(real,y,z,c) {
          T *ptrr = real.data(0,y,z,c), *ptri = imag.data(0,y,z,c);
          double *ptrd = (double*)data_in;
          cimg_forX(real,x) { *(ptrd++) = (double)*(ptrr++); *(ptrd++) = (double)*(ptri++); }
          fftw_execute(data_plan);
          const unsigned int fact = real._width;
          if (is_invert) cimg_forX(real,x) { *(--ptri) = (T)(*(--ptrd)/fact); *(--ptrr) = (T)(*(--ptrd)/fact); }
          else cimg_forX(real,x) { *(--ptri) = (T)*(--ptrd); *(--ptrr) = (T)*(--ptrd); }
        }
      } break;
      case 'y' : { // Fourier along Y, using FFTW library.
        data_in = (fftw_complex*)fftw_malloc(sizeof(fftw_complex) * real._height);
        if (!data_in) throw CImgInstanceException("CImgList<%s>::FFT(): Failed to allocate memory (%s) for computing FFT of image (%u,%u,%u,%u) along the Y-axis.",
                                                  pixel_type(),
                                                  cimg::strbuffersize(sizeof(fftw_complex)*real._height),
                                                  real._width,real._height,real._depth,real._spectrum);

        data_plan = fftw_plan_dft_1d(real._height,data_in,data_in,is_invert?FFTW_BACKWARD:FFTW_FORWARD,FFTW_ESTIMATE);
        const unsigned int off = real._width;
        cimg_forXZC(real,x,z,c) {
          T *ptrr = real.data(x,0,z,c), *ptri = imag.data(x,0,z,c);
          double *ptrd = (double*)data_in;
          cimg_forY(real,y) { *(ptrd++) = (double)*ptrr; *(ptrd++) = (double)*ptri; ptrr+=off; ptri+=off; }
          fftw_execute(data_plan);
          const unsigned int fact = real._height;
          if (is_invert) cimg_forY(real,y) { ptrr-=off; ptri-=off; *ptri = (T)(*(--ptrd)/fact); *ptrr = (T)(*(--ptrd)/fact); }
          else cimg_forY(real,y) { ptrr-=off; ptri-=off; *ptri = (T)*(--ptrd); *ptrr = (T)*(--ptrd); }
        }
      } break;
      case 'z' : { // Fourier along Z, using FFTW library.
        data_in = (fftw_complex*)fftw_malloc(sizeof(fftw_complex) * real._depth);
        if (!data_in) throw CImgInstanceException("CImgList<%s>::FFT(): Failed to allocate memory (%s) for computing FFT of image (%u,%u,%u,%u) along the Z-axis.",
                                                  pixel_type(),
                                                  cimg::strbuffersize(sizeof(fftw_complex)*real._depth),
                                                  real._width,real._height,real._depth,real._spectrum);

        data_plan = fftw_plan_dft_1d(real._depth,data_in,data_in,is_invert?FFTW_BACKWARD:FFTW_FORWARD,FFTW_ESTIMATE);
        const unsigned long off = (unsigned long)real._width*real._height;
        cimg_forXYC(real,x,y,c) {
          T *ptrr = real.data(x,y,0,c), *ptri = imag.data(x,y,0,c);
          double *ptrd = (double*)data_in;
          cimg_forZ(real,z) { *(ptrd++) = (double)*ptrr; *(ptrd++) = (double)*ptri; ptrr+=off; ptri+=off; }
          fftw_execute(data_plan);
          const unsigned int fact = real._depth;
          if (is_invert) cimg_forZ(real,z) { ptrr-=off; ptri-=off; *ptri = (T)(*(--ptrd)/fact); *ptrr = (T)(*(--ptrd)/fact); }
          else cimg_forZ(real,z) { ptrr-=off; ptri-=off; *ptri = (T)*(--ptrd); *ptrr = (T)*(--ptrd); }
        }
      } break;
      default : { // Fourier along C, using FFTW library.
        data_in = (fftw_complex*)fftw_malloc(sizeof(fftw_complex) * real._spectrum);
        if (!data_in) throw CImgInstanceException("CImgList<%s>::FFT(): Failed to allocate memory (%s) for computing FFT of image (%u,%u,%u,%u) along the C-axis.",
                                                  pixel_type(),
                                                  cimg::strbuffersize(sizeof(fftw_complex)*real._spectrum),
                                                  real._width,real._height,real._depth,real._spectrum);

        data_plan = fftw_plan_dft_1d(real._spectrum,data_in,data_in,is_invert?FFTW_BACKWARD:FFTW_FORWARD,FFTW_ESTIMATE);
        const unsigned long off = (unsigned long)real._width*real._height*real._depth;
        cimg_forXYZ(real,x,y,z) {
          T *ptrr = real.data(x,y,z,0), *ptri = imag.data(x,y,z,0);
          double *ptrd = (double*)data_in;
          cimg_forC(real,c) { *(ptrd++) = (double)*ptrr; *(ptrd++) = (double)*ptri; ptrr+=off; ptri+=off; }
          fftw_execute(data_plan);
          const unsigned int fact = real._spectrum;
          if (is_invert) cimg_forC(real,c) { ptrr-=off; ptri-=off; *ptri = (T)(*(--ptrd)/fact); *ptrr = (T)(*(--ptrd)/fact); }
          else cimg_forC(real,c) { ptrr-=off; ptri-=off; *ptri = (T)*(--ptrd); *ptrr = (T)*(--ptrd); }
        }
      }
      }
      fftw_destroy_plan(data_plan);
      fftw_free(data_in);
      cimg::mutex(12,0);
#else
# 26677 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      switch (cimg::uncase(axis)) {
      case 'x' : { // Fourier along X, using built-in functions.
        const unsigned int N = real._width, N2 = (N>>1);
        if (((N-1)&N) && N!=1)
          throw CImgInstanceException("CImgList<%s>::FFT(): Specified real and imaginary parts (%u,%u,%u,%u) have non 2^N dimension along the X-axis.",
                                      pixel_type(),
                                      real._width,real._height,real._depth,real._spectrum);

        for (unsigned int i = 0, j = 0; i<N2; ++i) {
          if (j>i) cimg_forYZC(real,y,z,c) {
            cimg::swap(real(i,y,z,c),real(j,y,z,c)); cimg::swap(imag(i,y,z,c),imag(j,y,z,c));
            if (j<N2) {
              const unsigned int ri = N-1-i, rj = N-1-j;
              cimg::swap(real(ri,y,z,c),real(rj,y,z,c)); cimg::swap(imag(ri,y,z,c),imag(rj,y,z,c));
            }
          }
          for (unsigned int m = N, n = N2; (j+=n)>=m; j-=m, m = n, n>>=1) {}
        }
        for (unsigned int delta = 2; delta<=N; delta<<=1) {
          const unsigned int delta2 = (delta>>1);
          for (unsigned int i = 0; i<N; i+=delta) {
            float wr = 1, wi = 0;
            const float angle = (float)((is_invert?+1:-1)*2*cimg::PI/delta),
                        ca = (float)std::cos(angle),
                        sa = (float)std::sin(angle);
            for (unsigned int k = 0; k<delta2; ++k) {
              const unsigned int j = i + k, nj = j + delta2;
              cimg_forYZC(real,y,z,c) {
                T &ir = real(j,y,z,c), &ii = imag(j,y,z,c), &nir = real(nj,y,z,c), &nii = imag(nj,y,z,c);
                const float tmpr = (float)(wr*nir - wi*nii), tmpi = (float)(wr*nii + wi*nir);
                nir = (T)(ir - tmpr);
                nii = (T)(ii - tmpi);
                ir+=(T)tmpr;
                ii+=(T)tmpi;
              }
              const float nwr = wr*ca-wi*sa;
              wi = wi*ca + wr*sa;
              wr = nwr;
            }
          }
        }
        if (is_invert) { real/=N; imag/=N; }
      } break;
      case 'y' : { // Fourier along Y, using built-in functions.
        const unsigned int N = real._height, N2 = (N>>1);
        if (((N-1)&N) && N!=1)
          throw CImgInstanceException("CImgList<%s>::FFT(): Specified real and imaginary parts (%u,%u,%u,%u) have non 2^N dimension along the Y-axis.",
                                      pixel_type(),
                                      real._width,real._height,real._depth,real._spectrum);

        for (unsigned int i = 0, j = 0; i<N2; ++i) {
          if (j>i) cimg_forXZC(real,x,z,c) {
            cimg::swap(real(x,i,z,c),real(x,j,z,c)); cimg::swap(imag(x,i,z,c),imag(x,j,z,c));
            if (j<N2) {
              const unsigned int ri = N - 1 - i, rj = N - 1 - j;
              cimg::swap(real(x,ri,z,c),real(x,rj,z,c)); cimg::swap(imag(x,ri,z,c),imag(x,rj,z,c));
            }
          }
          for (unsigned int m = N, n = N2; (j+=n)>=m; j-=m, m = n, n>>=1) {}
        }
        for (unsigned int delta = 2; delta<=N; delta<<=1) {
          const unsigned int delta2 = (delta>>1);
          for (unsigned int i = 0; i<N; i+=delta) {
            float wr = 1, wi = 0;
            const float angle = (float)((is_invert?+1:-1)*2*cimg::PI/delta),
                        ca = (float)std::cos(angle), sa = (float)std::sin(angle);
            for (unsigned int k = 0; k<delta2; ++k) {
              const unsigned int j = i + k, nj = j + delta2;
              cimg_forXZC(real,x,z,c) {
                T &ir = real(x,j,z,c), &ii = imag(x,j,z,c), &nir = real(x,nj,z,c), &nii = imag(x,nj,z,c);
                const float tmpr = (float)(wr*nir - wi*nii), tmpi = (float)(wr*nii + wi*nir);
                nir = (T)(ir - tmpr);
                nii = (T)(ii - tmpi);
                ir+=(T)tmpr;
                ii+=(T)tmpi;
              }
              const float nwr = wr*ca-wi*sa;
              wi = wi*ca + wr*sa;
              wr = nwr;
            }
          }
        }
        if (is_invert) { real/=N; imag/=N; }
      } break;
      case 'z' : { // Fourier along Z, using built-in functions.
        const unsigned int N = real._depth, N2 = (N>>1);
        if (((N-1)&N) && N!=1)
          throw CImgInstanceException("CImgList<%s>::FFT(): Specified real and imaginary parts (%u,%u,%u,%u) have non 2^N dimension along the Z-axis.",
                                      pixel_type(),
                                      real._width,real._height,real._depth,real._spectrum);

        for (unsigned int i = 0, j = 0; i<N2; ++i) {
          if (j>i) cimg_forXYC(real,x,y,c) {
            cimg::swap(real(x,y,i,c),real(x,y,j,c)); cimg::swap(imag(x,y,i,c),imag(x,y,j,c));
            if (j<N2) {
              const unsigned int ri = N - 1 - i, rj = N - 1 - j;
              cimg::swap(real(x,y,ri,c),real(x,y,rj,c)); cimg::swap(imag(x,y,ri,c),imag(x,y,rj,c));
            }
          }
          for (unsigned int m = N, n = N2; (j+=n)>=m; j-=m, m = n, n>>=1) {}
        }
        for (unsigned int delta = 2; delta<=N; delta<<=1) {
          const unsigned int delta2 = (delta>>1);
          for (unsigned int i = 0; i<N; i+=delta) {
            float wr = 1, wi = 0;
            const float angle = (float)((is_invert?+1:-1)*2*cimg::PI/delta),
                        ca = (float)std::cos(angle), sa = (float)std::sin(angle);
            for (unsigned int k = 0; k<delta2; ++k) {
              const unsigned int j = i + k, nj = j + delta2;
              cimg_forXYC(real,x,y,c) {
                T &ir = real(x,y,j,c), &ii = imag(x,y,j,c), &nir = real(x,y,nj,c), &nii = imag(x,y,nj,c);
                const float tmpr = (float)(wr*nir - wi*nii), tmpi = (float)(wr*nii + wi*nir);
                nir = (T)(ir - tmpr);
                nii = (T)(ii - tmpi);
                ir+=(T)tmpr;
                ii+=(T)tmpi;
              }
              const float nwr = wr*ca-wi*sa;
              wi = wi*ca + wr*sa;
              wr = nwr;
            }
          }
        }
        if (is_invert) { real/=N; imag/=N; }
      } break;
      default :
        throw CImgArgumentException("CImgList<%s>::FFT(): Invalid specified axis '%c' for real and imaginary parts (%u,%u,%u,%u) "
                                    "(should be { x | y | z }).",
                                    pixel_type(),axis,
                                    real._width,real._height,real._depth,real._spectrum);
      }
#endif
# 26809 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    }

    //! Compute n-d Fast Fourier Transform.
    /**
       \param[in,out] real Real part of the pixel values.
       \param[in,out] imag Imaginary part of the pixel values.
       \param is_invert Tells if the forward (\c false) or inverse (\c true) FFT is computed.
       \param nb_threads Number of parallel threads used for the computation. Use \c 0 to set this to the number of available cpus.
    **/
    static void FFT(CImg<T>& real, CImg<T>& imag, const bool is_invert=false, const unsigned int nb_threads=0) {
      if (!real)
        throw CImgInstanceException("CImgList<%s>::FFT(): Empty specified real part.",
                                    pixel_type());

      if (!imag) imag.assign(real._width,real._height,real._depth,real._spectrum,0);
      if (!real.is_sameXYZC(imag))
        throw CImgInstanceException("CImgList<%s>::FFT(): Specified real part (%u,%u,%u,%u,%p) and imaginary part (%u,%u,%u,%u,%p) have different dimensions.",
                                    pixel_type(),
                                    real._width,real._height,real._depth,real._spectrum,real._data,
                                    imag._width,imag._height,imag._depth,imag._spectrum,imag._data);

#ifdef cimg_use_fftw3
      cimg::mutex(12);
#ifndef cimg_use_fftw3_singlethread
      const unsigned int _nb_threads = nb_threads?nb_threads:cimg::nb_cpus();
      static int fftw_st = fftw_init_threads();
      cimg::unused(fftw_st);
      fftw_plan_with_nthreads(_nb_threads);
#else
# 26838 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      cimg::unused(nb_threads);
#endif
# 26840 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      fftw_complex *data_in = (fftw_complex*)fftw_malloc(sizeof(fftw_complex)*real._width*real._height*real._depth);
      if (!data_in) throw CImgInstanceException("CImgList<%s>::FFT(): Failed to allocate memory (%s) for computing FFT of image (%u,%u,%u,%u).",
                                                pixel_type(),
                                                cimg::strbuffersize(sizeof(fftw_complex)*real._width*real._height*real._depth*real._spectrum),
                                                real._width,real._height,real._depth,real._spectrum);

      fftw_plan data_plan;
      const unsigned long w = (unsigned long)real._width, wh = w*real._height, whd = wh*real._depth;
      data_plan = fftw_plan_dft_3d(real._width,real._height,real._depth,data_in,data_in,is_invert?FFTW_BACKWARD:FFTW_FORWARD,FFTW_ESTIMATE);
      cimg_forC(real,c) {
        T *ptrr = real.data(0,0,0,c), *ptri = imag.data(0,0,0,c);
        double *ptrd = (double*)data_in;
        for (unsigned int x = 0; x<real._width; ++x, ptrr-=wh-1, ptri-=wh-1)
          for (unsigned int y = 0; y<real._height; ++y, ptrr-=whd-w, ptri-=whd-w)
            for (unsigned int z = 0; z<real._depth; ++z, ptrr+=wh, ptri+=wh) {
              *(ptrd++) = (double)*ptrr; *(ptrd++) = (double)*ptri;
            }
        fftw_execute(data_plan);
        ptrd = (double*)data_in;
        ptrr = real.data(0,0,0,c);
        ptri = imag.data(0,0,0,c);
        if (!is_invert) for (unsigned int x = 0; x<real._width; ++x, ptrr-=wh-1, ptri-=wh-1)
          for (unsigned int y = 0; y<real._height; ++y, ptrr-=whd-w, ptri-=whd-w)
            for (unsigned int z = 0; z<real._depth; ++z, ptrr+=wh, ptri+=wh) {
              *ptrr = (T)*(ptrd++); *ptri = (T)*(ptrd++);
            }
        else for (unsigned int x = 0; x<real._width; ++x, ptrr-=wh-1, ptri-=wh-1)
          for (unsigned int y = 0; y<real._height; ++y, ptrr-=whd-w, ptri-=whd-w)
            for (unsigned int z = 0; z<real._depth; ++z, ptrr+=wh, ptri+=wh) {
              *ptrr = (T)(*(ptrd++)/whd); *ptri = (T)(*(ptrd++)/whd);
            }
      }
      fftw_destroy_plan(data_plan);
      fftw_free(data_in);
#ifndef cimg_use_fftw3_singlethread
      fftw_cleanup_threads();
#endif
# 26877 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      cimg::mutex(12,0);
#else
# 26879 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      cimg::unused(nb_threads);
      if (real._depth>1) FFT(real,imag,'z',is_invert);
      if (real._height>1) FFT(real,imag,'y',is_invert);
      if (real._width>1) FFT(real,imag,'x',is_invert);
#endif
# 26884 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    }

    //@}
    //-------------------------------------
    //
    //! \name 3d Objects Management
    //@{
    //-------------------------------------

    //! Shift 3d object's vertices.
    /**
       \param tx X-coordinate of the 3d displacement vector.
       \param ty Y-coordinate of the 3d displacement vector.
       \param tz Z-coordinate of the 3d displacement vector.
    **/
    CImg<T>& shift_object3d(const float tx, const float ty=0, const float tz=0) {
      if (_height!=3 || _depth>1 || _spectrum>1)
        throw CImgInstanceException(_cimg_instance
                                    "shift_object3d(): Instance is not a set of 3d vertices.",
                                    cimg_instance);

      get_shared_row(0)+=tx; get_shared_row(1)+=ty; get_shared_row(2)+=tz;
      return *this;
    }

    //! Shift 3d object's vertices \newinstance.
    CImg<Tfloat> get_shift_object3d(const float tx, const float ty=0, const float tz=0) const {
      return CImg<Tfloat>(*this,false).shift_object3d(tx,ty,tz);
    }

    //! Shift 3d object's vertices, so that it becomes centered.
    /**
       \note The object center is computed as its barycenter.
    **/
    CImg<T>& shift_object3d() {
      if (_height!=3 || _depth>1 || _spectrum>1)
        throw CImgInstanceException(_cimg_instance
                                    "shift_object3d(): Instance is not a set of 3d vertices.",
                                    cimg_instance);

      CImg<T> xcoords = get_shared_row(0), ycoords = get_shared_row(1), zcoords = get_shared_row(2);
      float xm, xM = (float)xcoords.max_min(xm), ym, yM = (float)ycoords.max_min(ym), zm, zM = (float)zcoords.max_min(zm);
      xcoords-=(xm + xM)/2; ycoords-=(ym + yM)/2; zcoords-=(zm + zM)/2;
      return *this;
    }

    //! Shift 3d object's vertices, so that it becomes centered \newinstance.
    CImg<Tfloat> get_shift_object3d() const {
      return CImg<Tfloat>(*this,false).shift_object3d();
    }

    //! Resize 3d object.
    /**
       \param sx Width of the 3d object's bounding box.
       \param sy Height of the 3d object's bounding box.
       \param sz Depth of the 3d object's bounding box.
    **/
    CImg<T>& resize_object3d(const float sx, const float sy=-100, const float sz=-100) {
      if (_height!=3 || _depth>1 || _spectrum>1)
        throw CImgInstanceException(_cimg_instance
                                    "resize_object3d(): Instance is not a set of 3d vertices.",
                                    cimg_instance);

      CImg<T> xcoords = get_shared_row(0), ycoords = get_shared_row(1), zcoords = get_shared_row(2);
      float xm, xM = (float)xcoords.max_min(xm), ym, yM = (float)ycoords.max_min(ym), zm, zM = (float)zcoords.max_min(zm);
      if (xm<xM) { if (sx>0) xcoords*=sx/(xM-xm); else xcoords*=-sx/100; }
      if (ym<yM) { if (sy>0) ycoords*=sy/(yM-ym); else ycoords*=-sy/100; }
      if (zm<zM) { if (sz>0) zcoords*=sz/(zM-zm); else zcoords*=-sz/100; }
      return *this;
    }

    //! Resize 3d object \newinstance.
    CImg<Tfloat> get_resize_object3d(const float sx, const float sy=-100, const float sz=-100) const {
      return CImg<Tfloat>(*this,false).resize_object3d(sx,sy,sz);
    }

    //! Resize 3d object to unit size.
    CImg<T> resize_object3d() {
      if (_height!=3 || _depth>1 || _spectrum>1)
        throw CImgInstanceException(_cimg_instance
                                    "resize_object3d(): Instance is not a set of 3d vertices.",
                                    cimg_instance);

      CImg<T> xcoords = get_shared_row(0), ycoords = get_shared_row(1), zcoords = get_shared_row(2);
      float xm, xM = (float)xcoords.max_min(xm), ym, yM = (float)ycoords.max_min(ym), zm, zM = (float)zcoords.max_min(zm);
      const float dx = xM - xm, dy = yM - ym, dz = zM - zm, dmax = cimg::max(dx,dy,dz);
      if (dmax>0) { xcoords/=dmax; ycoords/=dmax; zcoords/=dmax; }
      return *this;
    }

    //! Resize 3d object to unit size \newinstance.
    CImg<Tfloat> get_resize_object3d() const {
      return CImg<Tfloat>(*this,false).resize_object3d();
    }

    //! Merge two 3d objects together.
    /**
       \param[in,out] primitives Primitives data of the current 3d object.
       \param obj_vertices Vertices data of the additional 3d object.
       \param obj_primitives Primitives data of the additional 3d object.
    **/
    template<typename tf, typename tp, typename tff>
    CImg<T>& append_object3d(CImgList<tf>& primitives, const CImg<tp>& obj_vertices, const CImgList<tff>& obj_primitives) {
      if (!obj_vertices || !obj_primitives) return *this;
      if (obj_vertices._height!=3 || obj_vertices._depth>1 || obj_vertices._spectrum>1)
        throw CImgInstanceException(_cimg_instance
                                    "append_object3d(): Specified vertice image (%u,%u,%u,%u,%p) is not a set of 3d vertices.",
                                    cimg_instance,
                                    obj_vertices._width,obj_vertices._height,obj_vertices._depth,obj_vertices._spectrum,obj_vertices._data);

      if (is_empty()) { primitives.assign(obj_primitives); return assign(obj_vertices); }
      if (_height!=3 || _depth>1 || _spectrum>1)
        throw CImgInstanceException(_cimg_instance
                                    "append_object3d(): Instance is not a set of 3d vertices.",
                                    cimg_instance);

      const unsigned int P = _width;
      append(obj_vertices,'x');
      const unsigned int N = primitives._width;
      primitives.insert(obj_primitives);
      for (unsigned int i = N; i<primitives._width; ++i) {
        CImg<tf> &p = primitives[i];
        switch (p.size()) {
        case 1 : p[0]+=P; break; // Point.
        case 5 : p[0]+=P; p[1]+=P; break; // Sphere.
        case 2 : case 6 : p[0]+=P; p[1]+=P; break; // Segment.
        case 3 : case 9 : p[0]+=P; p[1]+=P; p[2]+=P; break; // Triangle.
        case 4 : case 12 : p[0]+=P; p[1]+=P; p[2]+=P; p[3]+=P; break; // Rectangle.
        }
      }
      return *this;
    }

    //! Texturize primitives of a 3d object.
    /**
       \param[in,out] primitives Primitives data of the 3d object.
       \param[in,out] colors Colors data of the 3d object.
       \param texture Texture image to map to 3d object.
       \param coords Texture-mapping coordinates.
    **/
    template<typename tp, typename tc, typename tt, typename tx>
    const CImg<T>& texturize_object3d(CImgList<tp>& primitives, CImgList<tc>& colors,
                                      const CImg<tt>& texture, const CImg<tx>& coords=CImg<tx>::empty()) const {
      if (is_empty()) return *this;
      if (_height!=3)
        throw CImgInstanceException(_cimg_instance
                                    "texturize_object3d(): image instance is not a set of 3d points.",
                                    cimg_instance);
      if (coords && (coords._width!=_width || coords._height!=2))
        throw CImgArgumentException(_cimg_instance
                                    "texturize_object3d(): Invalid specified texture coordinates (%u,%u,%u,%u,%p).",
                                    cimg_instance,
                                    coords._width,coords._height,coords._depth,coords._spectrum,coords._data);
      CImg<unsigned int> _coords;
      if (!coords) { // If no texture coordinates specified, do a default XY-projection.
        _coords.assign(_width,2);
        float
          xmin, xmax = (float)get_shared_row(0).max_min(xmin),
          ymin, ymax = (float)get_shared_row(1).max_min(ymin),
          dx = xmax>xmin?xmax-xmin:1,
          dy = ymax>ymin?ymax-ymin:1;
        cimg_forX(*this,p) {
          _coords(p,0) = (unsigned int)(((*this)(p,0)-xmin)*(texture._width-1)/dx);
          _coords(p,1) = (unsigned int)(((*this)(p,1)-ymin)*(texture._height-1)/dy);
        }
      } else _coords = coords;

      int texture_ind = -1;
      cimglist_for(primitives,l) {
        CImg<tp> &p = primitives[l];
        const unsigned int siz = p.size();
        switch (siz) {
        case 1 : { // Point.
          const unsigned int
            i0 = (unsigned int)p[0],
            x0 = (unsigned int)_coords(i0,0), y0 = (unsigned int)_coords(i0,1);
          texture.get_vector_at(x0,y0).move_to(colors[l]);
        } break;
        case 2 : case 6 : { // Line.
          const unsigned int
            i0 = (unsigned int)p[0], i1 = (unsigned int)p[1],
            x0 = (unsigned int)_coords(i0,0), y0 = (unsigned int)_coords(i0,1),
            x1 = (unsigned int)_coords(i1,0), y1 = (unsigned int)_coords(i1,1);
          if (texture_ind<0) colors[texture_ind=l] = texture; else colors[l].assign(colors[texture_ind],true);
          CImg<tp>::vector(i0,i1,x0,y0,x1,y1).move_to(p);
        } break;
        case 3 : case 9 : { // Triangle.
          const unsigned int
            i0 = (unsigned int)p[0], i1 = (unsigned int)p[1], i2 = (unsigned int)p[2],
            x0 = (unsigned int)_coords(i0,0), y0 = (unsigned int)_coords(i0,1),
            x1 = (unsigned int)_coords(i1,0), y1 = (unsigned int)_coords(i1,1),
            x2 = (unsigned int)_coords(i2,0), y2 = (unsigned int)_coords(i2,1);
          if (texture_ind<0) colors[texture_ind=l] = texture; else colors[l].assign(colors[texture_ind],true);
          CImg<tp>::vector(i0,i1,i2,x0,y0,x1,y1,x2,y2).move_to(p);
        } break;
        case 4 : case 12 : { // Quadrangle.
          const unsigned int
            i0 = (unsigned int)p[0], i1 = (unsigned int)p[1], i2 = (unsigned int)p[2], i3 = (unsigned int)p[3],
            x0 = (unsigned int)_coords(i0,0), y0 = (unsigned int)_coords(i0,1),
            x1 = (unsigned int)_coords(i1,0), y1 = (unsigned int)_coords(i1,1),
            x2 = (unsigned int)_coords(i2,0), y2 = (unsigned int)_coords(i2,1),
            x3 = (unsigned int)_coords(i3,0), y3 = (unsigned int)_coords(i3,1);
          if (texture_ind<0) colors[texture_ind=l] = texture; else colors[l].assign(colors[texture_ind],true);
          CImg<tp>::vector(i0,i1,i2,i3,x0,y0,x1,y1,x2,y2,x3,y3).move_to(p);
        } break;
        }
      }
      return *this;
    }

    //! Generate a 3d elevation of the image instance.
    /**
       \param[out] primitives The returned list of the 3d object primitives
                              (template type \e tf should be at least \e unsigned \e int).
       \param[out] colors The returned list of the 3d object colors.
       \param elevation The input elevation map.
       \return The N vertices (xi,yi,zi) of the 3d object as a Nx3 CImg<float> image (0<=i<=N-1).
       \par Example
       \code
       const CImg<float> img("reference.jpg");
       CImgList<unsigned int> faces3d;
       CImgList<unsigned char> colors3d;
       const CImg<float> points3d = img.get_elevation3d(faces3d,colors3d,img.get_norm()*0.2);
       CImg<unsigned char>().display_object3d("Elevation3d",points3d,faces3d,colors3d);
       \endcode
       \image html ref_elevation3d.jpg
    **/
    template<typename tf, typename tc, typename te>
    CImg<floatT> get_elevation3d(CImgList<tf>& primitives, CImgList<tc>& colors, const CImg<te>& elevation) const {
      if (!is_sameXY(elevation) || elevation._depth>1 || elevation._spectrum>1)
        throw CImgArgumentException(_cimg_instance
                                    "get_elevation3d(): Instance and specified elevation (%u,%u,%u,%u,%p) "
                                    "have incompatible dimensions.",
                                    cimg_instance,
                                    elevation._width,elevation._height,elevation._depth,elevation._spectrum,elevation._data);
      if (is_empty()) return *this;
      float m, M = (float)max_min(m);
      if (M==m) ++M;
      colors.assign();
      const unsigned int size_x1 = _width - 1, size_y1 = _height - 1;
      for (unsigned int y = 0; y<size_y1; ++y)
        for (unsigned int x = 0; x<size_x1; ++x) {
          const unsigned char
            r = (unsigned char)(((*this)(x,y,0) - m)*255/(M-m)),
            g = _spectrum>1?(unsigned char)(((*this)(x,y,1) - m)*255/(M-m)):r,
            b = _spectrum>2?(unsigned char)(((*this)(x,y,2) - m)*255/(M-m)):(_spectrum>1?0:r);
          CImg<tc>::vector((tc)r,(tc)g,(tc)b).move_to(colors);
        }
      const typename CImg<te>::_functor2d_int func(elevation);
      return elevation3d(primitives,func,0,0,_width-1.0f,_height-1.0f,_width,_height);
    }

    //! Generate the 3d projection planes of the image instance.
    /**
       \param[out] primitives Primitives data of the returned 3d object.
       \param[out] colors Colors data of the returned 3d object.
       \param x0 X-coordinate of the projection point.
       \param y0 Y-coordinate of the projection point.
       \param z0 Z-coordinate of the projection point.
       \param normalize_colors Tells if the created textures have normalized colors.
    **/
    template<typename tf, typename tc>
    CImg<floatT> get_projections3d(CImgList<tf>& primitives, CImgList<tc>& colors,
                                   const unsigned int x0, const unsigned int y0, const unsigned int z0,
                                   const bool normalize_colors=false) const {
      float m = 0, M = 0, delta = 1;
      if (normalize_colors) { m = (float)min_max(M); delta = 255/(m==M?1:M-m); }
      const unsigned int
        _x0 = (x0>=_width)?_width - 1:x0,
        _y0 = (y0>=_height)?_height - 1:y0,
        _z0 = (z0>=_depth)?_depth - 1:z0;
      CImg<tc> img_xy, img_xz, img_yz;
      if (normalize_colors) {
        ((get_crop(0,0,_z0,0,_width-1,_height-1,_z0,_spectrum-1)-=m)*=delta).move_to(img_xy);
        ((get_crop(0,_y0,0,0,_width-1,_y0,_depth-1,_spectrum-1)-=m)*=delta).resize(_width,_depth,1,-100,-1).move_to(img_xz);
        ((get_crop(_x0,0,0,0,_x0,_height-1,_depth-1,_spectrum-1)-=m)*=delta).resize(_height,_depth,1,-100,-1).move_to(img_yz);
      } else {
        get_crop(0,0,_z0,0,_width-1,_height-1,_z0,_spectrum-1).move_to(img_xy);
        get_crop(0,_y0,0,0,_width-1,_y0,_depth-1,_spectrum-1).resize(_width,_depth,1,-100,-1).move_to(img_xz);
        get_crop(_x0,0,0,0,_x0,_height-1,_depth-1,_spectrum-1).resize(_height,_depth,1,-100,-1).move_to(img_yz);
      }
      CImg<floatT> points(12,3,1,1,
                          0,_width-1,_width-1,0,   0,_width-1,_width-1,0, _x0,_x0,_x0,_x0,
                          0,0,_height-1,_height-1, _y0,_y0,_y0,_y0,       0,_height-1,_height-1,0,
                          _z0,_z0,_z0,_z0,         0,0,_depth-1,_depth-1, 0,0,_depth-1,_depth-1);
      primitives.assign();
      CImg<tf>::vector(0,1,2,3,0,0,img_xy._width-1,0,img_xy._width-1,img_xy._height-1,0,img_xy._height-1).move_to(primitives);
      CImg<tf>::vector(4,5,6,7,0,0,img_xz._width-1,0,img_xz._width-1,img_xz._height-1,0,img_xz._height-1).move_to(primitives);
      CImg<tf>::vector(8,9,10,11,0,0,img_yz._width-1,0,img_yz._width-1,img_yz._height-1,0,img_yz._height-1).move_to(primitives);
      colors.assign();
      img_xy.move_to(colors);
      img_xz.move_to(colors);
      img_yz.move_to(colors);
      return points;
    }

    //! Generate a isoline of the image instance as a 3d object.
    /**
       \param[out] primitives The returned list of the 3d object primitives
                              (template type \e tf should be at least \e unsigned \e int).
       \param isovalue The returned list of the 3d object colors.
       \param size_x The number of subdivisions along the X-axis.
       \param size_y The number of subdisivions along the Y-axis.
       \return The N vertices (xi,yi,zi) of the 3d object as a Nx3 CImg<float> image (0<=i<=N-1).
       \par Example
       \code
       const CImg<float> img("reference.jpg");
       CImgList<unsigned int> faces3d;
       const CImg<float> points3d = img.get_isoline3d(faces3d,100);
       CImg<unsigned char>().display_object3d("Isoline3d",points3d,faces3d,colors3d);
       \endcode
       \image html ref_isoline3d.jpg
    **/
    template<typename tf>
    CImg<floatT> get_isoline3d(CImgList<tf>& primitives, const float isovalue,
                               const int size_x=-100, const int size_y=-100) const {
      if (_spectrum>1)
        throw CImgInstanceException(_cimg_instance
                                    "get_isoline3d(): Instance is not a scalar image.",
                                    cimg_instance);
      if (_depth>1)
        throw CImgInstanceException(_cimg_instance
                                    "get_isoline3d(): Instance is not a 2d image.",
                                    cimg_instance);
      primitives.assign();
      if (is_empty()) return *this;
      CImg<floatT> vertices;
      if ((size_x==-100 && size_y==-100) || (size_x==width() && size_y==height())) {
        const _functor2d_int func(*this);
        vertices = isoline3d(primitives,func,isovalue,0,0,width()-1.0f,height()-1.0f,width(),height());
      } else {
        const _functor2d_float func(*this);
        vertices = isoline3d(primitives,func,isovalue,0,0,width()-1.0f,height()-1.0f,size_x,size_y);
      }
      return vertices;
    }

    //! Generate an isosurface of the image instance as a 3d object.
    /**
       \param[out] primitives The returned list of the 3d object primitives
                              (template type \e tf should be at least \e unsigned \e int).
       \param isovalue The returned list of the 3d object colors.
       \param size_x Number of subdivisions along the X-axis.
       \param size_y Number of subdisivions along the Y-axis.
       \param size_z Number of subdisivions along the Z-axis.
       \return The N vertices (xi,yi,zi) of the 3d object as a Nx3 CImg<float> image (0<=i<=N-1).
       \par Example
       \code
       const CImg<float> img = CImg<unsigned char>("reference.jpg").resize(-100,-100,20);
       CImgList<unsigned int> faces3d;
       const CImg<float> points3d = img.get_isosurface3d(faces3d,100);
       CImg<unsigned char>().display_object3d("Isosurface3d",points3d,faces3d,colors3d);
       \endcode
       \image html ref_isosurface3d.jpg
    **/
    template<typename tf>
    CImg<floatT> get_isosurface3d(CImgList<tf>& primitives, const float isovalue,
                                  const int size_x=-100, const int size_y=-100, const int size_z=-100) const {
      if (_spectrum>1)
        throw CImgInstanceException(_cimg_instance
                                    "get_isosurface3d(): Instance is not a scalar image.",
                                    cimg_instance);
      primitives.assign();
      if (is_empty()) return *this;
      CImg<floatT> vertices;
      if ((size_x==-100 && size_y==-100 && size_z==-100) || (size_x==width() && size_y==height() && size_z==depth())) {
        const _functor3d_int func(*this);
        vertices = isosurface3d(primitives,func,isovalue,0,0,0,width()-1.0f,height()-1.0f,depth()-1.0f,width(),height(),depth());
      } else {
        const _functor3d_float func(*this);
        vertices = isosurface3d(primitives,func,isovalue,0,0,0,width()-1.0f,height()-1.0f,depth()-1.0f,size_x,size_y,size_z);
      }
      return vertices;
    }

    //! Compute 3d elevation of a function as a 3d object.
    /**
       \param[out] primitives Primitives data of the resulting 3d object.
       \param func Elevation function. Is of type <tt>float (*func)(const float x,const float y)</tt>.
       \param x0 X-coordinate of the starting point.
       \param y0 Y-coordinate of the starting point.
       \param x1 X-coordinate of the ending point.
       \param y1 Y-coordinate of the ending point.
       \param size_x Resolution of the function along the X-axis.
       \param size_y Resolution of the function along the Y-axis.
    **/
    template<typename tf, typename tfunc>
    static CImg<floatT> elevation3d(CImgList<tf>& primitives, const tfunc& func,
                                    const float x0, const float y0, const float x1, const float y1,
                                    const int size_x=256, const int size_y=256) {
      const float
        nx0 = x0<x1?x0:x1, ny0 = y0<y1?y0:y1,
        nx1 = x0<x1?x1:x0, ny1 = y0<y1?y1:y0;
      const unsigned int
        _nsize_x = (unsigned int)(size_x>=0?size_x:(nx1-nx0)*-size_x/100), nsize_x = _nsize_x?_nsize_x:1, nsize_x1 = nsize_x - 1,
        _nsize_y = (unsigned int)(size_y>=0?size_y:(ny1-ny0)*-size_y/100), nsize_y = _nsize_y?_nsize_y:1, nsize_y1 = nsize_y - 1;
      if (nsize_x<2 || nsize_y<2)
        throw CImgArgumentException("CImg<%s>::elevation3d(): Invalid specified size (%d,%d).",
                                    pixel_type(),
                                    nsize_x,nsize_y);

      CImg<floatT> vertices(nsize_x*nsize_y,3);
      floatT *ptr_x = vertices.data(0,0), *ptr_y = vertices.data(0,1), *ptr_z = vertices.data(0,2);
      for (unsigned int y = 0; y<nsize_y; ++y) {
        const float Y = ny0 + y*(ny1-ny0)/nsize_y1;
        for (unsigned int x = 0; x<nsize_x; ++x) {
          const float X = nx0 + x*(nx1-nx0)/nsize_x1;
          *(ptr_x++) = (float)x;
          *(ptr_y++) = (float)y;
          *(ptr_z++) = (float)func(X,Y);
        }
      }
      primitives.assign(nsize_x1*nsize_y1,1,4);
      for (unsigned int p = 0, y = 0; y<nsize_y1; ++y) {
        const unsigned int yw = y*nsize_x;
        for (unsigned int x = 0; x<nsize_x1; ++x) {
          const unsigned int xpyw = x + yw, xpyww = xpyw + nsize_x;
          primitives[p++].fill(xpyw,xpyww,xpyww+1,xpyw+1);
        }
      }
      return vertices;
    }

    //! Compute 3d elevation of a function, as a 3d object \overloading.
    template<typename tf>
    static CImg<floatT> elevation3d(CImgList<tf>& primitives, const char *const expression,
                                    const float x0, const float y0, const float x1, const float y1,
                                    const int size_x=256, const int size_y=256) {
      const _functor2d_expr func(expression);
      return elevation3d(primitives,func,x0,y0,x1,y1,size_x,size_y);
    }

    //! Compute 0-isolines of a function, as a 3d object.
    /**
       \param[out] primitives Primitives data of the resulting 3d object.
       \param func Elevation function. Is of type <tt>float (*func)(const float x,const float y)</tt>.
       \param isovalue Isovalue to extract from function.
       \param x0 X-coordinate of the starting point.
       \param y0 Y-coordinate of the starting point.
       \param x1 X-coordinate of the ending point.
       \param y1 Y-coordinate of the ending point.
       \param size_x Resolution of the function along the X-axis.
       \param size_y Resolution of the function along the Y-axis.
       \note Use the marching squares algorithm for extracting the isolines.
     **/
    template<typename tf, typename tfunc>
    static CImg<floatT> isoline3d(CImgList<tf>& primitives, const tfunc& func, const float isovalue,
                                  const float x0, const float y0, const float x1, const float y1,
                                  const int size_x=256, const int size_y=256) {
      static const unsigned int edges[16] = { 0x0, 0x9, 0x3, 0xa, 0x6, 0xf, 0x5, 0xc, 0xc, 0x5, 0xf, 0x6, 0xa, 0x3, 0x9, 0x0 };
      static const int segments[16][4] = { { -1,-1,-1,-1 }, { 0,3,-1,-1 }, { 0,1,-1,-1 }, { 1,3,-1,-1 },
                                           { 1,2,-1,-1 },   { 0,1,2,3 },   { 0,2,-1,-1 }, { 2,3,-1,-1 },
                                           { 2,3,-1,-1 },   { 0,2,-1,-1},  { 0,3,1,2 },   { 1,2,-1,-1 },
                                           { 1,3,-1,-1 },   { 0,1,-1,-1},  { 0,3,-1,-1},  { -1,-1,-1,-1 } };
      const unsigned int
        _nx = (unsigned int)(size_x>=0?size_x:cimg::round((x1-x0)*-size_x/100 + 1)),
        _ny = (unsigned int)(size_y>=0?size_y:cimg::round((y1-y0)*-size_y/100 + 1)),
        nx = _nx?_nx:1,
        ny = _ny?_ny:1,
        nxm1 = nx - 1,
        nym1 = ny - 1;
      primitives.assign();
      if (!nxm1 || !nym1) return CImg<floatT>();
      const float dx = (x1 - x0)/nxm1, dy = (y1 - y0)/nym1;
      CImgList<floatT> vertices;
      CImg<intT> indices1(nx,1,1,2,-1), indices2(nx,1,1,2);
      CImg<floatT> values1(nx), values2(nx);
      float X = x0, Y = y0, nX = X + dx, nY = Y + dy;

      // Fill first line with values
      cimg_forX(values1,x) { values1(x) = (float)func(X,Y); X+=dx; }

      // Run the marching squares algorithm
      for (unsigned int yi = 0, nyi = 1; yi<nym1; ++yi, ++nyi, Y=nY, nY+=dy) {
        X = x0; nX = X + dx;
        indices2.fill(-1);
        for (unsigned int xi = 0, nxi = 1; xi<nxm1; ++xi, ++nxi, X=nX, nX+=dx) {

          // Determine square configuration
          const float
            val0 = values1(xi),
            val1 = values1(nxi),
            val2 = values2(nxi) = (float)func(nX,nY),
            val3 = values2(xi) = (float)func(X,nY);
          const unsigned int
            configuration = (val0<isovalue?1:0)  | (val1<isovalue?2:0)  | (val2<isovalue?4:0)  | (val3<isovalue?8:0),
            edge = edges[configuration];

          // Compute intersection vertices
          if (edge) {
            if ((edge&1) && indices1(xi,0)<0) {
              const float Xi = X + (isovalue-val0)*dx/(val1-val0);
              indices1(xi,0) = vertices._width;
              CImg<floatT>::vector(Xi,Y,0).move_to(vertices);
            }
            if ((edge&2) && indices1(nxi,1)<0) {
              const float Yi = Y + (isovalue-val1)*dy/(val2-val1);
              indices1(nxi,1) = vertices._width;
              CImg<floatT>::vector(nX,Yi,0).move_to(vertices);
            }
            if ((edge&4) && indices2(xi,0)<0) {
              const float Xi = X + (isovalue-val3)*dx/(val2-val3);
              indices2(xi,0) = vertices._width;
              CImg<floatT>::vector(Xi,nY,0).move_to(vertices);
            }
            if ((edge&8) && indices1(xi,1)<0) {
              const float Yi = Y + (isovalue-val0)*dy/(val3-val0);
              indices1(xi,1) = vertices._width;
              CImg<floatT>::vector(X,Yi,0).move_to(vertices);
            }

            // Create segments
            for (const int *segment = segments[configuration]; *segment!=-1; ) {
              const unsigned int p0 = *(segment++), p1 = *(segment++);
              const tf
                i0 = (tf)(_isoline3d_indice(p0,indices1,indices2,xi,nxi)),
                i1 = (tf)(_isoline3d_indice(p1,indices1,indices2,xi,nxi));
              CImg<tf>::vector(i0,i1).move_to(primitives);
            }
          }
        }
        values1.swap(values2);
        indices1.swap(indices2);
      }
      return vertices>'x';
    }

    //! Compute isolines of a function, as a 3d object \overloading.
    template<typename tf>
    static CImg<floatT> isoline3d(CImgList<tf>& primitives, const char *const expression, const float isovalue,
                                  const float x0, const float y0, const float x1, const float y1,
                                  const int size_x=256, const int size_y=256) {
      const _functor2d_expr func(expression);
      return isoline3d(primitives,func,isovalue,x0,y0,x1,y1,size_x,size_y);
    }

    template<typename t>
    static int _isoline3d_indice(const unsigned int edge, const CImg<t>& indices1, const CImg<t>& indices2,
                                 const unsigned int x, const unsigned int nx) {
      switch (edge) {
      case 0 : return (int)indices1(x,0);
      case 1 : return (int)indices1(nx,1);
      case 2 : return (int)indices2(x,0);
      case 3 : return (int)indices1(x,1);
      }
      return 0;
    }

    //! Compute isosurface of a function, as a 3d object.
    /**
       \param[out] primitives Primitives data of the resulting 3d object.
       \param func Implicit function. Is of type <tt>float (*func)(const float x, const float y, const float z)</tt>.
       \param isovalue Isovalue to extract.
       \param x0 X-coordinate of the starting point.
       \param y0 Y-coordinate of the starting point.
       \param z0 Z-coordinate of the starting point.
       \param x1 X-coordinate of the ending point.
       \param y1 Y-coordinate of the ending point.
       \param z1 Z-coordinate of the ending point.
       \param size_x Resolution of the elevation function along the X-axis.
       \param size_y Resolution of the elevation function along the Y-axis.
       \param size_z Resolution of the elevation function along the Z-axis.
       \note Use the marching cubes algorithm for extracting the isosurface.
     **/
    template<typename tf, typename tfunc>
    static CImg<floatT> isosurface3d(CImgList<tf>& primitives, const tfunc& func, const float isovalue,
                                     const float x0, const float y0, const float z0,
                                     const float x1, const float y1, const float z1,
                                     const int size_x=32, const int size_y=32, const int size_z=32) {
      static const unsigned int edges[256] = {
        0x000, 0x109, 0x203, 0x30a, 0x406, 0x50f, 0x605, 0x70c, 0x80c, 0x905, 0xa0f, 0xb06, 0xc0a, 0xd03, 0xe09, 0xf00,
        0x190, 0x99 , 0x393, 0x29a, 0x596, 0x49f, 0x795, 0x69c, 0x99c, 0x895, 0xb9f, 0xa96, 0xd9a, 0xc93, 0xf99, 0xe90,
        0x230, 0x339, 0x33 , 0x13a, 0x636, 0x73f, 0x435, 0x53c, 0xa3c, 0xb35, 0x83f, 0x936, 0xe3a, 0xf33, 0xc39, 0xd30,
        0x3a0, 0x2a9, 0x1a3, 0xaa , 0x7a6, 0x6af, 0x5a5, 0x4ac, 0xbac, 0xaa5, 0x9af, 0x8a6, 0xfaa, 0xea3, 0xda9, 0xca0,
        0x460, 0x569, 0x663, 0x76a, 0x66 , 0x16f, 0x265, 0x36c, 0xc6c, 0xd65, 0xe6f, 0xf66, 0x86a, 0x963, 0xa69, 0xb60,
        0x5f0, 0x4f9, 0x7f3, 0x6fa, 0x1f6, 0xff , 0x3f5, 0x2fc, 0xdfc, 0xcf5, 0xfff, 0xef6, 0x9fa, 0x8f3, 0xbf9, 0xaf0,
        0x650, 0x759, 0x453, 0x55a, 0x256, 0x35f, 0x55 , 0x15c, 0xe5c, 0xf55, 0xc5f, 0xd56, 0xa5a, 0xb53, 0x859, 0x950,
        0x7c0, 0x6c9, 0x5c3, 0x4ca, 0x3c6, 0x2cf, 0x1c5, 0xcc , 0xfcc, 0xec5, 0xdcf, 0xcc6, 0xbca, 0xac3, 0x9c9, 0x8c0,
        0x8c0, 0x9c9, 0xac3, 0xbca, 0xcc6, 0xdcf, 0xec5, 0xfcc, 0xcc , 0x1c5, 0x2cf, 0x3c6, 0x4ca, 0x5c3, 0x6c9, 0x7c0,
        0x950, 0x859, 0xb53, 0xa5a, 0xd56, 0xc5f, 0xf55, 0xe5c, 0x15c, 0x55 , 0x35f, 0x256, 0x55a, 0x453, 0x759, 0x650,
        0xaf0, 0xbf9, 0x8f3, 0x9fa, 0xef6, 0xfff, 0xcf5, 0xdfc, 0x2fc, 0x3f5, 0xff , 0x1f6, 0x6fa, 0x7f3, 0x4f9, 0x5f0,
        0xb60, 0xa69, 0x963, 0x86a, 0xf66, 0xe6f, 0xd65, 0xc6c, 0x36c, 0x265, 0x16f, 0x66 , 0x76a, 0x663, 0x569, 0x460,
        0xca0, 0xda9, 0xea3, 0xfaa, 0x8a6, 0x9af, 0xaa5, 0xbac, 0x4ac, 0x5a5, 0x6af, 0x7a6, 0xaa , 0x1a3, 0x2a9, 0x3a0,
        0xd30, 0xc39, 0xf33, 0xe3a, 0x936, 0x83f, 0xb35, 0xa3c, 0x53c, 0x435, 0x73f, 0x636, 0x13a, 0x33 , 0x339, 0x230,
        0xe90, 0xf99, 0xc93, 0xd9a, 0xa96, 0xb9f, 0x895, 0x99c, 0x69c, 0x795, 0x49f, 0x596, 0x29a, 0x393, 0x99 , 0x190,
        0xf00, 0xe09, 0xd03, 0xc0a, 0xb06, 0xa0f, 0x905, 0x80c, 0x70c, 0x605, 0x50f, 0x406, 0x30a, 0x203, 0x109, 0x000 };

      static const int triangles[256][16] = {
        { -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 0, 8, 3, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 0, 1, 9, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 1, 8, 3, 9, 8, 1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 1, 2, 10, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 0, 8, 3, 1, 2, 10, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 9, 2, 10, 0, 2, 9, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 2, 8, 3, 2, 10, 8, 10, 9, 8, -1, -1, -1, -1, -1, -1, -1 },
        { 3, 11, 2, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 0, 11, 2, 8, 11, 0, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 1, 9, 0, 2, 3, 11, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 1, 11, 2, 1, 9, 11, 9, 8, 11, -1, -1, -1, -1, -1, -1, -1 },
        { 3, 10, 1, 11, 10, 3, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 0, 10, 1, 0, 8, 10, 8, 11, 10, -1, -1, -1, -1, -1, -1, -1 },
        { 3, 9, 0, 3, 11, 9, 11, 10, 9, -1, -1, -1, -1, -1, -1, -1 }, { 9, 8, 10, 10, 8, 11, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 4, 7, 8, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 4, 3, 0, 7, 3, 4, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 0, 1, 9, 8, 4, 7, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 4, 1, 9, 4, 7, 1, 7, 3, 1, -1, -1, -1, -1, -1, -1, -1 },
        { 1, 2, 10, 8, 4, 7, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 3, 4, 7, 3, 0, 4, 1, 2, 10, -1, -1, -1, -1, -1, -1, -1 },
        { 9, 2, 10, 9, 0, 2, 8, 4, 7, -1, -1, -1, -1, -1, -1, -1 }, { 2, 10, 9, 2, 9, 7, 2, 7, 3, 7, 9, 4, -1, -1, -1, -1 },
        { 8, 4, 7, 3, 11, 2, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 11, 4, 7, 11, 2, 4, 2, 0, 4, -1, -1, -1, -1, -1, -1, -1 },
        { 9, 0, 1, 8, 4, 7, 2, 3, 11, -1, -1, -1, -1, -1, -1, -1 }, { 4, 7, 11, 9, 4, 11, 9, 11, 2, 9, 2, 1, -1, -1, -1, -1 },
        { 3, 10, 1, 3, 11, 10, 7, 8, 4, -1, -1, -1, -1, -1, -1, -1 }, { 1, 11, 10, 1, 4, 11, 1, 0, 4, 7, 11, 4, -1, -1, -1, -1 },
        { 4, 7, 8, 9, 0, 11, 9, 11, 10, 11, 0, 3, -1, -1, -1, -1 }, { 4, 7, 11, 4, 11, 9, 9, 11, 10, -1, -1, -1, -1, -1, -1, -1 },
        { 9, 5, 4, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 9, 5, 4, 0, 8, 3, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 0, 5, 4, 1, 5, 0, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 8, 5, 4, 8, 3, 5, 3, 1, 5, -1, -1, -1, -1, -1, -1, -1 },
        { 1, 2, 10, 9, 5, 4, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 3, 0, 8, 1, 2, 10, 4, 9, 5, -1, -1, -1, -1, -1, -1, -1 },
        { 5, 2, 10, 5, 4, 2, 4, 0, 2, -1, -1, -1, -1, -1, -1, -1 }, { 2, 10, 5, 3, 2, 5, 3, 5, 4, 3, 4, 8, -1, -1, -1, -1 },
        { 9, 5, 4, 2, 3, 11, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 0, 11, 2, 0, 8, 11, 4, 9, 5, -1, -1, -1, -1, -1, -1, -1 },
        { 0, 5, 4, 0, 1, 5, 2, 3, 11, -1, -1, -1, -1, -1, -1, -1 }, { 2, 1, 5, 2, 5, 8, 2, 8, 11, 4, 8, 5, -1, -1, -1, -1 },
        { 10, 3, 11, 10, 1, 3, 9, 5, 4, -1, -1, -1, -1, -1, -1, -1 }, { 4, 9, 5, 0, 8, 1, 8, 10, 1, 8, 11, 10, -1, -1, -1, -1 },
        { 5, 4, 0, 5, 0, 11, 5, 11, 10, 11, 0, 3, -1, -1, -1, -1 }, { 5, 4, 8, 5, 8, 10, 10, 8, 11, -1, -1, -1, -1, -1, -1, -1 },
        { 9, 7, 8, 5, 7, 9, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 9, 3, 0, 9, 5, 3, 5, 7, 3, -1, -1, -1, -1, -1, -1, -1 },
        { 0, 7, 8, 0, 1, 7, 1, 5, 7, -1, -1, -1, -1, -1, -1, -1 }, { 1, 5, 3, 3, 5, 7, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 9, 7, 8, 9, 5, 7, 10, 1, 2, -1, -1, -1, -1, -1, -1, -1 }, { 10, 1, 2, 9, 5, 0, 5, 3, 0, 5, 7, 3, -1, -1, -1, -1 },
        { 8, 0, 2, 8, 2, 5, 8, 5, 7, 10, 5, 2, -1, -1, -1, -1 }, { 2, 10, 5, 2, 5, 3, 3, 5, 7, -1, -1, -1, -1, -1, -1, -1 },
        { 7, 9, 5, 7, 8, 9, 3, 11, 2, -1, -1, -1, -1, -1, -1, -1 }, { 9, 5, 7, 9, 7, 2, 9, 2, 0, 2, 7, 11, -1, -1, -1, -1 },
        { 2, 3, 11, 0, 1, 8, 1, 7, 8, 1, 5, 7, -1, -1, -1, -1 }, { 11, 2, 1, 11, 1, 7, 7, 1, 5, -1, -1, -1, -1, -1, -1, -1 },
        { 9, 5, 8, 8, 5, 7, 10, 1, 3, 10, 3, 11, -1, -1, -1, -1 }, { 5, 7, 0, 5, 0, 9, 7, 11, 0, 1, 0, 10, 11, 10, 0, -1 },
        { 11, 10, 0, 11, 0, 3, 10, 5, 0, 8, 0, 7, 5, 7, 0, -1 }, { 11, 10, 5, 7, 11, 5, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 10, 6, 5, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 0, 8, 3, 5, 10, 6, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 9, 0, 1, 5, 10, 6, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 1, 8, 3, 1, 9, 8, 5, 10, 6, -1, -1, -1, -1, -1, -1, -1 },
        { 1, 6, 5, 2, 6, 1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 1, 6, 5, 1, 2, 6, 3, 0, 8, -1, -1, -1, -1, -1, -1, -1 },
        { 9, 6, 5, 9, 0, 6, 0, 2, 6, -1, -1, -1, -1, -1, -1, -1 }, { 5, 9, 8, 5, 8, 2, 5, 2, 6, 3, 2, 8, -1, -1, -1, -1 },
        { 2, 3, 11, 10, 6, 5, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 11, 0, 8, 11, 2, 0, 10, 6, 5, -1, -1, -1, -1, -1, -1, -1 },
        { 0, 1, 9, 2, 3, 11, 5, 10, 6, -1, -1, -1, -1, -1, -1, -1 }, { 5, 10, 6, 1, 9, 2, 9, 11, 2, 9, 8, 11, -1, -1, -1, -1 },
        { 6, 3, 11, 6, 5, 3, 5, 1, 3, -1, -1, -1, -1, -1, -1, -1 }, { 0, 8, 11, 0, 11, 5, 0, 5, 1, 5, 11, 6, -1, -1, -1, -1 },
        { 3, 11, 6, 0, 3, 6, 0, 6, 5, 0, 5, 9, -1, -1, -1, -1 }, { 6, 5, 9, 6, 9, 11, 11, 9, 8, -1, -1, -1, -1, -1, -1, -1 },
        { 5, 10, 6, 4, 7, 8, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 4, 3, 0, 4, 7, 3, 6, 5, 10, -1, -1, -1, -1, -1, -1, -1 },
        { 1, 9, 0, 5, 10, 6, 8, 4, 7, -1, -1, -1, -1, -1, -1, -1 }, { 10, 6, 5, 1, 9, 7, 1, 7, 3, 7, 9, 4, -1, -1, -1, -1 },
        { 6, 1, 2, 6, 5, 1, 4, 7, 8, -1, -1, -1, -1, -1, -1, -1 }, { 1, 2, 5, 5, 2, 6, 3, 0, 4, 3, 4, 7, -1, -1, -1, -1 },
        { 8, 4, 7, 9, 0, 5, 0, 6, 5, 0, 2, 6, -1, -1, -1, -1 }, { 7, 3, 9, 7, 9, 4, 3, 2, 9, 5, 9, 6, 2, 6, 9, -1 },
        { 3, 11, 2, 7, 8, 4, 10, 6, 5, -1, -1, -1, -1, -1, -1, -1 }, { 5, 10, 6, 4, 7, 2, 4, 2, 0, 2, 7, 11, -1, -1, -1, -1 },
        { 0, 1, 9, 4, 7, 8, 2, 3, 11, 5, 10, 6, -1, -1, -1, -1 }, { 9, 2, 1, 9, 11, 2, 9, 4, 11, 7, 11, 4, 5, 10, 6, -1 },
        { 8, 4, 7, 3, 11, 5, 3, 5, 1, 5, 11, 6, -1, -1, -1, -1 }, { 5, 1, 11, 5, 11, 6, 1, 0, 11, 7, 11, 4, 0, 4, 11, -1 },
        { 0, 5, 9, 0, 6, 5, 0, 3, 6, 11, 6, 3, 8, 4, 7, -1 }, { 6, 5, 9, 6, 9, 11, 4, 7, 9, 7, 11, 9, -1, -1, -1, -1 },
        { 10, 4, 9, 6, 4, 10, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 4, 10, 6, 4, 9, 10, 0, 8, 3, -1, -1, -1, -1, -1, -1, -1 },
        { 10, 0, 1, 10, 6, 0, 6, 4, 0, -1, -1, -1, -1, -1, -1, -1 }, { 8, 3, 1, 8, 1, 6, 8, 6, 4, 6, 1, 10, -1, -1, -1, -1 },
        { 1, 4, 9, 1, 2, 4, 2, 6, 4, -1, -1, -1, -1, -1, -1, -1 }, { 3, 0, 8, 1, 2, 9, 2, 4, 9, 2, 6, 4, -1, -1, -1, -1 },
        { 0, 2, 4, 4, 2, 6, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 8, 3, 2, 8, 2, 4, 4, 2, 6, -1, -1, -1, -1, -1, -1, -1 },
        { 10, 4, 9, 10, 6, 4, 11, 2, 3, -1, -1, -1, -1, -1, -1, -1 }, { 0, 8, 2, 2, 8, 11, 4, 9, 10, 4, 10, 6, -1, -1, -1, -1 },
        { 3, 11, 2, 0, 1, 6, 0, 6, 4, 6, 1, 10, -1, -1, -1, -1 }, { 6, 4, 1, 6, 1, 10, 4, 8, 1, 2, 1, 11, 8, 11, 1, -1 },
        { 9, 6, 4, 9, 3, 6, 9, 1, 3, 11, 6, 3, -1, -1, -1, -1 }, { 8, 11, 1, 8, 1, 0, 11, 6, 1, 9, 1, 4, 6, 4, 1, -1 },
        { 3, 11, 6, 3, 6, 0, 0, 6, 4, -1, -1, -1, -1, -1, -1, -1 }, { 6, 4, 8, 11, 6, 8, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 7, 10, 6, 7, 8, 10, 8, 9, 10, -1, -1, -1, -1, -1, -1, -1 }, { 0, 7, 3, 0, 10, 7, 0, 9, 10, 6, 7, 10, -1, -1, -1, -1 },
        { 10, 6, 7, 1, 10, 7, 1, 7, 8, 1, 8, 0, -1, -1, -1, -1 }, { 10, 6, 7, 10, 7, 1, 1, 7, 3, -1, -1, -1, -1, -1, -1, -1 },
        { 1, 2, 6, 1, 6, 8, 1, 8, 9, 8, 6, 7, -1, -1, -1, -1 }, { 2, 6, 9, 2, 9, 1, 6, 7, 9, 0, 9, 3, 7, 3, 9, -1 },
        { 7, 8, 0, 7, 0, 6, 6, 0, 2, -1, -1, -1, -1, -1, -1, -1 }, { 7, 3, 2, 6, 7, 2, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 2, 3, 11, 10, 6, 8, 10, 8, 9, 8, 6, 7, -1, -1, -1, -1 }, { 2, 0, 7, 2, 7, 11, 0, 9, 7, 6, 7, 10, 9, 10, 7, -1 },
        { 1, 8, 0, 1, 7, 8, 1, 10, 7, 6, 7, 10, 2, 3, 11, -1 }, { 11, 2, 1, 11, 1, 7, 10, 6, 1, 6, 7, 1, -1, -1, -1, -1 },
        { 8, 9, 6, 8, 6, 7, 9, 1, 6, 11, 6, 3, 1, 3, 6, -1 }, { 0, 9, 1, 11, 6, 7, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 7, 8, 0, 7, 0, 6, 3, 11, 0, 11, 6, 0, -1, -1, -1, -1 }, { 7, 11, 6, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 7, 6, 11, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 3, 0, 8, 11, 7, 6, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 0, 1, 9, 11, 7, 6, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 8, 1, 9, 8, 3, 1, 11, 7, 6, -1, -1, -1, -1, -1, -1, -1 },
        { 10, 1, 2, 6, 11, 7, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 1, 2, 10, 3, 0, 8, 6, 11, 7, -1, -1, -1, -1, -1, -1, -1 },
        { 2, 9, 0, 2, 10, 9, 6, 11, 7, -1, -1, -1, -1, -1, -1, -1 }, { 6, 11, 7, 2, 10, 3, 10, 8, 3, 10, 9, 8, -1, -1, -1, -1 },
        { 7, 2, 3, 6, 2, 7, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 7, 0, 8, 7, 6, 0, 6, 2, 0, -1, -1, -1, -1, -1, -1, -1 },
        { 2, 7, 6, 2, 3, 7, 0, 1, 9, -1, -1, -1, -1, -1, -1, -1 }, { 1, 6, 2, 1, 8, 6, 1, 9, 8, 8, 7, 6, -1, -1, -1, -1 },
        { 10, 7, 6, 10, 1, 7, 1, 3, 7, -1, -1, -1, -1, -1, -1, -1 }, { 10, 7, 6, 1, 7, 10, 1, 8, 7, 1, 0, 8, -1, -1, -1, -1 },
        { 0, 3, 7, 0, 7, 10, 0, 10, 9, 6, 10, 7, -1, -1, -1, -1 }, { 7, 6, 10, 7, 10, 8, 8, 10, 9, -1, -1, -1, -1, -1, -1, -1 },
        { 6, 8, 4, 11, 8, 6, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 3, 6, 11, 3, 0, 6, 0, 4, 6, -1, -1, -1, -1, -1, -1, -1 },
        { 8, 6, 11, 8, 4, 6, 9, 0, 1, -1, -1, -1, -1, -1, -1, -1 }, { 9, 4, 6, 9, 6, 3, 9, 3, 1, 11, 3, 6, -1, -1, -1, -1 },
        { 6, 8, 4, 6, 11, 8, 2, 10, 1, -1, -1, -1, -1, -1, -1, -1 }, { 1, 2, 10, 3, 0, 11, 0, 6, 11, 0, 4, 6, -1, -1, -1, -1 },
        { 4, 11, 8, 4, 6, 11, 0, 2, 9, 2, 10, 9, -1, -1, -1, -1 }, { 10, 9, 3, 10, 3, 2, 9, 4, 3, 11, 3, 6, 4, 6, 3, -1 },
        { 8, 2, 3, 8, 4, 2, 4, 6, 2, -1, -1, -1, -1, -1, -1, -1 }, { 0, 4, 2, 4, 6, 2, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 1, 9, 0, 2, 3, 4, 2, 4, 6, 4, 3, 8, -1, -1, -1, -1 }, { 1, 9, 4, 1, 4, 2, 2, 4, 6, -1, -1, -1, -1, -1, -1, -1 },
        { 8, 1, 3, 8, 6, 1, 8, 4, 6, 6, 10, 1, -1, -1, -1, -1 }, { 10, 1, 0, 10, 0, 6, 6, 0, 4, -1, -1, -1, -1, -1, -1, -1 },
        { 4, 6, 3, 4, 3, 8, 6, 10, 3, 0, 3, 9, 10, 9, 3, -1 }, { 10, 9, 4, 6, 10, 4, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 4, 9, 5, 7, 6, 11, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 0, 8, 3, 4, 9, 5, 11, 7, 6, -1, -1, -1, -1, -1, -1, -1 },
        { 5, 0, 1, 5, 4, 0, 7, 6, 11, -1, -1, -1, -1, -1, -1, -1 }, { 11, 7, 6, 8, 3, 4, 3, 5, 4, 3, 1, 5, -1, -1, -1, -1 },
        { 9, 5, 4, 10, 1, 2, 7, 6, 11, -1, -1, -1, -1, -1, -1, -1 }, { 6, 11, 7, 1, 2, 10, 0, 8, 3, 4, 9, 5, -1, -1, -1, -1 },
        { 7, 6, 11, 5, 4, 10, 4, 2, 10, 4, 0, 2, -1, -1, -1, -1 }, { 3, 4, 8, 3, 5, 4, 3, 2, 5, 10, 5, 2, 11, 7, 6, -1 },
        { 7, 2, 3, 7, 6, 2, 5, 4, 9, -1, -1, -1, -1, -1, -1, -1 }, { 9, 5, 4, 0, 8, 6, 0, 6, 2, 6, 8, 7, -1, -1, -1, -1 },
        { 3, 6, 2, 3, 7, 6, 1, 5, 0, 5, 4, 0, -1, -1, -1, -1 }, { 6, 2, 8, 6, 8, 7, 2, 1, 8, 4, 8, 5, 1, 5, 8, -1 },
        { 9, 5, 4, 10, 1, 6, 1, 7, 6, 1, 3, 7, -1, -1, -1, -1 }, { 1, 6, 10, 1, 7, 6, 1, 0, 7, 8, 7, 0, 9, 5, 4, -1 },
        { 4, 0, 10, 4, 10, 5, 0, 3, 10, 6, 10, 7, 3, 7, 10, -1 }, { 7, 6, 10, 7, 10, 8, 5, 4, 10, 4, 8, 10, -1, -1, -1, -1 },
        { 6, 9, 5, 6, 11, 9, 11, 8, 9, -1, -1, -1, -1, -1, -1, -1 }, { 3, 6, 11, 0, 6, 3, 0, 5, 6, 0, 9, 5, -1, -1, -1, -1 },
        { 0, 11, 8, 0, 5, 11, 0, 1, 5, 5, 6, 11, -1, -1, -1, -1 }, { 6, 11, 3, 6, 3, 5, 5, 3, 1, -1, -1, -1, -1, -1, -1, -1 },
        { 1, 2, 10, 9, 5, 11, 9, 11, 8, 11, 5, 6, -1, -1, -1, -1 }, { 0, 11, 3, 0, 6, 11, 0, 9, 6, 5, 6, 9, 1, 2, 10, -1 },
        { 11, 8, 5, 11, 5, 6, 8, 0, 5, 10, 5, 2, 0, 2, 5, -1 }, { 6, 11, 3, 6, 3, 5, 2, 10, 3, 10, 5, 3, -1, -1, -1, -1 },
        { 5, 8, 9, 5, 2, 8, 5, 6, 2, 3, 8, 2, -1, -1, -1, -1 }, { 9, 5, 6, 9, 6, 0, 0, 6, 2, -1, -1, -1, -1, -1, -1, -1 },
        { 1, 5, 8, 1, 8, 0, 5, 6, 8, 3, 8, 2, 6, 2, 8, -1 }, { 1, 5, 6, 2, 1, 6, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 1, 3, 6, 1, 6, 10, 3, 8, 6, 5, 6, 9, 8, 9, 6, -1 }, { 10, 1, 0, 10, 0, 6, 9, 5, 0, 5, 6, 0, -1, -1, -1, -1 },
        { 0, 3, 8, 5, 6, 10, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 10, 5, 6, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 11, 5, 10, 7, 5, 11, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 11, 5, 10, 11, 7, 5, 8, 3, 0, -1, -1, -1, -1, -1, -1, -1 },
        { 5, 11, 7, 5, 10, 11, 1, 9, 0, -1, -1, -1, -1, -1, -1, -1 }, { 10, 7, 5, 10, 11, 7, 9, 8, 1, 8, 3, 1, -1, -1, -1, -1 },
        { 11, 1, 2, 11, 7, 1, 7, 5, 1, -1, -1, -1, -1, -1, -1, -1 }, { 0, 8, 3, 1, 2, 7, 1, 7, 5, 7, 2, 11, -1, -1, -1, -1 },
        { 9, 7, 5, 9, 2, 7, 9, 0, 2, 2, 11, 7, -1, -1, -1, -1 }, { 7, 5, 2, 7, 2, 11, 5, 9, 2, 3, 2, 8, 9, 8, 2, -1 },
        { 2, 5, 10, 2, 3, 5, 3, 7, 5, -1, -1, -1, -1, -1, -1, -1 }, { 8, 2, 0, 8, 5, 2, 8, 7, 5, 10, 2, 5, -1, -1, -1, -1 },
        { 9, 0, 1, 5, 10, 3, 5, 3, 7, 3, 10, 2, -1, -1, -1, -1 }, { 9, 8, 2, 9, 2, 1, 8, 7, 2, 10, 2, 5, 7, 5, 2, -1 },
        { 1, 3, 5, 3, 7, 5, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 0, 8, 7, 0, 7, 1, 1, 7, 5, -1, -1, -1, -1, -1, -1, -1 },
        { 9, 0, 3, 9, 3, 5, 5, 3, 7, -1, -1, -1, -1, -1, -1, -1 }, { 9, 8, 7, 5, 9, 7, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 5, 8, 4, 5, 10, 8, 10, 11, 8, -1, -1, -1, -1, -1, -1, -1 }, { 5, 0, 4, 5, 11, 0, 5, 10, 11, 11, 3, 0, -1, -1, -1, -1 },
        { 0, 1, 9, 8, 4, 10, 8, 10, 11, 10, 4, 5, -1, -1, -1, -1 }, { 10, 11, 4, 10, 4, 5, 11, 3, 4, 9, 4, 1, 3, 1, 4, -1 },
        { 2, 5, 1, 2, 8, 5, 2, 11, 8, 4, 5, 8, -1, -1, -1, -1 }, { 0, 4, 11, 0, 11, 3, 4, 5, 11, 2, 11, 1, 5, 1, 11, -1 },
        { 0, 2, 5, 0, 5, 9, 2, 11, 5, 4, 5, 8, 11, 8, 5, -1 }, { 9, 4, 5, 2, 11, 3, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 2, 5, 10, 3, 5, 2, 3, 4, 5, 3, 8, 4, -1, -1, -1, -1 }, { 5, 10, 2, 5, 2, 4, 4, 2, 0, -1, -1, -1, -1, -1, -1, -1 },
        { 3, 10, 2, 3, 5, 10, 3, 8, 5, 4, 5, 8, 0, 1, 9, -1 }, { 5, 10, 2, 5, 2, 4, 1, 9, 2, 9, 4, 2, -1, -1, -1, -1 },
        { 8, 4, 5, 8, 5, 3, 3, 5, 1, -1, -1, -1, -1, -1, -1, -1 }, { 0, 4, 5, 1, 0, 5, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 8, 4, 5, 8, 5, 3, 9, 0, 5, 0, 3, 5, -1, -1, -1, -1 }, { 9, 4, 5, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 4, 11, 7, 4, 9, 11, 9, 10, 11, -1, -1, -1, -1, -1, -1, -1 }, { 0, 8, 3, 4, 9, 7, 9, 11, 7, 9, 10, 11, -1, -1, -1, -1 },
        { 1, 10, 11, 1, 11, 4, 1, 4, 0, 7, 4, 11, -1, -1, -1, -1 }, { 3, 1, 4, 3, 4, 8, 1, 10, 4, 7, 4, 11, 10, 11, 4, -1 },
        { 4, 11, 7, 9, 11, 4, 9, 2, 11, 9, 1, 2, -1, -1, -1, -1 }, { 9, 7, 4, 9, 11, 7, 9, 1, 11, 2, 11, 1, 0, 8, 3, -1 },
        { 11, 7, 4, 11, 4, 2, 2, 4, 0, -1, -1, -1, -1, -1, -1, -1 }, { 11, 7, 4, 11, 4, 2, 8, 3, 4, 3, 2, 4, -1, -1, -1, -1 },
        { 2, 9, 10, 2, 7, 9, 2, 3, 7, 7, 4, 9, -1, -1, -1, -1 }, { 9, 10, 7, 9, 7, 4, 10, 2, 7, 8, 7, 0, 2, 0, 7, -1 },
        { 3, 7, 10, 3, 10, 2, 7, 4, 10, 1, 10, 0, 4, 0, 10, -1 }, { 1, 10, 2, 8, 7, 4, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 4, 9, 1, 4, 1, 7, 7, 1, 3, -1, -1, -1, -1, -1, -1, -1 }, { 4, 9, 1, 4, 1, 7, 0, 8, 1, 8, 7, 1, -1, -1, -1, -1 },
        { 4, 0, 3, 7, 4, 3, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 4, 8, 7, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 9, 10, 8, 10, 11, 8, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 3, 0, 9, 3, 9, 11, 11, 9, 10, -1, -1, -1, -1, -1, -1, -1 },
        { 0, 1, 10, 0, 10, 8, 8, 10, 11, -1, -1, -1, -1, -1, -1, -1 }, { 3, 1, 10, 11, 3, 10, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 1, 2, 11, 1, 11, 9, 9, 11, 8, -1, -1, -1, -1, -1, -1, -1 }, { 3, 0, 9, 3, 9, 11, 1, 2, 9, 2, 11, 9, -1, -1, -1, -1 },
        { 0, 2, 11, 8, 0, 11, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 3, 2, 11, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 2, 3, 8, 2, 8, 10, 10, 8, 9, -1, -1, -1, -1, -1, -1, -1 }, { 9, 10, 2, 0, 9, 2, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 2, 3, 8, 2, 8, 10, 0, 1, 8, 1, 10, 8, -1, -1, -1, -1 }, { 1, 10, 2, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 1, 3, 8, 9, 1, 8, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { 0, 9, 1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 },
        { 0, 3, 8, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }, { -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1 }
      };

      const unsigned int
        _nx = (unsigned int)(size_x>=0?size_x:cimg::round((x1-x0)*-size_x/100 + 1)),
        _ny = (unsigned int)(size_y>=0?size_y:cimg::round((y1-y0)*-size_y/100 + 1)),
        _nz = (unsigned int)(size_z>=0?size_z:cimg::round((z1-z0)*-size_z/100 + 1)),
        nx = _nx?_nx:1,
        ny = _ny?_ny:1,
        nz = _nz?_nz:1,
        nxm1 = nx - 1,
        nym1 = ny - 1,
        nzm1 = nz - 1;
      primitives.assign();
      if (!nxm1 || !nym1 || !nzm1) return CImg<floatT>();
      const float dx = (x1 - x0)/nxm1, dy = (y1 - y0)/nym1, dz = (z1 - z0)/nzm1;
      CImgList<floatT> vertices;
      CImg<intT> indices1(nx,ny,1,3,-1), indices2(indices1);
      CImg<floatT> values1(nx,ny), values2(nx,ny);
      float X = 0, Y = 0, Z = 0, nX = 0, nY = 0, nZ = 0;

      // Fill the first plane with function values
      Y = y0;
      cimg_forY(values1,y) {
        X = x0;
        cimg_forX(values1,x) { values1(x,y) = (float)func(X,Y,z0); X+=dx; }
        Y+=dy;
      }

      // Run Marching Cubes algorithm
      Z = z0; nZ = Z + dz;
      for (unsigned int zi = 0; zi<nzm1; ++zi, Z = nZ, nZ+=dz) {
        Y = y0; nY = Y + dy;
        indices2.fill(-1);
        for (unsigned int yi = 0, nyi = 1; yi<nym1; ++yi, ++nyi, Y = nY, nY+=dy) {
          X = x0; nX = X + dx;
          for (unsigned int xi = 0, nxi = 1; xi<nxm1; ++xi, ++nxi, X = nX, nX+=dx) {

            // Determine cube configuration
            const float
              val0 = values1(xi,yi),
              val1 = values1(nxi,yi),
              val2 = values1(nxi,nyi),
              val3 = values1(xi,nyi),
              val4 = values2(xi,yi) = (float)func(X,Y,nZ),
              val5 = values2(nxi,yi) = (float)func(nX,Y,nZ),
              val6 = values2(nxi,nyi) = (float)func(nX,nY,nZ),
              val7 = values2(xi,nyi) = (float)func(X,nY,nZ);

            const unsigned int configuration =
              (val0<isovalue?1:0)  | (val1<isovalue?2:0)  | (val2<isovalue?4:0)  | (val3<isovalue?8:0) |
              (val4<isovalue?16:0) | (val5<isovalue?32:0) | (val6<isovalue?64:0) | (val7<isovalue?128:0),
              edge = edges[configuration];

            // Compute intersection vertices
            if (edge) {
              if ((edge&1) && indices1(xi,yi,0)<0) {
                const float Xi = X + (isovalue-val0)*dx/(val1-val0);
                indices1(xi,yi,0) = vertices._width;
                CImg<floatT>::vector(Xi,Y,Z).move_to(vertices);
              }
              if ((edge&2) && indices1(nxi,yi,1)<0) {
                const float Yi = Y + (isovalue-val1)*dy/(val2-val1);
                indices1(nxi,yi,1) = vertices._width;
                CImg<floatT>::vector(nX,Yi,Z).move_to(vertices);
              }
              if ((edge&4) && indices1(xi,nyi,0)<0) {
                const float Xi = X + (isovalue-val3)*dx/(val2-val3);
                indices1(xi,nyi,0) = vertices._width;
                CImg<floatT>::vector(Xi,nY,Z).move_to(vertices);
              }
              if ((edge&8) && indices1(xi,yi,1)<0) {
                const float Yi = Y + (isovalue-val0)*dy/(val3-val0);
                indices1(xi,yi,1) = vertices._width;
                CImg<floatT>::vector(X,Yi,Z).move_to(vertices);
              }
              if ((edge&16) && indices2(xi,yi,0)<0) {
                const float Xi = X + (isovalue-val4)*dx/(val5-val4);
                indices2(xi,yi,0) = vertices._width;
                CImg<floatT>::vector(Xi,Y,nZ).move_to(vertices);
              }
              if ((edge&32) && indices2(nxi,yi,1)<0) {
                const float Yi = Y + (isovalue-val5)*dy/(val6-val5);
                indices2(nxi,yi,1) = vertices._width;
                CImg<floatT>::vector(nX,Yi,nZ).move_to(vertices);
              }
              if ((edge&64) && indices2(xi,nyi,0)<0) {
                const float Xi = X + (isovalue-val7)*dx/(val6-val7);
                indices2(xi,nyi,0) = vertices._width;
                CImg<floatT>::vector(Xi,nY,nZ).move_to(vertices);
              }
              if ((edge&128) && indices2(xi,yi,1)<0)  {
                const float Yi = Y + (isovalue-val4)*dy/(val7-val4);
                indices2(xi,yi,1) = vertices._width;
                CImg<floatT>::vector(X,Yi,nZ).move_to(vertices);
              }
              if ((edge&256) && indices1(xi,yi,2)<0) {
                const float Zi = Z+ (isovalue-val0)*dz/(val4-val0);
                indices1(xi,yi,2) = vertices._width;
                CImg<floatT>::vector(X,Y,Zi).move_to(vertices);
              }
              if ((edge&512) && indices1(nxi,yi,2)<0)  {
                const float Zi = Z + (isovalue-val1)*dz/(val5-val1);
                indices1(nxi,yi,2) = vertices._width;
                CImg<floatT>::vector(nX,Y,Zi).move_to(vertices);
              }
              if ((edge&1024) && indices1(nxi,nyi,2)<0) {
                const float Zi = Z + (isovalue-val2)*dz/(val6-val2);
                indices1(nxi,nyi,2) = vertices._width;
                CImg<floatT>::vector(nX,nY,Zi).move_to(vertices);
              }
              if ((edge&2048) && indices1(xi,nyi,2)<0) {
                const float Zi = Z + (isovalue-val3)*dz/(val7-val3);
                indices1(xi,nyi,2) = vertices._width;
                CImg<floatT>::vector(X,nY,Zi).move_to(vertices);
              }

              // Create triangles
              for (const int *triangle = triangles[configuration]; *triangle!=-1; ) {
                const unsigned int p0 = *(triangle++), p1 = *(triangle++), p2 = *(triangle++);
                const tf
                  i0 = (tf)(_isosurface3d_indice(p0,indices1,indices2,xi,yi,nxi,nyi)),
                  i1 = (tf)(_isosurface3d_indice(p1,indices1,indices2,xi,yi,nxi,nyi)),
                  i2 = (tf)(_isosurface3d_indice(p2,indices1,indices2,xi,yi,nxi,nyi));
                CImg<tf>::vector(i0,i2,i1).move_to(primitives);
              }
            }
          }
        }
        cimg::swap(values1,values2);
        cimg::swap(indices1,indices2);
      }
      return vertices>'x';
    }

    //! Compute isosurface of a function, as a 3d object \overloading.
    template<typename tf>
    static CImg<floatT> isosurface3d(CImgList<tf>& primitives, const char *const expression, const float isovalue,
                                     const float x0, const float y0, const float z0,
                                     const float x1, const float y1, const float z1,
                                     const int dx=32, const int dy=32, const int dz=32) {
      const _functor3d_expr func(expression);
      return isosurface3d(primitives,func,isovalue,x0,y0,z0,x1,y1,z1,dx,dy,dz);
    }

    template<typename t>
    static int _isosurface3d_indice(const unsigned int edge, const CImg<t>& indices1, const CImg<t>& indices2,
                                    const unsigned int x, const unsigned int y, const unsigned int nx, const unsigned int ny) {
      switch (edge) {
      case 0 : return indices1(x,y,0);
      case 1 : return indices1(nx,y,1);
      case 2 : return indices1(x,ny,0);
      case 3 : return indices1(x,y,1);
      case 4 : return indices2(x,y,0);
      case 5 : return indices2(nx,y,1);
      case 6 : return indices2(x,ny,0);
      case 7 : return indices2(x,y,1);
      case 8 : return indices1(x,y,2);
      case 9 : return indices1(nx,y,2);
      case 10 : return indices1(nx,ny,2);
      case 11 : return indices1(x,ny,2);
      }
      return 0;
    }

    // Define functors for accessing image values (used in previous functions).
    struct _functor2d_int {
      const CImg<T>& ref;
      _functor2d_int(const CImg<T>& pref):ref(pref) {}
      float operator()(const float x, const float y) const {
        return (float)ref((int)x,(int)y);
      }
    };

    struct _functor2d_float {
      const CImg<T>& ref;
      _functor2d_float(const CImg<T>& pref):ref(pref) {}
      float operator()(const float x, const float y) const {
        return (float)ref._linear_atXY(x,y);
      }
    };

    struct _functor2d_expr {
      _cimg_math_parser *mp;
      _functor2d_expr(const char *const expr):mp(0) { mp = new _cimg_math_parser(CImg<T>::empty(),expr,0); }
      ~_functor2d_expr() { delete mp; }
      float operator()(const float x, const float y) const {
        return (float)mp->eval(x,y,0,0);
      }
    };

    struct _functor3d_int {
      const CImg<T>& ref;
      _functor3d_int(const CImg<T>& pref):ref(pref) {}
      float operator()(const float x, const float y, const float z) const {
        return (float)ref((int)x,(int)y,(int)z);
      }
    };

    struct _functor3d_float {
      const CImg<T>& ref;
      _functor3d_float(const CImg<T>& pref):ref(pref) {}
      float operator()(const float x, const float y, const float z) const {
        return (float)ref._linear_atXYZ(x,y,z);
      }
    };

    struct _functor3d_expr {
      _cimg_math_parser *mp;
      ~_functor3d_expr() { delete mp; }
      _functor3d_expr(const char *const expr):mp(0) { mp = new _cimg_math_parser(CImg<T>::empty(),expr,0); }
      float operator()(const float x, const float y, const float z) const {
        return (float)mp->eval(x,y,z,0);
      }
    };

    struct _functor4d_int {
      const CImg<T>& ref;
      _functor4d_int(const CImg<T>& pref):ref(pref) {}
      float operator()(const float x, const float y, const float z, const unsigned int c) const {
        return (float)ref((int)x,(int)y,(int)z,c);
      }
    };

    //! Generate a 3d box object.
    /**
       \param[out] primitives The returned list of the 3d object primitives
                              (template type \e tf should be at least \e unsigned \e int).
       \param size_x The width of the box (dimension along the X-axis).
       \param size_y The height of the box (dimension along the Y-axis).
       \param size_z The depth of the box (dimension along the Z-axis).
       \return The N vertices (xi,yi,zi) of the 3d object as a Nx3 CImg<float> image (0<=i<=N-1).
       \par Example
       \code
       CImgList<unsigned int> faces3d;
       const CImg<float> points3d = CImg<float>::box3d(faces3d,10,20,30);
       CImg<unsigned char>().display_object3d("Box3d",points3d,faces3d);
       \endcode
       \image html ref_box3d.jpg
    **/
    template<typename tf>
    static CImg<floatT> box3d(CImgList<tf>& primitives,
                              const float size_x=200, const float size_y=100, const float size_z=100) {
      primitives.assign(6,1,4,1,1, 0,3,2,1, 4,5,6,7, 0,1,5,4, 3,7,6,2, 0,4,7,3, 1,2,6,5);
      return CImg<floatT>(8,3,1,1,
                          0.,size_x,size_x,    0.,    0.,size_x,size_x,    0.,
                          0.,    0.,size_y,size_y,    0.,    0.,size_y,size_y,
                          0.,    0.,    0.,    0.,size_z,size_z,size_z,size_z);
    }

    //! Generate a 3d cone.
    /**
       \param[out] primitives The returned list of the 3d object primitives
                              (template type \e tf should be at least \e unsigned \e int).
       \param radius The radius of the cone basis.
       \param size_z The cone's height.
       \param subdivisions The number of basis angular subdivisions.
       \return The N vertices (xi,yi,zi) of the 3d object as a Nx3 CImg<float> image (0<=i<=N-1).
       \par Example
       \code
       CImgList<unsigned int> faces3d;
       const CImg<float> points3d = CImg<float>::cone3d(faces3d,50);
       CImg<unsigned char>().display_object3d("Cone3d",points3d,faces3d);
       \endcode
       \image html ref_cone3d.jpg
    **/
    template<typename tf>
    static CImg<floatT> cone3d(CImgList<tf>& primitives,
                               const float radius=50, const float size_z=100, const unsigned int subdivisions=24) {
      primitives.assign();
      if (!subdivisions) return CImg<floatT>();
      CImgList<floatT> vertices(2,1,3,1,1,
                                0.,0.,size_z,
                                0.,0.,0.);
      for (float delta = 360.0f/subdivisions, angle = 0; angle<360; angle+=delta) {
	const float a = (float)(angle*cimg::PI/180);
        CImg<floatT>::vector((float)(radius*std::cos(a)),(float)(radius*std::sin(a)),0).move_to(vertices);
      }
      const unsigned int nbr = vertices._width - 2;
      for (unsigned int p = 0; p<nbr; ++p) {
	const unsigned int curr = 2 + p, next = 2 + ((p+1)%nbr);
        CImg<tf>::vector(1,next,curr).move_to(primitives);
        CImg<tf>::vector(0,curr,next).move_to(primitives);
      }
      return vertices>'x';
    }

    //! Generate a 3d cylinder.
    /**
       \param[out] primitives The returned list of the 3d object primitives
                              (template type \e tf should be at least \e unsigned \e int).
       \param radius The radius of the cylinder basis.
       \param size_z The cylinder's height.
       \param subdivisions The number of basis angular subdivisions.
       \return The N vertices (xi,yi,zi) of the 3d object as a Nx3 CImg<float> image (0<=i<=N-1).
       \par Example
       \code
       CImgList<unsigned int> faces3d;
       const CImg<float> points3d = CImg<float>::cylinder3d(faces3d,50);
       CImg<unsigned char>().display_object3d("Cylinder3d",points3d,faces3d);
       \endcode
       \image html ref_cylinder3d.jpg
    **/
    template<typename tf>
    static CImg<floatT> cylinder3d(CImgList<tf>& primitives,
                                   const float radius=50, const float size_z=100, const unsigned int subdivisions=24) {
      primitives.assign();
      if (!subdivisions) return CImg<floatT>();
      CImgList<floatT> vertices(2,1,3,1,1,
                                0.,0.,0.,
                                0.,0.,size_z);
      for (float delta = 360.0f/subdivisions, angle = 0; angle<360; angle+=delta) {
	const float a = (float)(angle*cimg::PI/180);
        CImg<floatT>::vector((float)(radius*std::cos(a)),(float)(radius*std::sin(a)),0.0f).move_to(vertices);
        CImg<floatT>::vector((float)(radius*std::cos(a)),(float)(radius*std::sin(a)),size_z).move_to(vertices);
      }
      const unsigned int nbr = (vertices._width - 2)/2;
      for (unsigned int p = 0; p<nbr; ++p) {
	const unsigned int curr = 2+2*p, next = 2+(2*((p+1)%nbr));
        CImg<tf>::vector(0,next,curr).move_to(primitives);
        CImg<tf>::vector(1,curr+1,next+1).move_to(primitives);
        CImg<tf>::vector(curr,next,next+1,curr+1).move_to(primitives);
      }
      return vertices>'x';
    }

    //! Generate a 3d torus.
    /**
       \param[out] primitives The returned list of the 3d object primitives
                              (template type \e tf should be at least \e unsigned \e int).
       \param radius1 The large radius.
       \param radius2 The small radius.
       \param subdivisions1 The number of angular subdivisions for the large radius.
       \param subdivisions2 The number of angular subdivisions for the small radius.
       \return The N vertices (xi,yi,zi) of the 3d object as a Nx3 CImg<float> image (0<=i<=N-1).
       \par Example
       \code
       CImgList<unsigned int> faces3d;
       const CImg<float> points3d = CImg<float>::torus3d(faces3d,20,4);
       CImg<unsigned char>().display_object3d("Torus3d",points3d,faces3d);
       \endcode
       \image html ref_torus3d.jpg
    **/
    template<typename tf>
    static CImg<floatT> torus3d(CImgList<tf>& primitives,
                                const float radius1=100, const float radius2=30,
                                const unsigned int subdivisions1=24, const unsigned int subdivisions2=12) {
      primitives.assign();
      if (!subdivisions1 || !subdivisions2) return CImg<floatT>();
      CImgList<floatT> vertices;
      for (unsigned int v = 0; v<subdivisions1; ++v) {
	const float
	  beta = (float)(v*2*cimg::PI/subdivisions1),
	  xc = radius1*(float)std::cos(beta),
	  yc = radius1*(float)std::sin(beta);
        for (unsigned int u = 0; u<subdivisions2; ++u) {
          const float
            alpha = (float)(u*2*cimg::PI/subdivisions2),
            x = xc + radius2*(float)(std::cos(alpha)*std::cos(beta)),
	    y = yc + radius2*(float)(std::cos(alpha)*std::sin(beta)),
	    z = radius2*(float)std::sin(alpha);
          CImg<floatT>::vector(x,y,z).move_to(vertices);
        }
      }
      for (unsigned int vv = 0; vv<subdivisions1; ++vv) {
	const unsigned int nv = (vv+1)%subdivisions1;
        for (unsigned int uu = 0; uu<subdivisions2; ++uu) {
          const unsigned int nu = (uu+1)%subdivisions2, svv = subdivisions2*vv, snv = subdivisions2*nv;
          CImg<tf>::vector(svv+nu,svv+uu,snv+uu,snv+nu).move_to(primitives);
        }
      }
      return vertices>'x';
    }

    //! Generate a 3d XY-plane.
    /**
       \param[out] primitives The returned list of the 3d object primitives
                              (template type \e tf should be at least \e unsigned \e int).
       \param size_x The width of the plane (dimension along the X-axis).
       \param size_y The height of the plane (dimensions along the Y-axis).
       \param subdivisions_x The number of planar subdivisions along the X-axis.
       \param subdivisions_y The number of planar subdivisions along the Y-axis.
       \return The N vertices (xi,yi,zi) of the 3d object as a Nx3 CImg<float> image (0<=i<=N-1).
       \par Example
       \code
       CImgList<unsigned int> faces3d;
       const CImg<float> points3d = CImg<float>::plane3d(faces3d,100,50);
       CImg<unsigned char>().display_object3d("Plane3d",points3d,faces3d);
       \endcode
       \image html ref_plane3d.jpg
    **/
    template<typename tf>
    static CImg<floatT> plane3d(CImgList<tf>& primitives,
                                const float size_x=100, const float size_y=100,
                                const unsigned int subdivisions_x=10, const unsigned int subdivisions_y=10) {
      primitives.assign();
      if (!subdivisions_x || !subdivisions_y) return CImg<floatT>();
      CImgList<floatT> vertices;
      const unsigned int w = subdivisions_x + 1, h = subdivisions_y + 1;
      const float fx = (float)size_x/w, fy = (float)size_y/h;
      for (unsigned int y = 0; y<h; ++y) for (unsigned int x = 0; x<w; ++x)
        CImg<floatT>::vector(fx*x,fy*y,0).move_to(vertices);
      for (unsigned int y = 0; y<subdivisions_y; ++y) for (unsigned int x = 0; x<subdivisions_x; ++x) {
        const int off1 = x+y*w, off2 = x+1+y*w, off3 = x+1+(y+1)*w, off4 = x+(y+1)*w;
	CImg<tf>::vector(off1,off4,off3,off2).move_to(primitives);
      }
      return vertices>'x';
    }

    //! Generate a 3d sphere.
    /**
       \param[out] primitives The returned list of the 3d object primitives
                              (template type \e tf should be at least \e unsigned \e int).
       \param radius The radius of the sphere (dimension along the X-axis).
       \param subdivisions The number of recursive subdivisions from an initial icosahedron.
       \return The N vertices (xi,yi,zi) of the 3d object as a Nx3 CImg<float> image (0<=i<=N-1).
       \par Example
       \code
       CImgList<unsigned int> faces3d;
       const CImg<float> points3d = CImg<float>::sphere3d(faces3d,100,4);
       CImg<unsigned char>().display_object3d("Sphere3d",points3d,faces3d);
       \endcode
       \image html ref_sphere3d.jpg
    **/
    template<typename tf>
    static CImg<floatT> sphere3d(CImgList<tf>& primitives,
                                 const float radius=50, const unsigned int subdivisions=3) {

      // Create initial icosahedron
      primitives.assign();
      const double tmp = (1+std::sqrt(5.0f))/2, a = 1.0/std::sqrt(1+tmp*tmp), b = tmp*a;
      CImgList<floatT> vertices(12,1,3,1,1, b,a,0.0, -b,a,0.0, -b,-a,0.0, b,-a,0.0, a,0.0,b, a,0.0,-b,
                                -a,0.0,-b, -a,0.0,b, 0.0,b,a, 0.0,-b,a, 0.0,-b,-a, 0.0,b,-a);
      primitives.assign(20,1,3,1,1, 4,8,7, 4,7,9, 5,6,11, 5,10,6, 0,4,3, 0,3,5, 2,7,1, 2,1,6,
                        8,0,11, 8,11,1, 9,10,3, 9,2,10, 8,4,0, 11,0,5, 4,9,3,
                        5,3,10, 7,8,1, 6,1,11, 7,2,9, 6,10,2);
      // edge - length/2
      float he = (float)a;

      // Recurse subdivisions
      for (unsigned int i = 0; i<subdivisions; ++i) {
        const unsigned int L = primitives._width;
	he/=2;
	const float he2 = he*he;
        for (unsigned int l = 0; l<L; ++l) {
          const unsigned int
            p0 = (unsigned int)primitives(0,0), p1 = (unsigned int)primitives(0,1), p2 = (unsigned int)primitives(0,2);
          const float
            x0 = vertices(p0,0), y0 = vertices(p0,1), z0 = vertices(p0,2),
            x1 = vertices(p1,0), y1 = vertices(p1,1), z1 = vertices(p1,2),
            x2 = vertices(p2,0), y2 = vertices(p2,1), z2 = vertices(p2,2),
            tnx0 = (x0+x1)/2, tny0 = (y0+y1)/2, tnz0 = (z0+z1)/2, nn0 = (float)std::sqrt(tnx0*tnx0+tny0*tny0+tnz0*tnz0),
            tnx1 = (x0+x2)/2, tny1 = (y0+y2)/2, tnz1 = (z0+z2)/2, nn1 = (float)std::sqrt(tnx1*tnx1+tny1*tny1+tnz1*tnz1),
            tnx2 = (x1+x2)/2, tny2 = (y1+y2)/2, tnz2 = (z1+z2)/2, nn2 = (float)std::sqrt(tnx2*tnx2+tny2*tny2+tnz2*tnz2),
            nx0 = tnx0/nn0, ny0 = tny0/nn0, nz0 = tnz0/nn0,
            nx1 = tnx1/nn1, ny1 = tny1/nn1, nz1 = tnz1/nn1,
            nx2 = tnx2/nn2, ny2 = tny2/nn2, nz2 = tnz2/nn2;
          int i0 = -1, i1 = -1, i2 = -1;
          cimglist_for(vertices,p) {
            const float x = (float)vertices(p,0), y = (float)vertices(p,1), z = (float)vertices(p,2);
            if (cimg::sqr(x-nx0) + cimg::sqr(y-ny0) + cimg::sqr(z-nz0)<he2) i0 = p;
            if (cimg::sqr(x-nx1) + cimg::sqr(y-ny1) + cimg::sqr(z-nz1)<he2) i1 = p;
            if (cimg::sqr(x-nx2) + cimg::sqr(y-ny2) + cimg::sqr(z-nz2)<he2) i2 = p;
          }
          if (i0<0) { CImg<floatT>::vector(nx0,ny0,nz0).move_to(vertices); i0 = vertices._width - 1; }
          if (i1<0) { CImg<floatT>::vector(nx1,ny1,nz1).move_to(vertices); i1 = vertices._width - 1; }
          if (i2<0) { CImg<floatT>::vector(nx2,ny2,nz2).move_to(vertices); i2 = vertices._width - 1; }
          primitives.remove(0);
          CImg<tf>::vector(p0,i0,i1).move_to(primitives);
          CImg<tf>::vector((tf)i0,(tf)p1,(tf)i2).move_to(primitives);
          CImg<tf>::vector((tf)i1,(tf)i2,(tf)p2).move_to(primitives);
          CImg<tf>::vector((tf)i1,(tf)i0,(tf)i2).move_to(primitives);
        }
      }
      return (vertices>'x')*=radius;
    }

    //! Generate a 3d ellipsoid.
    /**
       \param[out] primitives The returned list of the 3d object primitives
                              (template type \e tf should be at least \e unsigned \e int).
       \param tensor The tensor which gives the shape and size of the ellipsoid.
       \param subdivisions The number of recursive subdivisions from an initial stretched icosahedron.
       \return The N vertices (xi,yi,zi) of the 3d object as a Nx3 CImg<float> image (0<=i<=N-1).
       \par Example
       \code
       CImgList<unsigned int> faces3d;
       const CImg<float> tensor = CImg<float>::diagonal(10,7,3),
                         points3d = CImg<float>::ellipsoid3d(faces3d,tensor,4);
       CImg<unsigned char>().display_object3d("Ellipsoid3d",points3d,faces3d);
       \endcode
       \image html ref_ellipsoid3d.jpg
    **/
    template<typename tf, typename t>
    static CImg<floatT> ellipsoid3d(CImgList<tf>& primitives,
                                    const CImg<t>& tensor, const unsigned int subdivisions=3) {
      primitives.assign();
      if (!subdivisions) return CImg<floatT>();
      CImg<floatT> S, V;
      tensor.symmetric_eigen(S,V);
      const float orient =
        (V(0,1)*V(1,2) - V(0,2)*V(1,1))*V(2,0) +
        (V(0,2)*V(1,0) - V(0,0)*V(1,2))*V(2,1) +
        (V(0,0)*V(1,1) - V(0,1)*V(1,0))*V(2,2);
      if (orient<0) { V(2,0) = -V(2,0); V(2,1) = -V(2,1); V(2,2) = -V(2,2); }
      const float l0 = S[0], l1 = S[1], l2 = S[2];
      CImg<floatT> vertices = sphere3d(primitives,1.0,subdivisions);
      vertices.get_shared_row(0)*=l0;
      vertices.get_shared_row(1)*=l1;
      vertices.get_shared_row(2)*=l2;
      return V*vertices;
    }

    //! Convert 3d object into a CImg3d representation.
    /**
       \param primitives Primitives data of the 3d object.
       \param colors Colors data of the 3d object.
       \param opacities Opacities data of the 3d object.
       \param full_check Tells if full checking of the 3d object must be performed.
    **/
    template<typename tp, typename tc, typename to>
    CImg<T>& object3dtoCImg3d(const CImgList<tp>& primitives,
                              const CImgList<tc>& colors,
                              const to& opacities,
                              const bool full_check=true) {
      return get_object3dtoCImg3d(primitives,colors,opacities,full_check).move_to(*this);
    }

    //! Convert 3d object into a CImg3d representation \overloading.
    template<typename tp, typename tc>
    CImg<T>& object3dtoCImg3d(const CImgList<tp>& primitives,
                              const CImgList<tc>& colors,
                              const bool full_check=true) {
      return get_object3dtoCImg3d(primitives,colors,full_check).move_to(*this);
    }

    //! Convert 3d object into a CImg3d representation \overloading.
    template<typename tp>
    CImg<T>& object3dtoCImg3d(const CImgList<tp>& primitives,
                              const bool full_check=true) {
      return get_object3dtoCImg3d(primitives,full_check).move_to(*this);
    }

    //! Convert 3d object into a CImg3d representation \overloading.
    CImg<T>& object3dtoCImg3d(const bool full_check=true) {
      return get_object3dtoCImg3d(full_check).move_to(*this);
    }

    //! Convert 3d object into a CImg3d representation \newinstance.
    template<typename tp, typename tc, typename to>
    CImg<floatT> get_object3dtoCImg3d(const CImgList<tp>& primitives,
                                      const CImgList<tc>& colors,
                                      const to& opacities,
                                      const bool full_check=true) const {
      char error_message[1024] = { 0 };
      if (!is_object3d(primitives,colors,opacities,full_check,error_message))
        throw CImgInstanceException(_cimg_instance
                                    "object3dtoCImg3d(): Invalid specified 3d object (%u,%u) (%s).",
                                    cimg_instance,_width,primitives._width,error_message);
      CImg<floatT> res(1,_size_object3dtoCImg3d(primitives,colors,opacities));
      float *ptrd = res._data;

      // Put magick number.
      *(ptrd++) = 'C' + 0.5f; *(ptrd++) = 'I' + 0.5f; *(ptrd++) = 'm' + 0.5f;
      *(ptrd++) = 'g' + 0.5f; *(ptrd++) = '3' + 0.5f; *(ptrd++) = 'd' + 0.5f;

      // Put number of vertices and primitives.
      *(ptrd++) = cimg::uint2float(_width);
      *(ptrd++) = cimg::uint2float(primitives._width);

      // Put vertex data.
      if (is_empty() || !primitives) return res;
      const T *ptrx = data(0,0), *ptry = data(0,1), *ptrz = data(0,2);
      cimg_forX(*this,p) {
        *(ptrd++) = (float)*(ptrx++);
        *(ptrd++) = (float)*(ptry++);
        *(ptrd++) = (float)*(ptrz++);
      }

      // Put primitive data.
      cimglist_for(primitives,p) {
        *(ptrd++) = (float)primitives[p].size();
        const tp *ptrp = primitives[p]._data;
        cimg_foroff(primitives[p],i) *(ptrd++) = cimg::uint2float((unsigned int)*(ptrp++));
      }

      // Put color/texture data.
      const unsigned int csiz = cimg::min(colors._width,primitives._width);
      for (int c = 0; c<(int)csiz; ++c) {
        const CImg<tc>& color = colors[c];
        const tc *ptrc = color._data;
        if (color.size()==3) { *(ptrd++) = (float)*(ptrc++); *(ptrd++) = (float)*(ptrc++); *(ptrd++) = (float)*ptrc; }
        else {
          *(ptrd++) = -128.0f;
          int shared_ind = -1;
          if (color.is_shared()) for (int i = 0; i<c; ++i) if (ptrc==colors[i]._data) { shared_ind = i; break; }
          if (shared_ind<0) {
            *(ptrd++) = (float)color._width;
            *(ptrd++) = (float)color._height;
            *(ptrd++) = (float)color._spectrum;
            cimg_foroff(color,l) *(ptrd++) = (float)*(ptrc++);
          } else {
            *(ptrd++) = (float)shared_ind;
            *(ptrd++) = 0;
            *(ptrd++) = 0;
          }
        }
      }
      const int csiz2 = primitives._width - colors._width;
      for (int c = 0; c<csiz2; ++c) { *(ptrd++) = 200.0f; *(ptrd++) = 200.0f; *(ptrd++) = 200.0f; }

      // Put opacity data.
      ptrd = _object3dtoCImg3d(opacities,ptrd);
      const float *ptre = res.end();
      while (ptrd<ptre) *(ptrd++) = 1.0f;
      return res;
    }

    template<typename to>
    float* _object3dtoCImg3d(const CImgList<to>& opacities, float *ptrd) const {
      cimglist_for(opacities,o) {
        const CImg<to>& opacity = opacities[o];
        const to *ptro = opacity._data;
        if (opacity.size()==1) *(ptrd++) = (float)*ptro;
        else {
          *(ptrd++) = -128.0f;
          int shared_ind = -1;
          if (opacity.is_shared()) for (int i = 0; i<o; ++i) if (ptro==opacities[i]._data) { shared_ind = i; break; }
          if (shared_ind<0) {
            *(ptrd++) = (float)opacity._width;
            *(ptrd++) = (float)opacity._height;
            *(ptrd++) = (float)opacity._spectrum;
            cimg_foroff(opacity,l) *(ptrd++) = (float)*(ptro++);
          } else {
            *(ptrd++) = (float)shared_ind;
            *(ptrd++) = 0;
            *(ptrd++) = 0;
          }
        }
      }
      return ptrd;
    }

    template<typename to>
    float* _object3dtoCImg3d(const CImg<to>& opacities, float *ptrd) const {
      const to *ptro = opacities._data;
      cimg_foroff(opacities,o) *(ptrd++) = (float)*(ptro++);
      return ptrd;
    }

    template<typename tp, typename tc, typename to>
    unsigned int _size_object3dtoCImg3d(const CImgList<tp>& primitives,
                                        const CImgList<tc>& colors,
                                        const CImgList<to>& opacities) const {
      unsigned int siz = 8 + 3*width();
      cimglist_for(primitives,p) siz+=primitives[p].size() + 1;
      for (int c = cimg::min(primitives._width,colors._width)-1; c>=0; --c) {
        if (colors[c].is_shared()) siz+=4;
        else { const unsigned int csiz = colors[c].size(); siz+=(csiz!=3)?4+csiz:3; }
      }
      if (colors._width<primitives._width) siz+=3*(primitives._width - colors._width);
      cimglist_for(opacities,o) {
        if (opacities[o].is_shared()) siz+=4;
        else { const unsigned int osiz = opacities[o].size(); siz+=(osiz!=1)?4+osiz:1; }
      }
      siz+=primitives._width - opacities._width;
      return siz;
    }

    template<typename tp, typename tc, typename to>
    unsigned int _size_object3dtoCImg3d(const CImgList<tp>& primitives,
                                        const CImgList<tc>& colors,
                                        const CImg<to>& opacities) const {
      unsigned int siz = 8 + 3*width();
      cimglist_for(primitives,p) siz+=primitives[p].size() + 1;
      for (int c = cimg::min(primitives._width,colors._width)-1; c>=0; --c) {
        const unsigned int csiz = colors[c].size(); siz+=(csiz!=3)?4+csiz:3;
      }
      if (colors._width<primitives._width) siz+=3*(primitives._width - colors._width);
      siz+=primitives.size();
      cimg::unused(opacities);
      return siz;
    }

    //! Convert 3d object into a CImg3d representation \overloading.
    template<typename tp, typename tc>
    CImg<floatT> get_object3dtoCImg3d(const CImgList<tp>& primitives,
                                      const CImgList<tc>& colors,
                                      const bool full_check=true) const {
      CImgList<T> opacities;
      return get_object3dtoCImg3d(primitives,colors,opacities,full_check);
    }

    //! Convert 3d object into a CImg3d representation \overloading.
    template<typename tp>
    CImg<floatT> get_object3dtoCImg3d(const CImgList<tp>& primitives,
                                      const bool full_check=true) const {
      CImgList<T> colors, opacities;
      return get_object3dtoCImg3d(primitives,colors,opacities,full_check);
    }

    //! Convert 3d object into a CImg3d representation \overloading.
    CImg<floatT> get_object3dtoCImg3d(const bool full_check=true) const {
      CImgList<T> opacities, colors;
      CImgList<uintT> primitives(width(),1,1,1,1);
      cimglist_for(primitives,p) primitives(p,0) = p;
      return get_object3dtoCImg3d(primitives,colors,opacities,full_check);
    }

    //! Convert CImg3d representation into a 3d object.
    /**
       \param[out] primitives Primitives data of the 3d object.
       \param[out] colors Colors data of the 3d object.
       \param[out] opacities Opacities data of the 3d object.
       \param full_check Tells if full checking of the 3d object must be performed.
    **/
    template<typename tp, typename tc, typename to>
    CImg<T>& CImg3dtoobject3d(CImgList<tp>& primitives,
                              CImgList<tc>& colors,
                              CImgList<to>& opacities,
                              const bool full_check=true) {
      return get_CImg3dtoobject3d(primitives,colors,opacities,full_check).move_to(*this);
    }

    //! Convert CImg3d representation into a 3d object \newinstance.
    template<typename tp, typename tc, typename to>
    CImg<T> get_CImg3dtoobject3d(CImgList<tp>& primitives,
                                 CImgList<tc>& colors,
                                 CImgList<to>& opacities,
                                 const bool full_check=true) const {
      char error_message[1024] = { 0 };
      if (!is_CImg3d(full_check,error_message))
        throw CImgInstanceException(_cimg_instance
                                    "CImg3dtoobject3d(): image instance is not a CImg3d (%s).",
                                    cimg_instance,error_message);
      const T *ptrs = _data + 6;
      const unsigned int
        nb_points = cimg::float2uint((float)*(ptrs++)),
        nb_primitives = cimg::float2uint((float)*(ptrs++));
      const CImg<T> points = CImg<T>(ptrs,3,nb_points,1,1,true).get_transpose();
      ptrs+=3*nb_points;
      primitives.assign(nb_primitives);
      cimglist_for(primitives,p) {
        const unsigned int nb_inds = (unsigned int)*(ptrs++);
        primitives[p].assign(1,nb_inds);
        tp *ptrp = primitives[p]._data;
        for (unsigned int i = 0; i<nb_inds; ++i) *(ptrp++) = (tp)cimg::float2uint((float)*(ptrs++));
      }
      colors.assign(nb_primitives);
      cimglist_for(colors,c) {
        if (*ptrs==(T)-128) {
          ++ptrs;
          const unsigned int w = (unsigned int)*(ptrs++), h = (unsigned int)*(ptrs++), s = (unsigned int)*(ptrs++);
          if (!h && !s) colors[c].assign(colors[w],true);
          else { colors[c].assign(ptrs,w,h,1,s,false); ptrs+=w*h*s; }
        } else { colors[c].assign(ptrs,1,1,1,3,false); ptrs+=3; }
      }
      opacities.assign(nb_primitives);
      cimglist_for(opacities,o) {
        if (*ptrs==(T)-128) {
          ++ptrs;
          const unsigned int w = (unsigned int)*(ptrs++), h = (unsigned int)*(ptrs++), s = (unsigned int)*(ptrs++);
          if (!h && !s) opacities[o].assign(opacities[w],true);
          else { opacities[o].assign(ptrs,w,h,1,s,false); ptrs+=w*h*s; }
        } else opacities[o].assign(1,1,1,1,*(ptrs++));
      }
      return points;
    }

    //@}
    //---------------------------
    //
    //! \name Drawing Functions
    //@{
    //---------------------------

#define cimg_init_scanline(color,opacity) \
    const float _sc_nopacity = cimg::abs((float)opacity), _sc_copacity = 1 - cimg::max((float)opacity,0); \
  const unsigned long _sc_whd = (unsigned long)_width*_height*_depth

#define cimg_draw_scanline(x0,x1,y,color,opacity,brightness) _draw_scanline(x0,x1,y,color,opacity,brightness,_sc_nopacity,_sc_copacity,_sc_whd)

    // [internal] The following _draw_scanline() routines are *non user-friendly functions*, used only for internal purpose.
    // Pre-requisites: x0<x1, y-coordinate is valid, col is valid.
    template<typename tc>
    CImg<T>& _draw_scanline(const int x0, const int x1, const int y,
                            const tc *const color, const float opacity,
                            const float brightness,
                            const float nopacity, const float copacity, const unsigned long whd) {
      static const T maxval = (T)cimg::min(cimg::type<T>::max(),cimg::type<tc>::max());
      const int nx0 = x0>0?x0:0, nx1 = x1<width()?x1:width()-1, dx = nx1 - nx0;
      if (dx>=0) {
        const tc *col = color;
        const unsigned long off = whd - dx - 1;
        T *ptrd = data(nx0,y);
        if (opacity>=1) { // ** Opaque drawing **
          if (brightness==1) { // Brightness==1
            if (sizeof(T)!=1) cimg_forC(*this,c) {
                const T val = (T)*(col++);
                for (int x = dx; x>=0; --x) *(ptrd++) = val;
                ptrd+=off;
              } else cimg_forC(*this,c) {
                const T val = (T)*(col++);
                std::memset(ptrd,(int)val,dx+1);
                ptrd+=whd;
              }
          } else if (brightness<1) { // Brightness<1
            if (sizeof(T)!=1) cimg_forC(*this,c) {
                const T val = (T)(*(col++)*brightness);
                for (int x = dx; x>=0; --x) *(ptrd++) = val;
                ptrd+=off;
              } else cimg_forC(*this,c) {
                const T val = (T)(*(col++)*brightness);
                std::memset(ptrd,(int)val,dx+1);
                ptrd+=whd;
              }
          } else { // Brightness>1
            if (sizeof(T)!=1) cimg_forC(*this,c) {
                const T val = (T)((2-brightness)**(col++) + (brightness-1)*maxval);
                for (int x = dx; x>=0; --x) *(ptrd++) = val;
                ptrd+=off;
              } else cimg_forC(*this,c) {
                const T val = (T)((2-brightness)**(col++) + (brightness-1)*maxval);
                std::memset(ptrd,(int)val,dx+1);
                ptrd+=whd;
              }
          }
        } else { // ** Transparent drawing **
          if (brightness==1) { // Brightness==1
            cimg_forC(*this,c) {
              const T val = (T)*(col++);
              for (int x = dx; x>=0; --x) { *ptrd = (T)(val*nopacity + *ptrd*copacity); ++ptrd; }
              ptrd+=off;
            }
          } else if (brightness<=1) { // Brightness<1
            cimg_forC(*this,c) {
              const T val = (T)(*(col++)*brightness);
              for (int x = dx; x>=0; --x) { *ptrd = (T)(val*nopacity + *ptrd*copacity); ++ptrd; }
              ptrd+=off;
            }
          } else { // Brightness>1
            cimg_forC(*this,c) {
              const T val = (T)((2-brightness)**(col++) + (brightness-1)*maxval);
              for (int x = dx; x>=0; --x) { *ptrd = (T)(val*nopacity + *ptrd*copacity); ++ptrd; }
              ptrd+=off;
            }
          }
        }
      }
      return *this;
    }

    //! Draw a 3d point.
    /**
       \param x0 X-coordinate of the point.
       \param y0 Y-coordinate of the point.
       \param z0 Z-coordinate of the point.
       \param color Pointer to \c spectrum() consecutive values, defining the drawing color.
       \param opacity Drawing opacity.
       \note
       - To set pixel values without clipping needs, you should use the faster CImg::operator()() function.
       \par Example:
       \code
       CImg<unsigned char> img(100,100,1,3,0);
       const unsigned char color[] = { 255,128,64 };
       img.draw_point(50,50,color);
       \endcode
    **/
    template<typename tc>
    CImg<T>& draw_point(const int x0, const int y0, const int z0,
                        const tc *const color, const float opacity=1) {
      if (is_empty()) return *this;
      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_point(): Specified color is (null).",
                                    cimg_instance);
      if (x0>=0 && y0>=0 && z0>=0 && x0<width() && y0<height() && z0<depth()) {
        const unsigned long whd = (unsigned long)_width*_height*_depth;
        const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
        T *ptrd = data(x0,y0,z0,0);
        const tc *col = color;
        if (opacity>=1) cimg_forC(*this,c) { *ptrd = (T)*(col++); ptrd+=whd; }
        else cimg_forC(*this,c) { *ptrd = (T)(*(col++)*nopacity + *ptrd*copacity); ptrd+=whd; }
      }
      return *this;
    }

    //! Draw a 2d point \simplification.
    template<typename tc>
    CImg<T>& draw_point(const int x0, const int y0,
                        const tc *const color, const float opacity=1) {
      return draw_point(x0,y0,0,color,opacity);
    }

    // Draw a points cloud.
    /**
       \param points Image of vertices coordinates.
       \param color Pointer to \c spectrum() consecutive values, defining the drawing color.
       \param opacity Drawing opacity.
    **/
    template<typename t, typename tc>
    CImg<T>& draw_point(const CImg<t>& points,
                        const tc *const color, const float opacity=1) {
      if (is_empty() || !points) return *this;
      switch (points._height) {
      case 0 : case 1 :
        throw CImgArgumentException(_cimg_instance
                                    "draw_point(): Invalid specified point set (%u,%u,%u,%u,%p).",
                                    cimg_instance,
                                    points._width,points._height,points._depth,points._spectrum,points._data);
      case 2 : {
        cimg_forX(points,i) draw_point((int)points(i,0),(int)points(i,1),color,opacity);
      } break;
      default : {
        cimg_forX(points,i) draw_point((int)points(i,0),(int)points(i,1),(int)points(i,2),color,opacity);
      }
      }
      return *this;
    }

    //! Draw a 2d line.
    /**
       \param x0 X-coordinate of the starting line point.
       \param y0 Y-coordinate of the starting line point.
       \param x1 X-coordinate of the ending line point.
       \param y1 Y-coordinate of the ending line point.
       \param color Pointer to \c spectrum() consecutive values of type \c T, defining the drawing color.
       \param opacity Drawing opacity.
       \param pattern An integer whose bits describe the line pattern.
       \param init_hatch Tells if a reinitialization of the hash state must be done.
       \note
       - Line routine uses Bresenham's algorithm.
       - Set \p init_hatch = false to draw consecutive hatched segments without breaking the line pattern.
       \par Example:
       \code
       CImg<unsigned char> img(100,100,1,3,0);
       const unsigned char color[] = { 255,128,64 };
        img.draw_line(40,40,80,70,color);
       \endcode
    **/
    template<typename tc>
    CImg<T>& draw_line(const int x0, const int y0,
                       const int x1, const int y1,
                       const tc *const color, const float opacity=1,
                       const unsigned int pattern=~0U, const bool init_hatch=true) {
      if (is_empty()) return *this;
      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_line(): Specified color is (null).",
                                    cimg_instance);
      static unsigned int hatch = ~0U - (~0U>>1);
      if (init_hatch) hatch = ~0U - (~0U>>1);
      const bool xdir = x0<x1, ydir = y0<y1;
      int
	nx0 = x0, nx1 = x1, ny0 = y0, ny1 = y1,
	&xleft = xdir?nx0:nx1, &yleft = xdir?ny0:ny1,
        &xright = xdir?nx1:nx0, &yright = xdir?ny1:ny0,
	&xup = ydir?nx0:nx1, &yup = ydir?ny0:ny1,
        &xdown = ydir?nx1:nx0, &ydown = ydir?ny1:ny0;
      if (xright<0 || xleft>=width()) return *this;
      if (xleft<0) { yleft-=(int)((float)xleft*((float)yright - yleft)/((float)xright - xleft)); xleft = 0; }
      if (xright>=width()) { yright-=(int)(((float)xright - width())*((float)yright - yleft)/((float)xright - xleft)); xright = width() - 1; }
      if (ydown<0 || yup>=height()) return *this;
      if (yup<0) { xup-=(int)((float)yup*((float)xdown - xup)/((float)ydown - yup)); yup = 0; }
      if (ydown>=height()) { xdown-=(int)(((float)ydown - height())*((float)xdown - xup)/((float)ydown - yup)); ydown = height() - 1; }
      T *ptrd0 = data(nx0,ny0);
      int dx = xright - xleft, dy = ydown - yup;
      const bool steep = dy>dx;
      if (steep) cimg::swap(nx0,ny0,nx1,ny1,dx,dy);
      const long
        offx = (nx0<nx1?1:-1)*(steep?width():1),
        offy = (ny0<ny1?1:-1)*(steep?1:width());
      const unsigned long wh = (unsigned long)_width*_height;
      if (opacity>=1) {
        if (~pattern) for (int error = dx>>1, x = 0; x<=dx; ++x) {
          if (pattern&hatch) {
            T *ptrd = ptrd0; const tc* col = color;
            cimg_forC(*this,c) { *ptrd = (T)*(col++); ptrd+=wh; }
          }
          hatch>>=1; if (!hatch) hatch = ~0U - (~0U>>1);
          ptrd0+=offx;
          if ((error-=dy)<0) { ptrd0+=offy; error+=dx; }
        } else for (int error = dx>>1, x = 0; x<=dx; ++x) {
          T *ptrd = ptrd0; const tc* col = color; cimg_forC(*this,c) { *ptrd = (T)*(col++); ptrd+=wh; }
          ptrd0+=offx;
          if ((error-=dy)<0) { ptrd0+=offy; error+=dx; }
        }
      } else {
        const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
        if (~pattern) for (int error = dx>>1, x = 0; x<=dx; ++x) {
          if (pattern&hatch) {
            T *ptrd = ptrd0; const tc* col = color;
            cimg_forC(*this,c) { *ptrd = (T)(nopacity**(col++) + *ptrd*copacity); ptrd+=wh; }
          }
          hatch>>=1; if (!hatch) hatch = ~0U - (~0U>>1);
          ptrd0+=offx;
          if ((error-=dy)<0) { ptrd0+=offy; error+=dx; }
        } else for (int error = dx>>1, x = 0; x<=dx; ++x) {
          T *ptrd = ptrd0; const tc* col = color; cimg_forC(*this,c) { *ptrd = (T)(nopacity**(col++) + *ptrd*copacity); ptrd+=wh; }
          ptrd0+=offx;
          if ((error-=dy)<0) { ptrd0+=offy; error+=dx; }
        }
      }
      return *this;
    }

    //! Draw a 2d line, with z-buffering.
    /**
       \param zbuffer Zbuffer image.
       \param x0 X-coordinate of the starting point.
       \param y0 Y-coordinate of the starting point.
       \param z0 Z-coordinate of the starting point
       \param x1 X-coordinate of the ending point.
       \param y1 Y-coordinate of the ending point.
       \param z1 Z-coordinate of the ending point.
       \param color Pointer to \c spectrum() consecutive values of type \c T, defining the drawing color.
       \param opacity Drawing opacity.
       \param pattern An integer whose bits describe the line pattern.
       \param init_hatch Tells if a reinitialization of the hash state must be done.
    **/
    template<typename tz,typename tc>
    CImg<T>& draw_line(CImg<tz>& zbuffer,
                       const int x0, const int y0, const float z0,
                       const int x1, const int y1, const float z1,
                       const tc *const color, const float opacity=1,
                       const unsigned int pattern=~0U, const bool init_hatch=true) {
      typedef typename cimg::superset<tz,float>::type tzfloat;
      if (is_empty() || z0<=0 || z1<=0) return *this;
      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_line(): Specified color is (null).",
                                    cimg_instance);
      if (!is_sameXY(zbuffer))
        throw CImgArgumentException(_cimg_instance
                                    "draw_line(): Instance and specified Z-buffer (%u,%u,%u,%u,%p) have different dimensions.",
                                    cimg_instance,
                                    zbuffer._width,zbuffer._height,zbuffer._depth,zbuffer._spectrum,zbuffer._data);
      static unsigned int hatch = ~0U - (~0U>>1);
      if (init_hatch) hatch = ~0U - (~0U>>1);
      const bool xdir = x0<x1, ydir = y0<y1;
      int
        nx0 = x0, nx1 = x1, ny0 = y0, ny1 = y1,
        &xleft = xdir?nx0:nx1, &yleft = xdir?ny0:ny1,
        &xright = xdir?nx1:nx0, &yright = xdir?ny1:ny0,
        &xup = ydir?nx0:nx1, &yup = ydir?ny0:ny1,
        &xdown = ydir?nx1:nx0, &ydown = ydir?ny1:ny0;
      tzfloat
        Z0 = 1/(tzfloat)z0, Z1 = 1/(tzfloat)z1, nz0 = Z0, nz1 = Z1, dz = Z1 - Z0,
        &zleft = xdir?nz0:nz1,
        &zright = xdir?nz1:nz0,
        &zup = ydir?nz0:nz1,
        &zdown = ydir?nz1:nz0;
      if (xright<0 || xleft>=width()) return *this;
      if (xleft<0) {
        const float D = (float)xright - xleft;
        yleft-=(int)((float)xleft*((float)yright - yleft)/D);
        zleft-=(tzfloat)xleft*(zright - zleft)/D;
        xleft = 0;
      }
      if (xright>=width()) {
        const float d = (float)xright - width(), D = (float)xright - xleft;
        yright-=(int)(d*((float)yright - yleft)/D);
        zright-=(tzfloat)d*(zright - zleft)/D;
        xright = width() - 1;
      }
      if (ydown<0 || yup>=height()) return *this;
      if (yup<0) {
        const float D = (float)ydown - yup;
        xup-=(int)((float)yup*((float)xdown - xup)/D);
        zup-=(tzfloat)yup*(zdown - zup)/D;
        yup = 0;
      }
      if (ydown>=height()) {
        const float d = (float)ydown - height(), D = (float)ydown - yup;
        xdown-=(int)(d*((float)xdown - xup)/D);
        zdown-=(tzfloat)d*(zdown - zup)/D;
        ydown = height() - 1;
      }
      T *ptrd0 = data(nx0,ny0);
      tz *ptrz = zbuffer.data(nx0,ny0);
      int dx = xright - xleft, dy = ydown - yup;
      const bool steep = dy>dx;
      if (steep) cimg::swap(nx0,ny0,nx1,ny1,dx,dy);
      const long
        offx = (nx0<nx1?1:-1)*(steep?width():1),
        offy = (ny0<ny1?1:-1)*(steep?1:width());
      const unsigned long wh = (unsigned long)_width*_height,
        ndx = dx>0?dx:1;
      if (opacity>=1) {
        if (~pattern) for (int error = dx>>1, x = 0; x<=dx; ++x) {
          const tzfloat z = Z0 + x*dz/ndx;
          if (z>=(tzfloat)*ptrz && pattern&hatch) {
            *ptrz = (tz)z;
            T *ptrd = ptrd0; const tc *col = color;
            cimg_forC(*this,c) { *ptrd = (T)*(col++); ptrd+=wh; }
          }
          hatch>>=1; if (!hatch) hatch = ~0U - (~0U>>1);
          ptrd0+=offx; ptrz+=offx;
          if ((error-=dy)<0) { ptrd0+=offy; ptrz+=offy; error+=dx; }
        } else for (int error = dx>>1, x = 0; x<=dx; ++x) {
          const tzfloat z = Z0 + x*dz/ndx;
          if (z>=(tzfloat)*ptrz) {
            *ptrz = (tz)z;
            T *ptrd = ptrd0; const tc *col = color;
            cimg_forC(*this,c) { *ptrd = (T)*(col++); ptrd+=wh; }
          }
          ptrd0+=offx; ptrz+=offx;
          if ((error-=dy)<0) { ptrd0+=offy; ptrz+=offy; error+=dx; }
        }
      } else {
        const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
        if (~pattern) for (int error = dx>>1, x = 0; x<=dx; ++x) {
          const tzfloat z = Z0 + x*dz/ndx;
          if (z>=(tzfloat)*ptrz && pattern&hatch) {
            *ptrz = (tz)z;
            T *ptrd = ptrd0; const tc *col = color;
            cimg_forC(*this,c) { *ptrd = (T)(nopacity**(col++) + *ptrd*copacity); ptrd+=wh; }
          }
          hatch>>=1; if (!hatch) hatch = ~0U - (~0U>>1);
          ptrd0+=offx; ptrz+=offx;
          if ((error-=dy)<0) { ptrd0+=offy; ptrz+=offy; error+=dx; }
        } else for (int error = dx>>1, x = 0; x<=dx; ++x) {
          const tzfloat z = Z0 + x*dz/ndx;
          if (z>=(tzfloat)*ptrz) {
            *ptrz = (tz)z;
            T *ptrd = ptrd0; const tc *col = color;
            cimg_forC(*this,c) { *ptrd = (T)(nopacity**(col++) + *ptrd*copacity); ptrd+=wh; }
          }
          ptrd0+=offx; ptrz+=offx;
          if ((error-=dy)<0) { ptrd0+=offy; ptrz+=offy; error+=dx; }
        }
      }
      return *this;
    }

    //! Draw a 3d line.
    /**
       \param x0 X-coordinate of the starting point.
       \param y0 Y-coordinate of the starting point.
       \param z0 Z-coordinate of the starting point
       \param x1 X-coordinate of the ending point.
       \param y1 Y-coordinate of the ending point.
       \param z1 Z-coordinate of the ending point.
       \param color Pointer to \c spectrum() consecutive values of type \c T, defining the drawing color.
       \param opacity Drawing opacity.
       \param pattern An integer whose bits describe the line pattern.
       \param init_hatch Tells if a reinitialization of the hash state must be done.
    **/
    template<typename tc>
    CImg<T>& draw_line(const int x0, const int y0, const int z0,
                       const int x1, const int y1, const int z1,
                       const tc *const color, const float opacity=1,
                       const unsigned int pattern=~0U, const bool init_hatch=true) {
      if (is_empty()) return *this;
      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_line(): Specified color is (null).",
                                    cimg_instance);
      static unsigned int hatch = ~0U - (~0U>>1);
      if (init_hatch) hatch = ~0U - (~0U>>1);
      int nx0 = x0, ny0 = y0, nz0 = z0, nx1 = x1, ny1 = y1, nz1 = z1;
      if (nx0>nx1) cimg::swap(nx0,nx1,ny0,ny1,nz0,nz1);
      if (nx1<0 || nx0>=width()) return *this;
      if (nx0<0) { const float D = 1.0f + nx1 - nx0; ny0-=(int)((float)nx0*(1.0f + ny1 - ny0)/D); nz0-=(int)((float)nx0*(1.0f + nz1 - nz0)/D); nx0 = 0; }
      if (nx1>=width()) { const float d = (float)nx1 - width(), D = 1.0f + nx1 - nx0; ny1+=(int)(d*(1.0f + ny0 - ny1)/D); nz1+=(int)(d*(1.0f + nz0 - nz1)/D); nx1 = width() - 1; }
      if (ny0>ny1) cimg::swap(nx0,nx1,ny0,ny1,nz0,nz1);
      if (ny1<0 || ny0>=height()) return *this;
      if (ny0<0) { const float D = 1.0f + ny1 - ny0; nx0-=(int)((float)ny0*(1.0f + nx1 - nx0)/D); nz0-=(int)((float)ny0*(1.0f + nz1 - nz0)/D); ny0 = 0; }
      if (ny1>=height()) { const float d = (float)ny1 - height(), D = 1.0f + ny1 - ny0; nx1+=(int)(d*(1.0f + nx0 - nx1)/D); nz1+=(int)(d*(1.0f + nz0 - nz1)/D); ny1 = height() - 1; }
      if (nz0>nz1) cimg::swap(nx0,nx1,ny0,ny1,nz0,nz1);
      if (nz1<0 || nz0>=depth()) return *this;
      if (nz0<0) { const float D = 1.0f + nz1 - nz0; nx0-=(int)((float)nz0*(1.0f + nx1 - nx0)/D); ny0-=(int)((float)nz0*(1.0f + ny1 - ny0)/D); nz0 = 0; }
      if (nz1>=depth()) { const float d = (float)nz1 - depth(), D = 1.0f + nz1 - nz0; nx1+=(int)(d*(1.0f + nx0 - nx1)/D); ny1+=(int)(d*(1.0f + ny0 - ny1)/D); nz1 = depth() - 1; }
      const unsigned int dmax = cimg::max(cimg::abs(nx1 - nx0),cimg::abs(ny1 - ny0),nz1 - nz0);
      const unsigned long whd = (unsigned long)_width*_height*_depth;
      const float px = (nx1 - nx0)/(float)dmax, py = (ny1 - ny0)/(float)dmax, pz = (nz1 - nz0)/(float)dmax;
      float x = (float)nx0, y = (float)ny0, z = (float)nz0;
      if (opacity>=1) for (unsigned int t = 0; t<=dmax; ++t) {
        if (!(~pattern) || (~pattern && pattern&hatch)) {
          T* ptrd = data((unsigned int)x,(unsigned int)y,(unsigned int)z);
          const tc *col = color; cimg_forC(*this,c) { *ptrd = (T)*(col++); ptrd+=whd; }
        }
        x+=px; y+=py; z+=pz; if (pattern) { hatch>>=1; if (!hatch) hatch = ~0U - (~0U>>1); }
      } else {
        const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
        for (unsigned int t = 0; t<=dmax; ++t) {
          if (!(~pattern) || (~pattern && pattern&hatch)) {
            T* ptrd = data((unsigned int)x,(unsigned int)y,(unsigned int)z);
            const tc *col = color; cimg_forC(*this,c) { *ptrd = (T)(*(col++)*nopacity + *ptrd*copacity); ptrd+=whd; }
          }
          x+=px; y+=py; z+=pz; if (pattern) { hatch>>=1; if (!hatch) hatch = ~0U - (~0U>>1); }
        }
      }
      return *this;
    }

    //! Draw a textured 2d line.
    /**
       \param x0 X-coordinate of the starting line point.
       \param y0 Y-coordinate of the starting line point.
       \param x1 X-coordinate of the ending line point.
       \param y1 Y-coordinate of the ending line point.
       \param texture Texture image defining the pixel colors.
       \param tx0 X-coordinate of the starting texture point.
       \param ty0 Y-coordinate of the starting texture point.
       \param tx1 X-coordinate of the ending texture point.
       \param ty1 Y-coordinate of the ending texture point.
       \param opacity Drawing opacity.
       \param pattern An integer whose bits describe the line pattern.
       \param init_hatch Tells if the hash variable must be reinitialized.
       \note
       - Line routine uses the well known Bresenham's algorithm.
       \par Example:
       \code
       CImg<unsigned char> img(100,100,1,3,0), texture("texture256x256.ppm");
       const unsigned char color[] = { 255,128,64 };
       img.draw_line(40,40,80,70,texture,0,0,255,255);
       \endcode
    **/
    template<typename tc>
    CImg<T>& draw_line(const int x0, const int y0,
                       const int x1, const int y1,
                       const CImg<tc>& texture,
                       const int tx0, const int ty0,
                       const int tx1, const int ty1,
                       const float opacity=1,
                       const unsigned int pattern=~0U, const bool init_hatch=true) {
      if (is_empty()) return *this;
      if (texture._depth>1 || texture._spectrum<_spectrum)
        throw CImgArgumentException(_cimg_instance
                                    "draw_line(): Invalid specified texture (%u,%u,%u,%u,%p).",
                                    cimg_instance,
                                    texture._width,texture._height,texture._depth,texture._spectrum,texture._data);
      if (is_overlapped(texture)) return draw_line(x0,y0,x1,y1,+texture,tx0,ty0,tx1,ty1,opacity,pattern,init_hatch);
      static unsigned int hatch = ~0U - (~0U>>1);
      if (init_hatch) hatch = ~0U - (~0U>>1);
      const bool xdir = x0<x1, ydir = y0<y1;
      int
        dtx = tx1-tx0, dty = ty1-ty0,
        nx0 = x0, nx1 = x1, ny0 = y0, ny1 = y1,
        tnx0 = tx0, tnx1 = tx1, tny0 = ty0, tny1 = ty1,
        &xleft = xdir?nx0:nx1, &yleft = xdir?ny0:ny1, &xright = xdir?nx1:nx0, &yright = xdir?ny1:ny0,
        &txleft = xdir?tnx0:tnx1, &tyleft = xdir?tny0:tny1, &txright = xdir?tnx1:tnx0, &tyright = xdir?tny1:tny0,
        &xup = ydir?nx0:nx1, &yup = ydir?ny0:ny1, &xdown = ydir?nx1:nx0, &ydown = ydir?ny1:ny0,
        &txup = ydir?tnx0:tnx1, &tyup = ydir?tny0:tny1, &txdown = ydir?tnx1:tnx0, &tydown = ydir?tny1:tny0;
      if (xright<0 || xleft>=width()) return *this;
      if (xleft<0) {
        const float D = (float)xright - xleft;
        yleft-=(int)((float)xleft*((float)yright - yleft)/D);
        txleft-=(int)((float)xleft*((float)txright - txleft)/D);
        tyleft-=(int)((float)xleft*((float)tyright - tyleft)/D);
        xleft = 0;
      }
      if (xright>=width()) {
        const float d = (float)xright - width(), D = (float)xright - xleft;
        yright-=(int)(d*((float)yright - yleft)/D);
        txright-=(int)(d*((float)txright - txleft)/D);
        tyright-=(int)(d*((float)tyright - tyleft)/D);
        xright = width() - 1;
      }
      if (ydown<0 || yup>=height()) return *this;
      if (yup<0) {
        const float D = (float)ydown - yup;
        xup-=(int)((float)yup*((float)xdown - xup)/D);
        txup-=(int)((float)yup*((float)txdown - txup)/D);
        tyup-=(int)((float)yup*((float)tydown - tyup)/D);
        yup = 0;
      }
      if (ydown>=height()) {
        const float d = (float)ydown - height(), D = (float)ydown - yup;
        xdown-=(int)(d*((float)xdown - xup)/D);
        txdown-=(int)(d*((float)txdown - txup)/D);
        tydown-=(int)(d*((float)tydown - tyup)/D);
        ydown = height() - 1;
      }
      T *ptrd0 = data(nx0,ny0);
      int dx = xright - xleft, dy = ydown - yup;
      const bool steep = dy>dx;
      if (steep) cimg::swap(nx0,ny0,nx1,ny1,dx,dy);
      const long
        offx = (nx0<nx1?1:-1)*(steep?width():1),
        offy = (ny0<ny1?1:-1)*(steep?1:width()),
        ndx = dx>0?dx:1;
      const unsigned long wh = (unsigned long)_width*_height;

      if (opacity>=1) {
        if (~pattern) for (int error = dx>>1, x = 0; x<=dx; ++x) {
          if (pattern&hatch) {
            T *ptrd = ptrd0;
            const int tx = tx0 + x*dtx/ndx, ty = ty0 + x*dty/ndx;
            cimg_forC(*this,c) { *ptrd = (T)texture(tx,ty,0,c); ptrd+=wh; }
          }
          hatch>>=1; if (!hatch) hatch = ~0U - (~0U>>1);
          ptrd0+=offx;
          if ((error-=dy)<0) { ptrd0+=offy; error+=dx; }
        } else for (int error = dx>>1, x = 0; x<=dx; ++x) {
          T *ptrd = ptrd0;
          const int tx = tx0 + x*dtx/ndx, ty = ty0 + x*dty/ndx;
          cimg_forC(*this,c) { *ptrd = (T)texture(tx,ty,0,c); ptrd+=wh; }
          ptrd0+=offx;
          if ((error-=dy)<0) { ptrd0+=offy; error+=dx; }
        }
      } else {
        const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
        if (~pattern) for (int error = dx>>1, x = 0; x<=dx; ++x) {
          T *ptrd = ptrd0;
          if (pattern&hatch) {
            const int tx = tx0 + x*dtx/ndx, ty = ty0 + x*dty/ndx;
            cimg_forC(*this,c) { *ptrd = (T)(nopacity*texture(tx,ty,0,c) + *ptrd*copacity); ptrd+=wh; }
          }
          hatch>>=1; if (!hatch) hatch = ~0U - (~0U>>1);
          ptrd0+=offx;
          if ((error-=dy)<0) { ptrd0+=offy; error+=dx; }
        } else for (int error = dx>>1, x = 0; x<=dx; ++x) {
          T *ptrd = ptrd0;
          const int tx = tx0 + x*dtx/ndx, ty = ty0 + x*dty/ndx;
          cimg_forC(*this,c) { *ptrd = (T)(nopacity*texture(tx,ty,0,c) + *ptrd*copacity); ptrd+=wh; }
          ptrd0+=offx;
          if ((error-=dy)<0) { ptrd0+=offy; error+=dx; }
        }
      }
      return *this;
    }

    //! Draw a textured 2d line, with perspective correction.
    /**
       \param x0 X-coordinate of the starting point.
       \param y0 Y-coordinate of the starting point.
       \param z0 Z-coordinate of the starting point
       \param x1 X-coordinate of the ending point.
       \param y1 Y-coordinate of the ending point.
       \param z1 Z-coordinate of the ending point.
       \param texture Texture image defining the pixel colors.
       \param tx0 X-coordinate of the starting texture point.
       \param ty0 Y-coordinate of the starting texture point.
       \param tx1 X-coordinate of the ending texture point.
       \param ty1 Y-coordinate of the ending texture point.
       \param opacity Drawing opacity.
       \param pattern An integer whose bits describe the line pattern.
       \param init_hatch Tells if the hash variable must be reinitialized.
    **/
    template<typename tc>
    CImg<T>& draw_line(const int x0, const int y0, const float z0,
                       const int x1, const int y1, const float z1,
                       const CImg<tc>& texture,
                       const int tx0, const int ty0,
                       const int tx1, const int ty1,
                       const float opacity=1,
                       const unsigned int pattern=~0U, const bool init_hatch=true) {
      if (is_empty() && z0<=0 && z1<=0) return *this;
      if (texture._depth>1 || texture._spectrum<_spectrum)
        throw CImgArgumentException(_cimg_instance
                                    "draw_line(): Invalid specified texture (%u,%u,%u,%u,%p).",
                                    cimg_instance,
                                    texture._width,texture._height,texture._depth,texture._spectrum,texture._data);
      if (is_overlapped(texture)) return draw_line(x0,y0,z0,x1,y1,z1,+texture,tx0,ty0,tx1,ty1,opacity,pattern,init_hatch);
      static unsigned int hatch = ~0U - (~0U>>1);
      if (init_hatch) hatch = ~0U - (~0U>>1);
      const bool xdir = x0<x1, ydir = y0<y1;
      int
        nx0 = x0, nx1 = x1, ny0 = y0, ny1 = y1,
        &xleft = xdir?nx0:nx1, &yleft = xdir?ny0:ny1,
        &xright = xdir?nx1:nx0, &yright = xdir?ny1:ny0,
        &xup = ydir?nx0:nx1, &yup = ydir?ny0:ny1,
        &xdown = ydir?nx1:nx0, &ydown = ydir?ny1:ny0;
      float
        Tx0 = tx0/z0, Tx1 = tx1/z1,
        Ty0 = ty0/z0, Ty1 = ty1/z1,
        Z0 = 1/z0, Z1 = 1/z1,
        dz = Z1 - Z0, dtx = Tx1 - Tx0, dty = Ty1 - Ty0,
        tnx0 = Tx0, tnx1 = Tx1, tny0 = Ty0, tny1 = Ty1, nz0 = Z0, nz1 = Z1,
        &zleft = xdir?nz0:nz1, &txleft = xdir?tnx0:tnx1, &tyleft = xdir?tny0:tny1,
        &zright = xdir?nz1:nz0, &txright = xdir?tnx1:tnx0, &tyright = xdir?tny1:tny0,
        &zup = ydir?nz0:nz1, &txup = ydir?tnx0:tnx1, &tyup = ydir?tny0:tny1,
        &zdown = ydir?nz1:nz0, &txdown = ydir?tnx1:tnx0, &tydown = ydir?tny1:tny0;
      if (xright<0 || xleft>=width()) return *this;
      if (xleft<0) {
        const float D = (float)xright - xleft;
        yleft-=(int)((float)xleft*((float)yright - yleft)/D);
        zleft-=(float)xleft*(zright - zleft)/D;
        txleft-=(float)xleft*(txright - txleft)/D;
        tyleft-=(float)xleft*(tyright - tyleft)/D;
        xleft = 0;
      }
      if (xright>=width()) {
        const float d = (float)xright - width(), D = (float)xright - xleft;
        yright-=(int)(d*((float)yright - yleft)/D);
        zright-=d*(zright - zleft)/D;
        txright-=d*(txright - txleft)/D;
        tyright-=d*(tyright - tyleft)/D;
        xright = width() - 1;
      }
      if (ydown<0 || yup>=height()) return *this;
      if (yup<0) {
        const float D = (float)ydown - yup;
        xup-=(int)((float)yup*((float)xdown - xup)/D);
        zup-=(float)yup*(zdown - zup)/D;
        txup-=(float)yup*(txdown - txup)/D;
        tyup-=(float)yup*(tydown - tyup)/D;
        yup = 0;
      }
      if (ydown>=height()) {
        const float d = (float)ydown - height(), D = (float)ydown - yup;
        xdown-=(int)(d*((float)xdown - xup)/D);
        zdown-=d*(zdown - zup)/D;
        txdown-=d*(txdown - txup)/D;
        tydown-=d*(tydown - tyup)/D;
        ydown = height() - 1;
      }
      T *ptrd0 = data(nx0,ny0);
      int dx = xright - xleft, dy = ydown - yup;
      const bool steep = dy>dx;
      if (steep) cimg::swap(nx0,ny0,nx1,ny1,dx,dy);
      const long
        offx = (nx0<nx1?1:-1)*(steep?width():1),
        offy = (ny0<ny1?1:-1)*(steep?1:width()),
        ndx = dx>0?dx:1;
      const unsigned long wh = (unsigned long)_width*_height;

      if (opacity>=1) {
        if (~pattern) for (int error = dx>>1, x = 0; x<=dx; ++x) {
          if (pattern&hatch) {
            const float z = Z0 + x*dz/ndx, tx = Tx0 + x*dtx/ndx, ty = Ty0 + x*dty/ndx;
            T *ptrd = ptrd0; cimg_forC(*this,c) { *ptrd = (T)texture((int)(tx/z),(int)(ty/z),0,c); ptrd+=wh; }
          }
          hatch>>=1; if (!hatch) hatch = ~0U - (~0U>>1);
          ptrd0+=offx;
          if ((error-=dy)<0) { ptrd0+=offy; error+=dx; }
        } else for (int error = dx>>1, x = 0; x<=dx; ++x) {
          const float z = Z0 + x*dz/ndx, tx = Tx0 + x*dtx/ndx, ty = Ty0 + x*dty/ndx;
          T *ptrd = ptrd0; cimg_forC(*this,c) { *ptrd = (T)texture((int)(tx/z),(int)(ty/z),0,c); ptrd+=wh; }
          ptrd0+=offx;
          if ((error-=dy)<0) { ptrd0+=offy; error+=dx; }
        }
      } else {
        const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
        if (~pattern) for (int error = dx>>1, x = 0; x<=dx; ++x) {
          if (pattern&hatch) {
            const float z = Z0 + x*dz/ndx, tx = Tx0 + x*dtx/ndx, ty = Ty0 + x*dty/ndx;
            T *ptrd = ptrd0; cimg_forC(*this,c) { *ptrd = (T)(nopacity*texture((int)(tx/z),(int)(ty/z),0,c) + *ptrd*copacity); ptrd+=wh; }
          }
          hatch>>=1; if (!hatch) hatch = ~0U - (~0U>>1);
          ptrd0+=offx;
          if ((error-=dy)<0) { ptrd0+=offy; error+=dx; }
        } else for (int error = dx>>1, x = 0; x<=dx; ++x) {
          const float z = Z0 + x*dz/ndx, tx = Tx0 + x*dtx/ndx, ty = Ty0 + x*dty/ndx;
          T *ptrd = ptrd0;
          cimg_forC(*this,c) { *ptrd = (T)(nopacity*texture((int)(tx/z),(int)(ty/z),0,c) + *ptrd*copacity); ptrd+=wh; }
          ptrd0+=offx;
          if ((error-=dy)<0) { ptrd0+=offy; error+=dx; }
        }
      }
      return *this;
    }

    //! Draw a textured 2d line, with perspective correction and z-buffering.
    /**
       \param zbuffer Z-buffer image.
       \param x0 X-coordinate of the starting point.
       \param y0 Y-coordinate of the starting point.
       \param z0 Z-coordinate of the starting point
       \param x1 X-coordinate of the ending point.
       \param y1 Y-coordinate of the ending point.
       \param z1 Z-coordinate of the ending point.
       \param texture Texture image defining the pixel colors.
       \param tx0 X-coordinate of the starting texture point.
       \param ty0 Y-coordinate of the starting texture point.
       \param tx1 X-coordinate of the ending texture point.
       \param ty1 Y-coordinate of the ending texture point.
       \param opacity Drawing opacity.
       \param pattern An integer whose bits describe the line pattern.
       \param init_hatch Tells if the hash variable must be reinitialized.
    **/
    template<typename tz, typename tc>
    CImg<T>& draw_line(CImg<tz>& zbuffer,
                       const int x0, const int y0, const float z0,
                       const int x1, const int y1, const float z1,
                       const CImg<tc>& texture,
                       const int tx0, const int ty0,
                       const int tx1, const int ty1,
                       const float opacity=1,
                       const unsigned int pattern=~0U, const bool init_hatch=true) {
      typedef typename cimg::superset<tz,float>::type tzfloat;
      if (is_empty() || z0<=0 || z1<=0) return *this;
      if (!is_sameXY(zbuffer))
        throw CImgArgumentException(_cimg_instance
                                    "draw_line(): Instance and specified Z-buffer (%u,%u,%u,%u,%p) have different dimensions.",
                                    cimg_instance,
                                    zbuffer._width,zbuffer._height,zbuffer._depth,zbuffer._spectrum,zbuffer._data);
      if (texture._depth>1 || texture._spectrum<_spectrum)
        throw CImgArgumentException(_cimg_instance
                                    "draw_line(): Invalid specified texture (%u,%u,%u,%u,%p).",
                                    cimg_instance,
                                    texture._width,texture._height,texture._depth,texture._spectrum,texture._data);
      if (is_overlapped(texture)) return draw_line(zbuffer,x0,y0,z0,x1,y1,z1,+texture,tx0,ty0,tx1,ty1,opacity,pattern,init_hatch);
      static unsigned int hatch = ~0U - (~0U>>1);
      if (init_hatch) hatch = ~0U - (~0U>>1);
      const bool xdir = x0<x1, ydir = y0<y1;
      int
        nx0 = x0, nx1 = x1, ny0 = y0, ny1 = y1,
        &xleft = xdir?nx0:nx1, &yleft = xdir?ny0:ny1,
        &xright = xdir?nx1:nx0, &yright = xdir?ny1:ny0,
        &xup = ydir?nx0:nx1, &yup = ydir?ny0:ny1,
        &xdown = ydir?nx1:nx0, &ydown = ydir?ny1:ny0;
      float
        Tx0 = tx0/z0, Tx1 = tx1/z1,
        Ty0 = ty0/z0, Ty1 = ty1/z1,
        dtx = Tx1 - Tx0, dty = Ty1 - Ty0,
        tnx0 = Tx0, tnx1 = Tx1, tny0 = Ty0, tny1 = Ty1,
        &txleft = xdir?tnx0:tnx1, &tyleft = xdir?tny0:tny1,
        &txright = xdir?tnx1:tnx0, &tyright = xdir?tny1:tny0,
        &txup = ydir?tnx0:tnx1, &tyup = ydir?tny0:tny1,
        &txdown = ydir?tnx1:tnx0, &tydown = ydir?tny1:tny0;
      tzfloat
        Z0 = 1/(tzfloat)z0, Z1 = 1/(tzfloat)z1,
        dz = Z1 - Z0,  nz0 = Z0, nz1 = Z1,
        &zleft = xdir?nz0:nz1,
        &zright = xdir?nz1:nz0,
        &zup = ydir?nz0:nz1,
        &zdown = ydir?nz1:nz0;
      if (xright<0 || xleft>=width()) return *this;
      if (xleft<0) {
        const float D = (float)xright - xleft;
        yleft-=(int)((float)xleft*((float)yright - yleft)/D);
        zleft-=(float)xleft*(zright - zleft)/D;
        txleft-=(float)xleft*(txright - txleft)/D;
        tyleft-=(float)xleft*(tyright - tyleft)/D;
        xleft = 0;
      }
      if (xright>=width()) {
        const float d = (float)xright - width(), D = (float)xright - xleft;
        yright-=(int)(d*((float)yright - yleft)/D);
        zright-=d*(zright - zleft)/D;
        txright-=d*(txright - txleft)/D;
        tyright-=d*(tyright - tyleft)/D;
        xright = width()-1;
      }
      if (ydown<0 || yup>=height()) return *this;
      if (yup<0) {
        const float D = (float)ydown - yup;
        xup-=(int)((float)yup*((float)xdown - xup)/D);
        zup-=yup*(zdown - zup)/D;
        txup-=yup*(txdown - txup)/D;
        tyup-=yup*(tydown - tyup)/D;
        yup = 0;
      }
      if (ydown>=height()) {
        const float d = (float)ydown - height(), D = (float)ydown - yup;
        xdown-=(int)(d*((float)xdown - xup)/D);
        zdown-=d*(zdown - zup)/D;
        txdown-=d*(txdown - txup)/D;
        tydown-=d*(tydown - tyup)/D;
        ydown = height()-1;
      }
      T *ptrd0 = data(nx0,ny0);
      tz *ptrz = zbuffer.data(nx0,ny0);
      int dx = xright - xleft, dy = ydown - yup;
      const bool steep = dy>dx;
      if (steep) cimg::swap(nx0,ny0,nx1,ny1,dx,dy);
      const long
        offx = (nx0<nx1?1:-1)*(steep?width():1),
        offy = (ny0<ny1?1:-1)*(steep?1:width()),
        ndx = dx>0?dx:1;
      const unsigned long wh = (unsigned long)_width*_height;

      if (opacity>=1) {
        if (~pattern) for (int error = dx>>1, x = 0; x<=dx; ++x) {
          if (pattern&hatch) {
            const tzfloat z = Z0 + x*dz/ndx;
            if (z>=(tzfloat)*ptrz) {
              *ptrz = (tz)z;
              const float tx = Tx0 + x*dtx/ndx, ty = Ty0 + x*dty/ndx;
              T *ptrd = ptrd0; cimg_forC(*this,c) { *ptrd = (T)texture((int)(tx/z),(int)(ty/z),0,c); ptrd+=wh; }
            }
          }
          hatch>>=1; if (!hatch) hatch = ~0U - (~0U>>1);
          ptrd0+=offx; ptrz+=offx;
          if ((error-=dy)<0) { ptrd0+=offy; ptrz+=offy; error+=dx; }
        } else for (int error = dx>>1, x = 0; x<=dx; ++x) {
          const tzfloat z = Z0 + x*dz/ndx;
          if (z>=(tzfloat)*ptrz) {
            *ptrz = (tz)z;
            const float tx = Tx0 + x*dtx/ndx, ty = Ty0 + x*dty/ndx;
            T *ptrd = ptrd0; cimg_forC(*this,c) { *ptrd = (T)texture((int)(tx/z),(int)(ty/z),0,c); ptrd+=wh; }
          }
          ptrd0+=offx; ptrz+=offx;
          if ((error-=dy)<0) { ptrd0+=offy; ptrz+=offy; error+=dx; }
        }
      } else {
        const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
        if (~pattern) for (int error = dx>>1, x = 0; x<=dx; ++x) {
          if (pattern&hatch) {
            const tzfloat z = Z0 + x*dz/ndx;
            if (z>=(tzfloat)*ptrz) {
              *ptrz = (tz)z;
              const float tx = Tx0 + x*dtx/ndx, ty = Ty0 + x*dty/ndx;
              T *ptrd = ptrd0; cimg_forC(*this,c) { *ptrd = (T)(nopacity*texture((int)(tx/z),(int)(ty/z),0,c) + *ptrd*copacity); ptrd+=wh; }
            }
          }
          hatch>>=1; if (!hatch) hatch = ~0U - (~0U>>1);
          ptrd0+=offx; ptrz+=offx;
          if ((error-=dy)<0) { ptrd0+=offy; ptrz+=offy; error+=dx; }
        } else for (int error = dx>>1, x = 0; x<=dx; ++x) {
          const tzfloat z = Z0 + x*dz/ndx;
          if (z>=(tzfloat)*ptrz) {
            *ptrz = (tz)z;
            const float tx = Tx0 + x*dtx/ndx, ty = Ty0 + x*dty/ndx;
            T *ptrd = ptrd0; cimg_forC(*this,c) { *ptrd = (T)(nopacity*texture((int)(tx/z),(int)(ty/z),0,c) + *ptrd*copacity); ptrd+=wh; }
          }
          ptrd0+=offx; ptrz+=offx;
          if ((error-=dy)<0) { ptrd0+=offy; ptrz+=offy; error+=dx; }
        }
      }
      return *this;
    }

    //! Draw a set of consecutive lines.
    /**
       \param points Coordinates of vertices, stored as a list of vectors.
       \param color Pointer to \c spectrum() consecutive values of type \c T, defining the drawing color.
       \param opacity Drawing opacity.
       \param pattern An integer whose bits describe the line pattern.
       \param init_hatch If set to true, init hatch motif.
       \note
       - This function uses several call to the single CImg::draw_line() procedure,
       depending on the vectors size in \p points.
    **/
    template<typename t, typename tc>
    CImg<T>& draw_line(const CImg<t>& points,
                       const tc *const color, const float opacity=1,
                       const unsigned int pattern=~0U, const bool init_hatch=true) {
      if (is_empty() || !points || points._width<2) return *this;
      bool ninit_hatch = init_hatch;
      switch (points._height) {
      case 0 : case 1 :
        throw CImgArgumentException(_cimg_instance
                                    "draw_line(): Invalid specified point set (%u,%u,%u,%u,%p).",
                                    cimg_instance,
                                    points._width,points._height,points._depth,points._spectrum,points._data);

      case 2 : {
        const int x0 = (int)points(0,0), y0 = (int)points(0,1);
        int ox = x0, oy = y0;
        for (unsigned int i = 1; i<points._width; ++i) {
          const int x = (int)points(i,0), y = (int)points(i,1);
          draw_line(ox,oy,x,y,color,opacity,pattern,ninit_hatch);
          ninit_hatch = false;
          ox = x; oy = y;
        }
      } break;
      default : {
        const int x0 = (int)points(0,0), y0 = (int)points(0,1), z0 = (int)points(0,2);
        int ox = x0, oy = y0, oz = z0;
        for (unsigned int i = 1; i<points._width; ++i) {
          const int x = (int)points(i,0), y = (int)points(i,1), z = (int)points(i,2);
          draw_line(ox,oy,oz,x,y,z,color,opacity,pattern,ninit_hatch);
          ninit_hatch = false;
          ox = x; oy = y; oz = z;
        }
      }
      }
      return *this;
    }

    //! Draw a 2d arrow.
    /**
       \param x0 X-coordinate of the starting arrow point (tail).
       \param y0 Y-coordinate of the starting arrow point (tail).
       \param x1 X-coordinate of the ending arrow point (head).
       \param y1 Y-coordinate of the ending arrow point (head).
       \param color Pointer to \c spectrum() consecutive values of type \c T, defining the drawing color.
       \param angle Aperture angle of the arrow head.
       \param length Length of the arrow head. If negative, describes a percentage of the arrow length.
       \param opacity Drawing opacity.
       \param pattern An integer whose bits describe the line pattern.
    **/
    template<typename tc>
    CImg<T>& draw_arrow(const int x0, const int y0,
                        const int x1, const int y1,
                        const tc *const color, const float opacity=1,
                        const float angle=30, const float length=-10,
                        const unsigned int pattern=~0U) {
      if (is_empty()) return *this;
      const float u = (float)(x0 - x1), v = (float)(y0 - y1), sq = u*u + v*v,
        deg = (float)(angle*cimg::PI/180), ang = (sq>0)?(float)std::atan2(v,u):0.0f,
        l = (length>=0)?length:-length*(float)std::sqrt(sq)/100;
      if (sq>0) {
        const float
            cl = (float)std::cos(ang - deg), sl = (float)std::sin(ang - deg),
            cr = (float)std::cos(ang + deg), sr = (float)std::sin(ang + deg);
        const int
          xl = x1 + (int)(l*cl), yl = y1 + (int)(l*sl),
          xr = x1 + (int)(l*cr), yr = y1 + (int)(l*sr),
          xc = x1 + (int)((l+1)*(cl+cr))/2, yc = y1 + (int)((l+1)*(sl+sr))/2;
        draw_line(x0,y0,xc,yc,color,opacity,pattern).draw_triangle(x1,y1,xl,yl,xr,yr,color,opacity);
      } else draw_point(x0,y0,color,opacity);
      return *this;
    }

    //! Draw a 2d spline.
    /**
       \param x0 X-coordinate of the starting curve point
       \param y0 Y-coordinate of the starting curve point
       \param u0 X-coordinate of the starting velocity
       \param v0 Y-coordinate of the starting velocity
       \param x1 X-coordinate of the ending curve point
       \param y1 Y-coordinate of the ending curve point
       \param u1 X-coordinate of the ending velocity
       \param v1 Y-coordinate of the ending velocity
       \param color Pointer to \c spectrum() consecutive values of type \c T, defining the drawing color.
       \param precision Curve drawing precision.
       \param opacity Drawing opacity.
       \param pattern An integer whose bits describe the line pattern.
       \param init_hatch If \c true, init hatch motif.
       \note
       - The curve is a 2d cubic Bezier spline, from the set of specified starting/ending points
       and corresponding velocity vectors.
       - The spline is drawn as a serie of connected segments. The \p precision parameter sets the
       average number of pixels in each drawn segment.
       - A cubic Bezier curve is sometimes defined by a set of 4 points { (\p x0,\p y0), (\p xa,\p ya), (\p xb,\p yb), (\p x1,\p y1) }
       where (\p x0,\p y0) is the starting point, (\p x1,\p y1) is the ending point and (\p xa,\p ya), (\p xb,\p yb) are two
       \e control points.
       The starting and ending velocities (\p u0,\p v0) and (\p u1,\p v1) can be deduced easily from the control points as
       \p u0 = (\p xa - \p x0), \p v0 = (\p ya - \p y0), \p u1 = (\p x1 - \p xb) and \p v1 = (\p y1 - \p yb).
       \par Example:
       \code
       CImg<unsigned char> img(100,100,1,3,0);
       const unsigned char color[] = { 255,255,255 };
       img.draw_spline(30,30,0,100,90,40,0,-100,color);
       \endcode
    **/
    template<typename tc>
    CImg<T>& draw_spline(const int x0, const int y0, const float u0, const float v0,
                         const int x1, const int y1, const float u1, const float v1,
                         const tc *const color, const float opacity=1,
                         const float precision=0.25, const unsigned int pattern=~0U,
                         const bool init_hatch=true) {
      if (is_empty()) return *this;
      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_spline(): Specified color is (null).",
                                    cimg_instance);
      if (x0==x1 && y0==y1) return draw_point(x0,y0,color,opacity);
      bool ninit_hatch = init_hatch;
      const float
        ax = u0 + u1 + 2*(x0 - x1),
        bx = 3*(x1 - x0) - 2*u0 - u1,
        ay = v0 + v1 + 2*(y0 - y1),
        by = 3*(y1 - y0) - 2*v0 - v1,
        _precision = 1/(std::sqrt(cimg::sqr((float)x0-x1)+cimg::sqr((float)y0-y1))*(precision>0?precision:1));
      int ox = x0, oy = y0;
      for (float t = 0; t<1; t+=_precision) {
        const float t2 = t*t, t3 = t2*t;
        const int
          nx = (int)(ax*t3 + bx*t2 + u0*t + x0),
          ny = (int)(ay*t3 + by*t2 + v0*t + y0);
        draw_line(ox,oy,nx,ny,color,opacity,pattern,ninit_hatch);
        ninit_hatch = false;
        ox = nx; oy = ny;
      }
      return draw_line(ox,oy,x1,y1,color,opacity,pattern,false);
    }

    //! Draw a 3d spline \overloading.
    /**
       \note
       - Similar to CImg::draw_spline() for a 3d spline in a volumetric image.
    **/
    template<typename tc>
    CImg<T>& draw_spline(const int x0, const int y0, const int z0, const float u0, const float v0, const float w0,
                         const int x1, const int y1, const int z1, const float u1, const float v1, const float w1,
                         const tc *const color, const float opacity=1,
                         const float precision=4, const unsigned int pattern=~0U,
                         const bool init_hatch=true) {
      if (is_empty()) return *this;
      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_spline(): Specified color is (null).",
                                    cimg_instance);
      if (x0==x1 && y0==y1 && z0==z1) return draw_point(x0,y0,z0,color,opacity);
      bool ninit_hatch = init_hatch;
      const float
        ax = u0 + u1 + 2*(x0 - x1),
        bx = 3*(x1 - x0) - 2*u0 - u1,
        ay = v0 + v1 + 2*(y0 - y1),
        by = 3*(y1 - y0) - 2*v0 - v1,
        az = w0 + w1 + 2*(z0 - z1),
        bz = 3*(z1 - z0) - 2*w0 - w1,
        _precision = 1/(std::sqrt(cimg::sqr(x0-x1)+cimg::sqr(y0-y1))*(precision>0?precision:1));
      int ox = x0, oy = y0, oz = z0;
      for (float t = 0; t<1; t+=_precision) {
        const float t2 = t*t, t3 = t2*t;
        const int
          nx = (int)(ax*t3 + bx*t2 + u0*t + x0),
          ny = (int)(ay*t3 + by*t2 + v0*t + y0),
          nz = (int)(az*t3 + bz*t2 + w0*t + z0);
        draw_line(ox,oy,oz,nx,ny,nz,color,opacity,pattern,ninit_hatch);
        ninit_hatch = false;
        ox = nx; oy = ny; oz = nz;
      }
      return draw_line(ox,oy,oz,x1,y1,z1,color,opacity,pattern,false);
    }

    //! Draw a textured 2d spline.
    /**
       \param x0 X-coordinate of the starting curve point
       \param y0 Y-coordinate of the starting curve point
       \param u0 X-coordinate of the starting velocity
       \param v0 Y-coordinate of the starting velocity
       \param x1 X-coordinate of the ending curve point
       \param y1 Y-coordinate of the ending curve point
       \param u1 X-coordinate of the ending velocity
       \param v1 Y-coordinate of the ending velocity
       \param texture Texture image defining line pixel colors.
       \param tx0 X-coordinate of the starting texture point.
       \param ty0 Y-coordinate of the starting texture point.
       \param tx1 X-coordinate of the ending texture point.
       \param ty1 Y-coordinate of the ending texture point.
       \param precision Curve drawing precision.
       \param opacity Drawing opacity.
       \param pattern An integer whose bits describe the line pattern.
       \param init_hatch if \c true, reinit hatch motif.
    **/
    template<typename t>
    CImg<T>& draw_spline(const int x0, const int y0, const float u0, const float v0,
                         const int x1, const int y1, const float u1, const float v1,
                         const CImg<t>& texture,
                         const int tx0, const int ty0, const int tx1, const int ty1,
                         const float opacity=1,
                         const float precision=4, const unsigned int pattern=~0U,
                         const bool init_hatch=true) {
      if (texture._depth>1 || texture._spectrum<_spectrum)
        throw CImgArgumentException(_cimg_instance
                                    "draw_spline(): Invalid specified texture (%u,%u,%u,%u,%p).",
                                    cimg_instance,
                                    texture._width,texture._height,texture._depth,texture._spectrum,texture._data);
      if (is_empty()) return *this;
      if (is_overlapped(texture)) return draw_spline(x0,y0,u0,v0,x1,y1,u1,v1,+texture,tx0,ty0,tx1,ty1,precision,opacity,pattern,init_hatch);
      if (x0==x1 && y0==y1) return draw_point(x0,y0,texture.get_vector_at(x0,y0),opacity);
      bool ninit_hatch = init_hatch;
      const float
        ax = u0 + u1 + 2*(x0 - x1),
        bx = 3*(x1 - x0) - 2*u0 - u1,
        ay = v0 + v1 + 2*(y0 - y1),
        by = 3*(y1 - y0) - 2*v0 - v1,
        _precision = 1/(std::sqrt(cimg::sqr(x0-x1)+cimg::sqr(y0-y1))*(precision>0?precision:1));
      int ox = x0, oy = y0, otx = tx0, oty = ty0;
      for (float t1 = 0; t1<1; t1+=_precision) {
        const float t2 = t1*t1, t3 = t2*t1;
        const int
          nx = (int)(ax*t3 + bx*t2 + u0*t1 + x0),
          ny = (int)(ay*t3 + by*t2 + v0*t1 + y0),
          ntx = tx0 + (int)((tx1-tx0)*t1),
          nty = ty0 + (int)((ty1-ty0)*t1);
        draw_line(ox,oy,nx,ny,texture,otx,oty,ntx,nty,opacity,pattern,ninit_hatch);
        ninit_hatch = false;
        ox = nx; oy = ny; otx = ntx; oty = nty;
      }
      return draw_line(ox,oy,x1,y1,texture,otx,oty,tx1,ty1,opacity,pattern,false);
    }

    //! Draw a set of consecutive splines.
    /**
       \param points Vertices data.
       \param tangents Tangents data.
       \param color Pointer to \c spectrum() consecutive values of type \c T, defining the drawing color.
       \param opacity Drawing opacity.
       \param is_closed_set Tells if the drawn spline set is closed.
       \param precision Precision of the drawing.
       \param pattern An integer whose bits describe the line pattern.
       \param init_hatch If \c true, init hatch motif.
    **/
    template<typename tp, typename tt, typename tc>
    CImg<T>& draw_spline(const CImg<tp>& points, const CImg<tt>& tangents,
                         const tc *const color, const float opacity=1,
                         const bool is_closed_set=false, const float precision=4,
                         const unsigned int pattern=~0U, const bool init_hatch=true) {
      if (is_empty() || !points || !tangents || points._width<2 || tangents._width<2) return *this;
      bool ninit_hatch = init_hatch;
      switch (points._height) {
      case 0 : case 1 :
        throw CImgArgumentException(_cimg_instance
                                    "draw_spline(): Invalid specified point set (%u,%u,%u,%u,%p).",
                                    cimg_instance,
                                    points._width,points._height,points._depth,points._spectrum,points._data);

      case 2 : {
        const int x0 = (int)points(0,0), y0 = (int)points(0,1);
        const float u0 = (float)tangents(0,0), v0 = (float)tangents(0,1);
        int ox = x0, oy = y0;
        float ou = u0, ov = v0;
        for (unsigned int i = 1; i<points._width; ++i) {
          const int x = (int)points(i,0), y = (int)points(i,1);
          const float u = (float)tangents(i,0), v = (float)tangents(i,1);
          draw_spline(ox,oy,ou,ov,x,y,u,v,color,precision,opacity,pattern,ninit_hatch);
          ninit_hatch = false;
          ox = x; oy = y; ou = u; ov = v;
        }
        if (is_closed_set) draw_spline(ox,oy,ou,ov,x0,y0,u0,v0,color,precision,opacity,pattern,false);
      } break;
      default : {
        const int x0 = (int)points(0,0), y0 = (int)points(0,1), z0 = (int)points(0,2);
        const float u0 = (float)tangents(0,0), v0 = (float)tangents(0,1), w0 = (float)tangents(0,2);
        int ox = x0, oy = y0, oz = z0;
        float ou = u0, ov = v0, ow = w0;
        for (unsigned int i = 1; i<points._width; ++i) {
          const int x = (int)points(i,0), y = (int)points(i,1), z = (int)points(i,2);
          const float u = (float)tangents(i,0), v = (float)tangents(i,1), w = (float)tangents(i,2);
          draw_spline(ox,oy,oz,ou,ov,ow,x,y,z,u,v,w,color,opacity,pattern,ninit_hatch);
          ninit_hatch = false;
          ox = x; oy = y; oz = z; ou = u; ov = v; ow = w;
        }
        if (is_closed_set) draw_spline(ox,oy,oz,ou,ov,ow,x0,y0,z0,u0,v0,w0,color,precision,opacity,pattern,false);
      }
      }
      return *this;
    }

    //! Draw a set of consecutive splines \overloading.
    /**
       Similar to previous function, with the point tangents automatically estimated from the given points set.
    **/
    template<typename tp, typename tc>
    CImg<T>& draw_spline(const CImg<tp>& points,
                         const tc *const color, const float opacity=1,
                         const bool is_closed_set=false, const float precision=4,
                         const unsigned int pattern=~0U, const bool init_hatch=true) {
      if (is_empty() || !points || points._width<2) return *this;
      CImg<Tfloat> tangents;
      switch (points._height) {
      case 0 : case 1 :
        throw CImgArgumentException(_cimg_instance
                                    "draw_spline(): Invalid specified point set (%u,%u,%u,%u,%p).",
                                    cimg_instance,
                                    points._width,points._height,points._depth,points._spectrum,points._data);
      case 2 : {
        tangents.assign(points._width,points._height);
        cimg_forX(points,p) {
          const unsigned int
            p0 = is_closed_set?(p+points._width-1)%points._width:(p?p-1:0),
            p1 = is_closed_set?(p+1)%points._width:(p+1<points._width?p+1:p);
          const float
            x = (float)points(p,0),
            y = (float)points(p,1),
            x0 = (float)points(p0,0),
            y0 = (float)points(p0,1),
            x1 = (float)points(p1,0),
            y1 = (float)points(p1,1),
            u0 = x - x0,
            v0 = y - y0,
            n0 = 1e-8f + (float)std::sqrt(u0*u0 + v0*v0),
            u1 = x1 - x,
            v1 = y1 - y,
            n1 = 1e-8f + (float)std::sqrt(u1*u1 + v1*v1),
            u = u0/n0 + u1/n1,
            v = v0/n0 + v1/n1,
            n = 1e-8f + (float)std::sqrt(u*u + v*v),
            fact = 0.5f*(n0 + n1);
          tangents(p,0) = (Tfloat)(fact*u/n);
          tangents(p,1) = (Tfloat)(fact*v/n);
        }
      } break;
      default : {
        tangents.assign(points._width,points._height);
        cimg_forX(points,p) {
          const unsigned int
            p0 = is_closed_set?(p+points._width-1)%points._width:(p?p-1:0),
            p1 = is_closed_set?(p+1)%points._width:(p+1<points._width?p+1:p);
          const float
            x = (float)points(p,0),
            y = (float)points(p,1),
            z = (float)points(p,2),
            x0 = (float)points(p0,0),
            y0 = (float)points(p0,1),
            z0 = (float)points(p0,2),
            x1 = (float)points(p1,0),
            y1 = (float)points(p1,1),
            z1 = (float)points(p1,2),
            u0 = x - x0,
            v0 = y - y0,
            w0 = z - z0,
            n0 = 1e-8f + (float)std::sqrt(u0*u0 + v0*v0 + w0*w0),
            u1 = x1 - x,
            v1 = y1 - y,
            w1 = z1 - z,
            n1 = 1e-8f + (float)std::sqrt(u1*u1 + v1*v1 + w1*w1),
            u = u0/n0 + u1/n1,
            v = v0/n0 + v1/n1,
            w = w0/n0 + w1/n1,
            n = 1e-8f + (float)std::sqrt(u*u + v*v + w*w),
            fact = 0.5f*(n0 + n1);
          tangents(p,0) = (Tfloat)(fact*u/n);
          tangents(p,1) = (Tfloat)(fact*v/n);
          tangents(p,2) = (Tfloat)(fact*w/n);
        }
      }
      }
      return draw_spline(points,tangents,color,opacity,is_closed_set,precision,pattern,init_hatch);
    }

    // Inner macro for drawing triangles.
#define _cimg_for_triangle1(img,xl,xr,y,x0,y0,x1,y1,x2,y2) \
        for (int y = y0<0?0:y0, \
               xr = y0>=0?x0:(x0-y0*(x2-x0)/(y2-y0)), \
               xl = y1>=0?(y0>=0?(y0==y1?x1:x0):(x0-y0*(x1-x0)/(y1-y0))):(x1-y1*(x2-x1)/(y2-y1)), \
               _sxn=1, \
               _sxr=1, \
               _sxl=1, \
               _dxn = x2>x1?x2-x1:(_sxn=-1,x1-x2), \
               _dxr = x2>x0?x2-x0:(_sxr=-1,x0-x2), \
               _dxl = x1>x0?x1-x0:(_sxl=-1,x0-x1), \
               _dyn = y2-y1, \
               _dyr = y2-y0, \
               _dyl = y1-y0, \
               _counter = (_dxn-=_dyn?_dyn*(_dxn/_dyn):0, \
                           _dxr-=_dyr?_dyr*(_dxr/_dyr):0, \
                           _dxl-=_dyl?_dyl*(_dxl/_dyl):0, \
                           cimg::min((int)(img)._height-y-1,y2-y)), \
               _errn = _dyn/2, \
               _errr = _dyr/2, \
               _errl = _dyl/2, \
               _rxn = _dyn?(x2-x1)/_dyn:0, \
               _rxr = _dyr?(x2-x0)/_dyr:0, \
               _rxl = (y0!=y1 && y1>0)?(_dyl?(x1-x0)/_dyl:0): \
                                       (_errl=_errn, _dxl=_dxn, _dyl=_dyn, _sxl=_sxn, _rxn); \
             _counter>=0; --_counter, ++y, \
               xr+=_rxr+((_errr-=_dxr)<0?_errr+=_dyr,_sxr:0), \
               xl+=(y!=y1)?_rxl+((_errl-=_dxl)<0?(_errl+=_dyl,_sxl):0): \
                           (_errl=_errn, _dxl=_dxn, _dyl=_dyn, _sxl=_sxn, _rxl=_rxn, x1-xl))

#define _cimg_for_triangle2(img,xl,cl,xr,cr,y,x0,y0,c0,x1,y1,c1,x2,y2,c2) \
        for (int y = y0<0?0:y0, \
               xr = y0>=0?x0:(x0-y0*(x2-x0)/(y2-y0)), \
               cr = y0>=0?c0:(c0-y0*(c2-c0)/(y2-y0)), \
               xl = y1>=0?(y0>=0?(y0==y1?x1:x0):(x0-y0*(x1-x0)/(y1-y0))):(x1-y1*(x2-x1)/(y2-y1)), \
               cl = y1>=0?(y0>=0?(y0==y1?c1:c0):(c0-y0*(c1-c0)/(y1-y0))):(c1-y1*(c2-c1)/(y2-y1)), \
               _sxn=1, _scn=1, \
               _sxr=1, _scr=1, \
               _sxl=1, _scl=1, \
               _dxn = x2>x1?x2-x1:(_sxn=-1,x1-x2), \
               _dxr = x2>x0?x2-x0:(_sxr=-1,x0-x2), \
               _dxl = x1>x0?x1-x0:(_sxl=-1,x0-x1), \
               _dcn = c2>c1?c2-c1:(_scn=-1,c1-c2), \
               _dcr = c2>c0?c2-c0:(_scr=-1,c0-c2), \
               _dcl = c1>c0?c1-c0:(_scl=-1,c0-c1), \
               _dyn = y2-y1, \
               _dyr = y2-y0, \
               _dyl = y1-y0, \
               _counter =(_dxn-=_dyn?_dyn*(_dxn/_dyn):0, \
                          _dxr-=_dyr?_dyr*(_dxr/_dyr):0, \
                          _dxl-=_dyl?_dyl*(_dxl/_dyl):0, \
                          _dcn-=_dyn?_dyn*(_dcn/_dyn):0, \
                          _dcr-=_dyr?_dyr*(_dcr/_dyr):0, \
                          _dcl-=_dyl?_dyl*(_dcl/_dyl):0, \
                          cimg::min((int)(img)._height-y-1,y2-y)), \
               _errn = _dyn/2, _errcn = _errn, \
               _errr = _dyr/2, _errcr = _errr, \
               _errl = _dyl/2, _errcl = _errl, \
               _rxn = _dyn?(x2-x1)/_dyn:0, \
               _rcn = _dyn?(c2-c1)/_dyn:0, \
               _rxr = _dyr?(x2-x0)/_dyr:0, \
               _rcr = _dyr?(c2-c0)/_dyr:0, \
               _rxl = (y0!=y1 && y1>0)?(_dyl?(x1-x0)/_dyl:0): \
                                       (_errl=_errn, _dxl=_dxn, _dyl=_dyn, _sxl=_sxn, _rxn), \
               _rcl = (y0!=y1 && y1>0)?(_dyl?(c1-c0)/_dyl:0): \
                                       (_errcl=_errcn, _dcl=_dcn, _dyl=_dyn, _scl=_scn, _rcn ); \
             _counter>=0; --_counter, ++y, \
               xr+=_rxr+((_errr-=_dxr)<0?_errr+=_dyr,_sxr:0), \
               cr+=_rcr+((_errcr-=_dcr)<0?_errcr+=_dyr,_scr:0), \
               xl+=(y!=y1)?(cl+=_rcl+((_errcl-=_dcl)<0?(_errcl+=_dyl,_scl):0), \
      	                   _rxl+((_errl-=_dxl)<0?(_errl+=_dyl,_sxl):0)): \
               (_errcl=_errcn, _dcl=_dcn, _dyl=_dyn, _scl=_scn, _rcl=_rcn, cl=c1, \
                _errl=_errn, _dxl=_dxn, _dyl=_dyn, _sxl=_sxn, _rxl=_rxn, x1-xl))

#define _cimg_for_triangle3(img,xl,txl,tyl,xr,txr,tyr,y,x0,y0,tx0,ty0,x1,y1,tx1,ty1,x2,y2,tx2,ty2) \
        for (int y = y0<0?0:y0, \
               xr = y0>=0?x0:(x0-y0*(x2-x0)/(y2-y0)), \
               txr = y0>=0?tx0:(tx0-y0*(tx2-tx0)/(y2-y0)), \
               tyr = y0>=0?ty0:(ty0-y0*(ty2-ty0)/(y2-y0)), \
               xl = y1>=0?(y0>=0?(y0==y1?x1:x0):(x0-y0*(x1-x0)/(y1-y0))):(x1-y1*(x2-x1)/(y2-y1)), \
               txl = y1>=0?(y0>=0?(y0==y1?tx1:tx0):(tx0-y0*(tx1-tx0)/(y1-y0))):(tx1-y1*(tx2-tx1)/(y2-y1)), \
               tyl = y1>=0?(y0>=0?(y0==y1?ty1:ty0):(ty0-y0*(ty1-ty0)/(y1-y0))):(ty1-y1*(ty2-ty1)/(y2-y1)), \
               _sxn=1, _stxn=1, _styn=1, \
               _sxr=1, _stxr=1, _styr=1, \
               _sxl=1, _stxl=1, _styl=1, \
               _dxn = x2>x1?x2-x1:(_sxn=-1,x1-x2), \
               _dxr = x2>x0?x2-x0:(_sxr=-1,x0-x2), \
               _dxl = x1>x0?x1-x0:(_sxl=-1,x0-x1), \
               _dtxn = tx2>tx1?tx2-tx1:(_stxn=-1,tx1-tx2), \
               _dtxr = tx2>tx0?tx2-tx0:(_stxr=-1,tx0-tx2), \
               _dtxl = tx1>tx0?tx1-tx0:(_stxl=-1,tx0-tx1), \
               _dtyn = ty2>ty1?ty2-ty1:(_styn=-1,ty1-ty2), \
               _dtyr = ty2>ty0?ty2-ty0:(_styr=-1,ty0-ty2), \
               _dtyl = ty1>ty0?ty1-ty0:(_styl=-1,ty0-ty1), \
               _dyn = y2-y1, \
               _dyr = y2-y0, \
               _dyl = y1-y0, \
               _counter =(_dxn-=_dyn?_dyn*(_dxn/_dyn):0, \
                          _dxr-=_dyr?_dyr*(_dxr/_dyr):0, \
                          _dxl-=_dyl?_dyl*(_dxl/_dyl):0, \
                          _dtxn-=_dyn?_dyn*(_dtxn/_dyn):0, \
                          _dtxr-=_dyr?_dyr*(_dtxr/_dyr):0, \
                          _dtxl-=_dyl?_dyl*(_dtxl/_dyl):0, \
                          _dtyn-=_dyn?_dyn*(_dtyn/_dyn):0, \
                          _dtyr-=_dyr?_dyr*(_dtyr/_dyr):0, \
                          _dtyl-=_dyl?_dyl*(_dtyl/_dyl):0, \
                          cimg::min((int)(img)._height-y-1,y2-y)), \
               _errn = _dyn/2, _errtxn = _errn, _errtyn = _errn, \
               _errr = _dyr/2, _errtxr = _errr, _errtyr = _errr, \
               _errl = _dyl/2, _errtxl = _errl, _errtyl = _errl, \
               _rxn = _dyn?(x2-x1)/_dyn:0, \
               _rtxn = _dyn?(tx2-tx1)/_dyn:0, \
               _rtyn = _dyn?(ty2-ty1)/_dyn:0, \
               _rxr = _dyr?(x2-x0)/_dyr:0, \
               _rtxr = _dyr?(tx2-tx0)/_dyr:0, \
               _rtyr = _dyr?(ty2-ty0)/_dyr:0, \
               _rxl = (y0!=y1 && y1>0)?(_dyl?(x1-x0)/_dyl:0): \
                                       (_errl=_errn, _dxl=_dxn, _dyl=_dyn, _sxl=_sxn, _rxn), \
               _rtxl = (y0!=y1 && y1>0)?(_dyl?(tx1-tx0)/_dyl:0): \
                                       (_errtxl=_errtxn, _dtxl=_dtxn, _dyl=_dyn, _stxl=_stxn, _rtxn ), \
               _rtyl = (y0!=y1 && y1>0)?(_dyl?(ty1-ty0)/_dyl:0): \
                                       (_errtyl=_errtyn, _dtyl=_dtyn, _dyl=_dyn, _styl=_styn, _rtyn ); \
             _counter>=0; --_counter, ++y, \
               xr+=_rxr+((_errr-=_dxr)<0?_errr+=_dyr,_sxr:0), \
               txr+=_rtxr+((_errtxr-=_dtxr)<0?_errtxr+=_dyr,_stxr:0), \
               tyr+=_rtyr+((_errtyr-=_dtyr)<0?_errtyr+=_dyr,_styr:0), \
               xl+=(y!=y1)?(txl+=_rtxl+((_errtxl-=_dtxl)<0?(_errtxl+=_dyl,_stxl):0), \
                            tyl+=_rtyl+((_errtyl-=_dtyl)<0?(_errtyl+=_dyl,_styl):0), \
                           _rxl+((_errl-=_dxl)<0?(_errl+=_dyl,_sxl):0)): \
               (_errtxl=_errtxn, _dtxl=_dtxn, _dyl=_dyn, _stxl=_stxn, _rtxl=_rtxn, txl=tx1, \
                _errtyl=_errtyn, _dtyl=_dtyn, _dyl=_dyn, _styl=_styn, _rtyl=_rtyn, tyl=ty1,\
                _errl=_errn, _dxl=_dxn, _dyl=_dyn, _sxl=_sxn, _rxl=_rxn, x1-xl))

#define _cimg_for_triangle4(img,xl,cl,txl,tyl,xr,cr,txr,tyr,y,x0,y0,c0,tx0,ty0,x1,y1,c1,tx1,ty1,x2,y2,c2,tx2,ty2) \
        for (int y = y0<0?0:y0, \
               xr = y0>=0?x0:(x0-y0*(x2-x0)/(y2-y0)), \
               cr = y0>=0?c0:(c0-y0*(c2-c0)/(y2-y0)), \
               txr = y0>=0?tx0:(tx0-y0*(tx2-tx0)/(y2-y0)), \
               tyr = y0>=0?ty0:(ty0-y0*(ty2-ty0)/(y2-y0)), \
               xl = y1>=0?(y0>=0?(y0==y1?x1:x0):(x0-y0*(x1-x0)/(y1-y0))):(x1-y1*(x2-x1)/(y2-y1)), \
               cl = y1>=0?(y0>=0?(y0==y1?c1:c0):(c0-y0*(c1-c0)/(y1-y0))):(c1-y1*(c2-c1)/(y2-y1)), \
               txl = y1>=0?(y0>=0?(y0==y1?tx1:tx0):(tx0-y0*(tx1-tx0)/(y1-y0))):(tx1-y1*(tx2-tx1)/(y2-y1)), \
               tyl = y1>=0?(y0>=0?(y0==y1?ty1:ty0):(ty0-y0*(ty1-ty0)/(y1-y0))):(ty1-y1*(ty2-ty1)/(y2-y1)), \
               _sxn=1, _scn=1, _stxn=1, _styn=1, \
               _sxr=1, _scr=1, _stxr=1, _styr=1, \
               _sxl=1, _scl=1, _stxl=1, _styl=1, \
               _dxn = x2>x1?x2-x1:(_sxn=-1,x1-x2), \
               _dxr = x2>x0?x2-x0:(_sxr=-1,x0-x2), \
               _dxl = x1>x0?x1-x0:(_sxl=-1,x0-x1), \
               _dcn = c2>c1?c2-c1:(_scn=-1,c1-c2), \
               _dcr = c2>c0?c2-c0:(_scr=-1,c0-c2), \
               _dcl = c1>c0?c1-c0:(_scl=-1,c0-c1), \
               _dtxn = tx2>tx1?tx2-tx1:(_stxn=-1,tx1-tx2), \
               _dtxr = tx2>tx0?tx2-tx0:(_stxr=-1,tx0-tx2), \
               _dtxl = tx1>tx0?tx1-tx0:(_stxl=-1,tx0-tx1), \
               _dtyn = ty2>ty1?ty2-ty1:(_styn=-1,ty1-ty2), \
               _dtyr = ty2>ty0?ty2-ty0:(_styr=-1,ty0-ty2), \
               _dtyl = ty1>ty0?ty1-ty0:(_styl=-1,ty0-ty1), \
               _dyn = y2-y1, \
               _dyr = y2-y0, \
               _dyl = y1-y0, \
               _counter =(_dxn-=_dyn?_dyn*(_dxn/_dyn):0, \
                          _dxr-=_dyr?_dyr*(_dxr/_dyr):0, \
                          _dxl-=_dyl?_dyl*(_dxl/_dyl):0, \
                          _dcn-=_dyn?_dyn*(_dcn/_dyn):0, \
                          _dcr-=_dyr?_dyr*(_dcr/_dyr):0, \
                          _dcl-=_dyl?_dyl*(_dcl/_dyl):0, \
                          _dtxn-=_dyn?_dyn*(_dtxn/_dyn):0, \
                          _dtxr-=_dyr?_dyr*(_dtxr/_dyr):0, \
                          _dtxl-=_dyl?_dyl*(_dtxl/_dyl):0, \
                          _dtyn-=_dyn?_dyn*(_dtyn/_dyn):0, \
                          _dtyr-=_dyr?_dyr*(_dtyr/_dyr):0, \
                          _dtyl-=_dyl?_dyl*(_dtyl/_dyl):0, \
                          cimg::min((int)(img)._height-y-1,y2-y)), \
               _errn = _dyn/2, _errcn = _errn, _errtxn = _errn, _errtyn = _errn, \
               _errr = _dyr/2, _errcr = _errr, _errtxr = _errr, _errtyr = _errr, \
               _errl = _dyl/2, _errcl = _errl, _errtxl = _errl, _errtyl = _errl, \
               _rxn = _dyn?(x2-x1)/_dyn:0, \
               _rcn = _dyn?(c2-c1)/_dyn:0, \
               _rtxn = _dyn?(tx2-tx1)/_dyn:0, \
               _rtyn = _dyn?(ty2-ty1)/_dyn:0, \
               _rxr = _dyr?(x2-x0)/_dyr:0, \
               _rcr = _dyr?(c2-c0)/_dyr:0, \
               _rtxr = _dyr?(tx2-tx0)/_dyr:0, \
               _rtyr = _dyr?(ty2-ty0)/_dyr:0, \
               _rxl = (y0!=y1 && y1>0)?(_dyl?(x1-x0)/_dyl:0): \
                                       (_errl=_errn, _dxl=_dxn, _dyl=_dyn, _sxl=_sxn, _rxn), \
               _rcl = (y0!=y1 && y1>0)?(_dyl?(c1-c0)/_dyl:0): \
                                       (_errcl=_errcn, _dcl=_dcn, _dyl=_dyn, _scl=_scn, _rcn ), \
               _rtxl = (y0!=y1 && y1>0)?(_dyl?(tx1-tx0)/_dyl:0): \
                                        (_errtxl=_errtxn, _dtxl=_dtxn, _dyl=_dyn, _stxl=_stxn, _rtxn ), \
               _rtyl = (y0!=y1 && y1>0)?(_dyl?(ty1-ty0)/_dyl:0): \
                                        (_errtyl=_errtyn, _dtyl=_dtyn, _dyl=_dyn, _styl=_styn, _rtyn ); \
             _counter>=0; --_counter, ++y, \
               xr+=_rxr+((_errr-=_dxr)<0?_errr+=_dyr,_sxr:0), \
               cr+=_rcr+((_errcr-=_dcr)<0?_errcr+=_dyr,_scr:0), \
               txr+=_rtxr+((_errtxr-=_dtxr)<0?_errtxr+=_dyr,_stxr:0), \
               tyr+=_rtyr+((_errtyr-=_dtyr)<0?_errtyr+=_dyr,_styr:0), \
               xl+=(y!=y1)?(cl+=_rcl+((_errcl-=_dcl)<0?(_errcl+=_dyl,_scl):0), \
                            txl+=_rtxl+((_errtxl-=_dtxl)<0?(_errtxl+=_dyl,_stxl):0), \
                            tyl+=_rtyl+((_errtyl-=_dtyl)<0?(_errtyl+=_dyl,_styl):0), \
                            _rxl+((_errl-=_dxl)<0?(_errl+=_dyl,_sxl):0)): \
               (_errcl=_errcn, _dcl=_dcn, _dyl=_dyn, _scl=_scn, _rcl=_rcn, cl=c1, \
                _errtxl=_errtxn, _dtxl=_dtxn, _dyl=_dyn, _stxl=_stxn, _rtxl=_rtxn, txl=tx1, \
                _errtyl=_errtyn, _dtyl=_dtyn, _dyl=_dyn, _styl=_styn, _rtyl=_rtyn, tyl=ty1, \
                _errl=_errn, _dxl=_dxn, _dyl=_dyn, _sxl=_sxn, _rxl=_rxn, x1-xl))

#define _cimg_for_triangle5(img,xl,txl,tyl,lxl,lyl,xr,txr,tyr,lxr,lyr,y,x0,y0,tx0,ty0,lx0,ly0,x1,y1,tx1,ty1,lx1,ly1,x2,y2,tx2,ty2,lx2,ly2) \
        for (int y = y0<0?0:y0, \
               xr = y0>=0?x0:(x0-y0*(x2-x0)/(y2-y0)), \
               txr = y0>=0?tx0:(tx0-y0*(tx2-tx0)/(y2-y0)), \
               tyr = y0>=0?ty0:(ty0-y0*(ty2-ty0)/(y2-y0)), \
               lxr = y0>=0?lx0:(lx0-y0*(lx2-lx0)/(y2-y0)), \
               lyr = y0>=0?ly0:(ly0-y0*(ly2-ly0)/(y2-y0)), \
               xl = y1>=0?(y0>=0?(y0==y1?x1:x0):(x0-y0*(x1-x0)/(y1-y0))):(x1-y1*(x2-x1)/(y2-y1)), \
               txl = y1>=0?(y0>=0?(y0==y1?tx1:tx0):(tx0-y0*(tx1-tx0)/(y1-y0))):(tx1-y1*(tx2-tx1)/(y2-y1)), \
               tyl = y1>=0?(y0>=0?(y0==y1?ty1:ty0):(ty0-y0*(ty1-ty0)/(y1-y0))):(ty1-y1*(ty2-ty1)/(y2-y1)), \
               lxl = y1>=0?(y0>=0?(y0==y1?lx1:lx0):(lx0-y0*(lx1-lx0)/(y1-y0))):(lx1-y1*(lx2-lx1)/(y2-y1)), \
               lyl = y1>=0?(y0>=0?(y0==y1?ly1:ly0):(ly0-y0*(ly1-ly0)/(y1-y0))):(ly1-y1*(ly2-ly1)/(y2-y1)), \
               _sxn=1, _stxn=1, _styn=1, _slxn=1, _slyn=1, \
               _sxr=1, _stxr=1, _styr=1, _slxr=1, _slyr=1, \
               _sxl=1, _stxl=1, _styl=1, _slxl=1, _slyl=1, \
               _dxn = x2>x1?x2-x1:(_sxn=-1,x1-x2), _dyn = y2-y1, \
               _dxr = x2>x0?x2-x0:(_sxr=-1,x0-x2), _dyr = y2-y0, \
               _dxl = x1>x0?x1-x0:(_sxl=-1,x0-x1), _dyl = y1-y0, \
               _dtxn = tx2>tx1?tx2-tx1:(_stxn=-1,tx1-tx2), \
               _dtxr = tx2>tx0?tx2-tx0:(_stxr=-1,tx0-tx2), \
               _dtxl = tx1>tx0?tx1-tx0:(_stxl=-1,tx0-tx1), \
               _dtyn = ty2>ty1?ty2-ty1:(_styn=-1,ty1-ty2), \
               _dtyr = ty2>ty0?ty2-ty0:(_styr=-1,ty0-ty2), \
               _dtyl = ty1>ty0?ty1-ty0:(_styl=-1,ty0-ty1), \
               _dlxn = lx2>lx1?lx2-lx1:(_slxn=-1,lx1-lx2), \
               _dlxr = lx2>lx0?lx2-lx0:(_slxr=-1,lx0-lx2), \
               _dlxl = lx1>lx0?lx1-lx0:(_slxl=-1,lx0-lx1), \
               _dlyn = ly2>ly1?ly2-ly1:(_slyn=-1,ly1-ly2), \
               _dlyr = ly2>ly0?ly2-ly0:(_slyr=-1,ly0-ly2), \
               _dlyl = ly1>ly0?ly1-ly0:(_slyl=-1,ly0-ly1), \
               _counter =(_dxn-=_dyn?_dyn*(_dxn/_dyn):0, \
                          _dxr-=_dyr?_dyr*(_dxr/_dyr):0, \
                          _dxl-=_dyl?_dyl*(_dxl/_dyl):0, \
                          _dtxn-=_dyn?_dyn*(_dtxn/_dyn):0, \
                          _dtxr-=_dyr?_dyr*(_dtxr/_dyr):0, \
                          _dtxl-=_dyl?_dyl*(_dtxl/_dyl):0, \
                          _dtyn-=_dyn?_dyn*(_dtyn/_dyn):0, \
                          _dtyr-=_dyr?_dyr*(_dtyr/_dyr):0, \
                          _dtyl-=_dyl?_dyl*(_dtyl/_dyl):0, \
                          _dlxn-=_dyn?_dyn*(_dlxn/_dyn):0, \
                          _dlxr-=_dyr?_dyr*(_dlxr/_dyr):0, \
                          _dlxl-=_dyl?_dyl*(_dlxl/_dyl):0, \
                          _dlyn-=_dyn?_dyn*(_dlyn/_dyn):0, \
                          _dlyr-=_dyr?_dyr*(_dlyr/_dyr):0, \
                          _dlyl-=_dyl?_dyl*(_dlyl/_dyl):0, \
                          cimg::min((int)(img)._height-y-1,y2-y)), \
               _errn = _dyn/2, _errtxn = _errn, _errtyn = _errn, _errlxn = _errn, _errlyn = _errn, \
               _errr = _dyr/2, _errtxr = _errr, _errtyr = _errr, _errlxr = _errr, _errlyr = _errr, \
               _errl = _dyl/2, _errtxl = _errl, _errtyl = _errl, _errlxl = _errl, _errlyl = _errl, \
               _rxn = _dyn?(x2-x1)/_dyn:0, \
               _rtxn = _dyn?(tx2-tx1)/_dyn:0, \
               _rtyn = _dyn?(ty2-ty1)/_dyn:0, \
               _rlxn = _dyn?(lx2-lx1)/_dyn:0, \
               _rlyn = _dyn?(ly2-ly1)/_dyn:0, \
               _rxr = _dyr?(x2-x0)/_dyr:0, \
               _rtxr = _dyr?(tx2-tx0)/_dyr:0, \
               _rtyr = _dyr?(ty2-ty0)/_dyr:0, \
               _rlxr = _dyr?(lx2-lx0)/_dyr:0, \
               _rlyr = _dyr?(ly2-ly0)/_dyr:0, \
               _rxl = (y0!=y1 && y1>0)?(_dyl?(x1-x0)/_dyl:0): \
                                       (_errl=_errn, _dxl=_dxn, _dyl=_dyn, _sxl=_sxn, _rxn), \
               _rtxl = (y0!=y1 && y1>0)?(_dyl?(tx1-tx0)/_dyl:0): \
                                        (_errtxl=_errtxn, _dtxl=_dtxn, _dyl=_dyn, _stxl=_stxn, _rtxn ), \
               _rtyl = (y0!=y1 && y1>0)?(_dyl?(ty1-ty0)/_dyl:0): \
                                        (_errtyl=_errtyn, _dtyl=_dtyn, _dyl=_dyn, _styl=_styn, _rtyn ), \
               _rlxl = (y0!=y1 && y1>0)?(_dyl?(lx1-lx0)/_dyl:0): \
                                        (_errlxl=_errlxn, _dlxl=_dlxn, _dyl=_dyn, _slxl=_slxn, _rlxn ), \
               _rlyl = (y0!=y1 && y1>0)?(_dyl?(ly1-ly0)/_dyl:0): \
                                        (_errlyl=_errlyn, _dlyl=_dlyn, _dyl=_dyn, _slyl=_slyn, _rlyn ); \
             _counter>=0; --_counter, ++y, \
               xr+=_rxr+((_errr-=_dxr)<0?_errr+=_dyr,_sxr:0), \
               txr+=_rtxr+((_errtxr-=_dtxr)<0?_errtxr+=_dyr,_stxr:0), \
               tyr+=_rtyr+((_errtyr-=_dtyr)<0?_errtyr+=_dyr,_styr:0), \
               lxr+=_rlxr+((_errlxr-=_dlxr)<0?_errlxr+=_dyr,_slxr:0), \
               lyr+=_rlyr+((_errlyr-=_dlyr)<0?_errlyr+=_dyr,_slyr:0), \
               xl+=(y!=y1)?(txl+=_rtxl+((_errtxl-=_dtxl)<0?(_errtxl+=_dyl,_stxl):0), \
                            tyl+=_rtyl+((_errtyl-=_dtyl)<0?(_errtyl+=_dyl,_styl):0), \
                            lxl+=_rlxl+((_errlxl-=_dlxl)<0?(_errlxl+=_dyl,_slxl):0), \
                            lyl+=_rlyl+((_errlyl-=_dlyl)<0?(_errlyl+=_dyl,_slyl):0), \
                            _rxl+((_errl-=_dxl)<0?(_errl+=_dyl,_sxl):0)): \
               (_errtxl=_errtxn, _dtxl=_dtxn, _dyl=_dyn, _stxl=_stxn, _rtxl=_rtxn, txl=tx1, \
                _errtyl=_errtyn, _dtyl=_dtyn, _dyl=_dyn, _styl=_styn, _rtyl=_rtyn, tyl=ty1, \
                _errlxl=_errlxn, _dlxl=_dlxn, _dyl=_dyn, _slxl=_slxn, _rlxl=_rlxn, lxl=lx1, \
                _errlyl=_errlyn, _dlyl=_dlyn, _dyl=_dyn, _slyl=_slyn, _rlyl=_rlyn, lyl=ly1, \
                _errl=_errn, _dxl=_dxn, _dyl=_dyn, _sxl=_sxn, _rxl=_rxn, x1-xl))

    // [internal] Draw a filled triangle.
    template<typename tc>
    CImg<T>& _draw_triangle(const int x0, const int y0,
                            const int x1, const int y1,
                            const int x2, const int y2,
                            const tc *const color, const float opacity,
                            const float brightness) {
      cimg_init_scanline(color,opacity);
      const float nbrightness = brightness<0?0:(brightness>2?2:brightness);
      int nx0 = x0, ny0 = y0, nx1 = x1, ny1 = y1, nx2 = x2, ny2 = y2;
      if (ny0>ny1) cimg::swap(nx0,nx1,ny0,ny1);
      if (ny0>ny2) cimg::swap(nx0,nx2,ny0,ny2);
      if (ny1>ny2) cimg::swap(nx1,nx2,ny1,ny2);
      if (ny0<height() && ny2>=0) {
        if ((nx1 - nx0)*(ny2 - ny0) - (nx2 - nx0)*(ny1 - ny0)<0)
          _cimg_for_triangle1(*this,xl,xr,y,nx0,ny0,nx1,ny1,nx2,ny2) cimg_draw_scanline(xl,xr,y,color,opacity,nbrightness);
        else
          _cimg_for_triangle1(*this,xl,xr,y,nx0,ny0,nx1,ny1,nx2,ny2) cimg_draw_scanline(xr,xl,y,color,opacity,nbrightness);
      }
      return *this;
    }

    //! Draw a filled 2d triangle.
    /**
       \param x0 X-coordinate of the first vertex.
       \param y0 Y-coordinate of the first vertex.
       \param x1 X-coordinate of the second vertex.
       \param y1 Y-coordinate of the second vertex.
       \param x2 X-coordinate of the third vertex.
       \param y2 Y-coordinate of the third vertex.
       \param color Pointer to \c spectrum() consecutive values of type \c T, defining the drawing color.
       \param opacity Drawing opacity.
     **/
    template<typename tc>
    CImg<T>& draw_triangle(const int x0, const int y0,
                           const int x1, const int y1,
                           const int x2, const int y2,
                           const tc *const color, const float opacity=1) {
      if (is_empty()) return *this;
      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Specified color is (null).",
                                    cimg_instance);
      _draw_triangle(x0,y0,x1,y1,x2,y2,color,opacity,1);
      return *this;
    }

    //! Draw a outlined 2d triangle.
    /**
       \param x0 X-coordinate of the first vertex.
       \param y0 Y-coordinate of the first vertex.
       \param x1 X-coordinate of the second vertex.
       \param y1 Y-coordinate of the second vertex.
       \param x2 X-coordinate of the third vertex.
       \param y2 Y-coordinate of the third vertex.
       \param color Pointer to \c spectrum() consecutive values of type \c T, defining the drawing color.
       \param opacity Drawing opacity.
       \param pattern An integer whose bits describe the outline pattern.
     **/
    template<typename tc>
    CImg<T>& draw_triangle(const int x0, const int y0,
                           const int x1, const int y1,
                           const int x2, const int y2,
                           const tc *const color, const float opacity,
                           const unsigned int pattern) {
      if (is_empty()) return *this;
      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Specified color is (null).",
                                    cimg_instance);
      draw_line(x0,y0,x1,y1,color,opacity,pattern,true).
        draw_line(x1,y1,x2,y2,color,opacity,pattern,false).
        draw_line(x2,y2,x0,y0,color,opacity,pattern,false);
      return *this;
    }

    //! Draw a filled 2d triangle, with z-buffering.
    /**
       \param zbuffer Z-buffer image.
       \param x0 X-coordinate of the first vertex.
       \param y0 Y-coordinate of the first vertex.
       \param z0 Z-coordinate of the first vertex.
       \param x1 X-coordinate of the second vertex.
       \param y1 Y-coordinate of the second vertex.
       \param z1 Z-coordinate of the second vertex.
       \param x2 X-coordinate of the third vertex.
       \param y2 Y-coordinate of the third vertex.
       \param z2 Z-coordinate of the third vertex.
       \param color Pointer to \c spectrum() consecutive values of type \c T, defining the drawing color.
       \param opacity Drawing opacity.
       \param brightness Brightness factor.
    **/
    template<typename tz, typename tc>
    CImg<T>& draw_triangle(CImg<tz>& zbuffer,
                           const int x0, const int y0, const float z0,
                           const int x1, const int y1, const float z1,
                           const int x2, const int y2, const float z2,
                           const tc *const color, const float opacity=1,
                           const float brightness=1) {
      typedef typename cimg::superset<tz,float>::type tzfloat;
      if (is_empty() || z0<=0 || z1<=0 || z2<=0) return *this;
      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Specified color is (null).",
                                    cimg_instance);
      if (!is_sameXY(zbuffer))
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Instance and specified Z-buffer (%u,%u,%u,%u,%p) have different dimensions.",
                                    cimg_instance,
                                    zbuffer._width,zbuffer._height,zbuffer._depth,zbuffer._spectrum,zbuffer._data);
      static const T maxval = (T)cimg::min(cimg::type<T>::max(),cimg::type<tc>::max());
      const float
        nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0),
        nbrightness = brightness<0?0:(brightness>2?2:brightness);
      const long whd = (long)_width*_height*_depth, offx = _spectrum*whd;
      int nx0 = x0, ny0 = y0, nx1 = x1, ny1 = y1, nx2 = x2, ny2 = y2;
      tzfloat nz0 = 1/(tzfloat)z0, nz1 = 1/(tzfloat)z1, nz2 = 1/(tzfloat)z2;
      if (ny0>ny1) cimg::swap(nx0,nx1,ny0,ny1,nz0,nz1);
      if (ny0>ny2) cimg::swap(nx0,nx2,ny0,ny2,nz0,nz2);
      if (ny1>ny2) cimg::swap(nx1,nx2,ny1,ny2,nz1,nz2);
      if (ny0>=height() || ny2<0) return *this;
      tzfloat
        pzl = (nz1 - nz0)/(ny1 - ny0),
        pzr = (nz2 - nz0)/(ny2 - ny0),
        pzn = (nz2 - nz1)/(ny2 - ny1),
        zr = ny0>=0?nz0:(nz0 - ny0*(nz2 - nz0)/(ny2 - ny0)),
        zl = ny1>=0?(ny0>=0?nz0:(nz0 - ny0*(nz1 - nz0)/(ny1 - ny0))):(pzl=pzn,(nz1 - ny1*(nz2 - nz1)/(ny2 - ny1)));
      _cimg_for_triangle1(*this,xleft0,xright0,y,nx0,ny0,nx1,ny1,nx2,ny2) {
        if (y==ny1) { zl = nz1; pzl = pzn; }
        int xleft = xleft0, xright = xright0;
        tzfloat zleft = zl, zright = zr;
        if (xright<xleft) cimg::swap(xleft,xright,zleft,zright);
        const int dx = xright - xleft;
        const tzfloat pentez = (zright - zleft)/dx;
        if (xleft<0 && dx) zleft-=xleft*(zright - zleft)/dx;
        if (xleft<0) xleft = 0;
        if (xright>=width()-1) xright = width() - 1;
        T* ptrd = data(xleft,y,0,0);
        tz *ptrz = zbuffer.data(xleft,y);
        if (opacity>=1) {
          if (nbrightness==1) for (int x = xleft; x<=xright; ++x, ++ptrz, ++ptrd) {
              if (zleft>=(tzfloat)*ptrz) {
                *ptrz = (tz)zleft;
              const tc *col = color; cimg_forC(*this,c) { *ptrd = (T)*(col++); ptrd+=whd; }
              ptrd-=offx;
            }
            zleft+=pentez;
          } else if (nbrightness<1) for (int x = xleft; x<=xright; ++x, ++ptrz, ++ptrd) {
              if (zleft>=(tzfloat)*ptrz) {
                *ptrz = (tz)zleft;
              const tc *col = color; cimg_forC(*this,c) { *ptrd = (T)(nbrightness*(*col++)); ptrd+=whd; }
              ptrd-=offx;
            }
            zleft+=pentez;
          } else for (int x = xleft; x<=xright; ++x, ++ptrz, ++ptrd) {
              if (zleft>=(tzfloat)*ptrz) {
                *ptrz = (tz)zleft;
              const tc *col = color; cimg_forC(*this,c) { *ptrd = (T)((2-nbrightness)**(col++) + (nbrightness-1)*maxval); ptrd+=whd; }
              ptrd-=offx;
            }
            zleft+=pentez;
          }
        } else {
          if (nbrightness==1) for (int x = xleft; x<=xright; ++x, ++ptrz, ++ptrd) {
              if (zleft>=(tzfloat)*ptrz) {
                *ptrz = (tz)zleft;
              const tc *col = color; cimg_forC(*this,c) { *ptrd = (T)(nopacity**(col++) + *ptrd*copacity); ptrd+=whd; }
              ptrd-=offx;
            }
            zleft+=pentez;
          } else if (nbrightness<1) for (int x = xleft; x<=xright; ++x, ++ptrz, ++ptrd) {
              if (zleft>=(tzfloat)*ptrz) {
                *ptrz = (tz)zleft;
              const tc *col = color; cimg_forC(*this,c) { *ptrd = (T)(nopacity*nbrightness**(col++) + *ptrd*copacity); ptrd+=whd; }
              ptrd-=offx;
            }
            zleft+=pentez;
          } else for (int x = xleft; x<=xright; ++x, ++ptrz, ++ptrd) {
              if (zleft>=(tzfloat)*ptrz) {
                *ptrz = (tz)zleft;
              const tc *col = color;
              cimg_forC(*this,c) {
                const T val = (T)((2-nbrightness)**(col++) + (nbrightness-1)*maxval);
                *ptrd = (T)(nopacity*val + *ptrd*copacity);
                ptrd+=whd;
              }
              ptrd-=offx;
            }
            zleft+=pentez;
          }
        }
        zr+=pzr; zl+=pzl;
      }
      return *this;
    }

    //! Draw a Gouraud-shaded 2d triangle.
    /**
       \param x0 X-coordinate of the first vertex in the image instance.
       \param y0 Y-coordinate of the first vertex in the image instance.
       \param x1 X-coordinate of the second vertex in the image instance.
       \param y1 Y-coordinate of the second vertex in the image instance.
       \param x2 X-coordinate of the third vertex in the image instance.
       \param y2 Y-coordinate of the third vertex in the image instance.
       \param color Pointer to \c spectrum() consecutive values, defining the drawing color.
       \param brightness0 Brightness factor of the first vertex (in [0,2]).
       \param brightness1 brightness factor of the second vertex (in [0,2]).
       \param brightness2 brightness factor of the third vertex (in [0,2]).
       \param opacity Drawing opacity.
    **/
    template<typename tc>
    CImg<T>& draw_triangle(const int x0, const int y0,
                           const int x1, const int y1,
                           const int x2, const int y2,
                           const tc *const color,
                           const float brightness0,
                           const float brightness1,
                           const float brightness2,
                           const float opacity=1) {
      if (is_empty()) return *this;
      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Specified color is (null).",
                                    cimg_instance);
      static const T maxval = (T)cimg::min(cimg::type<T>::max(),cimg::type<tc>::max());
      const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
      const long whd = (long)_width*_height*_depth, offx = _spectrum*whd-1;
      int nx0 = x0, ny0 = y0, nx1 = x1, ny1 = y1, nx2 = x2, ny2 = y2,
        nc0 = (int)((brightness0<0.0f?0.0f:(brightness0>2.0f?2.0f:brightness0))*256.0f),
        nc1 = (int)((brightness1<0.0f?0.0f:(brightness1>2.0f?2.0f:brightness1))*256.0f),
        nc2 = (int)((brightness2<0.0f?0.0f:(brightness2>2.0f?2.0f:brightness2))*256.0f);
      if (ny0>ny1) cimg::swap(nx0,nx1,ny0,ny1,nc0,nc1);
      if (ny0>ny2) cimg::swap(nx0,nx2,ny0,ny2,nc0,nc2);
      if (ny1>ny2) cimg::swap(nx1,nx2,ny1,ny2,nc1,nc2);
      if (ny0>=height() || ny2<0) return *this;
      _cimg_for_triangle2(*this,xleft0,cleft0,xright0,cright0,y,nx0,ny0,nc0,nx1,ny1,nc1,nx2,ny2,nc2) {
        int xleft = xleft0, xright = xright0, cleft = cleft0, cright = cright0;
        if (xright<xleft) cimg::swap(xleft,xright,cleft,cright);
        const int
          dx = xright - xleft,
          dc = cright>cleft?cright - cleft:cleft - cright,
          rc = dx?(cright - cleft)/dx:0,
          sc = cright>cleft?1:-1,
          ndc = dc-(dx?dx*(dc/dx):0);
        int errc = dx>>1;
        if (xleft<0 && dx) cleft-=xleft*(cright - cleft)/dx;
        if (xleft<0) xleft = 0;
        if (xright>=width()-1) xright = width() - 1;
        T* ptrd = data(xleft,y);
        if (opacity>=1) for (int x = xleft; x<=xright; ++x) {
          const tc *col = color;
          cimg_forC(*this,c) {
            *ptrd = (T)(cleft<256?cleft**(col++)/256:((512-cleft)**(col++)+(cleft-256)*maxval)/256);
            ptrd+=whd;
          }
          ptrd-=offx;
          cleft+=rc+((errc-=ndc)<0?errc+=dx,sc:0);
        } else for (int x = xleft; x<=xright; ++x) {
          const tc *col = color;
          cimg_forC(*this,c) {
            const T val = (T)(cleft<256?cleft**(col++)/256:((512-cleft)**(col++)+(cleft-256)*maxval)/256);
            *ptrd = (T)(nopacity*val + *ptrd*copacity);
            ptrd+=whd;
          }
          ptrd-=offx;
          cleft+=rc+((errc-=ndc)<0?errc+=dx,sc:0);
        }
      }
      return *this;
    }

    //! Draw a Gouraud-shaded 2d triangle, with z-buffering \overloading.
    template<typename tz, typename tc>
    CImg<T>& draw_triangle(CImg<tz>& zbuffer,
                           const int x0, const int y0, const float z0,
                           const int x1, const int y1, const float z1,
                           const int x2, const int y2, const float z2,
                           const tc *const color,
                           const float brightness0,
                           const float brightness1,
                           const float brightness2,
                           const float opacity=1) {
      typedef typename cimg::superset<tz,float>::type tzfloat;
      if (is_empty() || z0<=0 || z1<=0 || z2<=0) return *this;
      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Specified color is (null).",
                                    cimg_instance);
      if (!is_sameXY(zbuffer))
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Instance and specified Z-buffer (%u,%u,%u,%u,%p) have different dimensions.",
                                    cimg_instance,
                                    zbuffer._width,zbuffer._height,zbuffer._depth,zbuffer._spectrum,zbuffer._data);
      static const T maxval = (T)cimg::min(cimg::type<T>::max(),cimg::type<tc>::max());
      const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
      const long whd = (long)_width*_height*_depth, offx = _spectrum*whd;
      int nx0 = x0, ny0 = y0, nx1 = x1, ny1 = y1, nx2 = x2, ny2 = y2,
        nc0 = (int)((brightness0<0.0f?0.0f:(brightness0>2.0f?2.0f:brightness0))*256.0f),
        nc1 = (int)((brightness1<0.0f?0.0f:(brightness1>2.0f?2.0f:brightness1))*256.0f),
        nc2 = (int)((brightness2<0.0f?0.0f:(brightness2>2.0f?2.0f:brightness2))*256.0f);
      tzfloat nz0 = 1/(tzfloat)z0, nz1 = 1/(tzfloat)z1, nz2 = 1/(tzfloat)z2;
      if (ny0>ny1) cimg::swap(nx0,nx1,ny0,ny1,nz0,nz1,nc0,nc1);
      if (ny0>ny2) cimg::swap(nx0,nx2,ny0,ny2,nz0,nz2,nc0,nc2);
      if (ny1>ny2) cimg::swap(nx1,nx2,ny1,ny2,nz1,nz2,nc1,nc2);
      if (ny0>=height() || ny2<0) return *this;
      tzfloat
        pzl = (nz1 - nz0)/(ny1 - ny0),
        pzr = (nz2 - nz0)/(ny2 - ny0),
        pzn = (nz2 - nz1)/(ny2 - ny1),
        zr = ny0>=0?nz0:(nz0 - ny0*(nz2 - nz0)/(ny2 - ny0)),
        zl = ny1>=0?(ny0>=0?nz0:(nz0 - ny0*(nz1 - nz0)/(ny1 - ny0))):(pzl=pzn,(nz1 - ny1*(nz2 - nz1)/(ny2 - ny1)));
      _cimg_for_triangle2(*this,xleft0,cleft0,xright0,cright0,y,nx0,ny0,nc0,nx1,ny1,nc1,nx2,ny2,nc2) {
        if (y==ny1) { zl = nz1; pzl = pzn; }
        int xleft = xleft0, xright = xright0, cleft = cleft0, cright = cright0;
        tzfloat zleft = zl, zright = zr;
        if (xright<xleft) cimg::swap(xleft,xright,zleft,zright,cleft,cright);
        const int
          dx = xright - xleft,
          dc = cright>cleft?cright - cleft:cleft - cright,
          rc = dx?(cright-cleft)/dx:0,
          sc = cright>cleft?1:-1,
          ndc = dc-(dx?dx*(dc/dx):0);
        const tzfloat pentez = (zright - zleft)/dx;
        int errc = dx>>1;
        if (xleft<0 && dx) {
          cleft-=xleft*(cright - cleft)/dx;
          zleft-=xleft*(zright - zleft)/dx;
        }
        if (xleft<0) xleft = 0;
        if (xright>=width()-1) xright = width()-1;
        T *ptrd = data(xleft,y);
        tz *ptrz = zbuffer.data(xleft,y);
        if (opacity>=1) for (int x = xleft; x<=xright; ++x, ++ptrd, ++ptrz) {
            if (zleft>=(tzfloat)*ptrz) {
              *ptrz = (tz)zleft;
              const tc *col = color;
              cimg_forC(*this,c) {
                *ptrd = (T)(cleft<256?cleft**(col++)/256:((512-cleft)**(col++)+(cleft-256)*maxval)/256);
                ptrd+=whd;
              }
              ptrd-=offx;
            }
            zleft+=pentez;
            cleft+=rc+((errc-=ndc)<0?errc+=dx,sc:0);
          } else for (int x = xleft; x<=xright; ++x, ++ptrd, ++ptrz) {
            if (zleft>=(tzfloat)*ptrz) {
              *ptrz = (tz)zleft;
              const tc *col = color;
              cimg_forC(*this,c) {
                const T val = (T)(cleft<256?cleft**(col++)/256:((512-cleft)**(col++)+(cleft-256)*maxval)/256);
                *ptrd = (T)(nopacity*val + *ptrd*copacity);
                ptrd+=whd;
              }
              ptrd-=offx;
            }
            zleft+=pentez;
            cleft+=rc+((errc-=ndc)<0?errc+=dx,sc:0);
          }
        zr+=pzr; zl+=pzl;
      }
      return *this;
    }

    //! Draw a color-interpolated 2d triangle.
    /**
       \param x0 X-coordinate of the first vertex in the image instance.
       \param y0 Y-coordinate of the first vertex in the image instance.
       \param x1 X-coordinate of the second vertex in the image instance.
       \param y1 Y-coordinate of the second vertex in the image instance.
       \param x2 X-coordinate of the third vertex in the image instance.
       \param y2 Y-coordinate of the third vertex in the image instance.
       \param color1 Pointer to \c spectrum() consecutive values of type \c T, defining the color of the first vertex.
       \param color2 Pointer to \c spectrum() consecutive values of type \c T, defining the color of the seconf vertex.
       \param color3 Pointer to \c spectrum() consecutive values of type \c T, defining the color of the third vertex.
       \param opacity Drawing opacity.
     **/
    template<typename tc1, typename tc2, typename tc3>
    CImg<T>& draw_triangle(const int x0, const int y0,
                           const int x1, const int y1,
                           const int x2, const int y2,
                           const tc1 *const color1,
                           const tc2 *const color2,
                           const tc3 *const color3,
                           const float opacity=1) {
      const unsigned char one = 1;
      cimg_forC(*this,c) get_shared_channel(c).draw_triangle(x0,y0,x1,y1,x2,y2,&one,color1[c],color2[c],color3[c],opacity);
      return *this;
    }

    //! Draw a textured 2d triangle.
    /**
       \param x0 X-coordinate of the first vertex in the image instance.
       \param y0 Y-coordinate of the first vertex in the image instance.
       \param x1 X-coordinate of the second vertex in the image instance.
       \param y1 Y-coordinate of the second vertex in the image instance.
       \param x2 X-coordinate of the third vertex in the image instance.
       \param y2 Y-coordinate of the third vertex in the image instance.
       \param texture Texture image used to fill the triangle.
       \param tx0 X-coordinate of the first vertex in the texture image.
       \param ty0 Y-coordinate of the first vertex in the texture image.
       \param tx1 X-coordinate of the second vertex in the texture image.
       \param ty1 Y-coordinate of the second vertex in the texture image.
       \param tx2 X-coordinate of the third vertex in the texture image.
       \param ty2 Y-coordinate of the third vertex in the texture image.
       \param opacity Drawing opacity.
       \param brightness Brightness factor of the drawing (in [0,2]).
    **/
    template<typename tc>
    CImg<T>& draw_triangle(const int x0, const int y0,
                           const int x1, const int y1,
                           const int x2, const int y2,
                           const CImg<tc>& texture,
                           const int tx0, const int ty0,
                           const int tx1, const int ty1,
                           const int tx2, const int ty2,
                           const float opacity=1,
                           const float brightness=1) {
      if (is_empty()) return *this;
      if (texture._depth>1 || texture._spectrum<_spectrum)
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Invalid specified texture (%u,%u,%u,%u,%p).",
                                    cimg_instance,
                                    texture._width,texture._height,texture._depth,texture._spectrum,texture._data);
      if (is_overlapped(texture)) return draw_triangle(x0,y0,x1,y1,x2,y2,+texture,tx0,ty0,tx1,ty1,tx2,ty2,opacity,brightness);
      static const T maxval = (T)cimg::min(cimg::type<T>::max(),cimg::type<tc>::max());
      const float
        nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0),
        nbrightness = brightness<0?0:(brightness>2?2:brightness);
      const long whd = (long)_width*_height*_depth, twhd = (long)texture._width*texture._height*texture._depth, offx = _spectrum*whd-1;
      int nx0 = x0, ny0 = y0, nx1 = x1, ny1 = y1, nx2 = x2, ny2 = y2,
        ntx0 = tx0, nty0 = ty0, ntx1 = tx1, nty1 = ty1, ntx2 = tx2, nty2 = ty2;
      if (ny0>ny1) cimg::swap(nx0,nx1,ny0,ny1,ntx0,ntx1,nty0,nty1);
      if (ny0>ny2) cimg::swap(nx0,nx2,ny0,ny2,ntx0,ntx2,nty0,nty2);
      if (ny1>ny2) cimg::swap(nx1,nx2,ny1,ny2,ntx1,ntx2,nty1,nty2);
      if (ny0>=height() || ny2<0) return *this;
      _cimg_for_triangle3(*this,xleft0,txleft0,tyleft0,xright0,txright0,tyright0,y,
                          nx0,ny0,ntx0,nty0,nx1,ny1,ntx1,nty1,nx2,ny2,ntx2,nty2) {
        int
          xleft = xleft0, xright = xright0,
          txleft = txleft0, txright = txright0,
          tyleft = tyleft0, tyright = tyright0;
        if (xright<xleft) cimg::swap(xleft,xright,txleft,txright,tyleft,tyright);
        const int
          dx = xright - xleft,
          dtx = txright>txleft?txright - txleft:txleft - txright,
          dty = tyright>tyleft?tyright - tyleft:tyleft - tyright,
          rtx = dx?(txright - txleft)/dx:0,
          rty = dx?(tyright - tyleft)/dx:0,
          stx = txright>txleft?1:-1,
          sty = tyright>tyleft?1:-1,
          ndtx = dtx - (dx?dx*(dtx/dx):0),
          ndty = dty - (dx?dx*(dty/dx):0);
        int errtx = dx>>1, errty = errtx;
        if (xleft<0 && dx) {
          txleft-=xleft*(txright - txleft)/dx;
          tyleft-=xleft*(tyright - tyleft)/dx;
        }
        if (xleft<0) xleft = 0;
        if (xright>=width()-1) xright = width()-1;
        T* ptrd = data(xleft,y,0,0);
        if (opacity>=1) {
          if (nbrightness==1) for (int x = xleft; x<=xright; ++x) {
            const tc *col = texture.data(txleft,tyleft);
            cimg_forC(*this,c) {
              *ptrd = (T)*col;
              ptrd+=whd; col+=twhd;
            }
            ptrd-=offx;
            txleft+=rtx+((errtx-=ndtx)<0?errtx+=dx,stx:0);
            tyleft+=rty+((errty-=ndty)<0?errty+=dx,sty:0);
          } else if (nbrightness<1) for (int x = xleft; x<=xright; ++x) {
            const tc *col = texture.data(txleft,tyleft);
            cimg_forC(*this,c) {
              *ptrd = (T)(nbrightness**col);
              ptrd+=whd; col+=twhd;
            }
            ptrd-=offx;
            txleft+=rtx+((errtx-=ndtx)<0?errtx+=dx,stx:0);
            tyleft+=rty+((errty-=ndty)<0?errty+=dx,sty:0);
          } else for (int x = xleft; x<=xright; ++x) {
            const tc *col = texture.data(txleft,tyleft);
            cimg_forC(*this,c) {
              *ptrd = (T)((2-nbrightness)**(col++) + (nbrightness-1)*maxval);
              ptrd+=whd; col+=twhd;
            }
            ptrd-=offx;
            txleft+=rtx+((errtx-=ndtx)<0?errtx+=dx,stx:0);
            tyleft+=rty+((errty-=ndty)<0?errty+=dx,sty:0);
          }
        } else {
          if (nbrightness==1) for (int x = xleft; x<=xright; ++x) {
            const tc *col = texture.data(txleft,tyleft);
            cimg_forC(*this,c) {
              *ptrd = (T)(nopacity**col + *ptrd*copacity);
              ptrd+=whd; col+=twhd;
            }
            ptrd-=offx;
            txleft+=rtx+((errtx-=ndtx)<0?errtx+=dx,stx:0);
            tyleft+=rty+((errty-=ndty)<0?errty+=dx,sty:0);
          } else if (nbrightness<1) for (int x = xleft; x<=xright; ++x) {
            const tc *col = texture.data(txleft,tyleft);
            cimg_forC(*this,c) {
              *ptrd = (T)(nopacity*nbrightness**col + *ptrd*copacity);
              ptrd+=whd; col+=twhd;
            }
            ptrd-=offx;
            txleft+=rtx+((errtx-=ndtx)<0?errtx+=dx,stx:0);
            tyleft+=rty+((errty-=ndty)<0?errty+=dx,sty:0);
          } else for (int x = xleft; x<=xright; ++x) {
            const tc *col = texture.data(txleft,tyleft);
            cimg_forC(*this,c) {
              const T val = (T)((2-nbrightness)**(col++) + (nbrightness-1)*maxval);
              *ptrd = (T)(nopacity*val + *ptrd*copacity);
              ptrd+=whd; col+=twhd;
            }
            ptrd-=offx;
            txleft+=rtx+((errtx-=ndtx)<0?errtx+=dx,stx:0);
            tyleft+=rty+((errty-=ndty)<0?errty+=dx,sty:0);
          }
        }
      }
      return *this;
    }

    //! Draw a 2d textured triangle, with perspective correction.
    template<typename tc>
    CImg<T>& draw_triangle(const int x0, const int y0, const float z0,
                           const int x1, const int y1, const float z1,
                           const int x2, const int y2, const float z2,
                           const CImg<tc>& texture,
                           const int tx0, const int ty0,
                           const int tx1, const int ty1,
                           const int tx2, const int ty2,
                           const float opacity=1,
                           const float brightness=1) {
      if (is_empty() || z0<=0 || z1<=0 || z2<=0) return *this;
      if (texture._depth>1 || texture._spectrum<_spectrum)
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Invalid specified texture (%u,%u,%u,%u,%p).",
                                    cimg_instance,
                                    texture._width,texture._height,texture._depth,texture._spectrum,texture._data);
      if (is_overlapped(texture)) return draw_triangle(x0,y0,z0,x1,y1,z1,x2,y2,z2,+texture,tx0,ty0,tx1,ty1,tx2,ty2,opacity,brightness);
      static const T maxval = (T)cimg::min(cimg::type<T>::max(),cimg::type<tc>::max());
      const float
        nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0),
        nbrightness = brightness<0?0:(brightness>2?2:brightness);
      const long whd = (long)_width*_height*_depth, twhd = (long)texture._width*texture._height*texture._depth, offx = _spectrum*whd-1;
      int nx0 = x0, ny0 = y0, nx1 = x1, ny1 = y1, nx2 = x2, ny2 = y2;
      float
        ntx0 = tx0/z0, nty0 = ty0/z0,
        ntx1 = tx1/z1, nty1 = ty1/z1,
        ntx2 = tx2/z2, nty2 = ty2/z2,
        nz0 = 1/z0, nz1 = 1/z1, nz2 = 1/z2;
      if (ny0>ny1) cimg::swap(nx0,nx1,ny0,ny1,ntx0,ntx1,nty0,nty1,nz0,nz1);
      if (ny0>ny2) cimg::swap(nx0,nx2,ny0,ny2,ntx0,ntx2,nty0,nty2,nz0,nz2);
      if (ny1>ny2) cimg::swap(nx1,nx2,ny1,ny2,ntx1,ntx2,nty1,nty2,nz1,nz2);
      if (ny0>=height() || ny2<0) return *this;
      float
        ptxl = (ntx1 - ntx0)/(ny1 - ny0),
        ptxr = (ntx2 - ntx0)/(ny2 - ny0),
        ptxn = (ntx2 - ntx1)/(ny2 - ny1),
        ptyl = (nty1 - nty0)/(ny1 - ny0),
        ptyr = (nty2 - nty0)/(ny2 - ny0),
        ptyn = (nty2 - nty1)/(ny2 - ny1),
        pzl = (nz1 - nz0)/(ny1 - ny0),
        pzr = (nz2 - nz0)/(ny2 - ny0),
        pzn = (nz2 - nz1)/(ny2 - ny1),
        zr = ny0>=0?nz0:(nz0 - ny0*(nz2 - nz0)/(ny2 - ny0)),
        txr = ny0>=0?ntx0:(ntx0 - ny0*(ntx2 - ntx0)/(ny2 - ny0)),
        tyr = ny0>=0?nty0:(nty0 - ny0*(nty2 - nty0)/(ny2 - ny0)),
        zl = ny1>=0?(ny0>=0?nz0:(nz0 - ny0*(nz1 - nz0)/(ny1 - ny0))):(pzl=pzn,(nz1 - ny1*(nz2 - nz1)/(ny2 - ny1))),
        txl = ny1>=0?(ny0>=0?ntx0:(ntx0 - ny0*(ntx1 - ntx0)/(ny1 - ny0))):(ptxl=ptxn,(ntx1 - ny1*(ntx2 - ntx1)/(ny2 - ny1))),
        tyl = ny1>=0?(ny0>=0?nty0:(nty0 - ny0*(nty1 - nty0)/(ny1 - ny0))):(ptyl=ptyn,(nty1 - ny1*(nty2 - nty1)/(ny2 - ny1)));
      _cimg_for_triangle1(*this,xleft0,xright0,y,nx0,ny0,nx1,ny1,nx2,ny2) {
        if (y==ny1) { zl = nz1; txl = ntx1; tyl = nty1; pzl = pzn; ptxl = ptxn; ptyl = ptyn; }
        int xleft = xleft0, xright = xright0;
        float
          zleft = zl, zright = zr,
          txleft = txl, txright = txr,
          tyleft = tyl, tyright = tyr;
        if (xright<xleft) cimg::swap(xleft,xright,zleft,zright,txleft,txright,tyleft,tyright);
        const int dx = xright - xleft;
        const float
          pentez = (zright - zleft)/dx,
          pentetx = (txright - txleft)/dx,
          pentety = (tyright - tyleft)/dx;
        if (xleft<0 && dx) {
          zleft-=xleft*(zright - zleft)/dx;
          txleft-=xleft*(txright - txleft)/dx;
          tyleft-=xleft*(tyright - tyleft)/dx;
        }
        if (xleft<0) xleft = 0;
        if (xright>=width()-1) xright = width()-1;
        T* ptrd = data(xleft,y,0,0);
        if (opacity>=1) {
          if (nbrightness==1) for (int x = xleft; x<=xright; ++x) {
            const float invz = 1/zleft;
            const tc *col = texture.data((int)(txleft*invz),(int)(tyleft*invz));
            cimg_forC(*this,c) {
              *ptrd = (T)*col;
              ptrd+=whd; col+=twhd;
            }
            ptrd-=offx; zleft+=pentez; txleft+=pentetx; tyleft+=pentety;
          } else if (nbrightness<1) for (int x=xleft; x<=xright; ++x) {
            const float invz = 1/zleft;
            const tc *col = texture.data((int)(txleft*invz),(int)(tyleft*invz));
            cimg_forC(*this,c) {
              *ptrd = (T)(nbrightness**col);
              ptrd+=whd; col+=twhd;
            }
            ptrd-=offx; zleft+=pentez; txleft+=pentetx; tyleft+=pentety;
          } else for (int x = xleft; x<=xright; ++x) {
            const float invz = 1/zleft;
            const tc *col = texture.data((int)(txleft*invz),(int)(tyleft*invz));
            cimg_forC(*this,c) {
              *ptrd = (T)((2-nbrightness)**col + (nbrightness-1)*maxval);
              ptrd+=whd; col+=twhd;
            }
            ptrd-=offx; zleft+=pentez; txleft+=pentetx; tyleft+=pentety;
          }
        } else {
          if (nbrightness==1) for (int x = xleft; x<=xright; ++x) {
            const float invz = 1/zleft;
            const tc *col = texture.data((int)(txleft*invz),(int)(tyleft*invz));
            cimg_forC(*this,c) {
              *ptrd = (T)(nopacity**col + *ptrd*copacity);
              ptrd+=whd; col+=twhd;
            }
            ptrd-=offx; zleft+=pentez; txleft+=pentetx; tyleft+=pentety;
          } else if (nbrightness<1) for (int x = xleft; x<=xright; ++x) {
            const float invz = 1/zleft;
            const tc *col = texture.data((int)(txleft*invz),(int)(tyleft*invz));
            cimg_forC(*this,c) {
              *ptrd = (T)(nopacity*nbrightness**col + *ptrd*copacity);
              ptrd+=whd; col+=twhd;
            }
            ptrd-=offx; zleft+=pentez; txleft+=pentetx; tyleft+=pentety;
          } else for (int x = xleft; x<=xright; ++x) {
            const float invz = 1/zleft;
            const tc *col = texture.data((int)(txleft*invz),(int)(tyleft*invz));
            cimg_forC(*this,c) {
              const T val = (T)((2-nbrightness)**col + (nbrightness-1)*maxval);
              *ptrd = (T)(nopacity*val + *ptrd*copacity);
              ptrd+=whd; col+=twhd;
            }
            ptrd-=offx; zleft+=pentez; txleft+=pentetx; tyleft+=pentety;
          }
        }
        zr+=pzr; txr+=ptxr; tyr+=ptyr; zl+=pzl; txl+=ptxl; tyl+=ptyl;
      }
      return *this;
    }

    //! Draw a textured 2d triangle, with perspective correction and z-buffering.
    template<typename tz, typename tc>
    CImg<T>& draw_triangle(CImg<tz>& zbuffer,
                           const int x0, const int y0, const float z0,
                           const int x1, const int y1, const float z1,
                           const int x2, const int y2, const float z2,
                           const CImg<tc>& texture,
                           const int tx0, const int ty0,
                           const int tx1, const int ty1,
                           const int tx2, const int ty2,
                           const float opacity=1,
                           const float brightness=1) {
      typedef typename cimg::superset<tz,float>::type tzfloat;
      if (is_empty() || z0<=0 || z1<=0 || z2<=0) return *this;
      if (!is_sameXY(zbuffer))
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Instance and specified Z-buffer (%u,%u,%u,%u,%p) have different dimensions.",
                                    cimg_instance,
                                    zbuffer._width,zbuffer._height,zbuffer._depth,zbuffer._spectrum,zbuffer._data);

      if (texture._depth>1 || texture._spectrum<_spectrum)
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Invalid specified texture (%u,%u,%u,%u,%p).",
                                    cimg_instance,
                                    texture._width,texture._height,texture._depth,texture._spectrum,texture._data);
      if (is_overlapped(texture)) return draw_triangle(zbuffer,x0,y0,z0,x1,y1,z1,x2,y2,z2,+texture,tx0,ty0,tx1,ty1,tx2,ty2,opacity,brightness);
      static const T maxval = (T)cimg::min(cimg::type<T>::max(),cimg::type<tc>::max());
      const float
        nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0),
        nbrightness = brightness<0?0:(brightness>2?2:brightness);
      const long whd = (long)_width*_height*_depth, twhd = (long)texture._width*texture._height*texture._depth, offx = _spectrum*whd;
      int nx0 = x0, ny0 = y0, nx1 = x1, ny1 = y1, nx2 = x2, ny2 = y2;
      float
        ntx0 = tx0/z0, nty0 = ty0/z0,
        ntx1 = tx1/z1, nty1 = ty1/z1,
        ntx2 = tx2/z2, nty2 = ty2/z2;
      tzfloat nz0 = 1/(tzfloat)z0, nz1 = 1/(tzfloat)z1, nz2 = 1/(tzfloat)z2;
      if (ny0>ny1) cimg::swap(nx0,nx1,ny0,ny1,ntx0,ntx1,nty0,nty1,nz0,nz1);
      if (ny0>ny2) cimg::swap(nx0,nx2,ny0,ny2,ntx0,ntx2,nty0,nty2,nz0,nz2);
      if (ny1>ny2) cimg::swap(nx1,nx2,ny1,ny2,ntx1,ntx2,nty1,nty2,nz1,nz2);
      if (ny0>=height() || ny2<0) return *this;
      float
        ptxl = (ntx1 - ntx0)/(ny1 - ny0),
        ptxr = (ntx2 - ntx0)/(ny2 - ny0),
        ptxn = (ntx2 - ntx1)/(ny2 - ny1),
        ptyl = (nty1 - nty0)/(ny1 - ny0),
        ptyr = (nty2 - nty0)/(ny2 - ny0),
        ptyn = (nty2 - nty1)/(ny2 - ny1),
        txr = ny0>=0?ntx0:(ntx0 - ny0*(ntx2 - ntx0)/(ny2 - ny0)),
        tyr = ny0>=0?nty0:(nty0 - ny0*(nty2 - nty0)/(ny2 - ny0)),
        txl = ny1>=0?(ny0>=0?ntx0:(ntx0 - ny0*(ntx1 - ntx0)/(ny1 - ny0))):(ptxl=ptxn,(ntx1 - ny1*(ntx2 - ntx1)/(ny2 - ny1))),
        tyl = ny1>=0?(ny0>=0?nty0:(nty0 - ny0*(nty1 - nty0)/(ny1 - ny0))):(ptyl=ptyn,(nty1 - ny1*(nty2 - nty1)/(ny2 - ny1)));
      tzfloat
        pzl = (nz1 - nz0)/(ny1 - ny0),
        pzr = (nz2 - nz0)/(ny2 - ny0),
        pzn = (nz2 - nz1)/(ny2 - ny1),
        zr = ny0>=0?nz0:(nz0 - ny0*(nz2 - nz0)/(ny2 - ny0)),
        zl = ny1>=0?(ny0>=0?nz0:(nz0 - ny0*(nz1 - nz0)/(ny1 - ny0))):(pzl=pzn,(nz1 - ny1*(nz2 - nz1)/(ny2 - ny1)));
      _cimg_for_triangle1(*this,xleft0,xright0,y,nx0,ny0,nx1,ny1,nx2,ny2) {
        if (y==ny1) { zl = nz1; txl = ntx1; tyl = nty1; pzl = pzn; ptxl = ptxn; ptyl = ptyn; }
        int xleft = xleft0, xright = xright0;
        float txleft = txl, txright = txr, tyleft = tyl, tyright = tyr;
        tzfloat zleft = zl, zright = zr;
        if (xright<xleft) cimg::swap(xleft,xright,zleft,zright,txleft,txright,tyleft,tyright);
        const int dx = xright - xleft;
        const float pentetx = (txright - txleft)/dx, pentety = (tyright - tyleft)/dx;
        const tzfloat pentez = (zright - zleft)/dx;
        if (xleft<0 && dx) {
          zleft-=xleft*(zright - zleft)/dx;
          txleft-=xleft*(txright - txleft)/dx;
          tyleft-=xleft*(tyright - tyleft)/dx;
        }
        if (xleft<0) xleft = 0;
        if (xright>=width()-1) xright = width()-1;
        T *ptrd = data(xleft,y,0,0);
        tz *ptrz = zbuffer.data(xleft,y);
        if (opacity>=1) {
          if (nbrightness==1) for (int x = xleft; x<=xright; ++x, ++ptrz, ++ptrd) {
              if (zleft>=(tzfloat)*ptrz) {
                *ptrz = (tz)zleft;
                const tzfloat invz = 1/zleft;
                const tc *col = texture.data((int)(txleft*invz),(int)(tyleft*invz));
                cimg_forC(*this,c) {
                  *ptrd = (T)*col;
                  ptrd+=whd; col+=twhd;
                }
                ptrd-=offx;
              }
              zleft+=pentez; txleft+=pentetx; tyleft+=pentety;
            } else if (nbrightness<1) for (int x = xleft; x<=xright; ++x, ++ptrz, ++ptrd) {
              if (zleft>=(tzfloat)*ptrz) {
                *ptrz = (tz)zleft;
                const tzfloat invz = 1/zleft;
                const tc *col = texture.data((int)(txleft*invz),(int)(tyleft*invz));
                cimg_forC(*this,c) {
                  *ptrd = (T)(nbrightness**col);
                  ptrd+=whd; col+=twhd;
                }
                ptrd-=offx;
              }
              zleft+=pentez; txleft+=pentetx; tyleft+=pentety;
            } else for (int x = xleft; x<=xright; ++x, ++ptrz, ++ptrd) {
              if (zleft>=(tzfloat)*ptrz) {
                *ptrz = (tz)zleft;
                const tzfloat invz = 1/zleft;
                const tc *col = texture.data((int)(txleft*invz),(int)(tyleft*invz));
                cimg_forC(*this,c) {
                  *ptrd = (T)((2-nbrightness)**col + (nbrightness-1)*maxval);
                  ptrd+=whd; col+=twhd;
                }
                ptrd-=offx;
              }
              zleft+=pentez; txleft+=pentetx; tyleft+=pentety;
            }
        } else {
          if (nbrightness==1) for (int x = xleft; x<=xright; ++x, ++ptrz, ++ptrd) {
              if (zleft>=(tzfloat)*ptrz) {
                *ptrz = (tz)zleft;
                const tzfloat invz = 1/zleft;
                const tc *col = texture.data((int)(txleft*invz),(int)(tyleft*invz));
                cimg_forC(*this,c) {
                  *ptrd = (T)(nopacity**col + *ptrd*copacity);
                  ptrd+=whd; col+=twhd;
                }
                ptrd-=offx;
              }
              zleft+=pentez; txleft+=pentetx; tyleft+=pentety;
            } else if (nbrightness<1) for (int x = xleft; x<=xright; ++x, ++ptrz, ++ptrd) {
              if (zleft>=(tzfloat)*ptrz) {
                *ptrz = (tz)zleft;
                const tzfloat invz = 1/zleft;
                const tc *col = texture.data((int)(txleft*invz),(int)(tyleft*invz));
                cimg_forC(*this,c) {
                  *ptrd = (T)(nopacity*nbrightness**col + *ptrd*copacity);
                  ptrd+=whd; col+=twhd;
                }
                ptrd-=offx;
              }
              zleft+=pentez; txleft+=pentetx; tyleft+=pentety;
            } else for (int x = xleft; x<=xright; ++x, ++ptrz, ++ptrd) {
              if (zleft>=(tzfloat)*ptrz) {
                *ptrz = (tz)zleft;
                const tzfloat invz = 1/zleft;
                const tc *col = texture.data((int)(txleft*invz),(int)(tyleft*invz));
                cimg_forC(*this,c) {
                  const T val = (T)((2-nbrightness)**col + (nbrightness-1)*maxval);
                  *ptrd = (T)(nopacity*val + *ptrd*copacity);
                  ptrd+=whd; col+=twhd;
                }
                ptrd-=offx;
              }
              zleft+=pentez; txleft+=pentetx; tyleft+=pentety;
            }
        }
        zr+=pzr; txr+=ptxr; tyr+=ptyr; zl+=pzl; txl+=ptxl; tyl+=ptyl;
      }
      return *this;
    }

    //! Draw a Phong-shaded 2d triangle.
    /**
       \param x0 X-coordinate of the first vertex in the image instance.
       \param y0 Y-coordinate of the first vertex in the image instance.
       \param x1 X-coordinate of the second vertex in the image instance.
       \param y1 Y-coordinate of the second vertex in the image instance.
       \param x2 X-coordinate of the third vertex in the image instance.
       \param y2 Y-coordinate of the third vertex in the image instance.
       \param color Pointer to \c spectrum() consecutive values, defining the drawing color.
       \param light Light image.
       \param lx0 X-coordinate of the first vertex in the light image.
       \param ly0 Y-coordinate of the first vertex in the light image.
       \param lx1 X-coordinate of the second vertex in the light image.
       \param ly1 Y-coordinate of the second vertex in the light image.
       \param lx2 X-coordinate of the third vertex in the light image.
       \param ly2 Y-coordinate of the third vertex in the light image.
       \param opacity Drawing opacity.
    **/
    template<typename tc, typename tl>
    CImg<T>& draw_triangle(const int x0, const int y0,
                           const int x1, const int y1,
                           const int x2, const int y2,
                           const tc *const color,
                           const CImg<tl>& light,
                           const int lx0, const int ly0,
                           const int lx1, const int ly1,
                           const int lx2, const int ly2,
                           const float opacity=1) {
      if (is_empty()) return *this;
      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Specified color is (null).",
                                    cimg_instance);
      if (light._depth>1 || light._spectrum<_spectrum)
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Invalid specified light texture (%u,%u,%u,%u,%p).",
                                    cimg_instance,light._width,light._height,light._depth,light._spectrum,light._data);
      if (is_overlapped(light)) return draw_triangle(x0,y0,x1,y1,x2,y2,color,+light,lx0,ly0,lx1,ly1,lx2,ly2,opacity);
      static const T maxval = (T)cimg::min(cimg::type<T>::max(),cimg::type<tc>::max());
      const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
      int nx0 = x0, ny0 = y0, nx1 = x1, ny1 = y1, nx2 = x2, ny2 = y2,
        nlx0 = lx0, nly0 = ly0, nlx1 = lx1, nly1 = ly1, nlx2 = lx2, nly2 = ly2;
      const long whd = (long)_width*_height*_depth, offx = _spectrum*whd-1;
      if (ny0>ny1) cimg::swap(nx0,nx1,ny0,ny1,nlx0,nlx1,nly0,nly1);
      if (ny0>ny2) cimg::swap(nx0,nx2,ny0,ny2,nlx0,nlx2,nly0,nly2);
      if (ny1>ny2) cimg::swap(nx1,nx2,ny1,ny2,nlx1,nlx2,nly1,nly2);
      if (ny0>=height() || ny2<0) return *this;
      _cimg_for_triangle3(*this,xleft0,lxleft0,lyleft0,xright0,lxright0,lyright0,y,
                          nx0,ny0,nlx0,nly0,nx1,ny1,nlx1,nly1,nx2,ny2,nlx2,nly2) {
        int
          xleft = xleft0, xright = xright0,
          lxleft = lxleft0, lxright = lxright0,
          lyleft = lyleft0, lyright = lyright0;
        if (xright<xleft) cimg::swap(xleft,xright,lxleft,lxright,lyleft,lyright);
        const int
          dx = xright - xleft,
          dlx = lxright>lxleft?lxright - lxleft:lxleft - lxright,
          dly = lyright>lyleft?lyright - lyleft:lyleft - lyright,
          rlx = dx?(lxright - lxleft)/dx:0,
          rly = dx?(lyright - lyleft)/dx:0,
          slx = lxright>lxleft?1:-1,
          sly = lyright>lyleft?1:-1,
          ndlx = dlx - (dx?dx*(dlx/dx):0),
          ndly = dly - (dx?dx*(dly/dx):0);
        int errlx = dx>>1, errly = errlx;
        if (xleft<0 && dx) {
          lxleft-=xleft*(lxright - lxleft)/dx;
          lyleft-=xleft*(lyright - lyleft)/dx;
        }
        if (xleft<0) xleft = 0;
        if (xright>=width()-1) xright = width()-1;
        T* ptrd = data(xleft,y,0,0);
        if (opacity>=1) for (int x = xleft; x<=xright; ++x) {
          const tc *col = color;
          cimg_forC(*this,c) {
            const tl l = light(lxleft,lyleft,c);
            *ptrd = (T)(l<1?l**(col++):((2-l)**(col++)+(l-1)*maxval));
            ptrd+=whd;
          }
          ptrd-=offx;
          lxleft+=rlx+((errlx-=ndlx)<0?errlx+=dx,slx:0);
          lyleft+=rly+((errly-=ndly)<0?errly+=dx,sly:0);
        } else  for (int x = xleft; x<=xright; ++x) {
          const tc *col = color;
          cimg_forC(*this,c) {
            const tl l = light(lxleft,lyleft,c);
            const T val = (T)(l<1?l**(col++):((2-l)**(col++)+(l-1)*maxval));
            *ptrd = (T)(nopacity*val + *ptrd*copacity);
            ptrd+=whd;
          }
          ptrd-=offx;
          lxleft+=rlx+((errlx-=ndlx)<0?errlx+=dx,slx:0);
          lyleft+=rly+((errly-=ndly)<0?errly+=dx,sly:0);
        }
      }
      return *this;
    }

    //! Draw a Phong-shaded 2d triangle, with z-buffering.
    template<typename tz, typename tc, typename tl>
    CImg<T>& draw_triangle(CImg<tz>& zbuffer,
                           const int x0, const int y0, const float z0,
                           const int x1, const int y1, const float z1,
                           const int x2, const int y2, const float z2,
                           const tc *const color,
                           const CImg<tl>& light,
                           const int lx0, const int ly0,
                           const int lx1, const int ly1,
                           const int lx2, const int ly2,
                           const float opacity=1) {
      typedef typename cimg::superset<tz,float>::type tzfloat;
      if (is_empty() || z0<=0 || z1<=0 || z2<=0) return *this;
      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Specified color is (null).",
                                    cimg_instance);
      if (light._depth>1 || light._spectrum<_spectrum)
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Invalid specified light texture (%u,%u,%u,%u,%p).",
                                    cimg_instance,light._width,light._height,light._depth,light._spectrum,light._data);
      if (!is_sameXY(zbuffer))
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Instance and specified Z-buffer (%u,%u,%u,%u,%p) have different dimensions.",
                                    cimg_instance,
                                    zbuffer._width,zbuffer._height,zbuffer._depth,zbuffer._spectrum,zbuffer._data);
      if (is_overlapped(light)) return draw_triangle(zbuffer,x0,y0,z0,x1,y1,z1,x2,y2,z2,color,
                                                     +light,lx0,ly0,lx1,ly1,lx2,ly2,opacity);
      static const T maxval = (T)cimg::min(cimg::type<T>::max(),cimg::type<tc>::max());
      const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
      const long whd = (long)_width*_height*_depth, offx = _spectrum*whd;
      int nx0 = x0, ny0 = y0, nx1 = x1, ny1 = y1, nx2 = x2, ny2 = y2,
        nlx0 = lx0, nly0 = ly0, nlx1 = lx1, nly1 = ly1, nlx2 = lx2, nly2 = ly2;
      tzfloat nz0 = 1/(tzfloat)z0, nz1 = 1/(tzfloat)z1, nz2 = 1/(tzfloat)z2;
      if (ny0>ny1) cimg::swap(nx0,nx1,ny0,ny1,nlx0,nlx1,nly0,nly1,nz0,nz1);
      if (ny0>ny2) cimg::swap(nx0,nx2,ny0,ny2,nlx0,nlx2,nly0,nly2,nz0,nz2);
      if (ny1>ny2) cimg::swap(nx1,nx2,ny1,ny2,nlx1,nlx2,nly1,nly2,nz1,nz2);
      if (ny0>=height() || ny2<0) return *this;
      tzfloat
        pzl = (nz1 - nz0)/(ny1 - ny0),
        pzr = (nz2 - nz0)/(ny2 - ny0),
        pzn = (nz2 - nz1)/(ny2 - ny1),
        zr = ny0>=0?nz0:(nz0 - ny0*(nz2 - nz0)/(ny2 - ny0)),
        zl = ny1>=0?(ny0>=0?nz0:(nz0 - ny0*(nz1 - nz0)/(ny1 - ny0))):(pzl=pzn,(nz1 - ny1*(nz2 - nz1)/(ny2 - ny1)));
      _cimg_for_triangle3(*this,xleft0,lxleft0,lyleft0,xright0,lxright0,lyright0,y,
                          nx0,ny0,nlx0,nly0,nx1,ny1,nlx1,nly1,nx2,ny2,nlx2,nly2) {
        if (y==ny1) { zl = nz1; pzl = pzn; }
        int
          xleft = xleft0, xright = xright0,
          lxleft = lxleft0, lxright = lxright0,
          lyleft = lyleft0, lyright = lyright0;
        tzfloat zleft = zl, zright = zr;
        if (xright<xleft) cimg::swap(xleft,xright,zleft,zright,lxleft,lxright,lyleft,lyright);
        const int
          dx = xright - xleft,
          dlx = lxright>lxleft?lxright - lxleft:lxleft - lxright,
          dly = lyright>lyleft?lyright - lyleft:lyleft - lyright,
          rlx = dx?(lxright - lxleft)/dx:0,
          rly = dx?(lyright - lyleft)/dx:0,
          slx = lxright>lxleft?1:-1,
          sly = lyright>lyleft?1:-1,
          ndlx = dlx - (dx?dx*(dlx/dx):0),
          ndly = dly - (dx?dx*(dly/dx):0);
        const tzfloat pentez = (zright - zleft)/dx;
        int errlx = dx>>1, errly = errlx;
        if (xleft<0 && dx) {
          zleft-=xleft*(zright - zleft)/dx;
          lxleft-=xleft*(lxright - lxleft)/dx;
          lyleft-=xleft*(lyright - lyleft)/dx;
        }
        if (xleft<0) xleft = 0;
        if (xright>=width()-1) xright = width()-1;
        T *ptrd = data(xleft,y,0,0);
        tz *ptrz = zbuffer.data(xleft,y);
        if (opacity>=1) for (int x = xleft; x<=xright; ++x, ++ptrz, ++ptrd) {
            if (zleft>=(tzfloat)*ptrz) {
              *ptrz = (tz)zleft;
              const tc *col = color;
              cimg_forC(*this,c) {
                const tl l = light(lxleft,lyleft,c);
                const tc cval = *(col++);
                *ptrd = (T)(l<1?l*cval:(2-l)*cval+(l-1)*maxval);
                ptrd+=whd;
              }
              ptrd-=offx;
            }
            zleft+=pentez;
            lxleft+=rlx+((errlx-=ndlx)<0?errlx+=dx,slx:0);
            lyleft+=rly+((errly-=ndly)<0?errly+=dx,sly:0);
          } else for (int x = xleft; x<=xright; ++x, ++ptrz, ++ptrd) {
            if (zleft>=(tzfloat)*ptrz) {
              *ptrz = (tz)zleft;
              const tc *col = color;
              cimg_forC(*this,c) {
                const tl l = light(lxleft,lyleft,c);
                const tc cval = *(col++);
                const T val = (T)(l<1?l*cval:(2-l)*cval+(l-1)*maxval);
                *ptrd = (T)(nopacity*val + *ptrd*copacity);
                ptrd+=whd;
              }
              ptrd-=offx;
            }
            zleft+=pentez;
            lxleft+=rlx+((errlx-=ndlx)<0?errlx+=dx,slx:0);
            lyleft+=rly+((errly-=ndly)<0?errly+=dx,sly:0);
          }
        zr+=pzr; zl+=pzl;
      }
      return *this;
    }

    //! Draw a textured Gouraud-shaded 2d triangle.
    /**
       \param x0 X-coordinate of the first vertex in the image instance.
       \param y0 Y-coordinate of the first vertex in the image instance.
       \param x1 X-coordinate of the second vertex in the image instance.
       \param y1 Y-coordinate of the second vertex in the image instance.
       \param x2 X-coordinate of the third vertex in the image instance.
       \param y2 Y-coordinate of the third vertex in the image instance.
       \param texture Texture image used to fill the triangle.
       \param tx0 X-coordinate of the first vertex in the texture image.
       \param ty0 Y-coordinate of the first vertex in the texture image.
       \param tx1 X-coordinate of the second vertex in the texture image.
       \param ty1 Y-coordinate of the second vertex in the texture image.
       \param tx2 X-coordinate of the third vertex in the texture image.
       \param ty2 Y-coordinate of the third vertex in the texture image.
       \param brightness0 Brightness factor of the first vertex.
       \param brightness1 Brightness factor of the second vertex.
       \param brightness2 Brightness factor of the third vertex.
       \param opacity Drawing opacity.
    **/
    template<typename tc>
    CImg<T>& draw_triangle(const int x0, const int y0,
                           const int x1, const int y1,
                           const int x2, const int y2,
                           const CImg<tc>& texture,
                           const int tx0, const int ty0,
                           const int tx1, const int ty1,
                           const int tx2, const int ty2,
                           const float brightness0,
                           const float brightness1,
                           const float brightness2,
                           const float opacity=1) {
      if (is_empty()) return *this;
      if (texture._depth>1 || texture._spectrum<_spectrum)
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Invalid specified texture (%u,%u,%u,%u,%p).",
                                    cimg_instance,
                                    texture._width,texture._height,texture._depth,texture._spectrum,texture._data);
      if (is_overlapped(texture))
        return draw_triangle(x0,y0,x1,y1,x2,y2,+texture,tx0,ty0,tx1,ty1,tx2,ty2,brightness0,brightness1,brightness2,opacity);
      static const T maxval = (T)cimg::min(cimg::type<T>::max(),cimg::type<tc>::max());
      const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
      const long whd = (long)_width*_height*_depth, twhd = (long)texture._width*texture._height*texture._depth, offx = _spectrum*whd-1;
      int nx0 = x0, ny0 = y0, nx1 = x1, ny1 = y1, nx2 = x2, ny2 = y2,
        ntx0 = tx0, nty0 = ty0, ntx1 = tx1, nty1 = ty1, ntx2 = tx2, nty2 = ty2,
        nc0 = (int)((brightness0<0.0f?0.0f:(brightness0>2.0f?2.0f:brightness0))*256.0f),
        nc1 = (int)((brightness1<0.0f?0.0f:(brightness1>2.0f?2.0f:brightness1))*256.0f),
        nc2 = (int)((brightness2<0.0f?0.0f:(brightness2>2.0f?2.0f:brightness2))*256.0f);
      if (ny0>ny1) cimg::swap(nx0,nx1,ny0,ny1,ntx0,ntx1,nty0,nty1,nc0,nc1);
      if (ny0>ny2) cimg::swap(nx0,nx2,ny0,ny2,ntx0,ntx2,nty0,nty2,nc0,nc2);
      if (ny1>ny2) cimg::swap(nx1,nx2,ny1,ny2,ntx1,ntx2,nty1,nty2,nc1,nc2);
      if (ny0>=height() || ny2<0) return *this;
      _cimg_for_triangle4(*this,xleft0,cleft0,txleft0,tyleft0,xright0,cright0,txright0,tyright0,y,
                          nx0,ny0,nc0,ntx0,nty0,nx1,ny1,nc1,ntx1,nty1,nx2,ny2,nc2,ntx2,nty2) {
        int
          xleft = xleft0, xright = xright0,
          cleft = cleft0, cright = cright0,
          txleft = txleft0, txright = txright0,
          tyleft = tyleft0, tyright = tyright0;
        if (xright<xleft) cimg::swap(xleft,xright,cleft,cright,txleft,txright,tyleft,tyright);
        const int
          dx = xright - xleft,
          dc = cright>cleft?cright - cleft:cleft - cright,
          dtx = txright>txleft?txright - txleft:txleft - txright,
          dty = tyright>tyleft?tyright - tyleft:tyleft - tyright,
          rc = dx?(cright - cleft)/dx:0,
          rtx = dx?(txright - txleft)/dx:0,
          rty = dx?(tyright - tyleft)/dx:0,
          sc = cright>cleft?1:-1,
          stx = txright>txleft?1:-1,
          sty = tyright>tyleft?1:-1,
          ndc = dc - (dx?dx*(dc/dx):0),
          ndtx = dtx - (dx?dx*(dtx/dx):0),
          ndty = dty - (dx?dx*(dty/dx):0);
        int errc = dx>>1, errtx = errc, errty = errc;
        if (xleft<0 && dx) {
          cleft-=xleft*(cright - cleft)/dx;
          txleft-=xleft*(txright - txleft)/dx;
          tyleft-=xleft*(tyright - tyleft)/dx;
        }
        if (xleft<0) xleft = 0;
        if (xright>=width()-1) xright = width()-1;
        T* ptrd = data(xleft,y,0,0);
        if (opacity>=1) for (int x = xleft; x<=xright; ++x) {
          const tc *col = texture.data(txleft,tyleft);
          cimg_forC(*this,c) {
            *ptrd = (T)(cleft<256?cleft**col/256:((512-cleft)**col+(cleft-256)*maxval)/256);
            ptrd+=whd; col+=twhd;
          }
          ptrd-=offx;
          cleft+=rc+((errc-=ndc)<0?errc+=dx,sc:0);
          txleft+=rtx+((errtx-=ndtx)<0?errtx+=dx,stx:0);
          tyleft+=rty+((errty-=ndty)<0?errty+=dx,sty:0);
        } else for (int x = xleft; x<=xright; ++x) {
          const tc *col = texture.data(txleft,tyleft);
          cimg_forC(*this,c) {
            const T val = (T)(cleft<256?cleft**col/256:((512-cleft)**col+(cleft-256)*maxval)/256);
            *ptrd = (T)(nopacity*val + *ptrd*copacity);
            ptrd+=whd; col+=twhd;
          }
          ptrd-=offx;
          cleft+=rc+((errc-=ndc)<0?errc+=dx,sc:0);
          txleft+=rtx+((errtx-=ndtx)<0?errtx+=dx,stx:0);
          tyleft+=rty+((errty-=ndty)<0?errty+=dx,sty:0);
        }
      }
      return *this;
    }

    //! Draw a textured Gouraud-shaded 2d triangle, with perspective correction \overloading.
    template<typename tc>
    CImg<T>& draw_triangle(const int x0, const int y0, const float z0,
                           const int x1, const int y1, const float z1,
                           const int x2, const int y2, const float z2,
                           const CImg<tc>& texture,
                           const int tx0, const int ty0,
                           const int tx1, const int ty1,
                           const int tx2, const int ty2,
                           const float brightness0,
                           const float brightness1,
                           const float brightness2,
                           const float opacity=1) {
      if (is_empty() || z0<=0 || z1<=0 || z2<=0) return *this;
      if (texture._depth>1 || texture._spectrum<_spectrum)
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Invalid specified texture (%u,%u,%u,%u,%p).",
                                    cimg_instance,
                                    texture._width,texture._height,texture._depth,texture._spectrum,texture._data);
      if (is_overlapped(texture)) return draw_triangle(x0,y0,z0,x1,y1,z1,x2,y2,z2,+texture,tx0,ty0,tx1,ty1,tx2,ty2,
                                                       brightness0,brightness1,brightness2,opacity);
      static const T maxval = (T)cimg::min(cimg::type<T>::max(),cimg::type<tc>::max());
      const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
      const long whd = (long)_width*_height*_depth, twhd = (long)texture._width*texture._height*texture._depth, offx = _spectrum*whd-1;
      int nx0 = x0, ny0 = y0, nx1 = x1, ny1 = y1, nx2 = x2, ny2 = y2,
        nc0 = (int)((brightness0<0.0f?0.0f:(brightness0>2.0f?2.0f:brightness0))*256.0f),
        nc1 = (int)((brightness1<0.0f?0.0f:(brightness1>2.0f?2.0f:brightness1))*256.0f),
        nc2 = (int)((brightness2<0.0f?0.0f:(brightness2>2.0f?2.0f:brightness2))*256.0f);
      float
        ntx0 = tx0/z0, nty0 = ty0/z0,
        ntx1 = tx1/z1, nty1 = ty1/z1,
        ntx2 = tx2/z2, nty2 = ty2/z2,
        nz0 = 1/z0, nz1 = 1/z1, nz2 = 1/z2;
      if (ny0>ny1) cimg::swap(nx0,nx1,ny0,ny1,ntx0,ntx1,nty0,nty1,nz0,nz1,nc0,nc1);
      if (ny0>ny2) cimg::swap(nx0,nx2,ny0,ny2,ntx0,ntx2,nty0,nty2,nz0,nz2,nc0,nc2);
      if (ny1>ny2) cimg::swap(nx1,nx2,ny1,ny2,ntx1,ntx2,nty1,nty2,nz1,nz2,nc1,nc2);
      if (ny0>=height() || ny2<0) return *this;
      float
        ptxl = (ntx1 - ntx0)/(ny1 - ny0),
        ptxr = (ntx2 - ntx0)/(ny2 - ny0),
        ptxn = (ntx2 - ntx1)/(ny2 - ny1),
        ptyl = (nty1 - nty0)/(ny1 - ny0),
        ptyr = (nty2 - nty0)/(ny2 - ny0),
        ptyn = (nty2 - nty1)/(ny2 - ny1),
        pzl = (nz1 - nz0)/(ny1 - ny0),
        pzr = (nz2 - nz0)/(ny2 - ny0),
        pzn = (nz2 - nz1)/(ny2 - ny1),
        zr = ny0>=0?nz0:(nz0 - ny0*(nz2 - nz0)/(ny2 - ny0)),
        txr = ny0>=0?ntx0:(ntx0 - ny0*(ntx2 - ntx0)/(ny2 - ny0)),
        tyr = ny0>=0?nty0:(nty0 - ny0*(nty2 - nty0)/(ny2 - ny0)),
        zl = ny1>=0?(ny0>=0?nz0:(nz0 - ny0*(nz1 - nz0)/(ny1 - ny0))):(pzl=pzn,(nz1 - ny1*(nz2 - nz1)/(ny2 - ny1))),
        txl = ny1>=0?(ny0>=0?ntx0:(ntx0 - ny0*(ntx1 - ntx0)/(ny1 - ny0))):(ptxl=ptxn,(ntx1 - ny1*(ntx2 - ntx1)/(ny2 - ny1))),
        tyl = ny1>=0?(ny0>=0?nty0:(nty0 - ny0*(nty1 - nty0)/(ny1 - ny0))):(ptyl=ptyn,(nty1 - ny1*(nty2 - nty1)/(ny2 - ny1)));
      _cimg_for_triangle2(*this,xleft0,cleft0,xright0,cright0,y,nx0,ny0,nc0,nx1,ny1,nc1,nx2,ny2,nc2) {
        if (y==ny1) { zl = nz1; txl = ntx1; tyl = nty1; pzl = pzn; ptxl = ptxn; ptyl = ptyn; }
        int
          xleft = xleft0, xright = xright0,
          cleft = cleft0, cright = cright0;
        float
          zleft = zl, zright = zr,
          txleft = txl, txright = txr,
          tyleft = tyl, tyright = tyr;
        if (xright<xleft) cimg::swap(xleft,xright,zleft,zright,txleft,txright,tyleft,tyright,cleft,cright);
        const int
          dx = xright - xleft,
          dc = cright>cleft?cright - cleft:cleft - cright,
          rc = dx?(cright - cleft)/dx:0,
          sc = cright>cleft?1:-1,
          ndc = dc - (dx?dx*(dc/dx):0);
        const float
          pentez = (zright - zleft)/dx,
          pentetx = (txright - txleft)/dx,
          pentety = (tyright - tyleft)/dx;
        int errc = dx>>1;
        if (xleft<0 && dx) {
          cleft-=xleft*(cright - cleft)/dx;
          zleft-=xleft*(zright - zleft)/dx;
          txleft-=xleft*(txright - txleft)/dx;
          tyleft-=xleft*(tyright - tyleft)/dx;
        }
        if (xleft<0) xleft = 0;
        if (xright>=width()-1) xright = width()-1;
        T* ptrd = data(xleft,y,0,0);
        if (opacity>=1) for (int x = xleft; x<=xright; ++x) {
          const float invz = 1/zleft;
          const tc *col = texture.data((int)(txleft*invz),(int)(tyleft*invz));
          cimg_forC(*this,c) {
            *ptrd = (T)(cleft<256?cleft**col/256:((512-cleft)**col+(cleft-256)*maxval)/256);
            ptrd+=whd; col+=twhd;
          }
          ptrd-=offx; zleft+=pentez; txleft+=pentetx; tyleft+=pentety;
          cleft+=rc+((errc-=ndc)<0?errc+=dx,sc:0);
        } else for (int x = xleft; x<=xright; ++x) {
          const float invz = 1/zleft;
          const tc *col = texture.data((int)(txleft*invz),(int)(tyleft*invz));
          cimg_forC(*this,c) {
            const T val = (T)(cleft<256?cleft**col/256:((512-cleft)**col+(cleft-256)*maxval)/256);
            *ptrd = (T)(nopacity*val + *ptrd*copacity);
            ptrd+=whd; col+=twhd;
          }
          ptrd-=offx; zleft+=pentez; txleft+=pentetx; tyleft+=pentety;
          cleft+=rc+((errc-=ndc)<0?errc+=dx,sc:0);
        }
        zr+=pzr; txr+=ptxr; tyr+=ptyr; zl+=pzl; txl+=ptxl; tyl+=ptyl;
      }
      return *this;
    }

    //! Draw a textured Gouraud-shaded 2d triangle, with perspective correction and z-buffering \overloading.
    template<typename tz, typename tc>
    CImg<T>& draw_triangle(CImg<tz>& zbuffer,
                           const int x0, const int y0, const float z0,
                           const int x1, const int y1, const float z1,
                           const int x2, const int y2, const float z2,
                           const CImg<tc>& texture,
                           const int tx0, const int ty0,
                           const int tx1, const int ty1,
                           const int tx2, const int ty2,
                           const float brightness0,
                           const float brightness1,
                           const float brightness2,
                           const float opacity=1) {
      typedef typename cimg::superset<tz,float>::type tzfloat;
      if (is_empty() || z0<=0 || z1<=0 || z2<=0) return *this;
      if (!is_sameXY(zbuffer))
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Instance and specified Z-buffer (%u,%u,%u,%u,%p) have different dimensions.",
                                    cimg_instance,
                                    zbuffer._width,zbuffer._height,zbuffer._depth,zbuffer._spectrum,zbuffer._data);
      if (texture._depth>1 || texture._spectrum<_spectrum)
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Invalid specified texture (%u,%u,%u,%u,%p).",
                                    cimg_instance,
                                    texture._width,texture._height,texture._depth,texture._spectrum,texture._data);
      if (is_overlapped(texture)) return draw_triangle(zbuffer,x0,y0,z0,x1,y1,z1,x2,y2,z2,+texture,tx0,ty0,tx1,ty1,tx2,ty2,
                                                       brightness0,brightness1,brightness2,opacity);
      static const T maxval = (T)cimg::min(cimg::type<T>::max(),cimg::type<tc>::max());
      const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
      const long whd = (long)_width*_height*_depth, twhd = (long)texture._width*texture._height*texture._depth, offx = _spectrum*whd;
      int nx0 = x0, ny0 = y0, nx1 = x1, ny1 = y1, nx2 = x2, ny2 = y2,
        nc0 = (int)((brightness0<0.0f?0.0f:(brightness0>2.0f?2.0f:brightness0))*256.0f),
        nc1 = (int)((brightness1<0.0f?0.0f:(brightness1>2.0f?2.0f:brightness1))*256.0f),
        nc2 = (int)((brightness2<0.0f?0.0f:(brightness2>2.0f?2.0f:brightness2))*256.0f);
      float
        ntx0 = tx0/z0, nty0 = ty0/z0,
        ntx1 = tx1/z1, nty1 = ty1/z1,
        ntx2 = tx2/z2, nty2 = ty2/z2;
      tzfloat nz0 = 1/(tzfloat)z0, nz1 = 1/(tzfloat)z1, nz2 = 1/(tzfloat)z2;
      if (ny0>ny1) cimg::swap(nx0,nx1,ny0,ny1,ntx0,ntx1,nty0,nty1,nz0,nz1,nc0,nc1);
      if (ny0>ny2) cimg::swap(nx0,nx2,ny0,ny2,ntx0,ntx2,nty0,nty2,nz0,nz2,nc0,nc2);
      if (ny1>ny2) cimg::swap(nx1,nx2,ny1,ny2,ntx1,ntx2,nty1,nty2,nz1,nz2,nc1,nc2);
      if (ny0>=height() || ny2<0) return *this;
      float
        ptxl = (ntx1 - ntx0)/(ny1 - ny0),
        ptxr = (ntx2 - ntx0)/(ny2 - ny0),
        ptxn = (ntx2 - ntx1)/(ny2 - ny1),
        ptyl = (nty1 - nty0)/(ny1 - ny0),
        ptyr = (nty2 - nty0)/(ny2 - ny0),
        ptyn = (nty2 - nty1)/(ny2 - ny1),
        txr = ny0>=0?ntx0:(ntx0 - ny0*(ntx2 - ntx0)/(ny2 - ny0)),
        tyr = ny0>=0?nty0:(nty0 - ny0*(nty2 - nty0)/(ny2 - ny0)),
        txl = ny1>=0?(ny0>=0?ntx0:(ntx0 - ny0*(ntx1 - ntx0)/(ny1 - ny0))):(ptxl=ptxn,(ntx1 - ny1*(ntx2 - ntx1)/(ny2 - ny1))),
        tyl = ny1>=0?(ny0>=0?nty0:(nty0 - ny0*(nty1 - nty0)/(ny1 - ny0))):(ptyl=ptyn,(nty1 - ny1*(nty2 - nty1)/(ny2 - ny1)));
      tzfloat
        pzl = (nz1 - nz0)/(ny1 - ny0),
        pzr = (nz2 - nz0)/(ny2 - ny0),
        pzn = (nz2 - nz1)/(ny2 - ny1),
        zr = ny0>=0?nz0:(nz0 - ny0*(nz2 - nz0)/(ny2 - ny0)),
        zl = ny1>=0?(ny0>=0?nz0:(nz0 - ny0*(nz1 - nz0)/(ny1 - ny0))):(pzl=pzn,(nz1 - ny1*(nz2 - nz1)/(ny2 - ny1)));
      _cimg_for_triangle2(*this,xleft0,cleft0,xright0,cright0,y,nx0,ny0,nc0,nx1,ny1,nc1,nx2,ny2,nc2) {
        if (y==ny1) { zl = nz1; txl = ntx1; tyl = nty1; pzl = pzn; ptxl = ptxn; ptyl = ptyn; }
        int xleft = xleft0, xright = xright0, cleft = cleft0, cright = cright0;
        float txleft = txl, txright = txr, tyleft = tyl, tyright = tyr;
        tzfloat zleft = zl, zright = zr;
        if (xright<xleft) cimg::swap(xleft,xright,zleft,zright,txleft,txright,tyleft,tyright,cleft,cright);
        const int
          dx = xright - xleft,
          dc = cright>cleft?cright - cleft:cleft - cright,
          rc = dx?(cright - cleft)/dx:0,
          sc = cright>cleft?1:-1,
          ndc = dc - (dx?dx*(dc/dx):0);
        float pentetx = (txright - txleft)/dx, pentety = (tyright - tyleft)/dx;
        const tzfloat pentez = (zright - zleft)/dx;
        int errc = dx>>1;
        if (xleft<0 && dx) {
          cleft-=xleft*(cright - cleft)/dx;
          zleft-=xleft*(zright - zleft)/dx;
          txleft-=xleft*(txright - txleft)/dx;
          tyleft-=xleft*(tyright - tyleft)/dx;
        }
        if (xleft<0) xleft = 0;
        if (xright>=width()-1) xright = width()-1;
        T* ptrd = data(xleft,y);
        tz *ptrz = zbuffer.data(xleft,y);
        if (opacity>=1) for (int x = xleft; x<=xright; ++x, ++ptrd, ++ptrz) {
            if (zleft>=(tzfloat)*ptrz) {
              *ptrz = (tz)zleft;
              const tzfloat invz = 1/zleft;
              const tc *col = texture.data((int)(txleft*invz),(int)(tyleft*invz));
              cimg_forC(*this,c) {
                *ptrd = (T)(cleft<256?cleft**col/256:((512-cleft)**col+(cleft-256)*maxval)/256);
                ptrd+=whd; col+=twhd;
              }
              ptrd-=offx;
            }
            zleft+=pentez; txleft+=pentetx; tyleft+=pentety;
            cleft+=rc+((errc-=ndc)<0?errc+=dx,sc:0);
          } else for (int x = xleft; x<=xright; ++x, ++ptrd, ++ptrz) {
            if (zleft>=(tzfloat)*ptrz) {
              *ptrz = (tz)zleft;
              const tzfloat invz = 1/zleft;
              const tc *col = texture.data((int)(txleft*invz),(int)(tyleft*invz));
              cimg_forC(*this,c) {
                const T val = (T)(cleft<256?cleft**col/256:((512-cleft)**col+(cleft-256)*maxval)/256);
                *ptrd = (T)(nopacity*val + *ptrd*copacity);
                ptrd+=whd; col+=twhd;
              }
              ptrd-=offx;
            }
            zleft+=pentez; txleft+=pentetx; tyleft+=pentety;
            cleft+=rc+((errc-=ndc)<0?errc+=dx,sc:0);
          }
        zr+=pzr; txr+=ptxr; tyr+=ptyr; zl+=pzl; txl+=ptxl; tyl+=ptyl;
      }
      return *this;
    }

    //! Draw a textured Phong-shaded 2d triangle.
    /**
       \param x0 X-coordinate of the first vertex in the image instance.
       \param y0 Y-coordinate of the first vertex in the image instance.
       \param x1 X-coordinate of the second vertex in the image instance.
       \param y1 Y-coordinate of the second vertex in the image instance.
       \param x2 X-coordinate of the third vertex in the image instance.
       \param y2 Y-coordinate of the third vertex in the image instance.
       \param texture Texture image used to fill the triangle.
       \param tx0 X-coordinate of the first vertex in the texture image.
       \param ty0 Y-coordinate of the first vertex in the texture image.
       \param tx1 X-coordinate of the second vertex in the texture image.
       \param ty1 Y-coordinate of the second vertex in the texture image.
       \param tx2 X-coordinate of the third vertex in the texture image.
       \param ty2 Y-coordinate of the third vertex in the texture image.
       \param light Light image.
       \param lx0 X-coordinate of the first vertex in the light image.
       \param ly0 Y-coordinate of the first vertex in the light image.
       \param lx1 X-coordinate of the second vertex in the light image.
       \param ly1 Y-coordinate of the second vertex in the light image.
       \param lx2 X-coordinate of the third vertex in the light image.
       \param ly2 Y-coordinate of the third vertex in the light image.
       \param opacity Drawing opacity.
    **/
    template<typename tc, typename tl>
    CImg<T>& draw_triangle(const int x0, const int y0,
                           const int x1, const int y1,
                           const int x2, const int y2,
                           const CImg<tc>& texture,
                           const int tx0, const int ty0,
                           const int tx1, const int ty1,
                           const int tx2, const int ty2,
                           const CImg<tl>& light,
                           const int lx0, const int ly0,
                           const int lx1, const int ly1,
                           const int lx2, const int ly2,
                           const float opacity=1) {
      if (is_empty()) return *this;
      if (texture._depth>1 || texture._spectrum<_spectrum)
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Invalid specified texture (%u,%u,%u,%u,%p).",
                                    cimg_instance,
                                    texture._width,texture._height,texture._depth,texture._spectrum,texture._data);
      if (light._depth>1 || light._spectrum<_spectrum)
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Invalid specified light texture (%u,%u,%u,%u,%p).",
                                    cimg_instance,light._width,light._height,light._depth,light._spectrum,light._data);
      if (is_overlapped(texture)) return draw_triangle(x0,y0,x1,y1,x2,y2,+texture,tx0,ty0,tx1,ty1,tx2,ty2,light,lx0,ly0,lx1,ly1,lx2,ly2,opacity);
      if (is_overlapped(light))   return draw_triangle(x0,y0,x1,y1,x2,y2,texture,tx0,ty0,tx1,ty1,tx2,ty2,+light,lx0,ly0,lx1,ly1,lx2,ly2,opacity);
      static const T maxval = (T)cimg::min(cimg::type<T>::max(),cimg::type<tc>::max());
      const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
      const long whd = (long)_width*_height*_depth, twhd = (long)texture._width*texture._height*texture._depth, offx = _spectrum*whd-1;
      int nx0 = x0, ny0 = y0, nx1 = x1, ny1 = y1, nx2 = x2, ny2 = y2,
        ntx0 = tx0, nty0 = ty0, ntx1 = tx1, nty1 = ty1, ntx2 = tx2, nty2 = ty2,
        nlx0 = lx0, nly0 = ly0, nlx1 = lx1, nly1 = ly1, nlx2 = lx2, nly2 = ly2;
      if (ny0>ny1) cimg::swap(nx0,nx1,ny0,ny1,ntx0,ntx1,nty0,nty1,nlx0,nlx1,nly0,nly1);
      if (ny0>ny2) cimg::swap(nx0,nx2,ny0,ny2,ntx0,ntx2,nty0,nty2,nlx0,nlx2,nly0,nly2);
      if (ny1>ny2) cimg::swap(nx1,nx2,ny1,ny2,ntx1,ntx2,nty1,nty2,nlx1,nlx2,nly1,nly2);
      if (ny0>=height() || ny2<0) return *this;
      _cimg_for_triangle5(*this,xleft0,lxleft0,lyleft0,txleft0,tyleft0,xright0,lxright0,lyright0,txright0,tyright0,y,
                          nx0,ny0,nlx0,nly0,ntx0,nty0,nx1,ny1,nlx1,nly1,ntx1,nty1,nx2,ny2,nlx2,nly2,ntx2,nty2) {
        int
          xleft = xleft0, xright = xright0,
          lxleft = lxleft0, lxright = lxright0,
          lyleft = lyleft0, lyright = lyright0,
          txleft = txleft0, txright = txright0,
          tyleft = tyleft0, tyright = tyright0;
        if (xright<xleft) cimg::swap(xleft,xright,lxleft,lxright,lyleft,lyright,txleft,txright,tyleft,tyright);
        const int
          dx = xright - xleft,
          dlx = lxright>lxleft?lxright - lxleft:lxleft - lxright,
          dly = lyright>lyleft?lyright - lyleft:lyleft - lyright,
          dtx = txright>txleft?txright - txleft:txleft - txright,
          dty = tyright>tyleft?tyright - tyleft:tyleft - tyright,
          rlx = dx?(lxright - lxleft)/dx:0,
          rly = dx?(lyright - lyleft)/dx:0,
          rtx = dx?(txright - txleft)/dx:0,
          rty = dx?(tyright - tyleft)/dx:0,
          slx = lxright>lxleft?1:-1,
          sly = lyright>lyleft?1:-1,
          stx = txright>txleft?1:-1,
          sty = tyright>tyleft?1:-1,
          ndlx = dlx - (dx?dx*(dlx/dx):0),
          ndly = dly - (dx?dx*(dly/dx):0),
          ndtx = dtx - (dx?dx*(dtx/dx):0),
          ndty = dty - (dx?dx*(dty/dx):0);
        int errlx = dx>>1, errly = errlx, errtx = errlx, errty = errlx;
        if (xleft<0 && dx) {
          lxleft-=xleft*(lxright - lxleft)/dx;
          lyleft-=xleft*(lyright - lyleft)/dx;
          txleft-=xleft*(txright - txleft)/dx;
          tyleft-=xleft*(tyright - tyleft)/dx;
        }
        if (xleft<0) xleft = 0;
        if (xright>=width()-1) xright = width()-1;
        T* ptrd = data(xleft,y,0,0);
        if (opacity>=1) for (int x = xleft; x<=xright; ++x) {
          const tc *col = texture.data(txleft,tyleft);
          cimg_forC(*this,c) {
            const tl l = light(lxleft,lyleft,c);
            *ptrd = (T)(l<1?l**col:(2-l)**col+(l-1)*maxval);
            ptrd+=whd; col+=twhd;
          }
          ptrd-=offx;
          lxleft+=rlx+((errlx-=ndlx)<0?errlx+=dx,slx:0);
          lyleft+=rly+((errly-=ndly)<0?errly+=dx,sly:0);
          txleft+=rtx+((errtx-=ndtx)<0?errtx+=dx,stx:0);
          tyleft+=rty+((errty-=ndty)<0?errty+=dx,sty:0);
        } else for (int x = xleft; x<=xright; ++x) {
          const tc *col = texture.data(txleft,tyleft);
          cimg_forC(*this,c) {
            const tl l = light(lxleft,lyleft,c);
            const T val = (T)(l<1?l**col:(2-l)**col+(l-1)*maxval);
            *ptrd = (T)(nopacity*val + *ptrd*copacity);
            ptrd+=whd; col+=twhd;
          }
          ptrd-=offx;
          lxleft+=rlx+((errlx-=ndlx)<0?errlx+=dx,slx:0);
          lyleft+=rly+((errly-=ndly)<0?errly+=dx,sly:0);
          txleft+=rtx+((errtx-=ndtx)<0?errtx+=dx,stx:0);
          tyleft+=rty+((errty-=ndty)<0?errty+=dx,sty:0);
        }
      }
      return *this;
    }

    //! Draw a textured Phong-shaded 2d triangle, with perspective correction.
    template<typename tc, typename tl>
    CImg<T>& draw_triangle(const int x0, const int y0, const float z0,
                           const int x1, const int y1, const float z1,
                           const int x2, const int y2, const float z2,
                           const CImg<tc>& texture,
                           const int tx0, const int ty0,
                           const int tx1, const int ty1,
                           const int tx2, const int ty2,
                           const CImg<tl>& light,
                           const int lx0, const int ly0,
                           const int lx1, const int ly1,
                           const int lx2, const int ly2,
                           const float opacity=1) {
      if (is_empty() || z0<=0 || z1<=0 || z2<=0) return *this;
      if (texture._depth>1 || texture._spectrum<_spectrum)
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Invalid specified texture (%u,%u,%u,%u,%p).",
                                    cimg_instance,
                                    texture._width,texture._height,texture._depth,texture._spectrum,texture._data);
      if (light._depth>1 || light._spectrum<_spectrum)
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Invalid specified light texture (%u,%u,%u,%u,%p).",
                                    cimg_instance,light._width,light._height,light._depth,light._spectrum,light._data);
      if (is_overlapped(texture)) return draw_triangle(x0,y0,z0,x1,y1,z1,x2,y2,z2,+texture,tx0,ty0,tx1,ty1,tx2,ty2,light,lx0,ly0,lx1,ly1,lx2,ly2,opacity);
      if (is_overlapped(light)) return draw_triangle(x0,y0,z0,x1,y1,z1,x2,y2,z2,texture,tx0,ty0,tx1,ty1,tx2,ty2,+light,lx0,ly0,lx1,ly1,lx2,ly2,opacity);
      static const T maxval = (T)cimg::min(cimg::type<T>::max(),cimg::type<tc>::max());
      const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
      const long whd = (long)_width*_height*_depth, twhd = (long)texture._width*texture._height*texture._depth, offx = _spectrum*whd-1;
      int nx0 = x0, ny0 = y0, nx1 = x1, ny1 = y1, nx2 = x2, ny2 = y2,
        nlx0 = lx0, nly0 = ly0, nlx1 = lx1, nly1 = ly1, nlx2 = lx2, nly2 = ly2;
      float
        ntx0 = tx0/z0, nty0 = ty0/z0,
        ntx1 = tx1/z1, nty1 = ty1/z1,
        ntx2 = tx2/z2, nty2 = ty2/z2,
        nz0 = 1/z0, nz1 = 1/z1, nz2 = 1/z2;
      if (ny0>ny1) cimg::swap(nx0,nx1,ny0,ny1,ntx0,ntx1,nty0,nty1,nlx0,nlx1,nly0,nly1,nz0,nz1);
      if (ny0>ny2) cimg::swap(nx0,nx2,ny0,ny2,ntx0,ntx2,nty0,nty2,nlx0,nlx2,nly0,nly2,nz0,nz2);
      if (ny1>ny2) cimg::swap(nx1,nx2,ny1,ny2,ntx1,ntx2,nty1,nty2,nlx1,nlx2,nly1,nly2,nz1,nz2);
      if (ny0>=height() || ny2<0) return *this;
      float
        ptxl = (ntx1 - ntx0)/(ny1 - ny0),
        ptxr = (ntx2 - ntx0)/(ny2 - ny0),
        ptxn = (ntx2 - ntx1)/(ny2 - ny1),
        ptyl = (nty1 - nty0)/(ny1 - ny0),
        ptyr = (nty2 - nty0)/(ny2 - ny0),
        ptyn = (nty2 - nty1)/(ny2 - ny1),
        pzl = (nz1 - nz0)/(ny1 - ny0),
        pzr = (nz2 - nz0)/(ny2 - ny0),
        pzn = (nz2 - nz1)/(ny2 - ny1),
        zr = ny0>=0?nz0:(nz0 - ny0*(nz2 - nz0)/(ny2 - ny0)),
        txr = ny0>=0?ntx0:(ntx0 - ny0*(ntx2 - ntx0)/(ny2 - ny0)),
        tyr = ny0>=0?nty0:(nty0 - ny0*(nty2 - nty0)/(ny2 - ny0)),
        zl = ny1>=0?(ny0>=0?nz0:(nz0 - ny0*(nz1 - nz0)/(ny1 - ny0))):(pzl=pzn,(nz1 - ny1*(nz2 - nz1)/(ny2 - ny1))),
        txl = ny1>=0?(ny0>=0?ntx0:(ntx0 - ny0*(ntx1 - ntx0)/(ny1 - ny0))):(ptxl=ptxn,(ntx1 - ny1*(ntx2 - ntx1)/(ny2 - ny1))),
        tyl = ny1>=0?(ny0>=0?nty0:(nty0 - ny0*(nty1 - nty0)/(ny1 - ny0))):(ptyl=ptyn,(nty1 - ny1*(nty2 - nty1)/(ny2 - ny1)));
      _cimg_for_triangle3(*this,xleft0,lxleft0,lyleft0,xright0,lxright0,lyright0,y,
                          nx0,ny0,nlx0,nly0,nx1,ny1,nlx1,nly1,nx2,ny2,nlx2,nly2) {
        if (y==ny1) { zl = nz1; txl = ntx1; tyl = nty1; pzl = pzn; ptxl = ptxn; ptyl = ptyn; }
        int
          xleft = xleft0, xright = xright0,
          lxleft = lxleft0, lxright = lxright0,
          lyleft = lyleft0, lyright = lyright0;
        float
          zleft = zl, zright = zr,
          txleft = txl, txright = txr,
          tyleft = tyl, tyright = tyr;
        if (xright<xleft) cimg::swap(xleft,xright,zleft,zright,txleft,txright,tyleft,tyright,lxleft,lxright,lyleft,lyright);
        const int
          dx = xright - xleft,
          dlx = lxright>lxleft?lxright - lxleft:lxleft - lxright,
          dly = lyright>lyleft?lyright - lyleft:lyleft - lyright,
          rlx = dx?(lxright - lxleft)/dx:0,
          rly = dx?(lyright - lyleft)/dx:0,
          slx = lxright>lxleft?1:-1,
          sly = lyright>lyleft?1:-1,
          ndlx = dlx - (dx?dx*(dlx/dx):0),
          ndly = dly - (dx?dx*(dly/dx):0);
        const float
          pentez = (zright - zleft)/dx,
          pentetx = (txright - txleft)/dx,
          pentety = (tyright - tyleft)/dx;
        int errlx = dx>>1, errly = errlx;
        if (xleft<0 && dx) {
          zleft-=xleft*(zright - zleft)/dx;
          lxleft-=xleft*(lxright - lxleft)/dx;
          lyleft-=xleft*(lyright - lyleft)/dx;
          txleft-=xleft*(txright - txleft)/dx;
          tyleft-=xleft*(tyright - tyleft)/dx;
        }
        if (xleft<0) xleft = 0;
        if (xright>=width()-1) xright = width()-1;
        T* ptrd = data(xleft,y,0,0);
        if (opacity>=1) for (int x = xleft; x<=xright; ++x) {
          const float invz = 1/zleft;
          const tc *col = texture.data((int)(txleft*invz),(int)(tyleft*invz));
          cimg_forC(*this,c) {
            const tl l = light(lxleft,lyleft,c);
            *ptrd = (T)(l<1?l**col:(2-l)**col+(l-1)*maxval);
            ptrd+=whd; col+=twhd;
          }
          ptrd-=offx; zleft+=pentez; txleft+=pentetx; tyleft+=pentety;
          lxleft+=rlx+((errlx-=ndlx)<0?errlx+=dx,slx:0);
          lyleft+=rly+((errly-=ndly)<0?errly+=dx,sly:0);
        } else for (int x = xleft; x<=xright; ++x) {
          const float invz = 1/zleft;
          const tc *col = texture.data((int)(txleft*invz),(int)(tyleft*invz));
          cimg_forC(*this,c) {
            const tl l = light(lxleft,lyleft,c);
            const T val = (T)(l<1?l**col:(2-l)**col+(l-1)*maxval);
            *ptrd = (T)(nopacity*val + *ptrd*copacity);
            ptrd+=whd; col+=twhd;
          }
          ptrd-=offx; zleft+=pentez; txleft+=pentetx; tyleft+=pentety;
          lxleft+=rlx+((errlx-=ndlx)<0?errlx+=dx,slx:0);
          lyleft+=rly+((errly-=ndly)<0?errly+=dx,sly:0);
        }
        zr+=pzr; txr+=ptxr; tyr+=ptyr; zl+=pzl; txl+=ptxl; tyl+=ptyl;
      }
      return *this;
    }

    //! Draw a textured Phong-shaded 2d triangle, with perspective correction and z-buffering.
    template<typename tz, typename tc, typename tl>
    CImg<T>& draw_triangle(CImg<tz>& zbuffer,
                           const int x0, const int y0, const float z0,
                           const int x1, const int y1, const float z1,
                           const int x2, const int y2, const float z2,
                           const CImg<tc>& texture,
                           const int tx0, const int ty0,
                           const int tx1, const int ty1,
                           const int tx2, const int ty2,
                           const CImg<tl>& light,
                           const int lx0, const int ly0,
                           const int lx1, const int ly1,
                           const int lx2, const int ly2,
                           const float opacity=1) {
      typedef typename cimg::superset<tz,float>::type tzfloat;
      if (is_empty() || z0<=0 || z1<=0 || z2<=0) return *this;
      if (!is_sameXY(zbuffer))
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Instance and specified Z-buffer (%u,%u,%u,%u,%p) have different dimensions.",
                                    cimg_instance,
                                    zbuffer._width,zbuffer._height,zbuffer._depth,zbuffer._spectrum,zbuffer._data);
      if (texture._depth>1 || texture._spectrum<_spectrum)
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Invalid specified texture (%u,%u,%u,%u,%p).",
                                    cimg_instance,
                                    texture._width,texture._height,texture._depth,texture._spectrum,texture._data);
      if (light._depth>1 || light._spectrum<_spectrum)
        throw CImgArgumentException(_cimg_instance
                                    "draw_triangle(): Invalid specified light texture (%u,%u,%u,%u,%p).",
                                    cimg_instance,light._width,light._height,light._depth,light._spectrum,light._data);
      if (is_overlapped(texture)) return draw_triangle(zbuffer,x0,y0,z0,x1,y1,z1,x2,y2,z2,
                                                       +texture,tx0,ty0,tx1,ty1,tx2,ty2,light,lx0,ly0,lx1,ly1,lx2,ly2,opacity);
      if (is_overlapped(light)) return draw_triangle(zbuffer,x0,y0,z0,x1,y1,z1,x2,y2,z2,
                                                     texture,tx0,ty0,tx1,ty1,tx2,ty2,+light,lx0,ly0,lx1,ly1,lx2,ly2,opacity);
      static const T maxval = (T)cimg::min(cimg::type<T>::max(),cimg::type<tc>::max());
      const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
      const long whd = (long)_width*_height*_depth, twhd = (long)texture._width*texture._height*texture._depth, offx = _spectrum*whd;
      int nx0 = x0, ny0 = y0, nx1 = x1, ny1 = y1, nx2 = x2, ny2 = y2,
        nlx0 = lx0, nly0 = ly0, nlx1 = lx1, nly1 = ly1, nlx2 = lx2, nly2 = ly2;
      float
        ntx0 = tx0/z0, nty0 = ty0/z0,
        ntx1 = tx1/z1, nty1 = ty1/z1,
        ntx2 = tx2/z2, nty2 = ty2/z2;
      tzfloat nz0 = 1/(tzfloat)z0, nz1 = 1/(tzfloat)z1, nz2 = 1/(tzfloat)z2;
      if (ny0>ny1) cimg::swap(nx0,nx1,ny0,ny1,ntx0,ntx1,nty0,nty1,nlx0,nlx1,nly0,nly1,nz0,nz1);
      if (ny0>ny2) cimg::swap(nx0,nx2,ny0,ny2,ntx0,ntx2,nty0,nty2,nlx0,nlx2,nly0,nly2,nz0,nz2);
      if (ny1>ny2) cimg::swap(nx1,nx2,ny1,ny2,ntx1,ntx2,nty1,nty2,nlx1,nlx2,nly1,nly2,nz1,nz2);
      if (ny0>=height() || ny2<0) return *this;
      float
        ptxl = (ntx1 - ntx0)/(ny1 - ny0),
        ptxr = (ntx2 - ntx0)/(ny2 - ny0),
        ptxn = (ntx2 - ntx1)/(ny2 - ny1),
        ptyl = (nty1 - nty0)/(ny1 - ny0),
        ptyr = (nty2 - nty0)/(ny2 - ny0),
        ptyn = (nty2 - nty1)/(ny2 - ny1),
        txr = ny0>=0?ntx0:(ntx0 - ny0*(ntx2 - ntx0)/(ny2 - ny0)),
        tyr = ny0>=0?nty0:(nty0 - ny0*(nty2 - nty0)/(ny2 - ny0)),
        txl = ny1>=0?(ny0>=0?ntx0:(ntx0 - ny0*(ntx1 - ntx0)/(ny1 - ny0))):(ptxl=ptxn,(ntx1 - ny1*(ntx2 - ntx1)/(ny2 - ny1))),
        tyl = ny1>=0?(ny0>=0?nty0:(nty0 - ny0*(nty1 - nty0)/(ny1 - ny0))):(ptyl=ptyn,(nty1 - ny1*(nty2 - nty1)/(ny2 - ny1)));
      tzfloat
        pzl = (nz1 - nz0)/(ny1 - ny0),
        pzr = (nz2 - nz0)/(ny2 - ny0),
        pzn = (nz2 - nz1)/(ny2 - ny1),
        zr = ny0>=0?nz0:(nz0 - ny0*(nz2 - nz0)/(ny2 - ny0)),
        zl = ny1>=0?(ny0>=0?nz0:(nz0 - ny0*(nz1 - nz0)/(ny1 - ny0))):(pzl=pzn,(nz1 - ny1*(nz2 - nz1)/(ny2 - ny1)));
      _cimg_for_triangle3(*this,xleft0,lxleft0,lyleft0,xright0,lxright0,lyright0,y,
                          nx0,ny0,nlx0,nly0,nx1,ny1,nlx1,nly1,nx2,ny2,nlx2,nly2) {
        if (y==ny1) { zl = nz1; txl = ntx1; tyl = nty1; pzl = pzn; ptxl = ptxn; ptyl = ptyn; }
        int
          xleft = xleft0, xright = xright0,
          lxleft = lxleft0, lxright = lxright0,
          lyleft = lyleft0, lyright = lyright0;
        float txleft = txl, txright = txr, tyleft = tyl, tyright = tyr;
        tzfloat zleft = zl, zright = zr;
        if (xright<xleft) cimg::swap(xleft,xright,zleft,zright,txleft,txright,tyleft,tyright,lxleft,lxright,lyleft,lyright);
        const int
          dx = xright - xleft,
          dlx = lxright>lxleft?lxright - lxleft:lxleft - lxright,
          dly = lyright>lyleft?lyright - lyleft:lyleft - lyright,
          rlx = dx?(lxright - lxleft)/dx:0,
          rly = dx?(lyright - lyleft)/dx:0,
          slx = lxright>lxleft?1:-1,
          sly = lyright>lyleft?1:-1,
          ndlx = dlx - (dx?dx*(dlx/dx):0),
          ndly = dly - (dx?dx*(dly/dx):0);
        float pentetx = (txright - txleft)/dx, pentety = (tyright - tyleft)/dx;
        const tzfloat pentez = (zright - zleft)/dx;
        int errlx = dx>>1, errly = errlx;
        if (xleft<0 && dx) {
          zleft-=xleft*(zright - zleft)/dx;
          lxleft-=xleft*(lxright - lxleft)/dx;
          lyleft-=xleft*(lyright - lyleft)/dx;
          txleft-=xleft*(txright - txleft)/dx;
          tyleft-=xleft*(tyright - tyleft)/dx;
        }
        if (xleft<0) xleft = 0;
        if (xright>=width()-1) xright = width()-1;
        T* ptrd = data(xleft,y);
        tz *ptrz = zbuffer.data(xleft,y);
        if (opacity>=1) for (int x = xleft; x<=xright; ++x, ++ptrz, ++ptrd) {
            if (zleft>=(tzfloat)*ptrz) {
              *ptrz = (tz)zleft;
              const tzfloat invz = 1/zleft;
              const tc *col = texture.data((int)(txleft*invz),(int)(tyleft*invz));
              cimg_forC(*this,c) {
                const tl l = light(lxleft,lyleft,c);
                *ptrd = (T)(l<1?l**col:(2-l)**col+(l-1)*maxval);
                ptrd+=whd; col+=twhd;
              }
              ptrd-=offx;
            }
            zleft+=pentez; txleft+=pentetx; tyleft+=pentety;
            lxleft+=rlx+((errlx-=ndlx)<0?errlx+=dx,slx:0);
            lyleft+=rly+((errly-=ndly)<0?errly+=dx,sly:0);
          } else for (int x = xleft; x<=xright; ++x, ++ptrz, ++ptrd) {
            if (zleft>=(tzfloat)*ptrz) {
              *ptrz = (tz)zleft;
              const tzfloat invz = 1/zleft;
              const tc *col = texture.data((int)(txleft*invz),(int)(tyleft*invz));
              cimg_forC(*this,c) {
                const tl l = light(lxleft,lyleft,c);
                const T val = (T)(l<1?l**col:(2-l)**col+(l-1)*maxval);
                *ptrd = (T)(nopacity*val + *ptrd*copacity);
                ptrd+=whd; col+=twhd;
              }
              ptrd-=offx;
            }
            zleft+=pentez; txleft+=pentetx; tyleft+=pentety;
            lxleft+=rlx+((errlx-=ndlx)<0?errlx+=dx,slx:0);
            lyleft+=rly+((errly-=ndly)<0?errly+=dx,sly:0);
          }
        zr+=pzr; txr+=ptxr; tyr+=ptyr; zl+=pzl; txl+=ptxl; tyl+=ptyl;
      }
      return *this;
    }

    //! Draw a filled 4d rectangle.
    /**
       \param x0 X-coordinate of the upper-left rectangle corner.
       \param y0 Y-coordinate of the upper-left rectangle corner.
       \param z0 Z-coordinate of the upper-left rectangle corner.
       \param c0 C-coordinate of the upper-left rectangle corner.
       \param x1 X-coordinate of the lower-right rectangle corner.
       \param y1 Y-coordinate of the lower-right rectangle corner.
       \param z1 Z-coordinate of the lower-right rectangle corner.
       \param c1 C-coordinate of the lower-right rectangle corner.
       \param val Scalar value used to fill the rectangle area.
       \param opacity Drawing opacity.
    **/
    CImg<T>& draw_rectangle(const int x0, const int y0, const int z0, const int c0,
                            const int x1, const int y1, const int z1, const int c1,
                            const T val, const float opacity=1) {
      if (is_empty()) return *this;
      const bool bx = (x0<x1), by = (y0<y1), bz = (z0<z1), bc = (c0<c1);
      const int
        nx0 = bx?x0:x1, nx1 = bx?x1:x0,
        ny0 = by?y0:y1, ny1 = by?y1:y0,
        nz0 = bz?z0:z1, nz1 = bz?z1:z0,
        nc0 = bc?c0:c1, nc1 = bc?c1:c0;
      const int
        lX = (1 + nx1 - nx0) + (nx1>=width()?width() - 1 - nx1:0) + (nx0<0?nx0:0),
        lY = (1 + ny1 - ny0) + (ny1>=height()?height() - 1 - ny1:0) + (ny0<0?ny0:0),
        lZ = (1 + nz1 - nz0) + (nz1>=depth()?depth() - 1 - nz1:0) + (nz0<0?nz0:0),
        lC = (1 + nc1 - nc0) + (nc1>=spectrum()?spectrum() - 1 - nc1:0) + (nc0<0?nc0:0);
      const unsigned long
        offX = (unsigned long)_width - lX,
        offY = (unsigned long)_width*(_height - lY),
        offZ = (unsigned long)_width*_height*(_depth - lZ);
      const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
      T *ptrd = data(nx0<0?0:nx0,ny0<0?0:ny0,nz0<0?0:nz0,nc0<0?0:nc0);
      if (lX>0 && lY>0 && lZ>0 && lC>0)
        for (int v = 0; v<lC; ++v) {
          for (int z = 0; z<lZ; ++z) {
            for (int y = 0; y<lY; ++y) {
              if (opacity>=1) {
                if (sizeof(T)!=1) { for (int x = 0; x<lX; ++x) *(ptrd++) = val; ptrd+=offX; }
                else { std::memset(ptrd,(int)val,lX); ptrd+=_width; }
              } else { for (int x = 0; x<lX; ++x) { *ptrd = (T)(nopacity*val + *ptrd*copacity); ++ptrd; } ptrd+=offX; }
            }
            ptrd+=offY;
          }
          ptrd+=offZ;
        }
      return *this;
    }

    //! Draw a filled 3d rectangle.
    /**
       \param x0 X-coordinate of the upper-left rectangle corner.
       \param y0 Y-coordinate of the upper-left rectangle corner.
       \param z0 Z-coordinate of the upper-left rectangle corner.
       \param x1 X-coordinate of the lower-right rectangle corner.
       \param y1 Y-coordinate of the lower-right rectangle corner.
       \param z1 Z-coordinate of the lower-right rectangle corner.
       \param color Pointer to \c spectrum() consecutive values of type \c T, defining the drawing color.
       \param opacity Drawing opacity.
    **/
    template<typename tc>
    CImg<T>& draw_rectangle(const int x0, const int y0, const int z0,
                            const int x1, const int y1, const int z1,
                            const tc *const color, const float opacity=1) {
      if (is_empty()) return *this;
      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_rectangle(): Specified color is (null).",
                                    cimg_instance);
      cimg_forC(*this,c) draw_rectangle(x0,y0,z0,c,x1,y1,z1,c,(T)color[c],opacity);
      return *this;
    }

    //! Draw an outlined 3d rectangle \overloading.
    template<typename tc>
    CImg<T>& draw_rectangle(const int x0, const int y0, const int z0,
                            const int x1, const int y1, const int z1,
                            const tc *const color, const float opacity,
                            const unsigned int pattern) {
      return draw_line(x0,y0,z0,x1,y0,z0,color,opacity,pattern,true).
	draw_line(x1,y0,z0,x1,y1,z0,color,opacity,pattern,false).
	draw_line(x1,y1,z0,x0,y1,z0,color,opacity,pattern,false).
	draw_line(x0,y1,z0,x0,y0,z0,color,opacity,pattern,false).
	draw_line(x0,y0,z1,x1,y0,z1,color,opacity,pattern,true).
	draw_line(x1,y0,z1,x1,y1,z1,color,opacity,pattern,false).
	draw_line(x1,y1,z1,x0,y1,z1,color,opacity,pattern,false).
	draw_line(x0,y1,z1,x0,y0,z1,color,opacity,pattern,false).
	draw_line(x0,y0,z0,x0,y0,z1,color,opacity,pattern,true).
	draw_line(x1,y0,z0,x1,y0,z1,color,opacity,pattern,true).
	draw_line(x1,y1,z0,x1,y1,z1,color,opacity,pattern,true).
	draw_line(x0,y1,z0,x0,y1,z1,color,opacity,pattern,true);
    }

    //! Draw a filled 2d rectangle.
    /**
       \param x0 X-coordinate of the upper-left rectangle corner.
       \param y0 Y-coordinate of the upper-left rectangle corner.
       \param x1 X-coordinate of the lower-right rectangle corner.
       \param y1 Y-coordinate of the lower-right rectangle corner.
       \param color Pointer to \c spectrum() consecutive values of type \c T, defining the drawing color.
       \param opacity Drawing opacity.
    **/
    template<typename tc>
    CImg<T>& draw_rectangle(const int x0, const int y0,
                            const int x1, const int y1,
                            const tc *const color, const float opacity=1) {
      return draw_rectangle(x0,y0,0,x1,y1,_depth-1,color,opacity);
    }

    //! Draw a outlined 2d rectangle \overloading.
    template<typename tc>
    CImg<T>& draw_rectangle(const int x0, const int y0,
                            const int x1, const int y1,
                            const tc *const color, const float opacity,
                            const unsigned int pattern) {
      if (is_empty()) return *this;
      if (y0==y1) return draw_line(x0,y0,x1,y0,color,opacity,pattern,true);
      if (x0==x1) return draw_line(x0,y0,x0,y1,color,opacity,pattern,true);
      const bool bx = (x0<x1), by = (y0<y1);
      const int
        nx0 = bx?x0:x1, nx1 = bx?x1:x0,
        ny0 = by?y0:y1, ny1 = by?y1:y0;
      if (ny1==ny0+1) return draw_line(nx0,ny0,nx1,ny0,color,opacity,pattern,true).
                      draw_line(nx1,ny1,nx0,ny1,color,opacity,pattern,false);
      return draw_line(nx0,ny0,nx1,ny0,color,opacity,pattern,true).
        draw_line(nx1,ny0+1,nx1,ny1-1,color,opacity,pattern,false).
        draw_line(nx1,ny1,nx0,ny1,color,opacity,pattern,false).
        draw_line(nx0,ny1-1,nx0,ny0+1,color,opacity,pattern,false);
    }

    //! Draw a filled 2d polygon.
    /**
       \param points Set of polygon vertices.
       \param color Pointer to \c spectrum() consecutive values of type \c T, defining the drawing color.
       \param opacity Drawing opacity.
     **/
    template<typename t, typename tc>
    CImg<T>& draw_polygon(const CImg<t>& points,
                          const tc *const color, const float opacity=1) {
      if (is_empty() || !points) return *this;
      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_polygon(): Specified color is (null).",
                                    cimg_instance);

      // Normalize 2d input coordinates (remove adjacent duplicates).
      CImg<intT> npoints(points._width,2);
      unsigned int nb_points = 1, p = 0;
      int cx = npoints(0,0) = (int)points(0,0), cy = npoints(0,1) = (int)points(0,1);
      const int cx0 = cx, cy0 = cy;
      for (p = 1; p<points._width; ++p) {
        const int nx = (int)points(p,0), ny = (int)points(p,1);
        if (nx!=cx || ny!=cy) { npoints(nb_points,0) = nx; npoints(nb_points++,1) = ny; cx = nx; cy = ny; }
      }
      --p;
      if ((int)points(p,0)==cx0 && (int)points(p,1)==cy0) --nb_points;

      if (nb_points<=1) return draw_point((int)npoints(0,0),(int)npoints(0,1),color,opacity);
      if (nb_points==2) return draw_line((int)npoints(0,0),(int)npoints(0,1),
                                         (int)npoints(1,0),(int)npoints(1,1),color,opacity);
      if (nb_points==3) return draw_triangle((int)npoints(0,0),(int)npoints(0,1),
                                             (int)npoints(1,0),(int)npoints(1,1),
                                             (int)npoints(2,0),(int)npoints(2,1),color,opacity);
      cimg_init_scanline(color,1);

      if (opacity!=1) { // For non-opaque polygons, do a little trick to avoid horizontal lines artefacts.
        npoints.resize(nb_points,2,1,1,0);
        CImg<intT> npoints_x = npoints.get_shared_row(0), npoints_y = npoints.get_shared_row(1);
        int xmax = 0, xmin = (int)npoints_x.min_max(xmax), ymax = 0, ymin = (int)npoints_y.min_max(ymax);
        if (xmax<0 || xmin>=width() || ymax<0 || ymin>=height()) return *this;
        if (ymin==ymax) return cimg_draw_scanline(xmin,xmax,ymin,color,opacity,1);
        const unsigned int
          nxmin = xmin<0?0:(unsigned int)xmin, nxmax = xmax>=width()?_width-1:(unsigned int)xmax,
          nymin = ymin<0?0:(unsigned int)ymin, nymax = ymax>=height()?_height-1:(unsigned int)ymax,
          dx = 1 + nxmax - nxmin,
          dy = 1 + nymax - nymin;
        npoints_x-=nxmin; npoints_y-=nymin;
        unsigned char one = 1;
        const CImg<unsigned char> mask = CImg<unsigned char>(dx,dy,1,1,0).draw_polygon(npoints,&one,1);
        CImg<T> _color(dx,dy,1,spectrum());
        cimg_forC(_color,c) _color.get_shared_channel(c).fill(color[c]);
        return draw_image(nxmin,nymin,0,0,_color,mask,opacity,1);
      }

      // Draw polygon segments.
      int
        xmax = 0, xmin = (int)npoints.get_shared_points(0,nb_points-1,0).min_max(xmax),
        ymax = 0, ymin = (int)npoints.get_shared_points(0,nb_points-1,1).min_max(ymax);
      if (xmax<0 || xmin>=width() || ymax<0 || ymin>=height()) return *this;
      if (ymin==ymax) return cimg_draw_scanline(xmin,xmax,ymin,color,1,1);
      const unsigned int
        nymin = ymin<0?0:(unsigned int)ymin,
        nymax = ymax>=height()?_height-1:(unsigned int)ymax,
        dy = 1 + nymax - nymin;
      CImg<intT> X(1+2*nb_points,dy,1,1,0), tmp;
      cx = (int)npoints(0,0), cy = (int)npoints(0,1);
      unsigned int cp = 0;
      for (unsigned int p = 0; p<nb_points; ++p) {
        const unsigned int np = (p!=nb_points-1)?p+1:0, ap = (np!=nb_points-1)?np+1:0;
        const int
          nx = (int)npoints(np,0), ny = (int)npoints(np,1), ay = (int)npoints(ap,1),
          y0 = cy - nymin, y1 = ny - nymin;
        if (y0!=y1) {
          const int countermin = ((ny<ay && cy<ny) || (ny>ay && cy>ny))?1:0;
          for (int x = cx, y = y0, _sx = 1, _sy = 1,
                 _dx = nx>cx?nx-cx:((_sx=-1),cx-nx),
                 _dy = y1>y0?y1-y0:((_sy=-1),y0-y1),
                 _counter = ((_dx-=_dy?_dy*(_dx/_dy):0),_dy),
                 _err = _dx>>1,
                 _rx = _dy?(nx-cx)/_dy:0;
               _counter>=countermin;
               --_counter, y+=_sy, x+=_rx + ((_err-=_dx)<0?_err+=_dy,_sx:0))
            if (y>=0 && y<(int)dy) X(++X(0,y),y) = x;
          cp = np; cx = nx; cy = ny;
        } else {
          const int pp = (cp?cp-1:nb_points-1), py = (int)npoints(pp,1);
          if (y0>=0 && y0<(int)dy) {
            cimg_draw_scanline(cx<nx?cx:nx,cx<nx?nx:cx,y0+nymin,color,1,1);
            if ((cy>py && ay>cy) || (cy<py && ay<cy)) X(++X(0,y0),y0) = cx;
          }
          if (cy!=ay) { cp = np; cx = nx; cy = ny; }
        }
      }

      // Draw polygon scanlines.
      for (int y = 0; y<(int)dy; ++y) {
        tmp.assign(X.data(1,y),X(0,y),1,1,1,true).sort();
        for (int i = 1; i<=X(0,y); ) {
          const int xb = X(i++,y), xe = X(i++,y);
          cimg_draw_scanline(xb,xe,nymin+y,color,1,1);
        }
      }
      return *this;
    }

    //! Draw a outlined 2d polygon \overloading.
    template<typename t, typename tc>
    CImg<T>& draw_polygon(const CImg<t>& points,
                          const tc *const color, const float opacity, const unsigned int pattern) {
      if (is_empty() || !points || points._width<3) return *this;
      bool ninit_hatch = true;
      switch (points._height) {
      case 0 : case 1 :
        throw CImgArgumentException(_cimg_instance
                                    "draw_polygon(): Invalid specified point set.",
                                    cimg_instance);
      case 2 : { // 2d version.
        CImg<intT> npoints(points._width,2);
        int x = npoints(0,0) = (int)points(0,0), y = npoints(0,1) = (int)points(0,1);
        unsigned int nb_points = 1;
        for (unsigned int p = 1; p<points._width; ++p) {
          const int nx = (int)points(p,0), ny = (int)points(p,1);
          if (nx!=x || ny!=y) { npoints(nb_points,0) = nx; npoints(nb_points++,1) = ny; x = nx; y = ny; }
        }
        const int x0 = (int)npoints(0,0), y0 = (int)npoints(0,1);
        int ox = x0, oy = y0;
        for (unsigned int i = 1; i<nb_points; ++i) {
          const int x = (int)npoints(i,0), y = (int)npoints(i,1);
          draw_line(ox,oy,x,y,color,opacity,pattern,ninit_hatch);
          ninit_hatch = false;
          ox = x; oy = y;
        }
        draw_line(ox,oy,x0,y0,color,opacity,pattern,false);
      } break;
      default : { // 3d version.
        CImg<intT> npoints(points._width,3);
        int x = npoints(0,0) = (int)points(0,0), y = npoints(0,1) = (int)points(0,1), z = npoints(0,2) = (int)points(0,2);
        unsigned int nb_points = 1;
        for (unsigned int p = 1; p<points._width; ++p) {
          const int nx = (int)points(p,0), ny = (int)points(p,1), nz = (int)points(p,2);
          if (nx!=x || ny!=y || nz!=z) { npoints(nb_points,0) = nx; npoints(nb_points,1) = ny; npoints(nb_points++,2) = nz; x = nx; y = ny; z = nz; }
        }
        const int x0 = (int)npoints(0,0), y0 = (int)npoints(0,1), z0 = (int)npoints(0,2);
        int ox = x0, oy = y0, oz = z0;
        for (unsigned int i = 1; i<nb_points; ++i) {
          const int x = (int)npoints(i,0), y = (int)npoints(i,1), z = (int)npoints(i,2);
          draw_line(ox,oy,oz,x,y,z,color,opacity,pattern,ninit_hatch);
          ninit_hatch = false;
          ox = x; oy = y; oz = z;
        }
        draw_line(ox,oy,oz,x0,y0,z0,color,opacity,pattern,false);
      }
      }
      return *this;
    }

    //! Draw a filled 2d ellipse.
    /**
       \param x0 X-coordinate of the ellipse center.
       \param y0 Y-coordinate of the ellipse center.
       \param r1 First radius of the ellipse.
       \param r2 Second radius of the ellipse.
       \param angle Angle of the first radius.
       \param color Pointer to \c spectrum() consecutive values, defining the drawing color.
       \param opacity Drawing opacity.
    **/
    template<typename tc>
    CImg<T>& draw_ellipse(const int x0, const int y0, const float r1, const float r2, const float angle,
                          const tc *const color, const float opacity=1) {
      return _draw_ellipse(x0,y0,r1,r2,angle,color,opacity,0U);
    }

    //! Draw a filled 2d ellipse \overloading.
    /**
       \param x0 X-coordinate of the ellipse center.
       \param y0 Y-coordinate of the ellipse center.
       \param tensor Diffusion tensor describing the ellipse.
       \param color Pointer to \c spectrum() consecutive values, defining the drawing color.
       \param opacity Drawing opacity.
    **/
    template<typename t, typename tc>
    CImg<T>& draw_ellipse(const int x0, const int y0, const CImg<t> &tensor,
                          const tc *const color, const float opacity=1) {
      CImgList<t> eig = tensor.get_symmetric_eigen();
      const CImg<t> &val = eig[0], &vec = eig[1];
      return draw_ellipse(x0,y0,std::sqrt(val(0)),std::sqrt(val(1)),
                          std::atan2(vec(0,1),vec(0,0))*180/cimg::PI,
                          color,opacity);
    }

    //! Draw an outlined 2d ellipse.
    /**
       \param x0 X-coordinate of the ellipse center.
       \param y0 Y-coordinate of the ellipse center.
       \param r1 First radius of the ellipse.
       \param r2 Second radius of the ellipse.
       \param angle Angle of the first radius.
       \param color Pointer to \c spectrum() consecutive values, defining the drawing color.
       \param opacity Drawing opacity.
       \param pattern An integer whose bits describe the outline pattern.
    **/
    template<typename tc>
    CImg<T>& draw_ellipse(const int x0, const int y0, const float r1, const float r2, const float angle,
                          const tc *const color, const float opacity, const unsigned int pattern) {
      if (pattern) _draw_ellipse(x0,y0,r1,r2,angle,color,opacity,pattern);
      return *this;
    }

    //! Draw an outlined 2d ellipse \overloading.
    /**
       \param x0 X-coordinate of the ellipse center.
       \param y0 Y-coordinate of the ellipse center.
       \param tensor Diffusion tensor describing the ellipse.
       \param color Pointer to \c spectrum() consecutive values, defining the drawing color.
       \param opacity Drawing opacity.
       \param pattern An integer whose bits describe the outline pattern.
    **/
    template<typename t, typename tc>
    CImg<T>& draw_ellipse(const int x0, const int y0, const CImg<t> &tensor,
                          const tc *const color, const float opacity,
                          const unsigned int pattern) {
      CImgList<t> eig = tensor.get_symmetric_eigen();
      const CImg<t> &val = eig[0], &vec = eig[1];
      return draw_ellipse(x0,y0,std::sqrt(val(0)),std::sqrt(val(1)),
                          std::atan2(vec(0,1),vec(0,0))*180/cimg::PI,
                          color,opacity,pattern);
    }

    template<typename tc>
    CImg<T>& _draw_ellipse(const int x0, const int y0, const float r1, const float r2, const float angle,
                           const tc *const color, const float opacity,
                           const unsigned int pattern) {
      if (is_empty()) return *this;
      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_ellipse(): Specified color is (null).",
                                    cimg_instance);
      if (r1<=0 || r2<=0) return draw_point(x0,y0,color,opacity);
      cimg_init_scanline(color,opacity);
      const float
        nr1 = cimg::abs(r1), nr2 = cimg::abs(r2),
        nangle = (float)(angle*cimg::PI/180),
        u = (float)std::cos(nangle),
        v = (float)std::sin(nangle),
        rmax = cimg::max(nr1,nr2),
        l1 = (float)std::pow(rmax/(nr1>0?nr1:1e-6),2),
        l2 = (float)std::pow(rmax/(nr2>0?nr2:1e-6),2),
        a = l1*u*u + l2*v*v,
        b = u*v*(l1-l2),
        c = l1*v*v + l2*u*u;
      const int
        yb = (int)std::sqrt(a*rmax*rmax/(a*c - b*b)),
        tymin = y0 - yb - 1,
        tymax = y0 + yb + 1,
        ymin = tymin<0?0:tymin,
        ymax = tymax>=height()?height()-1:tymax;
      int oxmin = 0, oxmax = 0;
      bool first_line = true;
      for (int y = ymin; y<=ymax; ++y) {
        const float
          Y = y - y0 + (y<y0?0.5f:-0.5f),
          delta = b*b*Y*Y - a*(c*Y*Y - rmax*rmax),
          sdelta = delta>0?(float)std::sqrt(delta)/a:0.0f,
          bY = b*Y/a,
          fxmin = x0 - 0.5f - bY - sdelta,
          fxmax = x0 + 0.5f - bY + sdelta;
        const int xmin = (int)fxmin, xmax = (int)fxmax;
        if (!pattern) cimg_draw_scanline(xmin,xmax,y,color,opacity,1);
        else {
          if (first_line) {
            if (y0-yb>=0) cimg_draw_scanline(xmin,xmax,y,color,opacity,1);
            else draw_point(xmin,y,color,opacity).draw_point(xmax,y,color,opacity);
            first_line = false;
          } else {
            if (xmin<oxmin) cimg_draw_scanline(xmin,oxmin-1,y,color,opacity,1);
            else cimg_draw_scanline(oxmin+(oxmin==xmin?0:1),xmin,y,color,opacity,1);
            if (xmax<oxmax) cimg_draw_scanline(xmax,oxmax-1,y,color,opacity,1);
            else cimg_draw_scanline(oxmax+(oxmax==xmax?0:1),xmax,y,color,opacity,1);
            if (y==tymax) cimg_draw_scanline(xmin+1,xmax-1,y,color,opacity,1);
          }
        }
        oxmin = xmin; oxmax = xmax;
      }
      return *this;
    }

    //! Draw a filled 2d circle.
    /**
       \param x0 X-coordinate of the circle center.
       \param y0 Y-coordinate of the circle center.
       \param radius  Circle radius.
       \param color Pointer to \c spectrum() consecutive values, defining the drawing color.
       \param opacity Drawing opacity.
       \note
       - Circle version of the Bresenham's algorithm is used.
    **/
    template<typename tc>
    CImg<T>& draw_circle(const int x0, const int y0, int radius,
                         const tc *const color, const float opacity=1) {
      if (is_empty()) return *this;
      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_circle(): Specified color is (null).",
                                    cimg_instance);
      cimg_init_scanline(color,opacity);
      if (radius<0 || x0-radius>=width() || y0+radius<0 || y0-radius>=height()) return *this;
      if (y0>=0 && y0<height()) cimg_draw_scanline(x0-radius,x0+radius,y0,color,opacity,1);
      for (int f = 1-radius, ddFx = 0, ddFy = -(radius<<1), x = 0, y = radius; x<y; ) {
        if (f>=0) {
          const int x1 = x0-x, x2 = x0+x, y1 = y0-y, y2 = y0+y;
          if (y1>=0 && y1<height()) cimg_draw_scanline(x1,x2,y1,color,opacity,1);
          if (y2>=0 && y2<height()) cimg_draw_scanline(x1,x2,y2,color,opacity,1);
          f+=(ddFy+=2); --y;
        }
        const bool no_diag = y!=(x++);
        ++(f+=(ddFx+=2));
        const int x1 = x0-y, x2 = x0+y, y1 = y0-x, y2 = y0+x;
        if (no_diag) {
          if (y1>=0 && y1<height()) cimg_draw_scanline(x1,x2,y1,color,opacity,1);
          if (y2>=0 && y2<height()) cimg_draw_scanline(x1,x2,y2,color,opacity,1);
        }
      }
      return *this;
    }

    //! Draw an outlined 2d circle.
    /**
       \param x0 X-coordinate of the circle center.
       \param y0 Y-coordinate of the circle center.
       \param radius Circle radius.
       \param color Pointer to \c spectrum() consecutive values, defining the drawing color.
       \param opacity Drawing opacity.
       \param pattern An integer whose bits describe the outline pattern.
    **/
    template<typename tc>
    CImg<T>& draw_circle(const int x0, const int y0, int radius,
                         const tc *const color, const float opacity,
                         const unsigned int pattern) {
      cimg::unused(pattern);
      if (is_empty()) return *this;
      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_circle(): Specified color is (null).",
                                    cimg_instance);
      if (radius<0 || x0-radius>=width() || y0+radius<0 || y0-radius>=height()) return *this;
      if (!radius) return draw_point(x0,y0,color,opacity);
      draw_point(x0-radius,y0,color,opacity).draw_point(x0+radius,y0,color,opacity).
        draw_point(x0,y0-radius,color,opacity).draw_point(x0,y0+radius,color,opacity);
      if (radius==1) return *this;
      for (int f = 1-radius, ddFx = 0, ddFy = -(radius<<1), x = 0, y = radius; x<y; ) {
        if (f>=0) { f+=(ddFy+=2); --y; }
        ++x; ++(f+=(ddFx+=2));
        if (x!=y+1) {
          const int x1 = x0-y, x2 = x0+y, y1 = y0-x, y2 = y0+x, x3 = x0-x, x4 = x0+x, y3 = y0-y, y4 = y0+y;
          draw_point(x1,y1,color,opacity).draw_point(x1,y2,color,opacity).
            draw_point(x2,y1,color,opacity).draw_point(x2,y2,color,opacity);
          if (x!=y)
            draw_point(x3,y3,color,opacity).draw_point(x4,y4,color,opacity).
              draw_point(x4,y3,color,opacity).draw_point(x3,y4,color,opacity);
        }
      }
      return *this;
    }

    //! Draw an image.
    /**
       \param sprite Sprite image.
       \param x0 X-coordinate of the sprite position.
       \param y0 Y-coordinate of the sprite position.
       \param z0 Z-coordinate of the sprite position.
       \param c0 C-coordinate of the sprite position.
       \param opacity Drawing opacity.
    **/
    template<typename t>
    CImg<T>& draw_image(const int x0, const int y0, const int z0, const int c0,
                        const CImg<t>& sprite, const float opacity=1) {
      if (is_empty() || !sprite) return *this;
      if (is_overlapped(sprite)) return draw_image(x0,y0,z0,c0,+sprite,opacity);
      if (x0==0 && y0==0 && z0==0 && c0==0 && is_sameXYZC(sprite) && opacity>=1 && !is_shared()) return assign(sprite,false);
      const bool bx = (x0<0), by = (y0<0), bz = (z0<0), bc = (c0<0);
      const int
        lX = sprite.width() - (x0 + sprite.width()>width()?x0 + sprite.width() - width():0) + (bx?x0:0),
        lY = sprite.height() - (y0 + sprite.height()>height()?y0 + sprite.height() - height():0) + (by?y0:0),
        lZ = sprite.depth() - (z0 + sprite.depth()>depth()?z0 + sprite.depth() - depth():0) + (bz?z0:0),
        lC = sprite.spectrum() - (c0 + sprite.spectrum()>spectrum()?c0 + sprite.spectrum() - spectrum():0) + (bc?c0:0);
      const t
        *ptrs = sprite._data -
        (bx?x0:0) -
        (by?y0*sprite.width():0) -
        (bz?z0*sprite.width()*sprite.height():0) -
        (bc?c0*sprite.width()*sprite.height()*sprite.depth():0);
      const unsigned long
        offX = (unsigned long)_width - lX,
        soffX = (unsigned long)sprite._width - lX,
        offY = (unsigned long)_width*(_height - lY),
        soffY = (unsigned long)sprite._width*(sprite._height - lY),
        offZ = (unsigned long)_width*_height*(_depth - lZ),
        soffZ = (unsigned long)sprite._width*sprite._height*(sprite._depth - lZ);
      const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
      if (lX>0 && lY>0 && lZ>0 && lC>0) {
	T *ptrd = data(x0<0?0:x0,y0<0?0:y0,z0<0?0:z0,c0<0?0:c0);
        for (int v = 0; v<lC; ++v) {
          for (int z = 0; z<lZ; ++z) {
            for (int y = 0; y<lY; ++y) {
              if (opacity>=1) for (int x = 0; x<lX; ++x) *(ptrd++) = (T)*(ptrs++);
              else for (int x = 0; x<lX; ++x) { *ptrd = (T)(nopacity*(*(ptrs++)) + *ptrd*copacity); ++ptrd; }
              ptrd+=offX; ptrs+=soffX;
            }
            ptrd+=offY; ptrs+=soffY;
          }
          ptrd+=offZ; ptrs+=soffZ;
        }
      }
      return *this;
    }

    //! Draw an image \specialization.
    CImg<T>& draw_image(const int x0, const int y0, const int z0, const int c0,
                        const CImg<T>& sprite, const float opacity=1) {
      if (is_empty() || !sprite) return *this;
      if (is_overlapped(sprite)) return draw_image(x0,y0,z0,c0,+sprite,opacity);
      if (x0==0 && y0==0 && z0==0 && c0==0 && is_sameXYZC(sprite) && opacity>=1 && !is_shared()) return assign(sprite,false);
      const bool bx = (x0<0), by = (y0<0), bz = (z0<0), bc = (c0<0);
      const int
        lX = sprite.width() - (x0 + sprite.width()>width()?x0 + sprite.width() - width():0) + (bx?x0:0),
        lY = sprite.height() - (y0 + sprite.height()>height()?y0 + sprite.height() - height():0) + (by?y0:0),
        lZ = sprite.depth() - (z0 + sprite.depth()>depth()?z0 + sprite.depth() - depth():0) + (bz?z0:0),
        lC = sprite.spectrum() - (c0 + sprite.spectrum()>spectrum()?c0 + sprite.spectrum() - spectrum():0) + (bc?c0:0);
      const T
        *ptrs = sprite._data -
        (bx?x0:0) -
        (by?y0*sprite.width():0) -
        (bz?z0*sprite.width()*sprite.height():0) -
        (bc?c0*sprite.width()*sprite.height()*sprite.depth():0);
      const unsigned long
        offX = (unsigned long)_width - lX,
        soffX = (unsigned long)sprite._width - lX,
        offY = (unsigned long)_width*(_height - lY),
        soffY = (unsigned long)sprite._width*(sprite._height - lY),
        offZ = (unsigned long)_width*_height*(_depth - lZ),
        soffZ = (unsigned long)sprite._width*sprite._height*(sprite._depth - lZ),
        slX = lX*sizeof(T);
      const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
      if (lX>0 && lY>0 && lZ>0 && lC>0) {
	T *ptrd = data(x0<0?0:x0,y0<0?0:y0,z0<0?0:z0,c0<0?0:c0);
        for (int v = 0; v<lC; ++v) {
          for (int z = 0; z<lZ; ++z) {
            if (opacity>=1) for (int y = 0; y<lY; ++y) { std::memcpy(ptrd,ptrs,slX); ptrd+=_width; ptrs+=sprite._width; }
            else for (int y = 0; y<lY; ++y) {
                for (int x = 0; x<lX; ++x) { *ptrd = (T)(nopacity*(*(ptrs++)) + *ptrd*copacity); ++ptrd; }
                ptrd+=offX; ptrs+=soffX;
              }
            ptrd+=offY; ptrs+=soffY;
          }
          ptrd+=offZ; ptrs+=soffZ;
        }
      }
      return *this;
    }

    //! Draw an image \overloading.
    template<typename t>
    CImg<T>& draw_image(const int x0, const int y0, const int z0,
                        const CImg<t>& sprite, const float opacity=1) {
      return draw_image(x0,y0,z0,0,sprite,opacity);
    }

    //! Draw an image \overloading.
    template<typename t>
    CImg<T>& draw_image(const int x0, const int y0,
                        const CImg<t>& sprite, const float opacity=1) {
      return draw_image(x0,y0,0,sprite,opacity);
    }

    //! Draw an image \overloading.
    template<typename t>
    CImg<T>& draw_image(const int x0,
                        const CImg<t>& sprite, const float opacity=1) {
      return draw_image(x0,0,sprite,opacity);
    }

    //! Draw an image \overloading.
    template<typename t>
    CImg<T>& draw_image(const CImg<t>& sprite, const float opacity=1) {
      return draw_image(0,sprite,opacity);
    }

    //! Draw a masked image.
    /**
       \param sprite Sprite image.
       \param mask Mask image.
       \param x0 X-coordinate of the sprite position in the image instance.
       \param y0 Y-coordinate of the sprite position in the image instance.
       \param z0 Z-coordinate of the sprite position in the image instance.
       \param c0 C-coordinate of the sprite position in the image instance.
       \param mask_max_value Maximum pixel value of the mask image \c mask.
       \param opacity Drawing opacity.
       \note
       - Pixel values of \c mask set the opacity of the corresponding pixels in \c sprite.
       - Dimensions along x,y and z of \p sprite and \p mask must be the same.
    **/
    template<typename ti, typename tm>
    CImg<T>& draw_image(const int x0, const int y0, const int z0, const int c0,
                        const CImg<ti>& sprite, const CImg<tm>& mask, const float opacity=1,
                        const float mask_max_value=1) {
      if (is_empty() || !sprite || !mask) return *this;
      if (is_overlapped(sprite)) return draw_image(x0,y0,z0,c0,+sprite,mask,opacity,mask_max_value);
      if (is_overlapped(mask))   return draw_image(x0,y0,z0,c0,sprite,+mask,opacity,mask_max_value);
      if (mask._width!=sprite._width || mask._height!=sprite._height || mask._depth!=sprite._depth)
        throw CImgArgumentException(_cimg_instance
                                    "draw_image(): Sprite (%u,%u,%u,%u,%p) and mask (%u,%u,%u,%u,%p) have incompatible dimensions.",
                                    cimg_instance,
                                    sprite._width,sprite._height,sprite._depth,sprite._spectrum,sprite._data,
                                    mask._width,mask._height,mask._depth,mask._spectrum,mask._data);

      const bool bx = (x0<0), by = (y0<0), bz = (z0<0), bc = (c0<0);
      const int
        lX = sprite.width() - (x0 + sprite.width()>width()?x0 + sprite.width() - width():0) + (bx?x0:0),
        lY = sprite.height() - (y0 + sprite.height()>height()?y0 + sprite.height() - height():0) + (by?y0:0),
        lZ = sprite.depth() - (z0 + sprite.depth()>depth()?z0 + sprite.depth() - depth():0) + (bz?z0:0),
        lC = sprite.spectrum() - (c0 + sprite.spectrum()>spectrum()?c0 + sprite.spectrum() - spectrum():0) + (bc?c0:0);
      const int
        coff = -(bx?x0:0)-(by?y0*mask.width():0)-(bz?z0*mask.width()*mask.height():0)-(bc?c0*mask.width()*mask.height()*mask.depth():0),
        ssize = mask.width()*mask.height()*mask.depth()*mask.spectrum();
      const ti *ptrs = sprite._data + coff;
      const tm *ptrm = mask._data   + coff;
      const unsigned long
        offX = (unsigned long)_width - lX,
        soffX = (unsigned long)sprite._width - lX,
        offY = (unsigned long)_width*(_height - lY),
        soffY = (unsigned long)sprite._width*(sprite._height - lY),
        offZ = (unsigned long)_width*_height*(_depth - lZ),
        soffZ = (unsigned long)sprite._width*sprite._height*(sprite._depth - lZ);
      if (lX>0 && lY>0 && lZ>0 && lC>0) {
	T *ptrd = data(x0<0?0:x0,y0<0?0:y0,z0<0?0:z0,c0<0?0:c0);
        for (int c = 0; c<lC; ++c) {
          ptrm = mask._data + (ptrm - mask._data)%ssize;
          for (int z = 0; z<lZ; ++z) {
            for (int y = 0; y<lY; ++y) {
              for (int x = 0; x<lX; ++x) {
                const float mopacity = (float)(*(ptrm++)*opacity),
                  nopacity = cimg::abs(mopacity), copacity = mask_max_value - cimg::max(mopacity,0);
                *ptrd = (T)((nopacity*(*(ptrs++)) + *ptrd*copacity)/mask_max_value);
                ++ptrd;
              }
              ptrd+=offX; ptrs+=soffX; ptrm+=soffX;
            }
            ptrd+=offY; ptrs+=soffY; ptrm+=soffY;
          }
          ptrd+=offZ; ptrs+=soffZ; ptrm+=soffZ;
        }
      }
      return *this;
    }

    //! Draw a masked image \overloading.
    template<typename ti, typename tm>
    CImg<T>& draw_image(const int x0, const int y0, const int z0,
                        const CImg<ti>& sprite, const CImg<tm>& mask, const float opacity=1,
                        const float mask_max_value=1) {
      return draw_image(x0,y0,z0,0,sprite,mask,opacity,mask_max_value);
    }

    //! Draw a image \overloading.
    template<typename ti, typename tm>
    CImg<T>& draw_image(const int x0, const int y0,
                        const CImg<ti>& sprite, const CImg<tm>& mask, const float opacity=1,
                        const float mask_max_value=1) {
      return draw_image(x0,y0,0,sprite,mask,opacity,mask_max_value);
    }

    //! Draw a image \overloading.
    template<typename ti, typename tm>
    CImg<T>& draw_image(const int x0,
                        const CImg<ti>& sprite, const CImg<tm>& mask, const float opacity=1,
                        const float mask_max_value=1) {
      return draw_image(x0,0,sprite,mask,opacity,mask_max_value);
    }

    //! Draw an image.
    template<typename ti, typename tm>
    CImg<T>& draw_image(const CImg<ti>& sprite, const CImg<tm>& mask, const float opacity=1,
                        const float mask_max_value=1) {
      return draw_image(0,sprite,mask,opacity,mask_max_value);
    }

    //! Draw a text string.
    /**
       \param x0 X-coordinate of the text in the image instance.
       \param y0 Y-coordinate of the text in the image instance.
       \param text Format of the text ('printf'-style format string).
       \param foreground_color Pointer to \c spectrum() consecutive values, defining the foreground drawing color.
       \param background_color Pointer to \c spectrum() consecutive values, defining the background drawing color.
       \param opacity Drawing opacity.
       \param font Font used for drawing text.
    **/
    template<typename tc1, typename tc2, typename t>
    CImg<T>& draw_text(const int x0, const int y0,
                       const char *const text,
                       const tc1 *const foreground_color, const tc2 *const background_color,
                       const float opacity, const CImgList<t>& font, ...) {
      if (!font) return *this;
      char tmp[2048] = { 0 }; std::va_list ap; va_start(ap,font);
      cimg_vsnprintf(tmp,sizeof(tmp),text,ap); va_end(ap);
      return _draw_text(x0,y0,tmp,foreground_color,background_color,opacity,font);
    }

    //! Draw a text string \overloading.
    /**
       \note A transparent background is used for the text.
    **/
    template<typename tc, typename t>
    CImg<T>& draw_text(const int x0, const int y0,
                       const char *const text,
                       const tc *const foreground_color, const int,
                       const float opacity, const CImgList<t>& font, ...) {
      if (!font) return *this;
      char tmp[2048] = { 0 }; std::va_list ap; va_start(ap,font);
      cimg_vsnprintf(tmp,sizeof(tmp),text,ap); va_end(ap);
      return _draw_text(x0,y0,tmp,foreground_color,(tc*)0,opacity,font);
    }

    //! Draw a text string \overloading.
    /**
       \note A transparent foreground is used for the text.
    **/
    template<typename tc, typename t>
    CImg<T>& draw_text(const int x0, const int y0,
                       const char *const text,
                       const int, const tc *const background_color,
                       const float opacity, const CImgList<t>& font, ...) {
      if (!font) return *this;
      char tmp[2048] = { 0 }; std::va_list ap; va_start(ap,font);
      cimg_vsnprintf(tmp,sizeof(tmp),text,ap); va_end(ap);
      return _draw_text(x0,y0,tmp,(tc*)0,background_color,opacity,font);
    }

    //! Draw a text string \overloading.
    /**
       \param x0 X-coordinate of the text in the image instance.
       \param y0 Y-coordinate of the text in the image instance.
       \param text Format of the text ('printf'-style format string).
       \param foreground_color Array of spectrum() values of type \c T, defining the foreground color (0 means 'transparent').
       \param background_color Array of spectrum() values of type \c T, defining the background color (0 means 'transparent').
       \param opacity Drawing opacity.
       \param font_height Height of the text font (exact match for 13,24,32,57, interpolated otherwise).
    **/
    template<typename tc1, typename tc2>
    CImg<T>& draw_text(const int x0, const int y0,
                       const char *const text,
                       const tc1 *const foreground_color, const tc2 *const background_color,
                       const float opacity=1, const unsigned int font_height=13, ...) {
      if (!font_height) return *this;
      cimg::mutex(9);
      char tmp[2048] = { 0 }; std::va_list ap; va_start(ap,font_height); cimg_vsnprintf(tmp,sizeof(tmp),text,ap); va_end(ap);
      static CImgList<floatT> font;
      const unsigned int
        ref_height = font_height<=13?13:font_height<=28?24:font_height<=32?32:57,
        padding_x = font_height<=18?1:font_height<=32?2:3;
      if (!font || font[0]._height!=font_height) {
        font = CImgList<floatT>::font(ref_height,true);
        font[0].assign(1,font_height);
        if (ref_height==font_height) cimglist_for(font,l) font[l].resize(font[l]._width + padding_x,-100,-100,-100,0);
      }
      if (is_empty()) {
        if (font[0]._spectrum!=1) cimglist_for_in(font,0,255,l) font[l].channel(0);
      } else if (font[0]._spectrum<_spectrum) cimglist_for_in(font,0,255,l) font[l].resize(-100,-100,1,_spectrum);
      if (ref_height!=font_height) for (const char *ptrs = tmp; *ptrs; ++ptrs) {
          const unsigned int __c = (unsigned int)(unsigned char)*ptrs, _c = (__c=='\t')?' ':__c;
          if (_c<font._width) {
            CImg<floatT> &c = font[_c];
            if (c._height!=font_height) {
              c.resize(cimg::max(1U,c._width*font_height/c._height),font_height,-100,-100,c._height>font_height?2:3);
              c.resize(c._width + padding_x,-100,-100,-100,0);
            }
          }
          if (_c+256U<font._width) {
            CImg<floatT> &c = font[_c+256];
            if (c._height!=font_height) {
              c.resize(cimg::max(1U,c._width*font_height/c._height),font_height,-100,-100,c._height>font_height?2:3);
              c.resize(c._width + padding_x,-100,-100,-100,0);
            }
          }
        }
      _draw_text(x0,y0,tmp,foreground_color,background_color,opacity,font);
      cimg::mutex(9,0);
      return *this;
    }

    //! Draw a text string \overloading.
    template<typename tc>
    CImg<T>& draw_text(const int x0, const int y0,
                       const char *const text,
                       const tc *const foreground_color, const int background_color=0,
                       const float opacity=1, const unsigned int font_height=13, ...) {
      if (!font_height) return *this;
      cimg::unused(background_color);
      char tmp[2048] = { 0 }; std::va_list ap; va_start(ap,font_height); cimg_vsnprintf(tmp,sizeof(tmp),text,ap); va_end(ap);
      return draw_text(x0,y0,"%s",foreground_color,(const tc*)0,opacity,font_height,tmp);
    }

    //! Draw a text string \overloading.
    template<typename tc>
    CImg<T>& draw_text(const int x0, const int y0,
                       const char *const text,
                       const int, const tc *const background_color,
                       const float opacity=1, const unsigned int font_height=13, ...) {
      if (!font_height) return *this;
      char tmp[2048] = { 0 }; std::va_list ap; va_start(ap,font_height); cimg_vsnprintf(tmp,sizeof(tmp),text,ap); va_end(ap);
      return draw_text(x0,y0,"%s",(tc*)0,background_color,opacity,font_height,tmp);
    }

    template<typename tc1, typename tc2, typename t>
    CImg<T>& _draw_text(const int x0, const int y0,
                        const char *const text,
                        const tc1 *const foreground_color, const tc2 *const background_color,
                        const float opacity, const CImgList<t>& font) {
      if (!text) return *this;
      if (!font)
        throw CImgArgumentException(_cimg_instance
                                    "draw_text(): Empty specified font.",
                                    cimg_instance);
      const unsigned int text_length = (unsigned int)std::strlen(text);
      if (is_empty()) {
        // If needed, pre-compute necessary size of the image
        int x = 0, y = 0, w = 0;
        unsigned char c = 0;
        for (unsigned int i = 0; i<text_length; ++i) {
          c = text[i];
          switch (c) {
          case '\n' : y+=font[0]._height; if (x>w) w = x; x = 0; break;
          case '\t' : x+=4*font[' ']._width; break;
          default : if (c<font._width) x+=font[c]._width;
          }
        }
        if (x!=0 || c=='\n') {
          if (x>w) w=x;
          y+=font[0]._height;
        }
        assign(x0+w,y0+y,1,font[0]._spectrum,0);
        if (background_color) cimg_forC(*this,c) get_shared_channel(c).fill((T)background_color[c]);
      }

      int x = x0, y = y0;
      CImg<t> letter;
      for (unsigned int i = 0; i<text_length; ++i) {
        const unsigned char c = text[i];
        switch (c) {
        case '\n' : y+=font[0]._height; x = x0; break;
        case '\t' : x+=4*font[' ']._width; break;
        default : if (c<font._width) {
          letter = font[c];
          const unsigned int cmin = cimg::min(_spectrum,letter._spectrum);
          const CImg<t>& mask = (c+256)<(int)font._width?font[c+256]:font[c];
          if (foreground_color)
            for (unsigned long p = 0; p<(unsigned long)letter._width*letter._height; ++p)
              if (mask(p)) for (unsigned int c = 0; c<cmin; ++c) letter(p,0,0,c) = (t)(letter(p,0,0,c)*foreground_color[c]);
          if (background_color)
            for (unsigned long p = 0; p<(unsigned long)letter._width*letter._height; ++p)
              if (!mask(p)) for (unsigned int c = 0; c<cmin; ++c) letter(p,0,0,c) = (t)background_color[c];
          if (!background_color && font._width>=512) draw_image(x,y,letter,mask,opacity,(T)1);
          else draw_image(x,y,letter,opacity);
          x+=letter._width;
          }
        }
      }
      return *this;
    }

    //! Draw a 2d vector field.
    /**
       \param flow Image of 2d vectors used as input data.
       \param color Image of spectrum()-D vectors corresponding to the color of each arrow.
       \param opacity Drawing opacity.
       \param sampling Length (in pixels) between each arrow.
       \param factor Length factor of each arrow (if <0, computed as a percentage of the maximum length).
       \param is_arrow Tells if arrows must be drawn, instead of oriented segments.
       \param pattern Used pattern to draw lines.
       \note Clipping is supported.
    **/
    template<typename t1, typename t2>
    CImg<T>& draw_quiver(const CImg<t1>& flow,
                         const t2 *const color, const float opacity=1,
                         const unsigned int sampling=25, const float factor=-20,
                         const bool is_arrow=true, const unsigned int pattern=~0U) {
      return draw_quiver(flow,CImg<t2>(color,_spectrum,1,1,1,true),opacity,sampling,factor,is_arrow,pattern);
    }

    //! Draw a 2d vector field, using a field of colors.
    /**
       \param flow Image of 2d vectors used as input data.
       \param color Image of spectrum()-D vectors corresponding to the color of each arrow.
       \param opacity Opacity of the drawing.
       \param sampling Length (in pixels) between each arrow.
       \param factor Length factor of each arrow (if <0, computed as a percentage of the maximum length).
       \param is_arrow Tells if arrows must be drawn, instead of oriented segments.
       \param pattern Used pattern to draw lines.
       \note Clipping is supported.
    **/
    template<typename t1, typename t2>
    CImg<T>& draw_quiver(const CImg<t1>& flow,
                         const CImg<t2>& color, const float opacity=1,
                         const unsigned int sampling=25, const float factor=-20,
                         const bool is_arrow=true, const unsigned int pattern=~0U) {
      if (is_empty()) return *this;
      if (!flow || flow._spectrum!=2)
        throw CImgArgumentException(_cimg_instance
                                    "draw_quiver(): Invalid dimensions of specified flow (%u,%u,%u,%u,%p).",
                                    cimg_instance,
                                    flow._width,flow._height,flow._depth,flow._spectrum,flow._data);
      if (sampling<=0)
        throw CImgArgumentException(_cimg_instance
                                    "draw_quiver(): Invalid sampling value %g "
                                    "(should be >0)",
                                    cimg_instance,
                                    sampling);
      const bool colorfield = (color._width==flow._width && color._height==flow._height && color._depth==1 && color._spectrum==_spectrum);
      if (is_overlapped(flow)) return draw_quiver(+flow,color,opacity,sampling,factor,is_arrow,pattern);
      float vmax,fact;
      if (factor<=0) {
        float m, M = (float)flow.get_norm(2).max_min(m);
        vmax = (float)cimg::max(cimg::abs(m),cimg::abs(M));
        if (!vmax) vmax = 1;
        fact = -factor;
      } else { fact = factor; vmax = 1; }

      for (unsigned int y = sampling/2; y<_height; y+=sampling)
        for (unsigned int x = sampling/2; x<_width; x+=sampling) {
          const unsigned int X = x*flow._width/_width, Y = y*flow._height/_height;
          float u = (float)flow(X,Y,0,0)*fact/vmax, v = (float)flow(X,Y,0,1)*fact/vmax;
          if (is_arrow) {
            const int xx = x+(int)u, yy = y+(int)v;
            if (colorfield) draw_arrow(x,y,xx,yy,color.get_vector_at(X,Y)._data,opacity,45,sampling/5.0f,pattern);
            else draw_arrow(x,y,xx,yy,color._data,opacity,45,sampling/5.0f,pattern);
          } else {
            if (colorfield) draw_line((int)(x-0.5*u),(int)(y-0.5*v),(int)(x+0.5*u),(int)(y+0.5*v),color.get_vector_at(X,Y)._data,opacity,pattern);
            else draw_line((int)(x-0.5*u),(int)(y-0.5*v),(int)(x+0.5*u),(int)(y+0.5*v),color._data,opacity,pattern);
          }
        }

      return *this;
    }

    //! Draw a labeled horizontal axis.
    /**
       \param values_x Values along the horizontal axis.
       \param y Y-coordinate of the horizontal axis in the image instance.
       \param color Pointer to \c spectrum() consecutive values, defining the drawing color.
       \param opacity Drawing opacity.
       \param pattern Drawing pattern.
       \param font_height Height of the labels (exact match for 13,24,32,57, interpolated otherwise).
       \param allow_zero Enable/disable the drawing of label '0' if found.
    **/
    template<typename t, typename tc>
    CImg<T>& draw_axis(const CImg<t>& values_x, const int y,
                       const tc *const color, const float opacity=1,
                       const unsigned int pattern=~0U, const unsigned int font_height=13,
                       const bool allow_zero=true) {
      if (is_empty()) return *this;
      const int yt = (y+3+font_height)<_height?(y+3):(y-2-font_height);
      const int siz = (int)values_x.size()-1;
      char txt[32] = { 0 };
      CImg<T> label;
      if (siz<=0) { // Degenerated case.
        draw_line(0,y,_width-1,y,color,opacity,pattern);
        if (!siz) {
          cimg_snprintf(txt,sizeof(txt),"%g",(double)*values_x);
          label.assign().draw_text(0,0,txt,color,(tc*)0,opacity,font_height);
          const int
            _xt = (width() - label.width())/2,
            xt = _xt<3?3:_xt+label.width()>=width()-2?width()-3-label.width():_xt;
          draw_point(width()/2,y-1,color,opacity).draw_point(width()/2,y+1,color,opacity);
          if (allow_zero || txt[0]!='0' || txt[1]!=0)
            draw_text(xt,yt,txt,color,(tc*)0,opacity,font_height);
        }
      } else { // Regular case.
        if (values_x[0]<values_x[siz]) draw_arrow(0,y,_width-1,y,color,opacity,30,5,pattern);
        else draw_arrow(_width-1,y,0,y,color,opacity,30,5,pattern);
        cimg_foroff(values_x,x) {
          cimg_snprintf(txt,sizeof(txt),"%g",(double)values_x(x));
          label.assign().draw_text(0,0,txt,color,(tc*)0,opacity,font_height);
          const int
            xi = (int)(x*(_width-1)/siz),
            _xt = xi - label.width()/2,
            xt = _xt<3?3:_xt+label.width()>=width()-2?width()-3-label.width():_xt;
          draw_point(xi,y-1,color,opacity).draw_point(xi,y+1,color,opacity);
          if (allow_zero || txt[0]!='0' || txt[1]!=0)
            draw_text(xt,yt,txt,color,(tc*)0,opacity,font_height);
        }
      }
      return *this;
    }

    //! Draw a labeled vertical axis.
    /**
       \param x X-coordinate of the vertical axis in the image instance.
       \param values_y Values along the Y-axis.
       \param color Pointer to \c spectrum() consecutive values, defining the drawing color.
       \param opacity Drawing opacity.
       \param pattern Drawing pattern.
       \param font_height Height of the labels (exact match for 13,24,32,57, interpolated otherwise).
       \param allow_zero Enable/disable the drawing of label '0' if found.
    **/
    template<typename t, typename tc>
    CImg<T>& draw_axis(const int x, const CImg<t>& values_y,
                       const tc *const color, const float opacity=1,
                       const unsigned int pattern=~0U, const unsigned int font_height=13,
                       const bool allow_zero=true) {
      if (is_empty()) return *this;
      int siz = (int)values_y.size()-1;
      char txt[32] = { 0 };
      CImg<T> label;
      if (siz<=0) { // Degenerated case.
        draw_line(x,0,x,_height-1,color,opacity,pattern);
        if (!siz) {
          cimg_snprintf(txt,sizeof(txt),"%g",(double)*values_y);
          label.assign().draw_text(0,0,txt,color,(tc*)0,opacity,font_height);
          const int
            _yt = (height() - label.height())/2,
            yt = _yt<0?0:_yt+label.height()>=height()?height()-1-label.height():_yt,
            _xt = x - 2 - label.width(),
            xt = _xt>=0?_xt:x+3;
          draw_point(x-1,height()/2,color,opacity).draw_point(x+1,height()/2,color,opacity);
          if (allow_zero || txt[0]!='0' || txt[1]!=0)
            draw_text(xt,yt,txt,color,(tc*)0,opacity,font_height);
        }
      } else { // Regular case.
        if (values_y[0]<values_y[siz]) draw_arrow(x,0,x,_height-1,color,opacity,30,5,pattern);
        else draw_arrow(x,_height-1,x,0,color,opacity,30,5,pattern);
        cimg_foroff(values_y,y) {
          cimg_snprintf(txt,sizeof(txt),"%g",(double)values_y(y));
          label.assign().draw_text(0,0,txt,color,(tc*)0,opacity,font_height);
          const int
            yi = (int)(y*(_height-1)/siz),
            _yt = yi - label.height()/2,
            yt = _yt<0?0:_yt+label.height()>=height()?height()-1-label.height():_yt,
            _xt = x - 2 - label.width(),
            xt = _xt>=0?_xt:x+3;
          draw_point(x-1,yi,color,opacity).draw_point(x+1,yi,color,opacity);
          if (allow_zero || txt[0]!='0' || txt[1]!=0)
            draw_text(xt,yt,txt,color,(tc*)0,opacity,font_height);
        }
      }
      return *this;
    }

    //! Draw labeled horizontal and vertical axes.
    /**
       \param values_x Values along the X-axis.
       \param values_y Values along the Y-axis.
       \param color Pointer to \c spectrum() consecutive values, defining the drawing color.
       \param opacity Drawing opacity.
       \param pattern_x Drawing pattern for the X-axis.
       \param pattern_y Drawing pattern for the Y-axis.
       \param font_height Height of the labels (exact match for 13,24,32,57, interpolated otherwise).
       \param allow_zero Enable/disable the drawing of label '0' if found.
    **/
    template<typename tx, typename ty, typename tc>
    CImg<T>& draw_axes(const CImg<tx>& values_x, const CImg<ty>& values_y,
                       const tc *const color, const float opacity=1,
                       const unsigned int pattern_x=~0U, const unsigned int pattern_y=~0U,
                       const unsigned int font_height=13, const bool allow_zero=true) {
      if (is_empty()) return *this;
      const CImg<tx> nvalues_x(values_x._data,values_x.size(),1,1,1,true);
      const int sizx = (int)values_x.size()-1, wm1 = width()-1;
      if (sizx>=0) {
        float ox = (float)*nvalues_x;
        for (unsigned int x = sizx?1:0; x<_width; ++x) {
          const float nx = (float)nvalues_x._linear_atX((float)x*sizx/wm1);
          if (nx*ox<=0) { draw_axis(nx==0?x:x-1,values_y,color,opacity,pattern_y,font_height,allow_zero); break; }
          ox = nx;
        }
      }
      const CImg<ty> nvalues_y(values_y._data,values_y.size(),1,1,1,true);
      const int sizy = (int)values_y.size()-1, hm1 = height()-1;
      if (sizy>0) {
        float oy = (float)nvalues_y[0];
        for (unsigned int y = sizy?1:0; y<_height; ++y) {
          const float ny = (float)nvalues_y._linear_atX((float)y*sizy/hm1);
          if (ny*oy<=0) { draw_axis(values_x,ny==0?y:y-1,color,opacity,pattern_x,font_height,allow_zero); break; }
          oy = ny;
        }
      }
      return *this;
    }

    //! Draw labeled horizontal and vertical axes \overloading.
    template<typename tc>
    CImg<T>& draw_axes(const float x0, const float x1, const float y0, const float y1,
                       const tc *const color, const float opacity=1,
                       const int subdivisionx=-60, const int subdivisiony=-60,
                       const float precisionx=0, const float precisiony=0,
                       const unsigned int pattern_x=~0U, const unsigned int pattern_y=~0U,
                       const unsigned int font_height=13) {
      if (is_empty()) return *this;
      const bool allow_zero = (x0*x1>0) || (y0*y1>0);
      const float
        dx = cimg::abs(x1-x0), dy = cimg::abs(y1-y0),
        px = dx<=0?1:precisionx==0?(float)std::pow(10.0,(int)std::log10(dx)-2.0):precisionx,
        py = dy<=0?1:precisiony==0?(float)std::pow(10.0,(int)std::log10(dy)-2.0):precisiony;
      if (x0!=x1 && y0!=y1)
        draw_axes(CImg<floatT>::sequence(subdivisionx>0?subdivisionx:1-width()/subdivisionx,x0,x1).round(px),
                  CImg<floatT>::sequence(subdivisiony>0?subdivisiony:1-height()/subdivisiony,y0,y1).round(py),
                  color,opacity,pattern_x,pattern_y,font_height,allow_zero);
      else if (x0==x1 && y0!=y1)
        draw_axis((int)x0,CImg<floatT>::sequence(subdivisiony>0?subdivisiony:1-height()/subdivisiony,y0,y1).round(py),
                  color,opacity,pattern_y,font_height);
      else if (x0!=x1 && y0==y1)
        draw_axis(CImg<floatT>::sequence(subdivisionx>0?subdivisionx:1-width()/subdivisionx,x0,x1).round(px),(int)y0,
                  color,opacity,pattern_x,font_height);
      return *this;
    }

    //! Draw 2d grid.
    /**
       \param values_x X-coordinates of the vertical lines.
       \param values_y Y-coordinates of the horizontal lines.
       \param color Pointer to \c spectrum() consecutive values, defining the drawing color.
       \param opacity Drawing opacity.
       \param pattern_x Drawing pattern for vertical lines.
       \param pattern_y Drawing pattern for horizontal lines.
    **/
    template<typename tx, typename ty, typename tc>
    CImg<T>& draw_grid(const CImg<tx>& values_x, const CImg<ty>& values_y,
                       const tc *const color, const float opacity=1,
                       const unsigned int pattern_x=~0U, const unsigned int pattern_y=~0U) {
      if (is_empty()) return *this;
      if (values_x) cimg_foroff(values_x,x) {
          const int xi = (int)values_x[x];
          if (xi>=0 && xi<width()) draw_line(xi,0,xi,_height-1,color,opacity,pattern_x);
        }
      if (values_y) cimg_foroff(values_y,y) {
          const int yi = (int)values_y[y];
          if (yi>=0 && yi<height()) draw_line(0,yi,_width-1,yi,color,opacity,pattern_y);
        }
      return *this;
    }

    //! Draw 2d grid \simplification.
    template<typename tc>
    CImg<T>& draw_grid(const float delta_x,  const float delta_y,
                       const float offsetx, const float offsety,
                       const bool invertx, const bool inverty,
                       const tc *const color, const float opacity=1,
                       const unsigned int pattern_x=~0U, const unsigned int pattern_y=~0U) {
      if (is_empty()) return *this;
      CImg<uintT> seqx, seqy;
      if (delta_x!=0) {
        const float dx = delta_x>0?delta_x:_width*-delta_x/100;
        const unsigned int nx = (unsigned int)(_width/dx);
        seqx = CImg<uintT>::sequence(1+nx,0,(unsigned int)(dx*nx));
        if (offsetx) cimg_foroff(seqx,x) seqx(x) = (unsigned int)cimg::mod(seqx(x)+offsetx,(float)_width);
        if (invertx) cimg_foroff(seqx,x) seqx(x) = _width - 1 - seqx(x);
      }
      if (delta_y!=0) {
        const float dy = delta_y>0?delta_y:_height*-delta_y/100;
        const unsigned int ny = (unsigned int)(_height/dy);
        seqy = CImg<uintT>::sequence(1+ny,0,(unsigned int)(dy*ny));
        if (offsety) cimg_foroff(seqy,y) seqy(y) = (unsigned int)cimg::mod(seqy(y)+offsety,(float)_height);
        if (inverty) cimg_foroff(seqy,y) seqy(y) = _height - 1 - seqy(y);
     }
      return draw_grid(seqx,seqy,color,opacity,pattern_x,pattern_y);
    }

    //! Draw 1d graph.
    /**
       \param data Image containing the graph values I = f(x).
       \param color Pointer to \c spectrum() consecutive values, defining the drawing color.
       \param opacity Drawing opacity.

       \param plot_type Define the type of the plot:
                      - 0 = No plot.
                      - 1 = Plot using segments.
                      - 2 = Plot using cubic splines.
                      - 3 = Plot with bars.
       \param vertex_type Define the type of points:
                      - 0 = No points.
                      - 1 = Point.
                      - 2 = Straight cross.
                      - 3 = Diagonal cross.
                      - 4 = Filled circle.
                      - 5 = Outlined circle.
                      - 6 = Square.
                      - 7 = Diamond.
       \param ymin Lower bound of the y-range.
       \param ymax Upper bound of the y-range.
       \param pattern Drawing pattern.
       \note
         - if \c ymin==ymax==0, the y-range is computed automatically from the input samples.
    **/
    template<typename t, typename tc>
    CImg<T>& draw_graph(const CImg<t>& data,
                        const tc *const color, const float opacity=1,
                        const unsigned int plot_type=1, const int vertex_type=1,
                        const double ymin=0, const double ymax=0, const unsigned int pattern=~0U) {
      if (is_empty() || _height<=1) return *this;
      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_graph(): Specified color is (null).",
                                    cimg_instance);

      // Create shaded colors for displaying bar plots.
      CImg<tc> color1, color2;
      if (plot_type==3) {
        color1.assign(_spectrum); color2.assign(_spectrum);
        cimg_forC(*this,c) { color1[c] = (tc)cimg::min((float)cimg::type<tc>::max(),color[c]*1.2f); color2[c] = (tc)(color[c]*0.4f); }
      }

      // Compute min/max and normalization factors.
      const unsigned long
        siz = data.size(),
        _siz1 = siz - (plot_type!=3?1:0),
        siz1 = _siz1?_siz1:1;
      const unsigned int
        _width1 = _width - (plot_type!=3?1:0),
        width1 = _width1?_width1:1;
      double m = ymin, M = ymax;
      if (ymin==ymax) m = (double)data.max_min(M);
      if (m==M) { --m; ++M; }
      const float ca = (float)(M-m)/(_height-1);
      bool init_hatch = true;

      // Draw graph edges
      switch (plot_type%4) {
      case 1 : { // Segments
        int oX = 0, oY = (int)((data[0]-m)/ca);
        if (siz==1) {
          const int Y = (int)((*data-m)/ca);
          draw_line(0,Y,width()-1,Y,color,opacity,pattern);
        } else for (unsigned long off = 1; off<siz; ++off) {
            const int
              X = off*_width1/siz1,
              Y = (int)((data[off]-m)/ca);
            draw_line(oX,oY,X,Y,color,opacity,pattern,init_hatch);
            oX = X; oY = Y;
            init_hatch = false;
          }
      } break;
      case 2 : { // Spline
        const CImg<t> ndata(data._data,siz,1,1,1,true);
        int oY = (int)((data[0]-m)/ca);
        cimg_forX(*this,x) {
          const int Y = (int)((ndata._cubic_atX((float)x*siz1/width1)-m)/ca);
          if (x>0) draw_line(x,oY,x+1,Y,color,opacity,pattern,init_hatch);
          init_hatch = false;
          oY = Y;
        }
      } break;
      case 3 : { // Bars
        const int Y0 = (int)(-m/ca);
        int oX = 0;
        cimg_foroff(data,off) {
          const int
            X = (off+1)*_width/siz-1,
            Y = (int)((data[off]-m)/ca);
          draw_rectangle(oX,Y0,X,Y,color,opacity).
            draw_line(oX,Y,oX,Y0,color2.data(),opacity).
            draw_line(oX,Y0,X,Y0,Y<=Y0?color2.data():color1.data(),opacity).
            draw_line(X,Y,X,Y0,color1.data(),opacity).
            draw_line(oX,Y,X,Y,Y<=Y0?color1.data():color2.data(),opacity);
          oX = X+1;
        }
      } break;
      default : break; // No edges
      }

      // Draw graph points
      const unsigned int wb2 = plot_type==3?_width1/(2*siz):0;
      switch (vertex_type%8) {
      case 1 : { // Point
        cimg_foroff(data,off) {
          const int
            X = off*_width1/siz1 + wb2,
            Y = (int)((data[off]-m)/ca);
          draw_point(X,Y,color,opacity);
        }
      } break;
      case 2 : { // Straight Cross
        cimg_foroff(data,off) {
          const int
            X = off*_width1/siz1 + wb2,
            Y = (int)((data[off]-m)/ca);
          draw_line(X-3,Y,X+3,Y,color,opacity).draw_line(X,Y-3,X,Y+3,color,opacity);
        }
      } break;
      case 3 : { // Diagonal Cross
        cimg_foroff(data,off) {
          const int
            X = off*_width1/siz1 + wb2,
            Y = (int)((data[off]-m)/ca);
          draw_line(X-3,Y-3,X+3,Y+3,color,opacity).draw_line(X-3,Y+3,X+3,Y-3,color,opacity);
        }
      } break;
      case 4 : { // Filled Circle
        cimg_foroff(data,off) {
          const int
            X = off*_width1/siz1 + wb2,
            Y = (int)((data[off]-m)/ca);
          draw_circle(X,Y,3,color,opacity);
        }
      } break;
      case 5 : { // Outlined circle
        cimg_foroff(data,off) {
          const int
            X = off*_width1/siz1 + wb2,
            Y = (int)((data[off]-m)/ca);
          draw_circle(X,Y,3,color,opacity,0U);
        }
      } break;
      case 6 : { // Square
        cimg_foroff(data,off) {
          const int
            X = off*_width1/siz1 + wb2,
            Y = (int)((data[off]-m)/ca);
          draw_rectangle(X-3,Y-3,X+3,Y+3,color,opacity,~0U);
        }
      } break;
      case 7 : { // Diamond
        cimg_foroff(data,off) {
          const int
            X = off*_width1/siz1 + wb2,
            Y = (int)((data[off]-m)/ca);
          draw_line(X,Y-4,X+4,Y,color,opacity).
            draw_line(X+4,Y,X,Y+4,color,opacity).
            draw_line(X,Y+4,X-4,Y,color,opacity).
            draw_line(X-4,Y,X,Y-4,color,opacity);
        }
      } break;
      default : break; // No points
      }
      return *this;
    }

    //! Draw filled 3d region with the flood fill algorithm.
    /**
       \param x X-coordinate of the starting point of the region to fill.
       \param y Y-coordinate of the starting point of the region to fill.
       \param z Z-coordinate of the starting point of the region to fill.
       \param color Pointer to \c spectrum() consecutive values, defining the drawing color.
       \param[out] region Image that will contain the mask of the filled region mask, as an output.
       \param sigma Tolerance concerning neighborhood values.
       \param opacity Opacity of the drawing.
       \param is_high_connexity Tells if 8-connexity must be used (only for 2d images).
       \return \c region is initialized with the binary mask of the filled region.
    **/
    template<typename tc, typename t>
    CImg<T>& draw_fill(const int x, const int y, const int z,
                       const tc *const color, const float opacity,
                       CImg<t>& region, const float sigma=0,
                       const bool is_high_connexity=false) {

#define _cimg_draw_fill_test(x,y,z,res) if (region(x,y,z)) res = false; else { \
  res = true; \
  const T *reference_col = reference_color._data + _spectrum, *ptrs = data(x,y,z) + siz; \
  for (unsigned int i = _spectrum; res && i; --i) { ptrs-=whd; res = (cimg::abs(*ptrs - *(--reference_col))<=sigma); } \
  region(x,y,z) = (t)(res?1:noregion); \
}

#define _cimg_draw_fill_set(x,y,z) { \
  const tc *col = color; \
  T *ptrd = data(x,y,z); \
  if (opacity>=1) cimg_forC(*this,c) { *ptrd = (T)*(col++); ptrd+=whd; } \
  else cimg_forC(*this,c) { *ptrd = (T)(*(col++)*nopacity + *ptrd*copacity); ptrd+=whd; } \
}

#define _cimg_draw_fill_insert(x,y,z) { \
  if (posr1>=remaining._height) remaining.resize(3,remaining._height<<1,1,1,0); \
  unsigned int *ptrr = remaining.data(0,posr1); \
  *(ptrr++) = x; *(ptrr++) = y; *(ptrr++) = z; ++posr1; \
}

#define _cimg_draw_fill_test_neighbor(x,y,z,cond) if (cond) { \
  const unsigned int tx = x, ty = y, tz = z; \
  _cimg_draw_fill_test(tx,ty,tz,res); if (res) _cimg_draw_fill_insert(tx,ty,tz); \
}

      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_fill(): Specified color is (null).",
                                    cimg_instance);

      region.assign(_width,_height,_depth,1,(t)0);
      if (x>=0 && x<width() && y>=0 && y<height() && z>=0 && z<depth()) {
        const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
        const unsigned long whd = (unsigned long)_width*_height*_depth, siz = (unsigned long)_spectrum*whd;
        const unsigned int W1 = _width-1, H1 = _height-1, D1 = _depth-1;
        const bool is_3d = (_depth>1);
        const CImg<T> reference_color = get_vector_at(x,y,z);
        CImg<uintT> remaining(3,512,1,1,0);
        remaining(0,0) = x; remaining(1,0) = y; remaining(2,0) = z;
        unsigned int posr0 = 0, posr1 = 1;
        region(x,y,z) = (t)1;
        const t noregion = ((t)1==(t)2)?(t)0:(t)(-1);
        if (is_3d) do { // 3d version of the filling algorithm
          const unsigned int *pcurr = remaining.data(0,posr0++), xc = *(pcurr++), yc = *(pcurr++), zc = *(pcurr++);
          if (posr0>=512) { remaining.shift(0,-(int)posr0); posr1-=posr0; posr0 = 0; }
          bool cont, res;
          unsigned int nxc = xc;
          do { // X-backward
            _cimg_draw_fill_set(nxc,yc,zc);
            _cimg_draw_fill_test_neighbor(nxc,yc-1,zc,yc!=0);
            _cimg_draw_fill_test_neighbor(nxc,yc+1,zc,yc<H1);
            _cimg_draw_fill_test_neighbor(nxc,yc,zc-1,zc!=0);
            _cimg_draw_fill_test_neighbor(nxc,yc,zc+1,zc<D1);
            if (nxc) { --nxc; _cimg_draw_fill_test(nxc,yc,zc,cont); } else cont = false;
          } while (cont);
          nxc = xc;
          do { // X-forward
            if ((++nxc)<=W1) { _cimg_draw_fill_test(nxc,yc,zc,cont); } else cont = false;
            if (cont) {
              _cimg_draw_fill_set(nxc,yc,zc);
              _cimg_draw_fill_test_neighbor(nxc,yc-1,zc,yc!=0);
              _cimg_draw_fill_test_neighbor(nxc,yc+1,zc,yc<H1);
              _cimg_draw_fill_test_neighbor(nxc,yc,zc-1,zc!=0);
              _cimg_draw_fill_test_neighbor(nxc,yc,zc+1,zc<D1);
            }
          } while (cont);
          unsigned int nyc = yc;
          do { // Y-backward
            if (nyc) { --nyc; _cimg_draw_fill_test(xc,nyc,zc,cont); } else cont = false;
            if (cont) {
              _cimg_draw_fill_set(xc,nyc,zc);
              _cimg_draw_fill_test_neighbor(xc-1,nyc,zc,xc!=0);
              _cimg_draw_fill_test_neighbor(xc+1,nyc,zc,xc<W1);
              _cimg_draw_fill_test_neighbor(xc,nyc,zc-1,zc!=0);
              _cimg_draw_fill_test_neighbor(xc,nyc,zc+1,zc<D1);
            }
          } while (cont);
          nyc = yc;
          do { // Y-forward
            if ((++nyc)<=H1) { _cimg_draw_fill_test(xc,nyc,zc,cont); } else cont = false;
            if (cont) {
              _cimg_draw_fill_set(xc,nyc,zc);
              _cimg_draw_fill_test_neighbor(xc-1,nyc,zc,xc!=0);
              _cimg_draw_fill_test_neighbor(xc+1,nyc,zc,xc<W1);
              _cimg_draw_fill_test_neighbor(xc,nyc,zc-1,zc!=0);
              _cimg_draw_fill_test_neighbor(xc,nyc,zc+1,zc<D1);
            }
          } while (cont);
          unsigned int nzc = zc;
          do { // Z-backward
            if (nzc) { --nzc; _cimg_draw_fill_test(xc,yc,nzc,cont); } else cont = false;
            if (cont) {
              _cimg_draw_fill_set(xc,yc,nzc);
              _cimg_draw_fill_test_neighbor(xc-1,yc,nzc,xc!=0);
              _cimg_draw_fill_test_neighbor(xc+1,yc,nzc,xc<W1);
              _cimg_draw_fill_test_neighbor(xc,yc-1,nzc,yc!=0);
              _cimg_draw_fill_test_neighbor(xc,yc+1,nzc,yc<H1);
            }
          } while (cont);
          nzc = zc;
          do { // Z-forward
            if ((++nzc)<=D1) { _cimg_draw_fill_test(xc,yc,nzc,cont); } else cont = false;
            if (cont) {
              _cimg_draw_fill_set(xc,nyc,zc);
              _cimg_draw_fill_test_neighbor(xc-1,yc,nzc,xc!=0);
              _cimg_draw_fill_test_neighbor(xc+1,yc,nzc,xc<W1);
              _cimg_draw_fill_test_neighbor(xc,yc-1,nzc,yc!=0);
              _cimg_draw_fill_test_neighbor(xc,yc+1,nzc,yc<H1);
            }
          } while (cont);
        } while (posr1>posr0);
        else do { // 2d version of the filling algorithm
          const unsigned int *pcurr = remaining.data(0,posr0++), xc = *(pcurr++), yc = *(pcurr++);
          if (posr0>=512) { remaining.shift(0,-(int)posr0); posr1-=posr0; posr0 = 0; }
          bool cont, res;
          unsigned int nxc = xc;
          do { // X-backward
            _cimg_draw_fill_set(nxc,yc,0);
            _cimg_draw_fill_test_neighbor(nxc,yc-1,0,yc!=0);
            _cimg_draw_fill_test_neighbor(nxc,yc+1,0,yc<H1);
            if (is_high_connexity) {
              _cimg_draw_fill_test_neighbor(nxc-1,yc-1,0,(nxc!=0 && yc!=0));
              _cimg_draw_fill_test_neighbor(nxc+1,yc-1,0,(nxc<W1 && yc!=0));
              _cimg_draw_fill_test_neighbor(nxc-1,yc+1,0,(nxc!=0 && yc<H1));
              _cimg_draw_fill_test_neighbor(nxc+1,yc+1,0,(nxc<W1 && yc<H1));
            }
            if (nxc) { --nxc; _cimg_draw_fill_test(nxc,yc,0,cont); } else cont = false;
          } while (cont);
          nxc = xc;
          do { // X-forward
            if ((++nxc)<=W1) { _cimg_draw_fill_test(nxc,yc,0,cont); } else cont = false;
            if (cont) {
              _cimg_draw_fill_set(nxc,yc,0);
              _cimg_draw_fill_test_neighbor(nxc,yc-1,0,yc!=0);
              _cimg_draw_fill_test_neighbor(nxc,yc+1,0,yc<H1);
              if (is_high_connexity) {
                _cimg_draw_fill_test_neighbor(nxc-1,yc-1,0,(nxc!=0 && yc!=0));
                _cimg_draw_fill_test_neighbor(nxc+1,yc-1,0,(nxc<W1 && yc!=0));
                _cimg_draw_fill_test_neighbor(nxc-1,yc+1,0,(nxc!=0 && yc<H1));
                _cimg_draw_fill_test_neighbor(nxc+1,yc+1,0,(nxc<W1 && yc<H1));
              }
            }
          } while (cont);
          unsigned int nyc = yc;
          do { // Y-backward
            if (nyc) { --nyc; _cimg_draw_fill_test(xc,nyc,0,cont); } else cont = false;
            if (cont) {
              _cimg_draw_fill_set(xc,nyc,0);
              _cimg_draw_fill_test_neighbor(xc-1,nyc,0,xc!=0);
              _cimg_draw_fill_test_neighbor(xc+1,nyc,0,xc<W1);
              if (is_high_connexity) {
                _cimg_draw_fill_test_neighbor(xc-1,nyc-1,0,(xc!=0 && nyc!=0));
                _cimg_draw_fill_test_neighbor(xc+1,nyc-1,0,(xc<W1 && nyc!=0));
                _cimg_draw_fill_test_neighbor(xc-1,nyc+1,0,(xc!=0 && nyc<H1));
                _cimg_draw_fill_test_neighbor(xc+1,nyc+1,0,(xc<W1 && nyc<H1));
              }
            }
          } while (cont);
          nyc = yc;
          do { // Y-forward
            if ((++nyc)<=H1) { _cimg_draw_fill_test(xc,nyc,0,cont); } else cont = false;
            if (cont) {
              _cimg_draw_fill_set(xc,nyc,0);
              _cimg_draw_fill_test_neighbor(xc-1,nyc,0,xc!=0);
              _cimg_draw_fill_test_neighbor(xc+1,nyc,0,xc<W1);
              if (is_high_connexity) {
                _cimg_draw_fill_test_neighbor(xc-1,nyc-1,0,(xc!=0 && nyc!=0));
                _cimg_draw_fill_test_neighbor(xc+1,nyc-1,0,(xc<W1 && nyc!=0));
                _cimg_draw_fill_test_neighbor(xc-1,nyc+1,0,(xc!=0 && nyc<H1));
                _cimg_draw_fill_test_neighbor(xc+1,nyc+1,0,(xc<W1 && nyc<H1));
              }
            }
          } while (cont);
        } while (posr1>posr0);
        if (noregion) cimg_for(region,ptrd,t) if (*ptrd==noregion) *ptrd = (t)0;
      }
      return *this;
    }

    //! Draw filled 3d region with the flood fill algorithm \simplification.
    template<typename tc>
    CImg<T>& draw_fill(const int x, const int y, const int z,
                       const tc *const color, const float opacity=1,
                       const float sigma=0, const bool is_high_connexity=false) {
      CImg<boolT> tmp;
      return draw_fill(x,y,z,color,opacity,tmp,sigma,is_high_connexity);
    }

    //! Draw filled 2d region with the flood fill algorithm \simplification.
    template<typename tc>
    CImg<T>& draw_fill(const int x, const int y,
                       const tc *const color, const float opacity=1,
                       const float sigma=0, const bool is_high_connexity=false) {
      CImg<boolT> tmp;
      return draw_fill(x,y,0,color,opacity,tmp,sigma,is_high_connexity);
    }

    //! Draw a random plasma texture.
    /**
       \param alpha Alpha-parameter.
       \param beta Beta-parameter.
       \param scale Scale-parameter.
       \note Use the mid-point algorithm to render.
    **/
    CImg<T>& draw_plasma(const float alpha=1, const float beta=0, const unsigned int scale=8) {
      if (is_empty()) return *this;
      const int w = width(), h = height();
      const Tfloat m = (Tfloat)cimg::type<T>::min(), M = (Tfloat)cimg::type<T>::max();
      cimg_forZC(*this,z,c) {
        CImg<T> ref = get_shared_slice(z,c);
        for (int delta = 1<<cimg::min(scale,31U); delta>1; delta>>=1) {
          const int delta2 = delta>>1;
          const float r = alpha*delta + beta;

          // Square step.
          for (int y0 = 0; y0<h; y0+=delta)
            for (int x0 = 0; x0<w; x0+=delta) {
              const int x1 = (x0 + delta)%w, y1 = (y0 + delta)%h, xc = (x0 + delta2)%w, yc = (y0 + delta2)%h;
              const Tfloat val = (Tfloat)(0.25f*(ref(x0,y0) + ref(x0,y1) + ref(x0,y1) + ref(x1,y1)) + r*cimg::crand());
              ref(xc,yc) = (T)(val<m?m:val>M?M:val);
            }

          // Diamond steps.
          for (int y = -delta2; y<h; y+=delta)
            for (int x0=0; x0<w; x0+=delta) {
              const int y0 = cimg::mod(y,h), x1 = (x0 + delta)%w, y1 = (y + delta)%h, xc = (x0 + delta2)%w, yc = (y + delta2)%h;
              const Tfloat val = (Tfloat)(0.25f*(ref(xc,y0) + ref(x0,yc) + ref(xc,y1) + ref(x1,yc)) + r*cimg::crand());
              ref(xc,yc) = (T)(val<m?m:val>M?M:val);
            }
          for (int y0 = 0; y0<h; y0+=delta)
            for (int x = -delta2; x<w; x+=delta) {
              const int x0 = cimg::mod(x,w), x1 = (x + delta)%w, y1 = (y0 + delta)%h, xc = (x + delta2)%w, yc = (y0 + delta2)%h;
              const Tfloat val = (Tfloat)(0.25f*(ref(xc,y0) + ref(x0,yc) + ref(xc,y1) + ref(x1,yc)) + r*cimg::crand());
              ref(xc,yc) = (T)(val<m?m:val>M?M:val);
            }
          for (int y = -delta2; y<h; y+=delta)
            for (int x = -delta2; x<w; x+=delta) {
              const int x0 = cimg::mod(x,w), y0 = cimg::mod(y,h), x1 = (x + delta)%w, y1 = (y + delta)%h, xc = (x + delta2)%w, yc = (y + delta2)%h;
              const Tfloat val = (Tfloat)(0.25f*(ref(xc,y0) + ref(x0,yc) + ref(xc,y1) + ref(x1,yc)) + r*cimg::crand());
                ref(xc,yc) = (T)(val<m?m:val>M?M:val);
            }
        }
      }
      return *this;
    }

    //! Draw a quadratic Mandelbrot or Julia 2d fractal.
    /**
       \param x0 X-coordinate of the upper-left pixel.
       \param y0 Y-coordinate of the upper-left pixel.
       \param x1 X-coordinate of the lower-right pixel.
       \param y1 Y-coordinate of the lower-right pixel.
       \param colormap Colormap.
       \param opacity Drawing opacity.
       \param z0r Real part of the upper-left fractal vertex.
       \param z0i Imaginary part of the upper-left fractal vertex.
       \param z1r Real part of the lower-right fractal vertex.
       \param z1i Imaginary part of the lower-right fractal vertex.
       \param iteration_max Maximum number of iterations for each estimated point.
       \param is_normalized_iteration Tells if iterations are normalized.
       \param is_julia_set Tells if the Mandelbrot or Julia set is rendered.
       \param param_r Real part of the Julia set parameter.
       \param param_i Imaginary part of the Julia set parameter.
       \note Fractal rendering is done by the Escape Time Algorithm.
    **/
    template<typename tc>
    CImg<T>& draw_mandelbrot(const int x0, const int y0, const int x1, const int y1,
                             const CImg<tc>& colormap, const float opacity=1,
                             const double z0r=-2, const double z0i=-2, const double z1r=2, const double z1i=2,
                             const unsigned int iteration_max=255,
                             const bool is_normalized_iteration=false,
                             const bool is_julia_set=false,
                             const double param_r=0, const double param_i=0) {
      if (is_empty()) return *this;
      CImg<tc> palette;
      if (colormap) palette.assign(colormap._data,colormap.size()/colormap._spectrum,1,1,colormap._spectrum,true);
      if (palette && palette._spectrum!=_spectrum)
        throw CImgArgumentException(_cimg_instance
                                    "draw_mandelbrot(): Instance and specified colormap (%u,%u,%u,%u,%p) have incompatible dimensions.",
                                    cimg_instance,
                                    colormap._width,colormap._height,colormap._depth,colormap._spectrum,colormap._data);

      const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0), ln2 = (float)std::log(2.0);
      unsigned int iteration = 0;
      cimg_for_inXY(*this,x0,y0,x1,y1,p,q) {
        const double x = z0r + p*(z1r-z0r)/_width, y = z0i + q*(z1i-z0i)/_height;
        double zr, zi, cr, ci;
        if (is_julia_set) { zr = x; zi = y; cr = param_r; ci = param_i; }
        else { zr = param_r; zi = param_i; cr = x; ci = y; }
        for (iteration=1; zr*zr + zi*zi<=4 && iteration<=iteration_max; ++iteration) {
          const double temp = zr*zr - zi*zi + cr;
          zi = 2*zr*zi + ci;
          zr = temp;
        }
        if (iteration>iteration_max) {
          if (palette) {
            if (opacity>=1) cimg_forC(*this,c) (*this)(p,q,0,c) = (T)palette(0,c);
            else cimg_forC(*this,c) (*this)(p,q,0,c) = (T)(palette(0,c)*nopacity + (*this)(p,q,0,c)*copacity);
          } else {
            if (opacity>=1) cimg_forC(*this,c) (*this)(p,q,0,c) = (T)0;
            else cimg_forC(*this,c) (*this)(p,q,0,c) = (T)((*this)(p,q,0,c)*copacity);
          }
        } else if (is_normalized_iteration) {
          const float
            normz = (float)cimg::abs(zr*zr+zi*zi),
            niteration = (float)(iteration + 1 - std::log(std::log(normz))/ln2);
          if (palette) {
            if (opacity>=1) cimg_forC(*this,c) (*this)(p,q,0,c) = (T)palette._linear_atX(niteration,c);
            else cimg_forC(*this,c) (*this)(p,q,0,c) = (T)(palette._linear_atX(niteration,c)*nopacity + (*this)(p,q,0,c)*copacity);
          } else {
            if (opacity>=1) cimg_forC(*this,c) (*this)(p,q,0,c) = (T)niteration;
            else cimg_forC(*this,c) (*this)(p,q,0,c) = (T)(niteration*nopacity + (*this)(p,q,0,c)*copacity);
          }
        } else {
          if (palette) {
            if (opacity>=1) cimg_forC(*this,c) (*this)(p,q,0,c) = (T)palette._atX(iteration,c);
            else cimg_forC(*this,c) (*this)(p,q,0,c) = (T)(palette(iteration,c)*nopacity + (*this)(p,q,0,c)*copacity);
          } else {
            if (opacity>=1) cimg_forC(*this,c) (*this)(p,q,0,c) = (T)iteration;
            else cimg_forC(*this,c) (*this)(p,q,0,c) = (T)(iteration*nopacity + (*this)(p,q,0,c)*copacity);
          }
        }
      }
      return *this;
    }

    //! Draw a quadratic Mandelbrot or Julia 2d fractal \overloading.
    template<typename tc>
    CImg<T>& draw_mandelbrot(const CImg<tc>& colormap, const float opacity=1,
                             const double z0r=-2, const double z0i=-2, const double z1r=2, const double z1i=2,
                             const unsigned int iteration_max=255,
                             const bool is_normalized_iteration=false,
                             const bool is_julia_set=false,
                             const double param_r=0, const double param_i=0) {
      return draw_mandelbrot(0,0,_width-1,_height-1,colormap,opacity,
                             z0r,z0i,z1r,z1i,iteration_max,is_normalized_iteration,is_julia_set,param_r,param_i);
    }

    //! Draw a 1d gaussian function.
    /**
       \param xc X-coordinate of the gaussian center.
       \param sigma Standard variation of the gaussian distribution.
       \param color Pointer to \c spectrum() consecutive values, defining the drawing color.
       \param opacity Drawing opacity.
    **/
    template<typename tc>
    CImg<T>& draw_gaussian(const float xc, const float sigma,
                           const tc *const color, const float opacity=1) {
      if (is_empty()) return *this;
      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_gaussian(): Specified color is (null).",
                                    cimg_instance);
      const float sigma2 = 2*sigma*sigma, nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
      const unsigned long whd = (unsigned long)_width*_height*_depth;
      const tc *col = color;
      cimg_forX(*this,x) {
        const float dx = (x - xc), val = (float)std::exp(-dx*dx/sigma2);
        T *ptrd = data(x,0,0,0);
        if (opacity>=1) cimg_forC(*this,c) { *ptrd = (T)(val*(*col++)); ptrd+=whd; }
        else cimg_forC(*this,c) { *ptrd = (T)(nopacity*val*(*col++) + *ptrd*copacity); ptrd+=whd; }
        col-=_spectrum;
      }
      return *this;
    }

    //! Draw a 2d gaussian function.
    /**
       \param xc X-coordinate of the gaussian center.
       \param yc Y-coordinate of the gaussian center.
       \param tensor Covariance matrix (must be 2x2).
       \param color Pointer to \c spectrum() consecutive values, defining the drawing color.
       \param opacity Drawing opacity.
    **/
    template<typename t, typename tc>
    CImg<T>& draw_gaussian(const float xc, const float yc, const CImg<t>& tensor,
                           const tc *const color, const float opacity=1) {
      if (is_empty()) return *this;
      if (tensor._width!=2 || tensor._height!=2 || tensor._depth!=1 || tensor._spectrum!=1)
        throw CImgArgumentException(_cimg_instance
                                    "draw_gaussian(): Specified tensor (%u,%u,%u,%u,%p) is not a 2x2 matrix.",
                                    cimg_instance,
                                    tensor._width,tensor._height,tensor._depth,tensor._spectrum,tensor._data);
      if (!color)
        throw CImgArgumentException(_cimg_instance
                                    "draw_gaussian(): Specified color is (null).",
                                    cimg_instance);
      typedef typename CImg<t>::Tfloat tfloat;
      const CImg<tfloat> invT = tensor.get_invert(), invT2 = (invT*invT)/(-2.0);
      const tfloat a = invT2(0,0), b = 2*invT2(1,0), c = invT2(1,1);
      const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
      const unsigned long whd = (unsigned long)_width*_height*_depth;
      const tc *col = color;
      float dy = -yc;
      cimg_forY(*this,y) {
        float dx = -xc;
        cimg_forX(*this,x) {
          const float val = (float)std::exp(a*dx*dx + b*dx*dy + c*dy*dy);
          T *ptrd = data(x,y,0,0);
          if (opacity>=1) cimg_forC(*this,c) { *ptrd = (T)(val*(*col++)); ptrd+=whd; }
          else cimg_forC(*this,c) { *ptrd = (T)(nopacity*val*(*col++) + *ptrd*copacity); ptrd+=whd; }
          col-=_spectrum;
          ++dx;
        }
        ++dy;
      }
      return *this;
    }

    //! Draw a 2d gaussian function \overloading.
    template<typename tc>
    CImg<T>& draw_gaussian(const int xc, const int yc, const float r1, const float r2, const float ru, const float rv,
                           const tc *const color, const float opacity=1) {
      const double
        a = r1*ru*ru + r2*rv*rv,
        b = (r1-r2)*ru*rv,
        c = r1*rv*rv + r2*ru*ru;
      const CImg<Tfloat> tensor(2,2,1,1, a,b,b,c);
      return draw_gaussian(xc,yc,tensor,color,opacity);
    }

    //! Draw a 2d gaussian function \overloading.
    template<typename tc>
    CImg<T>& draw_gaussian(const float xc, const float yc, const float sigma,
                           const tc *const color, const float opacity=1) {
      return draw_gaussian(xc,yc,CImg<floatT>::diagonal(sigma,sigma),color,opacity);
    }

    //! Draw a 3d gaussian function \overloading.
    template<typename t, typename tc>
    CImg<T>& draw_gaussian(const float xc, const float yc, const float zc, const CImg<t>& tensor,
                           const tc *const color, const float opacity=1) {
      if (is_empty()) return *this;
      typedef typename CImg<t>::Tfloat tfloat;
      if (tensor._width!=3 || tensor._height!=3 || tensor._depth!=1 || tensor._spectrum!=1)
        throw CImgArgumentException(_cimg_instance
                                    "draw_gaussian(): Specified tensor (%u,%u,%u,%u,%p) is not a 3x3 matrix.",
                                    cimg_instance,
                                    tensor._width,tensor._height,tensor._depth,tensor._spectrum,tensor._data);

      const CImg<tfloat> invT = tensor.get_invert(), invT2 = (invT*invT)/(-2.0);
      const tfloat a = invT2(0,0), b = 2*invT2(1,0), c = 2*invT2(2,0), d = invT2(1,1), e = 2*invT2(2,1), f = invT2(2,2);
      const float nopacity = cimg::abs(opacity), copacity = 1 - cimg::max(opacity,0);
      const unsigned long whd = (unsigned long)_width*_height*_depth;
      const tc *col = color;
      cimg_forXYZ(*this,x,y,z) {
        const float
          dx = (x - xc), dy = (y - yc), dz = (z - zc),
          val = (float)std::exp(a*dx*dx + b*dx*dy + c*dx*dz + d*dy*dy + e*dy*dz + f*dz*dz);
        T *ptrd = data(x,y,z,0);
        if (opacity>=1) cimg_forC(*this,c) { *ptrd = (T)(val*(*col++)); ptrd+=whd; }
        else cimg_forC(*this,c) { *ptrd = (T)(nopacity*val*(*col++) + *ptrd*copacity); ptrd+=whd; }
        col-=_spectrum;
      }
      return *this;
    }

    //! Draw a 3d gaussian function \overloading.
    template<typename tc>
    CImg<T>& draw_gaussian(const float xc, const float yc, const float zc, const float sigma,
                           const tc *const color, const float opacity=1) {
      return draw_gaussian(xc,yc,zc,CImg<floatT>::diagonal(sigma,sigma,sigma),color,opacity);
    }

    //! Draw a 3d object.
    /**
       \param x0 X-coordinate of the 3d object position
       \param y0 Y-coordinate of the 3d object position
       \param z0 Z-coordinate of the 3d object position
       \param vertices Image Nx3 describing 3d point coordinates
       \param primitives List of P primitives
       \param colors List of P color (or textures)
       \param opacities Image or list of P opacities
       \param render_type d Render type (0=Points, 1=Lines, 2=Faces (no light), 3=Faces (flat), 4=Faces(Gouraud)
       \param is_double_sided Tells if object faces have two sides or are oriented.
       \param focale length of the focale (0 for parallel projection)
       \param lightx X-coordinate of the light
       \param lighty Y-coordinate of the light
       \param lightz Z-coordinate of the light
       \param specular_lightness Amount of specular light.
       \param specular_shininess Shininess of the object
    **/
    template<typename tp, typename tf, typename tc, typename to>
    CImg<T>& draw_object3d(const float x0, const float y0, const float z0,
                           const CImg<tp>& vertices, const CImgList<tf>& primitives,
                           const CImgList<tc>& colors, const CImg<to>& opacities,
                           const unsigned int render_type=4,
                           const bool is_double_sided=false, const float focale=700,
                           const float lightx=0, const float lighty=0, const float lightz=-5e8,
                           const float specular_lightness=0.2f, const float specular_shininess=0.1f) {
      return draw_object3d(x0,y0,z0,vertices,primitives,colors,opacities,render_type,is_double_sided,focale,lightx,lighty,lightz,
                           specular_lightness,specular_shininess,CImg<floatT>::empty());
    }

    //! Draw a 3d object \simplification.
    template<typename tp, typename tf, typename tc, typename to, typename tz>
    CImg<T>& draw_object3d(const float x0, const float y0, const float z0,
                           const CImg<tp>& vertices, const CImgList<tf>& primitives,
                           const CImgList<tc>& colors, const CImg<to>& opacities,
                           const unsigned int render_type,
                           const bool is_double_sided, const float focale,
                           const float lightx, const float lighty, const float lightz,
                           const float specular_lightness, const float specular_shininess,
                           CImg<tz>& zbuffer) {
      return _draw_object3d(0,zbuffer,x0,y0,z0,vertices,primitives,colors,opacities,
                            render_type,is_double_sided,focale,lightx,lighty,lightz,specular_lightness,specular_shininess,1);
    }

#ifdef cimg_use_board
    template<typename tp, typename tf, typename tc, typename to>
    CImg<T>& draw_object3d(LibBoard::Board& board,
                           const float x0, const float y0, const float z0,
                           const CImg<tp>& vertices, const CImgList<tf>& primitives,
                           const CImgList<tc>& colors, const CImg<to>& opacities,
                           const unsigned int render_type=4,
                           const bool is_double_sided=false, const float focale=700,
                           const float lightx=0, const float lighty=0, const float lightz=-5e8,
                           const float specular_lightness=0.2f, const float specular_shininess=0.1f) {
      return draw_object3d(board,x0,y0,z0,vertices,primitives,colors,opacities,render_type,is_double_sided,focale,lightx,lighty,lightz,
                           specular_lightness,specular_shininess,CImg<floatT>::empty());
    }

    template<typename tp, typename tf, typename tc, typename to, typename tz>
    CImg<T>& draw_object3d(LibBoard::Board& board,
                           const float x0, const float y0, const float z0,
                           const CImg<tp>& vertices, const CImgList<tf>& primitives,
                           const CImgList<tc>& colors, const CImg<to>& opacities,
                           const unsigned int render_type,
                           const bool is_double_sided, const float focale,
                           const float lightx, const float lighty, const float lightz,
                           const float specular_lightness, const float specular_shininess,
                           CImg<tz>& zbuffer) {
      return _draw_object3d((void*)&board,zbuffer,x0,y0,z0,vertices,primitives,colors,opacities,
                            render_type,is_double_sided,focale,lightx,lighty,lightz,specular_lightness,specular_shininess,1);
    }
#endif
# 33553 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    //! Draw a 3d object \simplification.
    template<typename tp, typename tf, typename tc, typename to>
    CImg<T>& draw_object3d(const float x0, const float y0, const float z0,
                           const CImg<tp>& vertices, const CImgList<tf>& primitives,
                           const CImgList<tc>& colors, const CImgList<to>& opacities,
                           const unsigned int render_type=4,
                           const bool is_double_sided=false, const float focale=700,
                           const float lightx=0, const float lighty=0, const float lightz=-5e8,
                           const float specular_lightness=0.2f, const float specular_shininess=0.1f) {
      return draw_object3d(x0,y0,z0,vertices,primitives,colors,opacities,render_type,is_double_sided,focale,lightx,lighty,lightz,
                           specular_lightness,specular_shininess,CImg<floatT>::empty());
    }

    //! Draw a 3d object \simplification.
    template<typename tp, typename tf, typename tc, typename to, typename tz>
    CImg<T>& draw_object3d(const float x0, const float y0, const float z0,
                           const CImg<tp>& vertices, const CImgList<tf>& primitives,
                           const CImgList<tc>& colors, const CImgList<to>& opacities,
                           const unsigned int render_type,
                           const bool is_double_sided, const float focale,
                           const float lightx, const float lighty, const float lightz,
                           const float specular_lightness, const float specular_shininess,
                           CImg<tz>& zbuffer) {
      return _draw_object3d(0,zbuffer,x0,y0,z0,vertices,primitives,colors,opacities,
                            render_type,is_double_sided,focale,lightx,lighty,lightz,specular_lightness,specular_shininess,1);
    }

#ifdef cimg_use_board
    template<typename tp, typename tf, typename tc, typename to>
    CImg<T>& draw_object3d(LibBoard::Board& board,
                           const float x0, const float y0, const float z0,
                           const CImg<tp>& vertices, const CImgList<tf>& primitives,
                           const CImgList<tc>& colors, const CImgList<to>& opacities,
                           const unsigned int render_type=4,
                           const bool is_double_sided=false, const float focale=700,
                           const float lightx=0, const float lighty=0, const float lightz=-5e8,
                           const float specular_lightness=0.2f, const float specular_shininess=0.1f) {
      return draw_object3d(board,x0,y0,z0,vertices,primitives,colors,opacities,render_type,is_double_sided,focale,lightx,lighty,lightz,
                           specular_lightness,specular_shininess,CImg<floatT>::empty());
    }

    template<typename tp, typename tf, typename tc, typename to, typename tz>
    CImg<T>& draw_object3d(LibBoard::Board& board,
                           const float x0, const float y0, const float z0,
                           const CImg<tp>& vertices, const CImgList<tf>& primitives,
                           const CImgList<tc>& colors, const CImgList<to>& opacities,
                           const unsigned int render_type,
                           const bool is_double_sided, const float focale,
                           const float lightx, const float lighty, const float lightz,
                           const float specular_lightness, const float specular_shininess,
                           CImg<tz>& zbuffer) {
      return _draw_object3d((void*)&board,zbuffer,x0,y0,z0,vertices,primitives,colors,opacities,
                            render_type,is_double_sided,focale,lightx,lighty,lightz,specular_lightness,specular_shininess,1);
    }
#endif
# 33609 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    //! Draw a 3d object \simplification.
    template<typename tp, typename tf, typename tc>
    CImg<T>& draw_object3d(const float x0, const float y0, const float z0,
                           const CImg<tp>& vertices, const CImgList<tf>& primitives,
                           const CImgList<tc>& colors,
                           const unsigned int render_type=4,
                           const bool is_double_sided=false, const float focale=700,
                           const float lightx=0, const float lighty=0, const float lightz=-5e8,
                           const float specular_lightness=0.2f, const float specular_shininess=0.1f) {
      return draw_object3d(x0,y0,z0,vertices,primitives,colors,CImg<floatT>::empty(),
                           render_type,is_double_sided,focale,lightx,lighty,lightz,specular_lightness,specular_shininess,CImg<floatT>::empty());
    }

    //! Draw a 3d object \simplification.
    template<typename tp, typename tf, typename tc, typename tz>
    CImg<T>& draw_object3d(const float x0, const float y0, const float z0,
                           const CImg<tp>& vertices, const CImgList<tf>& primitives,
                           const CImgList<tc>& colors,
                           const unsigned int render_type,
                           const bool is_double_sided, const float focale,
                           const float lightx, const float lighty, const float lightz,
                           const float specular_lightness, const float specular_shininess,
                           CImg<tz>& zbuffer) {
      return draw_object3d(x0,y0,z0,vertices,primitives,colors,CImg<floatT>::empty(),
                           render_type,is_double_sided,focale,lightx,lighty,lightz,specular_lightness,specular_shininess,zbuffer);
    }

#ifdef cimg_use_board
    template<typename tp, typename tf, typename tc, typename to>
    CImg<T>& draw_object3d(LibBoard::Board& board,
                           const float x0, const float y0, const float z0,
                           const CImg<tp>& vertices, const CImgList<tf>& primitives,
                           const CImgList<tc>& colors,
                           const unsigned int render_type=4,
                           const bool is_double_sided=false, const float focale=700,
                           const float lightx=0, const float lighty=0, const float lightz=-5e8,
                           const float specular_lightness=0.2f, const float specular_shininess=0.1f) {
      return draw_object3d(x0,y0,z0,vertices,primitives,colors,CImg<floatT>::empty(),
                           render_type,is_double_sided,focale,lightx,lighty,lightz,specular_lightness,specular_shininess,CImg<floatT>::empty());
    }

    template<typename tp, typename tf, typename tc, typename to, typename tz>
    CImg<T>& draw_object3d(LibBoard::Board& board,
                           const float x0, const float y0, const float z0,
                           const CImg<tp>& vertices, const CImgList<tf>& primitives,
                           const CImgList<tc>& colors,
                           const unsigned int render_type,
                           const bool is_double_sided, const float focale,
                           const float lightx, const float lighty, const float lightz,
                           const float specular_lightness, const float specular_shininess,
                           CImg<tz>& zbuffer) {
      return draw_object3d(x0,y0,z0,vertices,primitives,colors,CImg<floatT>::empty(),
                           render_type,is_double_sided,focale,lightx,lighty,lightz,specular_lightness,specular_shininess,zbuffer);
    }
#endif
# 33665 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    template<typename t, typename to>
    static float __draw_object3d(const CImgList<t>& opacities, const unsigned int n_primitive, CImg<to>& opacity) {
      if (n_primitive>=opacities._width || opacities[n_primitive].is_empty()) { opacity.assign(); return 1; }
      if (opacities[n_primitive].size()==1) { opacity.assign(); return opacities(n_primitive,0); }
      opacity.assign(opacities[n_primitive],true);
      return 1.0f;
    }

    template<typename t, typename to>
    static float __draw_object3d(const CImg<t>& opacities, const unsigned int n_primitive, CImg<to>& opacity) {
      opacity.assign();
      return n_primitive>=opacities._width?1.0f:(float)opacities[n_primitive];
    }

    template<typename tz, typename tp, typename tf, typename tc, typename to>
    CImg<T>& _draw_object3d(void *const pboard, CImg<tz>& zbuffer,
                            const float X, const float Y, const float Z,
                            const CImg<tp>& vertices,
                            const CImgList<tf>& primitives,
                            const CImgList<tc>& colors,
                            const to& opacities,
                            const unsigned int render_type,
                            const bool is_double_sided, const float focale,
                            const float lightx, const float lighty, const float lightz,
                            const float specular_lightness, const float specular_shininess,
                            const float sprite_scale) {
      typedef typename cimg::superset2<tp,tz,float>::type tpfloat;
      if (is_empty() || !vertices || !primitives) return *this;
      char error_message[1024] = { 0 };
      if (!vertices.is_object3d(primitives,colors,opacities,false,error_message))
        throw CImgArgumentException(_cimg_instance
                                    "draw_object3d(): Invalid specified 3d object (%u,%u) (%s).",
                                    cimg_instance,vertices._width,primitives._width,error_message);
      if (render_type==5) cimg::mutex(10);  // Static variable used in this case, breaks thread-safety.

#ifndef cimg_use_board
      if (pboard) return *this;
#endif
# 33704 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      const float
        nspec = 1 - (specular_lightness<0.0f?0.0f:(specular_lightness>1.0f?1.0f:specular_lightness)),
        nspec2 = 1 + (specular_shininess<0.0f?0.0f:specular_shininess),
        nsl1 = (nspec2 - 1)/cimg::sqr(nspec - 1),
        nsl2 = 1 - 2*nsl1*nspec,
        nsl3 = nspec2 - nsl1 - nsl2;

      // Create light texture for phong-like rendering.
      CImg<floatT> light_texture;
      if (render_type==5) {
        if (colors._width>primitives._width) {
          static CImg<floatT> default_light_texture;
          static const tc *lptr = 0;
          static tc ref_values[64] = { 0 };
          const CImg<tc>& img = colors.back();
          bool is_same_texture = (lptr==img._data);
          if (is_same_texture)
            for (unsigned int r = 0, j = 0; j<8; ++j)
              for (unsigned int i = 0; i<8; ++i)
                if (ref_values[r++]!=img(i*img._width/9,j*img._height/9,0,(i+j)%img._spectrum)) { is_same_texture = false; break; }
          if (!is_same_texture || default_light_texture._spectrum<_spectrum) {
            (default_light_texture.assign(img,false)/=255).resize(-100,-100,1,_spectrum);
            lptr = colors.back().data();
            for (unsigned int r = 0, j = 0; j<8; ++j)
              for (unsigned int i = 0; i<8; ++i)
                ref_values[r++] = img(i*img._width/9,j*img._height/9,0,(i+j)%img._spectrum);
          }
          light_texture.assign(default_light_texture,true);
        } else {
          static CImg<floatT> default_light_texture;
          static float olightx = 0, olighty = 0, olightz = 0, ospecular_shininess = 0;
          if (!default_light_texture ||
              lightx!=olightx || lighty!=olighty || lightz!=olightz ||
              specular_shininess!=ospecular_shininess || default_light_texture._spectrum<_spectrum) {
            default_light_texture.assign(512,512);
            const float
              dlx = lightx - X,
              dly = lighty - Y,
              dlz = lightz - Z,
              nl = (float)std::sqrt(dlx*dlx + dly*dly + dlz*dlz),
              nlx = (default_light_texture._width - 1)/2*(1 + dlx/nl),
              nly = (default_light_texture._height - 1)/2*(1 + dly/nl),
              white[] = { 1 };
            default_light_texture.draw_gaussian(nlx,nly,default_light_texture._width/3.0f,white);
            cimg_forXY(default_light_texture,x,y) {
              const float factor = default_light_texture(x,y);
              if (factor>nspec) default_light_texture(x,y) = cimg::min(2,nsl1*factor*factor + nsl2*factor + nsl3);
            }
            default_light_texture.resize(-100,-100,1,_spectrum);
            olightx = lightx; olighty = lighty; olightz = lightz; ospecular_shininess = specular_shininess;
          }
          light_texture.assign(default_light_texture,true);
        }
      }

      // Compute 3d to 2d projection.
      CImg<tpfloat> projections(vertices._width,2);
      tpfloat parallzmin = cimg::type<tpfloat>::max();
      const float absfocale = focale?cimg::abs(focale):0;
      if (absfocale) cimg_forX(projections,l) { // Perspective projection
          const tpfloat
            x = (tpfloat)vertices(l,0),
            y = (tpfloat)vertices(l,1),
            z = (tpfloat)vertices(l,2);
          const tpfloat projectedz = z + Z + absfocale;
          projections(l,1) = Y + absfocale*y/projectedz;
          projections(l,0) = X + absfocale*x/projectedz;
        } else cimg_forX(projections,l) { // Parallel projection
          const tpfloat
            x = (tpfloat)vertices(l,0),
            y = (tpfloat)vertices(l,1),
            z = (tpfloat)vertices(l,2);
          if (z<parallzmin) parallzmin = z;
          projections(l,1) = Y + y;
          projections(l,0) = X + x;
        }
      const float _focale = absfocale?absfocale:(1e5f-parallzmin);

      // Compute and sort visible primitives.
      CImg<uintT> visibles(primitives._width);
      CImg<tpfloat> zrange(primitives._width);
      unsigned int nb_visibles = 0;
      const tpfloat zmin = absfocale?(tpfloat)(1.5f - absfocale):cimg::type<tpfloat>::min();
      cimglist_for(primitives,l) {
        const CImg<tf>& primitive = primitives[l];
        switch (primitive.size()) {
        case 1 : { // Point
          const unsigned int i0 = (unsigned int)primitive(0);
          const tpfloat z0 = Z + vertices(i0,2);
          if (z0>zmin) {
            visibles(nb_visibles) = (unsigned int)l;
            zrange(nb_visibles++) = z0;
          }
        } break;
        case 5 : { // Sphere
          const unsigned int
            i0 = (unsigned int)primitive(0),
            i1 = (unsigned int)primitive(1);
          const tpfloat
            Xc = 0.5f*((float)vertices(i0,0) + (float)vertices(i1,0)),
            Yc = 0.5f*((float)vertices(i0,1) + (float)vertices(i1,1)),
            Zc = 0.5f*((float)vertices(i0,2) + (float)vertices(i1,2)),
            _zc = Z + Zc,
            zc = _zc + _focale,
            xc = X + Xc*(absfocale?absfocale/zc:1),
            yc = Y + Yc*(absfocale?absfocale/zc:1),
            radius = 0.5f*std::sqrt(cimg::sqr(vertices(i1,0) - vertices(i0,0)) +
                                    cimg::sqr(vertices(i1,1) - vertices(i0,1)) +
                                    cimg::sqr(vertices(i1,2) - vertices(i0,2)))*(absfocale?absfocale/zc:1),
            xm = xc - radius,
            ym = yc - radius,
            xM = xc + radius,
            yM = yc + radius;
          if (xM>=0 && xm<_width && yM>=0 && ym<_height && _zc>zmin) {
            visibles(nb_visibles) = (unsigned int)l;
            zrange(nb_visibles++) = _zc;
          }
        } break;
        case 2 : // Segment
        case 6 : {
          const unsigned int
            i0 = (unsigned int)primitive(0),
            i1 = (unsigned int)primitive(1);
          const tpfloat
            x0 = projections(i0,0), y0 = projections(i0,1), z0 = Z + vertices(i0,2),
            x1 = projections(i1,0), y1 = projections(i1,1), z1 = Z + vertices(i1,2);
          tpfloat xm, xM, ym, yM;
          if (x0<x1) { xm = x0; xM = x1; } else { xm = x1; xM = x0; }
          if (y0<y1) { ym = y0; yM = y1; } else { ym = y1; yM = y0; }
          if (xM>=0 && xm<_width && yM>=0 && ym<_height && z0>zmin && z1>zmin) {
            visibles(nb_visibles) = (unsigned int)l;
            zrange(nb_visibles++) = (z0 + z1)/2;
          }
        } break;
        case 3 :  // Triangle
        case 9 : {
          const unsigned int
            i0 = (unsigned int)primitive(0),
            i1 = (unsigned int)primitive(1),
            i2 = (unsigned int)primitive(2);
          const tpfloat
            x0 = projections(i0,0), y0 = projections(i0,1), z0 = Z + vertices(i0,2),
            x1 = projections(i1,0), y1 = projections(i1,1), z1 = Z + vertices(i1,2),
            x2 = projections(i2,0), y2 = projections(i2,1), z2 = Z + vertices(i2,2);
          tpfloat xm, xM, ym, yM;
          if (x0<x1) { xm = x0; xM = x1; } else { xm = x1; xM = x0; }
          if (x2<xm) xm = x2;
          if (x2>xM) xM = x2;
          if (y0<y1) { ym = y0; yM = y1; } else { ym = y1; yM = y0; }
          if (y2<ym) ym = y2;
          if (y2>yM) yM = y2;
          if (xM>=0 && xm<_width && yM>=0 && ym<_height && z0>zmin && z1>zmin && z2>zmin) {
            const tpfloat d = (x1-x0)*(y2-y0) - (x2-x0)*(y1-y0);
            if (is_double_sided || d<0) {
              visibles(nb_visibles) = (unsigned int)l;
              zrange(nb_visibles++) = (z0 + z1 + z2)/3;
            }
          }
        } break;
        case 4 : // Rectangle
        case 12 : {
          const unsigned int
            i0 = (unsigned int)primitive(0),
            i1 = (unsigned int)primitive(1),
            i2 = (unsigned int)primitive(2),
            i3 = (unsigned int)primitive(3);
          const tpfloat
            x0 = projections(i0,0), y0 = projections(i0,1), z0 = Z + vertices(i0,2),
            x1 = projections(i1,0), y1 = projections(i1,1), z1 = Z + vertices(i1,2),
            x2 = projections(i2,0), y2 = projections(i2,1), z2 = Z + vertices(i2,2),
            x3 = projections(i3,0), y3 = projections(i3,1), z3 = Z + vertices(i3,2);
          tpfloat xm, xM, ym, yM;
          if (x0<x1) { xm = x0; xM = x1; } else { xm = x1; xM = x0; }
          if (x2<xm) xm = x2;
          if (x2>xM) xM = x2;
          if (x3<xm) xm = x3;
          if (x3>xM) xM = x3;
          if (y0<y1) { ym = y0; yM = y1; } else { ym = y1; yM = y0; }
          if (y2<ym) ym = y2;
          if (y2>yM) yM = y2;
          if (y3<ym) ym = y3;
          if (y3>yM) yM = y3;
          if (xM>=0 && xm<_width && yM>=0 && ym<_height && z0>zmin && z1>zmin && z2>zmin) {
            const float d = (x1 - x0)*(y2 - y0) - (x2 - x0)*(y1 - y0);
            if (is_double_sided || d<0) {
              visibles(nb_visibles) = (unsigned int)l;
              zrange(nb_visibles++) = (z0 + z1 + z2 + z3)/4;
            }
          }
        } break;
        default :
          throw CImgArgumentException(_cimg_instance
                                      "draw_object3d(): Invalid primitive[%u] with size %u "
                                      "(should have size 1,2,3,4,5,6,9 or 12).",
                                      cimg_instance,
                                      l,primitive.size());
        }
      }

      if (nb_visibles<=0) return *this;
      CImg<uintT> permutations;
      CImg<tpfloat>(zrange._data,nb_visibles,1,1,1,true).sort(permutations,false);

      // Compute light properties
      CImg<floatT> lightprops;
      switch (render_type) {
      case 3 : { // Flat Shading
        lightprops.assign(nb_visibles);
        cimg_forX(lightprops,l) {
          const CImg<tf>& primitive = primitives(visibles(permutations(l)));
          const unsigned int psize = primitive.size();
          if (psize==3 || psize==4 || psize==9 || psize==12) {
            const unsigned int
              i0 = (unsigned int)primitive(0),
              i1 = (unsigned int)primitive(1),
              i2 = (unsigned int)primitive(2);
            const tpfloat
              x0 = (tpfloat)vertices(i0,0), y0 = (tpfloat)vertices(i0,1), z0 = (tpfloat)vertices(i0,2),
              x1 = (tpfloat)vertices(i1,0), y1 = (tpfloat)vertices(i1,1), z1 = (tpfloat)vertices(i1,2),
              x2 = (tpfloat)vertices(i2,0), y2 = (tpfloat)vertices(i2,1), z2 = (tpfloat)vertices(i2,2),
              dx1 = x1 - x0, dy1 = y1 - y0, dz1 = z1 - z0,
              dx2 = x2 - x0, dy2 = y2 - y0, dz2 = z2 - z0,
              nx = dy1*dz2 - dz1*dy2,
              ny = dz1*dx2 - dx1*dz2,
              nz = dx1*dy2 - dy1*dx2,
              norm = (tpfloat)std::sqrt(1e-5f + nx*nx + ny*ny + nz*nz),
              lx = X + (x0 + x1 + x2)/3 - lightx,
              ly = Y + (y0 + y1 + y2)/3 - lighty,
              lz = Z + (z0 + z1 + z2)/3 - lightz,
              nl = (tpfloat)std::sqrt(1e-5f + lx*lx + ly*ly + lz*lz),
              factor = cimg::max(cimg::abs(-lx*nx-ly*ny-lz*nz)/(norm*nl),0);
            lightprops[l] = factor<=nspec?factor:(nsl1*factor*factor + nsl2*factor + nsl3);
          } else lightprops[l] = 1;
        }
      } break;

      case 4 : // Gouraud Shading
      case 5 : { // Phong-Shading
        CImg<tpfloat> vertices_normals(vertices._width,3,1,1,0);
        for (unsigned int l = 0; l<nb_visibles; ++l) {
          const CImg<tf>& primitive = primitives[visibles(l)];
          const unsigned int psize = primitive.size();
          const bool
            triangle_flag = (psize==3) || (psize==9),
            rectangle_flag = (psize==4) || (psize==12);
          if (triangle_flag || rectangle_flag) {
            const unsigned int
              i0 = (unsigned int)primitive(0),
              i1 = (unsigned int)primitive(1),
              i2 = (unsigned int)primitive(2),
              i3 = rectangle_flag?(unsigned int)primitive(3):0;
            const tpfloat
              x0 = (tpfloat)vertices(i0,0), y0 = (tpfloat)vertices(i0,1), z0 = (tpfloat)vertices(i0,2),
              x1 = (tpfloat)vertices(i1,0), y1 = (tpfloat)vertices(i1,1), z1 = (tpfloat)vertices(i1,2),
              x2 = (tpfloat)vertices(i2,0), y2 = (tpfloat)vertices(i2,1), z2 = (tpfloat)vertices(i2,2),
              dx1 = x1 - x0, dy1 = y1 - y0, dz1 = z1 - z0,
              dx2 = x2 - x0, dy2 = y2 - y0, dz2 = z2 - z0,
              nnx = dy1*dz2 - dz1*dy2,
              nny = dz1*dx2 - dx1*dz2,
              nnz = dx1*dy2 - dy1*dx2,
              norm = (tpfloat)(1e-5f + std::sqrt(nnx*nnx + nny*nny + nnz*nnz)),
              nx = nnx/norm,
              ny = nny/norm,
              nz = nnz/norm;
            vertices_normals(i0,0)+=nx; vertices_normals(i0,1)+=ny; vertices_normals(i0,2)+=nz;
            vertices_normals(i1,0)+=nx; vertices_normals(i1,1)+=ny; vertices_normals(i1,2)+=nz;
            vertices_normals(i2,0)+=nx; vertices_normals(i2,1)+=ny; vertices_normals(i2,2)+=nz;
            if (rectangle_flag) { vertices_normals(i3,0)+=nx; vertices_normals(i3,1)+=ny; vertices_normals(i3,2)+=nz; }
          }
        }

        if (is_double_sided) cimg_forX(vertices_normals,p) if (vertices_normals(p,2)>0) {
          vertices_normals(p,0) = -vertices_normals(p,0);
          vertices_normals(p,1) = -vertices_normals(p,1);
          vertices_normals(p,2) = -vertices_normals(p,2);
        }

        if (render_type==4) {
          lightprops.assign(vertices._width);
          cimg_forX(lightprops,l) {
            const tpfloat
              nx = vertices_normals(l,0),
              ny = vertices_normals(l,1),
              nz = vertices_normals(l,2),
              norm = (tpfloat)std::sqrt(1e-5f + nx*nx + ny*ny + nz*nz),
              lx = X + vertices(l,0) - lightx,
              ly = Y + vertices(l,1) - lighty,
              lz = Z + vertices(l,2) - lightz,
              nl = (tpfloat)std::sqrt(1e-5f + lx*lx + ly*ly + lz*lz),
              factor = cimg::max((-lx*nx-ly*ny-lz*nz)/(norm*nl),0);
            lightprops[l] = factor<=nspec?factor:(nsl1*factor*factor + nsl2*factor + nsl3);
          }
        } else {
          const unsigned int
            lw2 = light_texture._width/2 - 1,
            lh2 = light_texture._height/2 - 1;
          lightprops.assign(vertices._width,2);
          cimg_forX(lightprops,l) {
            const tpfloat
              nx = vertices_normals(l,0),
              ny = vertices_normals(l,1),
              nz = vertices_normals(l,2),
              norm = (tpfloat)std::sqrt(1e-5f + nx*nx + ny*ny + nz*nz),
              nnx = nx/norm,
              nny = ny/norm;
            lightprops(l,0) = lw2*(1 + nnx);
            lightprops(l,1) = lh2*(1 + nny);
          }
        }
      } break;
      }

      // Draw visible primitives
      const CImg<tc> default_color(1,_spectrum,1,1,(tc)200);
      typedef typename to::value_type _to;
      CImg<_to> _opacity;

      for (unsigned int l = 0; l<nb_visibles; ++l) {
        const unsigned int n_primitive = visibles(permutations(l));
        const CImg<tf>& primitive = primitives[n_primitive];
        const CImg<tc>
          &__color = n_primitive<colors._width?colors[n_primitive]:CImg<tc>(),
          _color = (__color && __color.size()!=_spectrum && __color._spectrum<_spectrum)?__color.get_resize(-100,-100,-100,_spectrum,0):CImg<tc>(),
          &color = _color?_color:(__color?__color:default_color);
        const tc *const pcolor = color._data;
        const float opacity = __draw_object3d(opacities,n_primitive,_opacity);

#ifdef cimg_use_board
        LibBoard::Board &board = *(LibBoard::Board*)pboard;
#endif
# 34034 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

        switch (primitive.size()) {
        case 1 : { // Colored point or sprite
          const unsigned int n0 = (unsigned int)primitive[0];
          const int x0 = (int)projections(n0,0), y0 = (int)projections(n0,1);

          if (_opacity.is_empty()) { // Scalar opacity.

            if (color.size()==_spectrum) { // Colored point.
              draw_point(x0,y0,pcolor,opacity);
#ifdef cimg_use_board
              if (pboard) {
                board.setPenColorRGBi(color[0],color[1],color[2],(unsigned char)(opacity*255));
                board.fillCircle((float)x0,height()-(float)y0,0);
              }
#endif
# 34050 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            } else { // Sprite.
              const tpfloat z = Z + vertices(n0,2);
              const float factor = focale<0?1:sprite_scale*(absfocale?absfocale/(z + absfocale):1);
              const unsigned int
                _sw = (unsigned int)(color._width*factor),
                _sh = (unsigned int)(color._height*factor),
                sw = _sw?_sw:1, sh = _sh?_sh:1;
              const int nx0 = x0 - (int)sw/2, ny0 = y0 - (int)sh/2;
              if (sw<=3*_width/2 && sh<=3*_height/2 && (nx0+(int)sw/2>=0 || nx0-(int)sw/2<width() || ny0+(int)sh/2>=0 || ny0-(int)sh/2<height())) {
                const CImg<tc>
                  _sprite = (sw!=color._width || sh!=color._height)?color.get_resize(sw,sh,1,-100,render_type<=3?1:3):CImg<tc>(),
                  &sprite = _sprite?_sprite:color;
                draw_image(nx0,ny0,sprite,opacity);
#ifdef cimg_use_board
                if (pboard) {
                  board.setPenColorRGBi(128,128,128);
                  board.setFillColor(LibBoard::Color::None);
                  board.drawRectangle((float)nx0,height()-(float)ny0,sw,sh);
                }
#endif
# 34070 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
              }
            }
          } else { // Opacity mask.
            const tpfloat z = Z + vertices(n0,2);
            const float factor = focale<0?1:sprite_scale*(absfocale?absfocale/(z + absfocale):1);
            const unsigned int
              _sw = (unsigned int)(cimg::max(color._width,_opacity._width)*factor),
              _sh = (unsigned int)(cimg::max(color._height,_opacity._height)*factor),
              sw = _sw?_sw:1, sh = _sh?_sh:1;
            const int nx0 = x0 - (int)sw/2, ny0 = y0 - (int)sh/2;
            if (sw<=3*_width/2 && sh<=3*_height/2 && (nx0+(int)sw/2>=0 || nx0-(int)sw/2<width() || ny0+(int)sh/2>=0 || ny0-(int)sh/2<height())) {
              const CImg<tc>
                _sprite = (sw!=color._width || sh!=color._height)?color.get_resize(sw,sh,1,-100,render_type<=3?1:3):CImg<tc>(),
                &sprite = _sprite?_sprite:color;
              const CImg<_to>
                _nopacity = (sw!=_opacity._width || sh!=_opacity._height)?_opacity.get_resize(sw,sh,1,-100,render_type<=3?1:3):CImg<_to>(),
                &nopacity = _nopacity?_nopacity:_opacity;
              draw_image(nx0,ny0,sprite,nopacity);
#ifdef cimg_use_board
              if (pboard) {
                board.setPenColorRGBi(128,128,128);
                board.setFillColor(LibBoard::Color::None);
                board.drawRectangle((float)nx0,height()-(float)ny0,sw,sh);
              }
#endif
# 34095 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            }
          }
        } break;
        case 2 : { // Colored line
          const unsigned int
            n0 = (unsigned int)primitive[0],
            n1 = (unsigned int)primitive[1];
          const int
            x0 = (int)projections(n0,0), y0 = (int)projections(n0,1),
            x1 = (int)projections(n1,0), y1 = (int)projections(n1,1);
          const float
            z0 = vertices(n0,2) + Z + _focale,
            z1 = vertices(n1,2) + Z + _focale;
          if (render_type) {
            if (zbuffer) draw_line(zbuffer,x0,y0,z0,x1,y1,z1,pcolor,opacity);
            else draw_line(x0,y0,x1,y1,pcolor,opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi(color[0],color[1],color[2],(unsigned char)(opacity*255));
              board.drawLine((float)x0,height()-(float)y0,x1,height()-(float)y1);
            }
#endif
# 34117 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
          } else {
            draw_point(x0,y0,pcolor,opacity).draw_point(x1,y1,pcolor,opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi(color[0],color[1],color[2],(unsigned char)(opacity*255));
              board.drawCircle((float)x0,height()-(float)y0,0);
              board.drawCircle((float)x1,height()-(float)y1,0);
            }
#endif
# 34126 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
          }
        } break;
        case 5 : { // Colored sphere
          const unsigned int
            n0 = (unsigned int)primitive[0],
            n1 = (unsigned int)primitive[1];
          const float
            Xc = 0.5f*((float)vertices(n0,0) + (float)vertices(n1,0)),
            Yc = 0.5f*((float)vertices(n0,1) + (float)vertices(n1,1)),
            Zc = 0.5f*((float)vertices(n0,2) + (float)vertices(n1,2)),
            zc = Z + Zc + _focale,
            xc = X + Xc*(absfocale?absfocale/zc:1),
            yc = Y + Yc*(absfocale?absfocale/zc:1),
            radius = 0.5f*std::sqrt(cimg::sqr(vertices(n1,0) - vertices(n0,0)) +
                                    cimg::sqr(vertices(n1,1) - vertices(n0,1)) +
                                    cimg::sqr(vertices(n1,2) - vertices(n0,2)))*(absfocale?absfocale/zc:1);
          switch (render_type) {
          case 0 :
            draw_point((int)xc,(int)yc,pcolor,opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi(color[0],color[1],color[2],(unsigned char)(opacity*255));
              board.fillCircle(xc,height()-yc,0);
            }
#endif
# 34151 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          case 1 :
            draw_circle((int)xc,(int)yc,(int)radius,pcolor,opacity,~0U);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi(color[0],color[1],color[2],(unsigned char)(opacity*255));
              board.setFillColor(LibBoard::Color::None);
              board.drawCircle(xc,height()-yc,radius);
            }
#endif
# 34161 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          default :
            draw_circle((int)xc,(int)yc,(int)radius,pcolor,opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi(color[0],color[1],color[2],(unsigned char)(opacity*255));
              board.fillCircle(xc,height()-yc,radius);
            }
#endif
# 34170 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          }
        } break;
        case 6 : { // Textured line
          if (!__color)
            throw CImgArgumentException(_cimg_instance
                                        "draw_object3d(): Undefined texture for line primitive [%u].",
                                        cimg_instance,n_primitive);
          const unsigned int
            n0 = (unsigned int)primitive[0],
            n1 = (unsigned int)primitive[1],
            tx0 = (unsigned int)primitive[2],
            ty0 = (unsigned int)primitive[3],
            tx1 = (unsigned int)primitive[4],
            ty1 = (unsigned int)primitive[5];
          const int
            x0 = (int)projections(n0,0), y0 = (int)projections(n0,1),
            x1 = (int)projections(n1,0), y1 = (int)projections(n1,1);
          const float
            z0 = vertices(n0,2) + Z + _focale,
            z1 = vertices(n1,2) + Z + _focale;
          if (render_type) {
            if (zbuffer) draw_line(zbuffer,x0,y0,z0,x1,y1,z1,color,tx0,ty0,tx1,ty1,opacity);
            else draw_line(x0,y0,x1,y1,color,tx0,ty0,tx1,ty1,opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi(128,128,128,(unsigned char)(opacity*255));
              board.drawLine((float)x0,height()-(float)y0,(float)x1,height()-(float)y1);
            }
#endif
# 34200 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
          } else {
            draw_point(x0,y0,color.get_vector_at(tx0,ty0)._data,opacity).
              draw_point(x1,y1,color.get_vector_at(tx1,ty1)._data,opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi(128,128,128,(unsigned char)(opacity*255));
              board.drawCircle((float)x0,height()-(float)y0,0);
              board.drawCircle((float)x1,height()-(float)y1,0);
            }
#endif
# 34210 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
          }
        } break;
        case 3 : { // Colored triangle
          const unsigned int
            n0 = (unsigned int)primitive[0],
            n1 = (unsigned int)primitive[1],
            n2 = (unsigned int)primitive[2];
          const int
            x0 = (int)projections(n0,0), y0 = (int)projections(n0,1),
            x1 = (int)projections(n1,0), y1 = (int)projections(n1,1),
            x2 = (int)projections(n2,0), y2 = (int)projections(n2,1);
          const float
            z0 = vertices(n0,2) + Z + _focale,
            z1 = vertices(n1,2) + Z + _focale,
            z2 = vertices(n2,2) + Z + _focale;
          switch (render_type) {
          case 0 :
            draw_point(x0,y0,pcolor,opacity).draw_point(x1,y1,pcolor,opacity).draw_point(x2,y2,pcolor,opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi(color[0],color[1],color[2],(unsigned char)(opacity*255));
              board.drawCircle((float)x0,height()-(float)y0,0);
              board.drawCircle((float)x1,height()-(float)y1,0);
              board.drawCircle((float)x2,height()-(float)y2,0);
            }
#endif
# 34236 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          case 1 :
            if (zbuffer)
              draw_line(zbuffer,x0,y0,z0,x1,y1,z1,pcolor,opacity).draw_line(zbuffer,x0,y0,z0,x2,y2,z2,pcolor,opacity).
                draw_line(zbuffer,x1,y1,z1,x2,y2,z2,pcolor,opacity);
            else
              draw_line(x0,y0,x1,y1,pcolor,opacity).draw_line(x0,y0,x2,y2,pcolor,opacity).
                draw_line(x1,y1,x2,y2,pcolor,opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi(color[0],color[1],color[2],(unsigned char)(opacity*255));
              board.drawLine((float)x0,height()-(float)y0,(float)x1,height()-(float)y1);
              board.drawLine((float)x0,height()-(float)y0,(float)x2,height()-(float)y2);
              board.drawLine((float)x1,height()-(float)y1,(float)x2,height()-(float)y2);
            }
#endif
# 34252 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          case 2 :
            if (zbuffer) draw_triangle(zbuffer,x0,y0,z0,x1,y1,z1,x2,y2,z2,pcolor,opacity);
            else draw_triangle(x0,y0,x1,y1,x2,y2,pcolor,opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi(color[0],color[1],color[2],(unsigned char)(opacity*255));
              board.fillTriangle((float)x0,height()-(float)y0,(float)x1,height()-(float)y1,(float)x2,height()-(float)y2);
            }
#endif
# 34262 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          case 3 :
            if (zbuffer) draw_triangle(zbuffer,x0,y0,z0,x1,y1,z1,x2,y2,z2,pcolor,opacity,lightprops(l));
            else _draw_triangle(x0,y0,x1,y1,x2,y2,pcolor,opacity,lightprops(l));
#ifdef cimg_use_board
            if (pboard) {
              const float lp = cimg::min(lightprops(l),1);
              board.setPenColorRGBi((unsigned char)(color[0]*lp),
                                     (unsigned char)(color[1]*lp),
                                     (unsigned char)(color[2]*lp),
                                     (unsigned char)(opacity*255));
              board.fillTriangle((float)x0,height()-(float)y0,(float)x1,height()-(float)y1,(float)x2,height()-(float)y2);
            }
#endif
# 34276 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          case 4 :
            if (zbuffer) draw_triangle(zbuffer,x0,y0,z0,x1,y1,z1,x2,y2,z2,pcolor,lightprops(n0),lightprops(n1),lightprops(n2),opacity);
            else draw_triangle(x0,y0,x1,y1,x2,y2,pcolor,lightprops(n0),lightprops(n1),lightprops(n2),opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi((unsigned char)(color[0]),
                                     (unsigned char)(color[1]),
                                     (unsigned char)(color[2]),
                                     (unsigned char)(opacity*255));
              board.fillGouraudTriangle((float)x0,height()-(float)y0,lightprops(n0),
                                         (float)x1,height()-(float)y1,lightprops(n1),
                                         (float)x2,height()-(float)y2,lightprops(n2));
            }
#endif
# 34291 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          case 5 : {
            const unsigned int
              lx0 = (unsigned int)lightprops(n0,0), ly0 = (unsigned int)lightprops(n0,1),
              lx1 = (unsigned int)lightprops(n1,0), ly1 = (unsigned int)lightprops(n1,1),
              lx2 = (unsigned int)lightprops(n2,0), ly2 = (unsigned int)lightprops(n2,1);
            if (zbuffer) draw_triangle(zbuffer,x0,y0,z0,x1,y1,z1,x2,y2,z2,pcolor,light_texture,lx0,ly0,lx1,ly1,lx2,ly2,opacity);
            else draw_triangle(x0,y0,x1,y1,x2,y2,pcolor,light_texture,lx0,ly0,lx1,ly1,lx2,ly2,opacity);
#ifdef cimg_use_board
            if (pboard) {
              const float
                l0 = light_texture((int)(light_texture.width()/2*(1+lightprops(n0,0))), (int)(light_texture.height()/2*(1+lightprops(n0,1)))),
                l1 = light_texture((int)(light_texture.width()/2*(1+lightprops(n1,0))), (int)(light_texture.height()/2*(1+lightprops(n1,1)))),
                l2 = light_texture((int)(light_texture.width()/2*(1+lightprops(n2,0))), (int)(light_texture.height()/2*(1+lightprops(n2,1))));
              board.setPenColorRGBi((unsigned char)(color[0]),
                                     (unsigned char)(color[1]),
                                     (unsigned char)(color[2]),
                                     (unsigned char)(opacity*255));
              board.fillGouraudTriangle((float)x0,height()-(float)y0,l0,
                                         (float)x1,height()-(float)y1,l1,
                                         (float)x2,height()-(float)y2,l2);
            }
#endif
# 34314 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
          } break;
          }
        } break;
        case 4 : { // Colored rectangle
          const unsigned int
            n0 = (unsigned int)primitive[0],
            n1 = (unsigned int)primitive[1],
            n2 = (unsigned int)primitive[2],
            n3 = (unsigned int)primitive[3];
          const int
            x0 = (int)projections(n0,0), y0 = (int)projections(n0,1),
            x1 = (int)projections(n1,0), y1 = (int)projections(n1,1),
            x2 = (int)projections(n2,0), y2 = (int)projections(n2,1),
            x3 = (int)projections(n3,0), y3 = (int)projections(n3,1);
          const float
            z0 = vertices(n0,2) + Z + _focale,
            z1 = vertices(n1,2) + Z + _focale,
            z2 = vertices(n2,2) + Z + _focale,
            z3 = vertices(n3,2) + Z + _focale;

          switch (render_type) {
          case 0 :
            draw_point(x0,y0,pcolor,opacity).draw_point(x1,y1,pcolor,opacity).
              draw_point(x2,y2,pcolor,opacity).draw_point(x3,y3,pcolor,opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi(color[0],color[1],color[2],(unsigned char)(opacity*255));
              board.drawCircle((float)x0,height()-(float)y0,0);
              board.drawCircle((float)x1,height()-(float)y1,0);
              board.drawCircle((float)x2,height()-(float)y2,0);
              board.drawCircle((float)x3,height()-(float)y3,0);
            }
#endif
# 34347 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          case 1 :
            if (zbuffer)
              draw_line(zbuffer,x0,y0,z0,x1,y1,z1,pcolor,opacity).draw_line(zbuffer,x1,y1,z1,x2,y2,z2,pcolor,opacity).
                draw_line(zbuffer,x2,y2,z2,x3,y3,z3,pcolor,opacity).draw_line(zbuffer,x3,y3,z3,x0,y0,z0,pcolor,opacity);
            else
              draw_line(x0,y0,x1,y1,pcolor,opacity).draw_line(x1,y1,x2,y2,pcolor,opacity).
                draw_line(x2,y2,x3,y3,pcolor,opacity).draw_line(x3,y3,x0,y0,pcolor,opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi(color[0],color[1],color[2],(unsigned char)(opacity*255));
              board.drawLine((float)x0,height()-(float)y0,(float)x1,height()-(float)y1);
              board.drawLine((float)x1,height()-(float)y1,(float)x2,height()-(float)y2);
              board.drawLine((float)x2,height()-(float)y2,(float)x3,height()-(float)y3);
              board.drawLine((float)x3,height()-(float)y3,(float)x0,height()-(float)y0);
            }
#endif
# 34364 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          case 2 :
            if (zbuffer)
              draw_triangle(zbuffer,x0,y0,z0,x1,y1,z1,x2,y2,z2,pcolor,opacity).draw_triangle(zbuffer,x0,y0,z0,x2,y2,z2,x3,y3,z3,pcolor,opacity);
            else
              draw_triangle(x0,y0,x1,y1,x2,y2,pcolor,opacity).draw_triangle(x0,y0,x2,y2,x3,y3,pcolor,opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi(color[0],color[1],color[2],(unsigned char)(opacity*255));
              board.fillTriangle((float)x0,height()-(float)y0,(float)x1,height()-(float)y1,(float)x2,height()-(float)y2);
              board.fillTriangle((float)x0,height()-(float)y0,(float)x2,height()-(float)y2,(float)x3,height()-(float)y3);
            }
#endif
# 34377 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          case 3 :
            if (zbuffer)
              draw_triangle(zbuffer,x0,y0,z0,x1,y1,z1,x2,y2,z2,pcolor,opacity,lightprops(l)).
                draw_triangle(zbuffer,x0,y0,z0,x2,y2,z2,x3,y3,z3,pcolor,opacity,lightprops(l));
            else
              _draw_triangle(x0,y0,x1,y1,x2,y2,pcolor,opacity,lightprops(l)).
                _draw_triangle(x0,y0,x2,y2,x3,y3,pcolor,opacity,lightprops(l));
#ifdef cimg_use_board
            if (pboard) {
              const float lp = cimg::min(lightprops(l),1);
              board.setPenColorRGBi((unsigned char)(color[0]*lp),
                                     (unsigned char)(color[1]*lp),
                                     (unsigned char)(color[2]*lp),(unsigned char)(opacity*255));
              board.fillTriangle((float)x0,height()-(float)y0,(float)x1,height()-(float)y1,(float)x2,height()-(float)y2);
              board.fillTriangle((float)x0,height()-(float)y0,(float)x2,height()-(float)y2,(float)x3,height()-(float)y3);
            }
#endif
# 34395 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          case 4 : {
            const float
              lightprop0 = lightprops(n0), lightprop1 = lightprops(n1),
              lightprop2 = lightprops(n2), lightprop3 = lightprops(n3);
            if (zbuffer)
              draw_triangle(zbuffer,x0,y0,z0,x1,y1,z1,x2,y2,z2,pcolor,lightprop0,lightprop1,lightprop2,opacity).
                draw_triangle(zbuffer,x0,y0,z0,x2,y2,z2,x3,y3,z3,pcolor,lightprop0,lightprop2,lightprop3,opacity);
            else
              draw_triangle(x0,y0,x1,y1,x2,y2,pcolor,lightprop0,lightprop1,lightprop2,opacity).
                draw_triangle(x0,y0,x2,y2,x3,y3,pcolor,lightprop0,lightprop2,lightprop3,opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi((unsigned char)(color[0]),
                                     (unsigned char)(color[1]),
                                     (unsigned char)(color[2]),
                                     (unsigned char)(opacity*255));
              board.fillGouraudTriangle((float)x0,height()-(float)y0,lightprop0,
                                         (float)x1,height()-(float)y1,lightprop1,
                                         (float)x2,height()-(float)y2,lightprop2);
              board.fillGouraudTriangle((float)x0,height()-(float)y0,lightprop0,
                                         (float)x2,height()-(float)y2,lightprop2,
                                         (float)x3,height()-(float)y3,lightprop3);
            }
#endif
# 34420 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
          } break;
          case 5 : {
            const unsigned int
              lx0 = (unsigned int)lightprops(n0,0), ly0 = (unsigned int)lightprops(n0,1),
              lx1 = (unsigned int)lightprops(n1,0), ly1 = (unsigned int)lightprops(n1,1),
              lx2 = (unsigned int)lightprops(n2,0), ly2 = (unsigned int)lightprops(n2,1),
              lx3 = (unsigned int)lightprops(n3,0), ly3 = (unsigned int)lightprops(n3,1);
            if (zbuffer)
              draw_triangle(zbuffer,x0,y0,z0,x1,y1,z1,x2,y2,z2,pcolor,light_texture,lx0,ly0,lx1,ly1,lx2,ly2,opacity).
                draw_triangle(zbuffer,x0,y0,z0,x2,y2,z2,x3,y3,z3,pcolor,light_texture,lx0,ly0,lx2,ly2,lx3,ly3,opacity);
            else
              draw_triangle(x0,y0,x1,y1,x2,y2,pcolor,light_texture,lx0,ly0,lx1,ly1,lx2,ly2,opacity).
                draw_triangle(x0,y0,x2,y2,x3,y3,pcolor,light_texture,lx0,ly0,lx2,ly2,lx3,ly3,opacity);
#ifdef cimg_use_board
            if (pboard) {
              const float
                l0 = light_texture((int)(light_texture.width()/2*(1+lx0)), (int)(light_texture.height()/2*(1+ly0))),
                l1 = light_texture((int)(light_texture.width()/2*(1+lx1)), (int)(light_texture.height()/2*(1+ly1))),
                l2 = light_texture((int)(light_texture.width()/2*(1+lx2)), (int)(light_texture.height()/2*(1+ly2))),
                l3 = light_texture((int)(light_texture.width()/2*(1+lx3)), (int)(light_texture.height()/2*(1+ly3)));
              board.setPenColorRGBi((unsigned char)(color[0]),
                                     (unsigned char)(color[1]),
                                     (unsigned char)(color[2]),
                                     (unsigned char)(opacity*255));
              board.fillGouraudTriangle((float)x0,height()-(float)y0,l0,
                                         (float)x1,height()-(float)y1,l1,
                                         (float)x2,height()-(float)y2,l2);
              board.fillGouraudTriangle((float)x0,height()-(float)y0,l0,
                                         (float)x2,height()-(float)y2,l2,
                                         (float)x3,height()-(float)y3,l3);
            }
#endif
# 34452 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
          } break;
          }
        } break;
        case 9 : { // Textured triangle
          if (!__color)
            throw CImgArgumentException(_cimg_instance
                                        "draw_object3d(): Undefined texture for triangle primitive [%u].",
                                        cimg_instance,n_primitive);
          const unsigned int
            n0 = (unsigned int)primitive[0],
            n1 = (unsigned int)primitive[1],
            n2 = (unsigned int)primitive[2],
            tx0 = (unsigned int)primitive[3],
            ty0 = (unsigned int)primitive[4],
            tx1 = (unsigned int)primitive[5],
            ty1 = (unsigned int)primitive[6],
            tx2 = (unsigned int)primitive[7],
            ty2 = (unsigned int)primitive[8];
          const int
            x0 = (int)projections(n0,0), y0 = (int)projections(n0,1),
            x1 = (int)projections(n1,0), y1 = (int)projections(n1,1),
            x2 = (int)projections(n2,0), y2 = (int)projections(n2,1);
          const float
            z0 = vertices(n0,2) + Z + _focale,
            z1 = vertices(n1,2) + Z + _focale,
            z2 = vertices(n2,2) + Z + _focale;
          switch (render_type) {
          case 0 :
            draw_point(x0,y0,color.get_vector_at(tx0,ty0)._data,opacity).
              draw_point(x1,y1,color.get_vector_at(tx1,ty1)._data,opacity).
              draw_point(x2,y2,color.get_vector_at(tx2,ty2)._data,opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi(128,128,128,(unsigned char)(opacity*255));
              board.drawCircle((float)x0,height()-(float)y0,0);
              board.drawCircle((float)x1,height()-(float)y1,0);
              board.drawCircle((float)x2,height()-(float)y2,0);
            }
#endif
# 34491 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          case 1 :
            if (zbuffer)
              draw_line(zbuffer,x0,y0,z0,x1,y1,z1,color,tx0,ty0,tx1,ty1,opacity).
                draw_line(zbuffer,x0,y0,z0,x2,y2,z2,color,tx0,ty0,tx2,ty2,opacity).
                draw_line(zbuffer,x1,y1,z1,x2,y2,z2,color,tx1,ty1,tx2,ty2,opacity);
            else
              draw_line(x0,y0,z0,x1,y1,z1,color,tx0,ty0,tx1,ty1,opacity).
                draw_line(x0,y0,z0,x2,y2,z2,color,tx0,ty0,tx2,ty2,opacity).
                draw_line(x1,y1,z1,x2,y2,z2,color,tx1,ty1,tx2,ty2,opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi(128,128,128,(unsigned char)(opacity*255));
              board.drawLine((float)x0,height()-(float)y0,(float)x1,height()-(float)y1);
              board.drawLine((float)x0,height()-(float)y0,(float)x2,height()-(float)y2);
              board.drawLine((float)x1,height()-(float)y1,(float)x2,height()-(float)y2);
            }
#endif
# 34509 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          case 2 :
            if (zbuffer) draw_triangle(zbuffer,x0,y0,z0,x1,y1,z1,x2,y2,z2,color,tx0,ty0,tx1,ty1,tx2,ty2,opacity);
            else draw_triangle(x0,y0,z0,x1,y1,z1,x2,y2,z2,color,tx0,ty0,tx1,ty1,tx2,ty2,opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi(128,128,128,(unsigned char)(opacity*255));
              board.fillTriangle((float)x0,height()-(float)y0,(float)x1,height()-(float)y1,(float)x2,height()-(float)y2);
            }
#endif
# 34519 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          case 3 :
            if (zbuffer) draw_triangle(zbuffer,x0,y0,z0,x1,y1,z1,x2,y2,z2,color,tx0,ty0,tx1,ty1,tx2,ty2,opacity,lightprops(l));
            else draw_triangle(x0,y0,z0,x1,y1,z1,x2,y2,z2,color,tx0,ty0,tx1,ty1,tx2,ty2,opacity,lightprops(l));
#ifdef cimg_use_board
            if (pboard) {
              const float lp = cimg::min(lightprops(l),1);
              board.setPenColorRGBi((unsigned char)(128*lp),
                                    (unsigned char)(128*lp),
                                    (unsigned char)(128*lp),
                                    (unsigned char)(opacity*255));
              board.fillTriangle((float)x0,height()-(float)y0,(float)x1,height()-(float)y1,(float)x2,height()-(float)y2);
            }
#endif
# 34533 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          case 4 :
            if (zbuffer)
              draw_triangle(zbuffer,x0,y0,z0,x1,y1,z1,x2,y2,z2,color,tx0,ty0,tx1,ty1,tx2,ty2,lightprops(n0),lightprops(n1),lightprops(n2),opacity);
            else
              draw_triangle(x0,y0,z0,x1,y1,z1,x2,y2,z2,color,tx0,ty0,tx1,ty1,tx2,ty2,lightprops(n0),lightprops(n1),lightprops(n2),opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi(128,128,128,(unsigned char)(opacity*255));
              board.fillGouraudTriangle((float)x0,height()-(float)y0,lightprops(n0),
                                        (float)x1,height()-(float)y1,lightprops(n1),
                                        (float)x2,height()-(float)y2,lightprops(n2));
            }
#endif
# 34547 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          case 5 :
            if (zbuffer)
              draw_triangle(zbuffer,x0,y0,z0,x1,y1,z1,x2,y2,z2,color,tx0,ty0,tx1,ty1,tx2,ty2,light_texture,
                            (unsigned int)lightprops(n0,0),(unsigned int)lightprops(n0,1),
                            (unsigned int)lightprops(n1,0),(unsigned int)lightprops(n1,1),
                            (unsigned int)lightprops(n2,0),(unsigned int)lightprops(n2,1),
                            opacity);
            else
              draw_triangle(x0,y0,z0,x1,y1,z1,x2,y2,z2,color,tx0,ty0,tx1,ty1,tx2,ty2,light_texture,
                            (unsigned int)lightprops(n0,0),(unsigned int)lightprops(n0,1),
                            (unsigned int)lightprops(n1,0),(unsigned int)lightprops(n1,1),
                            (unsigned int)lightprops(n2,0),(unsigned int)lightprops(n2,1),
                            opacity);
#ifdef cimg_use_board
            if (pboard) {
              const float
                l0 = light_texture((int)(light_texture.width()/2*(1+lightprops(n0,0))), (int)(light_texture.height()/2*(1+lightprops(n0,1)))),
                l1 = light_texture((int)(light_texture.width()/2*(1+lightprops(n1,0))), (int)(light_texture.height()/2*(1+lightprops(n1,1)))),
                l2 = light_texture((int)(light_texture.width()/2*(1+lightprops(n2,0))), (int)(light_texture.height()/2*(1+lightprops(n2,1))));
              board.setPenColorRGBi(128,128,128,(unsigned char)(opacity*255));
              board.fillGouraudTriangle((float)x0,height()-(float)y0,l0,(float)x1,height()-(float)y1,l1,(float)x2,height()-(float)y2,l2);
            }
#endif
# 34571 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          }
        } break;
        case 12 : { // Textured quadrangle
          if (!__color)
            throw CImgArgumentException(_cimg_instance
                                        "draw_object3d(): Undefined texture for quadrangle primitive [%u].",
                                        cimg_instance,n_primitive);
          const unsigned int
            n0 = (unsigned int)primitive[0],
            n1 = (unsigned int)primitive[1],
            n2 = (unsigned int)primitive[2],
            n3 = (unsigned int)primitive[3],
            tx0 = (unsigned int)primitive[4],
            ty0 = (unsigned int)primitive[5],
            tx1 = (unsigned int)primitive[6],
            ty1 = (unsigned int)primitive[7],
            tx2 = (unsigned int)primitive[8],
            ty2 = (unsigned int)primitive[9],
            tx3 = (unsigned int)primitive[10],
            ty3 = (unsigned int)primitive[11];
          const int
            x0 = (int)projections(n0,0), y0 = (int)projections(n0,1),
            x1 = (int)projections(n1,0), y1 = (int)projections(n1,1),
            x2 = (int)projections(n2,0), y2 = (int)projections(n2,1),
            x3 = (int)projections(n3,0), y3 = (int)projections(n3,1);
          const float
            z0 = vertices(n0,2) + Z + _focale,
            z1 = vertices(n1,2) + Z + _focale,
            z2 = vertices(n2,2) + Z + _focale,
            z3 = vertices(n3,2) + Z + _focale;

          switch (render_type) {
          case 0 :
            draw_point(x0,y0,color.get_vector_at(tx0,ty0)._data,opacity).
              draw_point(x1,y1,color.get_vector_at(tx1,ty1)._data,opacity).
              draw_point(x2,y2,color.get_vector_at(tx2,ty2)._data,opacity).
              draw_point(x3,y3,color.get_vector_at(tx3,ty3)._data,opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi(128,128,128,(unsigned char)(opacity*255));
              board.drawCircle((float)x0,height()-(float)y0,0);
              board.drawCircle((float)x1,height()-(float)y1,0);
              board.drawCircle((float)x2,height()-(float)y2,0);
              board.drawCircle((float)x3,height()-(float)y3,0);
            }
#endif
# 34618 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          case 1 :
            if (zbuffer)
              draw_line(zbuffer,x0,y0,z0,x1,y1,z1,color,tx0,ty0,tx1,ty1,opacity).
                draw_line(zbuffer,x1,y1,z1,x2,y2,z2,color,tx1,ty1,tx2,ty2,opacity).
                draw_line(zbuffer,x2,y2,z2,x3,y3,z3,color,tx2,ty2,tx3,ty3,opacity).
                draw_line(zbuffer,x3,y3,z3,x0,y0,z0,color,tx3,ty3,tx0,ty0,opacity);
            else
              draw_line(x0,y0,z0,x1,y1,z1,color,tx0,ty0,tx1,ty1,opacity).
                draw_line(x1,y1,z1,x2,y2,z2,color,tx1,ty1,tx2,ty2,opacity).
                draw_line(x2,y2,z2,x3,y3,z3,color,tx2,ty2,tx3,ty3,opacity).
                draw_line(x3,y3,z3,x0,y0,z0,color,tx3,ty3,tx0,ty0,opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi(128,128,128,(unsigned char)(opacity*255));
              board.drawLine((float)x0,height()-(float)y0,(float)x1,height()-(float)y1);
              board.drawLine((float)x1,height()-(float)y1,(float)x2,height()-(float)y2);
              board.drawLine((float)x2,height()-(float)y2,(float)x3,height()-(float)y3);
              board.drawLine((float)x3,height()-(float)y3,(float)x0,height()-(float)y0);
            }
#endif
# 34639 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          case 2 :
            if (zbuffer)
              draw_triangle(zbuffer,x0,y0,z0,x1,y1,z1,x2,y2,z2,color,tx0,ty0,tx1,ty1,tx2,ty2,opacity).
                draw_triangle(zbuffer,x0,y0,z0,x2,y2,z2,x3,y3,z3,color,tx0,ty0,tx2,ty2,tx3,ty3,opacity);
            else
              draw_triangle(x0,y0,z0,x1,y1,z1,x2,y2,z2,color,tx0,ty0,tx1,ty1,tx2,ty2,opacity).
                draw_triangle(x0,y0,z0,x2,y2,z2,x3,y3,z3,color,tx0,ty0,tx2,ty2,tx3,ty3,opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi(128,128,128,(unsigned char)(opacity*255));
              board.fillTriangle((float)x0,height()-(float)y0,(float)x1,height()-(float)y1,(float)x2,height()-(float)y2);
              board.fillTriangle((float)x0,height()-(float)y0,(float)x2,height()-(float)y2,(float)x3,height()-(float)y3);
            }
#endif
# 34654 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          case 3 :
            if (zbuffer)
              draw_triangle(zbuffer,x0,y0,z0,x1,y1,z1,x2,y2,z2,color,tx0,ty0,tx1,ty1,tx2,ty2,opacity,lightprops(l)).
                draw_triangle(zbuffer,x0,y0,z0,x2,y2,z2,x3,y3,z3,color,tx0,ty0,tx2,ty2,tx3,ty3,opacity,lightprops(l));
            else
              draw_triangle(x0,y0,z0,x1,y1,z1,x2,y2,z2,color,tx0,ty0,tx1,ty1,tx2,ty2,opacity,lightprops(l)).
                draw_triangle(x0,y0,z0,x2,y2,z2,x3,y3,z3,color,tx0,ty0,tx2,ty2,tx3,ty3,opacity,lightprops(l));
#ifdef cimg_use_board
            if (pboard) {
              const float lp = cimg::min(lightprops(l),1);
              board.setPenColorRGBi((unsigned char)(128*lp),
                                     (unsigned char)(128*lp),
                                     (unsigned char)(128*lp),
                                     (unsigned char)(opacity*255));
              board.fillTriangle((float)x0,height()-(float)y0,(float)x1,height()-(float)y1,(float)x2,height()-(float)y2);
              board.fillTriangle((float)x0,height()-(float)y0,(float)x2,height()-(float)y2,(float)x3,height()-(float)y3);
            }
#endif
# 34673 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
            break;
          case 4 : {
            const float
              lightprop0 = lightprops(n0), lightprop1 = lightprops(n1),
              lightprop2 = lightprops(n2), lightprop3 = lightprops(n3);
            if (zbuffer)
              draw_triangle(zbuffer,x0,y0,z0,x1,y1,z1,x2,y2,z2,color,tx0,ty0,tx1,ty1,tx2,ty2,lightprop0,lightprop1,lightprop2,opacity).
                draw_triangle(zbuffer,x0,y0,z0,x2,y2,z2,x3,y3,z3,color,tx0,ty0,tx2,ty2,tx3,ty3,lightprop0,lightprop2,lightprop3,opacity);
            else
              draw_triangle(x0,y0,z0,x1,y1,z1,x2,y2,z2,color,tx0,ty0,tx1,ty1,tx2,ty2,lightprop0,lightprop1,lightprop2,opacity).
                draw_triangle(x0,y0,z0,x2,y2,z2,x3,y3,z3,color,tx0,ty0,tx2,ty2,tx3,ty3,lightprop0,lightprop2,lightprop3,opacity);
#ifdef cimg_use_board
            if (pboard) {
              board.setPenColorRGBi(128,128,128,(unsigned char)(opacity*255));
              board.fillGouraudTriangle((float)x0,height()-(float)y0,lightprop0,
                                         (float)x1,height()-(float)y1,lightprop1,
                                         (float)x2,height()-(float)y2,lightprop2);
              board.fillGouraudTriangle((float)x0,height()-(float)y0,lightprop0,
                                         (float)x2,height()-(float)y2,lightprop2,
                                         (float)x3,height()-(float)y3,lightprop3);
            }
#endif
# 34695 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
          } break;
          case 5 : {
            const unsigned int
              lx0 = (unsigned int)lightprops(n0,0), ly0 = (unsigned int)lightprops(n0,1),
              lx1 = (unsigned int)lightprops(n1,0), ly1 = (unsigned int)lightprops(n1,1),
              lx2 = (unsigned int)lightprops(n2,0), ly2 = (unsigned int)lightprops(n2,1),
              lx3 = (unsigned int)lightprops(n3,0), ly3 = (unsigned int)lightprops(n3,1);
            if (zbuffer)
              draw_triangle(zbuffer,x0,y0,z0,x1,y1,z1,x2,y2,z2,color,tx0,ty0,tx1,ty1,tx2,ty2,light_texture,lx0,ly0,lx1,ly1,lx2,ly2,opacity).
                draw_triangle(zbuffer,x0,y0,z0,x2,y2,z2,x3,y3,z3,color,tx0,ty0,tx2,ty2,tx3,ty3,light_texture,lx0,ly0,lx2,ly2,lx3,ly3,opacity);
            else
              draw_triangle(x0,y0,z0,x1,y1,z1,x2,y2,z2,color,tx0,ty0,tx1,ty1,tx2,ty2,light_texture,lx0,ly0,lx1,ly1,lx2,ly2,opacity).
                draw_triangle(x0,y0,z0,x2,y2,z2,x3,y3,z3,color,tx0,ty0,tx2,ty2,tx3,ty3,light_texture,lx0,ly0,lx2,ly2,lx3,ly3,opacity);
#ifdef cimg_use_board
            if (pboard) {
              const float
                l0 = light_texture((int)(light_texture.width()/2*(1+lx0)), (int)(light_texture.height()/2*(1+ly0))),
                l1 = light_texture((int)(light_texture.width()/2*(1+lx1)), (int)(light_texture.height()/2*(1+ly1))),
                l2 = light_texture((int)(light_texture.width()/2*(1+lx2)), (int)(light_texture.height()/2*(1+ly2))),
                l3 = light_texture((int)(light_texture.width()/2*(1+lx3)), (int)(light_texture.height()/2*(1+ly3)));
              board.setPenColorRGBi(128,128,128,(unsigned char)(opacity*255));
              board.fillGouraudTriangle((float)x0,height()-(float)y0,l0,
                                         (float)x1,height()-(float)y1,l1,
                                         (float)x2,height()-(float)y2,l2);
              board.fillGouraudTriangle((float)x0,height()-(float)y0,l0,
                                         (float)x2,height()-(float)y2,l2,
                                         (float)x3,height()-(float)y3,l3);
            }
#endif
# 34724 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
          } break;
          }
        } break;
        }
      }

      if (render_type==5) cimg::mutex(10,0);
      return *this;
    }

    //@}
    //---------------------------
    //
    //! \name Data Input
    //@{
    //---------------------------

    //! Launch simple interface to select a shape from an image.
    /**
       \param disp Display window to use.
       \param feature_type Type of feature to select. Can be <tt>{ 0=point | 1=line | 2=rectangle | 3=ellipse }</tt>.
       \param XYZ Pointer to 3 values X,Y,Z which tells about the projection point coordinates, for volumetric images.
    **/
    CImg<T>& select(CImgDisplay &disp,
		    const unsigned int feature_type=2, unsigned int *const XYZ=0) {
      return get_select(disp,feature_type,XYZ).move_to(*this);
    }

    //! Simple interface to select a shape from an image \overloading.
    CImg<T>& select(const char *const title,
		    const unsigned int feature_type=2, unsigned int *const XYZ=0) {
      return get_select(title,feature_type,XYZ).move_to(*this);
    }

    //! Simple interface to select a shape from an image \newinstance.
    CImg<intT> get_select(CImgDisplay &disp,
		          const unsigned int feature_type=2, unsigned int *const XYZ=0) const {
      return _get_select(disp,0,feature_type,XYZ,0,0,0,true,false);
    }

    //! Simple interface to select a shape from an image \newinstance.
    CImg<intT> get_select(const char *const title,
    			  const unsigned int feature_type=2, unsigned int *const XYZ=0) const {
      CImgDisplay disp;
      return _get_select(disp,title,feature_type,XYZ,0,0,0,true,false);
    }

    CImg<intT> _get_select(CImgDisplay &disp, const char *const title,
			   const unsigned int feature_type, unsigned int *const XYZ,
			   const int origX, const int origY, const int origZ,
                           const bool reset_view3d,
                           const bool force_display_z_coord) const {
      if (is_empty()) return CImg<intT>(1,feature_type==0?3:6,1,1,-1);
      if (!disp) {
        disp.assign(cimg_fitscreen(_width,_height,_depth),title?title:0,1);
        if (!title) disp.set_title("CImg<%s> (%ux%ux%ux%u)",pixel_type(),_width,_height,_depth,_spectrum);
      } else if (title) disp.set_title("%s",title);

      const unsigned int old_normalization = disp.normalization();
      bool old_is_resized = disp.is_resized();
      disp._normalization = 0;
      disp.show().set_key(0).set_wheel().show_mouse();

      unsigned char foreground_color[] = { 255,255,255 }, background_color[] = { 0,0,0 };

      int area = 0, starting_area = 0, clicked_area = 0, phase = 0,
        X0 = (int)((XYZ?XYZ[0]:(_width-1)/2)%_width),
        Y0 = (int)((XYZ?XYZ[1]:(_height-1)/2)%_height),
        Z0 = (int)((XYZ?XYZ[2]:(_depth-1)/2)%_depth),
        X1 =-1, Y1 = -1, Z1 = -1,
        X3d = -1, Y3d = -1,
        oX3d = X3d, oY3d = -1,
        omx = -1, omy = -1;
      float X = -1, Y = -1, Z = -1;
      unsigned int old_button = 0, key = 0;

      bool shape_selected = false, text_down = false, visible_cursor = true;
      static CImg<floatT> pose3d;
      static bool is_view3d = false, is_axes = true;
      if (reset_view3d) { pose3d.assign(); is_view3d = false; }
      CImg<floatT> points3d, opacities3d, sel_opacities3d;
      CImgList<uintT> primitives3d, sel_primitives3d;
      CImgList<ucharT> colors3d, sel_colors3d;
      CImg<ucharT> visu, visu0, view3d;
      char text[1024] = { 0 };

      while (!key && !disp.is_closed() && !shape_selected) {

        // Handle mouse motion and selection
        int
          mx = disp.mouse_x(),
          my = disp.mouse_y();

        const float
          mX = mx<0?-1.0f:(float)mx*(width()+(depth()>1?depth():0))/disp.width(),
          mY = my<0?-1.0f:(float)my*(height()+(depth()>1?depth():0))/disp.height();

        area = 0;
        if (mX>=0 && mY>=0 && mX<width() && mY<height())  { area = 1; X = mX; Y = mY; Z = (float)(phase?Z1:Z0); }
        if (mX>=0 && mX<width() && mY>=height()) { area = 2; X = mX; Z = mY - _height; Y = (float)(phase?Y1:Y0); }
        if (mY>=0 && mX>=width() && mY<height()) { area = 3; Y = mY; Z = mX - _width; X = (float)(phase?X1:X0); }
        if (mX>=width() && mY>=height()) area = 4;
        if (disp.button()) { if (!clicked_area) clicked_area = area; } else clicked_area = 0;

        switch (key = disp.key()) {
#if cimg_OS!=2
        case cimg::keyCTRLRIGHT :
#endif
# 34832 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        case 0 : case cimg::keyCTRLLEFT : key = 0; break;
        case cimg::keyPAGEUP : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) { disp.set_wheel(1); key = 0; } break;
        case cimg::keyPAGEDOWN : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) { disp.set_wheel(-1); key = 0; } break;
        case cimg::keyA : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
            is_axes = !is_axes; disp.set_key(key,false); key = 0; visu0.assign();
          } break;
        case cimg::keyD : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
            disp.set_fullscreen(false).resize(CImgDisplay::_fitscreen(3*disp.width()/2,3*disp.height()/2,1,128,-100,false),
                                              CImgDisplay::_fitscreen(3*disp.width()/2,3*disp.height()/2,1,128,-100,true),false).
              _is_resized = true;
            disp.set_key(key,false); key = 0; visu0.assign();
          } break;
        case cimg::keyC : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
            disp.set_fullscreen(false).resize(cimg_fitscreen(2*disp.width()/3,2*disp.height()/3,1),false)._is_resized = true;
            disp.set_key(key,false); key = 0; visu0.assign();
          } break;
        case cimg::keyR : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
            disp.set_fullscreen(false).resize(cimg_fitscreen(_width,_height,_depth),false)._is_resized = true;
            disp.set_key(key,false); key = 0; visu0.assign();
          } break;
        case cimg::keyF : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
            disp.resize(disp.screen_width(),disp.screen_height(),false).toggle_fullscreen()._is_resized = true;
            disp.set_key(key,false); key = 0; visu0.assign();
          } break;
        case cimg::keyV : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
            is_view3d = !is_view3d; disp.set_key(key,false); key = 0; visu0.assign();
          } break;
        case cimg::keyS : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
            static unsigned int snap_number = 0;
            char filename[32] = { 0 };
            std::FILE *file;
            do {
              cimg_snprintf(filename,sizeof(filename),cimg_appname "_%.4u.bmp",snap_number++);
              if ((file=std::fopen(filename,"r"))!=0) cimg::fclose(file);
            } while (file);
            if (visu0) {
              visu.draw_text(0,0," Saving snapshot... ",foreground_color,background_color,1,13).display(disp);
              visu0.save(filename);
              visu.draw_text(0,0," Snapshot '%s' saved. ",foreground_color,background_color,1,13,filename).display(disp);
            }
            disp.set_key(key,false); key = 0;
          } break;
        case cimg::keyO : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
            static unsigned int snap_number = 0;
            char filename[32] = { 0 };
            std::FILE *file;
            do {
#ifdef cimg_use_zlib
              cimg_snprintf(filename,sizeof(filename),cimg_appname "_%.4u.cimgz",snap_number++);
#else
# 34882 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
              cimg_snprintf(filename,sizeof(filename),cimg_appname "_%.4u.cimg",snap_number++);
#endif
# 34884 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
              if ((file=std::fopen(filename,"r"))!=0) cimg::fclose(file);
            } while (file);
            visu.draw_text(0,0," Saving instance... ",foreground_color,background_color,1,13).display(disp);
            save(filename);
            visu.draw_text(0,0," Instance '%s' saved. ",foreground_color,background_color,1,13,filename).display(disp);
            disp.set_key(key,false); key = 0;
          } break;
        }

        switch (area) {

        case 0 : // When mouse is out of image range.
          mx = my = -1; X = Y = Z = -1;
          break;

        case 1 : case 2 : case 3 : // When mouse is over the XY,XZ or YZ projections.
          if (disp.button()&1 && phase<2 && clicked_area==area) { // When selection has been started (1st step).
            if (_depth>1 && (X1!=(int)X || Y1!=(int)Y || Z1!=(int)Z)) visu0.assign();
            X1 = (int)X; Y1 = (int)Y; Z1 = (int)Z;
          }
          if (!(disp.button()&1) && phase>=2 && clicked_area!=area) { // When selection is at 2nd step (for volumes).
            switch (starting_area) {
            case 1 : if (Z1!=(int)Z) visu0.assign(); Z1 = (int)Z; break;
            case 2 : if (Y1!=(int)Y) visu0.assign(); Y1 = (int)Y; break;
            case 3 : if (X1!=(int)X) visu0.assign(); X1 = (int)X; break;
            }
          }
          if (disp.button()&2 && clicked_area==area) { // When moving through the image/volume.
            if (phase) {
              if (_depth>1 && (X1!=(int)X || Y1!=(int)Y || Z1!=(int)Z)) visu0.assign();
              X1 = (int)X; Y1 = (int)Y; Z1 = (int)Z;
            } else {
              if (_depth>1 && (X0!=(int)X || Y0!=(int)Y || Z0!=(int)Z)) visu0.assign();
              X0 = (int)X; Y0 = (int)Y; Z0 = (int)Z;
            }
          }
          if (disp.button()&4) { // Reset positions.
            X = (float)X0; Y = (float)Y0; Z = (float)Z0; phase = area = clicked_area = starting_area = 0; visu0.assign();
          }
          if (disp.wheel()) { // When moving through the slices of the volume (with mouse wheel).
            if (_depth>1 && !disp.is_keyCTRLLEFT() && !disp.is_keyCTRLRIGHT() && !disp.is_keySHIFTLEFT() && !disp.is_keySHIFTRIGHT() &&
                !disp.is_keyALT() && !disp.is_keyALTGR()) {
              switch (area) {
              case 1 :
                if (phase) Z = (float)(Z1+=disp.wheel()); else Z = (float)(Z0+=disp.wheel());
                visu0.assign(); break;
              case 2 :
                if (phase) Y = (float)(Y1+=disp.wheel()); else Y = (float)(Y0+=disp.wheel());
                visu0.assign(); break;
              case 3 :
                if (phase) X = (float)(X1+=disp.wheel()); else X = (float)(X0+=disp.wheel());
                visu0.assign(); break;
              }
              disp.set_wheel();
            } else key = ~0U;
          }
          if ((disp.button()&1)!=old_button) { // When left button has just been pressed or released.
            switch (phase) {
            case 0 :
              if (area==clicked_area) {
                X0 = X1 = (int)X; Y0 = Y1 = (int)Y; Z0 = Z1 = (int)Z; starting_area = area; ++phase;
              } break;
            case 1 :
              if (area==starting_area) {
                X1 = (int)X; Y1 = (int)Y; Z1 = (int)Z; ++phase;
              } else if (!(disp.button()&1)) { X = (float)X0; Y = (float)Y0; Z = (float)Z0; phase = 0; visu0.assign(); }
              break;
            case 2 : ++phase; break;
            }
            old_button = disp.button()&1;
          }
          break;

        case 4 : // When mouse is over the 3d view.
          if (is_view3d && points3d) {
            X3d = mx - _width*disp.width()/(_width+(_depth>1?_depth:0));
            Y3d = my - _height*disp.height()/(_height+(_depth>1?_depth:0));
            if (oX3d<0) { oX3d = X3d; oY3d = Y3d; }
            if ((disp.button()&3)==3) { pose3d.assign(); view3d.assign(); oX3d = oY3d = X3d = Y3d = -1; } // Left + right buttons: reset.
            else if (disp.button()&1 && pose3d && (oX3d!=X3d || oY3d!=Y3d)) { // Left button: rotate.
              const float
                R = 0.45f*cimg::min(view3d._width,view3d._height),
                R2 = R*R,
                u0 = (float)(oX3d-view3d.width()/2),
                v0 = (float)(oY3d-view3d.height()/2),
                u1 = (float)(X3d-view3d.width()/2),
                v1 = (float)(Y3d-view3d.height()/2),
                n0 = (float)std::sqrt(u0*u0+v0*v0),
                n1 = (float)std::sqrt(u1*u1+v1*v1),
                nu0 = n0>R?(u0*R/n0):u0,
                nv0 = n0>R?(v0*R/n0):v0,
                nw0 = (float)std::sqrt(cimg::max(0,R2-nu0*nu0-nv0*nv0)),
                nu1 = n1>R?(u1*R/n1):u1,
                nv1 = n1>R?(v1*R/n1):v1,
                nw1 = (float)std::sqrt(cimg::max(0,R2-nu1*nu1-nv1*nv1)),
                u = nv0*nw1 - nw0*nv1,
                v = nw0*nu1 - nu0*nw1,
                w = nv0*nu1 - nu0*nv1,
                n = (float)std::sqrt(u*u+v*v+w*w),
                alpha = (float)std::asin(n/R2);
              pose3d.draw_image(CImg<floatT>::rotation_matrix(u,v,w,alpha)*pose3d.get_crop(0,0,2,2));
              view3d.assign();
            } else if (disp.button()&2 && pose3d && oY3d!=Y3d) {  // Right button: zoom.
              pose3d(3,2)-=(oY3d - Y3d)*1.5f; view3d.assign();
            }
            if (disp.wheel()) { // Wheel: zoom
              pose3d(3,2)-=disp.wheel()*15; view3d.assign(); disp.set_wheel();
            }
            if (disp.button()&4 && pose3d && (oX3d!=X3d || oY3d!=Y3d)) { // Middle button: shift.
              pose3d(3,0)-=oX3d - X3d; pose3d(3,1)-=oY3d - Y3d; view3d.assign();
            }
            oX3d = X3d; oY3d = Y3d;
          }
          mx = my = -1; X = Y = Z = -1;
          break;
        }

        if (phase) {
          if (!feature_type) shape_selected = phase?true:false;
          else {
            if (_depth>1) shape_selected = (phase==3)?true:false;
            else shape_selected = (phase==2)?true:false;
          }
        }

        if (X0<0) X0 = 0; if (X0>=width()) X0 = width() - 1;
        if (Y0<0) Y0 = 0; if (Y0>=height()) Y0 = height() - 1;
        if (Z0<0) Z0 = 0; if (Z0>=depth()) Z0 = depth() - 1;
        if (X1<1) X1 = 0; if (X1>=width()) X1 = width() - 1;
        if (Y1<0) Y1 = 0; if (Y1>=height()) Y1 = height() - 1;
        if (Z1<0) Z1 = 0; if (Z1>=depth()) Z1 = depth() - 1;

        // Draw visualization image on the display
        if (mx!=omx || my!=omy || !visu0 || (_depth>1 && !view3d)) {

          if (!visu0) { // Create image of projected planes.
            __get_select(disp,old_normalization,phase?X1:X0,phase?Y1:Y0,phase?Z1:Z0).move_to(visu0).resize(disp);
            view3d.assign();
            points3d.assign();
          }

          if (is_view3d && _depth>1 && !view3d) { // Create 3d view for volumetric images.
            const unsigned int
              _x3d = (unsigned int)cimg::round((float)_width*visu0._width/(_width+_depth),1,1),
              _y3d = (unsigned int)cimg::round((float)_height*visu0._height/(_height+_depth),1,1),
              x3d = _x3d>=visu0._width?visu0._width-1:_x3d,
              y3d = _y3d>=visu0._height?visu0._height-1:_y3d;
            CImg<ucharT>(1,2,1,1,64,128).resize(visu0._width-x3d,visu0._height-y3d,1,visu0._spectrum,3).move_to(view3d);
            if (!points3d) {
              get_projections3d(primitives3d,colors3d,phase?X1:X0,phase?Y1:Y0,phase?Z1:Z0,true).move_to(points3d);
              points3d.append(CImg<floatT>(8,3,1,1,
                                           0,_width-1,_width-1,0,0,_width-1,_width-1,0,
                                           0,0,_height-1,_height-1,0,0,_height-1,_height-1,
                                           0,0,0,0,_depth-1,_depth-1,_depth-1,_depth-1),'x');
              CImg<uintT>::vector(12,13).move_to(primitives3d); CImg<uintT>::vector(13,14).move_to(primitives3d);
              CImg<uintT>::vector(14,15).move_to(primitives3d); CImg<uintT>::vector(15,12).move_to(primitives3d);
              CImg<uintT>::vector(16,17).move_to(primitives3d); CImg<uintT>::vector(17,18).move_to(primitives3d);
              CImg<uintT>::vector(18,19).move_to(primitives3d); CImg<uintT>::vector(19,16).move_to(primitives3d);
              CImg<uintT>::vector(12,16).move_to(primitives3d); CImg<uintT>::vector(13,17).move_to(primitives3d);
              CImg<uintT>::vector(14,18).move_to(primitives3d); CImg<uintT>::vector(15,19).move_to(primitives3d);
              colors3d.insert(12,CImg<ucharT>::vector(255,255,255));
              opacities3d.assign(primitives3d.width(),1,1,1,0.5f);
              if (!phase) {
                opacities3d[0] = opacities3d[1] = opacities3d[2] = 0.8f;
                sel_primitives3d.assign();
                sel_colors3d.assign();
                sel_opacities3d.assign();
              } else {
                if (feature_type==2) {
                  points3d.append(CImg<floatT>(8,3,1,1,
                                               X0,X1,X1,X0,X0,X1,X1,X0,
                                               Y0,Y0,Y1,Y1,Y0,Y0,Y1,Y1,
                                               Z0,Z0,Z0,Z0,Z1,Z1,Z1,Z1),'x');
                  sel_primitives3d.assign();
                  CImg<uintT>::vector(20,21).move_to(sel_primitives3d); CImg<uintT>::vector(21,22).move_to(sel_primitives3d);
                  CImg<uintT>::vector(22,23).move_to(sel_primitives3d); CImg<uintT>::vector(23,20).move_to(sel_primitives3d);
                  CImg<uintT>::vector(24,25).move_to(sel_primitives3d); CImg<uintT>::vector(25,26).move_to(sel_primitives3d);
                  CImg<uintT>::vector(26,27).move_to(sel_primitives3d); CImg<uintT>::vector(27,24).move_to(sel_primitives3d);
                  CImg<uintT>::vector(20,24).move_to(sel_primitives3d); CImg<uintT>::vector(21,25).move_to(sel_primitives3d);
                  CImg<uintT>::vector(22,26).move_to(sel_primitives3d); CImg<uintT>::vector(23,27).move_to(sel_primitives3d);
                } else {
                  points3d.append(CImg<floatT>(2,3,1,1,
                                               X0,X1,
                                               Y0,Y1,
                                               Z0,Z1),'x');
                  sel_primitives3d.assign(CImg<uintT>::vector(20,21));
                }
                sel_colors3d.assign(sel_primitives3d._width,CImg<ucharT>::vector(255,255,255));
                sel_opacities3d.assign(sel_primitives3d._width,1,1,1,0.8f);
              }
              points3d.shift_object3d(-0.5f*(_width-1),-0.5f*(_height-1),-0.5f*(_depth-1)).resize_object3d();
              points3d*=0.75f*cimg::min(view3d._width,view3d._height);
            }

            if (!pose3d) CImg<floatT>(4,3,1,1, 1,0,0,0, 0,1,0,0, 0,0,1,0).move_to(pose3d);
            CImg<floatT> zbuffer3d(view3d._width,view3d._height,1,1,0);
            const CImg<floatT> rotated_points3d = pose3d.get_crop(0,0,2,2)*points3d;
            if (sel_primitives3d)
              view3d.draw_object3d(pose3d(3,0) + 0.5f*view3d._width,
                                   pose3d(3,1) + 0.5f*view3d._height,
                                   pose3d(3,2),
                                   rotated_points3d,sel_primitives3d,sel_colors3d,sel_opacities3d,
                                   2,true,500,0,0,0,0,0,zbuffer3d);
            view3d.draw_object3d(pose3d(3,0) + 0.5f*view3d._width,
                                 pose3d(3,1) + 0.5f*view3d._height,
                                 pose3d(3,2),
                                 rotated_points3d,primitives3d,colors3d,opacities3d,
                                 2,true,500,0,0,0,0,0,zbuffer3d);
            visu0.draw_image(x3d,y3d,view3d);
          }
          visu = visu0;

          if (X<0 || Y<0 || Z<0) { if (!visible_cursor) { disp.show_mouse(); visible_cursor = true; }}
          else {
            if (is_axes) { if (visible_cursor) { disp.hide_mouse(); visible_cursor = false; }}
            else { if (!visible_cursor) { disp.show_mouse(); visible_cursor = true; }}
            const int d = (_depth>1)?_depth:0;
            int
              w = disp.width(), W = width() + d,
              h = disp.height(), H = height() + d,
              _xp = (int)X*w/W, xp = _xp + (_xp*W/w!=(int)X?1:0),
              _yp = (int)Y*h/H, yp = _yp + (_yp*H/h!=(int)Y?1:0),
              _xn = (int)(X+1)*w/W-1, xn = _xn + ((_xn+1)*W/w!=(int)X+1?1:0),
              _yn = (int)(Y+1)*h/H-1, yn = _yn + ((_yn+1)*H/h!=(int)Y+1?1:0),
              _zxp = ((int)Z+width())*w/W, zxp = _zxp + (_zxp*W/w!=(int)Z+width()?1:0),
              _zyp = ((int)Z+height())*h/H, zyp = _zyp + (_zyp*H/h!=(int)Z+height()?1:0),
              _zxn = ((int)Z+width()+1)*w/W-1, zxn = _zxn + ((_zxn+1)*W/w!=(int)Z+width()+1?1:0),
              _zyn = ((int)Z+height()+1)*h/H-1, zyn = _zyn + ((_zyn+1)*H/h!=(int)Z+height()+1?1:0),
              _xM = width()*w/W-1, xM = _xM + ((_xM+1)*W/w!=width()?1:0),
              _yM = height()*h/H-1, yM = _yM + ((_yM+1)*H/h!=height()?1:0),
              xc = (xp + xn)/2,
              yc = (yp + yn)/2,
              zxc = (zxp + zxn)/2,
              zyc = (zyp + zyn)/2,
              xf = (int)(X*w/W),
              yf = (int)(Y*h/H),
              zxf = (int)((Z+width())*w/W),
              zyf = (int)((Z+height())*h/H);

            if (is_axes) { // Draw axes.
              visu.draw_line(0,yf,visu.width()-1,yf,foreground_color,0.7f,0xFF00FF00).
                draw_line(0,yf,visu.width()-1,yf,background_color,0.7f,0x00FF00FF).
                draw_line(xf,0,xf,visu.height()-1,foreground_color,0.7f,0xFF00FF00).
                draw_line(xf,0,xf,visu.height()-1,background_color,0.7f,0x00FF00FF);
              if (_depth>1)
                visu.draw_line(zxf,0,zxf,yM,foreground_color,0.7f,0xFF00FF00).
                  draw_line(zxf,0,zxf,yM,background_color,0.7f,0x00FF00FF).
                  draw_line(0,zyf,xM,zyf,foreground_color,0.7f,0xFF00FF00).
                  draw_line(0,zyf,xM,zyf,background_color,0.7f,0x00FF00FF);
            }

            // Draw box cursor.
            if (xn-xp>=4 && yn-yp>=4) visu.draw_rectangle(xp,yp,xn,yn,foreground_color,0.2f).
                                        draw_rectangle(xp,yp,xn,yn,foreground_color,1,0xAAAAAAAA).
                                        draw_rectangle(xp,yp,xn,yn,background_color,1,0x55555555);
            if (_depth>1) {
              if (yn-yp>=4 && zxn-zxp>=4) visu.draw_rectangle(zxp,yp,zxn,yn,background_color,0.2f).
                                            draw_rectangle(zxp,yp,zxn,yn,foreground_color,1,0xAAAAAAAA).
                                            draw_rectangle(zxp,yp,zxn,yn,background_color,1,0x55555555);
              if (xn-xp>=4 && zyn-zyp>=4) visu.draw_rectangle(xp,zyp,xn,zyn,background_color,0.2f).
                                            draw_rectangle(xp,zyp,xn,zyn,foreground_color,1,0xAAAAAAAA).
                                            draw_rectangle(xp,zyp,xn,zyn,background_color,1,0x55555555);
            }

            // Draw selection.
            if (phase) {
              const int
                _xp0 = X0*w/W, xp0 = _xp0 + (_xp0*W/w!=X0?1:0),
                _yp0 = Y0*h/H, yp0 = _yp0 + (_yp0*H/h!=Y0?1:0),
                _xn0 = (X0+1)*w/W-1, xn0 = _xn0 + ((_xn0+1)*W/w!=X0+1?1:0),
                _yn0 = (Y0+1)*h/H-1, yn0 = _yn0 + ((_yn0+1)*H/h!=Y0+1?1:0),
                _zxp0 = (Z0+width())*w/W, zxp0 = _zxp0 + (_zxp0*W/w!=Z0+width()?1:0),
                _zyp0 = (Z0+height())*h/H, zyp0 = _zyp0 + (_zyp0*H/h!=Z0+height()?1:0),
                _zxn0 = (Z0+width()+1)*w/W-1, zxn0 = _zxn0 + ((_zxn0+1)*W/w!=Z0+width()+1?1:0),
                _zyn0 = (Z0+height()+1)*h/H-1, zyn0 = _zyn0 + ((_zyn0+1)*H/h!=Z0+height()+1?1:0),
                xc0 = (xp0 + xn0)/2,
                yc0 = (yp0 + yn0)/2,
                zxc0 = (zxp0 + zxn0)/2,
                zyc0 = (zyp0 + zyn0)/2;

              switch (feature_type) {
              case 1 : {
                visu.draw_arrow(xc0,yc0,xc,yc,background_color,0.9f,30,5,0x55555555).
                  draw_arrow(xc0,yc0,xc,yc,foreground_color,0.9f,30,5,0xAAAAAAAA);
                if (d) {
                  visu.draw_arrow(zxc0,yc0,zxc,yc,background_color,0.9f,30,5,0x55555555).
                    draw_arrow(zxc0,yc0,zxc,yc,foreground_color,0.9f,30,5,0xAAAAAAAA).
                    draw_arrow(xc0,zyc0,xc,zyc,background_color,0.9f,30,5,0x55555555).
                    draw_arrow(xc0,zyc0,xc,zyc,foreground_color,0.9f,30,5,0xAAAAAAAA);
                }
              } break;
              case 2 : {
                visu.draw_rectangle(X0<X1?xp0:xp,Y0<Y1?yp0:yp,X0<X1?xn:xn0,Y0<Y1?yn:yn0,background_color,0.2f).
                  draw_rectangle(X0<X1?xp0:xp,Y0<Y1?yp0:yp,X0<X1?xn:xn0,Y0<Y1?yn:yn0,foreground_color,0.9f,0xAAAAAAAA).
                  draw_rectangle(X0<X1?xp0:xp,Y0<Y1?yp0:yp,X0<X1?xn:xn0,Y0<Y1?yn:yn0,background_color,0.9f,0x55555555);
                if (d) {
                  visu.draw_rectangle(Z0<Z1?zxp0:zxp,Y0<Y1?yp0:yp,Z0<Z1?zxn:zxn0,Y0<Y1?yn:yn0,background_color,0.2f).
                    draw_rectangle(Z0<Z1?zxp0:zxp,Y0<Y1?yp0:yp,Z0<Z1?zxn:zxn0,Y0<Y1?yn:yn0,foreground_color,0.9f,0xAAAAAAAA).
                    draw_rectangle(Z0<Z1?zxp0:zxp,Y0<Y1?yp0:yp,Z0<Z1?zxn:zxn0,Y0<Y1?yn:yn0,background_color,0.9f,0x55555555).
                    draw_rectangle(X0<X1?xp0:xp,Z0<Z1?zyp0:zyp,X0<X1?xn:xn0,Z0<Z1?zyn:zyn0,background_color,0.2f).
                    draw_rectangle(X0<X1?xp0:xp,Z0<Z1?zyp0:zyp,X0<X1?xn:xn0,Z0<Z1?zyn:zyn0,foreground_color,0.9f,0xAAAAAAAA).
                    draw_rectangle(X0<X1?xp0:xp,Z0<Z1?zyp0:zyp,X0<X1?xn:xn0,Z0<Z1?zyn:zyn0,background_color,0.9f,0x55555555);
                }
              } break;
              case 3 : {
                visu.draw_ellipse(xc0,yc0,(float)cimg::abs(xc-xc0),(float)cimg::abs(yc-yc0),0,background_color,0.2f).
                  draw_ellipse(xc0,yc0,(float)cimg::abs(xc-xc0),(float)cimg::abs(yc-yc0),0,foreground_color,0.9f,~0U).
                  draw_point(xc0,yc0,foreground_color,0.9f);
                if (d) {
                  visu.draw_ellipse(zxc0,yc0,(float)cimg::abs(zxc-zxc0),(float)cimg::abs(yc-yc0),0,background_color,0.2f).
                    draw_ellipse(zxc0,yc0,(float)cimg::abs(zxc-zxc0),(float)cimg::abs(yc-yc0),0,foreground_color,0.9f,~0U).
                    draw_point(zxc0,yc0,foreground_color,0.9f).
                    draw_ellipse(xc0,zyc0,(float)cimg::abs(xc-xc0),(float)cimg::abs(zyc-zyc0),0,background_color,0.2f).
                    draw_ellipse(xc0,zyc0,(float)cimg::abs(xc-xc0),(float)cimg::abs(zyc-zyc0),0,foreground_color,0.9f,~0U).
                    draw_point(xc0,zyc0,foreground_color,0.9f);
                }
              } break;
              }
            }

            // Draw text info.
            if (my>=0 && my<13) text_down = true; else if (my>=visu.height()-13) text_down = false;
            if (!feature_type || !phase) {
              if (X>=0 && Y>=0 && Z>=0 && X<width() && Y<height() && Z<depth()) {
                if (_depth>1 || force_display_z_coord) cimg_snprintf(text,sizeof(text)," Point (%d,%d,%d) = [ ",origX+(int)X,origY+(int)Y,origZ+(int)Z);
                else cimg_snprintf(text,sizeof(text)," Point (%d,%d) = [ ",origX+(int)X,origY+(int)Y);
                char *ctext = text + std::strlen(text), *const ltext = text + 512;
                for (unsigned int c = 0; c<_spectrum && ctext<ltext; ++c) {
                  cimg_snprintf(ctext,sizeof(text)/2,cimg::type<T>::format(),cimg::type<T>::format((*this)((int)X,(int)Y,(int)Z,c)));
                  ctext = text + std::strlen(text);
                  *(ctext++) = ' '; *ctext = 0;
                }
                std::strcpy(text + std::strlen(text),"] ");
              }
            } else switch (feature_type) {
              case 1 : {
                const double dX = (double)(X0 - X1), dY = (double)(Y0 - Y1), dZ = (double)(Z0 - Z1), norm = std::sqrt(dX*dX+dY*dY+dZ*dZ);
                if (_depth>1 || force_display_z_coord) cimg_snprintf(text,sizeof(text)," Vect (%d,%d,%d)-(%d,%d,%d), Norm = %g ",
                                                                     origX+X0,origY+Y0,origZ+Z0,origX+X1,origY+Y1,origZ+Z1,norm);
                else cimg_snprintf(text,sizeof(text)," Vect (%d,%d)-(%d,%d), Norm = %g ",
                                   origX+X0,origY+Y0,origX+X1,origY+Y1,norm);
              } break;
              case 2 :
                if (_depth>1 || force_display_z_coord) cimg_snprintf(text,sizeof(text)," Box (%d,%d,%d)-(%d,%d,%d), Size = (%d,%d,%d) ",
                                                                     origX+(X0<X1?X0:X1),origY+(Y0<Y1?Y0:Y1),origZ+(Z0<Z1?Z0:Z1),
                                                                     origX+(X0<X1?X1:X0),origY+(Y0<Y1?Y1:Y0),origZ+(Z0<Z1?Z1:Z0),
                                                                     1+cimg::abs(X0-X1),1+cimg::abs(Y0-Y1),1+cimg::abs(Z0-Z1));
                else cimg_snprintf(text,sizeof(text)," Box (%d,%d)-(%d,%d), Size = (%d,%d) ",
                                   origX+(X0<X1?X0:X1),origY+(Y0<Y1?Y0:Y1),origX+(X0<X1?X1:X0),origY+(Y0<Y1?Y1:Y0),
                                   1+cimg::abs(X0-X1),1+cimg::abs(Y0-Y1));
                break;
              default :
                if (_depth>1 || force_display_z_coord) cimg_snprintf(text,sizeof(text)," Ellipse (%d,%d,%d)-(%d,%d,%d), Radii = (%d,%d,%d) ",
                                                                     origX+X0,origY+Y0,origZ+Z0,origX+X1,origY+Y1,origZ+Z1,
                                                                     1+cimg::abs(X0-X1),1+cimg::abs(Y0-Y1),1+cimg::abs(Z0-Z1));
                else cimg_snprintf(text,sizeof(text)," Ellipse (%d,%d)-(%d,%d), Radii = (%d,%d) ",
                                   origX+X0,origY+Y0,origX+X1,origY+Y1,1+cimg::abs(X0-X1),1+cimg::abs(Y0-Y1));
              }
            if (phase || (mx>=0 && my>=0)) visu.draw_text(0,text_down?visu.height()-13:0,text,foreground_color,background_color,0.7f,13);
          }

          disp.display(visu).wait();
        } else if (!shape_selected) disp.wait();
        if (disp.is_resized()) { disp.resize(false)._is_resized = false; old_is_resized = true; visu0.assign(); }
        omx = mx; omy = my;
      }

      // Return result.
      CImg<intT> res(1,feature_type==0?3:6,1,1,-1);
      if (XYZ) { XYZ[0] = (unsigned int)X0; XYZ[1] = (unsigned int)Y0; XYZ[2] = (unsigned int)Z0; }
      if (shape_selected) {
        if (feature_type==2) {
          if (X0>X1) cimg::swap(X0,X1);
          if (Y0>Y1) cimg::swap(Y0,Y1);
          if (Z0>Z1) cimg::swap(Z0,Z1);
        }
	if (X1<0 || Y1<0 || Z1<0) X0 = Y0 = Z0 = X1 = Y1 = Z1 = -1;
	switch (feature_type) {
	case 1 : case 2 : res[0] = X0; res[1] = Y0; res[2] = Z0; res[3] = X1; res[4] = Y1; res[5] = Z1; break;
        case 3 : res[3] = cimg::abs(X1-X0); res[4] = cimg::abs(Y1-Y0); res[5] = cimg::abs(Z1-Z0);  // keep no break here!
	default : res[0] = X0; res[1] = Y0; res[2] = Z0;
	}
      }
      disp.set_button();
      if (!visible_cursor) disp.show_mouse();
      disp._normalization = old_normalization;
      disp._is_resized = old_is_resized;
      if (key!=~0U) disp.set_key(key);
      return res;
    }

    // Return a visualizable uchar8 image for display routines.
    CImg<ucharT> __get_select(const CImgDisplay& disp, const int normalization, const int x, const int y, const int z) const {
      if (is_empty()) return CImg<ucharT>(1,1,1,1,0);
      const CImg<T> crop = get_shared_channels(0,cimg::min(2,spectrum()-1));
      CImg<Tuchar> img2d;
      if (_depth>1) crop.get_projections2d(x,y,z).move_to(img2d);
      else CImg<Tuchar>(crop,false).move_to(img2d);

      if (cimg::type<T>::is_float()) { // Check for inf and nan values.
        bool is_inf = false, is_nan = false;
        cimg_for(img2d,ptr,Tuchar)
          if (cimg::type<T>::is_inf(*ptr)) { is_inf = true; break; }
          else if (cimg::type<T>::is_nan(*ptr)) { is_nan = true; break; }
        if (is_inf || is_nan) {
          T m0 = cimg::type<T>::max(), M0 = cimg::type<T>::min();
          if (!normalization) { m0 = 0; M0 = 255; }
          else if (normalization==2) { m0 = disp._min; M0 = disp._max; }
          else cimg_for(img2d,ptr,Tuchar) if (!cimg::type<T>::is_inf(*ptr) && !cimg::type<T>::is_nan(*ptr)) { if (*ptr<m0) m0 = *ptr; if (*ptr>M0) M0 = *ptr; }
          const T
            val_minf = (normalization==1 || normalization==3)?m0-(M0-m0)*20-1:m0,
            val_pinf = (normalization==1 || normalization==3)?M0+(M0-m0)*20+1:M0;
          if (is_nan) cimg_for(img2d,ptr,Tuchar) if (cimg::type<T>::is_nan(*ptr)) *ptr = val_minf; // Replace nan values.
          if (is_inf) cimg_for(img2d,ptr,Tuchar) if (cimg::type<T>::is_inf(*ptr)) *ptr = (float)*ptr<0?val_minf:val_pinf; // Replace +-inf values.
        }
      }

      switch (normalization) {
      case 1 : img2d.normalize(0,255); break;
      case 2 : {
        const float m = disp._min, M = disp._max;
        (img2d-=m)*=255.0f/(M-m>0?M-m:1);
      } break;
      case 3 :
        if (cimg::type<T>::is_float()) img2d.normalize(0,255);
        else {
          const float m = (float)cimg::type<T>::min(), M = (float)cimg::type<T>::max();
          (img2d-=m)*=255.0f/(M-m>0?M-m:1);
        } break;
      }

      if (img2d.spectrum()==2) img2d.channels(0,2);
      return img2d;
    }

    //! Select sub-graph in a graph.
    CImg<intT> get_select_graph(CImgDisplay &disp,
                                const unsigned int plot_type=1, const unsigned int vertex_type=1,
                                const char *const labelx=0, const double xmin=0, const double xmax=0,
                                const char *const labely=0, const double ymin=0, const double ymax=0) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "select_graph(): Empty instance.",
                                    cimg_instance);
      if (!disp) disp.assign(cimg_fitscreen(640,480,1),0,0).set_title("CImg<%s>",pixel_type());
      const unsigned long siz = (unsigned long)_width*_height*_depth;
      const unsigned int old_normalization = disp.normalization();
      disp.show().set_button().set_wheel()._normalization = 0;

      double nymin = ymin, nymax = ymax, nxmin = xmin, nxmax = xmax;
      if (nymin==nymax) { nymin = (Tfloat)min_max(nymax); const double dy = nymax - nymin; nymin-=dy/20; nymax+=dy/20; }
      if (nymin==nymax) { --nymin; ++nymax; }
      if (nxmin==nxmax && nxmin==0) { nxmin = 0; nxmax = siz - 1.0; }

      const unsigned char black[] = { 0, 0, 0 }, white[] = { 255, 255, 255 }, gray[] = { 220, 220, 220 };
      const unsigned char gray2[] = { 110, 110, 110 }, ngray[] = { 35, 35, 35 };
      static unsigned int odimv = 0;
      static CImg<ucharT> colormap;
      if (odimv!=_spectrum) {
        odimv = _spectrum;
        colormap = CImg<ucharT>(3,_spectrum,1,1,120).noise(70,1);
        if (_spectrum==1) { colormap[0] = colormap[1] = 120; colormap[2] = 200; }
        else {
          colormap(0,0) = 220; colormap(1,0) = 10; colormap(2,0) = 10;
          if (_spectrum>1) { colormap(0,1) = 10; colormap(1,1) = 220; colormap(2,1) = 10; }
          if (_spectrum>2) { colormap(0,2) = 10; colormap(1,2) = 10; colormap(2,2) = 220; }
        }
      }

      CImg<ucharT> visu0, visu, graph, text, axes;
      int x0 = -1, x1 = -1, y0 = -1, y1 = -1, omouse_x = -2, omouse_y = -2;
      const unsigned int one = plot_type==3?0:1;
      unsigned int okey = 0, obutton = 0;
      char message[1024] = { 0 };
      CImg_3x3(I,unsigned char);

      for (bool selected = false; !selected && !disp.is_closed() && !okey && !disp.wheel(); ) {
        const int mouse_x = disp.mouse_x(), mouse_y = disp.mouse_y();
        const unsigned int key = disp.key(), button = disp.button();

        // Generate graph representation.
        if (!visu0) {
          visu0.assign(disp.width(),disp.height(),1,3,220);
          const int gdimx = disp.width() - 32, gdimy = disp.height() - 32;
          if (gdimx>0 && gdimy>0) {
            graph.assign(gdimx,gdimy,1,3,255);
            if (siz<32) { if (siz>1) graph.draw_grid(gdimx/(float)(siz - one),gdimy/(float)(siz - one),0,0,false,true,black,0.2f,0x33333333,0x33333333); }
            else graph.draw_grid(-10,-10,0,0,false,true,black,0.2f,0x33333333,0x33333333);
            cimg_forC(*this,c) graph.draw_graph(get_shared_channel(c),&colormap(0,c),(plot_type!=3 || _spectrum==1)?1:0.6f,
                                                plot_type,vertex_type,nymax,nymin);

            axes.assign(gdimx,gdimy,1,1,0);
            const float
              dx = (float)cimg::abs(nxmax-nxmin), dy = (float)cimg::abs(nymax-nymin),
              px = (float)std::pow(10.0,(int)std::log10(dx?dx:1)-2.0),
              py = (float)std::pow(10.0,(int)std::log10(dy?dy:1)-2.0);
            const CImg<Tdouble>
              seqx = dx<=0?CImg<Tdouble>::vector(nxmin):CImg<Tdouble>::sequence(1 + gdimx/60,nxmin,one?nxmax:nxmin+(nxmax-nxmin)*(siz+1)/siz).round(px),
              seqy = CImg<Tdouble>::sequence(1 + gdimy/60,nymax,nymin).round(py);

            const bool allow_zero = (nxmin*nxmax>0) || (nymin*nymax>0);
            axes.draw_axes(seqx,seqy,white,1,~0U,~0U,13,allow_zero);
            if (nymin>0) axes.draw_axis(seqx,gdimy-1,gray,1,~0U,13,allow_zero);
            if (nymax<0) axes.draw_axis(seqx,0,gray,1,~0U,13,allow_zero);
	    if (nxmin>0) axes.draw_axis(0,seqy,gray,1,~0U,13,allow_zero);
	    if (nxmax<0) axes.draw_axis(gdimx-1,seqy,gray,1,~0U,13,allow_zero);

            cimg_for3x3(axes,x,y,0,0,I,unsigned char)
              if (Icc) {
                if (Icc==255) cimg_forC(graph,c) graph(x,y,c) = 0;
                else cimg_forC(graph,c) graph(x,y,c) = (unsigned char)(2*graph(x,y,c)/3);
              }
              else if (Ipc || Inc || Icp || Icn || Ipp || Inn || Ipn || Inp) cimg_forC(graph,c) graph(x,y,c) = (graph(x,y,c)+511)/3;

            visu0.draw_image(16,16,graph);
	    visu0.draw_line(15,15,16+gdimx,15,gray2).draw_line(16+gdimx,15,16+gdimx,16+gdimy,gray2).
	      draw_line(16+gdimx,16+gdimy,15,16+gdimy,white).draw_line(15,16+gdimy,15,15,white);
          } else graph.assign();
          text.assign().draw_text(0,0,labelx?labelx:"X-axis",white,ngray,1,13).resize(-100,-100,1,3);
          visu0.draw_image((visu0.width()-text.width())/2,visu0.height()-14,~text);
          text.assign().draw_text(0,0,labely?labely:"Y-axis",white,ngray,1,13).rotate(-90).resize(-100,-100,1,3);
          visu0.draw_image(1,(visu0.height()-text.height())/2,~text);
          visu.assign();
        }

        // Generate and display current view.
        if (!visu) {
          visu.assign(visu0);
          if (graph && x0>=0 && x1>=0) {
            const int
              nx0 = x0<=x1?x0:x1,
              nx1 = x0<=x1?x1:x0,
              ny0 = y0<=y1?y0:y1,
              ny1 = y0<=y1?y1:y0,
              sx0 = 16 + nx0*(visu.width()-32)/cimg::max(1U,siz-one),
              sx1 = 15 + (nx1+1)*(visu.width()-32)/cimg::max(1U,siz-one),
              sy0 = 16 + ny0,
              sy1 = 16 + ny1;
            if (y0>=0 && y1>=0)
              visu.draw_rectangle(sx0,sy0,sx1,sy1,gray,0.5f).draw_rectangle(sx0,sy0,sx1,sy1,black,0.5f,0xCCCCCCCCU);
            else visu.draw_rectangle(sx0,0,sx1,visu.height()-17,gray,0.5f).
                   draw_line(sx0,16,sx0,visu.height()-17,black,0.5f,0xCCCCCCCCU).
                   draw_line(sx1,16,sx1,visu.height()-17,black,0.5f,0xCCCCCCCCU);
          }
          if (mouse_x>=16 && mouse_y>=16 && mouse_x<visu.width()-16 && mouse_y<visu.height()-16) {
            if (graph) visu.draw_line(mouse_x,16,mouse_x,visu.height()-17,black,0.5f,0x55555555U);
            const unsigned int x = (unsigned int)cimg::round((mouse_x-16.0f)*(siz-one)/(disp.width()-32),1,one?0:-1);
            const double cx = nxmin + x*(nxmax-nxmin)/cimg::max(1U,siz-1);
            if (_spectrum>=7)
              cimg_snprintf(message,sizeof(message),"Value[%u:%g] = ( %g %g %g ... %g %g %g )",x,cx,
                            (double)(*this)(x,0,0,0),(double)(*this)(x,0,0,1),(double)(*this)(x,0,0,2),
                            (double)(*this)(x,0,0,_spectrum-4),(double)(*this)(x,0,0,_spectrum-3),(double)(*this)(x,0,0,_spectrum-1));
            else {
              cimg_snprintf(message,sizeof(message),"Value[%u:%g] = ( ",x,cx);
              cimg_forC(*this,c) std::sprintf(message + std::strlen(message),"%g ",(double)(*this)(x,0,0,c));
              std::sprintf(message + std::strlen(message),")");
            }
	    if (x0>=0 && x1>=0) {
	      const unsigned int
                nx0 = x0<=x1?x0:x1,
                nx1 = x0<=x1?x1:x0,
                ny0 = y0<=y1?y0:y1,
                ny1 = y0<=y1?y1:y0;
	      const double
                cx0 = nxmin + nx0*(nxmax-nxmin)/cimg::max(1U,siz-1),
                cx1 = nxmin + (nx1+one)*(nxmax-nxmin)/cimg::max(1U,siz-1),
                cy0 = nymax - ny0*(nymax-nymin)/(visu._height-32),
                cy1 = nymax - ny1*(nymax-nymin)/(visu._height-32);
	      if (y0>=0 && y1>=0)
	        std::sprintf(message + std::strlen(message)," - Range ( %u:%g, %g ) - ( %u:%g, %g )",x0,cx0,cy0,x1+one,cx1,cy1);
	      else
	        std::sprintf(message + std::strlen(message)," - Range [ %u:%g - %u:%g ]",x0,cx0,x1+one,cx1);
	    }
            text.assign().draw_text(0,0,message,white,ngray,1,13).resize(-100,-100,1,3);
            visu.draw_image((visu.width()-text.width())/2,1,~text);
          }
          visu.display(disp);
        }

        // Test keys.
        switch (okey = key) {
#if cimg_OS!=2
        case cimg::keyCTRLRIGHT : case cimg::keySHIFTRIGHT :
#endif
# 35468 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        case cimg::keyCTRLLEFT : case cimg::keySHIFTLEFT : okey = 0; break;
        case cimg::keyD : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
          disp.set_fullscreen(false).resize(CImgDisplay::_fitscreen(3*disp.width()/2,3*disp.height()/2,1,128,-100,false),
                                            CImgDisplay::_fitscreen(3*disp.width()/2,3*disp.height()/2,1,128,-100,true),false).
            _is_resized = true;
          disp.set_key(key,false); okey = 0;
        } break;
        case cimg::keyC : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
          disp.set_fullscreen(false).resize(cimg_fitscreen(2*disp.width()/3,2*disp.height()/3,1),false)._is_resized = true;
          disp.set_key(key,false); okey = 0;
        } break;
        case cimg::keyR : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
          disp.set_fullscreen(false).resize(cimg_fitscreen(640,480,1),false)._is_resized = true;
          disp.set_key(key,false); okey = 0;
        } break;
        case cimg::keyF : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
          disp.resize(disp.screen_width(),disp.screen_height(),false).toggle_fullscreen()._is_resized = true;
          disp.set_key(key,false); okey = 0;
        } break;
        case cimg::keyS : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
          static unsigned int snap_number = 0;
          if (visu || visu0) {
            CImg<ucharT> &screen = visu?visu:visu0;
            char filename[32] = { 0 };
            std::FILE *file;
            do {
              cimg_snprintf(filename,sizeof(filename),cimg_appname "_%.4u.bmp",snap_number++);
              if ((file=std::fopen(filename,"r"))!=0) cimg::fclose(file);
            } while (file);
            (+screen).draw_text(0,0," Saving snapshot... ",black,gray,1,13).display(disp);
            screen.save(filename);
            screen.draw_text(0,0," Snapshot '%s' saved. ",black,gray,1,13,filename).display(disp);
          }
          disp.set_key(key,false); okey = 0;
        } break;
        case cimg::keyO : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
            static unsigned int snap_number = 0;
            if (visu || visu0) {
              CImg<ucharT> &screen = visu?visu:visu0;
              char filename[32] = { 0 };
              std::FILE *file;
              do {
#ifdef cimg_use_zlib
                cimg_snprintf(filename,sizeof(filename),cimg_appname "_%.4u.cimgz",snap_number++);
#else
# 35513 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                cimg_snprintf(filename,sizeof(filename),cimg_appname "_%.4u.cimg",snap_number++);
#endif
# 35515 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                if ((file=std::fopen(filename,"r"))!=0) cimg::fclose(file);
              } while (file);
              (+screen).draw_text(0,0," Saving instance... ",black,gray,1,13).display(disp);
              save(filename);
              screen.draw_text(0,0," Instance '%s' saved. ",black,gray,1,13,filename).display(disp);
            }
            disp.set_key(key,false); okey = 0;
          } break;
        }

        // Handle mouse motion and mouse buttons
        if (obutton!=button || omouse_x!=mouse_x || omouse_y!=mouse_y) {
          visu.assign();
          if (disp.mouse_x()>=0 && disp.mouse_y()>=0) {
            const int
              mx = (mouse_x -16)*(int)(siz-one)/(disp.width()-32),
              cx = mx<0?0:(mx>=(int)(siz-one)?(int)(siz-1-one):mx),
              my = mouse_y - 16,
              cy = my<=0?0:(my>=(disp.height()-32)?(disp.height()-32):my);
	    if (button&1) {
              if (!obutton) { x0 = cx; y0 = -1; } else { x1 = cx; y1 = -1; }
            }
	    else if (button&2) {
              if (!obutton) { x0 = cx; y0 = cy; } else { x1 = cx; y1 = cy; }
            }
            else if (obutton) { x1 = x1>=0?cx:-1; y1 = y1>=0?cy:-1; selected = true; }
          } else if (!button && obutton) selected = true;
          obutton = button; omouse_x = mouse_x; omouse_y = mouse_y;
        }
        if (disp.is_resized()) { disp.resize(false); visu0.assign(); }
        if (visu && visu0) disp.wait();
      }

      disp._normalization = old_normalization;
      if (x1>=0 && x1<x0) cimg::swap(x0,x1);
      if (y1<y0) cimg::swap(y0,y1);
      disp.set_key(okey);
      return CImg<intT>(4,1,1,1,x0,y0,x1>=0?x1+(int)one:-1,y1);
    }

    //! Load image from a file.
    /**
       \param filename Filename, as a C-string.
       \note The extension of \c filename defines the file format. If no filename
       extension is provided, CImg<T>::get_load() will try to load the file as a .cimg or .cimgz file.
    **/
    CImg<T>& load(const char *const filename) {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "load(): Specified filename is (null).",
                                    cimg_instance);

      if (!cimg::strncasecmp(filename,"http://",7) || !cimg::strncasecmp(filename,"https://",8)) {
        char filename_local[1024] = { 0 };
        load(cimg::load_network_external(filename,filename_local));
        std::remove(filename_local);
        return *this;
      }

      const char *const ext = cimg::split_filename(filename);
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      try {
#ifdef cimg_load_plugin
        cimg_load_plugin(filename);
#endif
# 35581 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_load_plugin1
        cimg_load_plugin1(filename);
#endif
# 35584 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_load_plugin2
        cimg_load_plugin2(filename);
#endif
# 35587 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_load_plugin3
        cimg_load_plugin3(filename);
#endif
# 35590 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_load_plugin4
        cimg_load_plugin4(filename);
#endif
# 35593 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_load_plugin5
        cimg_load_plugin5(filename);
#endif
# 35596 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_load_plugin6
        cimg_load_plugin6(filename);
#endif
# 35599 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_load_plugin7
        cimg_load_plugin7(filename);
#endif
# 35602 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_load_plugin8
        cimg_load_plugin8(filename);
#endif
# 35605 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        // Ascii formats
        if (!cimg::strcasecmp(ext,"asc")) load_ascii(filename);
        else if (!cimg::strcasecmp(ext,"dlm") ||
                 !cimg::strcasecmp(ext,"txt")) load_dlm(filename);

        // 2d binary formats
        else if (!cimg::strcasecmp(ext,"bmp")) load_bmp(filename);
        else if (!cimg::strcasecmp(ext,"jpg") ||
                 !cimg::strcasecmp(ext,"jpeg") ||
                 !cimg::strcasecmp(ext,"jpe") ||
                 !cimg::strcasecmp(ext,"jfif") ||
                 !cimg::strcasecmp(ext,"jif")) load_jpeg(filename);
        else if (!cimg::strcasecmp(ext,"png")) load_png(filename);
        else if (!cimg::strcasecmp(ext,"ppm") ||
                 !cimg::strcasecmp(ext,"pgm") ||
                 !cimg::strcasecmp(ext,"pnm") ||
                 !cimg::strcasecmp(ext,"pbm") ||
                 !cimg::strcasecmp(ext,"pnk")) load_pnm(filename);
        else if (!cimg::strcasecmp(ext,"pfm")) load_pfm(filename);
        else if (!cimg::strcasecmp(ext,"tif") ||
                 !cimg::strcasecmp(ext,"tiff")) load_tiff(filename);
        else if (!cimg::strcasecmp(ext,"exr")) load_exr(filename);
        else if (!cimg::strcasecmp(ext,"cr2") ||
                 !cimg::strcasecmp(ext,"crw") ||
                 !cimg::strcasecmp(ext,"dcr") ||
                 !cimg::strcasecmp(ext,"mrw") ||
                 !cimg::strcasecmp(ext,"nef") ||
                 !cimg::strcasecmp(ext,"orf") ||
                 !cimg::strcasecmp(ext,"pix") ||
                 !cimg::strcasecmp(ext,"ptx") ||
                 !cimg::strcasecmp(ext,"raf") ||
                 !cimg::strcasecmp(ext,"srf")) load_dcraw_external(filename);
        else if (!cimg::strcasecmp(ext,"gif")) load_gif_external(filename);

        // 3d binary formats
        else if (!cimg::strcasecmp(ext,"dcm") ||
                 !cimg::strcasecmp(ext,"dicom")) load_medcon_external(filename);
        else if (!cimg::strcasecmp(ext,"hdr") ||
                 !cimg::strcasecmp(ext,"nii")) load_analyze(filename);
        else if (!cimg::strcasecmp(ext,"par") ||
                 !cimg::strcasecmp(ext,"rec")) load_parrec(filename);
        else if (!cimg::strcasecmp(ext,"mnc")) load_minc2(filename);
        else if (!cimg::strcasecmp(ext,"inr")) load_inr(filename);
        else if (!cimg::strcasecmp(ext,"pan")) load_pandore(filename);
        else if (!cimg::strcasecmp(ext,"cimg") ||
                 !cimg::strcasecmp(ext,"cimgz") ||
                 !*ext)  return load_cimg(filename);

        // Archive files
        else if (!cimg::strcasecmp(ext,"gz")) load_gzip_external(filename);

        // Image sequences
        else if (!cimg::strcasecmp(ext,"avi") ||
                 !cimg::strcasecmp(ext,"mov") ||
                 !cimg::strcasecmp(ext,"asf") ||
                 !cimg::strcasecmp(ext,"divx") ||
                 !cimg::strcasecmp(ext,"flv") ||
                 !cimg::strcasecmp(ext,"mpg") ||
                 !cimg::strcasecmp(ext,"m1v") ||
                 !cimg::strcasecmp(ext,"m2v") ||
                 !cimg::strcasecmp(ext,"m4v") ||
                 !cimg::strcasecmp(ext,"mjp") ||
                 !cimg::strcasecmp(ext,"mkv") ||
                 !cimg::strcasecmp(ext,"mpe") ||
                 !cimg::strcasecmp(ext,"movie") ||
                 !cimg::strcasecmp(ext,"ogm") ||
                 !cimg::strcasecmp(ext,"ogg") ||
                 !cimg::strcasecmp(ext,"qt") ||
                 !cimg::strcasecmp(ext,"rm") ||
                 !cimg::strcasecmp(ext,"vob") ||
                 !cimg::strcasecmp(ext,"wmv") ||
                 !cimg::strcasecmp(ext,"xvid") ||
                 !cimg::strcasecmp(ext,"mpeg")) load_ffmpeg(filename);
        else throw CImgIOException("CImg<%s>::load()",
                                   pixel_type());
      } catch (CImgIOException&) {
        std::FILE *file = 0;
        try {
          file = cimg::fopen(filename,"rb");
        } catch (CImgIOException&) {
          cimg::exception_mode() = omode;
          throw CImgIOException(_cimg_instance
                                "load(): Failed to open file '%s'.",
                                cimg_instance,
                                filename);
        }

        try {
          const char *const f_type = cimg::file_type(file,filename);
          std::fclose(file);
          if (!cimg::strcasecmp(f_type,"pnm")) load_pnm(filename);
          else if (!cimg::strcasecmp(f_type,"pfm")) load_pfm(filename);
          else if (!cimg::strcasecmp(f_type,"bmp")) load_bmp(filename);
          else if (!cimg::strcasecmp(f_type,"jpg")) load_jpeg(filename);
          else if (!cimg::strcasecmp(f_type,"pan")) load_pandore(filename);
          else if (!cimg::strcasecmp(f_type,"png")) load_png(filename);
          else if (!cimg::strcasecmp(f_type,"tif")) load_tiff(filename);
          else if (!cimg::strcasecmp(f_type,"inr")) load_inr(filename);
          else if (!cimg::strcasecmp(f_type,"dcm")) load_medcon_external(filename);
          else throw CImgIOException("CImg<%s>::load()",
                                     pixel_type());
        } catch (CImgIOException&) {
          try {
            load_other(filename);
          } catch (CImgIOException&) {
            cimg::exception_mode() = omode;
            throw CImgIOException(_cimg_instance
                                  "load(): Failed to recognize format of file '%s'.",
                                  cimg_instance,
                                  filename);
          }
        }
      }
      cimg::exception_mode() = omode;
      return *this;
    }

    //! Load image from a file \newinstance.
    static CImg<T> get_load(const char *const filename) {
      return CImg<T>().load(filename);
    }

    //! Load image from an ascii file.
    /**
       \param filename Filename, as a C -string.
    **/
    CImg<T>& load_ascii(const char *const filename) {
      return _load_ascii(0,filename);
    }

    //! Load image from an ascii file \inplace.
    static CImg<T> get_load_ascii(const char *const filename) {
      return CImg<T>().load_ascii(filename);
    }

    //! Load image from an ascii file \overloading.
    CImg<T>& load_ascii(std::FILE *const file) {
      return _load_ascii(file,0);
    }

    //! Loadimage from an ascii file \newinstance.
    static CImg<T> get_load_ascii(std::FILE *const file) {
      return CImg<T>().load_ascii(file);
    }

    CImg<T>& _load_ascii(std::FILE *const file, const char *const filename) {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_ascii(): Specified filename is (null).",
                                    cimg_instance);

      std::FILE *const nfile = file?file:cimg::fopen(filename,"rb");
      char line[256] = { 0 };
      int err = std::fscanf(nfile,"%255[^\n]",line);
      unsigned int dx = 0, dy = 1, dz = 1, dc = 1;
      std::sscanf(line,"%u%*c%u%*c%u%*c%u",&dx,&dy,&dz,&dc);
      err = std::fscanf(nfile,"%*[^0-9.eE+-]");
      if (!dx || !dy || !dz || !dc) {
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimg_instance
                              "load_ascii(): Invalid ascii header in file '%s', image dimensions are set to (%u,%u,%u,%u).",
                              cimg_instance,
                              filename?filename:"(FILE*)",dx,dy,dz,dc);
      }
      assign(dx,dy,dz,dc);
      const unsigned long siz = size();
      unsigned long off = 0;
      double val;
      T *ptr = _data;
      for (err = 1, off = 0; off<siz && err==1; ++off) {
        err = std::fscanf(nfile,"%lf%*[^0-9.eE+-]",&val);
        *(ptr++) = (T)val;
      }
      if (err!=1)
        cimg::warn(_cimg_instance
                   "load_ascii(): Only %lu/%lu values read from file '%s'.",
                   cimg_instance,
                   off-1,siz,filename?filename:"(FILE*)");

      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Load image from a DLM file.
    /**
      \param filename Filename, as a C-string.
    **/
    CImg<T>& load_dlm(const char *const filename) {
      return _load_dlm(0,filename);
    }

    //! Load image from a DLM file \newinstance.
    static CImg<T> get_load_dlm(const char *const filename) {
      return CImg<T>().load_dlm(filename);
    }

    //! Load image from a DLM file \overloading.
    CImg<T>& load_dlm(std::FILE *const file) {
      return _load_dlm(file,0);
    }

    //! Load image from a DLM file \newinstance.
    static CImg<T> get_load_dlm(std::FILE *const file) {
      return CImg<T>().load_dlm(file);
    }

    CImg<T>& _load_dlm(std::FILE *const file, const char *const filename) {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_dlm(): Specified filename is (null).",
                                    cimg_instance);

      std::FILE *const nfile = file?file:cimg::fopen(filename,"r");
      char delimiter[256] = { 0 }, tmp[256] = { 0 };
      unsigned int cdx = 0, dx = 0, dy = 0;
      int err = 0;
      double val;
      assign(256,256);
      while ((err = std::fscanf(nfile,"%lf%255[^0-9.+-]",&val,delimiter))>0) {
        if (err>0) (*this)(cdx++,dy) = (T)val;
        if (cdx>=_width) resize(3*_width/2,_height,1,1,0);
        char c = 0;
        if (!std::sscanf(delimiter,"%255[^\n]%c",tmp,&c) || c=='\n') {
          dx = cimg::max(cdx,dx);
          if (++dy>=_height) resize(_width,3*_height/2,1,1,0);
          cdx = 0;
        }
      }
      if (cdx && err==1) { dx = cdx; ++dy; }
      if (!dx || !dy) {
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimg_instance
                              "load_dlm(): Invalid DLM file '%s'.",
                              cimg_instance,
                              filename?filename:"(FILE*)");
      }
      resize(dx,dy,1,1,0);
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Load image from a BMP file.
    /**
       \param filename Filename, as a C-string.
    **/
    CImg<T>& load_bmp(const char *const filename) {
      return _load_bmp(0,filename);
    }

    //! Load image from a BMP file \newinstance.
    static CImg<T> get_load_bmp(const char *const filename) {
      return CImg<T>().load_bmp(filename);
    }

    //! Load image from a BMP file \overloading.
    CImg<T>& load_bmp(std::FILE *const file) {
      return _load_bmp(file,0);
    }

    //! Load image from a BMP file \newinstance.
    static CImg<T> get_load_bmp(std::FILE *const file) {
      return CImg<T>().load_bmp(file);
    }

    CImg<T>& _load_bmp(std::FILE *const file, const char *const filename) {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_bmp(): Specified filename is (null).",
                                    cimg_instance);

      std::FILE *const nfile = file?file:cimg::fopen(filename,"rb");
      unsigned char header[64] = { 0 };
      cimg::fread(header,54,nfile);
      if (*header!='B' || header[1]!='M') {
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimg_instance
                              "load_bmp(): Invalid BMP file '%s'.",
                              cimg_instance,
                              filename?filename:"(FILE*)");
      }

      // Read header and pixel buffer
      int
        file_size = header[0x02] + (header[0x03]<<8) + (header[0x04]<<16) + (header[0x05]<<24),
        offset = header[0x0A] + (header[0x0B]<<8) + (header[0x0C]<<16) + (header[0x0D]<<24),
        header_size = header[0x0E] + (header[0x0F]<<8) + (header[0x10]<<16) + (header[0x11]<<24),
        dx = header[0x12] + (header[0x13]<<8) + (header[0x14]<<16) + (header[0x15]<<24),
        dy = header[0x16] + (header[0x17]<<8) + (header[0x18]<<16) + (header[0x19]<<24),
        compression = header[0x1E] + (header[0x1F]<<8) + (header[0x20]<<16) + (header[0x21]<<24),
        nb_colors = header[0x2E] + (header[0x2F]<<8) + (header[0x30]<<16) + (header[0x31]<<24),
        bpp = header[0x1C] + (header[0x1D]<<8);

      if (!file_size || file_size==offset) {
        std::fseek(nfile,0,SEEK_END);
        file_size = (int)std::ftell(nfile);
        std::fseek(nfile,54,SEEK_SET);
      }
      if (header_size>40) std::fseek(nfile, header_size - 40, SEEK_CUR);

      const int
        cimg_iobuffer = 12*1024*1024,
        dx_bytes = (bpp==1)?(dx/8+(dx%8?1:0)):((bpp==4)?(dx/2+(dx%2?1:0)):(dx*bpp/8)),
        align_bytes = (4-dx_bytes%4)%4,
        buf_size = cimg::min(cimg::abs(dy)*(dx_bytes + align_bytes),file_size - offset);

      CImg<intT> colormap;
      if (bpp<16) { if (!nb_colors) nb_colors = 1<<bpp; } else nb_colors = 0;
      if (nb_colors) { colormap.assign(nb_colors); cimg::fread(colormap._data,nb_colors,nfile); }
      const int xoffset = offset - 14 - header_size - 4*nb_colors;
      if (xoffset>0) std::fseek(nfile,xoffset,SEEK_CUR);

      CImg<ucharT> buffer;
      if (buf_size<cimg_iobuffer) { buffer.assign(buf_size); cimg::fread(buffer._data,buf_size,nfile); }
      else buffer.assign(dx_bytes + align_bytes);
      unsigned char *ptrs = buffer;

      // Decompress buffer (if necessary)
      if (compression) {
        if (file)
          throw CImgIOException(_cimg_instance
                                "load_bmp(): Unable to load compressed data from '(*FILE)' inputs.",
                                cimg_instance);
        else {
          if (!file) cimg::fclose(nfile);
          return load_other(filename);
        }
      }

      // Read pixel data
      assign(dx,cimg::abs(dy),1,3);
      switch (bpp) {
      case 1 : { // Monochrome
        for (int y = height()-1; y>=0; --y) {
          if (buf_size>=cimg_iobuffer) { cimg::fread(ptrs=buffer._data,dx_bytes,nfile); std::fseek(nfile,align_bytes,SEEK_CUR); }
          unsigned char mask = 0x80, val = 0;
          cimg_forX(*this,x) {
            if (mask==0x80) val = *(ptrs++);
            const unsigned char *col = (unsigned char*)(colormap._data + (val&mask?1:0));
            (*this)(x,y,2) = (T)*(col++);
            (*this)(x,y,1) = (T)*(col++);
            (*this)(x,y,0) = (T)*(col++);
            mask = cimg::ror(mask);
          }
          ptrs+=align_bytes;
        }
      } break;
      case 4 : { // 16 colors
        for (int y = height()-1; y>=0; --y) {
          if (buf_size>=cimg_iobuffer) { cimg::fread(ptrs=buffer._data,dx_bytes,nfile); std::fseek(nfile,align_bytes,SEEK_CUR); }
          unsigned char mask = 0xF0, val = 0;
          cimg_forX(*this,x) {
            if (mask==0xF0) val = *(ptrs++);
            const unsigned char color = (unsigned char)((mask<16)?(val&mask):((val&mask)>>4));
            const unsigned char *col = (unsigned char*)(colormap._data + color);
            (*this)(x,y,2) = (T)*(col++);
            (*this)(x,y,1) = (T)*(col++);
            (*this)(x,y,0) = (T)*(col++);
            mask = cimg::ror(mask,4);
          }
          ptrs+=align_bytes;
        }
      } break;
      case 8 : { //  256 colors
        for (int y = height()-1; y>=0; --y) {
          if (buf_size>=cimg_iobuffer) { cimg::fread(ptrs=buffer._data,dx_bytes,nfile); std::fseek(nfile,align_bytes,SEEK_CUR); }
          cimg_forX(*this,x) {
            const unsigned char *col = (unsigned char*)(colormap._data + *(ptrs++));
            (*this)(x,y,2) = (T)*(col++);
            (*this)(x,y,1) = (T)*(col++);
            (*this)(x,y,0) = (T)*(col++);
          }
          ptrs+=align_bytes;
        }
      } break;
      case 16 : { // 16 bits colors
        for (int y = height()-1; y>=0; --y) {
          if (buf_size>=cimg_iobuffer) { cimg::fread(ptrs=buffer._data,dx_bytes,nfile); std::fseek(nfile,align_bytes,SEEK_CUR); }
          cimg_forX(*this,x) {
            const unsigned char c1 = *(ptrs++), c2 = *(ptrs++);
            const unsigned short col = (unsigned short)(c1|(c2<<8));
            (*this)(x,y,2) = (T)(col&0x1F);
            (*this)(x,y,1) = (T)((col>>5)&0x1F);
            (*this)(x,y,0) = (T)((col>>10)&0x1F);
          }
          ptrs+=align_bytes;
        }
      } break;
      case 24 : { // 24 bits colors
        for (int y = height()-1; y>=0; --y) {
          if (buf_size>=cimg_iobuffer) { cimg::fread(ptrs=buffer._data,dx_bytes,nfile); std::fseek(nfile,align_bytes,SEEK_CUR); }
          cimg_forX(*this,x) {
            (*this)(x,y,2) = (T)*(ptrs++);
            (*this)(x,y,1) = (T)*(ptrs++);
            (*this)(x,y,0) = (T)*(ptrs++);
          }
          ptrs+=align_bytes;
        }
      } break;
      case 32 : { // 32 bits colors
        for (int y = height()-1; y>=0; --y) {
          if (buf_size>=cimg_iobuffer) { cimg::fread(ptrs=buffer._data,dx_bytes,nfile); std::fseek(nfile,align_bytes,SEEK_CUR); }
          cimg_forX(*this,x) {
            (*this)(x,y,2) = (T)*(ptrs++);
            (*this)(x,y,1) = (T)*(ptrs++);
            (*this)(x,y,0) = (T)*(ptrs++);
            ++ptrs;
          }
          ptrs+=align_bytes;
        }
      } break;
      }
      if (dy<0) mirror('y');
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Load image from a JPEG file.
    /**
       \param filename Filename, as a C-string.
    **/
    CImg<T>& load_jpeg(const char *const filename) {
      return _load_jpeg(0,filename);
    }

    //! Load image from a JPEG file \newinstance.
    static CImg<T> get_load_jpeg(const char *const filename) {
      return CImg<T>().load_jpeg(filename);
    }

    //! Load image from a JPEG file \overloading.
    CImg<T>& load_jpeg(std::FILE *const file) {
      return _load_jpeg(file,0);
    }

    //! Load image from a JPEG file \newinstance.
    static CImg<T> get_load_jpeg(std::FILE *const file) {
      return CImg<T>().load_jpeg(file);
    }

    // Custom error handler for libjpeg.
#ifdef cimg_use_jpeg
    struct _cimg_error_mgr {
      struct jpeg_error_mgr original;
      jmp_buf setjmp_buffer;
      char message[JMSG_LENGTH_MAX];
    };

    typedef struct _cimg_error_mgr *_cimg_error_ptr;

    METHODDEF(void) _cimg_jpeg_error_exit(j_common_ptr cinfo) {
      _cimg_error_ptr c_err = (_cimg_error_ptr) cinfo->err;  // Return control to the setjmp point
      (*cinfo->err->format_message)(cinfo,c_err->message);
      jpeg_destroy(cinfo);  // Clean memory and temp files.
      longjmp(c_err->setjmp_buffer,1);
    }
#endif
# 36061 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    CImg<T>& _load_jpeg(std::FILE *const file, const char *const filename) {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_jpeg(): Specified filename is (null).",
                                    cimg_instance);

#ifndef cimg_use_jpeg
      if (file)
        throw CImgIOException(_cimg_instance
                              "load_jpeg(): Unable to load data from '(FILE*)' unless libjpeg is enabled.",
                              cimg_instance);
      else return load_other(filename);
#else
# 36075 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

      struct jpeg_decompress_struct cinfo;
      struct _cimg_error_mgr jerr;
      cinfo.err = jpeg_std_error(&jerr.original);
      jerr.original.error_exit = _cimg_jpeg_error_exit;

      if (setjmp(jerr.setjmp_buffer)) { // JPEG error
        throw CImgIOException(_cimg_instance
                             "load_jpeg(): Error message returned by libjpeg: %s.",
                             cimg_instance,jerr.message);
      }

      std::FILE *const nfile = file?file:cimg::fopen(filename,"rb");
      jpeg_create_decompress(&cinfo);
      jpeg_stdio_src(&cinfo,nfile);
      jpeg_read_header(&cinfo,TRUE);
      jpeg_start_decompress(&cinfo);

      if (cinfo.output_components!=1 && cinfo.output_components!=3 && cinfo.output_components!=4) {
        if (!file) {
          cimg::fclose(nfile);
          return load_other(filename);
        } else
          throw CImgIOException(_cimg_instance
                                "load_jpeg(): Failed to load JPEG data from file '%s'.",
                                cimg_instance,filename?filename:"(FILE*)");
      }
      CImg<ucharT> buffer(cinfo.output_width*cinfo.output_components);
      JSAMPROW row_pointer[1];
      assign(cinfo.output_width,cinfo.output_height,1,cinfo.output_components);
      T *ptr_r = _data, *ptr_g = _data + 1UL*_width*_height, *ptr_b = _data + 2UL*_width*_height, *ptr_a = _data + 3UL*_width*_height;
      while (cinfo.output_scanline<cinfo.output_height) {
        *row_pointer = buffer._data;
        if (jpeg_read_scanlines(&cinfo,row_pointer,1)!=1) {
          cimg::warn(_cimg_instance
                     "load_jpeg(): Incomplete data in file '%s'.",
                     cimg_instance,filename?filename:"(FILE*)");
          break;
        }
        const unsigned char *ptrs = buffer._data;
        switch (_spectrum) {
        case 1 : {
          cimg_forX(*this,x) *(ptr_r++) = (T)*(ptrs++);
        } break;
        case 3 : {
          cimg_forX(*this,x) {
            *(ptr_r++) = (T)*(ptrs++);
            *(ptr_g++) = (T)*(ptrs++);
            *(ptr_b++) = (T)*(ptrs++);
          }
        } break;
        case 4 : {
          cimg_forX(*this,x) {
            *(ptr_r++) = (T)*(ptrs++);
            *(ptr_g++) = (T)*(ptrs++);
            *(ptr_b++) = (T)*(ptrs++);
            *(ptr_a++) = (T)*(ptrs++);
          }
        } break;
        }
      }
      jpeg_finish_decompress(&cinfo);
      jpeg_destroy_decompress(&cinfo);
      if (!file) cimg::fclose(nfile);
      return *this;
#endif
# 36141 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    }

    //! Load image from a file, using Magick++ library.
    /**
       \param filename Filename, as a C-string.
    **/
    // Added April/may 2006 by Christoph Hormann <chris_hormann@gmx.de>
    //   This is experimental code, not much tested, use with care.
    CImg<T>& load_magick(const char *const filename) {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_magick(): Specified filename is (null).",
                                    cimg_instance);

#ifdef cimg_use_magick
      Magick::Image image(filename);
      const unsigned int W = image.size().width(), H = image.size().height();
      switch (image.type()) {
      case Magick::PaletteMatteType :
      case Magick::TrueColorMatteType :
      case Magick::ColorSeparationType : {
        assign(W,H,1,4);
        T *ptr_r = data(0,0,0,0), *ptr_g = data(0,0,0,1), *ptr_b = data(0,0,0,2), *ptr_a = data(0,0,0,3);
        Magick::PixelPacket *pixels = image.getPixels(0,0,W,H);
        for (unsigned long off = (unsigned long)W*H; off; --off) {
          *(ptr_r++) = (T)(pixels->red);
          *(ptr_g++) = (T)(pixels->green);
          *(ptr_b++) = (T)(pixels->blue);
          *(ptr_a++) = (T)(pixels->opacity);
          ++pixels;
        }
      } break;
      case Magick::PaletteType :
      case Magick::TrueColorType : {
        assign(W,H,1,3);
        T *ptr_r = data(0,0,0,0), *ptr_g = data(0,0,0,1), *ptr_b = data(0,0,0,2);
        Magick::PixelPacket *pixels = image.getPixels(0,0,W,H);
        for (unsigned long off = (unsigned long)W*H; off; --off) {
          *(ptr_r++) = (T)(pixels->red);
          *(ptr_g++) = (T)(pixels->green);
          *(ptr_b++) = (T)(pixels->blue);
          ++pixels;
        }
      } break;
      case Magick::GrayscaleMatteType : {
        assign(W,H,1,2);
        T *ptr_r = data(0,0,0,0), *ptr_a = data(0,0,0,1);
        Magick::PixelPacket *pixels = image.getPixels(0,0,W,H);
        for (unsigned long off = (unsigned long)W*H; off; --off) {
          *(ptr_r++) = (T)(pixels->red);
          *(ptr_a++) = (T)(pixels->opacity);
          ++pixels;
        }
      } break;
      default : {
        assign(W,H,1,1);
        T *ptr_r = data(0,0,0,0);
        Magick::PixelPacket *pixels = image.getPixels(0,0,W,H);
        for (unsigned long off = (unsigned long)W*H; off; --off) {
          *(ptr_r++) = (T)(pixels->red);
          ++pixels;
        }
      }
      }
#else
# 36206 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      throw CImgIOException(_cimg_instance
                            "load_magick(): Unable to load file '%s' unless libMagick++ is enabled.",
                            cimg_instance,
                            filename);
#endif
# 36211 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      return *this;
    }

    //! Load image from a file, using Magick++ library \newinstance.
    static CImg<T> get_load_magick(const char *const filename) {
      return CImg<T>().load_magick(filename);
    }

    //! Load image from a PNG file.
    /**
       \param filename Filename, as a C-string.
    **/
    CImg<T>& load_png(const char *const filename) {
      return _load_png(0,filename);
    }

    //! Load image from a PNG file \newinstance.
    static CImg<T> get_load_png(const char *const filename) {
      return CImg<T>().load_png(filename);
    }

    //! Load image from a PNG file \overloading.
    CImg<T>& load_png(std::FILE *const file) {
      return _load_png(file,0);
    }

    //! Load image from a PNG file \newinstance.
    static CImg<T> get_load_png(std::FILE *const file) {
      return CImg<T>().load_png(file);
    }

    // (Note: Most of this function has been written by Eric Fausett)
    CImg<T>& _load_png(std::FILE *const file, const char *const filename) {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_png(): Specified filename is (null).",
                                    cimg_instance);

#ifndef cimg_use_png
      if (file)
        throw CImgIOException(_cimg_instance
                              "load_png(): Unable to load data from '(FILE*)' unless libpng is enabled.",
                              cimg_instance);

      else return load_other(filename);
#else
# 36257 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      // Open file and check for PNG validity
      const char *volatile nfilename = filename; // two 'volatile' here to remove a g++ warning due to 'setjmp'.
      std::FILE *volatile nfile = file?file:cimg::fopen(nfilename,"rb");

      unsigned char pngCheck[8] = { 0 };
      cimg::fread(pngCheck,8,(std::FILE*)nfile);
      if (png_sig_cmp(pngCheck,0,8)) {
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimg_instance
                              "load_png(): Invalid PNG file '%s'.",
                              cimg_instance,
                              nfilename?nfilename:"(FILE*)");
      }

      // Setup PNG structures for read
      png_voidp user_error_ptr = 0;
      png_error_ptr user_error_fn = 0, user_warning_fn = 0;
      png_structp png_ptr = png_create_read_struct(PNG_LIBPNG_VER_STRING,user_error_ptr,user_error_fn,user_warning_fn);
      if (!png_ptr) {
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimg_instance
                              "load_png(): Failed to initialize 'png_ptr' structure for file '%s'.",
                              cimg_instance,
                              nfilename?nfilename:"(FILE*)");
      }
      png_infop info_ptr = png_create_info_struct(png_ptr);
      if (!info_ptr) {
        if (!file) cimg::fclose(nfile);
        png_destroy_read_struct(&png_ptr,(png_infopp)0,(png_infopp)0);
        throw CImgIOException(_cimg_instance
                              "load_png(): Failed to initialize 'info_ptr' structure for file '%s'.",
                              cimg_instance,
                              nfilename?nfilename:"(FILE*)");
      }
      png_infop end_info = png_create_info_struct(png_ptr);
      if (!end_info) {
        if (!file) cimg::fclose(nfile);
        png_destroy_read_struct(&png_ptr,&info_ptr,(png_infopp)0);
        throw CImgIOException(_cimg_instance
                              "load_png(): Failed to initialize 'end_info' structure for file '%s'.",
                              cimg_instance,
                              nfilename?nfilename:"(FILE*)");
      }

      // Error handling callback for png file reading
      if (setjmp(png_jmpbuf(png_ptr))) {
        if (!file) cimg::fclose((std::FILE*)nfile);
        png_destroy_read_struct(&png_ptr, &end_info, (png_infopp)0);
        throw CImgIOException(_cimg_instance
                              "load_png(): Encountered unknown fatal error in libpng for file '%s'.",
                              cimg_instance,
                              nfilename?nfilename:"(FILE*)");
      }
      png_init_io(png_ptr, nfile);
      png_set_sig_bytes(png_ptr, 8);

      // Get PNG Header Info up to data block
      png_read_info(png_ptr,info_ptr);
      png_uint_32 W, H;
      int bit_depth, color_type, interlace_type;
      bool is_gray = false;
      png_get_IHDR(png_ptr,info_ptr,&W,&H,&bit_depth,&color_type,&interlace_type,(int*)0,(int*)0);

      // Transforms to unify image data
      if (color_type==PNG_COLOR_TYPE_PALETTE) {
        png_set_palette_to_rgb(png_ptr);
        color_type = PNG_COLOR_TYPE_RGB;
        bit_depth = 8;
      }
      if (color_type==PNG_COLOR_TYPE_GRAY && bit_depth<8) {
        png_set_expand_gray_1_2_4_to_8(png_ptr);
        is_gray = true;
        bit_depth = 8;
      }
      if (png_get_valid(png_ptr,info_ptr,PNG_INFO_tRNS)) {
        png_set_tRNS_to_alpha(png_ptr);
        color_type |= PNG_COLOR_MASK_ALPHA;
      }
      if (color_type==PNG_COLOR_TYPE_GRAY || color_type==PNG_COLOR_TYPE_GRAY_ALPHA) {
        png_set_gray_to_rgb(png_ptr);
        color_type |= PNG_COLOR_MASK_COLOR;
        is_gray = true;
      }
      if (color_type==PNG_COLOR_TYPE_RGB)
        png_set_filler(png_ptr,0xffffU,PNG_FILLER_AFTER);

      png_read_update_info(png_ptr,info_ptr);
      if (bit_depth!=8 && bit_depth!=16) {
        if (!file) cimg::fclose(nfile);
        png_destroy_read_struct(&png_ptr,&end_info,(png_infopp)0);
        throw CImgIOException(_cimg_instance
                              "load_png(): Invalid bit depth %u in file '%s'.",
                              cimg_instance,
                              bit_depth,nfilename?nfilename:"(FILE*)");
      }
      const int byte_depth = bit_depth>>3;

      // Allocate Memory for Image Read
      png_bytep *const imgData = new png_bytep[H];
      for (unsigned int row = 0; row<H; ++row) imgData[row] = new png_byte[byte_depth*4*W];
      png_read_image(png_ptr,imgData);
      png_read_end(png_ptr,end_info);

      // Read pixel data
      if (color_type!=PNG_COLOR_TYPE_RGB && color_type!=PNG_COLOR_TYPE_RGB_ALPHA) {
        if (!file) cimg::fclose(nfile);
        png_destroy_read_struct(&png_ptr,&end_info,(png_infopp)0);
        throw CImgIOException(_cimg_instance
                              "load_png(): Invalid color coding type %u in file '%s'.",
                              cimg_instance,
                              color_type,nfilename?nfilename:"(FILE*)");
      }
      const bool is_alpha = (color_type==PNG_COLOR_TYPE_RGBA);
      assign(W,H,1,(is_gray?1:3) + (is_alpha?1:0));
      T
        *ptr_r = data(0,0,0,0),
        *ptr_g = is_gray?0:data(0,0,0,1),
        *ptr_b = is_gray?0:data(0,0,0,2),
        *ptr_a = !is_alpha?0:data(0,0,0,is_gray?1:3);
      switch (bit_depth) {
      case 8 : {
        cimg_forY(*this,y) {
          const unsigned char *ptrs = (unsigned char*)imgData[y];
          cimg_forX(*this,x) {
            *(ptr_r++) = (T)*(ptrs++);
            if (ptr_g) *(ptr_g++) = (T)*(ptrs++); else ++ptrs;
            if (ptr_b) *(ptr_b++) = (T)*(ptrs++); else ++ptrs;
            if (ptr_a) *(ptr_a++) = (T)*(ptrs++); else ++ptrs;
          }
        }
      } break;
      case 16 : {
        cimg_forY(*this,y) {
          const unsigned short *ptrs = (unsigned short*)(imgData[y]);
          if (!cimg::endianness()) cimg::invert_endianness(ptrs,4*_width);
          cimg_forX(*this,x) {
            *(ptr_r++) = (T)*(ptrs++);
            if (ptr_g) *(ptr_g++) = (T)*(ptrs++); else ++ptrs;
            if (ptr_b) *(ptr_b++) = (T)*(ptrs++); else ++ptrs;
            if (ptr_a) *(ptr_a++) = (T)*(ptrs++); else ++ptrs;
          }
        }
      } break;
      }
      png_destroy_read_struct(&png_ptr, &info_ptr, &end_info);

      // Deallocate Image Read Memory
      cimg_forY(*this,n) delete[] imgData[n];
      delete[] imgData;
      if (!file) cimg::fclose(nfile);
      return *this;
#endif
# 36409 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    }

    //! Load image from a PNM file.
    /**
      \param filename Filename, as a C-string.
    **/
    CImg<T>& load_pnm(const char *const filename) {
      return _load_pnm(0,filename);
    }

    //! Load image from a PNM file \newinstance.
    static CImg<T> get_load_pnm(const char *const filename) {
      return CImg<T>().load_pnm(filename);
    }

    //! Load image from a PNM file \overloading.
    CImg<T>& load_pnm(std::FILE *const file) {
      return _load_pnm(file,0);
    }

    //! Load image from a PNM file \newinstance.
    static CImg<T> get_load_pnm(std::FILE *const file) {
      return CImg<T>().load_pnm(file);
    }

    CImg<T>& _load_pnm(std::FILE *const file, const char *const filename) {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_pnm(): Specified filename is (null).",
                                    cimg_instance);

      std::FILE *const nfile = file?file:cimg::fopen(filename,"rb");
      unsigned int ppm_type, W, H, D = 1, colormax = 255;
      CImg<charT> item(16384,1,1,1,0);
      int err, rval, gval, bval;
      const long cimg_iobuffer = 12*1024*1024;
      while ((err=std::fscanf(nfile,"%16383[^\n]",item.data()))!=EOF && (*item=='#' || !err)) std::fgetc(nfile);
      if (std::sscanf(item," P%u",&ppm_type)!=1) {
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimg_instance
                              "load_pnm(): PNM header not found in file '%s'.",
                              cimg_instance,
                              filename?filename:"(FILE*)");
      }
      while ((err=std::fscanf(nfile," %16383[^\n]",item.data()))!=EOF && (*item=='#' || !err)) std::fgetc(nfile);
      if ((err=std::sscanf(item," %u %u %u %u",&W,&H,&D,&colormax))<2) {
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimg_instance
                              "load_pnm(): WIDTH and HEIGHT fields undefined in file '%s'.",
                              cimg_instance,
                              filename?filename:"(FILE*)");
      }
      if (ppm_type!=1 && ppm_type!=4) {
        if (err==2 || (err==3 && (ppm_type==5 || ppm_type==7 || ppm_type==8 || ppm_type==9))) {
          while ((err=std::fscanf(nfile," %16383[^\n]",item.data()))!=EOF && (*item=='#' || !err)) std::fgetc(nfile);
          if (std::sscanf(item,"%u",&colormax)!=1)
            cimg::warn(_cimg_instance
                       "load_pnm(): COLORMAX field is undefined in file '%s'.",
                       cimg_instance,
                       filename?filename:"(FILE*)");
        } else { colormax = D; D = 1; }
      }
      std::fgetc(nfile);

      switch (ppm_type) {
      case 1 : { // 2d b&w ascii.
        assign(W,H,1,1);
        T* ptrd = _data;
        cimg_foroff(*this,off) { if (std::fscanf(nfile,"%d",&rval)>0) *(ptrd++) = (T)(rval?0:255); else break; }
      } break;
      case 2 : { // 2d grey ascii.
        assign(W,H,1,1);
        T* ptrd = _data;
        cimg_foroff(*this,off) { if (std::fscanf(nfile,"%d",&rval)>0) *(ptrd++) = (T)rval; else break; }
      } break;
      case 3 : { // 2d color ascii.
        assign(W,H,1,3);
        T *ptrd = data(0,0,0,0), *ptr_g = data(0,0,0,1), *ptr_b = data(0,0,0,2);
        cimg_forXY(*this,x,y) {
          if (std::fscanf(nfile,"%d %d %d",&rval,&gval,&bval)==3) { *(ptrd++) = (T)rval; *(ptr_g++) = (T)gval; *(ptr_b++) = (T)bval; }
          else break;
        }
      } break;
      case 4 : { // 2d b&w binary (support 3D PINK extension).
        CImg<ucharT> raw;
        assign(W,H,D,1);
        T *ptrd = data(0,0,0,0);
        unsigned int w = 0, h = 0, d = 0;
        for (long to_read = (long)((W/8 + (W%8?1:0))*H*D); to_read>0; ) {
          raw.assign(cimg::min(to_read,cimg_iobuffer));
          cimg::fread(raw._data,raw._width,nfile);
          to_read-=raw._width;
          const unsigned char *ptrs = raw._data;
          unsigned char mask = 0, val = 0;
          for (unsigned long off = (unsigned long)raw._width; off || mask; mask>>=1) {
            if (!mask) { if (off--) val = *(ptrs++); mask = 128; }
            *(ptrd++) = (T)((val&mask)?0:255);
            if (++w==W) { w = 0; mask = 0; if (++h==H) { h = 0; if (++d==D) break; }}
          }
        }
      } break;
      case 5 : case 7 : { // 2d/3d grey binary (support 3D PINK extension).
        if (colormax<256) { // 8 bits.
          CImg<ucharT> raw;
          assign(W,H,D,1);
          T *ptrd = data(0,0,0,0);
          for (long to_read = (long)size(); to_read>0; ) {
            raw.assign(cimg::min(to_read,cimg_iobuffer));
            cimg::fread(raw._data,raw._width,nfile);
            to_read-=raw._width;
            const unsigned char *ptrs = raw._data;
            for (unsigned long off = (unsigned long)raw._width; off; --off) *(ptrd++) = (T)*(ptrs++);
          }
        } else { // 16 bits.
          CImg<ushortT> raw;
          assign(W,H,D,1);
          T *ptrd = data(0,0,0,0);
          for (long to_read = (long)size(); to_read>0; ) {
            raw.assign(cimg::min(to_read,cimg_iobuffer/2));
            cimg::fread(raw._data,raw._width,nfile);
	    if (!cimg::endianness()) cimg::invert_endianness(raw._data,raw._width);
            to_read-=raw._width;
            const unsigned short *ptrs = raw._data;
            for (unsigned long off = (unsigned long)raw._width; off; --off) *(ptrd++) = (T)*(ptrs++);
          }
        }
      } break;
      case 6 : { // 2d color binary.
        if (colormax<256) { // 8 bits.
          CImg<ucharT> raw;
          assign(W,H,1,3);
          T
            *ptr_r = data(0,0,0,0),
            *ptr_g = data(0,0,0,1),
            *ptr_b = data(0,0,0,2);
          for (long to_read = (long)size(); to_read>0; ) {
            raw.assign(cimg::min(to_read,cimg_iobuffer));
            cimg::fread(raw._data,raw._width,nfile);
            to_read-=raw._width;
            const unsigned char *ptrs = raw._data;
            for (unsigned long off = (unsigned long)raw._width/3; off; --off) {
              *(ptr_r++) = (T)*(ptrs++);
              *(ptr_g++) = (T)*(ptrs++);
              *(ptr_b++) = (T)*(ptrs++);
            }
          }
        } else { // 16 bits.
          CImg<ushortT> raw;
          assign(W,H,1,3);
          T
            *ptr_r = data(0,0,0,0),
            *ptr_g = data(0,0,0,1),
            *ptr_b = data(0,0,0,2);
          for (long to_read = (int)size(); to_read>0; ) {
            raw.assign(cimg::min(to_read,cimg_iobuffer/2));
            cimg::fread(raw._data,raw._width,nfile);
            if (!cimg::endianness()) cimg::invert_endianness(raw._data,raw._width);
            to_read-=raw._width;
            const unsigned short *ptrs = raw._data;
            for (unsigned long off = (unsigned long)raw._width/3; off; --off) {
              *(ptr_r++) = (T)*(ptrs++);
              *(ptr_g++) = (T)*(ptrs++);
              *(ptr_b++) = (T)*(ptrs++);
            }
          }
        }
      } break;
      case 8 : { // 2d/3d grey binary with int32 integers (PINK extension).
        CImg<intT> raw;
        assign(W,H,D,1);
        T *ptrd = data(0,0,0,0);
        for (long to_read = (long)size(); to_read>0; ) {
          raw.assign(cimg::min(to_read,cimg_iobuffer));
          cimg::fread(raw._data,raw._width,nfile);
          to_read-=raw._width;
          const int *ptrs = raw._data;
          for (unsigned long off = (unsigned long)raw._width; off; --off) *(ptrd++) = (T)*(ptrs++);
        }
      } break;
      case 9 : { // 2d/3d grey binary with float values (PINK extension).
        CImg<floatT> raw;
        assign(W,H,D,1);
        T *ptrd = data(0,0,0,0);
        for (long to_read = (long)size(); to_read>0; ) {
          raw.assign(cimg::min(to_read,cimg_iobuffer));
          cimg::fread(raw._data,raw._width,nfile);
          to_read-=raw._width;
          const float *ptrs = raw._data;
          for (unsigned long off = (unsigned long)raw._width; off; --off) *(ptrd++) = (T)*(ptrs++);
        }
      } break;
      default :
        assign();
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimg_instance
                              "load_pnm(): PNM type 'P%d' found, but type is not supported.",
                              cimg_instance,
                              filename?filename:"(FILE*)",ppm_type);
      }
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Load image from a PFM file.
    /**
      \param filename Filename, as a C-string.
    **/
    CImg<T>& load_pfm(const char *const filename) {
      return _load_pfm(0,filename);
    }

    //! Load image from a PFM file \newinstance.
    static CImg<T> get_load_pfm(const char *const filename) {
      return CImg<T>().load_pfm(filename);
    }

    //! Load image from a PFM file \overloading.
    CImg<T>& load_pfm(std::FILE *const file) {
      return _load_pfm(file,0);
    }

    //! Load image from a PFM file \newinstance.
    static CImg<T> get_load_pfm(std::FILE *const file) {
      return CImg<T>().load_pfm(file);
    }

    CImg<T>& _load_pfm(std::FILE *const file, const char *const filename) {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_pfm(): Specified filename is (null).",
                                    cimg_instance);

      std::FILE *const nfile = file?file:cimg::fopen(filename,"rb");
      char pfm_type;
      CImg<charT> item(16384,1,1,1,0);
      int W = 0, H = 0, err = 0;
      double scale = 0;
      while ((err=std::fscanf(nfile,"%16383[^\n]",item.data()))!=EOF && (*item=='#' || !err)) std::fgetc(nfile);
      if (std::sscanf(item," P%c",&pfm_type)!=1) {
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimg_instance
                              "load_pfm(): PFM header not found in file '%s'.",
                              cimg_instance,
                              filename?filename:"(FILE*)");
      }
      while ((err=std::fscanf(nfile," %16383[^\n]",item.data()))!=EOF && (*item=='#' || !err)) std::fgetc(nfile);
      if ((err=std::sscanf(item," %d %d",&W,&H))<2) {
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimg_instance
                              "load_pfm(): WIDTH and HEIGHT fields are undefined in file '%s'.",
                              cimg_instance,
                              filename?filename:"(FILE*)");
      }
      if (err==2) {
        while ((err=std::fscanf(nfile," %16383[^\n]",item.data()))!=EOF && (*item=='#' || !err)) std::fgetc(nfile);
        if (std::sscanf(item,"%lf",&scale)!=1)
          cimg::warn(_cimg_instance
                     "load_pfm(): SCALE field is undefined in file '%s'.",
                     cimg_instance,
                     filename?filename:"(FILE*)");
      }
      std::fgetc(nfile);
      const bool is_color = (pfm_type=='F'), is_inverted = (scale>0)!=cimg::endianness();
      if (is_color) {
        assign(W,H,1,3,0);
        CImg<floatT> buf(3*W);
        T *ptr_r = data(0,0,0,0), *ptr_g = data(0,0,0,1), *ptr_b = data(0,0,0,2);
        cimg_forY(*this,y) {
          cimg::fread(buf._data,3*W,nfile);
          if (is_inverted) cimg::invert_endianness(buf._data,3*W);
          const float *ptrs = buf._data;
          cimg_forX(*this,x) {
            *(ptr_r++) = (T)*(ptrs++);
            *(ptr_g++) = (T)*(ptrs++);
            *(ptr_b++) = (T)*(ptrs++);
          }
        }
      } else {
        assign(W,H,1,1,0);
        CImg<floatT> buf(W);
        T *ptrd = data(0,0,0,0);
        cimg_forY(*this,y) {
          cimg::fread(buf._data,W,nfile);
          if (is_inverted) cimg::invert_endianness(buf._data,W);
          const float *ptrs = buf._data;
          cimg_forX(*this,x) *(ptrd++) = (T)*(ptrs++);
        }
      }
      if (!file) cimg::fclose(nfile);
      return mirror('y');  // Most of the .pfm files are flipped along the y-axis.
    }

    //! Load image from a RGB file.
    /**
      \param filename Filename, as a C-string.
      \param dimw Width of the image buffer.
      \param dimh Height of the image buffer.
    **/
    CImg<T>& load_rgb(const char *const filename, const unsigned int dimw, const unsigned int dimh=1) {
      return _load_rgb(0,filename,dimw,dimh);
    }

    //! Load image from a RGB file \newinstance.
    static CImg<T> get_load_rgb(const char *const filename, const unsigned int dimw, const unsigned int dimh=1) {
      return CImg<T>().load_rgb(filename,dimw,dimh);
    }

    //! Load image from a RGB file \overloading.
    CImg<T>& load_rgb(std::FILE *const file, const unsigned int dimw, const unsigned int dimh=1) {
      return _load_rgb(file,0,dimw,dimh);
    }

    //! Load image from a RGB file \newinstance.
    static CImg<T> get_load_rgb(std::FILE *const file, const unsigned int dimw, const unsigned int dimh=1) {
      return CImg<T>().load_rgb(file,dimw,dimh);
    }

    CImg<T>& _load_rgb(std::FILE *const file, const char *const filename, const unsigned int dimw, const unsigned int dimh) {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_rgb(): Specified filename is (null).",
                                    cimg_instance);

      if (!dimw || !dimh) return assign();
      const long cimg_iobuffer = 12*1024*1024;
      std::FILE *const nfile = file?file:cimg::fopen(filename,"rb");
      CImg<ucharT> raw;
      assign(dimw,dimh,1,3);
      T
        *ptr_r = data(0,0,0,0),
        *ptr_g = data(0,0,0,1),
        *ptr_b = data(0,0,0,2);
      for (long to_read = (long)size(); to_read>0; ) {
        raw.assign(cimg::min(to_read,cimg_iobuffer));
        cimg::fread(raw._data,raw._width,nfile);
        to_read-=raw._width;
        const unsigned char *ptrs = raw._data;
        for (unsigned long off = raw._width/3UL; off; --off) {
          *(ptr_r++) = (T)*(ptrs++);
          *(ptr_g++) = (T)*(ptrs++);
          *(ptr_b++) = (T)*(ptrs++);
        }
      }
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Load image from a RGBA file.
    /**
       \param filename Filename, as a C-string.
       \param dimw Width of the image buffer.
       \param dimh Height of the image buffer.
    **/
    CImg<T>& load_rgba(const char *const filename, const unsigned int dimw, const unsigned int dimh=1) {
      return _load_rgba(0,filename,dimw,dimh);
    }

    //! Load image from a RGBA file \newinstance.
    static CImg<T> get_load_rgba(const char *const filename, const unsigned int dimw, const unsigned int dimh=1) {
      return CImg<T>().load_rgba(filename,dimw,dimh);
    }

    //! Load image from a RGBA file \overloading.
    CImg<T>& load_rgba(std::FILE *const file, const unsigned int dimw, const unsigned int dimh=1) {
      return _load_rgba(file,0,dimw,dimh);
    }

    //! Load image from a RGBA file \newinstance.
    static CImg<T> get_load_rgba(std::FILE *const file, const unsigned int dimw, const unsigned int dimh=1) {
      return CImg<T>().load_rgba(file,dimw,dimh);
    }

    CImg<T>& _load_rgba(std::FILE *const file, const char *const filename, const unsigned int dimw, const unsigned int dimh) {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_rgba(): Specified filename is (null).",
                                    cimg_instance);

      if (!dimw || !dimh) return assign();
      const long cimg_iobuffer = 12*1024*1024;
      std::FILE *const nfile = file?file:cimg::fopen(filename,"rb");
      CImg<ucharT> raw;
      assign(dimw,dimh,1,4);
      T
        *ptr_r = data(0,0,0,0),
        *ptr_g = data(0,0,0,1),
        *ptr_b = data(0,0,0,2),
        *ptr_a = data(0,0,0,3);
      for (long to_read = (long)size(); to_read>0; ) {
        raw.assign(cimg::min(to_read,cimg_iobuffer));
        cimg::fread(raw._data,raw._width,nfile);
        to_read-=raw._width;
        const unsigned char *ptrs = raw._data;
        for (unsigned long off = raw._width/4UL; off; --off) {
          *(ptr_r++) = (T)*(ptrs++);
          *(ptr_g++) = (T)*(ptrs++);
          *(ptr_b++) = (T)*(ptrs++);
          *(ptr_a++) = (T)*(ptrs++);
        }
      }
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Load image from a TIFF file.
    /**
       \param filename Filename, as a C-string.
       \param first_frame First frame to read (for multi-pages tiff).
       \param last_frame Last frame to read (for multi-pages tiff).
       \param step_frame Step value of frame reading.
       \note
       - libtiff support is enabled by defining the precompilation
        directive \c cimg_use_tif.
       - When libtiff is enabled, 2D and 3D (multipage) several
        channel per pixel are supported for
        <tt>char,uchar,short,ushort,float</tt> and \c double pixel types.
       - If \c cimg_use_tif is not defined at compilation time the
        function uses CImg<T>& load_other(const char*).
     **/
    CImg<T>& load_tiff(const char *const filename,
		       const unsigned int first_frame=0, const unsigned int last_frame=~0U,
		       const unsigned int step_frame=1) {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_tiff(): Specified filename is (null).",
                                    cimg_instance);

      const unsigned int
	nfirst_frame = first_frame<last_frame?first_frame:last_frame,
	nstep_frame = step_frame?step_frame:1;
      unsigned int nlast_frame = first_frame<last_frame?last_frame:first_frame;

#ifndef cimg_use_tiff
      if (nfirst_frame || nlast_frame!=~0U || nstep_frame>1)
        throw CImgArgumentException(_cimg_instance
                                    "load_tiff(): Unable to read sub-images from file '%s' unless libtiff is enabled.",
                                    cimg_instance,
                                    filename);
      return load_other(filename);
#else
# 36849 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      TIFF *tif = TIFFOpen(filename,"r");
      if (tif) {
        unsigned int nb_images = 0;
        do ++nb_images; while (TIFFReadDirectory(tif));
        if (nfirst_frame>=nb_images || (nlast_frame!=~0U && nlast_frame>=nb_images))
          cimg::warn(_cimg_instance
                     "load_tiff(): File '%s' contains %u image(s) while specified frame range is [%u,%u] (step %u).",
                     cimg_instance,
                     filename,nb_images,nfirst_frame,nlast_frame,nstep_frame);

        if (nfirst_frame>=nb_images) return assign();
        if (nlast_frame>=nb_images) nlast_frame = nb_images-1;
        TIFFSetDirectory(tif,0);
        CImg<T> frame;
        for (unsigned int l = nfirst_frame; l<=nlast_frame; l+=nstep_frame) {
          frame._load_tiff(tif,l);
          if (l==nfirst_frame) assign(frame._width,frame._height,1+(nlast_frame-nfirst_frame)/nstep_frame,frame._spectrum);
          if (frame._width>_width || frame._height>_height || frame._spectrum>_spectrum)
            resize(cimg::max(frame._width,_width),cimg::max(frame._height,_height),-100,cimg::max(frame._spectrum,_spectrum),0);
          draw_image(0,0,(l-nfirst_frame)/nstep_frame,frame);
        }
        TIFFClose(tif);
      } else throw CImgIOException(_cimg_instance
                                   "load_tiff(): Failed to open file '%s'.",
                                   cimg_instance,
                                   filename);
      return *this;
#endif
# 36877 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    }

    //! Load image from a TIFF file \newinstance.
    static CImg<T> get_load_tiff(const char *const filename,
				 const unsigned int first_frame=0, const unsigned int last_frame=~0U,
				 const unsigned int step_frame=1) {
      return CImg<T>().load_tiff(filename,first_frame,last_frame,step_frame);
    }

    // (Original contribution by Jerome Boulanger).
#ifdef cimg_use_tiff
    template<typename t>
    void _load_tiff_tiled_contig(TIFF *const tif, const uint16 samplesperpixel, const uint32 nx, const uint32 ny, const uint32 tw, const uint32 th) {
      t *const buf = (t*)_TIFFmalloc(TIFFTileSize(tif));
      if (buf) {
        for (unsigned int row = 0; row<ny; row+=th)
          for (unsigned int col = 0; col<nx; col+=tw) {
            if (TIFFReadTile(tif,buf,col,row,0,0)<0) {
              _TIFFfree(buf); TIFFClose(tif);
              throw CImgIOException(_cimg_instance
                                    "load_tiff(): Invalid tile in file '%s'.",
                                    cimg_instance,
                                    TIFFFileName(tif));
            }
            const t *ptr = buf;
            for (unsigned int rr = row; rr<cimg::min((unsigned int)(row+th),(unsigned int)ny); ++rr)
              for (unsigned int cc = col; cc<cimg::min((unsigned int)(col+tw),(unsigned int)nx); ++cc)
                for (unsigned int vv = 0; vv<samplesperpixel; ++vv)
                  (*this)(cc,rr,vv) = (T)(ptr[(rr-row)*th*samplesperpixel + (cc-col)*samplesperpixel + vv]);
          }
        _TIFFfree(buf);
      }
    }

    template<typename t>
    void _load_tiff_tiled_separate(TIFF *const tif, const uint16 samplesperpixel, const uint32 nx, const uint32 ny, const uint32 tw, const uint32 th) {
      t *const buf = (t*)_TIFFmalloc(TIFFTileSize(tif));
      if (buf) {
        for (unsigned int vv = 0; vv<samplesperpixel; ++vv)
          for (unsigned int row = 0; row<ny; row+=th)
            for (unsigned int col = 0; col<nx; col+=tw) {
              if (TIFFReadTile(tif,buf,col,row,0,vv)<0) {
                _TIFFfree(buf); TIFFClose(tif);
                throw CImgIOException(_cimg_instance
                                      "load_tiff(): Invalid tile in file '%s'.",
                                      cimg_instance,
                                      TIFFFileName(tif));
              }
              const t *ptr = buf;
              for (unsigned int rr = row; rr<cimg::min((unsigned int)(row+th),(unsigned int)ny); ++rr)
                for (unsigned int cc = col; cc<cimg::min((unsigned int)(col+tw),(unsigned int)nx); ++cc)
                  (*this)(cc,rr,vv) = (T)*(ptr++);
            }
        _TIFFfree(buf);
      }
    }

    template<typename t>
    void _load_tiff_contig(TIFF *const tif, const uint16 samplesperpixel, const uint32 nx, const uint32 ny) {
      t *const buf = (t*)_TIFFmalloc(TIFFStripSize(tif));
      if (buf) {
        uint32 row, rowsperstrip = (uint32)-1;
        TIFFGetField(tif,TIFFTAG_ROWSPERSTRIP,&rowsperstrip);
        for (row = 0; row<ny; row+= rowsperstrip) {
          uint32 nrow = (row+rowsperstrip>ny?ny-row:rowsperstrip);
          tstrip_t strip = TIFFComputeStrip(tif, row, 0);
          if ((TIFFReadEncodedStrip(tif,strip,buf,-1))<0) {
            _TIFFfree(buf); TIFFClose(tif);
            throw CImgIOException(_cimg_instance
                                  "load_tiff(): Invalid strip in file '%s'.",
                                  cimg_instance,
                                  TIFFFileName(tif));
          }
          const t *ptr = buf;
          for (unsigned int rr = 0; rr<nrow; ++rr)
            for (unsigned int cc = 0; cc<nx; ++cc)
              for (unsigned int vv = 0; vv<samplesperpixel; ++vv) (*this)(cc,row+rr,vv) = (T)*(ptr++);
        }
        _TIFFfree(buf);
      }
    }

    template<typename t>
    void _load_tiff_separate(TIFF *const tif, const uint16 samplesperpixel, const uint32 nx, const uint32 ny) {
      t *buf = (t*)_TIFFmalloc(TIFFStripSize(tif));
      if (buf) {
        uint32 row, rowsperstrip = (uint32)-1;
        TIFFGetField(tif,TIFFTAG_ROWSPERSTRIP,&rowsperstrip);
        for (unsigned int vv = 0; vv<samplesperpixel; ++vv)
          for (row = 0; row<ny; row+= rowsperstrip) {
            uint32 nrow = (row+rowsperstrip>ny?ny-row:rowsperstrip);
            tstrip_t strip = TIFFComputeStrip(tif, row, vv);
            if ((TIFFReadEncodedStrip(tif,strip,buf,-1))<0) {
              _TIFFfree(buf); TIFFClose(tif);
              throw CImgIOException(_cimg_instance
                                    "load_tiff(): Invalid strip in file '%s'.",
                                    cimg_instance,
                                    TIFFFileName(tif));
            }
            const t *ptr = buf;
            for (unsigned int rr = 0;rr<nrow; ++rr)
              for (unsigned int cc = 0; cc<nx; ++cc)
                (*this)(cc,row+rr,vv) = (T)*(ptr++);
          }
        _TIFFfree(buf);
      }
    }

    CImg<T>& _load_tiff(TIFF *const tif, const unsigned int directory) {
      if (!TIFFSetDirectory(tif,directory)) return assign();
      uint16 samplesperpixel = 1, bitspersample, photo;
      uint16 sampleformat = SAMPLEFORMAT_UINT;
      uint32 nx,ny;
      const char *const filename = TIFFFileName(tif);
      TIFFGetField(tif,TIFFTAG_IMAGEWIDTH,&nx);
      TIFFGetField(tif,TIFFTAG_IMAGELENGTH,&ny);
      TIFFGetField(tif,TIFFTAG_SAMPLESPERPIXEL,&samplesperpixel);
      TIFFGetField(tif, TIFFTAG_SAMPLEFORMAT, &sampleformat);
      TIFFGetFieldDefaulted(tif,TIFFTAG_BITSPERSAMPLE,&bitspersample);
      TIFFGetField(tif,TIFFTAG_PHOTOMETRIC,&photo);
      int spectrum = samplesperpixel;
      if (photo == 3) spectrum = 3;
      assign(nx,ny,1,spectrum);
      if ((photo < 3)  && ( bitspersample!=8 || !(samplesperpixel==3 || samplesperpixel==4))) {
        uint16 config;
        TIFFGetField(tif,TIFFTAG_PLANARCONFIG,&config);
        if (TIFFIsTiled(tif)) {
          uint32 tw, th;
          TIFFGetField(tif,TIFFTAG_TILEWIDTH,&tw);
          TIFFGetField(tif,TIFFTAG_TILELENGTH,&th);
          if (config==PLANARCONFIG_CONTIG) switch (bitspersample) {
            case 8 : {
              if (sampleformat==SAMPLEFORMAT_UINT) _load_tiff_tiled_contig<unsigned char>(tif,samplesperpixel,nx,ny,tw,th);
              else _load_tiff_tiled_contig<signed char>(tif,samplesperpixel,nx,ny,tw,th);
            } break;
            case 16 :
              if (sampleformat==SAMPLEFORMAT_UINT) _load_tiff_tiled_contig<unsigned short>(tif,samplesperpixel,nx,ny,tw,th);
              else _load_tiff_tiled_contig<short>(tif,samplesperpixel,nx,ny,tw,th);
              break;
            case 32 :
              if (sampleformat==SAMPLEFORMAT_UINT) _load_tiff_tiled_contig<unsigned int>(tif,samplesperpixel,nx,ny,tw,th);
              else if (sampleformat==SAMPLEFORMAT_INT) _load_tiff_tiled_contig<int>(tif,samplesperpixel,nx,ny,tw,th);
              else _load_tiff_tiled_contig<float>(tif,samplesperpixel,nx,ny,tw,th);
              break;
            } else switch (bitspersample) {
            case 8 :
              if (sampleformat==SAMPLEFORMAT_UINT) _load_tiff_tiled_separate<unsigned char>(tif,samplesperpixel,nx,ny,tw,th);
              else _load_tiff_tiled_separate<signed char>(tif,samplesperpixel,nx,ny,tw,th);
              break;
            case 16 :
              if (sampleformat==SAMPLEFORMAT_UINT) _load_tiff_tiled_separate<unsigned short>(tif,samplesperpixel,nx,ny,tw,th);
              else _load_tiff_tiled_separate<short>(tif,samplesperpixel,nx,ny,tw,th);
              break;
            case 32 :
              if (sampleformat==SAMPLEFORMAT_UINT) _load_tiff_tiled_separate<unsigned int>(tif,samplesperpixel,nx,ny,tw,th);
              else if (sampleformat==SAMPLEFORMAT_INT) _load_tiff_tiled_separate<int>(tif,samplesperpixel,nx,ny,tw,th);
              else _load_tiff_tiled_separate<float>(tif,samplesperpixel,nx,ny,tw,th);
              break;
            }
        } else {
          if (config==PLANARCONFIG_CONTIG) switch (bitspersample) {
            case 8 :
              if (sampleformat==SAMPLEFORMAT_UINT) _load_tiff_contig<unsigned char>(tif,samplesperpixel,nx,ny);
              else _load_tiff_contig<signed char>(tif,samplesperpixel,nx,ny);
              break;
            case 16 :
              if (sampleformat==SAMPLEFORMAT_UINT) _load_tiff_contig<unsigned short>(tif,samplesperpixel,nx,ny);
              else _load_tiff_contig<short>(tif,samplesperpixel,nx,ny);
              break;
            case 32 :
              if (sampleformat==SAMPLEFORMAT_UINT) _load_tiff_contig<unsigned int>(tif,samplesperpixel,nx,ny);
              else if (sampleformat==SAMPLEFORMAT_INT) _load_tiff_contig<int>(tif,samplesperpixel,nx,ny);
              else _load_tiff_contig<float>(tif,samplesperpixel,nx,ny);
              break;
            } else switch (bitspersample){
            case 8 :
              if (sampleformat==SAMPLEFORMAT_UINT) _load_tiff_separate<unsigned char>(tif,samplesperpixel,nx,ny);
              else _load_tiff_separate<signed char>(tif,samplesperpixel,nx,ny);
              break;
            case 16 :
              if (sampleformat==SAMPLEFORMAT_UINT) _load_tiff_separate<unsigned short>(tif,samplesperpixel,nx,ny);
              else _load_tiff_separate<short>(tif,samplesperpixel,nx,ny);
              break;
            case 32 :
              if (sampleformat==SAMPLEFORMAT_UINT) _load_tiff_separate<unsigned int>(tif,samplesperpixel,nx,ny);
              else if (sampleformat==SAMPLEFORMAT_INT) _load_tiff_separate<int>(tif,samplesperpixel,nx,ny);
              else _load_tiff_separate<float>(tif,samplesperpixel,nx,ny);
              break;
            }
        }
      } else {
        uint32 *const raster = (uint32*)_TIFFmalloc(nx*ny*sizeof(uint32));
        if (!raster) {
          _TIFFfree(raster); TIFFClose(tif);
          throw CImgException(_cimg_instance
                              "load_tiff(): Failed to allocate memory (%s) for file '%s'.",
                              cimg_instance,
                              cimg::strbuffersize(nx*ny*sizeof(uint32)),filename);
        }
        TIFFReadRGBAImage(tif,nx,ny,raster,0);
        switch (spectrum) {
        case 1 : {
          cimg_forXY(*this,x,y) (*this)(x,y) = (T)(float)((raster[nx*(ny-1-y)+x] + 128)/257);
        } break;
        case 3 : {
          cimg_forXY(*this,x,y) {
            (*this)(x,y,0) = (T)(float)TIFFGetR(raster[nx*(ny-1-y)+x]);
            (*this)(x,y,1) = (T)(float)TIFFGetG(raster[nx*(ny-1-y)+x]);
            (*this)(x,y,2) = (T)(float)TIFFGetB(raster[nx*(ny-1-y)+x]);
          }
        } break;
        case 4 : {
          cimg_forXY(*this,x,y) {
            (*this)(x,y,0) = (T)(float)TIFFGetR(raster[nx*(ny-1-y)+x]);
            (*this)(x,y,1) = (T)(float)TIFFGetG(raster[nx*(ny-1-y)+x]);
            (*this)(x,y,2) = (T)(float)TIFFGetB(raster[nx*(ny-1-y)+x]);
            (*this)(x,y,3) = (T)(float)TIFFGetA(raster[nx*(ny-1-y)+x]);
          }
        } break;
        }
        _TIFFfree(raster);
      }
      return *this;
    }
#endif
# 37102 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    //! Load image from a MINC2 file.
    /**
        \param filename Filename, as a C-string.
    **/
    // (Original code by Haz-Edine Assemlal).
    CImg<T>& load_minc2(const char *const filename) {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_minc2(): Specified filename is (null).",
                                    cimg_instance);
#ifndef cimg_use_minc2
      return load_other(filename);
#else
# 37116 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      minc::minc_1_reader rdr;
      rdr.open(filename);
      assign(rdr.ndim(1)?rdr.ndim(1):1,
             rdr.ndim(2)?rdr.ndim(2):1,
             rdr.ndim(3)?rdr.ndim(3):1,
             rdr.ndim(4)?rdr.ndim(4):1);
      if(typeid(T)==typeid(unsigned char))
        rdr.setup_read_byte();
      else if(typeid(T)==typeid(int))
        rdr.setup_read_int();
      else if(typeid(T)==typeid(double))
        rdr.setup_read_double();
      else
        rdr.setup_read_float();
      minc::load_standard_volume(rdr, this->_data);
      return *this;
#endif
# 37133 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    }

    //! Load image from a MINC2 file \newinstance.
    static CImg<T> get_load_minc2(const char *const filename) {
      return CImg<T>().load_analyze(filename);
    }

    //! Load image from an ANALYZE7.5/NIFTI file.
    /**
       \param filename Filename, as a C-string.
       \param[out] voxel_size Pointer to the three voxel sizes read from the file.
    **/
    CImg<T>& load_analyze(const char *const filename, float *const voxel_size=0) {
      return _load_analyze(0,filename,voxel_size);
    }

    //! Load image from an ANALYZE7.5/NIFTI file \newinstance.
    static CImg<T> get_load_analyze(const char *const filename, float *const voxel_size=0) {
      return CImg<T>().load_analyze(filename,voxel_size);
    }

    //! Load image from an ANALYZE7.5/NIFTI file \overloading.
    CImg<T>& load_analyze(std::FILE *const file, float *const voxel_size=0) {
      return _load_analyze(file,0,voxel_size);
    }

    //! Load image from an ANALYZE7.5/NIFTI file \newinstance.
    static CImg<T> get_load_analyze(std::FILE *const file, float *const voxel_size=0) {
      return CImg<T>().load_analyze(file,voxel_size);
    }

    CImg<T>& _load_analyze(std::FILE *const file, const char *const filename, float *const voxel_size=0) {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_analyze(): Specified filename is (null).",
                                    cimg_instance);

      std::FILE *nfile_header = 0, *nfile = 0;
      if (!file) {
        char body[1024] = { 0 };
        const char *const ext = cimg::split_filename(filename,body);
        if (!cimg::strcasecmp(ext,"hdr")) { // File is an Analyze header file.
          nfile_header = cimg::fopen(filename,"rb");
          std::sprintf(body + std::strlen(body),".img");
          nfile = cimg::fopen(body,"rb");
        } else if (!cimg::strcasecmp(ext,"img")) { // File is an Analyze data file.
          nfile = cimg::fopen(filename,"rb");
          std::sprintf(body + std::strlen(body),".hdr");
          nfile_header = cimg::fopen(body,"rb");
        } else nfile_header = nfile = cimg::fopen(filename,"rb"); // File is a Niftii file.
      } else nfile_header = nfile = file; // File is a Niftii file.
      if (!nfile || !nfile_header)
        throw CImgIOException(_cimg_instance
                              "load_analyze(): Invalid Analyze7.5 or NIFTI header in file '%s'.",
                              cimg_instance,
                              filename?filename:"(FILE*)");

      // Read header.
      bool endian = false;
      unsigned int header_size;
      cimg::fread(&header_size,1,nfile_header);
      if (!header_size)
        throw CImgIOException(_cimg_instance
                              "load_analyze(): Invalid zero-sized header in file '%s'.",
                              cimg_instance,
                              filename?filename:"(FILE*)");

      if (header_size>=4096) { endian = true; cimg::invert_endianness(header_size); }
      unsigned char *const header = new unsigned char[header_size];
      cimg::fread(header+4,header_size-4,nfile_header);
      if (!file && nfile_header!=nfile) cimg::fclose(nfile_header);
      if (endian) {
        cimg::invert_endianness((short*)(header+40),5);
        cimg::invert_endianness((short*)(header+70),1);
        cimg::invert_endianness((short*)(header+72),1);
        cimg::invert_endianness((float*)(header+76),4);
        cimg::invert_endianness((float*)(header+112),1);
      }
      unsigned short *dim = (unsigned short*)(header+40), dimx = 1, dimy = 1, dimz = 1, dimv = 1;
      if (!dim[0])
        cimg::warn(_cimg_instance
                   "load_analyze(): File '%s' defines an image with zero dimensions.",
                   cimg_instance,
                   filename?filename:"(FILE*)");

      if (dim[0]>4)
        cimg::warn(_cimg_instance
                   "load_analyze(): File '%s' defines an image with %u dimensions, reading only the 4 first.",
                   cimg_instance,
                   filename?filename:"(FILE*)",dim[0]);

      if (dim[0]>=1) dimx = dim[1];
      if (dim[0]>=2) dimy = dim[2];
      if (dim[0]>=3) dimz = dim[3];
      if (dim[0]>=4) dimv = dim[4];
      float scalefactor = *(float*)(header+112); if (scalefactor==0) scalefactor=1;
      const unsigned short datatype = *(short*)(header+70);
      if (voxel_size) {
        const float *vsize = (float*)(header+76);
        voxel_size[0] = vsize[1]; voxel_size[1] = vsize[2]; voxel_size[2] = vsize[3];
      }
      delete[] header;

      // Read pixel data.
      assign(dimx,dimy,dimz,dimv);
      switch (datatype) {
      case 2 : {
        unsigned char *const buffer = new unsigned char[dimx*dimy*dimz*dimv];
        cimg::fread(buffer,dimx*dimy*dimz*dimv,nfile);
        cimg_foroff(*this,off) _data[off] = (T)(buffer[off]*scalefactor);
        delete[] buffer;
      } break;
      case 4 : {
        short *const buffer = new short[dimx*dimy*dimz*dimv];
        cimg::fread(buffer,dimx*dimy*dimz*dimv,nfile);
        if (endian) cimg::invert_endianness(buffer,dimx*dimy*dimz*dimv);
        cimg_foroff(*this,off) _data[off] = (T)(buffer[off]*scalefactor);
        delete[] buffer;
      } break;
      case 8 : {
        int *const buffer = new int[dimx*dimy*dimz*dimv];
        cimg::fread(buffer,dimx*dimy*dimz*dimv,nfile);
        if (endian) cimg::invert_endianness(buffer,dimx*dimy*dimz*dimv);
        cimg_foroff(*this,off) _data[off] = (T)(buffer[off]*scalefactor);
        delete[] buffer;
      } break;
      case 16 : {
        float *const buffer = new float[dimx*dimy*dimz*dimv];
        cimg::fread(buffer,dimx*dimy*dimz*dimv,nfile);
        if (endian) cimg::invert_endianness(buffer,dimx*dimy*dimz*dimv);
        cimg_foroff(*this,off) _data[off] = (T)(buffer[off]*scalefactor);
        delete[] buffer;
      } break;
      case 64 : {
        double *const buffer = new double[dimx*dimy*dimz*dimv];
        cimg::fread(buffer,dimx*dimy*dimz*dimv,nfile);
        if (endian) cimg::invert_endianness(buffer,dimx*dimy*dimz*dimv);
        cimg_foroff(*this,off) _data[off] = (T)(buffer[off]*scalefactor);
        delete[] buffer;
      } break;
      default :
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimg_instance
                              "load_analyze(): Unable to load datatype %d in file '%s'",
                              cimg_instance,
                              datatype,filename?filename:"(FILE*)");
      }
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Load image from a .cimg[z] file.
    /**
      \param filename Filename, as a C-string.
      \param axis Appending axis, if file contains multiple images. Can be <tt>{ 'x' | 'y' | 'z' | 'c' }</tt>.
      \param align Appending alignment.
    **/
    CImg<T>& load_cimg(const char *const filename, const char axis='z', const float align=0) {
      CImgList<T> list;
      list.load_cimg(filename);
      if (list._width==1) return list[0].move_to(*this);
      return assign(list.get_append(axis,align));
    }

    //! Load image from a .cimg[z] file \newinstance
    static CImg<T> get_load_cimg(const char *const filename, const char axis='z', const float align=0) {
      return CImg<T>().load_cimg(filename,axis,align);
    }

    //! Load image from a .cimg[z] file \overloading.
    CImg<T>& load_cimg(std::FILE *const file, const char axis='z', const float align=0) {
      CImgList<T> list;
      list.load_cimg(file);
      if (list._width==1) return list[0].move_to(*this);
      return assign(list.get_append(axis,align));
    }

    //! Load image from a .cimg[z] file \newinstance
    static CImg<T> get_load_cimg(std::FILE *const file, const char axis='z', const float align=0) {
      return CImg<T>().load_cimg(file,axis,align);
    }

    //! Load sub-images of a .cimg file.
    /**
      \param filename Filename, as a C-string.
      \param n0 Starting frame.
      \param n1 Ending frame (~0U for max).
      \param x0 X-coordinate of the starting sub-image vertex.
      \param y0 Y-coordinate of the starting sub-image vertex.
      \param z0 Z-coordinate of the starting sub-image vertex.
      \param c0 C-coordinate of the starting sub-image vertex.
      \param x1 X-coordinate of the ending sub-image vertex (~0U for max).
      \param y1 Y-coordinate of the ending sub-image vertex (~0U for max).
      \param z1 Z-coordinate of the ending sub-image vertex (~0U for max).
      \param c1 C-coordinate of the ending sub-image vertex (~0U for max).
      \param axis Appending axis, if file contains multiple images. Can be <tt>{ 'x' | 'y' | 'z' | 'c' }</tt>.
      \param align Appending alignment.
    **/
    CImg<T>& load_cimg(const char *const filename,
                       const unsigned int n0, const unsigned int n1,
                       const unsigned int x0, const unsigned int y0, const unsigned int z0, const unsigned int c0,
                       const unsigned int x1, const unsigned int y1, const unsigned int z1, const unsigned int c1,
                       const char axis='z', const float align=0) {
      CImgList<T> list;
      list.load_cimg(filename,n0,n1,x0,y0,z0,c0,x1,y1,z1,c1);
      if (list._width==1) return list[0].move_to(*this);
      return assign(list.get_append(axis,align));
    }

    //! Load sub-images of a .cimg file \newinstance.
    static CImg<T> get_load_cimg(const char *const filename,
                                 const unsigned int n0, const unsigned int n1,
                                 const unsigned int x0, const unsigned int y0, const unsigned int z0, const unsigned int c0,
                                 const unsigned int x1, const unsigned int y1, const unsigned int z1, const unsigned int c1,
                                 const char axis='z', const float align=0) {
      return CImg<T>().load_cimg(filename,n0,n1,x0,y0,z0,c0,x1,y1,z1,c1,axis,align);
    }

    //! Load sub-images of a .cimg file \overloading.
    CImg<T>& load_cimg(std::FILE *const file,
                       const unsigned int n0, const unsigned int n1,
                       const unsigned int x0, const unsigned int y0, const unsigned int z0, const unsigned int c0,
                       const unsigned int x1, const unsigned int y1, const unsigned int z1, const unsigned int c1,
                       const char axis='z', const float align=0) {
      CImgList<T> list;
      list.load_cimg(file,n0,n1,x0,y0,z0,c0,x1,y1,z1,c1);
      if (list._width==1) return list[0].move_to(*this);
      return assign(list.get_append(axis,align));
    }

    //! Load sub-images of a .cimg file \newinstance.
    static CImg<T> get_load_cimg(std::FILE *const file,
                                 const unsigned int n0, const unsigned int n1,
                                 const unsigned int x0, const unsigned int y0, const unsigned int z0, const unsigned int c0,
                                 const unsigned int x1, const unsigned int y1, const unsigned int z1, const unsigned int c1,
                                 const char axis='z', const float align=0) {
      return CImg<T>().load_cimg(file,n0,n1,x0,y0,z0,c0,x1,y1,z1,c1,axis,align);
    }

    //! Load image from an INRIMAGE-4 file.
    /**
       \param filename Filename, as a C-string.
       \param[out] voxel_size Pointer to the three voxel sizes read from the file.
    **/
    CImg<T>& load_inr(const char *const filename, float *const voxel_size=0) {
      return _load_inr(0,filename,voxel_size);
    }

    //! Load image from an INRIMAGE-4 file \newinstance.
    static CImg<T> get_load_inr(const char *const filename, float *const voxel_size=0) {
      return CImg<T>().load_inr(filename,voxel_size);
    }

    //! Load image from an INRIMAGE-4 file \overloading.
    CImg<T>& load_inr(std::FILE *const file, float *const voxel_size=0) {
      return _load_inr(file,0,voxel_size);
    }

    //! Load image from an INRIMAGE-4 file \newinstance.
    static CImg<T> get_load_inr(std::FILE *const file, float *voxel_size=0) {
      return CImg<T>().load_inr(file,voxel_size);
    }

    static void _load_inr_header(std::FILE *file, int out[8], float *const voxel_size) {
      char item[1024] = { 0 }, tmp1[64] = { 0 }, tmp2[64] = { 0 };
      out[0] = std::fscanf(file,"%63s",item);
      out[0] = out[1] = out[2] = out[3] = out[5] = 1; out[4] = out[6] = out[7] = -1;
      if(cimg::strncasecmp(item,"#INRIMAGE-4#{",13)!=0)
        throw CImgIOException("CImg<%s>::load_inr(): INRIMAGE-4 header not found.",
                              pixel_type());

      while (std::fscanf(file," %63[^\n]%*c",item)!=EOF && std::strncmp(item,"##}",3)) {
        std::sscanf(item," XDIM%*[^0-9]%d",out);
        std::sscanf(item," YDIM%*[^0-9]%d",out+1);
        std::sscanf(item," ZDIM%*[^0-9]%d",out+2);
        std::sscanf(item," VDIM%*[^0-9]%d",out+3);
        std::sscanf(item," PIXSIZE%*[^0-9]%d",out+6);
        if (voxel_size) {
          std::sscanf(item," VX%*[^0-9.+-]%f",voxel_size);
          std::sscanf(item," VY%*[^0-9.+-]%f",voxel_size+1);
          std::sscanf(item," VZ%*[^0-9.+-]%f",voxel_size+2);
        }
        if (std::sscanf(item," CPU%*[ =]%s",tmp1)) out[7]=cimg::strncasecmp(tmp1,"sun",3)?0:1;
        switch (std::sscanf(item," TYPE%*[ =]%s %s",tmp1,tmp2)) {
        case 0 : break;
        case 2 : out[5] = cimg::strncasecmp(tmp1,"unsigned",8)?1:0; std::strncpy(tmp1,tmp2,sizeof(tmp1)-1);
        case 1 :
          if (!cimg::strncasecmp(tmp1,"int",3)   || !cimg::strncasecmp(tmp1,"fixed",5))  out[4] = 0;
          if (!cimg::strncasecmp(tmp1,"float",5) || !cimg::strncasecmp(tmp1,"double",6)) out[4] = 1;
          if (!cimg::strncasecmp(tmp1,"packed",6))                                       out[4] = 2;
          if (out[4]>=0) break;
        default :
          throw CImgIOException("CImg<%s>::load_inr(): Invalid pixel type '%s' defined in header.",
                                pixel_type(),
                                tmp2);
        }
      }
      if(out[0]<0 || out[1]<0 || out[2]<0 || out[3]<0)
        throw CImgIOException("CImg<%s>::load_inr(): Invalid dimensions (%d,%d,%d,%d) defined in header.",
                              pixel_type(),
                              out[0],out[1],out[2],out[3]);
      if(out[4]<0 || out[5]<0)
        throw CImgIOException("CImg<%s>::load_inr(): Incomplete pixel type defined in header.",
                              pixel_type());
      if(out[6]<0)
        throw CImgIOException("CImg<%s>::load_inr(): Incomplete PIXSIZE field defined in header.",
                              pixel_type());
      if(out[7]<0)
        throw CImgIOException("CImg<%s>::load_inr(): Big/Little Endian coding type undefined in header.",
                              pixel_type());
    }

    CImg<T>& _load_inr(std::FILE *const file, const char *const filename, float *const voxel_size) {
#define _cimg_load_inr_case(Tf,sign,pixsize,Ts) \
     if (!loaded && fopt[6]==pixsize && fopt[4]==Tf && fopt[5]==sign) { \
        Ts *xval, *const val = new Ts[fopt[0]*fopt[3]]; \
        cimg_forYZ(*this,y,z) { \
            cimg::fread(val,fopt[0]*fopt[3],nfile); \
            if (fopt[7]!=endian) cimg::invert_endianness(val,fopt[0]*fopt[3]); \
            xval = val; cimg_forX(*this,x) cimg_forC(*this,c) (*this)(x,y,z,c) = (T)*(xval++); \
          } \
        delete[] val; \
        loaded = true; \
      }

      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_inr(): Specified filename is (null).",
                                    cimg_instance);

      std::FILE *const nfile = file?file:cimg::fopen(filename,"rb");
      int fopt[8], endian=cimg::endianness()?1:0;
      bool loaded = false;
      if (voxel_size) voxel_size[0] = voxel_size[1] = voxel_size[2] = 1;
      _load_inr_header(nfile,fopt,voxel_size);
      assign(fopt[0],fopt[1],fopt[2],fopt[3]);
      _cimg_load_inr_case(0,0,8,unsigned char);
      _cimg_load_inr_case(0,1,8,char);
      _cimg_load_inr_case(0,0,16,unsigned short);
      _cimg_load_inr_case(0,1,16,short);
      _cimg_load_inr_case(0,0,32,unsigned int);
      _cimg_load_inr_case(0,1,32,int);
      _cimg_load_inr_case(1,0,32,float);
      _cimg_load_inr_case(1,1,32,float);
      _cimg_load_inr_case(1,0,64,double);
      _cimg_load_inr_case(1,1,64,double);
      if (!loaded) {
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimg_instance
                              "load_inr(): Unknown pixel type defined in file '%s'.",
                              cimg_instance,
                              filename?filename:"(FILE*)");
      }
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Load image from a EXR file.
    /**
      \param filename Filename, as a C-string.
    **/
    CImg<T>& load_exr(const char *const filename) {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_exr(): Specified filename is (null).",
                                    cimg_instance);

#ifndef cimg_use_openexr
      return load_other(filename);
#else
# 37503 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      Imf::RgbaInputFile file(filename);
      Imath::Box2i dw = file.dataWindow();
      const int
        inwidth = dw.max.x - dw.min.x + 1,
        inheight = dw.max.y - dw.min.y + 1;
      Imf::Array2D<Imf::Rgba> pixels;
      pixels.resizeErase(inheight,inwidth);
      file.setFrameBuffer(&pixels[0][0] - dw.min.x - dw.min.y*inwidth, 1, inwidth);
      file.readPixels(dw.min.y, dw.max.y);
      assign(inwidth,inheight,1,4);
      T *ptr_r = data(0,0,0,0), *ptr_g = data(0,0,0,1), *ptr_b = data(0,0,0,2), *ptr_a = data(0,0,0,3);
      cimg_forXY(*this,x,y) {
        *(ptr_r++) = (T)pixels[y][x].r;
        *(ptr_g++) = (T)pixels[y][x].g;
        *(ptr_b++) = (T)pixels[y][x].b;
        *(ptr_a++) = (T)pixels[y][x].a;
      }
      return *this;
#endif
# 37522 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    }

    //! Load image from a EXR file \newinstance.
    static CImg<T> get_load_exr(const char *const filename) {
      return CImg<T>().load_exr(filename);
    }

    //! Load image from a PANDORE-5 file.
    /**
      \param filename Filename, as a C-string.
    **/
    CImg<T>& load_pandore(const char *const filename) {
      return _load_pandore(0,filename);
    }

    //! Load image from a PANDORE-5 file \newinstance.
    static CImg<T> get_load_pandore(const char *const filename) {
      return CImg<T>().load_pandore(filename);
    }

    //! Load image from a PANDORE-5 file \overloading.
    CImg<T>& load_pandore(std::FILE *const file) {
      return _load_pandore(file,0);
    }

    //! Load image from a PANDORE-5 file \newinstance.
    static CImg<T> get_load_pandore(std::FILE *const file) {
      return CImg<T>().load_pandore(file);
    }

    CImg<T>& _load_pandore(std::FILE *const file, const char *const filename) {
#define __cimg_load_pandore_case(nbdim,nwidth,nheight,ndepth,ndim,stype) \
        cimg::fread(dims,nbdim,nfile); \
        if (endian) cimg::invert_endianness(dims,nbdim); \
        assign(nwidth,nheight,ndepth,ndim); \
        const unsigned int siz = size(); \
        stype *buffer = new stype[siz]; \
        cimg::fread(buffer,siz,nfile); \
        if (endian) cimg::invert_endianness(buffer,siz); \
        T *ptrd = _data; \
        cimg_foroff(*this,off) *(ptrd++) = (T)*(buffer++); \
        buffer-=siz; \
        delete[] buffer

#define _cimg_load_pandore_case(nbdim,nwidth,nheight,ndepth,dim,stype1,stype2,stype3,ltype) { \
        if (sizeof(stype1)==ltype) { __cimg_load_pandore_case(nbdim,nwidth,nheight,ndepth,dim,stype1); } \
        else if (sizeof(stype2)==ltype) { __cimg_load_pandore_case(nbdim,nwidth,nheight,ndepth,dim,stype2); } \
        else if (sizeof(stype3)==ltype) { __cimg_load_pandore_case(nbdim,nwidth,nheight,ndepth,dim,stype3); } \
        else throw CImgIOException(_cimg_instance \
                                   "load_pandore(): Unknown pixel datatype in file '%s'.", \
                                   cimg_instance, \
                                   filename?filename:"(FILE*)"); }

      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_pandore(): Specified filename is (null).",
                                    cimg_instance);

      std::FILE *const nfile = file?file:cimg::fopen(filename,"rb");
      char header[32] = { 0 };
      cimg::fread(header,12,nfile);
      if (cimg::strncasecmp("PANDORE",header,7)) {
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimg_instance
                              "load_pandore(): PANDORE header not found in file '%s'.",
                              cimg_instance,
                              filename?filename:"(FILE*)");
      }
      unsigned int imageid, dims[8] = { 0 };
      cimg::fread(&imageid,1,nfile);
      const bool endian = (imageid>255);
      if (endian) cimg::invert_endianness(imageid);
      cimg::fread(header,20,nfile);

      switch (imageid) {
      case 2: _cimg_load_pandore_case(2,dims[1],1,1,1,unsigned char,unsigned char,unsigned char,1); break;
      case 3: _cimg_load_pandore_case(2,dims[1],1,1,1,long,int,short,4); break;
      case 4: _cimg_load_pandore_case(2,dims[1],1,1,1,double,float,float,4); break;
      case 5: _cimg_load_pandore_case(3,dims[2],dims[1],1,1,unsigned char,unsigned char,unsigned char,1); break;
      case 6: _cimg_load_pandore_case(3,dims[2],dims[1],1,1,long,int,short,4); break;
      case 7: _cimg_load_pandore_case(3,dims[2],dims[1],1,1,double,float,float,4); break;
      case 8: _cimg_load_pandore_case(4,dims[3],dims[2],dims[1],1,unsigned char,unsigned char,unsigned char,1); break;
      case 9: _cimg_load_pandore_case(4,dims[3],dims[2],dims[1],1,long,int,short,4); break;
      case 10: _cimg_load_pandore_case(4,dims[3],dims[2],dims[1],1,double,float,float,4); break;
      case 11 : { // Region 1d
        cimg::fread(dims,3,nfile);
        if (endian) cimg::invert_endianness(dims,3);
        assign(dims[1],1,1,1);
        const unsigned siz = size();
        if (dims[2]<256) {
          unsigned char *buffer = new unsigned char[siz];
          cimg::fread(buffer,siz,nfile);
          T *ptrd = _data;
          cimg_foroff(*this,off) *(ptrd++) = (T)*(buffer++);
          buffer-=siz;
          delete[] buffer;
        } else {
          if (dims[2]<65536) {
            unsigned short *buffer = new unsigned short[siz];
            cimg::fread(buffer,siz,nfile);
            if (endian) cimg::invert_endianness(buffer,siz);
            T *ptrd = _data;
            cimg_foroff(*this,off) *(ptrd++) = (T)*(buffer++);
            buffer-=siz;
            delete[] buffer;
          } else {
            unsigned int *buffer = new unsigned int[siz];
            cimg::fread(buffer,siz,nfile);
            if (endian) cimg::invert_endianness(buffer,siz);
            T *ptrd = _data;
            cimg_foroff(*this,off) *(ptrd++) = (T)*(buffer++);
            buffer-=siz;
            delete[] buffer;
          }
        }
      }
        break;
      case 12 : { // Region 2d
        cimg::fread(dims,4,nfile);
        if (endian) cimg::invert_endianness(dims,4);
        assign(dims[2],dims[1],1,1);
        const unsigned int siz = size();
        if (dims[3]<256) {
          unsigned char *buffer = new unsigned char[siz];
          cimg::fread(buffer,siz,nfile);
          T *ptrd = _data;
          cimg_foroff(*this,off) *(ptrd++) = (T)*(buffer++);
          buffer-=siz;
          delete[] buffer;
        } else {
          if (dims[3]<65536) {
            unsigned short *buffer = new unsigned short[siz];
            cimg::fread(buffer,siz,nfile);
            if (endian) cimg::invert_endianness(buffer,siz);
            T *ptrd = _data;
            cimg_foroff(*this,off) *(ptrd++) = (T)*(buffer++);
            buffer-=siz;
            delete[] buffer;
          } else {
            unsigned long *buffer = new unsigned long[siz];
            cimg::fread(buffer,siz,nfile);
            if (endian) cimg::invert_endianness(buffer,siz);
            T *ptrd = _data;
            cimg_foroff(*this,off) *(ptrd++) = (T)*(buffer++);
            buffer-=siz;
            delete[] buffer;
          }
        }
      }
        break;
      case 13 : { // Region 3d
        cimg::fread(dims,5,nfile);
        if (endian) cimg::invert_endianness(dims,5);
        assign(dims[3],dims[2],dims[1],1);
        const unsigned int siz = size();
        if (dims[4]<256) {
          unsigned char *buffer = new unsigned char[siz];
          cimg::fread(buffer,siz,nfile);
          T *ptrd = _data;
          cimg_foroff(*this,off) *(ptrd++) = (T)*(buffer++);
          buffer-=siz;
          delete[] buffer;
        } else {
          if (dims[4]<65536) {
            unsigned short *buffer = new unsigned short[siz];
            cimg::fread(buffer,siz,nfile);
            if (endian) cimg::invert_endianness(buffer,siz);
            T *ptrd = _data;
            cimg_foroff(*this,off) *(ptrd++) = (T)*(buffer++);
            buffer-=siz;
            delete[] buffer;
          } else {
            unsigned int *buffer = new unsigned int[siz];
            cimg::fread(buffer,siz,nfile);
            if (endian) cimg::invert_endianness(buffer,siz);
            T *ptrd = _data;
            cimg_foroff(*this,off) *(ptrd++) = (T)*(buffer++);
            buffer-=siz;
            delete[] buffer;
          }
        }
      }
        break;
      case 16: _cimg_load_pandore_case(4,dims[2],dims[1],1,3,unsigned char,unsigned char,unsigned char,1); break;
      case 17: _cimg_load_pandore_case(4,dims[2],dims[1],1,3,long,int,short,4); break;
      case 18: _cimg_load_pandore_case(4,dims[2],dims[1],1,3,double,float,float,4); break;
      case 19: _cimg_load_pandore_case(5,dims[3],dims[2],dims[1],3,unsigned char,unsigned char,unsigned char,1); break;
      case 20: _cimg_load_pandore_case(5,dims[3],dims[2],dims[1],3,long,int,short,4); break;
      case 21: _cimg_load_pandore_case(5,dims[3],dims[2],dims[1],3,double,float,float,4); break;
      case 22: _cimg_load_pandore_case(2,dims[1],1,1,dims[0],unsigned char,unsigned char,unsigned char,1); break;
      case 23: _cimg_load_pandore_case(2,dims[1],1,1,dims[0],long,int,short,4);
      case 24: _cimg_load_pandore_case(2,dims[1],1,1,dims[0],unsigned long,unsigned int,unsigned short,4); break;
      case 25: _cimg_load_pandore_case(2,dims[1],1,1,dims[0],double,float,float,4); break;
      case 26: _cimg_load_pandore_case(3,dims[2],dims[1],1,dims[0],unsigned char,unsigned char,unsigned char,1); break;
      case 27: _cimg_load_pandore_case(3,dims[2],dims[1],1,dims[0],long,int,short,4); break;
      case 28: _cimg_load_pandore_case(3,dims[2],dims[1],1,dims[0],unsigned long,unsigned int,unsigned short,4); break;
      case 29: _cimg_load_pandore_case(3,dims[2],dims[1],1,dims[0],double,float,float,4); break;
      case 30: _cimg_load_pandore_case(4,dims[3],dims[2],dims[1],dims[0],unsigned char,unsigned char,unsigned char,1); break;
      case 31: _cimg_load_pandore_case(4,dims[3],dims[2],dims[1],dims[0],long,int,short,4); break;
      case 32: _cimg_load_pandore_case(4,dims[3],dims[2],dims[1],dims[0],unsigned long,unsigned int,unsigned short,4); break;
      case 33: _cimg_load_pandore_case(4,dims[3],dims[2],dims[1],dims[0],double,float,float,4); break;
      case 34 : { // Points 1d
        int ptbuf[4] = { 0 };
        cimg::fread(ptbuf,1,nfile);
        if (endian) cimg::invert_endianness(ptbuf,1);
        assign(1); (*this)(0) = (T)ptbuf[0];
      } break;
      case 35 : { // Points 2d
        int ptbuf[4] = { 0 };
        cimg::fread(ptbuf,2,nfile);
        if (endian) cimg::invert_endianness(ptbuf,2);
        assign(2); (*this)(0) = (T)ptbuf[1]; (*this)(1) = (T)ptbuf[0];
      } break;
      case 36 : { // Points 3d
        int ptbuf[4] = { 0 };
        cimg::fread(ptbuf,3,nfile);
        if (endian) cimg::invert_endianness(ptbuf,3);
        assign(3); (*this)(0) = (T)ptbuf[2]; (*this)(1) = (T)ptbuf[1]; (*this)(2) = (T)ptbuf[0];
      } break;
      default :
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimg_instance
                              "load_pandore(): Unable to load data with ID_type %u in file '%s'.",
                              cimg_instance,
                              imageid,filename?filename:"(FILE*)");
      }
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Load image from a PAR-REC (Philips) file.
    /**
      \param filename Filename, as a C-string.
      \param axis Appending axis, if file contains multiple images. Can be <tt>{ 'x' | 'y' | 'z' | 'c' }</tt>.
      \param align Appending alignment.
    **/
    CImg<T>& load_parrec(const char *const filename, const char axis='c', const float align=0) {
      CImgList<T> list;
      list.load_parrec(filename);
      if (list._width==1) return list[0].move_to(*this);
      return assign(list.get_append(axis,align));
    }

    //! Load image from a PAR-REC (Philips) file \newinstance.
    static CImg<T> get_load_parrec(const char *const filename, const char axis='c', const float align=0) {
      return CImg<T>().load_parrec(filename,axis,align);
    }

    //! Load image from a raw binary file.
    /**
      \param filename Filename, as a C-string.
      \param size_x Width of the image buffer.
      \param size_y Height of the image buffer.
      \param size_z Depth of the image buffer.
      \param size_c Spectrum of the image buffer.
      \param is_multiplexed Tells if the image values are multiplexed along the C-axis.
      \param invert_endianness Tells if the endianness of the image buffer must be inverted.
      \param offset Starting offset of the read in the specified file.
    **/
    CImg<T>& load_raw(const char *const filename,
                      const unsigned int size_x=0, const unsigned int size_y=1,
                      const unsigned int size_z=1, const unsigned int size_c=1,
                      const bool is_multiplexed=false, const bool invert_endianness=false,
                      const unsigned long offset=0) {
      return _load_raw(0,filename,size_x,size_y,size_z,size_c,is_multiplexed,invert_endianness,offset);
    }

    //! Load image from a raw binary file \newinstance.
    static CImg<T> get_load_raw(const char *const filename,
                                const unsigned int size_x=0, const unsigned int size_y=1,
                                const unsigned int size_z=1, const unsigned int size_c=1,
                                const bool is_multiplexed=false, const bool invert_endianness=false,
                                const unsigned long offset=0) {
      return CImg<T>().load_raw(filename,size_x,size_y,size_z,size_c,is_multiplexed,invert_endianness,offset);
    }

    //! Load image from a raw binary file \overloading.
    CImg<T>& load_raw(std::FILE *const file,
                      const unsigned int size_x=0, const unsigned int size_y=1,
                      const unsigned int size_z=1, const unsigned int size_c=1,
                      const bool is_multiplexed=false, const bool invert_endianness=false,
                      const unsigned long offset=0) {
      return _load_raw(file,0,size_x,size_y,size_z,size_c,is_multiplexed,invert_endianness,offset);
    }

    //! Load image from a raw binary file \newinstance.
    static CImg<T> get_load_raw(std::FILE *const file,
                                const unsigned int size_x=0, const unsigned int size_y=1,
                                const unsigned int size_z=1, const unsigned int size_c=1,
                                const bool is_multiplexed=false, const bool invert_endianness=false,
                                const unsigned long offset=0) {
      return CImg<T>().load_raw(file,size_x,size_y,size_z,size_c,is_multiplexed,invert_endianness,offset);
    }

    CImg<T>& _load_raw(std::FILE *const file, const char *const filename,
		       const unsigned int size_x, const unsigned int size_y,
		       const unsigned int size_z, const unsigned int size_c,
		       const bool is_multiplexed, const bool invert_endianness,
                       const unsigned long offset) {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_raw(): Specified filename is (null).",
                                    cimg_instance);
      unsigned int siz = size_x*size_y*size_z*size_c, _size_x = size_x, _size_y = size_y, _size_z = size_z, _size_c = size_c;
      std::FILE *const nfile = file?file:cimg::fopen(filename,"rb");
      if (!siz) {  // Retrieve file size.
        const long fpos = std::ftell(nfile);
        if (fpos<0) throw CImgArgumentException(_cimg_instance
                                                "load_raw(): Cannot determine size of input file '%s'.",
                                                cimg_instance,filename?filename:"(FILE*)");
        std::fseek(nfile,0,SEEK_END);
        siz = _size_y = (unsigned int)std::ftell(nfile)/sizeof(T);
        _size_x = _size_z = _size_c = 1;
        std::fseek(nfile,fpos,SEEK_SET);
      }
      std::fseek(nfile,(long)offset,SEEK_SET);
      assign(_size_x,_size_y,_size_z,_size_c,0);
      if (!is_multiplexed || size_c==1) {
        cimg::fread(_data,siz,nfile);
        if (invert_endianness) cimg::invert_endianness(_data,siz);
      } else {
        CImg<T> buf(1,1,1,_size_c);
        cimg_forXYZ(*this,x,y,z) {
          cimg::fread(buf._data,_size_c,nfile);
          if (invert_endianness) cimg::invert_endianness(buf._data,_size_c);
          set_vector_at(buf,x,y,z);
        }
      }
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Load image sequence using FFMPEG av's libraries.
    /**
      \param filename Filename, as a C-string.
      \param first_frame Index of the first frame to read.
      \param last_frame Index of the last frame to read.
      \param step_frame Step value for frame reading.
      \param pixel_format To be documented.
      \param resume To be documented.
      \param axis Appending axis, if file contains multiple images. Can be <tt>{ 'x' | 'y' | 'z' | 'c' }</tt>.
      \param align Appending alignment.
    **/
    CImg<T>& load_ffmpeg(const char *const filename, const unsigned int first_frame=0, const unsigned int last_frame=~0U,
			 const unsigned int step_frame=1, const bool pixel_format=true, const bool resume=false,
			 const char axis='z', const float align=0) {
      return get_load_ffmpeg(filename,first_frame,last_frame,step_frame,pixel_format,resume,axis,align).move_to(*this);
    }

    //! Load image sequence using FFMPEG av's libraries \newinstance.
    static CImg<T> get_load_ffmpeg(const char *const filename, const unsigned int first_frame=0, const unsigned int last_frame=~0U,
				   const unsigned int step_frame=1, const bool pixel_format=true, const bool resume=false,
				   const char axis='z', const float align=0) {
      return CImgList<T>().load_ffmpeg(filename,first_frame,last_frame,step_frame,pixel_format,resume).get_append(axis,align);
    }

    //! Load image sequence from a YUV file.
    /**
      \param filename Filename, as a C-string.
      \param size_x Width of the frames.
      \param size_y Height of the frames.
      \param first_frame Index of the first frame to read.
      \param last_frame Index of the last frame to read.
      \param step_frame Step value for frame reading.
      \param yuv2rgb Tells if the YUV to RGB transform must be applied.
      \param axis Appending axis, if file contains multiple images. Can be <tt>{ 'x' | 'y' | 'z' | 'c' }</tt>.
    **/
    CImg<T>& load_yuv(const char *const filename,
                      const unsigned int size_x, const unsigned int size_y=1,
                      const unsigned int first_frame=0, const unsigned int last_frame=~0U,
                      const unsigned int step_frame=1, const bool yuv2rgb=true, const char axis='z') {
      return get_load_yuv(filename,size_x,size_y,first_frame,last_frame,step_frame,yuv2rgb,axis).move_to(*this);
    }

    //! Load image sequence from a YUV file \newinstance.
    static CImg<T> get_load_yuv(const char *const filename,
                                const unsigned int size_x, const unsigned int size_y=1,
                                const unsigned int first_frame=0, const unsigned int last_frame=~0U,
                                const unsigned int step_frame=1, const bool yuv2rgb=true, const char axis='z') {
      return CImgList<T>().load_yuv(filename,size_x,size_y,first_frame,last_frame,step_frame,yuv2rgb).get_append(axis);
    }

    //! Load image sequence from a YUV file \overloading.
    CImg<T>& load_yuv(std::FILE *const file,
                      const unsigned int size_x, const unsigned int size_y=1,
                      const unsigned int first_frame=0, const unsigned int last_frame=~0U,
		      const unsigned int step_frame=1, const bool yuv2rgb=true, const char axis='z') {
      return get_load_yuv(file,size_x,size_y,first_frame,last_frame,step_frame,yuv2rgb,axis).move_to(*this);
    }

    //! Load image sequence from a YUV file \newinstance.
    static CImg<T> get_load_yuv(std::FILE *const file,
                                const unsigned int size_x, const unsigned int size_y=1,
                                const unsigned int first_frame=0, const unsigned int last_frame=~0U,
				const unsigned int step_frame=1, const bool yuv2rgb=true, const char axis='z') {
      return CImgList<T>().load_yuv(file,size_x,size_y,first_frame,last_frame,step_frame,yuv2rgb).get_append(axis);
    }

    //! Load 3d object from a .OFF file.
    /**
        \param[out] primitives Primitives data of the 3d object.
        \param[out] colors Colors data of the 3d object.
        \param filename Filename, as a C-string.
    **/
    template<typename tf, typename tc>
    CImg<T>& load_off(CImgList<tf>& primitives, CImgList<tc>& colors, const char *const filename) {
      return _load_off(primitives,colors,0,filename);
    }

    //! Load 3d object from a .OFF file \newinstance.
    template<typename tf, typename tc>
    static CImg<T> get_load_off(CImgList<tf>& primitives, CImgList<tc>& colors, const char *const filename) {
      return CImg<T>().load_off(primitives,colors,filename);
    }

    //! Load 3d object from a .OFF file \overloading.
    template<typename tf, typename tc>
    CImg<T>& load_off(CImgList<tf>& primitives, CImgList<tc>& colors, std::FILE *const file) {
      return _load_off(primitives,colors,file,0);
    }

    //! Load 3d object from a .OFF file \newinstance.
    template<typename tf, typename tc>
    static CImg<T> get_load_off(CImgList<tf>& primitives, CImgList<tc>& colors, std::FILE *const file) {
      return CImg<T>().load_off(primitives,colors,file);
    }

    template<typename tf, typename tc>
    CImg<T>& _load_off(CImgList<tf>& primitives, CImgList<tc>& colors,
                       std::FILE *const file, const char *const filename) {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_off(): Specified filename is (null).",
                                    cimg_instance);

      std::FILE *const nfile = file?file:cimg::fopen(filename,"r");
      unsigned int nb_points = 0, nb_primitives = 0, nb_read = 0;
      char line[256] = { 0 };
      int err;

      // Skip comments, and read magic string OFF
      do { err = std::fscanf(nfile,"%255[^\n] ",line); } while (!err || (err==1 && *line=='#'));
      if (cimg::strncasecmp(line,"OFF",3) && cimg::strncasecmp(line,"COFF",4)) {
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimg_instance
                              "load_off(): OFF header not found in file '%s'.",
                              cimg_instance,
                              filename?filename:"(FILE*)");
      }
      do { err = std::fscanf(nfile,"%255[^\n] ",line); } while (!err || (err==1 && *line=='#'));
      if ((err = std::sscanf(line,"%u%u%*[^\n] ",&nb_points,&nb_primitives))!=2) {
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimg_instance
                              "load_off(): Invalid number of vertices or primitives specified in file '%s'.",
                              cimg_instance,
                              filename?filename:"(FILE*)");
      }

      // Read points data
      assign(nb_points,3);
      float X = 0, Y = 0, Z = 0;
      cimg_forX(*this,l) {
        do { err = std::fscanf(nfile,"%255[^\n] ",line); } while (!err || (err==1 && *line=='#'));
        if ((err = std::sscanf(line,"%f%f%f%*[^\n] ",&X,&Y,&Z))!=3) {
          if (!file) cimg::fclose(nfile);
          throw CImgIOException(_cimg_instance
                                "load_off(): Failed to read vertex %u/%u in file '%s'.",
                                cimg_instance,
                                l+1,nb_points,filename?filename:"(FILE*)");
        }
        (*this)(l,0) = (T)X; (*this)(l,1) = (T)Y; (*this)(l,2) = (T)Z;
      }

      // Read primitive data
      primitives.assign();
      colors.assign();
      bool stop_flag = false;
      while (!stop_flag) {
        float c0 = 0.7f, c1 = 0.7f, c2 = 0.7f;
        unsigned int prim = 0, i0 = 0, i1 = 0, i2 = 0, i3 = 0, i4 = 0, i5 = 0, i6 = 0, i7 = 0;
        *line = 0;
        if ((err = std::fscanf(nfile,"%u",&prim))!=1) stop_flag = true;
        else {
          ++nb_read;
          switch (prim) {
          case 1 : {
            if ((err = std::fscanf(nfile,"%u%255[^\n] ",&i0,line))<2) {
              cimg::warn(_cimg_instance
                         "load_off(): Failed to read primitive %u/%u from file '%s'.",
                         cimg_instance,
                         nb_read,nb_primitives,filename?filename:"(FILE*)");

              err = std::fscanf(nfile,"%*[^\n] ");
            } else {
              err = std::sscanf(line,"%f%f%f",&c0,&c1,&c2);
              CImg<tf>::vector(i0).move_to(primitives);
              CImg<tc>::vector((tc)(c0*255),(tc)(c1*255),(tc)(c2*255)).move_to(colors);
            }
          } break;
          case 2 : {
            if ((err = std::fscanf(nfile,"%u%u%255[^\n] ",&i0,&i1,line))<2) {
              cimg::warn(_cimg_instance
                         "load_off(): Failed to read primitive %u/%u from file '%s'.",
                         cimg_instance,
                         nb_read,nb_primitives,filename?filename:"(FILE*)");

              err = std::fscanf(nfile,"%*[^\n] ");
            } else {
              err = std::sscanf(line,"%f%f%f",&c0,&c1,&c2);
              CImg<tf>::vector(i0,i1).move_to(primitives);
              CImg<tc>::vector((tc)(c0*255),(tc)(c1*255),(tc)(c2*255)).move_to(colors);
            }
          } break;
          case 3 : {
            if ((err = std::fscanf(nfile,"%u%u%u%255[^\n] ",&i0,&i1,&i2,line))<3) {
              cimg::warn(_cimg_instance
                         "load_off(): Failed to read primitive %u/%u from file '%s'.",
                         cimg_instance,
                         nb_read,nb_primitives,filename?filename:"(FILE*)");

              err = std::fscanf(nfile,"%*[^\n] ");
            } else {
              err = std::sscanf(line,"%f%f%f",&c0,&c1,&c2);
              CImg<tf>::vector(i0,i2,i1).move_to(primitives);
              CImg<tc>::vector((tc)(c0*255),(tc)(c1*255),(tc)(c2*255)).move_to(colors);
            }
          } break;
          case 4 : {
            if ((err = std::fscanf(nfile,"%u%u%u%u%255[^\n] ",&i0,&i1,&i2,&i3,line))<4) {
              cimg::warn(_cimg_instance
                         "load_off(): Failed to read primitive %u/%u from file '%s'.",
                         cimg_instance,
                         nb_read,nb_primitives,filename?filename:"(FILE*)");

              err = std::fscanf(nfile,"%*[^\n] ");
            } else {
              err = std::sscanf(line,"%f%f%f",&c0,&c1,&c2);
              CImg<tf>::vector(i0,i3,i2,i1).move_to(primitives);
              CImg<tc>::vector((tc)(c0*255),(tc)(c1*255),(tc)(c2*255)).move_to(colors);
            }
          } break;
          case 5 : {
            if ((err = std::fscanf(nfile,"%u%u%u%u%u%255[^\n] ",&i0,&i1,&i2,&i3,&i4,line))<5) {
              cimg::warn(_cimg_instance
                         "load_off(): Failed to read primitive %u/%u from file '%s'.",
                         cimg_instance,
                         nb_read,nb_primitives,filename?filename:"(FILE*)");

              err = std::fscanf(nfile,"%*[^\n] ");
            } else {
              err = std::sscanf(line,"%f%f%f",&c0,&c1,&c2);
              CImg<tf>::vector(i0,i3,i2,i1).move_to(primitives);
              CImg<tf>::vector(i0,i4,i3).move_to(primitives);
              colors.insert(2,CImg<tc>::vector((tc)(c0*255),(tc)(c1*255),(tc)(c2*255)));
              ++nb_primitives;
            }
          } break;
          case 6 : {
            if ((err = std::fscanf(nfile,"%u%u%u%u%u%u%255[^\n] ",&i0,&i1,&i2,&i3,&i4,&i5,line))<6) {
              cimg::warn(_cimg_instance
                         "load_off(): Failed to read primitive %u/%u from file '%s'.",
                         cimg_instance,
                         nb_read,nb_primitives,filename?filename:"(FILE*)");

              err = std::fscanf(nfile,"%*[^\n] ");
            } else {
              err = std::sscanf(line,"%f%f%f",&c0,&c1,&c2);
              CImg<tf>::vector(i0,i3,i2,i1).move_to(primitives);
              CImg<tf>::vector(i0,i5,i4,i3).move_to(primitives);
              colors.insert(2,CImg<tc>::vector((tc)(c0*255),(tc)(c1*255),(tc)(c2*255)));
              ++nb_primitives;
            }
          } break;
          case 7 : {
            if ((err = std::fscanf(nfile,"%u%u%u%u%u%u%u%255[^\n] ",&i0,&i1,&i2,&i3,&i4,&i5,&i6,line))<7) {
              cimg::warn(_cimg_instance
                         "load_off(): Failed to read primitive %u/%u from file '%s'.",
                         cimg_instance,
                         nb_read,nb_primitives,filename?filename:"(FILE*)");

              err = std::fscanf(nfile,"%*[^\n] ");
            } else {
              err = std::sscanf(line,"%f%f%f",&c0,&c1,&c2);
              CImg<tf>::vector(i0,i4,i3,i1).move_to(primitives);
              CImg<tf>::vector(i0,i6,i5,i4).move_to(primitives);
              CImg<tf>::vector(i3,i2,i1).move_to(primitives);
              colors.insert(3,CImg<tc>::vector((tc)(c0*255),(tc)(c1*255),(tc)(c2*255)));
              ++(++nb_primitives);
            }
          } break;
          case 8 : {
            if ((err = std::fscanf(nfile,"%u%u%u%u%u%u%u%u%255[^\n] ",&i0,&i1,&i2,&i3,&i4,&i5,&i6,&i7,line))<7) {
              cimg::warn(_cimg_instance
                         "load_off(): Failed to read primitive %u/%u from file '%s'.",
                         cimg_instance,
                         nb_read,nb_primitives,filename?filename:"(FILE*)");

              err = std::fscanf(nfile,"%*[^\n] ");
            } else {
              err = std::sscanf(line,"%f%f%f",&c0,&c1,&c2);
              CImg<tf>::vector(i0,i3,i2,i1).move_to(primitives);
              CImg<tf>::vector(i0,i5,i4,i3).move_to(primitives);
              CImg<tf>::vector(i0,i7,i6,i5).move_to(primitives);
              colors.insert(3,CImg<tc>::vector((tc)(c0*255),(tc)(c1*255),(tc)(c2*255)));
              ++(++nb_primitives);
            }
          } break;
          default :
            cimg::warn(_cimg_instance
                       "load_off(): Failed to read primitive %u/%u (%u vertices) from file '%s'.",
                       cimg_instance,
                       nb_read,nb_primitives,prim,filename?filename:"(FILE*)");

            err = std::fscanf(nfile,"%*[^\n] ");
          }
        }
      }
      if (!file) cimg::fclose(nfile);
      if (primitives._width!=nb_primitives)
        cimg::warn(_cimg_instance
                   "load_off(): Only %u/%u primitives read from file '%s'.",
                   cimg_instance,
                   primitives._width,nb_primitives,filename?filename:"(FILE*)");
      return *this;
    }

    //! Load image sequence using FFMPEG's external tool 'ffmpeg'.
    /**
      \param filename Filename, as a C-string.
      \param axis Appending axis, if file contains multiple images. Can be <tt>{ 'x' | 'y' | 'z' | 'c' }</tt>.
      \param align Appending alignment.
    **/
    CImg<T>& load_ffmpeg_external(const char *const filename, const char axis='z', const float align=0) {
      return get_load_ffmpeg_external(filename,axis,align).move_to(*this);
    }

    //! Load image sequence using FFMPEG's external tool 'ffmpeg' \newinstance.
    static CImg<T> get_load_ffmpeg_external(const char *const filename, const char axis='z', const float align=0) {
      return CImgList<T>().load_ffmpeg_external(filename).get_append(axis,align);
    }

    //! Load gif file, using Imagemagick or GraphicsMagicks's external tools.
    /**
      \param filename Filename, as a C-string.
      \param use_graphicsmagick Tells if GraphicsMagick's tool 'gm' is used instead of ImageMagick's tool 'convert'.
      \param axis Appending axis, if file contains multiple images. Can be <tt>{ 'x' | 'y' | 'z' | 'c' }</tt>.
      \param align Appending alignment.
    **/
    CImg<T>& load_gif_external(const char *const filename,
                               const char axis='z', const float align=0) {
      return get_load_gif_external(filename,axis,align).move_to(*this);
    }

    //! Load gif file, using ImageMagick or GraphicsMagick's external tool 'convert' \newinstance.
    static CImg<T> get_load_gif_external(const char *const filename,
                                         const char axis='z', const float align=0) {
      return CImgList<T>().load_gif_external(filename).get_append(axis,align);
    }

    //! Load image using GraphicsMagick's external tool 'gm'.
    /**
       \param filename Filename, as a C-string.
    **/
    CImg<T>& load_graphicsmagick_external(const char *const filename) {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_graphicsmagick_external(): Specified filename is (null).",
                                    cimg_instance);
      std::fclose(cimg::fopen(filename,"rb"));            // Check if file exists.
      char command[1024] = { 0 }, filetmp[512] = { 0 };
      std::FILE *file = 0;
      const CImg<charT> s_filename = CImg<charT>::string(filename)._system_strescape();
#if cimg_OS==1
      cimg_snprintf(command,sizeof(command),"%s convert \"%s\" pnm:-",
                    cimg::graphicsmagick_path(),s_filename.data());
      file = popen(command,"r");
      if (file) {
        const unsigned int omode = cimg::exception_mode();
        cimg::exception_mode() = 0;
        try { load_pnm(file); } catch (...) {
          pclose(file);
          cimg::exception_mode() = omode;
          throw CImgIOException(_cimg_instance
                                "load_graphicsmagick_external(): Failed to load file '%s' with external command 'gm'.",
                                cimg_instance,
                                filename);
        }
        pclose(file);
        return *this;
      }
#endif
# 38213 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      do {
        cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s.pnm",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand());
        if ((file=std::fopen(filetmp,"rb"))!=0) cimg::fclose(file);
      } while (file);
      cimg_snprintf(command,sizeof(command),"%s convert \"%s\" \"%s\"",
                    cimg::graphicsmagick_path(),s_filename.data(),CImg<charT>::string(filetmp)._system_strescape().data());
      cimg::system(command,cimg::graphicsmagick_path());
      if (!(file = std::fopen(filetmp,"rb"))) {
        cimg::fclose(cimg::fopen(filename,"r"));
        throw CImgIOException(_cimg_instance
                              "load_graphicsmagick_external(): Failed to load file '%s' with external command 'gm'.",
                              cimg_instance,
                              filename);

      } else cimg::fclose(file);
      load_pnm(filetmp);
      std::remove(filetmp);
      return *this;
    }

    //! Load image using GraphicsMagick's external tool 'gm' \newinstance.
    static CImg<T> get_load_graphicsmagick_external(const char *const filename) {
      return CImg<T>().load_graphicsmagick_external(filename);
    }

    //! Load gzipped image file, using external tool 'gunzip'.
    /**
       \param filename Filename, as a C-string.
    **/
    CImg<T>& load_gzip_external(const char *const filename) {
      if (!filename)
        throw CImgIOException(_cimg_instance
                              "load_gzip_external(): Specified filename is (null).",
                              cimg_instance);
      std::fclose(cimg::fopen(filename,"rb"));            // Check if file exists.
      char command[1024] = { 0 }, filetmp[512] = { 0 }, body[512] = { 0 };
      const char
        *const ext = cimg::split_filename(filename,body),
        *const ext2 = cimg::split_filename(body,0);

      std::FILE *file = 0;
      do {
        if (!cimg::strcasecmp(ext,"gz")) {
          if (*ext2) cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s.%s",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand(),ext2);
          else cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand());
        } else {
          if (*ext) cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s.%s",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand(),ext);
          else cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand());
        }
        if ((file=std::fopen(filetmp,"rb"))!=0) cimg::fclose(file);
      } while (file);
      cimg_snprintf(command,sizeof(command),"%s -c \"%s\" > \"%s\"",
                    cimg::gunzip_path(),
                    CImg<charT>::string(filename)._system_strescape().data(),
                    CImg<charT>::string(filetmp)._system_strescape().data());
      cimg::system(command);
      if (!(file = std::fopen(filetmp,"rb"))) {
        cimg::fclose(cimg::fopen(filename,"r"));
        throw CImgIOException(_cimg_instance
                              "load_gzip_external(): Failed to load file '%s' with external command 'gunzip'.",
                              cimg_instance,
                              filename);

      } else cimg::fclose(file);
      load(filetmp);
      std::remove(filetmp);
      return *this;
    }

    //! Load gzipped image file, using external tool 'gunzip' \newinstance.
    static CImg<T> get_load_gzip_external(const char *const filename) {
      return CImg<T>().load_gzip_external(filename);
    }

    //! Load image using ImageMagick's external tool 'convert'.
    /**
       \param filename Filename, as a C-string.
    **/
    CImg<T>& load_imagemagick_external(const char *const filename) {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_imagemagick_external(): Specified filename is (null).",
                                    cimg_instance);
      std::fclose(cimg::fopen(filename,"rb"));            // Check if file exists.
      char command[1024] = { 0 }, filetmp[512] = { 0 };
      std::FILE *file = 0;
      const CImg<charT> s_filename = CImg<charT>::string(filename)._system_strescape();
#if cimg_OS==1
      cimg_snprintf(command,sizeof(command),"%s%s \"%s\" pnm:-",
                    cimg::imagemagick_path(),
                    !cimg::strcasecmp(cimg::split_filename(filename),"pdf")?" -density 400x400":"",
                    s_filename.data());
      file = popen(command,"r");
      if (file) {
        const unsigned int omode = cimg::exception_mode();
        cimg::exception_mode() = 0;
        try { load_pnm(file); } catch (...) {
          pclose(file);
          cimg::exception_mode() = omode;
          throw CImgIOException(_cimg_instance
                                "load_imagemagick_external(): Failed to load file '%s' with external command 'convert'.",
                                cimg_instance,
                                filename);
        }
        pclose(file);
        return *this;
      }
#endif
# 38321 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      do {
        cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s.pnm",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand());
        if ((file=std::fopen(filetmp,"rb"))!=0) cimg::fclose(file);
      } while (file);
      cimg_snprintf(command,sizeof(command),"%s%s \"%s\" \"%s\"",
                    cimg::imagemagick_path(),
                    !cimg::strcasecmp(cimg::split_filename(filename),"pdf")?" -density 400x400":"",
                    s_filename.data(),CImg<charT>::string(filetmp)._system_strescape().data());
      cimg::system(command,cimg::imagemagick_path());
      if (!(file = std::fopen(filetmp,"rb"))) {
        cimg::fclose(cimg::fopen(filename,"r"));
        throw CImgIOException(_cimg_instance
                              "load_imagemagick_external(): Failed to load file '%s' with external command 'convert'.",
                              cimg_instance,
                              filename);

      } else cimg::fclose(file);
      load_pnm(filetmp);
      std::remove(filetmp);
      return *this;
    }

    //! Load image using ImageMagick's external tool 'convert' \newinstance.
    static CImg<T> get_load_imagemagick_external(const char *const filename) {
      return CImg<T>().load_imagemagick_external(filename);
    }

    //! Load image from a DICOM file, using XMedcon's external tool 'medcon'.
    /**
       \param filename Filename, as a C-string.
    **/
    CImg<T>& load_medcon_external(const char *const filename) {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_medcon_external(): Specified filename is (null).",
                                    cimg_instance);
      std::fclose(cimg::fopen(filename,"rb"));            // Check if file exists.
      char command[1024] = { 0 }, filetmp[512] = { 0 }, body[512] = { 0 };
      cimg::fclose(cimg::fopen(filename,"r"));
      std::FILE *file = 0;
      do {
        cimg_snprintf(filetmp,sizeof(filetmp),"%s.hdr",cimg::filenamerand());
        if ((file=std::fopen(filetmp,"rb"))!=0) cimg::fclose(file);
      } while (file);
      cimg_snprintf(command,sizeof(command),"%s -w -c anlz -o \"%s\" -f \"%s\"",
                    cimg::medcon_path(),
                    CImg<charT>::string(filetmp)._system_strescape().data(),
                    CImg<charT>::string(filename)._system_strescape().data());
      cimg::system(command);
      cimg::split_filename(filetmp,body);

      cimg_snprintf(command,sizeof(command),"%s.hdr",body);
      file = std::fopen(command,"rb");
      if (!file) {
        cimg_snprintf(command,sizeof(command),"m000-%s.hdr",body);
        file = std::fopen(command,"rb");
        if (!file) {
          throw CImgIOException(_cimg_instance
                                "load_medcon_external(): Failed to load file '%s' with external command 'medcon'.",
                                cimg_instance,
                                filename);
        }
      }
      cimg::fclose(file);
      load_analyze(command);
      std::remove(command);
      cimg::split_filename(command,body);
      cimg_snprintf(command,sizeof(command),"%s.img",body);
      std::remove(command);
      return *this;
    }

    //! Load image from a DICOM file, using XMedcon's external tool 'medcon' \newinstance.
    static CImg<T> get_load_medcon_external(const char *const filename) {
      return CImg<T>().load_medcon_external(filename);
    }

    //! Load image from a RAW Color Camera file, using external tool 'dcraw'.
    /**
       \param filename Filename, as a C-string.
    **/
    CImg<T>& load_dcraw_external(const char *const filename) {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_dcraw_external(): Specified filename is (null).",
                                    cimg_instance);
      std::fclose(cimg::fopen(filename,"rb"));            // Check if file exists.
      char command[1024] = { 0 }, filetmp[512] = { 0 };
      std::FILE *file = 0;
      const CImg<charT> s_filename = CImg<charT>::string(filename)._system_strescape();
#if cimg_OS==1
      cimg_snprintf(command,sizeof(command),"%s -w -4 -c \"%s\"",
                    cimg::dcraw_path(),s_filename.data());
      file = popen(command,"r");
      if (file) {
        const unsigned int omode = cimg::exception_mode();
        cimg::exception_mode() = 0;
        try { load_pnm(file); } catch (...) {
          pclose(file);
          cimg::exception_mode() = omode;
          throw CImgIOException(_cimg_instance
                                "load_dcraw_external(): Failed to load file '%s' with external command 'dcraw'.",
                                cimg_instance,
                                filename);
        }
        pclose(file);
        return *this;
      }
#endif
# 38430 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      do {
        cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s.ppm",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand());
        if ((file=std::fopen(filetmp,"rb"))!=0) cimg::fclose(file);
      } while (file);
      cimg_snprintf(command,sizeof(command),"%s -w -4 -c \"%s\" > \"%s\"",
                    cimg::dcraw_path(),s_filename.data(),CImg<charT>::string(filetmp)._system_strescape().data());
      cimg::system(command,cimg::dcraw_path());
      if (!(file = std::fopen(filetmp,"rb"))) {
        cimg::fclose(cimg::fopen(filename,"r"));
        throw CImgIOException(_cimg_instance
                              "load_dcraw_external(): Failed to load file '%s' with external command 'dcraw'.",
                              cimg_instance,
                              filename);

      } else cimg::fclose(file);
      load_pnm(filetmp);
      std::remove(filetmp);
      return *this;
    }

    //! Load image from a RAW Color Camera file, using external tool 'dcraw' \newinstance.
    static CImg<T> get_load_dcraw_external(const char *const filename) {
      return CImg<T>().load_dcraw_external(filename);
    }

    //! Load image from a camera stream, using OpenCV.
    /**
       \param camera_index Index of the camera to capture images from.
       \param skip_frames Number of frames to skip before the capture.
       \param release_camera Tells if the camera ressource must be released at the end of the method.
    **/
    CImg<T>& load_camera(const unsigned int camera_index=0, const unsigned int skip_frames=0, const bool release_camera=false,
                         const unsigned int capture_width=0, const unsigned int capture_height=0) {
#ifdef cimg_use_opencv
      if (camera_index>255)
        throw CImgArgumentException(_cimg_instance
                                    "load_camera(): Invalid request for camera #%u (no more than 256 cameras can be managed).",
                                    cimg_instance,
                                    camera_index);
      static CvCapture *capture[256] = { 0 };
      if (release_camera) {
        if (capture[camera_index]) cvReleaseCapture(&(capture[camera_index]));
        capture[camera_index] = 0;
        return *this;
      }
      if (!capture[camera_index]) {
        capture[camera_index] = cvCreateCameraCapture(camera_index);
        if (!capture[camera_index]) {
          throw CImgIOException(_cimg_instance
                                "load_camera(): Failed to initialize camera #%u.",
                                cimg_instance,
                                camera_index);
        }
      }
      if (capture_width) cvSetCaptureProperty(capture[camera_index],CV_CAP_PROP_FRAME_WIDTH,capture_width);
      if (capture_height) cvSetCaptureProperty(capture[camera_index],CV_CAP_PROP_FRAME_HEIGHT,capture_height);
      const IplImage *img = 0;
      for (unsigned int i = 0; i<skip_frames; ++i) img = cvQueryFrame(capture[camera_index]);
      img = cvQueryFrame(capture[camera_index]);
      if (img) {
        const int step = (int)(img->widthStep - 3*img->width);
        assign(img->width,img->height,1,3);
        const unsigned char* ptrs = (unsigned char*)img->imageData;
        T *ptr_r = data(0,0,0,0), *ptr_g = data(0,0,0,1), *ptr_b = data(0,0,0,2);
        if (step>0) cimg_forY(*this,y) {
            cimg_forX(*this,x) { *(ptr_b++) = (T)*(ptrs++); *(ptr_g++) = (T)*(ptrs++); *(ptr_r++) = (T)*(ptrs++); }
            ptrs+=step;
          } else for (unsigned long siz = (unsigned long)img->width*img->height; siz; --siz) {
            *(ptr_b++) = (T)*(ptrs++); *(ptr_g++) = (T)*(ptrs++); *(ptr_r++) = (T)*(ptrs++);
          }
      }
#else
# 38502 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      cimg::unused(camera_index,skip_frames,release_camera,capture_width,capture_height);
      throw CImgIOException(_cimg_instance
                            "load_camera(): This function requires the OpenCV library to run "
                            "(macro 'cimg_use_opencv' must be defined).",
                            cimg_instance);
#endif
# 38508 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      return *this;
    }

    //! Load image from a camera stream, using OpenCV \newinstance.
    static CImg<T> get_load_camera(const unsigned int camera_index=0, const unsigned int skip_frames=0, const bool release_camera=false,
                                   const unsigned int capture_width=0, const unsigned int capture_height=0) {
      return CImg<T>().load_camera(camera_index,skip_frames,release_camera,capture_width,capture_height);
    }

    //! Load image using various non-native ways.
    /**
       \param filename Filename, as a C-string.
    **/
    CImg<T>& load_other(const char *const filename) {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "load_other(): Specified filename is (null).",
                                    cimg_instance);

      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      try { load_magick(filename); }
      catch (CImgException&) {
        try { load_imagemagick_external(filename); }
        catch (CImgException&) {
          try { load_graphicsmagick_external(filename); }
          catch (CImgException&) {
            try { load_cimg(filename); }
            catch (CImgException&) {
              try {
                std::fclose(cimg::fopen(filename,"rb"));
              } catch (CImgException&) {
                cimg::exception_mode() = omode;
                throw CImgIOException(_cimg_instance
                                      "load_other(): Failed to open file '%s'.",
                                      cimg_instance,
                                      filename);
              }
              cimg::exception_mode() = omode;
              throw CImgIOException(_cimg_instance
                                    "load_other(): Failed to recognize format of file '%s'.",
                                    cimg_instance,
                                    filename);
            }
          }
        }
      }
      cimg::exception_mode() = omode;
      return *this;
    }

    //! Load image using various non-native ways \newinstance.
    static CImg<T> get_load_other(const char *const filename) {
      return CImg<T>().load_other(filename);
    }

    //@}
    //---------------------------
    //
    //! \name Data Output
    //@{
    //---------------------------

    //! Display informations about the image data.
    /**
       \param title Name for the considered image.
       \param display_stats Tells to compute and display image statistics.
    **/
    const CImg<T>& print(const char *const title=0, const bool display_stats=true) const {
      int xm = 0, ym = 0, zm = 0, vm = 0, xM = 0, yM = 0, zM = 0, vM = 0;
      CImg<doubleT> st;
      if (!is_empty() && display_stats) {
        st = get_stats();
        xm = (int)st[4]; ym = (int)st[5], zm = (int)st[6], vm = (int)st[7];
        xM = (int)st[8]; yM = (int)st[9], zM = (int)st[10], vM = (int)st[11];
      }
      const unsigned long siz = size(), msiz = siz*sizeof(T), siz1 = siz-1, mdisp = msiz<8*1024?0:(msiz<8*1024*1024?1:2), width1 = _width-1;

      char _title[64] = { 0 };
      if (!title) cimg_snprintf(_title,sizeof(_title),"CImg<%s>",pixel_type());

      std::fprintf(cimg::output(),"%s%s%s%s: %sthis%s = %p, %ssize%s = (%u,%u,%u,%u) [%lu %s], %sdata%s = (%s*)%p",
                   cimg::t_magenta,cimg::t_bold,title?title:_title,cimg::t_normal,
                   cimg::t_bold,cimg::t_normal,(void*)this,
                   cimg::t_bold,cimg::t_normal,_width,_height,_depth,_spectrum,
                   mdisp==0?msiz:(mdisp==1?(msiz>>10):(msiz>>20)),
                   mdisp==0?"b":(mdisp==1?"Kio":"Mio"),
                   cimg::t_bold,cimg::t_normal,pixel_type(),(void*)begin());
      if (_data) std::fprintf(cimg::output(),"..%p (%s) = [ ",(void*)((char*)end()-1),_is_shared?"shared":"non-shared");
      else std::fprintf(cimg::output()," (%s) = [ ",_is_shared?"shared":"non-shared");

      if (!is_empty()) cimg_foroff(*this,off) {
        std::fprintf(cimg::output(),cimg::type<T>::format(),cimg::type<T>::format(_data[off]));
        if (off!=siz1) std::fprintf(cimg::output(),"%s",off%_width==width1?" ; ":" ");
        if (off==7 && siz>16) { off = siz1-8; std::fprintf(cimg::output(),"... "); }
      }
      if (!is_empty() && display_stats)
	std::fprintf(cimg::output()," ], %smin%s = %g, %smax%s = %g, %smean%s = %g, %sstd%s = %g, %scoords_min%s = (%u,%u,%u,%u), %scoords_max%s = (%u,%u,%u,%u).\n",
		     cimg::t_bold,cimg::t_normal,st[0],
                     cimg::t_bold,cimg::t_normal,st[1],
                     cimg::t_bold,cimg::t_normal,st[2],
                     cimg::t_bold,cimg::t_normal,std::sqrt(st[3]),
                     cimg::t_bold,cimg::t_normal,xm,ym,zm,vm,
                     cimg::t_bold,cimg::t_normal,xM,yM,zM,vM);
      else std::fprintf(cimg::output(),"%s].\n",is_empty()?"":" ");
      std::fflush(cimg::output());
      return *this;
    }

    //! Display image into a CImgDisplay window.
    /**
       \param disp Display window.
    **/
    const CImg<T>& display(CImgDisplay& disp) const {
      disp.display(*this);
      return *this;
    }

    //! Display image into a CImgDisplay window, in an interactive way.
    /**
        \param disp Display window.
        \param display_info Tells if image informations are displayed on the standard output.
    **/
    const CImg<T>& display(CImgDisplay &disp, const bool display_info, unsigned int *const XYZ=0) const {
      return _display(disp,0,display_info,XYZ,false);
    }

    //! Display image into an interactive window.
    /**
        \param title Window title
        \param display_info Tells if image informations are displayed on the standard output.
    **/
    const CImg<T>& display(const char *const title=0, const bool display_info=true, unsigned int *const XYZ=0) const {
      CImgDisplay disp;
      return _display(disp,title,display_info,XYZ,false);
    }

    const CImg<T>& _display(CImgDisplay &disp, const char *const title,
                            const bool display_info, unsigned int *const XYZ,
                            const bool exit_on_simpleclick) const {
      unsigned int oldw = 0, oldh = 0, _XYZ[3], key = 0;
      int x0 = 0, y0 = 0, z0 = 0, x1 = width()-1, y1 = height()-1, z1 = depth()-1;

      if (!disp) {
        disp.assign(cimg_fitscreen(_width,_height,_depth),title?title:0,1);
        if (!title) disp.set_title("CImg<%s> (%ux%ux%ux%u)",pixel_type(),_width,_height,_depth,_spectrum);
        else disp.set_title("%s",title);
      } else if (title) disp.set_title("%s",title);
      disp.show().flush();

      const CImg<char> dtitle = CImg<char>::string(disp.title());
      if (display_info) print(dtitle);

      CImg<T> zoom;
      for (bool reset_view = true, resize_disp = false, is_first_select = true; !key && !disp.is_closed(); ) {
        if (reset_view) {
          if (XYZ) { _XYZ[0] = XYZ[0]; _XYZ[1] = XYZ[1]; _XYZ[2] = XYZ[2]; }
          else { _XYZ[0] = (x0 + x1)/2; _XYZ[1] = (y0 + y1)/2; _XYZ[2] = (z0 + z1)/2; }
          x0 = 0; y0 = 0; z0 = 0; x1 = width()-1; y1 = height()-1; z1 = depth()-1;
          oldw = disp.width(); oldh = disp.height();
          reset_view = false;
        }
        if (!x0 && !y0 && !z0 && x1==width()-1 && y1==height()-1 && z1==depth()-1) { if (is_empty()) zoom.assign(1,1,1,1,0); else zoom.assign(); }
        else zoom = get_crop(x0,y0,z0,x1,y1,z1);

        const unsigned int
          dx = 1 + x1 - x0, dy = 1 + y1 - y0, dz = 1 + z1 - z0,
          tw = dx + (dz>1?dz:0), th = dy + (dz>1?dz:0);
        if (!is_empty() && !disp.is_fullscreen() && resize_disp) {
          const unsigned int
            ttw = tw*disp.width()/oldw, tth = th*disp.height()/oldh,
            dM = cimg::max(ttw,tth), diM = (unsigned int)cimg::max(disp.width(),disp.height()),
            imgw = cimg::max(16U,ttw*diM/dM), imgh = cimg::max(16U,tth*diM/dM);
          disp.set_fullscreen(false).resize(cimg_fitscreen(imgw,imgh,1),false);
          resize_disp = false;
        }
        oldw = tw; oldh = th;

        bool
          go_up = false, go_down = false, go_left = false, go_right = false,
          go_inc = false, go_dec = false, go_in = false, go_out = false,
          go_in_center = false;
        const CImg<T>& visu = zoom?zoom:*this;

        disp.set_title(dtitle._data);
        if (_width>1 && visu._width==1) disp.set_title("%s | x=%u",disp._title,x0);
        if (_height>1 && visu._height==1) disp.set_title("%s | y=%u",disp._title,y0);
        if (_depth>1 && visu._depth==1) disp.set_title("%s | z=%u",disp._title,z0);

        if (!is_first_select) { _XYZ[0] = (x1-x0)/2; _XYZ[1] = (y1-y0)/2; _XYZ[2] = (z1-z0)/2; }
        const CImg<intT> selection = visu._get_select(disp,0,2,_XYZ,x0,y0,z0,is_first_select,_depth>1);
        is_first_select = false;

        if (disp.wheel()) {
          if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) { go_out = !(go_in = disp.wheel()>0); go_in_center = false; }
          else if (disp.is_keySHIFTLEFT() || disp.is_keySHIFTRIGHT()) { go_right = !(go_left = disp.wheel()>0); }
          else if (disp.is_keyALT() || disp.is_keyALTGR() || _depth==1) { go_down = !(go_up = disp.wheel()>0); }
          disp.set_wheel();
        }

        const int
          sx0 = selection(0), sy0 = selection(1), sz0 = selection(2),
          sx1 = selection(3), sy1 = selection(4), sz1 = selection(5);
        if (sx0>=0 && sy0>=0 && sz0>=0 && sx1>=0 && sy1>=0 && sz1>=0) {
          x1 = x0 + sx1; y1 = y0 + sy1; z1 = z0 + sz1;
          x0+=sx0; y0+=sy0; z0+=sz0;
          if (sx0==sx1 && sy0==sy1 && sz0==sz1) {
            if (exit_on_simpleclick && (!zoom || is_empty())) break; else reset_view = true;
          }
          resize_disp = true;
        } else switch (key = disp.key()) {
#if cimg_OS!=2
          case cimg::keyCTRLRIGHT : case cimg::keySHIFTRIGHT :
#endif
# 38722 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
          case 0 : case cimg::keyCTRLLEFT : case cimg::keyPAD5 : case cimg::keySHIFTLEFT :
#if cimg_OS!=2
          case cimg::keyALTGR :
#endif
# 38726 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
          case cimg::keyALT : key = 0; break;
          case cimg::keyP : if (visu._depth>1 && (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT())) { // Special mode: play stack of frames
              const unsigned int
                w1 = visu._width*disp.width()/(visu._width+(visu._depth>1?visu._depth:0)),
                h1 = visu._height*disp.height()/(visu._height+(visu._depth>1?visu._depth:0));
              float frame_timing = 5;
              bool is_stopped = false;
              disp.set_key(key,false).set_wheel().resize(cimg_fitscreen(w1,h1,1),false); key = 0;
              for (unsigned int timer = 0; !key && !disp.is_closed() && !disp.button(); ) {
                if (disp.is_resized()) disp.resize(false);
                if (!timer) {
                  visu.get_slice((int)_XYZ[2]).display(disp.set_title("%s | z=%d",dtitle.data(),_XYZ[2]));
                  (++_XYZ[2])%=visu._depth;
                }
                if (!is_stopped) { if (++timer>(unsigned int)frame_timing) timer = 0; } else timer = ~0U;
                if (disp.wheel()) { frame_timing-=disp.wheel()/3.0f; disp.set_wheel(); }
                switch (key = disp.key()) {
#if cimg_OS!=2
                case cimg::keyCTRLRIGHT :
#endif
# 38746 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
                case cimg::keyCTRLLEFT : key = 0; break;
                case cimg::keyPAGEUP : frame_timing-=0.3f; key = 0; break;
                case cimg::keyPAGEDOWN : frame_timing+=0.3f; key = 0; break;
                case cimg::keySPACE : is_stopped = !is_stopped; disp.set_key(key,false); key = 0; break;
                case cimg::keyARROWLEFT : case cimg::keyARROWUP : is_stopped = true; timer = 0; key = 0; break;
                case cimg::keyARROWRIGHT : case cimg::keyARROWDOWN : is_stopped = true; (_XYZ[2]+=visu._depth-2)%=visu._depth; timer = 0; key = 0; break;
                case cimg::keyD : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
                    disp.set_fullscreen(false).resize(CImgDisplay::_fitscreen(3*disp.width()/2,3*disp.height()/2,1,128,-100,false),
                                                      CImgDisplay::_fitscreen(3*disp.width()/2,3*disp.height()/2,1,128,-100,true),false);
                    disp.set_key(key,false); key = 0;
                  } break;
                case cimg::keyC : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
                    disp.set_fullscreen(false).resize(cimg_fitscreen(2*disp.width()/3,2*disp.height()/3,1),false).set_key(key,false); key = 0;
                  } break;
                case cimg::keyR : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
                    disp.set_fullscreen(false).resize(cimg_fitscreen(_width,_height,_depth),false).set_key(key,false); key = 0;
                  } break;
                case cimg::keyF : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
                    disp.resize(disp.screen_width(),disp.screen_height(),false).toggle_fullscreen().set_key(key,false); key = 0;
                  } break;
                }
                frame_timing = frame_timing<1?1:(frame_timing>39?39:frame_timing);
                disp.wait(20);
              }
              const unsigned int
                w2 = (visu._width + (visu._depth>1?visu._depth:0))*disp.width()/visu._width,
                h2 = (visu._height + (visu._depth>1?visu._depth:0))*disp.height()/visu._height;
              disp.resize(cimg_fitscreen(w2,h2,1),false).set_title(dtitle.data()).set_key().set_button().set_wheel();
              key = 0;
            } break;
          case cimg::keyHOME : reset_view = resize_disp = true; key = 0; break;
          case cimg::keyPADADD : go_in = true; go_in_center = true; key = 0; break;
          case cimg::keyPADSUB : go_out = true; key = 0; break;
          case cimg::keyARROWLEFT : case cimg::keyPAD4: go_left = true; key = 0; break;
          case cimg::keyARROWRIGHT : case cimg::keyPAD6: go_right = true; key = 0; break;
          case cimg::keyARROWUP : case cimg::keyPAD8: go_up = true; key = 0; break;
          case cimg::keyARROWDOWN : case cimg::keyPAD2: go_down = true; key = 0; break;
          case cimg::keyPAD7 : go_up = go_left = true; key = 0; break;
          case cimg::keyPAD9 : go_up = go_right = true; key = 0; break;
          case cimg::keyPAD1 : go_down = go_left = true; key = 0; break;
          case cimg::keyPAD3 : go_down = go_right = true; key = 0; break;
          case cimg::keyPAGEUP : go_inc = true; key = 0; break;
          case cimg::keyPAGEDOWN : go_dec = true; key = 0; break;
          }
        if (go_in) {
          const int
            mx = go_in_center?disp.width()/2:disp.mouse_x(),
            my = go_in_center?disp.height()/2:disp.mouse_y(),
            mX = mx*(_width+(_depth>1?_depth:0))/disp.width(),
            mY = my*(_height+(_depth>1?_depth:0))/disp.height();
          int X = _XYZ[0], Y = _XYZ[1], Z = _XYZ[2];
          if (mX<width() && mY<height())  { X = x0 + mX*(1+x1-x0)/_width; Y = y0 + mY*(1+y1-y0)/_height; Z = _XYZ[2]; }
          if (mX<width() && mY>=height()) { X = x0 + mX*(1+x1-x0)/_width; Z = z0 + (mY-_height)*(1+z1-z0)/_depth; Y = _XYZ[1]; }
          if (mX>=width() && mY<height()) { Y = y0 + mY*(1+y1-y0)/_height; Z = z0 + (mX-_width)*(1+z1-z0)/_depth; X = _XYZ[0]; }
          if (x1-x0>4) { x0 = X - 7*(X-x0)/8; x1 = X + 7*(x1-X)/8; }
          if (y1-y0>4) { y0 = Y - 7*(Y-y0)/8; y1 = Y + 7*(y1-Y)/8; }
          if (z1-z0>4) { z0 = Z - 7*(Z-z0)/8; z1 = Z + 7*(z1-Z)/8; }
        }
        if (go_out) {
          const int
            delta_x = (x1-x0)/8, delta_y = (y1-y0)/8, delta_z = (z1-z0)/8,
            ndelta_x = delta_x?delta_x:(_width>1?1:0),
            ndelta_y = delta_y?delta_y:(_height>1?1:0),
            ndelta_z = delta_z?delta_z:(_depth>1?1:0);
          x0-=ndelta_x; y0-=ndelta_y; z0-=ndelta_z;
          x1+=ndelta_x; y1+=ndelta_y; z1+=ndelta_z;
          if (x0<0) { x1-=x0; x0 = 0; if (x1>=width()) x1 = width() - 1; }
          if (y0<0) { y1-=y0; y0 = 0; if (y1>=height()) y1 = height() - 1; }
          if (z0<0) { z1-=z0; z0 = 0; if (z1>=depth()) z1 = depth() - 1; }
          if (x1>=width()) { x0-=(x1-width()+1); x1 = width()-1; if (x0<0) x0 = 0; }
          if (y1>=height()) { y0-=(y1-height()+1); y1 = height()-1; if (y0<0) y0 = 0; }
          if (z1>=depth()) { z0-=(z1-depth()+1); z1 = depth()-1; if (z0<0) z0 = 0; }
        }
        if (go_left) {
          const int delta = (x1-x0)/5, ndelta = delta?delta:(_width>1?1:0);
          if (x0-ndelta>=0) { x0-=ndelta; x1-=ndelta; }
          else { x1-=x0; x0 = 0; }
        }
        if (go_right) {
          const int delta = (x1-x0)/5, ndelta = delta?delta:(_width>1?1:0);
          if (x1+ndelta<width()) { x0+=ndelta; x1+=ndelta; }
          else { x0+=(width()-1-x1); x1 = width()-1; }
        }
        if (go_up) {
          const int delta = (y1-y0)/5, ndelta = delta?delta:(_height>1?1:0);
          if (y0-ndelta>=0) { y0-=ndelta; y1-=ndelta; }
          else { y1-=y0; y0 = 0; }
        }
        if (go_down) {
          const int delta = (y1-y0)/5, ndelta = delta?delta:(_height>1?1:0);
          if (y1+ndelta<height()) { y0+=ndelta; y1+=ndelta; }
          else { y0+=(height()-1-y1); y1 = height()-1; }
        }
        if (go_inc) {
          const int delta = (z1-z0)/5, ndelta = delta?delta:(_depth>1?1:0);
          if (z0-ndelta>=0) { z0-=ndelta; z1-=ndelta; }
          else { z1-=z0; z0 = 0; }
        }
        if (go_dec) {
          const int delta = (z1-z0)/5, ndelta = delta?delta:(_depth>1?1:0);
          if (z1+ndelta<depth()) { z0+=ndelta; z1+=ndelta; }
          else { z0+=(depth()-1-z1); z1 = depth()-1; }
        }
        disp.wait(100);
      }
      disp.set_key(key);
      if (XYZ) { XYZ[0] = _XYZ[0]; XYZ[1] = _XYZ[1]; XYZ[2] = _XYZ[2]; }
      return *this;
    }

    //! Display object 3d in an interactive window.
    /**
       \param disp Display window.
       \param vertices Vertices data of the 3d object.
       \param primitives Primitives data of the 3d object.
       \param colors Colors data of the 3d object.
       \param opacities Opacities data of the 3d object.
       \param centering Tells if the 3d object must be centered for the display.
       \param render_static Rendering mode.
       \param render_motion Rendering mode, when the 3d object is moved.
       \param is_double_sided Tells if the object primitives are double-sided.
       \param focale Focale
       \param light_x X-coordinate of the light source.
       \param light_y Y-coordinate of the light source.
       \param light_z Z-coordinate of the light source.
       \param specular_lightness Amount of specular light.
       \param specular_shininess Shininess of the object material.
       \param display_axes Tells if the 3d axes are displayed.
       \param pose_matrix Pointer to 12 values, defining a 3d pose (as a 4x3 matrix).
    **/
    template<typename tp, typename tf, typename tc, typename to>
    const CImg<T>& display_object3d(CImgDisplay& disp,
                                    const CImg<tp>& vertices,
                                    const CImgList<tf>& primitives,
                                    const CImgList<tc>& colors,
                                    const to& opacities,
                                    const bool centering=true,
                                    const int render_static=4, const int render_motion=1,
                                    const bool is_double_sided=true, const float focale=700,
                                    const float light_x=0, const float light_y=0, const float light_z=-5e8f,
                                    const float specular_lightness=0.2f, const float specular_shininess=0.1f,
                                    const bool display_axes=true, float *const pose_matrix=0) const {
      return _display_object3d(disp,0,vertices,primitives,colors,opacities,centering,render_static,
			       render_motion,is_double_sided,focale,
                               light_x,light_y,light_z,specular_lightness,specular_shininess,
			       display_axes,pose_matrix);
    }

    //! Display object 3d in an interactive window \simplification.
    template<typename tp, typename tf, typename tc, typename to>
    const CImg<T>& display_object3d(const char *const title,
                                    const CImg<tp>& vertices,
                                    const CImgList<tf>& primitives,
                                    const CImgList<tc>& colors,
                                    const to& opacities,
                                    const bool centering=true,
                                    const int render_static=4, const int render_motion=1,
                                    const bool is_double_sided=true, const float focale=700,
                                    const float light_x=0, const float light_y=0, const float light_z=-5e8f,
                                    const float specular_lightness=0.2f, const float specular_shininess=0.1f,
                                    const bool display_axes=true, float *const pose_matrix=0) const {
      CImgDisplay disp;
      return _display_object3d(disp,title,vertices,primitives,colors,opacities,centering,render_static,
			       render_motion,is_double_sided,focale,
                               light_x,light_y,light_z,specular_lightness,specular_shininess,
			       display_axes,pose_matrix);
    }

    //! Display object 3d in an interactive window \simplification.
    template<typename tp, typename tf, typename tc>
    const CImg<T>& display_object3d(CImgDisplay &disp,
                                    const CImg<tp>& vertices,
                                    const CImgList<tf>& primitives,
                                    const CImgList<tc>& colors,
                                    const bool centering=true,
                                    const int render_static=4, const int render_motion=1,
                                    const bool is_double_sided=true, const float focale=700,
                                    const float light_x=0, const float light_y=0, const float light_z=-5e8f,
                                    const float specular_lightness=0.2f, const float specular_shininess=0.1f,
                                    const bool display_axes=true, float *const pose_matrix=0) const {
      return display_object3d(disp,vertices,primitives,colors,CImgList<floatT>(),centering,
			      render_static,render_motion,is_double_sided,focale,
                              light_x,light_y,light_z,specular_lightness,specular_shininess,
			      display_axes,pose_matrix);
    }

    //! Display object 3d in an interactive window \simplification.
    template<typename tp, typename tf, typename tc>
    const CImg<T>& display_object3d(const char *const title,
				    const CImg<tp>& vertices,
                                    const CImgList<tf>& primitives,
                                    const CImgList<tc>& colors,
                                    const bool centering=true,
                                    const int render_static=4, const int render_motion=1,
                                    const bool is_double_sided=true, const float focale=700,
                                    const float light_x=0, const float light_y=0, const float light_z=-5e8f,
                                    const float specular_lightness=0.2f, const float specular_shininess=0.1f,
                                    const bool display_axes=true, float *const pose_matrix=0) const {
      return display_object3d(title,vertices,primitives,colors,CImgList<floatT>(),centering,
                              render_static,render_motion,is_double_sided,focale,
                              light_x,light_y,light_z,specular_lightness,specular_shininess,
                              display_axes,pose_matrix);
    }

    //! Display object 3d in an interactive window \simplification.
    template<typename tp, typename tf>
    const CImg<T>& display_object3d(CImgDisplay &disp,
                                    const CImg<tp>& vertices,
                                    const CImgList<tf>& primitives,
                                    const bool centering=true,
                                    const int render_static=4, const int render_motion=1,
                                    const bool is_double_sided=true, const float focale=700,
                                    const float light_x=0, const float light_y=0, const float light_z=-5e8f,
                                    const float specular_lightness=0.2f, const float specular_shininess=0.1f,
                                    const bool display_axes=true, float *const pose_matrix=0) const {
      return display_object3d(disp,vertices,primitives,CImgList<T>(),centering,
                              render_static,render_motion,is_double_sided,focale,
                              light_x,light_y,light_z,specular_lightness,specular_shininess,
                              display_axes,pose_matrix);
    }


    //! Display object 3d in an interactive window \simplification.
    template<typename tp, typename tf>
    const CImg<T>& display_object3d(const char *const title,
				    const CImg<tp>& vertices,
                                    const CImgList<tf>& primitives,
                                    const bool centering=true,
                                    const int render_static=4, const int render_motion=1,
                                    const bool is_double_sided=true, const float focale=700,
                                    const float light_x=0, const float light_y=0, const float light_z=-5e8f,
                                    const float specular_lightness=0.2f, const float specular_shininess=0.1f,
                                    const bool display_axes=true, float *const pose_matrix=0) const {
      return display_object3d(title,vertices,primitives,CImgList<T>(),centering,
                              render_static,render_motion,is_double_sided,focale,
                              light_x,light_y,light_z,specular_lightness,specular_shininess,
                              display_axes,pose_matrix);
    }

    //! Display object 3d in an interactive window \simplification.
    template<typename tp>
    const CImg<T>& display_object3d(CImgDisplay &disp,
                                    const CImg<tp>& vertices,
                                    const bool centering=true,
                                    const int render_static=4, const int render_motion=1,
                                    const bool is_double_sided=true, const float focale=700,
                                    const float light_x=0, const float light_y=0, const float light_z=-5e8f,
                                    const float specular_lightness=0.2f, const float specular_shininess=0.1f,
                                    const bool display_axes=true, float *const pose_matrix=0) const {
      return display_object3d(disp,vertices,CImgList<uintT>(),centering,
                              render_static,render_motion,is_double_sided,focale,
                              light_x,light_y,light_z,specular_lightness,specular_shininess,
                              display_axes,pose_matrix);
    }

    //! Display object 3d in an interactive window \simplification.
    template<typename tp>
    const CImg<T>& display_object3d(const char *const title,
				    const CImg<tp>& vertices,
                                    const bool centering=true,
                                    const int render_static=4, const int render_motion=1,
                                    const bool is_double_sided=true, const float focale=700,
                                    const float light_x=0, const float light_y=0, const float light_z=-5e8f,
                                    const float specular_lightness=0.2f, const float specular_shininess=0.1f,
                                    const bool display_axes=true, float *const pose_matrix=0) const {
      return display_object3d(title,vertices,CImgList<uintT>(),centering,
                              render_static,render_motion,is_double_sided,focale,
                              light_x,light_y,light_z,specular_lightness,specular_shininess,
                              display_axes,pose_matrix);
    }

    template<typename tp, typename tf, typename tc, typename to>
    const CImg<T>& _display_object3d(CImgDisplay& disp, const char *const title,
				     const CImg<tp>& vertices,
				     const CImgList<tf>& primitives,
				     const CImgList<tc>& colors,
                                     const to& opacities,
				     const bool centering,
				     const int render_static, const int render_motion,
				     const bool is_double_sided, const float focale,
                                     const float light_x, const float light_y, const float light_z,
				     const float specular_lightness, const float specular_shininess,
				     const bool display_axes, float *const pose_matrix) const {
      typedef typename cimg::superset<tp,float>::type tpfloat;

      // Check input arguments
      if (is_empty()) {
	if (disp) return CImg<T>(disp.width(),disp.height(),1,(colors && colors[0].size()==1)?1:3,0).
		    _display_object3d(disp,title,vertices,primitives,colors,opacities,centering,
                                      render_static,render_motion,is_double_sided,focale,
                                      light_x,light_y,light_z,specular_lightness,specular_shininess,
                                      display_axes,pose_matrix);
	else return CImg<T>(1,2,1,1,64,128).resize(cimg_fitscreen(640,480,1),1,(colors && colors[0].size()==1)?1:3,3).
               _display_object3d(disp,title,vertices,primitives,colors,opacities,centering,
				 render_static,render_motion,is_double_sided,focale,
                                 light_x,light_y,light_z,specular_lightness,specular_shininess,
				 display_axes,pose_matrix);
      } else { if (disp) disp.resize(*this,false); }
      char error_message[1024] = { 0 };
      if (!vertices.is_object3d(primitives,colors,opacities,true,error_message))
        throw CImgArgumentException(_cimg_instance
                                    "display_object3d(): Invalid specified 3d object (%u,%u) (%s).",
                                    cimg_instance,vertices._width,primitives._width,error_message);
      if (vertices._width && !primitives) {
        CImgList<tf> nprimitives(vertices._width,1,1,1,1);
        cimglist_for(nprimitives,l) nprimitives(l,0) = l;
        return _display_object3d(disp,title,vertices,nprimitives,colors,opacities,centering,
				 render_static,render_motion,is_double_sided,focale,
                                 light_x,light_y,light_z,specular_lightness,specular_shininess,
				 display_axes,pose_matrix);
      }
      if (!disp) {
	disp.assign(cimg_fitscreen(_width,_height,_depth),title?title:0,3);
        if (!title) disp.set_title("CImg<%s> (%u vertices, %u primitives)",pixel_type(),vertices._width,primitives._width);
      } else if (title) disp.set_title("%s",title);

      // Init 3d objects and compute object statistics
      CImg<floatT>
        pose,
        rotated_vertices(vertices._width,3),
        bbox_vertices, rotated_bbox_vertices,
        axes_vertices, rotated_axes_vertices,
        bbox_opacities, axes_opacities;
      CImgList<uintT> bbox_primitives, axes_primitives;
      CImgList<tf> reverse_primitives;
      CImgList<T> bbox_colors, bbox_colors2, axes_colors;
      unsigned int ns_width = 0, ns_height = 0;
      int _is_double_sided = (int)is_double_sided;
      bool ndisplay_axes = display_axes;
      const CImg<T>
        background_color(1,1,1,_spectrum,0),
        foreground_color(1,1,1,_spectrum,255);
      float
        Xoff = 0, Yoff = 0, Zoff = 0, sprite_scale = 1,
        xm = 0, xM = vertices?vertices.get_shared_row(0).max_min(xm):0,
        ym = 0, yM = vertices?vertices.get_shared_row(1).max_min(ym):0,
        zm = 0, zM = vertices?vertices.get_shared_row(2).max_min(zm):0;
      const float delta = cimg::max(xM-xm,yM-ym,zM-zm);

      rotated_bbox_vertices = bbox_vertices.assign(8,3,1,1,
                                                   xm,xM,xM,xm,xm,xM,xM,xm,
                                                   ym,ym,yM,yM,ym,ym,yM,yM,
                                                   zm,zm,zm,zm,zM,zM,zM,zM);
      bbox_primitives.assign(6,1,4,1,1, 0,3,2,1, 4,5,6,7, 1,2,6,5, 0,4,7,3, 0,1,5,4, 2,3,7,6);
      bbox_colors.assign(6,_spectrum,1,1,1,background_color[0]);
      bbox_colors2.assign(6,_spectrum,1,1,1,foreground_color[0]);
      bbox_opacities.assign(bbox_colors._width,1,1,1,0.3f);

      rotated_axes_vertices = axes_vertices.assign(7,3,1,1,
                                                   0,20,0,0,22,-6,-6,
                                                   0,0,20,0,-6,22,-6,
                                                   0,0,0,20,0,0,22);
      axes_opacities.assign(3,1,1,1,1);
      axes_colors.assign(3,_spectrum,1,1,1,foreground_color[0]);
      axes_primitives.assign(3,1,2,1,1, 0,1, 0,2, 0,3);

      // Begin user interaction loop
      CImg<T> visu0(*this), visu;
      CImg<tpfloat> zbuffer(visu0.width(),visu0.height(),1,1,0);
      bool init_pose = true, clicked = false, redraw = true;
      unsigned int key = 0;
      int
        x0 = 0, y0 = 0, x1 = 0, y1 = 0,
        nrender_static = render_static,
        nrender_motion = render_motion;
      disp.show().flush();

      while (!disp.is_closed() && !key) {

        // Init object pose
        if (init_pose) {
          const float
            ratio = delta>0?(2.0f*cimg::min(disp.width(),disp.height())/(3.0f*delta)):1,
            dx = (xM + xm)/2, dy = (yM + ym)/2, dz = (zM + zm)/2;
          if (centering)
            CImg<floatT>(4,3,1,1, ratio,0.,0.,-ratio*dx, 0.,ratio,0.,-ratio*dy, 0.,0.,ratio,-ratio*dz).move_to(pose);
          else CImg<floatT>(4,3,1,1, 1,0,0,0, 0,1,0,0, 0,0,1,0).move_to(pose);
          if (pose_matrix) {
            CImg<floatT> pose0(pose_matrix,4,3,1,1,false);
            pose0.resize(4,4,1,1,0); pose.resize(4,4,1,1,0);
            pose0(3,3) = pose(3,3) = 1;
            (pose0*pose).get_crop(0,0,3,2).move_to(pose);
            Xoff = pose_matrix[12]; Yoff = pose_matrix[13]; Zoff = pose_matrix[14]; sprite_scale = pose_matrix[15];
          } else { Xoff = Yoff = Zoff = 0; sprite_scale = 1; }
          init_pose = false;
          redraw = true;
        }

        // Rotate and draw 3d object
        if (redraw) {
          const float
            r00 = pose(0,0), r10 = pose(1,0), r20 = pose(2,0), r30 = pose(3,0),
            r01 = pose(0,1), r11 = pose(1,1), r21 = pose(2,1), r31 = pose(3,1),
            r02 = pose(0,2), r12 = pose(1,2), r22 = pose(2,2), r32 = pose(3,2);
          if ((clicked && nrender_motion>=0) || (!clicked && nrender_static>=0))
            cimg_forX(vertices,l) {
              const float x = (float)vertices(l,0), y = (float)vertices(l,1), z = (float)vertices(l,2);
              rotated_vertices(l,0) = r00*x + r10*y + r20*z + r30;
              rotated_vertices(l,1) = r01*x + r11*y + r21*z + r31;
              rotated_vertices(l,2) = r02*x + r12*y + r22*z + r32;
            }
          else cimg_forX(bbox_vertices,l) {
              const float x = bbox_vertices(l,0), y = bbox_vertices(l,1), z = bbox_vertices(l,2);
              rotated_bbox_vertices(l,0) = r00*x + r10*y + r20*z + r30;
              rotated_bbox_vertices(l,1) = r01*x + r11*y + r21*z + r31;
              rotated_bbox_vertices(l,2) = r02*x + r12*y + r22*z + r32;
            }

          // Draw objects
          visu = visu0;
          if ((clicked && nrender_motion<0) || (!clicked && nrender_static<0))
            visu.draw_object3d(Xoff + visu._width/2.0f,Yoff + visu._height/2.0f,Zoff,
                               rotated_bbox_vertices,bbox_primitives,bbox_colors,bbox_opacities,2,false,focale).
              draw_object3d(Xoff + visu._width/2.0f,Yoff + visu._height/2.0f,Zoff,
                            rotated_bbox_vertices,bbox_primitives,bbox_colors2,1,false,focale);
          else visu._draw_object3d((void*)0,(!clicked && nrender_static>0)?zbuffer.fill(0):CImg<tpfloat>::empty(),
                                   Xoff + visu._width/2.0f,Yoff + visu._height/2.0f,Zoff,
                                   rotated_vertices,reverse_primitives?reverse_primitives:primitives,
                                   colors,opacities,clicked?nrender_motion:nrender_static,_is_double_sided==1,focale,
                                   width()/2.0f+light_x,height()/2.0f+light_y,light_z+Zoff,specular_lightness,specular_shininess,
                                   sprite_scale);
          // Draw axes
          if (ndisplay_axes) {
            const float
              n = (float)std::sqrt(1e-8 + r00*r00 + r01*r01 + r02*r02),
              _r00 = r00/n, _r10 = r10/n, _r20 = r20/n,
              _r01 = r01/n, _r11 = r11/n, _r21 = r21/n,
              _r02 = r01/n, _r12 = r12/n, _r22 = r22/n,
              Xaxes = 25, Yaxes = visu._height - 38.0f;
            cimg_forX(axes_vertices,l) {
              const float
                x = axes_vertices(l,0),
                y = axes_vertices(l,1),
                z = axes_vertices(l,2);
              rotated_axes_vertices(l,0) = _r00*x + _r10*y + _r20*z;
              rotated_axes_vertices(l,1) = _r01*x + _r11*y + _r21*z;
              rotated_axes_vertices(l,2) = _r02*x + _r12*y + _r22*z;
            }
            axes_opacities(0,0) = (rotated_axes_vertices(1,2)>0)?0.5f:1.0f;
            axes_opacities(1,0) = (rotated_axes_vertices(2,2)>0)?0.5f:1.0f;
            axes_opacities(2,0) = (rotated_axes_vertices(3,2)>0)?0.5f:1.0f;
            visu.draw_object3d(Xaxes,Yaxes,0,rotated_axes_vertices,axes_primitives,axes_colors,axes_opacities,1,false,focale).
              draw_text((int)(Xaxes+rotated_axes_vertices(4,0)),
                        (int)(Yaxes+rotated_axes_vertices(4,1)),
                        "X",axes_colors[0]._data,0,axes_opacities(0,0),13).
              draw_text((int)(Xaxes+rotated_axes_vertices(5,0)),
                        (int)(Yaxes+rotated_axes_vertices(5,1)),
                        "Y",axes_colors[1]._data,0,axes_opacities(1,0),13).
              draw_text((int)(Xaxes+rotated_axes_vertices(6,0)),
                        (int)(Yaxes+rotated_axes_vertices(6,1)),
                        "Z",axes_colors[2]._data,0,axes_opacities(2,0),13);
          }
          visu.display(disp);
          if (!clicked || nrender_motion==nrender_static) redraw = false;
        }

        // Handle user interaction
        disp.wait();
        if ((disp.button() || disp.wheel()) && disp.mouse_x()>=0 && disp.mouse_y()>=0) {
          redraw = true;
          if (!clicked) { x0 = x1 = disp.mouse_x(); y0 = y1 = disp.mouse_y(); if (!disp.wheel()) clicked = true; }
          else { x1 = disp.mouse_x(); y1 = disp.mouse_y(); }
          if (disp.button()&1) {
            const float
              R = 0.45f*cimg::min(disp.width(),disp.height()),
              R2 = R*R,
              u0 = (float)(x0-disp.width()/2),
              v0 = (float)(y0-disp.height()/2),
              u1 = (float)(x1-disp.width()/2),
              v1 = (float)(y1-disp.height()/2),
              n0 = (float)std::sqrt(u0*u0+v0*v0),
              n1 = (float)std::sqrt(u1*u1+v1*v1),
              nu0 = n0>R?(u0*R/n0):u0,
              nv0 = n0>R?(v0*R/n0):v0,
              nw0 = (float)std::sqrt(cimg::max(0,R2-nu0*nu0-nv0*nv0)),
              nu1 = n1>R?(u1*R/n1):u1,
              nv1 = n1>R?(v1*R/n1):v1,
              nw1 = (float)std::sqrt(cimg::max(0,R2-nu1*nu1-nv1*nv1)),
              u = nv0*nw1-nw0*nv1,
              v = nw0*nu1-nu0*nw1,
              w = nv0*nu1-nu0*nv1,
              n = (float)std::sqrt(u*u+v*v+w*w),
              alpha = (float)std::asin(n/R2);
            (CImg<floatT>::rotation_matrix(u,v,w,alpha)*pose).move_to(pose);
            x0 = x1; y0 = y1;
          }
          if (disp.button()&2) {
            if (focale>0) Zoff-=(y0-y1)*focale/400;
            else { const float s = std::exp((y0-y1)/400.0f); pose*=s; sprite_scale*=s; }
            x0 = x1; y0 = y1;
          }
          if (disp.wheel()) {
            if (focale>0) Zoff-=disp.wheel()*focale/20;
            else { const float s = std::exp(disp.wheel()/20.0f); pose*=s; sprite_scale*=s; }
            disp.set_wheel();
          }
          if (disp.button()&4) { Xoff+=(x1-x0); Yoff+=(y1-y0); x0 = x1; y0 = y1; }
          if ((disp.button()&1) && (disp.button()&2)) {
            init_pose = true; disp.set_button(); x0 = x1; y0 = y1;
            pose = CImg<floatT>(4,3,1,1, 1,0,0,0, 0,1,0,0, 0,0,1,0);
          }
        } else if (clicked) { x0 = x1; y0 = y1; clicked = false; redraw = true; }

        switch (key = disp.key()) {
#if cimg_OS!=2
        case cimg::keyCTRLRIGHT :
#endif
# 39253 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        case 0 : case cimg::keyCTRLLEFT : key = 0; break;
        case cimg::keyD: if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
            disp.set_fullscreen(false).resize(CImgDisplay::_fitscreen(3*disp.width()/2,3*disp.height()/2,1,128,-100,false),
                                              CImgDisplay::_fitscreen(3*disp.width()/2,3*disp.height()/2,1,128,-100,true),false).
              _is_resized = true;
            disp.set_key(key,false); key = 0;
          } break;
        case cimg::keyC : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
            disp.set_fullscreen(false).resize(cimg_fitscreen(2*disp.width()/3,2*disp.height()/3,1),false)._is_resized = true;
            disp.set_key(key,false); key = 0;
          } break;
        case cimg::keyR : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
            disp.set_fullscreen(false).resize(cimg_fitscreen(_width,_height,_depth),false)._is_resized = true;
            disp.set_key(key,false); key = 0;
          } break;
        case cimg::keyF : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
            if (!ns_width || !ns_height ||
                ns_width>(unsigned int)disp.screen_width() || ns_height>(unsigned int)disp.screen_height()) {
              ns_width = disp.screen_width()*3U/4;
              ns_height = disp.screen_height()*3U/4;
            }
            if (disp.is_fullscreen()) disp.resize(ns_width,ns_height,false);
            else {
              ns_width = (unsigned int)disp.width(); ns_height = disp.height();
              disp.resize(disp.screen_width(),disp.screen_height(),false);
            }
            disp.toggle_fullscreen()._is_resized = true;
            disp.set_key(key,false); key = 0;
          } break;
        case cimg::keyT : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) { // Switch single/double-sided primitives.
            if (--_is_double_sided==-2) _is_double_sided = 1;
            if (_is_double_sided>=0) reverse_primitives.assign();
            else primitives.get_reverse_object3d().move_to(reverse_primitives);
            disp.set_key(key,false); key = 0; redraw = true;
          } break;
        case cimg::keyZ : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) { // Enable/disable Z-buffer
            if (zbuffer) zbuffer.assign();
            else zbuffer.assign(visu0.width(),visu0.height(),1,1,0);
            disp.set_key(key,false); key = 0; redraw = true;
          } break;
        case cimg::keyA : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) { // Show/hide 3d axes.
            ndisplay_axes = !ndisplay_axes;
            disp.set_key(key,false); key = 0; redraw = true;
          } break;
        case cimg::keyF1 : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) { // Set rendering mode to points.
            nrender_motion = (nrender_static==0 && nrender_motion!=0)?0:-1; nrender_static = 0;
            disp.set_key(key,false); key = 0; redraw = true;
          } break;
        case cimg::keyF2 : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) { // Set rendering mode to lines.
            nrender_motion = (nrender_static==1 && nrender_motion!=1)?1:-1; nrender_static = 1;
            disp.set_key(key,false); key = 0; redraw = true;
          } break;
        case cimg::keyF3 : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) { // Set rendering mode to flat.
            nrender_motion = (nrender_static==2 && nrender_motion!=2)?2:-1; nrender_static = 2;
            disp.set_key(key,false); key = 0; redraw = true;
          } break;
        case cimg::keyF4 : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) { // Set rendering mode to flat-shaded.
            nrender_motion = (nrender_static==3 && nrender_motion!=3)?3:-1; nrender_static = 3;
            disp.set_key(key,false); key = 0; redraw = true;
          } break;
        case cimg::keyF5 : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) { // Set rendering mode to gouraud-shaded.
            nrender_motion = (nrender_static==4 && nrender_motion!=4)?4:-1; nrender_static = 4;
            disp.set_key(key,false); key = 0; redraw = true;
          } break;
        case cimg::keyF6 : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) { // Set rendering mode to phong-shaded.
            nrender_motion = (nrender_static==5 && nrender_motion!=5)?5:-1; nrender_static = 5;
            disp.set_key(key,false); key = 0; redraw = true;
          } break;
        case cimg::keyS : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) { // Save snapshot
            static unsigned int snap_number = 0;
            char filename[32] = { 0 };
            std::FILE *file;
            do {
              cimg_snprintf(filename,sizeof(filename),cimg_appname "_%.4u.bmp",snap_number++);
              if ((file=std::fopen(filename,"r"))!=0) cimg::fclose(file);
            } while (file);
            (+visu).draw_text(0,0," Saving snapshot... ",foreground_color._data,background_color._data,1,13).display(disp);
            visu.save(filename);
            visu.draw_text(0,0," Snapshot '%s' saved. ",foreground_color._data,background_color._data,1,13,filename).display(disp);
            disp.set_key(key,false); key = 0;
          } break;
        case cimg::keyG : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) { // Save object as a .off file
            static unsigned int snap_number = 0;
            char filename[32] = { 0 };
            std::FILE *file;
            do {
              cimg_snprintf(filename,sizeof(filename),cimg_appname "_%.4u.off",snap_number++);
              if ((file=std::fopen(filename,"r"))!=0) cimg::fclose(file);
            } while (file);
            visu.draw_text(0,0," Saving object... ",foreground_color._data,background_color._data,1,13).display(disp);
            vertices.save_off(reverse_primitives?reverse_primitives:primitives,colors,filename);
            visu.draw_text(0,0," Object '%s' saved. ",foreground_color._data,background_color._data,1,13,filename).display(disp);
            disp.set_key(key,false); key = 0;
          } break;
        case cimg::keyO : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) { // Save object as a .cimg file
            static unsigned int snap_number = 0;
            char filename[32] = { 0 };
            std::FILE *file;
            do {
#ifdef cimg_use_zlib
              cimg_snprintf(filename,sizeof(filename),cimg_appname "_%.4u.cimgz",snap_number++);
#else
# 39355 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
              cimg_snprintf(filename,sizeof(filename),cimg_appname "_%.4u.cimg",snap_number++);
#endif
# 39357 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
              if ((file=std::fopen(filename,"r"))!=0) cimg::fclose(file);
            } while (file);
            visu.draw_text(0,0," Saving object... ",foreground_color._data,background_color._data,1,13).display(disp);
            vertices.get_object3dtoCImg3d(reverse_primitives?reverse_primitives:primitives,colors,opacities).save(filename);
            visu.draw_text(0,0," Object '%s' saved. ",foreground_color._data,background_color._data,1,13,filename).display(disp);
            disp.set_key(key,false); key = 0;
          } break;
#ifdef cimg_use_board
        case cimg::keyP : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) { // Save object as a .EPS file
            static unsigned int snap_number = 0;
            char filename[32] = { 0 };
            std::FILE *file;
            do {
              cimg_snprintf(filename,sizeof(filename),cimg_appname "_%.4u.eps",snap_number++);
              if ((file=std::fopen(filename,"r"))!=0) cimg::fclose(file);
            } while (file);
            visu.draw_text(0,0," Saving EPS snapshot... ",foreground_color._data,background_color._data,1,13).display(disp);
            LibBoard::Board board;
            (+visu)._draw_object3d(&board,zbuffer.fill(0),
                                   Xoff + visu._width/2.0f,Yoff + visu._height/2.0f,Zoff,
                                   rotated_vertices,reverse_primitives?reverse_primitives:primitives,
                                   colors,opacities,clicked?nrender_motion:nrender_static,
                                   _is_double_sided==1,focale,
                                   visu.width()/2.0f+light_x,visu.height()/2.0f+light_y,light_z+Zoff,specular_lightness,specular_shininess,
                                   sprite_scale);
            board.saveEPS(filename);
            visu.draw_text(0,0," Object '%s' saved. ",foreground_color._data,background_color._data,1,13,filename).display(disp);
            disp.set_key(key,false); key = 0;
          } break;
        case cimg::keyV : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) { // Save object as a .SVG file
            static unsigned int snap_number = 0;
            char filename[32] = { 0 };
            std::FILE *file;
            do {
              cimg_snprintf(filename,sizeof(filename),cimg_appname "_%.4u.svg",snap_number++);
              if ((file=std::fopen(filename,"r"))!=0) cimg::fclose(file);
            } while (file);
            visu.draw_text(0,0," Saving SVG snapshot... ",foreground_color._data,background_color._data,1,13).display(disp);
            LibBoard::Board board;
            (+visu)._draw_object3d(&board,zbuffer.fill(0),
                                   Xoff + visu._width/2.0f,Yoff + visu._height/2.0f,Zoff,
                                   rotated_vertices,reverse_primitives?reverse_primitives:primitives,
                                   colors,opacities,clicked?nrender_motion:nrender_static,
                                   _is_double_sided==1,focale,
                                   visu.width()/2.0f+light_x,visu.height()/2.0f+light_y,light_z+Zoff,specular_lightness,specular_shininess,
                                   sprite_scale);
            board.saveSVG(filename);
            visu.draw_text(0,0," Object '%s' saved. ",foreground_color._data,background_color._data,1,13,filename).display(disp);
            disp.set_key(key,false); key = 0;
          } break;
#endif
# 39408 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        }
        if (disp.is_resized()) {
          disp.resize(false); visu0 = get_resize(disp,1);
          if (zbuffer) zbuffer.assign(disp.width(),disp.height());
          redraw = true;
        }
      }
      if (pose_matrix) {
        std::memcpy(pose_matrix,pose._data,12*sizeof(float));
        pose_matrix[12] = Xoff; pose_matrix[13] = Yoff; pose_matrix[14] = Zoff; pose_matrix[15] = sprite_scale;
      }
      disp.set_button().set_key(key);
      return *this;
    }

    //! Display 1d graph in an interactive window.
    /**
       \param disp Display window.
       \param plot_type Plot type. Can be <tt>{ 0=points | 1=segments | 2=splines | 3=bars }</tt>.
       \param vertex_type Vertex type.
       \param labelx Title for the horizontal axis, as a C-string.
       \param xmin Minimum value along the X-axis.
       \param xmax Maximum value along the X-axis.
       \param labely Title for the vertical axis, as a C-string.
       \param ymin Minimum value along the X-axis.
       \param ymax Maximum value along the X-axis.
    **/
    const CImg<T>& display_graph(CImgDisplay &disp,
                                 const unsigned int plot_type=1, const unsigned int vertex_type=1,
                                 const char *const labelx=0, const double xmin=0, const double xmax=0,
                                 const char *const labely=0, const double ymin=0, const double ymax=0) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "display_graph(): Empty instance.",
                                    cimg_instance);
      if (!disp) disp.assign(cimg_fitscreen(640,480,1),0,0).set_title("CImg<%s>",pixel_type());
      const unsigned long siz = (unsigned long)_width*_height*_depth, siz1 = cimg::max(1U,siz-1);
      const unsigned int old_normalization = disp.normalization();
      disp.show().flush()._normalization = 0;

      double y0 = ymin, y1 = ymax, nxmin = xmin, nxmax = xmax;
      if (nxmin==nxmax) { nxmin = 0; nxmax = siz1; }
      int x0 = 0, x1 = width()*height()*depth() - 1, key = 0;

      for (bool reset_view = true, resize_disp = false; !key && !disp.is_closed(); ) {
        if (reset_view) { x0 = 0; x1 = width()*height()*depth()-1; y0 = ymin; y1 = ymax; reset_view = false; }
        CImg<T> zoom(x1-x0+1,1,1,spectrum());
        cimg_forC(*this,c) zoom.get_shared_channel(c) = CImg<T>(data(x0,0,0,c),x1-x0+1,1,1,1,true);

        if (y0==y1) { y0 = zoom.min_max(y1); const double dy = y1 - y0; y0-=dy/20; y1+=dy/20; }
        if (y0==y1) { --y0; ++y1; }
        const CImg<intT> selection = zoom.get_select_graph(disp,plot_type,vertex_type,
        					           labelx,
                                                           nxmin + x0*(nxmax-nxmin)/siz1,
                                                           nxmin + x1*(nxmax-nxmin)/siz1,
                                                           labely,y0,y1);
	const int mouse_x = disp.mouse_x(), mouse_y = disp.mouse_y();
        if (selection[0]>=0) {
          if (selection[2]<0) reset_view = true;
          else {
            x1 = x0 + selection[2]; x0+=selection[0];
            if (selection[1]>=0 && selection[3]>=0) {
              y0 = y1 - selection[3]*(y1-y0)/(disp.height()-32);
              y1-=selection[1]*(y1-y0)/(disp.height()-32);
            }
          }
        } else {
          bool go_in = false, go_out = false, go_left = false, go_right = false, go_up = false, go_down = false;
          switch (key = disp.key()) {
          case cimg::keyHOME : reset_view = resize_disp = true; key = 0; disp.set_key(); break;
          case cimg::keyPADADD : go_in = true; go_out = false; key = 0; disp.set_key(); break;
          case cimg::keyPADSUB : go_out = true; go_in = false; key = 0; disp.set_key(); break;
          case cimg::keyARROWLEFT : case cimg::keyPAD4 : go_left = true; go_right = false; key = 0; disp.set_key(); break;
          case cimg::keyARROWRIGHT : case cimg::keyPAD6 : go_right = true; go_left = false; key = 0; disp.set_key(); break;
          case cimg::keyARROWUP : case cimg::keyPAD8 : go_up = true; go_down = false; key = 0; disp.set_key(); break;
          case cimg::keyARROWDOWN : case cimg::keyPAD2 : go_down = true; go_up = false; key = 0; disp.set_key(); break;
          case cimg::keyPAD7 : go_left = true; go_up = true; key = 0; disp.set_key(); break;
          case cimg::keyPAD9 : go_right = true; go_up = true; key = 0; disp.set_key(); break;
          case cimg::keyPAD1 : go_left = true; go_down = true; key = 0; disp.set_key(); break;
          case cimg::keyPAD3 : go_right = true; go_down = true; key = 0; disp.set_key(); break;
          }
          if (disp.wheel()) {
            if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) go_out = !(go_in = disp.wheel()>0);
            else if (disp.is_keySHIFTLEFT() || disp.is_keySHIFTRIGHT()) go_left = !(go_right = disp.wheel()>0);
            else go_up = !(go_down = disp.wheel()<0);
            key = 0;
          }

          if (go_in) {
            const int
              xsiz = x1 - x0,
              mx = (mouse_x-16)*xsiz/(disp.width()-32),
              cx = x0 + (mx<0?0:(mx>=xsiz?xsiz:mx));
            if (x1-x0>4) {
              x0 = cx - 7*(cx-x0)/8; x1 = cx + 7*(x1-cx)/8;
              if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
                const double
                  ysiz = y1 - y0,
                  my = (mouse_y-16)*ysiz/(disp.height()-32),
                  cy = y1 - (my<0?0:(my>=ysiz?ysiz:my));
                y0 = cy - 7*(cy-y0)/8; y1 = cy + 7*(y1-cy)/8;
              } else y0 = y1 = 0;
            }
          }
          if (go_out) {
            if (x0>0 || x1<(int)siz1) {
              const int delta_x = (x1-x0)/8, ndelta_x = delta_x?delta_x:(siz>1?1:0);
              const double ndelta_y = (y1-y0)/8;
              x0-=ndelta_x; x1+=ndelta_x;
              y0-=ndelta_y; y1+=ndelta_y;
              if (x0<0) { x1-=x0; x0 = 0; if (x1>=(int)siz) x1 = (int)siz1; }
              if (x1>=(int)siz) { x0-=(x1-siz1); x1 = (int)siz1; if (x0<0) x0 = 0; }
            }
          }
          if (go_left) {
            const int delta = (x1-x0)/5, ndelta = delta?delta:1;
            if (x0-ndelta>=0) { x0-=ndelta; x1-=ndelta; }
            else { x1-=x0; x0 = 0; }
            go_left = false;
          }
          if (go_right) {
            const int delta = (x1-x0)/5, ndelta = delta?delta:1;
            if (x1+ndelta<(int)siz) { x0+=ndelta; x1+=ndelta; }
            else { x0+=(siz1-x1); x1 = siz1; }
            go_right = false;
          }
          if (go_up) {
            const double delta = (y1-y0)/10, ndelta = delta?delta:1;
            y0+=ndelta; y1+=ndelta;
            go_up = false;
          }
          if (go_down) {
            const double delta = (y1-y0)/10, ndelta = delta?delta:1;
            y0-=ndelta; y1-=ndelta;
            go_down = false;
          }
        }
      }
      disp._normalization = old_normalization;
      return *this;
    }

    //! Display 1d graph in an interactive window \overloading.
    const CImg<T>& display_graph(const char *const title=0,
                                 const unsigned int plot_type=1, const unsigned int vertex_type=1,
                                 const char *const labelx=0, const double xmin=0, const double xmax=0,
                                 const char *const labely=0, const double ymin=0, const double ymax=0) const {
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "display_graph(): Empty instance.",
                                    cimg_instance);
      CImgDisplay disp;
      return display_graph(disp.set_title("%s",title),plot_type,vertex_type,labelx,xmin,xmax,labely,ymin,ymax);
    }

    //! Save image as a file.
    /**
       \param filename Filename, as a C-string.
       \param number When positive, represents an index added to the filename. Otherwise, no number is added.
       \param digits Number of digits used for adding the number to the filename.
       \note
       - The used file format is defined by the file extension in the filename \p filename.
       - Parameter \p number can be used to add a 6-digit number to the filename before saving.

    **/
    const CImg<T>& save(const char *const filename, const int number=-1, const unsigned int digits=6) const {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "save(): Specified filename is (null).",
                                    cimg_instance);
      // Do not test for empty instances, since .cimg format is able to manage empty instances.
      const char *const ext = cimg::split_filename(filename);
      char nfilename[1024] = { 0 };
      const char *const fn = (number>=0)?cimg::number_filename(filename,number,digits,nfilename):filename;

#ifdef cimg_save_plugin
      cimg_save_plugin(fn);
#endif
# 39586 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_save_plugin1
      cimg_save_plugin1(fn);
#endif
# 39589 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_save_plugin2
      cimg_save_plugin2(fn);
#endif
# 39592 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_save_plugin3
      cimg_save_plugin3(fn);
#endif
# 39595 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_save_plugin4
      cimg_save_plugin4(fn);
#endif
# 39598 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_save_plugin5
      cimg_save_plugin5(fn);
#endif
# 39601 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_save_plugin6
      cimg_save_plugin6(fn);
#endif
# 39604 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_save_plugin7
      cimg_save_plugin7(fn);
#endif
# 39607 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimg_save_plugin8
      cimg_save_plugin8(fn);
#endif
# 39610 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      // Ascii formats
      if (!cimg::strcasecmp(ext,"asc")) return save_ascii(fn);
      else if (!cimg::strcasecmp(ext,"dlm") ||
               !cimg::strcasecmp(ext,"txt")) return save_dlm(fn);
      else if (!cimg::strcasecmp(ext,"cpp") ||
               !cimg::strcasecmp(ext,"hpp") ||
               !cimg::strcasecmp(ext,"h") ||
               !cimg::strcasecmp(ext,"c")) return save_cpp(fn);

      // 2d binary formats
      else if (!cimg::strcasecmp(ext,"bmp")) return save_bmp(fn);
      else if (!cimg::strcasecmp(ext,"jpg") ||
               !cimg::strcasecmp(ext,"jpeg") ||
               !cimg::strcasecmp(ext,"jpe") ||
               !cimg::strcasecmp(ext,"jfif") ||
               !cimg::strcasecmp(ext,"jif")) return save_jpeg(fn);
      else if (!cimg::strcasecmp(ext,"rgb")) return save_rgb(fn);
      else if (!cimg::strcasecmp(ext,"rgba")) return save_rgba(fn);
      else if (!cimg::strcasecmp(ext,"png")) return save_png(fn);
      else if (!cimg::strcasecmp(ext,"pgm") ||
               !cimg::strcasecmp(ext,"ppm") ||
               !cimg::strcasecmp(ext,"pnm")) return save_pnm(fn);
      else if (!cimg::strcasecmp(ext,"pnk")) return save_pnk(fn);
      else if (!cimg::strcasecmp(ext,"pfm")) return save_pfm(fn);
      else if (!cimg::strcasecmp(ext,"exr")) return save_exr(fn);
      else if (!cimg::strcasecmp(ext,"tif") ||
               !cimg::strcasecmp(ext,"tiff")) return save_tiff(fn);

      // 3d binary formats
      else if (!cimg::strcasecmp(ext,"cimgz")) return save_cimg(fn,true);
      else if (!cimg::strcasecmp(ext,"cimg") || !*ext) return save_cimg(fn,false);
      else if (!cimg::strcasecmp(ext,"dcm")) return save_medcon_external(fn);
      else if (!cimg::strcasecmp(ext,"hdr") ||
               !cimg::strcasecmp(ext,"nii")) return save_analyze(fn);
      else if (!cimg::strcasecmp(ext,"inr")) return save_inr(fn);
      else if (!cimg::strcasecmp(ext,"mnc")) return save_minc2(fn);
      else if (!cimg::strcasecmp(ext,"pan")) return save_pandore(fn);
      else if (!cimg::strcasecmp(ext,"raw")) return save_raw(fn);

      // Archive files
      else if (!cimg::strcasecmp(ext,"gz")) return save_gzip_external(fn);

      // Image sequences
      else if (!cimg::strcasecmp(ext,"yuv")) return save_yuv(fn,true);
      else if (!cimg::strcasecmp(ext,"avi") ||
               !cimg::strcasecmp(ext,"mov") ||
               !cimg::strcasecmp(ext,"asf") ||
               !cimg::strcasecmp(ext,"divx") ||
               !cimg::strcasecmp(ext,"flv") ||
               !cimg::strcasecmp(ext,"mpg") ||
               !cimg::strcasecmp(ext,"m1v") ||
               !cimg::strcasecmp(ext,"m2v") ||
               !cimg::strcasecmp(ext,"m4v") ||
               !cimg::strcasecmp(ext,"mjp") ||
               !cimg::strcasecmp(ext,"mkv") ||
               !cimg::strcasecmp(ext,"mpe") ||
               !cimg::strcasecmp(ext,"movie") ||
               !cimg::strcasecmp(ext,"ogm") ||
               !cimg::strcasecmp(ext,"ogg") ||
               !cimg::strcasecmp(ext,"qt") ||
               !cimg::strcasecmp(ext,"rm") ||
               !cimg::strcasecmp(ext,"vob") ||
               !cimg::strcasecmp(ext,"wmv") ||
               !cimg::strcasecmp(ext,"xvid") ||
               !cimg::strcasecmp(ext,"mpeg")) return save_ffmpeg(fn);
      return save_other(fn);
    }

    //! Save image as an ascii file.
    /**
      \param filename Filename, as a C-string.
    **/
    const CImg<T>& save_ascii(const char *const filename) const {
      return _save_ascii(0,filename);
    }

    //! Save image as an ascii file \overloading.
    const CImg<T>& save_ascii(std::FILE *const file) const {
      return _save_ascii(file,0);
    }

    const CImg<T>& _save_ascii(std::FILE *const file, const char *const filename) const {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_ascii(): Specified filename is (null).",
                                    cimg_instance);
      std::FILE *const nfile = file?file:cimg::fopen(filename,"w");
      std::fprintf(nfile,"%u %u %u %u\n",_width,_height,_depth,_spectrum);
      const T* ptrs = _data;
      cimg_forYZC(*this,y,z,c) {
        cimg_forX(*this,x) std::fprintf(nfile,"%.16g ",(double)*(ptrs++));
        std::fputc('\n',nfile);
      }
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Save image as a .cpp source file.
    /**
      \param filename Filename, as a C-string.
    **/
    const CImg<T>& save_cpp(const char *const filename) const {
      return _save_cpp(0,filename);
    }

    //! Save image as a .cpp source file \overloading.
    const CImg<T>& save_cpp(std::FILE *const file) const {
      return _save_cpp(file,0);
    }

    const CImg<T>& _save_cpp(std::FILE *const file, const char *const filename) const {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_cpp(): Specified filename is (null).",
                                    cimg_instance);
      std::FILE *const nfile = file?file:cimg::fopen(filename,"w");
      char varname[1024] = { 0 };
      if (filename) std::sscanf(cimg::basename(filename),"%1023[a-zA-Z0-9_]",varname);
      if (!*varname) cimg_snprintf(varname,sizeof(varname),"unnamed");
      std::fprintf(nfile,
                   "/* Define image '%s' of size %ux%ux%ux%u and type '%s' */\n"
                   "%s data_%s[] = { %s\n  ",
                   varname,_width,_height,_depth,_spectrum,pixel_type(),pixel_type(),varname,
                   is_empty()?"};":"");
      if (!is_empty()) for (unsigned long off = 0, siz = size()-1; off<=siz; ++off) {
        std::fprintf(nfile,cimg::type<T>::format(),cimg::type<T>::format((*this)[off]));
        if (off==siz) std::fprintf(nfile," };\n");
        else if (!((off+1)%16)) std::fprintf(nfile,",\n  ");
        else std::fprintf(nfile,", ");
      }
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Save image as a DLM file.
    /**
       \param filename Filename, as a C-string.
    **/
    const CImg<T>& save_dlm(const char *const filename) const {
      return _save_dlm(0,filename);
    }

    //! Save image as a DLM file \overloading.
    const CImg<T>& save_dlm(std::FILE *const file) const {
      return _save_dlm(file,0);
    }

    const CImg<T>& _save_dlm(std::FILE *const file, const char *const filename) const {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_dlm(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(file,filename); return *this; }
      if (_depth>1)
        cimg::warn(_cimg_instance
                   "save_dlm(): Instance is volumetric, values along Z will be unrolled in file '%s'.",
                   cimg_instance,
                   filename?filename:"(FILE*)");
      if (_spectrum>1)
        cimg::warn(_cimg_instance
                   "save_dlm(): Instance is multispectral, values along C will be unrolled in file '%s'.",
                   cimg_instance,
                   filename?filename:"(FILE*)");

      std::FILE *const nfile = file?file:cimg::fopen(filename,"w");
      const T* ptrs = _data;
      cimg_forYZC(*this,y,z,c) {
        cimg_forX(*this,x) std::fprintf(nfile,"%.16g%s",(double)*(ptrs++),(x==width()-1)?"":",");
        std::fputc('\n',nfile);
      }
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Save image as a BMP file.
    /**
      \param filename Filename, as a C-string.
    **/
    const CImg<T>& save_bmp(const char *const filename) const {
      return _save_bmp(0,filename);
    }

    //! Save image as a BMP file \overloading.
    const CImg<T>& save_bmp(std::FILE *const file) const {
      return _save_bmp(file,0);
    }

    const CImg<T>& _save_bmp(std::FILE *const file, const char *const filename) const {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_bmp(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(file,filename); return *this; }
      if (_depth>1)
        cimg::warn(_cimg_instance
                   "save_bmp(): Instance is volumetric, only the first slice will be saved in file '%s'.",
                   cimg_instance,
                   filename?filename:"(FILE*)");
      if (_spectrum>3)
        cimg::warn(_cimg_instance
                   "save_bmp(): Instance is multispectral, only the three first channels will be saved in file '%s'.",
                   cimg_instance,
                   filename?filename:"(FILE*)");

      std::FILE *const nfile = file?file:cimg::fopen(filename,"wb");
      unsigned char header[54] = { 0 }, align_buf[4] = { 0 };
      const unsigned int
        align = (4 - (3*_width)%4)%4,
        buf_size = (3*_width + align)*height(),
        file_size = 54 + buf_size;
      header[0] = 'B'; header[1] = 'M';
      header[0x02] = file_size&0xFF;
      header[0x03] = (file_size>>8)&0xFF;
      header[0x04] = (file_size>>16)&0xFF;
      header[0x05] = (file_size>>24)&0xFF;
      header[0x0A] = 0x36;
      header[0x0E] = 0x28;
      header[0x12] = _width&0xFF;
      header[0x13] = (_width>>8)&0xFF;
      header[0x14] = (_width>>16)&0xFF;
      header[0x15] = (_width>>24)&0xFF;
      header[0x16] = _height&0xFF;
      header[0x17] = (_height>>8)&0xFF;
      header[0x18] = (_height>>16)&0xFF;
      header[0x19] = (_height>>24)&0xFF;
      header[0x1A] = 1;
      header[0x1B] = 0;
      header[0x1C] = 24;
      header[0x1D] = 0;
      header[0x22] = buf_size&0xFF;
      header[0x23] = (buf_size>>8)&0xFF;
      header[0x24] = (buf_size>>16)&0xFF;
      header[0x25] = (buf_size>>24)&0xFF;
      header[0x27] = 0x1;
      header[0x2B] = 0x1;
      cimg::fwrite(header,54,nfile);

      const T
        *ptr_r = data(0,_height-1,0,0),
        *ptr_g = (_spectrum>=2)?data(0,_height-1,0,1):0,
        *ptr_b = (_spectrum>=3)?data(0,_height-1,0,2):0;

      switch (_spectrum) {
      case 1 : {
        cimg_forY(*this,y) {
          cimg_forX(*this,x) {
            const unsigned char val = (unsigned char)*(ptr_r++);
            std::fputc(val,nfile); std::fputc(val,nfile); std::fputc(val,nfile);
          }
          cimg::fwrite(align_buf,align,nfile);
          ptr_r-=2*_width;
        }
      } break;
      case 2 : {
        cimg_forY(*this,y) {
          cimg_forX(*this,x) {
            std::fputc(0,nfile);
            std::fputc((unsigned char)(*(ptr_g++)),nfile);
            std::fputc((unsigned char)(*(ptr_r++)),nfile);
          }
          cimg::fwrite(align_buf,align,nfile);
          ptr_r-=2*_width; ptr_g-=2*_width;
        }
      } break;
      default : {
        cimg_forY(*this,y) {
          cimg_forX(*this,x) {
            std::fputc((unsigned char)(*(ptr_b++)),nfile);
            std::fputc((unsigned char)(*(ptr_g++)),nfile);
            std::fputc((unsigned char)(*(ptr_r++)),nfile);
          }
          cimg::fwrite(align_buf,align,nfile);
          ptr_r-=2*_width; ptr_g-=2*_width; ptr_b-=2*_width;
        }
      }
      }
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Save image as a JPEG file.
    /**
      \param filename Filename, as a C-string.
      \param quality Image quality (in %)
    **/
    const CImg<T>& save_jpeg(const char *const filename, const unsigned int quality=100) const {
      return _save_jpeg(0,filename,quality);
    }

    //! Save image as a JPEG file \overloading.
    const CImg<T>& save_jpeg(std::FILE *const file, const unsigned int quality=100) const {
      return _save_jpeg(file,0,quality);
    }

    const CImg<T>& _save_jpeg(std::FILE *const file, const char *const filename, const unsigned int quality) const {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_jpeg(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(file,filename); return *this; }
      if (_depth>1)
        cimg::warn(_cimg_instance
                   "save_jpeg(): Instance is volumetric, only the first slice will be saved in file '%s'.",
                   cimg_instance,
                   filename?filename:"(FILE*)");

#ifndef cimg_use_jpeg
      if (!file) return save_other(filename,quality);
      else throw CImgIOException(_cimg_instance
                                 "save_jpeg(): Unable to save data in '(*FILE)' unless libjpeg is enabled.",
                                 cimg_instance);
#else
# 39922 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      unsigned int dimbuf = 0;
      J_COLOR_SPACE colortype = JCS_RGB;

      switch(_spectrum) {
      case 1 : dimbuf = 1; colortype = JCS_GRAYSCALE; break;
      case 2 : dimbuf = 3; colortype = JCS_RGB; break;
      case 3 : dimbuf = 3; colortype = JCS_RGB; break;
      default : dimbuf = 4; colortype = JCS_CMYK; break;
      }

      // Call libjpeg functions
      struct jpeg_compress_struct cinfo;
      struct jpeg_error_mgr jerr;
      cinfo.err = jpeg_std_error(&jerr);
      jpeg_create_compress(&cinfo);
      std::FILE *const nfile = file?file:cimg::fopen(filename,"wb");
      jpeg_stdio_dest(&cinfo,nfile);
      cinfo.image_width = _width;
      cinfo.image_height = _height;
      cinfo.input_components = dimbuf;
      cinfo.in_color_space = colortype;
      jpeg_set_defaults(&cinfo);
      jpeg_set_quality(&cinfo,quality<100?quality:100,TRUE);
      jpeg_start_compress(&cinfo,TRUE);

      JSAMPROW row_pointer[1];
      CImg<ucharT> buffer((unsigned long)_width*dimbuf);

      while (cinfo.next_scanline<cinfo.image_height) {
        unsigned char *ptrd = buffer._data;

        // Fill pixel buffer
        switch (_spectrum) {
        case 1 : { // Greyscale images
          const T *ptr_g = data(0, cinfo.next_scanline);
          for(unsigned int b = 0; b < cinfo.image_width; b++)
            *(ptrd++) = (unsigned char)*(ptr_g++);
        } break;
        case 2 : { // RG images
          const T *ptr_r = data(0,cinfo.next_scanline,0,0),
            *ptr_g = data(0,cinfo.next_scanline,0,1);
          for(unsigned int b = 0; b < cinfo.image_width; ++b) {
            *(ptrd++) = (unsigned char)*(ptr_r++);
            *(ptrd++) = (unsigned char)*(ptr_g++);
            *(ptrd++) = 0;
          }
        } break;
        case 3 : { // RGB images
          const T *ptr_r = data(0,cinfo.next_scanline,0,0),
            *ptr_g = data(0,cinfo.next_scanline,0,1),
            *ptr_b = data(0,cinfo.next_scanline,0,2);
          for(unsigned int b = 0; b < cinfo.image_width; ++b) {
            *(ptrd++) = (unsigned char)*(ptr_r++);
            *(ptrd++) = (unsigned char)*(ptr_g++);
            *(ptrd++) = (unsigned char)*(ptr_b++);
          }
        } break;
        default : { // CMYK images
          const T *ptr_r = data(0,cinfo.next_scanline,0,0),
            *ptr_g = data(0,cinfo.next_scanline,0,1),
            *ptr_b = data(0,cinfo.next_scanline,0,2),
            *ptr_a = data(0,cinfo.next_scanline,0,3);
          for(unsigned int b = 0; b < cinfo.image_width; ++b) {
            *(ptrd++) = (unsigned char)*(ptr_r++);
            *(ptrd++) = (unsigned char)*(ptr_g++);
            *(ptrd++) = (unsigned char)*(ptr_b++);
            *(ptrd++) = (unsigned char)*(ptr_a++);
          }
        }
        }
        *row_pointer = buffer._data;
        jpeg_write_scanlines(&cinfo,row_pointer,1);
      }
      jpeg_finish_compress(&cinfo);
      if (!file) cimg::fclose(nfile);
      jpeg_destroy_compress(&cinfo);
      return *this;
#endif
# 40000 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    }

    //! Save image, using built-in ImageMagick++ library.
    /**
      \param filename Filename, as a C-string.
      \param bytes_per_pixel Force the number of bytes per pixel for the saving, when possible.
    **/
    const CImg<T>& save_magick(const char *const filename, const unsigned int bytes_per_pixel=0) const {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_magick(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(0,filename); return *this; }

#ifdef cimg_use_magick
      double stmin, stmax = (double)max_min(stmin);
      if (_depth>1)
        cimg::warn(_cimg_instance
                   "save_magick(): Instance is volumetric, only the first slice will be saved in file '%s'.",
                   cimg_instance,
                   filename);

      if (_spectrum>3)
        cimg::warn(_cimg_instance
                   "save_magick(): Instance is multispectral, only the three first channels will be saved in file '%s'.",
                   cimg_instance,
                   filename);

      if (stmin<0 || (bytes_per_pixel==1 && stmax>=256) || stmax>=65536)
        cimg::warn(_cimg_instance
                   "save_magick(): Instance has pixel values in [%g,%g], probable type overflow in file '%s'.",
                   cimg_instance,
                   filename,stmin,stmax);

      Magick::Image image(Magick::Geometry(_width,_height),"black");
      image.type(Magick::TrueColorType);
      image.depth(bytes_per_pixel?(8*bytes_per_pixel):(stmax>=256?16:8));
      const T
        *ptr_r = data(0,0,0,0),
        *ptr_g = _spectrum>1?data(0,0,0,1):0,
        *ptr_b = _spectrum>2?data(0,0,0,2):0;
      Magick::PixelPacket *pixels = image.getPixels(0,0,_width,_height);
      switch (_spectrum) {
      case 1 : // Scalar images
        for (unsigned long off = (unsigned long)_width*_height; off; --off) {
          pixels->red = pixels->green = pixels->blue = (Magick::Quantum)*(ptr_r++);
          ++pixels;
        }
        break;
      case 2 : // RG images
        for (unsigned long off = (unsigned long)_width*_height; off; --off) {
          pixels->red = (Magick::Quantum)*(ptr_r++);
          pixels->green = (Magick::Quantum)*(ptr_g++);
          pixels->blue = 0; ++pixels;
        }
        break;
      default : // RGB images
        for (unsigned long off = (unsigned long)_width*_height; off; --off) {
          pixels->red = (Magick::Quantum)*(ptr_r++);
          pixels->green = (Magick::Quantum)*(ptr_g++);
          pixels->blue = (Magick::Quantum)*(ptr_b++);
          ++pixels;
        }
      }
      image.syncPixels();
      image.write(filename);
#else
# 40067 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      cimg::unused(bytes_per_pixel);
      throw CImgIOException(_cimg_instance
                            "save_magick(): Unable to save file '%s' unless libMagick++ is enabled.",
                            cimg_instance,
                            filename);
#endif
# 40073 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      return *this;
    }

    //! Save image as a PNG file.
    /**
       \param filename Filename, as a C-string.
       \param bytes_per_pixel Force the number of bytes per pixels for the saving, when possible.
    **/
    const CImg<T>& save_png(const char *const filename, const unsigned int bytes_per_pixel=0) const {
      return _save_png(0,filename,bytes_per_pixel);
    }

    //! Save image as a PNG file \overloading.
    const CImg<T>& save_png(std::FILE *const file, const unsigned int bytes_per_pixel=0) const {
      return _save_png(file,0,bytes_per_pixel);
    }

    const CImg<T>& _save_png(std::FILE *const file, const char *const filename, const unsigned int bytes_per_pixel=0) const {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_png(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(file,filename); return *this; }

#ifndef cimg_use_png
      cimg::unused(bytes_per_pixel);
      if (!file) return save_other(filename);
      else throw CImgIOException(_cimg_instance
                                 "save_png(): Unable to save data in '(*FILE)' unless libpng is enabled.",
                                 cimg_instance);
#else
# 40104 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      const char *volatile nfilename = filename; // two 'volatile' here to remove a g++ warning due to 'setjmp'.
      std::FILE *volatile nfile = file?file:cimg::fopen(nfilename,"wb");

      double stmin, stmax = (double)max_min(stmin);
      if (_depth>1)
        cimg::warn(_cimg_instance
                   "save_png(): Instance is volumetric, only the first slice will be saved in file '%s'.",
                   cimg_instance,
                   filename);

      if (_spectrum>4)
        cimg::warn(_cimg_instance
                   "save_png(): Instance is multispectral, only the three first channels will be saved in file '%s'.",
                   cimg_instance,
                   filename);

      if (stmin<0 || (bytes_per_pixel==1 && stmax>=256) || stmax>=65536)
        cimg::warn(_cimg_instance
                   "save_png(): Instance has pixel values in [%g,%g], probable type overflow in file '%s'.",
                   cimg_instance,
                   filename,stmin,stmax);

      // Setup PNG structures for write
      png_voidp user_error_ptr = 0;
      png_error_ptr user_error_fn = 0, user_warning_fn = 0;
      png_structp png_ptr = png_create_write_struct(PNG_LIBPNG_VER_STRING,user_error_ptr, user_error_fn, user_warning_fn);
      if(!png_ptr){
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimg_instance
                              "save_png(): Failed to initialize 'png_ptr' structure when saving file '%s'.",
                              cimg_instance,
                              nfilename?nfilename:"(FILE*)");
      }
      png_infop info_ptr = png_create_info_struct(png_ptr);
      if (!info_ptr) {
        png_destroy_write_struct(&png_ptr,(png_infopp)0);
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimg_instance
                              "save_png(): Failed to initialize 'info_ptr' structure when saving file '%s'.",
                              cimg_instance,
                              nfilename?nfilename:"(FILE*)");
      }
      if (setjmp(png_jmpbuf(png_ptr))) {
        png_destroy_write_struct(&png_ptr, &info_ptr);
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimg_instance
                              "save_png(): Encountered unknown fatal error in libpng when saving file '%s'.",
                              cimg_instance,
                              nfilename?nfilename:"(FILE*)");
      }
      png_init_io(png_ptr, nfile);
      const int bit_depth = bytes_per_pixel?(bytes_per_pixel*8):(stmax>=256?16:8);
      int color_type;
      switch (spectrum()) {
      case 1 : color_type = PNG_COLOR_TYPE_GRAY; break;
      case 2 : color_type = PNG_COLOR_TYPE_GRAY_ALPHA; break;
      case 3 : color_type = PNG_COLOR_TYPE_RGB; break;
      default : color_type = PNG_COLOR_TYPE_RGB_ALPHA;
      }
      const int interlace_type = PNG_INTERLACE_NONE;
      const int compression_type = PNG_COMPRESSION_TYPE_DEFAULT;
      const int filter_method = PNG_FILTER_TYPE_DEFAULT;
      png_set_IHDR(png_ptr,info_ptr,_width,_height,bit_depth,color_type,interlace_type,compression_type,filter_method);
      png_write_info(png_ptr,info_ptr);
      const int byte_depth = bit_depth>>3;
      const int numChan = spectrum()>4?4:spectrum();
      const int pixel_bit_depth_flag = numChan * (bit_depth-1);

      // Allocate Memory for Image Save and Fill pixel data
      png_bytep *const imgData = new png_byte*[_height];
      for (unsigned int row = 0; row<_height; ++row) imgData[row] = new png_byte[byte_depth*numChan*_width];
      const T *pC0 = data(0,0,0,0);
      switch (pixel_bit_depth_flag) {
      case 7 :  { // Gray 8-bit
        cimg_forY(*this,y) {
          unsigned char *ptrd = imgData[y];
          cimg_forX(*this,x) *(ptrd++) = (unsigned char)*(pC0++);
        }
      } break;
      case 14 : { // Gray w/ Alpha 8-bit
        const T *pC1 = data(0,0,0,1);
        cimg_forY(*this,y) {
          unsigned char *ptrd = imgData[y];
          cimg_forX(*this,x) {
            *(ptrd++) = (unsigned char)*(pC0++);
            *(ptrd++) = (unsigned char)*(pC1++);
          }
        }
      } break;
      case 21 :  { // RGB 8-bit
        const T *pC1 = data(0,0,0,1), *pC2 = data(0,0,0,2);
        cimg_forY(*this,y) {
          unsigned char *ptrd = imgData[y];
          cimg_forX(*this,x) {
            *(ptrd++) = (unsigned char)*(pC0++);
            *(ptrd++) = (unsigned char)*(pC1++);
            *(ptrd++) = (unsigned char)*(pC2++);
          }
        }
      } break;
      case 28 : { // RGB x/ Alpha 8-bit
        const T *pC1 = data(0,0,0,1), *pC2 = data(0,0,0,2), *pC3 = data(0,0,0,3);
        cimg_forY(*this,y){
          unsigned char *ptrd = imgData[y];
          cimg_forX(*this,x){
            *(ptrd++) = (unsigned char)*(pC0++);
            *(ptrd++) = (unsigned char)*(pC1++);
            *(ptrd++) = (unsigned char)*(pC2++);
            *(ptrd++) = (unsigned char)*(pC3++);
          }
        }
      } break;
      case 15 : { // Gray 16-bit
        cimg_forY(*this,y){
          unsigned short *ptrd = (unsigned short*)(imgData[y]);
          cimg_forX(*this,x) *(ptrd++) = (unsigned short)*(pC0++);
          if (!cimg::endianness()) cimg::invert_endianness((unsigned short*)imgData[y],_width);
        }
      } break;
      case 30 : { // Gray w/ Alpha 16-bit
        const T *pC1 = data(0,0,0,1);
        cimg_forY(*this,y){
          unsigned short *ptrd = (unsigned short*)(imgData[y]);
          cimg_forX(*this,x) {
            *(ptrd++) = (unsigned short)*(pC0++);
            *(ptrd++) = (unsigned short)*(pC1++);
          }
          if (!cimg::endianness()) cimg::invert_endianness((unsigned short*)imgData[y],2*_width);
        }
      } break;
      case 45 : { // RGB 16-bit
        const T *pC1 = data(0,0,0,1), *pC2 = data(0,0,0,2);
        cimg_forY(*this,y) {
          unsigned short *ptrd = (unsigned short*)(imgData[y]);
          cimg_forX(*this,x) {
            *(ptrd++) = (unsigned short)*(pC0++);
            *(ptrd++) = (unsigned short)*(pC1++);
            *(ptrd++) = (unsigned short)*(pC2++);
          }
          if (!cimg::endianness()) cimg::invert_endianness((unsigned short*)imgData[y],3*_width);
        }
      } break;
      case 60 : { // RGB w/ Alpha 16-bit
        const T *pC1 = data(0,0,0,1), *pC2 = data(0,0,0,2), *pC3 = data(0,0,0,3);
        cimg_forY(*this,y) {
          unsigned short *ptrd = (unsigned short*)(imgData[y]);
          cimg_forX(*this,x) {
            *(ptrd++) = (unsigned short)*(pC0++);
            *(ptrd++) = (unsigned short)*(pC1++);
            *(ptrd++) = (unsigned short)*(pC2++);
            *(ptrd++) = (unsigned short)*(pC3++);
          }
          if (!cimg::endianness()) cimg::invert_endianness((unsigned short*)imgData[y],4*_width);
        }
      } break;
      default :
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimg_instance
                              "save_png(): Encountered unknown fatal error in libpng when saving file '%s'.",
                              cimg_instance,
                              nfilename?nfilename:"(FILE*)");
      }
      png_write_image(png_ptr,imgData);
      png_write_end(png_ptr,info_ptr);
      png_destroy_write_struct(&png_ptr, &info_ptr);

      // Deallocate Image Write Memory
      cimg_forY(*this,n) delete[] imgData[n];
      delete[] imgData;
      if (!file) cimg::fclose(nfile);
      return *this;
#endif
# 40276 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    }

    //! Save image as a PNM file.
    /**
      \param filename Filename, as a C-string.
      \param bytes_per_pixel Force the number of bytes per pixels for the saving.
    **/
    const CImg<T>& save_pnm(const char *const filename, const unsigned int bytes_per_pixel=0) const {
      return _save_pnm(0,filename,bytes_per_pixel);
    }

    //! Save image as a PNM file \overloading.
    const CImg<T>& save_pnm(std::FILE *const file, const unsigned int bytes_per_pixel=0) const {
      return _save_pnm(file,0,bytes_per_pixel);
    }

    const CImg<T>& _save_pnm(std::FILE *const file, const char *const filename, const unsigned int bytes_per_pixel=0) const {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_pnm(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(file,filename); return *this; }

      double stmin, stmax = (double)max_min(stmin);
      if (_depth>1)
        cimg::warn(_cimg_instance
                   "save_pnm(): Instance is volumetric, only the first slice will be saved in file '%s'.",
                   cimg_instance,
                   filename?filename:"(FILE*)");
      if (_spectrum>3)
        cimg::warn(_cimg_instance
                   "save_pnm(): Instance is multispectral, only the three first channels will be saved in file '%s'.",
                   cimg_instance,
                   filename?filename:"(FILE*)");
      if (stmin<0 || (bytes_per_pixel==1 && stmax>=256) || stmax>=65536)
        cimg::warn(_cimg_instance
                   "save_pnm(): Instance has pixel values in [%g,%g], probable type overflow in file '%s'.",
                   cimg_instance,
                   stmin,stmax,filename?filename:"(FILE*)");

      std::FILE *const nfile = file?file:cimg::fopen(filename,"wb");
      const T
        *ptr_r = data(0,0,0,0),
        *ptr_g = (_spectrum>=2)?data(0,0,0,1):0,
        *ptr_b = (_spectrum>=3)?data(0,0,0,2):0;
      const unsigned long buf_size = cimg::min(1024*1024UL,_width*_height*(_spectrum==1?1UL:3UL));

      std::fprintf(nfile,"P%c\n%u %u\n%u\n",
                   (_spectrum==1?'5':'6'),_width,_height,stmax<256?255:(stmax<4096?4095:65535));

      switch (_spectrum) {
      case 1 : { // Scalar image
        if (bytes_per_pixel==1 || (!bytes_per_pixel && stmax<256)) { // Binary PGM 8 bits
          CImg<ucharT> buf(buf_size);
          for (long to_write = (long)_width*_height; to_write>0; ) {
            const unsigned long N = cimg::min((unsigned long)to_write,buf_size);
            unsigned char *ptrd = buf._data;
            for (unsigned long i = N; i>0; --i) *(ptrd++) = (unsigned char)*(ptr_r++);
            cimg::fwrite(buf._data,N,nfile);
            to_write-=N;
          }
        } else { // Binary PGM 16 bits
          CImg<ushortT> buf(buf_size);
          for (long to_write = (long)_width*_height; to_write>0; ) {
            const unsigned long N = cimg::min((unsigned long)to_write,buf_size);
            unsigned short *ptrd = buf._data;
            for (unsigned long i = N; i>0; --i) *(ptrd++) = (unsigned short)*(ptr_r++);
            if (!cimg::endianness()) cimg::invert_endianness(buf._data,buf_size);
            cimg::fwrite(buf._data,N,nfile);
            to_write-=N;
          }
        }
      } break;
      case 2 : { // RG image
        if (bytes_per_pixel==1 || (!bytes_per_pixel && stmax<256)) { // Binary PPM 8 bits
          CImg<ucharT> buf(buf_size);
          for (long to_write = (long)_width*_height; to_write>0; ) {
            const unsigned long N = cimg::min((unsigned long)to_write,buf_size/3);
            unsigned char *ptrd = buf._data;
            for (unsigned long i = N; i>0; --i) {
              *(ptrd++) = (unsigned char)*(ptr_r++);
              *(ptrd++) = (unsigned char)*(ptr_g++);
              *(ptrd++) = 0;
            }
            cimg::fwrite(buf._data,3*N,nfile);
            to_write-=N;
          }
        } else {             // Binary PPM 16 bits
          CImg<ushortT> buf(buf_size);
          for (long to_write = (long)_width*_height; to_write>0; ) {
            const unsigned long N = cimg::min((unsigned long)to_write,buf_size/3);
            unsigned short *ptrd = buf._data;
            for (unsigned long i = N; i>0; --i) {
              *(ptrd++) = (unsigned short)*(ptr_r++);
              *(ptrd++) = (unsigned short)*(ptr_g++);
              *(ptrd++) = 0;
            }
            if (!cimg::endianness()) cimg::invert_endianness(buf._data,buf_size);
            cimg::fwrite(buf._data,3*N,nfile);
            to_write-=N;
          }
        }
      } break;
      default : { // RGB image
        if (bytes_per_pixel==1 || (!bytes_per_pixel && stmax<256)) { // Binary PPM 8 bits
          CImg<ucharT> buf(buf_size);
          for (long to_write = (long)_width*_height; to_write>0; ) {
            const unsigned long N = cimg::min((unsigned long)to_write,buf_size/3);
            unsigned char *ptrd = buf._data;
            for (unsigned long i = N; i>0; --i) {
              *(ptrd++) = (unsigned char)*(ptr_r++);
              *(ptrd++) = (unsigned char)*(ptr_g++);
              *(ptrd++) = (unsigned char)*(ptr_b++);
            }
            cimg::fwrite(buf._data,3*N,nfile);
            to_write-=N;
          }
        } else {             // Binary PPM 16 bits
          CImg<ushortT> buf(buf_size);
          for (long to_write = (long)_width*_height; to_write>0; ) {
            const unsigned long N = cimg::min((unsigned long)to_write,buf_size/3);
            unsigned short *ptrd = buf._data;
            for (unsigned long i = N; i>0; --i) {
              *(ptrd++) = (unsigned short)*(ptr_r++);
              *(ptrd++) = (unsigned short)*(ptr_g++);
              *(ptrd++) = (unsigned short)*(ptr_b++);
            }
            if (!cimg::endianness()) cimg::invert_endianness(buf._data,buf_size);
            cimg::fwrite(buf._data,3*N,nfile);
            to_write-=N;
          }
        }
      }
      }
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Save image as a PNK file.
    /**
      \param filename Filename, as a C-string.
    **/
    const CImg<T>& save_pnk(const char *const filename) const {
      return _save_pnk(0,filename);
    }

    //! Save image as a PNK file \overloading.
    const CImg<T>& save_pnk(std::FILE *const file) const {
      return _save_pnk(file,0);
    }

    const CImg<T>& _save_pnk(std::FILE *const file, const char *const filename) const {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_pnk(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(file,filename); return *this; }
      if (_spectrum>1)
        cimg::warn(_cimg_instance
                   "save_pnk(): Instance is multispectral, only the first channel will be saved in file '%s'.",
                   cimg_instance,
                   filename?filename:"(FILE*)");

      const unsigned long buf_size = cimg::min(1024*1024LU,_width*_height*_depth);
      std::FILE *const nfile = file?file:cimg::fopen(filename,"wb");
      const T *ptr = data(0,0,0,0);

      if (!cimg::type<T>::is_float() && sizeof(T)==1 && _depth<2) _save_pnm(file,filename,0); // Can be saved as regular PNM file.
      else if (!cimg::type<T>::is_float() && sizeof(T)==1) { // Save as extended P5 file: Binary byte-valued 3d.
        std::fprintf(nfile,"P5\n%u %u %u\n255\n",_width,_height,_depth);
        CImg<ucharT> buf(buf_size);
        for (long to_write = (long)_width*_height*_depth; to_write>0; ) {
          const unsigned long N = cimg::min((unsigned long)to_write,buf_size);
          unsigned char *ptrd = buf._data;
          for (unsigned long i = N; i>0; --i) *(ptrd++) = (unsigned char)*(ptr++);
          cimg::fwrite(buf._data,N,nfile);
          to_write-=N;
        }
      } else if (!cimg::type<T>::is_float()) { // Save as P8: Binary int32-valued 3d.
        if (_depth>1) std::fprintf(nfile,"P8\n%u %u %u\n%d\n",_width,_height,_depth,(int)max());
        else std::fprintf(nfile,"P8\n%u %u\n%d\n",_width,_height,(int)max());
        CImg<intT> buf(buf_size);
        for (long to_write = (long)_width*_height*_depth; to_write>0; ) {
          const unsigned long N = cimg::min((unsigned long)to_write,buf_size);
          int *ptrd = buf._data;
          for (unsigned long i = N; i>0; --i) *(ptrd++) = (int)*(ptr++);
          cimg::fwrite(buf._data,N,nfile);
          to_write-=N;
        }
      } else { // Save as P9: Binary float-valued 3d.
        if (_depth>1) std::fprintf(nfile,"P9\n%u %u %u\n%g\n",_width,_height,_depth,(double)max());
        else std::fprintf(nfile,"P9\n%u %u\n%g\n",_width,_height,(double)max());
        CImg<floatT> buf(buf_size);
        for (long to_write = (long)_width*_height*_depth; to_write>0; ) {
          const unsigned long N = cimg::min((unsigned long)to_write,buf_size);
          float *ptrd = buf._data;
          for (unsigned long i = N; i>0; --i) *(ptrd++) = (float)*(ptr++);
          cimg::fwrite(buf._data,N,nfile);
          to_write-=N;
        }
      }

      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Save image as a PFM file.
    /**
      \param filename Filename, as a C-string.
    **/
    const CImg<T>& save_pfm(const char *const filename) const {
      return get_mirror('y')._save_pfm(0,filename);
    }

    //! Save image as a PFM file \overloading.
    const CImg<T>& save_pfm(std::FILE *const file) const {
      return get_mirror('y')._save_pfm(file,0);
    }

    const CImg<T>& _save_pfm(std::FILE *const file, const char *const filename) const {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_pfm(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(file,filename); return *this; }
      if (_depth>1)
        cimg::warn(_cimg_instance
                   "save_pfm(): Instance is volumetric, only the first slice will be saved in file '%s'.",
                   cimg_instance,
                   filename?filename:"(FILE*)");
      if (_spectrum>3)
        cimg::warn(_cimg_instance
                   "save_pfm(): image instance is multispectral, only the three first channels will be saved in file '%s'.",
                   cimg_instance,
                   filename?filename:"(FILE*)");

      std::FILE *const nfile = file?file:cimg::fopen(filename,"wb");
      const T
        *ptr_r = data(0,0,0,0),
        *ptr_g = (_spectrum>=2)?data(0,0,0,1):0,
        *ptr_b = (_spectrum>=3)?data(0,0,0,2):0;
      const unsigned int buf_size = cimg::min(1024*1024U,_width*_height*(_spectrum==1?1:3));

      std::fprintf(nfile,"P%c\n%u %u\n1.0\n",
                   (_spectrum==1?'f':'F'),_width,_height);

      switch (_spectrum) {
      case 1 : { // Scalar image
        CImg<floatT> buf(buf_size);
        for (long to_write = (long)_width*_height; to_write>0; ) {
          const unsigned long N = cimg::min((unsigned long)to_write,buf_size);
          float *ptrd = buf._data;
          for (unsigned long i = N; i>0; --i) *(ptrd++) = (float)*(ptr_r++);
          if (!cimg::endianness()) cimg::invert_endianness(buf._data,buf_size);
          cimg::fwrite(buf._data,N,nfile);
          to_write-=N;
        }
      } break;
      case 2 : { // RG image
        CImg<floatT> buf(buf_size);
        for (long to_write = (long)_width*_height; to_write>0; ) {
          const unsigned int N = cimg::min((unsigned int)to_write,buf_size/3);
          float *ptrd = buf._data;
          for (unsigned long i = N; i>0; --i) {
            *(ptrd++) = (float)*(ptr_r++);
            *(ptrd++) = (float)*(ptr_g++);
            *(ptrd++) = 0;
          }
          if (!cimg::endianness()) cimg::invert_endianness(buf._data,buf_size);
          cimg::fwrite(buf._data,3*N,nfile);
          to_write-=N;
        }
      } break;
      default : { // RGB image
        CImg<floatT> buf(buf_size);
        for (long to_write = (long)_width*_height; to_write>0; ) {
          const unsigned int N = cimg::min((unsigned int)to_write,buf_size/3);
          float *ptrd = buf._data;
          for (unsigned long i = N; i>0; --i) {
            *(ptrd++) = (float)*(ptr_r++);
            *(ptrd++) = (float)*(ptr_g++);
            *(ptrd++) = (float)*(ptr_b++);
          }
          if (!cimg::endianness()) cimg::invert_endianness(buf._data,buf_size);
          cimg::fwrite(buf._data,3*N,nfile);
          to_write-=N;
        }
      }
      }
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Save image as a RGB file.
    /**
      \param filename Filename, as a C-string.
    **/
    const CImg<T>& save_rgb(const char *const filename) const {
      return _save_rgb(0,filename);
    }

    //! Save image as a RGB file \overloading.
    const CImg<T>& save_rgb(std::FILE *const file) const {
      return _save_rgb(file,0);
    }

    const CImg<T>& _save_rgb(std::FILE *const file, const char *const filename) const {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_rgb(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(file,filename); return *this; }
      if (_spectrum!=3)
        cimg::warn(_cimg_instance
                   "save_rgb(): image instance has not exactly 3 channels, for file '%s'.",
                   cimg_instance,
                   filename?filename:"(FILE*)");

      std::FILE *const nfile = file?file:cimg::fopen(filename,"wb");
      const unsigned long wh = (unsigned long)_width*_height;
      unsigned char *const buffer = new unsigned char[3*wh], *nbuffer = buffer;
      const T
        *ptr1 = data(0,0,0,0),
        *ptr2 = _spectrum>1?data(0,0,0,1):0,
        *ptr3 = _spectrum>2?data(0,0,0,2):0;
      switch (_spectrum) {
      case 1 : { // Scalar image
        for (unsigned long k = 0; k<wh; ++k) {
          const unsigned char val = (unsigned char)*(ptr1++);
          *(nbuffer++) = val;
          *(nbuffer++) = val;
          *(nbuffer++) = val;
        }
      } break;
      case 2 : { // RG image
        for (unsigned long k = 0; k<wh; ++k) {
          *(nbuffer++) = (unsigned char)(*(ptr1++));
          *(nbuffer++) = (unsigned char)(*(ptr2++));
          *(nbuffer++) = 0;
        }
      } break;
      default : { // RGB image
        for (unsigned long k = 0; k<wh; ++k) {
          *(nbuffer++) = (unsigned char)(*(ptr1++));
          *(nbuffer++) = (unsigned char)(*(ptr2++));
          *(nbuffer++) = (unsigned char)(*(ptr3++));
        }
      }
      }
      cimg::fwrite(buffer,3*wh,nfile);
      if (!file) cimg::fclose(nfile);
      delete[] buffer;
      return *this;
    }

    //! Save image as a RGBA file.
    /**
       \param filename Filename, as a C-string.
    **/
    const CImg<T>& save_rgba(const char *const filename) const {
      return _save_rgba(0,filename);
    }

    //! Save image as a RGBA file \overloading.
    const CImg<T>& save_rgba(std::FILE *const file) const {
      return _save_rgba(file,0);
    }

    const CImg<T>& _save_rgba(std::FILE *const file, const char *const filename) const {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_rgba(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(file,filename); return *this; }
      if (_spectrum!=4)
        cimg::warn(_cimg_instance
                   "save_rgba(): image instance has not exactly 4 channels, for file '%s'.",
                   cimg_instance,
                   filename?filename:"(FILE*)");

      std::FILE *const nfile = file?file:cimg::fopen(filename,"wb");
      const unsigned long wh = (unsigned long)_width*_height;
      unsigned char *const buffer = new unsigned char[4*wh], *nbuffer = buffer;
      const T
        *ptr1 = data(0,0,0,0),
        *ptr2 = _spectrum>1?data(0,0,0,1):0,
        *ptr3 = _spectrum>2?data(0,0,0,2):0,
        *ptr4 = _spectrum>3?data(0,0,0,3):0;
      switch (_spectrum) {
      case 1 : { // Scalar images
        for (unsigned long k = 0; k<wh; ++k) {
          const unsigned char val = (unsigned char)*(ptr1++);
          *(nbuffer++) = val;
          *(nbuffer++) = val;
          *(nbuffer++) = val;
          *(nbuffer++) = 255;
        }
      } break;
      case 2 : { // RG images
        for (unsigned long k = 0; k<wh; ++k) {
          *(nbuffer++) = (unsigned char)(*(ptr1++));
          *(nbuffer++) = (unsigned char)(*(ptr2++));
          *(nbuffer++) = 0;
          *(nbuffer++) = 255;
        }
      } break;
      case 3 : { // RGB images
        for (unsigned long k = 0; k<wh; ++k) {
          *(nbuffer++) = (unsigned char)(*(ptr1++));
          *(nbuffer++) = (unsigned char)(*(ptr2++));
          *(nbuffer++) = (unsigned char)(*(ptr3++));
          *(nbuffer++) = 255;
        }
      } break;
      default : { // RGBA images
        for (unsigned long k = 0; k<wh; ++k) {
          *(nbuffer++) = (unsigned char)(*(ptr1++));
          *(nbuffer++) = (unsigned char)(*(ptr2++));
          *(nbuffer++) = (unsigned char)(*(ptr3++));
          *(nbuffer++) = (unsigned char)(*(ptr4++));
        }
      }
      }
      cimg::fwrite(buffer,4*wh,nfile);
      if (!file) cimg::fclose(nfile);
      delete[] buffer;
      return *this;
    }

    //! Save image as a TIFF file.
    /**
       \param filename Filename, as a C-string.
       \param compression_type Type of data compression. Can be <tt>{ 1=None | 2=CCITTRLE | 3=CCITTFAX3 | 4=CCITTFAX4 | 5=LZW | 6=JPEG }</tt>.
       \note
       - libtiff support is enabled by defining the precompilation
        directive \c cimg_use_tif.
       - When libtiff is enabled, 2D and 3D (multipage) several
        channel per pixel are supported for
        <tt>char,uchar,short,ushort,float</tt> and \c double pixel types.
       - If \c cimg_use_tif is not defined at compilation time the
        function uses CImg<T>&save_other(const char*).
     **/
    const CImg<T>& save_tiff(const char *const filename, const unsigned int compression_type=0) const {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_tiff(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(0,filename); return *this; }

#ifdef cimg_use_tiff
      TIFF *tif = TIFFOpen(filename,"w");
      if (tif) {
        cimg_forZ(*this,z) get_slice(z)._save_tiff(tif,z,compression_type);
        TIFFClose(tif);
      } else throw CImgIOException(_cimg_instance
                                   "save_tiff(): Failed to open file '%s' for writing.",
                                   cimg_instance,
                                   filename);
#else
# 40735 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      cimg::unused(compression_type);
      return save_other(filename);
#endif
# 40738 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      return *this;
    }

#ifdef cimg_use_tiff

#define _cimg_save_tiff(types,typed,compression_type) \
    if (!std::strcmp(types,pixel_type())) { const typed foo = (typed)0; return _save_tiff(tif,directory,foo,compression_type); }

    // [internal] Save a plane into a tiff file
    template<typename t>
    const CImg<T>& _save_tiff(TIFF *tif, const unsigned int directory, const t& pixel_t, const unsigned int compression_type) const {
      if (is_empty() || !tif || pixel_t) return *this;
      const char *const filename = TIFFFileName(tif);
      uint32 rowsperstrip = (uint32)-1;
      uint16 spp = _spectrum, bpp = sizeof(t)*8, photometric;
      if (spp==3 || spp==4) photometric = PHOTOMETRIC_RGB;
      else photometric = PHOTOMETRIC_MINISBLACK;
      TIFFSetDirectory(tif,directory);
      TIFFSetField(tif,TIFFTAG_IMAGEWIDTH,_width);
      TIFFSetField(tif,TIFFTAG_IMAGELENGTH,_height);
      TIFFSetField(tif,TIFFTAG_ORIENTATION,ORIENTATION_TOPLEFT);
      TIFFSetField(tif,TIFFTAG_SAMPLESPERPIXEL,spp);
      if (cimg::type<t>::is_float()) TIFFSetField(tif,TIFFTAG_SAMPLEFORMAT,3);
      else if (cimg::type<t>::min()==0) TIFFSetField(tif,TIFFTAG_SAMPLEFORMAT,1);
      else TIFFSetField(tif,TIFFTAG_SAMPLEFORMAT,2);
      TIFFSetField(tif,TIFFTAG_BITSPERSAMPLE,bpp);
      TIFFSetField(tif,TIFFTAG_PLANARCONFIG,PLANARCONFIG_CONTIG);
      TIFFSetField(tif,TIFFTAG_PHOTOMETRIC,photometric);
      TIFFSetField(tif,TIFFTAG_COMPRESSION,compression_type?(compression_type-1):COMPRESSION_NONE);
      rowsperstrip = TIFFDefaultStripSize(tif,rowsperstrip);
      TIFFSetField(tif,TIFFTAG_ROWSPERSTRIP,rowsperstrip);
      TIFFSetField(tif,TIFFTAG_FILLORDER,FILLORDER_MSB2LSB);
      TIFFSetField(tif,TIFFTAG_SOFTWARE,"CImg");
      t *const buf = (t*)_TIFFmalloc(TIFFStripSize(tif));
      if (buf) {
        for (unsigned int row = 0; row<_height; row+=rowsperstrip) {
          uint32 nrow = (row + rowsperstrip>_height?_height-row:rowsperstrip);
          tstrip_t strip = TIFFComputeStrip(tif,row,0);
          tsize_t i = 0;
          for (unsigned int rr = 0; rr<nrow; ++rr)
            for (unsigned int cc = 0; cc<_width; ++cc)
              for (unsigned int vv = 0; vv<spp; ++vv)
                buf[i++] = (t)(*this)(cc,row + rr,0,vv);
          if (TIFFWriteEncodedStrip(tif,strip,buf,i*sizeof(t))<0)
            throw CImgIOException(_cimg_instance
                                  "save_tiff(): Invalid strip writing when saving file '%s'.",
                                  cimg_instance,
                                  filename?filename:"(FILE*)");
        }
        _TIFFfree(buf);
      }
      TIFFWriteDirectory(tif);
      return (*this);
    }

    const CImg<T>& _save_tiff(TIFF *tif, const unsigned int directory, const unsigned int compression_type) const {
      _cimg_save_tiff("bool",unsigned char,compression_type);
      _cimg_save_tiff("char",char,compression_type);
      _cimg_save_tiff("unsigned char",unsigned char,compression_type);
      _cimg_save_tiff("short",short,compression_type);
      _cimg_save_tiff("unsigned short",unsigned short,compression_type);
      _cimg_save_tiff("int",int,compression_type);
      _cimg_save_tiff("unsigned int",unsigned int,compression_type);
      _cimg_save_tiff("long",int,compression_type);
      _cimg_save_tiff("unsigned long",unsigned int,compression_type);
      _cimg_save_tiff("float",float,compression_type);
      _cimg_save_tiff("double",float,compression_type);
      const char *const filename = TIFFFileName(tif);
      throw CImgInstanceException(_cimg_instance
                                  "save_tiff(): Unsupported pixel type '%s' for file '%s'.",
                                  cimg_instance,
                                  pixel_type(),filename?filename:"(FILE*)");
      return *this;
    }
#endif
# 40813 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    //! Save image as a MINC2 file.
    /**
       \param filename Filename, as a C-string.
       \param imitate_file If non-zero, reference filename, as a C-string, to borrow header from.
    **/
    const CImg<T>& save_minc2(const char *const filename,
                              const char *const imitate_file=0) const {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                   "save_minc2(): Specified filename is (null).",
                                   cimg_instance);
      if (is_empty()) { cimg::fempty(0,filename); return *this; }

#ifndef cimg_use_minc2
     cimg::unused(imitate_file);
     return save_other(filename);
#else
# 40831 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
     minc::minc_1_writer wtr;
     if (imitate_file)
       wtr.open(filename, imitate_file);
     else {
       minc::minc_info di;
       if(width()) di.push_back(minc::dim_info(width(), width()*0.5, -1, minc::dim_info::DIM_X));
       if(height()) di.push_back(minc::dim_info(height(), height()*0.5, -1, minc::dim_info::DIM_Y));
       if(depth()) di.push_back(minc::dim_info(depth(), depth()*0.5, -1, minc::dim_info::DIM_Z));
       if(spectrum()) di.push_back(minc::dim_info(spectrum(), spectrum()*0.5, -1, minc::dim_info::DIM_TIME));
       wtr.open(filename, di, 1, NC_FLOAT, 0);
     }
     if(typeid(T)==typeid(unsigned char))
       wtr.setup_write_byte();
     else if(typeid(T)==typeid(int))
       wtr.setup_write_int();
     else if(typeid(T)==typeid(double))
       wtr.setup_write_double();
     else
       wtr.setup_write_float();
     minc::save_standard_volume(wtr, this->_data);
     return *this;
#endif
# 40853 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    }

    //! Save image as an ANALYZE7.5 or NIFTI file.
    /**
      \param filename Filename, as a C-string.
      \param voxel_size Pointer to 3 consecutive values that tell about the voxel sizes along the X,Y and Z dimensions.
    **/
    const CImg<T>& save_analyze(const char *const filename, const float *const voxel_size=0) const {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_analyze(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(0,filename); return *this; }

      std::FILE *file;
      char header[348] = { 0 }, hname[1024] = { 0 }, iname[1024] = { 0 };
      const char *const ext = cimg::split_filename(filename);
      short datatype=-1;
      std::memset(header,0,348);
      if (!*ext) { cimg_snprintf(hname,sizeof(hname),"%s.hdr",filename); cimg_snprintf(iname,sizeof(iname),"%s.img",filename); }
      if (!cimg::strncasecmp(ext,"hdr",3)) {
        std::strcpy(hname,filename); std::strncpy(iname,filename,sizeof(iname)-1); std::sprintf(iname + std::strlen(iname)-3,"img");
      }
      if (!cimg::strncasecmp(ext,"img",3)) {
        std::strcpy(hname,filename); std::strncpy(iname,filename,sizeof(iname)-1); std::sprintf(hname + std::strlen(iname)-3,"hdr");
      }
      if (!cimg::strncasecmp(ext,"nii",3)) {
        std::strncpy(hname,filename,sizeof(hname)-1); *iname = 0;
      }
      int *const iheader = (int*)header;
      *iheader = 348;
      std::strcpy(header + 4,"CImg");
      std::strcpy(header + 14," ");
      ((short*)(header + 36))[0] = 4096;
      ((char*)(header + 38))[0] = 114;
      ((short*)(header + 40))[0] = 4;
      ((short*)(header + 40))[1] = _width;
      ((short*)(header + 40))[2] = _height;
      ((short*)(header + 40))[3] = _depth;
      ((short*)(header + 40))[4] = _spectrum;
      if (!cimg::strcasecmp(pixel_type(),"bool")) datatype = 2;
      if (!cimg::strcasecmp(pixel_type(),"unsigned char")) datatype = 2;
      if (!cimg::strcasecmp(pixel_type(),"char")) datatype = 2;
      if (!cimg::strcasecmp(pixel_type(),"unsigned short")) datatype = 4;
      if (!cimg::strcasecmp(pixel_type(),"short")) datatype = 4;
      if (!cimg::strcasecmp(pixel_type(),"unsigned int")) datatype = 8;
      if (!cimg::strcasecmp(pixel_type(),"int")) datatype = 8;
      if (!cimg::strcasecmp(pixel_type(),"unsigned long")) datatype = 8;
      if (!cimg::strcasecmp(pixel_type(),"long")) datatype = 8;
      if (!cimg::strcasecmp(pixel_type(),"float")) datatype = 16;
      if (!cimg::strcasecmp(pixel_type(),"double")) datatype = 64;
      if (datatype<0)
        throw CImgIOException(_cimg_instance
                              "save_analyze(): Unsupported pixel type '%s' for file '%s'.",
                              cimg_instance,
                              pixel_type(),filename);

      ((short*)(header+70))[0] = datatype;
      ((short*)(header+72))[0] = sizeof(T);
      ((float*)(header+112))[0] = 1;
      ((float*)(header+76))[0] = 0;
      if (voxel_size) {
        ((float*)(header+76))[1] = voxel_size[0];
        ((float*)(header+76))[2] = voxel_size[1];
        ((float*)(header+76))[3] = voxel_size[2];
      } else ((float*)(header+76))[1] = ((float*)(header+76))[2] = ((float*)(header+76))[3] = 1;
      file = cimg::fopen(hname,"wb");
      cimg::fwrite(header,348,file);
      if (*iname) { cimg::fclose(file); file = cimg::fopen(iname,"wb"); }
      cimg::fwrite(_data,size(),file);
      cimg::fclose(file);
      return *this;
    }

    //! Save image as a .cimg file.
    /**
      \param filename Filename, as a C-string.
      \param is_compressed Tells if the file contains compressed image data.
    **/
    const CImg<T>& save_cimg(const char *const filename, const bool is_compressed=false) const {
      CImgList<T>(*this,true).save_cimg(filename,is_compressed);
      return *this;
    }

    //! Save image as a .cimg file \overloading.
    const CImg<T>& save_cimg(std::FILE *const file, const bool is_compressed=false) const {
      CImgList<T>(*this,true).save_cimg(file,is_compressed);
      return *this;
    }

    //! Save image as a sub-image into an existing .cimg file.
    /**
      \param filename Filename, as a C-string.
      \param n0 Index of the image inside the file.
      \param x0 X-coordinate of the sub-image location.
      \param y0 Y-coordinate of the sub-image location.
      \param z0 Z-coordinate of the sub-image location.
      \param c0 C-coordinate of the sub-image location.
    **/
    const CImg<T>& save_cimg(const char *const filename,
                             const unsigned int n0,
                             const unsigned int x0, const unsigned int y0,
                             const unsigned int z0, const unsigned int c0) const {
      CImgList<T>(*this,true).save_cimg(filename,n0,x0,y0,z0,c0);
      return *this;
    }

    //! Save image as a sub-image into an existing .cimg file \overloading.
    const CImg<T>& save_cimg(std::FILE *const file,
			     const unsigned int n0,
			     const unsigned int x0, const unsigned int y0,
			     const unsigned int z0, const unsigned int c0) const {
      CImgList<T>(*this,true).save_cimg(file,n0,x0,y0,z0,c0);
      return *this;
    }

    //! Save blank image as a .cimg file.
    /**
        \param filename Filename, as a C-string.
        \param dx Width of the image.
        \param dy Height of the image.
        \param dz Depth of the image.
        \param dc Number of channels of the image.
        \note
        - All pixel values of the saved image are set to \c 0.
        - Use this method to save large images without having to instanciate and allocate them.
    **/
    static void save_empty_cimg(const char *const filename,
                                const unsigned int dx, const unsigned int dy=1,
                                const unsigned int dz=1, const unsigned int dc=1) {
      return CImgList<T>::save_empty_cimg(filename,1,dx,dy,dz,dc);
    }

    //! Save blank image as a .cimg file \overloading.
    /**
       Same as save_empty_cimg(const char *,unsigned int,unsigned int,unsigned int,unsigned int)
       with a file stream argument instead of a filename string.
    **/
    static void save_empty_cimg(std::FILE *const file,
                                const unsigned int dx, const unsigned int dy=1,
                                const unsigned int dz=1, const unsigned int dc=1) {
      return CImgList<T>::save_empty_cimg(file,1,dx,dy,dz,dc);
    }

    //! Save image as an INRIMAGE-4 file.
    /**
      \param filename Filename, as a C-string.
      \param voxel_size Pointer to 3 values specifying the voxel sizes along the X,Y and Z dimensions.
    **/
    const CImg<T>& save_inr(const char *const filename, const float *const voxel_size=0) const {
      return _save_inr(0,filename,voxel_size);
    }

    //! Save image as an INRIMAGE-4 file \overloading.
    const CImg<T>& save_inr(std::FILE *const file, const float *const voxel_size=0) const {
      return _save_inr(file,0,voxel_size);
    }

    const CImg<T>& _save_inr(std::FILE *const file, const char *const filename, const float *const voxel_size) const {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_inr(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(file,filename); return *this; }

      int inrpixsize=-1;
      const char *inrtype = "unsigned fixed\nPIXSIZE=8 bits\nSCALE=2**0";
      if (!cimg::strcasecmp(pixel_type(),"unsigned char"))  { inrtype = "unsigned fixed\nPIXSIZE=8 bits\nSCALE=2**0"; inrpixsize = 1; }
      if (!cimg::strcasecmp(pixel_type(),"char"))           { inrtype = "fixed\nPIXSIZE=8 bits\nSCALE=2**0"; inrpixsize = 1; }
      if (!cimg::strcasecmp(pixel_type(),"unsigned short")) { inrtype = "unsigned fixed\nPIXSIZE=16 bits\nSCALE=2**0";inrpixsize = 2; }
      if (!cimg::strcasecmp(pixel_type(),"short"))          { inrtype = "fixed\nPIXSIZE=16 bits\nSCALE=2**0"; inrpixsize = 2; }
      if (!cimg::strcasecmp(pixel_type(),"unsigned int"))   { inrtype = "unsigned fixed\nPIXSIZE=32 bits\nSCALE=2**0";inrpixsize = 4; }
      if (!cimg::strcasecmp(pixel_type(),"int"))            { inrtype = "fixed\nPIXSIZE=32 bits\nSCALE=2**0"; inrpixsize = 4; }
      if (!cimg::strcasecmp(pixel_type(),"float"))          { inrtype = "float\nPIXSIZE=32 bits"; inrpixsize = 4; }
      if (!cimg::strcasecmp(pixel_type(),"double"))         { inrtype = "float\nPIXSIZE=64 bits"; inrpixsize = 8; }
      if (inrpixsize<=0)
        throw CImgIOException(_cimg_instance
                              "save_inr(): Unsupported pixel type '%s' for file '%s'",
                              cimg_instance,
                              pixel_type(),filename?filename:"(FILE*)");

      std::FILE *const nfile = file?file:cimg::fopen(filename,"wb");
      char header[257] = { 0 };
      int err = cimg_snprintf(header,sizeof(header),"#INRIMAGE-4#{\nXDIM=%u\nYDIM=%u\nZDIM=%u\nVDIM=%u\n",_width,_height,_depth,_spectrum);
      if (voxel_size) err+=std::sprintf(header + err,"VX=%g\nVY=%g\nVZ=%g\n",voxel_size[0],voxel_size[1],voxel_size[2]);
      err+=std::sprintf(header + err,"TYPE=%s\nCPU=%s\n",inrtype,cimg::endianness()?"sun":"decm");
      std::memset(header + err,'\n',252 - err);
      std::memcpy(header + 252,"##}\n",4);
      cimg::fwrite(header,256,nfile);
      cimg_forXYZ(*this,x,y,z) cimg_forC(*this,c) cimg::fwrite(&((*this)(x,y,z,c)),1,nfile);
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Save image as an OpenEXR file.
    /**
       \param filename Filename, as a C-string.
       \note The OpenEXR file format is <a href="http://en.wikipedia.org/wiki/OpenEXR">described here</a>.
    **/
    const CImg<T>& save_exr(const char *const filename) const {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_exr(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(0,filename); return *this; }
      if (_depth>1)
        cimg::warn(_cimg_instance
                   "save_exr(): Instance is volumetric, only the first slice will be saved in file '%s'.",
                   cimg_instance,
                   filename);

#ifndef cimg_use_openexr
      return save_other(filename);
#else
# 41067 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      Imf::Rgba *const ptrd0 = new Imf::Rgba[(unsigned long)_width*_height], *ptrd = ptrd0, rgba;
      switch (_spectrum) {
      case 1 : { // Grayscale image.
        for (const T *ptr_r = data(), *const ptr_e = ptr_r + (unsigned long)_width*_height; ptr_r<ptr_e;) {
          rgba.r = rgba.g = rgba.b = (half)(*(ptr_r++));
          rgba.a = (half)1;
          *(ptrd++) = rgba;
        }
      } break;
      case 2 : { // RG image.
        for (const T *ptr_r = data(), *ptr_g = data(0,0,0,1), *const ptr_e = ptr_r + (unsigned long)_width*_height; ptr_r<ptr_e; ) {
          rgba.r = (half)(*(ptr_r++));
          rgba.g = (half)(*(ptr_g++));
          rgba.b = (half)0;
          rgba.a = (half)1;
          *(ptrd++) = rgba;
        }
      } break;
      case 3 : { // RGB image.
        for (const T *ptr_r = data(), *ptr_g = data(0,0,0,1), *ptr_b = data(0,0,0,2), *const ptr_e = ptr_r + (unsigned long)_width*_height; ptr_r<ptr_e;) {
          rgba.r = (half)(*(ptr_r++));
          rgba.g = (half)(*(ptr_g++));
          rgba.b = (half)(*(ptr_b++));
          rgba.a = (half)1;
          *(ptrd++) = rgba;
        }
      } break;
      default : { // RGBA image.
        for (const T *ptr_r = data(), *ptr_g = data(0,0,0,1), *ptr_b = data(0,0,0,2), *ptr_a = data(0,0,0,3),
               *const ptr_e = ptr_r + (unsigned long)_width*_height; ptr_r<ptr_e;) {
          rgba.r = (half)(*(ptr_r++));
          rgba.g = (half)(*(ptr_g++));
          rgba.b = (half)(*(ptr_b++));
          rgba.a = (half)(*(ptr_a++));
          *(ptrd++) = rgba;
        }
      } break;
      }
      Imf::RgbaOutputFile outFile(filename,_width,_height,
                                  _spectrum==1?Imf::WRITE_Y:_spectrum==2?Imf::WRITE_YA:_spectrum==3?Imf::WRITE_RGB:Imf::WRITE_RGBA);
      outFile.setFrameBuffer(ptrd0,1,_width);
      outFile.writePixels(_height);
      delete[] ptrd0;
      return *this;
#endif
# 41112 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    }

    //! Save image as a Pandore-5 file.
    /**
       \param filename Filename, as a C-string.
       \param colorspace Colorspace data field in output file
       (see <a href="http://www.greyc.ensicaen.fr/~regis/Pandore/#documentation">Pandore file specifications</a> for more informations).
    **/
    const CImg<T>& save_pandore(const char *const filename, const unsigned int colorspace=0) const {
      return _save_pandore(0,filename,colorspace);
    }

    //! Save image as a Pandore-5 file \overloading.
    /**
        Same as save_pandore(const char *,unsigned int) const
        with a file stream argument instead of a filename string.
    **/
    const CImg<T>& save_pandore(std::FILE *const file, const unsigned int colorspace=0) const {
      return _save_pandore(file,0,colorspace);
    }

    unsigned int _save_pandore_header_length(unsigned int id, unsigned int *dims, const unsigned int colorspace) const {
      unsigned int nbdims = 0;
      if (id==2 || id==3 || id==4) { dims[0] = 1; dims[1] = _width;  nbdims = 2; }
      if (id==5 || id==6 || id==7) { dims[0] = 1; dims[1] = _height; dims[2] = _width;  nbdims=3; }
      if (id==8 || id==9 || id==10) { dims[0] = _spectrum; dims[1] = _depth;  dims[2] = _height; dims[3] = _width; nbdims = 4; }
      if (id==16 || id==17 || id==18) { dims[0] = 3; dims[1] = _height; dims[2] = _width;  dims[3] = colorspace; nbdims = 4; }
      if (id==19 || id==20 || id==21) { dims[0] = 3; dims[1] = _depth;  dims[2] = _height; dims[3] = _width; dims[4] = colorspace; nbdims = 5; }
      if (id==22 || id==23 || id==25) { dims[0] = _spectrum; dims[1] = _width;  nbdims = 2; }
      if (id==26 || id==27 || id==29) { dims[0] = _spectrum; dims[1] = _height; dims[2] = _width;  nbdims=3; }
      if (id==30 || id==31 || id==33) { dims[0] = _spectrum; dims[1] = _depth;  dims[2] = _height; dims[3] = _width; nbdims = 4; }
      return nbdims;
    }

    const CImg<T>& _save_pandore(std::FILE *const file, const char *const filename, const unsigned int colorspace) const {

#define __cimg_save_pandore_case(dtype) \
       dtype *buffer = new dtype[size()]; \
       const T *ptrs = _data; \
       cimg_foroff(*this,off) *(buffer++) = (dtype)(*(ptrs++)); \
       buffer-=size(); \
       cimg::fwrite(buffer,size(),nfile); \
       delete[] buffer

#define _cimg_save_pandore_case(sy,sz,sv,stype,id) \
      if (!saved && (sy?(sy==_height):true) && (sz?(sz==_depth):true) && (sv?(sv==_spectrum):true) && !std::strcmp(stype,pixel_type())) { \
	unsigned int *iheader = (unsigned int*)(header+12); \
	nbdims = _save_pandore_header_length((*iheader=id),dims,colorspace); \
	cimg::fwrite(header,36,nfile); \
        if (sizeof(unsigned long)==4) { unsigned long ndims[5] = { 0 }; for (int d = 0; d<5; ++d) ndims[d] = (unsigned long)dims[d]; cimg::fwrite(ndims,nbdims,nfile); } \
        else if (sizeof(unsigned int)==4) { unsigned int ndims[5] = { 0 }; for (int d = 0; d<5; ++d) ndims[d] = (unsigned int)dims[d]; cimg::fwrite(ndims,nbdims,nfile); } \
        else if (sizeof(unsigned short)==4) { unsigned short ndims[5] = { 0 }; for (int d = 0; d<5; ++d) ndims[d] = (unsigned short)dims[d]; cimg::fwrite(ndims,nbdims,nfile); } \
        else throw CImgIOException(_cimg_instance \
                                   "save_pandore(): Unsupported datatype for file '%s'.",\
                                   cimg_instance, \
                                   filename?filename:"(FILE*)"); \
	if (id==2 || id==5 || id==8 || id==16 || id==19 || id==22 || id==26 || id==30) { \
          __cimg_save_pandore_case(unsigned char); \
	} else if (id==3 || id==6 || id==9 || id==17 || id==20 || id==23 || id==27 || id==31) { \
          if (sizeof(unsigned long)==4) { __cimg_save_pandore_case(unsigned long); } \
          else if (sizeof(unsigned int)==4) { __cimg_save_pandore_case(unsigned int); } \
          else if (sizeof(unsigned short)==4) { __cimg_save_pandore_case(unsigned short); } \
          else throw CImgIOException(_cimg_instance \
                                     "save_pandore(): Unsupported datatype for file '%s'.",\
                                     cimg_instance, \
                                     filename?filename:"(FILE*)"); \
	} else if (id==4 || id==7 || id==10 || id==18 || id==21 || id==25 || id==29 || id==33) { \
          if (sizeof(double)==4) { __cimg_save_pandore_case(double); } \
          else if (sizeof(float)==4) { __cimg_save_pandore_case(float); } \
          else throw CImgIOException(_cimg_instance \
                                     "save_pandore(): Unsupported datatype for file '%s'.",\
                                     cimg_instance, \
                                     filename?filename:"(FILE*)"); \
        } \
	saved = true; \
      }

      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_pandore(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(file,filename); return *this; }

      std::FILE *const nfile = file?file:cimg::fopen(filename,"wb");
      unsigned char header[36] = { 'P','A','N','D','O','R','E','0','4',0,0,0,
                                   0,0,0,0,'C','I','m','g',0,0,0,0,0,'N','o',' ','d','a','t','e',0,0,0,0 };
      unsigned int nbdims, dims[5] = { 0 };
      bool saved = false;
      _cimg_save_pandore_case(1,1,1,"unsigned char",2);
      _cimg_save_pandore_case(1,1,1,"char",3);
      _cimg_save_pandore_case(1,1,1,"short",3);
      _cimg_save_pandore_case(1,1,1,"unsigned short",3);
      _cimg_save_pandore_case(1,1,1,"unsigned int",3);
      _cimg_save_pandore_case(1,1,1,"int",3);
      _cimg_save_pandore_case(1,1,1,"unsigned long",4);
      _cimg_save_pandore_case(1,1,1,"long",3);
      _cimg_save_pandore_case(1,1,1,"float",4);
      _cimg_save_pandore_case(1,1,1,"double",4);

      _cimg_save_pandore_case(0,1,1,"unsigned char",5);
      _cimg_save_pandore_case(0,1,1,"char",6);
      _cimg_save_pandore_case(0,1,1,"short",6);
      _cimg_save_pandore_case(0,1,1,"unsigned short",6);
      _cimg_save_pandore_case(0,1,1,"unsigned int",6);
      _cimg_save_pandore_case(0,1,1,"int",6);
      _cimg_save_pandore_case(0,1,1,"unsigned long",7);
      _cimg_save_pandore_case(0,1,1,"long",6);
      _cimg_save_pandore_case(0,1,1,"float",7);
      _cimg_save_pandore_case(0,1,1,"double",7);

      _cimg_save_pandore_case(0,0,1,"unsigned char",8);
      _cimg_save_pandore_case(0,0,1,"char",9);
      _cimg_save_pandore_case(0,0,1,"short",9);
      _cimg_save_pandore_case(0,0,1,"unsigned short",9);
      _cimg_save_pandore_case(0,0,1,"unsigned int",9);
      _cimg_save_pandore_case(0,0,1,"int",9);
      _cimg_save_pandore_case(0,0,1,"unsigned long",10);
      _cimg_save_pandore_case(0,0,1,"long",9);
      _cimg_save_pandore_case(0,0,1,"float",10);
      _cimg_save_pandore_case(0,0,1,"double",10);

      _cimg_save_pandore_case(0,1,3,"unsigned char",16);
      _cimg_save_pandore_case(0,1,3,"char",17);
      _cimg_save_pandore_case(0,1,3,"short",17);
      _cimg_save_pandore_case(0,1,3,"unsigned short",17);
      _cimg_save_pandore_case(0,1,3,"unsigned int",17);
      _cimg_save_pandore_case(0,1,3,"int",17);
      _cimg_save_pandore_case(0,1,3,"unsigned long",18);
      _cimg_save_pandore_case(0,1,3,"long",17);
      _cimg_save_pandore_case(0,1,3,"float",18);
      _cimg_save_pandore_case(0,1,3,"double",18);

      _cimg_save_pandore_case(0,0,3,"unsigned char",19);
      _cimg_save_pandore_case(0,0,3,"char",20);
      _cimg_save_pandore_case(0,0,3,"short",20);
      _cimg_save_pandore_case(0,0,3,"unsigned short",20);
      _cimg_save_pandore_case(0,0,3,"unsigned int",20);
      _cimg_save_pandore_case(0,0,3,"int",20);
      _cimg_save_pandore_case(0,0,3,"unsigned long",21);
      _cimg_save_pandore_case(0,0,3,"long",20);
      _cimg_save_pandore_case(0,0,3,"float",21);
      _cimg_save_pandore_case(0,0,3,"double",21);

      _cimg_save_pandore_case(1,1,0,"unsigned char",22);
      _cimg_save_pandore_case(1,1,0,"char",23);
      _cimg_save_pandore_case(1,1,0,"short",23);
      _cimg_save_pandore_case(1,1,0,"unsigned short",23);
      _cimg_save_pandore_case(1,1,0,"unsigned int",23);
      _cimg_save_pandore_case(1,1,0,"int",23);
      _cimg_save_pandore_case(1,1,0,"unsigned long",25);
      _cimg_save_pandore_case(1,1,0,"long",23);
      _cimg_save_pandore_case(1,1,0,"float",25);
      _cimg_save_pandore_case(1,1,0,"double",25);

      _cimg_save_pandore_case(0,1,0,"unsigned char",26);
      _cimg_save_pandore_case(0,1,0,"char",27);
      _cimg_save_pandore_case(0,1,0,"short",27);
      _cimg_save_pandore_case(0,1,0,"unsigned short",27);
      _cimg_save_pandore_case(0,1,0,"unsigned int",27);
      _cimg_save_pandore_case(0,1,0,"int",27);
      _cimg_save_pandore_case(0,1,0,"unsigned long",29);
      _cimg_save_pandore_case(0,1,0,"long",27);
      _cimg_save_pandore_case(0,1,0,"float",29);
      _cimg_save_pandore_case(0,1,0,"double",29);

      _cimg_save_pandore_case(0,0,0,"unsigned char",30);
      _cimg_save_pandore_case(0,0,0,"char",31);
      _cimg_save_pandore_case(0,0,0,"short",31);
      _cimg_save_pandore_case(0,0,0,"unsigned short",31);
      _cimg_save_pandore_case(0,0,0,"unsigned int",31);
      _cimg_save_pandore_case(0,0,0,"int",31);
      _cimg_save_pandore_case(0,0,0,"unsigned long",33);
      _cimg_save_pandore_case(0,0,0,"long",31);
      _cimg_save_pandore_case(0,0,0,"float",33);
      _cimg_save_pandore_case(0,0,0,"double",33);

      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Save image as a raw data file.
    /**
       \param filename Filename, as a C-string.
       \param is_multiplexed Tells if the image channels are stored in a multiplexed way (\c true) or not (\c false).
       \note The .raw format does not store the image dimensions in the output file, so you have to keep track of them somewhere
       to be able to read the file correctly afterwards.
    **/
    const CImg<T>& save_raw(const char *const filename, const bool is_multiplexed=false) const {
      return _save_raw(0,filename,is_multiplexed);
    }

    //! Save image as a raw data file \overloading.
    /**
       Same as save_raw(const char *,bool) const
       with a file stream argument instead of a filename string.
    **/
    const CImg<T>& save_raw(std::FILE *const file, const bool is_multiplexed=false) const {
      return _save_raw(file,0,is_multiplexed);
    }

    const CImg<T>& _save_raw(std::FILE *const file, const char *const filename, const bool is_multiplexed) const {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_raw(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(file,filename); return *this; }

      std::FILE *const nfile = file?file:cimg::fopen(filename,"wb");
      if (!is_multiplexed) cimg::fwrite(_data,size(),nfile);
      else {
        CImg<T> buf(_spectrum);
        cimg_forXYZ(*this,x,y,z) {
          cimg_forC(*this,c) buf[c] = (*this)(x,y,z,c);
          cimg::fwrite(buf._data,_spectrum,nfile);
        }
      }
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Save image as a video file, using the FFmpeg library.
    /**
      \param filename Filename, as a C-string.
      \param fps Video framerate.
      \param bitrate Video bitrate.
      \note
      - Each slice of the instance image is considered to be a single frame of the output video file.
      - This method uses functions provided by the <a href="http://www.ffmpeg.org">FFmpeg</a> library.
      Configuration macro \c cimg_use_ffmpeg must be set for the method to succeed natively.
      Otherwise, the method calls save_ffmpeg_external(const char*,unsigned int,unsigned int,const char*,unsigned int,unsigned int) const.
    **/
    const CImg<T>& save_ffmpeg(const char *const filename, const unsigned int fps=25, const unsigned int bitrate=2048) const {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_ffmpeg(): Specified filename is (null).",
                                    cimg_instance);
      if (!fps)
        throw CImgArgumentException(_cimg_instance
                                    "save_ffmpeg(): Invalid specified framerate 0, for file '%s'.",
                                    cimg_instance,
                                    filename);
      if (is_empty()) { cimg::fempty(0,filename); return *this; }

#ifndef cimg_use_ffmpeg
      return save_ffmpeg_external(filename,0,fps,bitrate);
#else
# 41358 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      CImgList<T> list;
      get_split('z').move_to(list);
      list.save_ffmpeg(filename,fps,bitrate);
#endif
# 41362 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      return *this;
    }

    //! Save image as a .yuv video file.
    /**
       \param filename Filename, as a C-string.
       \param is_rgb Tells if pixel values of the instance image are RGB-coded (\c true) or YUV-coded (\c false).
       \note Each slice of the instance image is considered to be a single frame of the output video file.
    **/
    const CImg<T>& save_yuv(const char *const filename, const bool is_rgb=true) const {
      get_split('z').save_yuv(filename,is_rgb);
      return *this;
    }

    //! Save image as a .yuv video file \overloading.
    /**
       Same as save_yuv(const char*,bool) const
       with a file stream argument instead of a filename string.
    **/
    const CImg<T>& save_yuv(std::FILE *const file, const bool is_rgb=true) const {
      get_split('z').save_yuv(file,is_rgb);
      return *this;
    }

    //! Save 3d object as an Object File Format (.off) file.
    /**
       \param filename Filename, as a C-string.
       \param primitives List of 3d object primitives.
       \param colors List of 3d object colors.
       \note
       - Instance image contains the vertices data of the 3d object.
       - Textured, transparent or sphere-shaped primitives cannot be managed by the .off file format.
       Such primitives will be lost or simplified during file saving.
       - The .off file format is <a href="http://people.sc.fsu.edu/~jburkardt/html/off_format.html">described here</a>.
    **/
    template<typename tf, typename tc>
    const CImg<T>& save_off(const CImgList<tf>& primitives, const CImgList<tc>& colors,
                            const char *const filename) const {
      return _save_off(primitives,colors,0,filename);
    }

    //! Save 3d object as an Object File Format (.off) file \overloading.
    /**
       Same as save_off(const CImgList<tf>&,const CImgList<tc>&,const char*) const
       with a file stream argument instead of a filename string.
    **/
    template<typename tf, typename tc>
    const CImg<T>& save_off(const CImgList<tf>& primitives, const CImgList<tc>& colors,
                            std::FILE *const file) const {
      return _save_off(primitives,colors,file,0);
    }

    template<typename tf, typename tc>
    const CImg<T>& _save_off(const CImgList<tf>& primitives, const CImgList<tc>& colors,
                             std::FILE *const file, const char *const filename) const {
      if (!file && !filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_off(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty())
        throw CImgInstanceException(_cimg_instance
                                    "save_off(): Empty instance, for file '%s'.",
                                    cimg_instance,
                                    filename?filename:"(FILE*)");

      CImgList<T> opacities;
      char error_message[1024] = { 0 };
      if (!is_object3d(primitives,colors,opacities,true,error_message))
        throw CImgInstanceException(_cimg_instance
                                    "save_off(): Invalid specified 3d object, for file '%s' (%s).",
                                    cimg_instance,
                                    filename?filename:"(FILE*)",error_message);

      const CImg<tc> default_color(1,3,1,1,200);
      std::FILE *const nfile = file?file:cimg::fopen(filename,"w");
      unsigned int supported_primitives = 0;
      cimglist_for(primitives,l) if (primitives[l].size()!=5) ++supported_primitives;
      std::fprintf(nfile,"OFF\n%u %u %u\n",_width,supported_primitives,3*primitives._width);
      cimg_forX(*this,i) std::fprintf(nfile,"%f %f %f\n",(float)((*this)(i,0)),(float)((*this)(i,1)),(float)((*this)(i,2)));
      cimglist_for(primitives,l) {
        const CImg<tc>& color = l<colors.width()?colors[l]:default_color;
        const unsigned int psiz = primitives[l].size(), csiz = color.size();
        const float r = color[0]/255.0f, g = (csiz>1?color[1]:r)/255.0f, b = (csiz>2?color[2]:g)/255.0f;
        switch (psiz) {
        case 1 : std::fprintf(nfile,"1 %u %f %f %f\n",(unsigned int)primitives(l,0),r,g,b); break;
        case 2 : std::fprintf(nfile,"2 %u %u %f %f %f\n",(unsigned int)primitives(l,0),(unsigned int)primitives(l,1),r,g,b); break;
        case 3 : std::fprintf(nfile,"3 %u %u %u %f %f %f\n",(unsigned int)primitives(l,0),(unsigned int)primitives(l,2),
                              (unsigned int)primitives(l,1),r,g,b); break;
        case 4 : std::fprintf(nfile,"4 %u %u %u %u %f %f %f\n",(unsigned int)primitives(l,0),(unsigned int)primitives(l,3),
                              (unsigned int)primitives(l,2),(unsigned int)primitives(l,1),r,g,b); break;
        case 5 : std::fprintf(nfile,"2 %u %u %f %f %f\n",(unsigned int)primitives(l,0),(unsigned int)primitives(l,1),r,g,b); break;
        case 6 : {
          const unsigned int xt = (unsigned int)primitives(l,2), yt = (unsigned int)primitives(l,3);
          const float rt = color.atXY(xt,yt,0)/255.0f, gt = (csiz>1?color.atXY(xt,yt,1):r)/255.0f, bt = (csiz>2?color.atXY(xt,yt,2):g)/255.0f;
          std::fprintf(nfile,"2 %u %u %f %f %f\n",(unsigned int)primitives(l,0),(unsigned int)primitives(l,1),rt,gt,bt);
        } break;
        case 9 : {
          const unsigned int xt = (unsigned int)primitives(l,3), yt = (unsigned int)primitives(l,4);
          const float rt = color.atXY(xt,yt,0)/255.0f, gt = (csiz>1?color.atXY(xt,yt,1):r)/255.0f, bt = (csiz>2?color.atXY(xt,yt,2):g)/255.0f;
          std::fprintf(nfile,"3 %u %u %u %f %f %f\n",(unsigned int)primitives(l,0),(unsigned int)primitives(l,2),
                       (unsigned int)primitives(l,1),rt,gt,bt);
        } break;
        case 12 : {
          const unsigned int xt = (unsigned int)primitives(l,4), yt = (unsigned int)primitives(l,5);
          const float rt = color.atXY(xt,yt,0)/255.0f, gt = (csiz>1?color.atXY(xt,yt,1):r)/255.0f, bt = (csiz>2?color.atXY(xt,yt,2):g)/255.0f;
          std::fprintf(nfile,"4 %u %u %u %u %f %f %f\n",(unsigned int)primitives(l,0),(unsigned int)primitives(l,3),
                       (unsigned int)primitives(l,2),(unsigned int)primitives(l,1),rt,gt,bt);
        } break;
        }
      }
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Save volumetric image as a video, using ffmpeg external binary.
    /**
       \param filename Filename, as a C-string.
       \param codec Video codec, as a C-string.
       \param fps Video framerate.
       \param bitrate Video bitrate.
       \note
       - Each slice of the instance image is considered to be a single frame of the output video file.
       - This method uses \c ffmpeg, an external executable binary provided by <a href="http://www.ffmpeg.org">FFmpeg</a>.
       It must be installed for the method to succeed.
    **/
    const CImg<T>& save_ffmpeg_external(const char *const filename, const char *const codec=0,
                                        const unsigned int fps=25, const unsigned int bitrate=2048) const {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_ffmpeg_external(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(0,filename); return *this; }

      CImgList<T> list;
      get_split('z').move_to(list);
      list.save_ffmpeg_external(filename,codec,fps,bitrate);
      return *this;
    }

    //! Save image using gzip external binary.
    /**
       \param filename Filename, as a C-string.
       \note This method uses \c gzip, an external executable binary provided by <a href="//http://www.gzip.org">gzip</a>.
       It must be installed for the method to succeed.
    **/
    const CImg<T>& save_gzip_external(const char *const filename) const {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_gzip_external(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(0,filename); return *this; }

      char command[1024] = { 0 }, filetmp[512] = { 0 }, body[512] = { 0 };
      const char
        *ext = cimg::split_filename(filename,body),
        *ext2 = cimg::split_filename(body,0);
      std::FILE *file;
      do {
        if (!cimg::strcasecmp(ext,"gz")) {
          if (*ext2) cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s.%s",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand(),ext2);
          else cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s.cimg",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand());
        } else {
          if (*ext) cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s.%s",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand(),ext);
          else cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s.cimg",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand());
        }
        if ((file=std::fopen(filetmp,"rb"))!=0) cimg::fclose(file);
      } while (file);
      save(filetmp);
      cimg_snprintf(command,sizeof(command),"%s -c \"%s\" > \"%s\"",
                    cimg::gzip_path(),
                    CImg<charT>::string(filetmp)._system_strescape().data(),
                    CImg<charT>::string(filename)._system_strescape().data());
      cimg::system(command);
      file = std::fopen(filename,"rb");
      if (!file)
        throw CImgIOException(_cimg_instance
                              "save_gzip_external(): Failed to save file '%s' with external command 'gzip'.",
                              cimg_instance,
                              filename);

      else cimg::fclose(file);
      std::remove(filetmp);
      return *this;
    }

    //! Save image using GraphicsMagick's external binary.
    /**
       \param filename Filename, as a C-string.
       \param quality Image quality (expressed in percent), when the file format supports it.
       \note This method uses \c gm, an external executable binary provided by <a href="http://www.graphicsmagick.org">GraphicsMagick</a>.
       It must be installed for the method to succeed.
    **/
    const CImg<T>& save_graphicsmagick_external(const char *const filename, const unsigned int quality=100) const {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_graphicsmagick_external(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(0,filename); return *this; }

#ifdef cimg_use_png
#define _cimg_sge_ext1 "png"
#define _cimg_sge_ext2 "png"
#else
# 41565 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#define _cimg_sge_ext1 "pgm"
#define _cimg_sge_ext2 "ppm"
#endif
# 41568 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      char command[1024] = { 0 }, filetmp[512] = { 0 };
      std::FILE *file;
      do {
        cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s.%s",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand(),_spectrum==1?_cimg_sge_ext1:_cimg_sge_ext2);
        if ((file=std::fopen(filetmp,"rb"))!=0) cimg::fclose(file);
      } while (file);
#ifdef cimg_use_png
      save_png(filetmp);
#else
# 41577 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      save_pnm(filetmp);
#endif
# 41579 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      cimg_snprintf(command,sizeof(command),"%s convert -quality %u \"%s\" \"%s\"",
                    cimg::graphicsmagick_path(),quality,
                    CImg<charT>::string(filetmp)._system_strescape().data(),
                    CImg<charT>::string(filename)._system_strescape().data());
      cimg::system(command);
      file = std::fopen(filename,"rb");
      if (!file)
        throw CImgIOException(_cimg_instance
                              "save_graphicsmagick_external(): Failed to save file '%s' with external command 'gm'.",
                              cimg_instance,
                              filename);

      if (file) cimg::fclose(file);
      std::remove(filetmp);
      return *this;
    }

    //! Save image using ImageMagick's external binary.
    /**
       \param filename Filename, as a C-string.
       \param quality Image quality (expressed in percent), when the file format supports it.
       \note This method uses \c convert, an external executable binary provided by <a href="http://www.imagemagick.org">ImageMagick</a>.
       It must be installed for the method to succeed.
    **/
    const CImg<T>& save_imagemagick_external(const char *const filename, const unsigned int quality=100) const {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_imagemagick_external(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(0,filename); return *this; }

#ifdef cimg_use_png
#define _cimg_sie_ext1 "png"
#define _cimg_sie_ext2 "png"
#else
# 41614 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#define _cimg_sie_ext1 "pgm"
#define _cimg_sie_ext2 "ppm"
#endif
# 41617 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      char command[1024] = { 0 }, filetmp[512] = { 0 };
      std::FILE *file;
      do {
        cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s.%s",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand(),_spectrum==1?_cimg_sie_ext1:_cimg_sie_ext2);
        if ((file=std::fopen(filetmp,"rb"))!=0) cimg::fclose(file);
      } while (file);
#ifdef cimg_use_png
      save_png(filetmp);
#else
# 41626 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      save_pnm(filetmp);
#endif
# 41628 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      cimg_snprintf(command,sizeof(command),"%s -quality %u \"%s\" \"%s\"",
                    cimg::imagemagick_path(),quality,
                    CImg<charT>::string(filetmp)._system_strescape().data(),
                    CImg<charT>::string(filename)._system_strescape().data());
      cimg::system(command);
      file = std::fopen(filename,"rb");
      if (!file)
        throw CImgIOException(_cimg_instance
                              "save_imagemagick_external(): Failed to save file '%s' with external command 'convert'.",
                              cimg_instance,
                              filename);

      if (file) cimg::fclose(file);
      std::remove(filetmp);
      return *this;
    }

    //! Save image as a Dicom file.
    /**
       \param filename Filename, as a C-string.
       \note This method uses \c medcon, an external executable binary provided by <a href="http://xmedcon.sourceforge.net">(X)Medcon</a>.
       It must be installed for the method to succeed.
    **/
    const CImg<T>& save_medcon_external(const char *const filename) const {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_medcon_external(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(0,filename); return *this; }

      char command[1024] = { 0 }, filetmp[512] = { 0 }, body[512] = { 0 };
      std::FILE *file;
      do {
        cimg_snprintf(filetmp,sizeof(filetmp),"%s.hdr",cimg::filenamerand());
        if ((file=std::fopen(filetmp,"rb"))!=0) cimg::fclose(file);
      } while (file);
      save_analyze(filetmp);
      cimg_snprintf(command,sizeof(command),"%s -w -c dicom -o \"%s\" -f \"%s\"",
                    cimg::medcon_path(),
                    CImg<charT>::string(filename)._system_strescape().data(),
                    CImg<charT>::string(filetmp)._system_strescape().data());
      cimg::system(command);
      std::remove(filetmp);
      cimg::split_filename(filetmp,body);
      cimg_snprintf(filetmp,sizeof(filetmp),"%s.img",body);
      std::remove(filetmp);

      file = std::fopen(filename,"rb");
      if (!file) {
        cimg_snprintf(command,sizeof(command),"m000-%s",filename);
        file = std::fopen(command,"rb");
        if (!file) {
          cimg::fclose(cimg::fopen(filename,"r"));
          throw CImgIOException(_cimg_instance
                                "save_medcon_external(): Failed to save file '%s' with external command 'medcon'.",
                                cimg_instance,
                                filename);
        }
      }
      cimg::fclose(file);
      std::rename(command,filename);
      return *this;
    }

    // Save image for non natively supported formats.
    /**
       \param filename Filename, as a C-string.
       \param quality Image quality (expressed in percent), when the file format supports it.
       \note
       - The filename extension tells about the desired file format.
       - This method tries to save the instance image as a file, using external tools from
       <a href="http://www.imagemagick.org">ImageMagick</a> or
       <a href="http://www.graphicsmagick.org">GraphicsMagick</a>. At least one of these tool must be installed for the method to succeed.
       - It is recommended to use the generic method save(const char*, int) const instead, as it can handle some file formats natively.
    **/
    const CImg<T>& save_other(const char *const filename, const unsigned int quality=100) const {
      if (!filename)
        throw CImgArgumentException(_cimg_instance
                                    "save_other(): Specified filename is (null).",
                                    cimg_instance);
      if (is_empty()) { cimg::fempty(0,filename); return *this; }

      const unsigned int omode = cimg::exception_mode();
      bool is_saved = true;
      cimg::exception_mode() = 0;
      try { save_magick(filename); }
      catch (CImgException&) {
        try { save_imagemagick_external(filename,quality); }
        catch (CImgException&) {
          try { save_graphicsmagick_external(filename,quality); }
          catch (CImgException&) {
            is_saved = false;
          }
        }
      }
      cimg::exception_mode() = omode;
      if (!is_saved)
        throw CImgIOException(_cimg_instance
                              "save_other(): Failed to save file '%s'. Format is not natively supported, and no external commands succeeded.",
                              cimg_instance,
                              filename);
      return *this;
    }

    // [internal] Return a 40x38 color logo of a 'danger' item.
    static CImg<T> _logo40x38() {
      CImg<T> res(40,38,1,3);
      const unsigned char *ptrs = cimg::logo40x38;
      T *ptr1 = res.data(0,0,0,0), *ptr2 = res.data(0,0,0,1), *ptr3 = res.data(0,0,0,2);
      for (unsigned long off = 0; off<(unsigned long)res._width*res._height;) {
        const unsigned char n = *(ptrs++), r = *(ptrs++), g = *(ptrs++), b = *(ptrs++);
        for (unsigned int l = 0; l<n; ++off, ++l) { *(ptr1++) = (T)r; *(ptr2++) = (T)g; *(ptr3++) = (T)b; }
      }
      return res;
    }

    //@}
  };

  /*
   #-----------------------------------------
   #
   #
   #
   # Definition of the CImgList<T> structure
   #
   #
   #
   #------------------------------------------
   */
  //! Represent a list of images CImg<T>.
  template<typename T>
  struct CImgList {
    unsigned int _width, _allocated_width;
    CImg<T> *_data;

    //! Simple iterator type, to loop through each image of a list.
    /**
       \note
       - The \c CImgList<T>::iterator type is defined as a <tt>CImg<T>*</tt>.
       - You may use it like this:
       \code
       CImgList<> list;   // Assuming this image list is not empty.
       for (CImgList<>::iterator it = list.begin(); it<list.end(); ++it) (*it).mirror('x');
       \endcode
       - Using the loop macro \c cimglist_for is another (more concise) alternative:
       \code
       cimglist_for(list,l) list[l].mirror('x');
       \endcode
    **/
    typedef CImg<T>* iterator;

    //! Simple const iterator type, to loop through each image of a \c const list instance.
    /**
       \note
       - The \c CImgList<T>::const_iterator type is defined to be a <tt>const CImg<T>*</tt>.
       - Similar to CImgList<T>::iterator, but for constant list instances.
    **/
    typedef const CImg<T>* const_iterator;

    //! Pixel value type.
    /**
       Refer to the pixels value type of the images in the list.
       \note
       - The \c CImgList<T>::value_type type of a \c CImgList<T> is defined to be a \c T. It is then similar to CImg<T>::value_type.
       - \c CImgList<T>::value_type is actually not used in %CImg methods. It has been mainly defined for
         compatibility with STL naming conventions.
    **/
    typedef T value_type;

    // Define common T-dependant types.
    typedef typename cimg::superset<T,bool>::type Tbool;
    typedef typename cimg::superset<T,unsigned char>::type Tuchar;
    typedef typename cimg::superset<T,char>::type Tchar;
    typedef typename cimg::superset<T,unsigned short>::type Tushort;
    typedef typename cimg::superset<T,short>::type Tshort;
    typedef typename cimg::superset<T,unsigned int>::type Tuint;
    typedef typename cimg::superset<T,int>::type Tint;
    typedef typename cimg::superset<T,unsigned long>::type Tulong;
    typedef typename cimg::superset<T,long>::type Tlong;
    typedef typename cimg::superset<T,float>::type Tfloat;
    typedef typename cimg::superset<T,double>::type Tdouble;
    typedef typename cimg::last<T,bool>::type boolT;
    typedef typename cimg::last<T,unsigned char>::type ucharT;
    typedef typename cimg::last<T,char>::type charT;
    typedef typename cimg::last<T,unsigned short>::type ushortT;
    typedef typename cimg::last<T,short>::type shortT;
    typedef typename cimg::last<T,unsigned int>::type uintT;
    typedef typename cimg::last<T,int>::type intT;
    typedef typename cimg::last<T,unsigned long>::type ulongT;
    typedef typename cimg::last<T,long>::type longT;
    typedef typename cimg::last<T,float>::type floatT;
    typedef typename cimg::last<T,double>::type doubleT;

    //@}
    //---------------------------
    //
    //! \name Plugins
    //@{
    //---------------------------
#ifdef cimglist_plugin
#if 0 /* expanded by -frewrite-includes */
#include cimglist_plugin
#endif /* expanded by -frewrite-includes */
# 41830 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 41831 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_plugin1
#if 0 /* expanded by -frewrite-includes */
#include cimglist_plugin1
#endif /* expanded by -frewrite-includes */
# 41833 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 41834 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_plugin2
#if 0 /* expanded by -frewrite-includes */
#include cimglist_plugin2
#endif /* expanded by -frewrite-includes */
# 41836 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 41837 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_plugin3
#if 0 /* expanded by -frewrite-includes */
#include cimglist_plugin3
#endif /* expanded by -frewrite-includes */
# 41839 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 41840 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_plugin4
#if 0 /* expanded by -frewrite-includes */
#include cimglist_plugin4
#endif /* expanded by -frewrite-includes */
# 41842 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 41843 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_plugin5
#if 0 /* expanded by -frewrite-includes */
#include cimglist_plugin5
#endif /* expanded by -frewrite-includes */
# 41845 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 41846 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_plugin6
#if 0 /* expanded by -frewrite-includes */
#include cimglist_plugin6
#endif /* expanded by -frewrite-includes */
# 41848 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 41849 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_plugin7
#if 0 /* expanded by -frewrite-includes */
#include cimglist_plugin7
#endif /* expanded by -frewrite-includes */
# 41851 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 41852 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_plugin8
#if 0 /* expanded by -frewrite-includes */
#include cimglist_plugin8
#endif /* expanded by -frewrite-includes */
# 41854 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#endif
# 41855 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    //@}
    //--------------------------------------------------------
    //
    //! \name Constructors / Destructor / Instance Management
    //@{
    //--------------------------------------------------------

    //! Destructor.
    /**
       Destroy current list instance.
       \note
       - Any allocated buffer is deallocated.
       - Destroying an empty list does nothing actually.
     **/
    ~CImgList() {
      delete[] _data;
    }

    //! Default constructor.
    /**
       Construct a new empty list instance.
       \note
       - An empty list has no pixel data and its dimension width() is set to \c 0, as well as its image buffer pointer data().
       - An empty list may be reassigned afterwards, with the family of the assign() methods. In all cases, the type of pixels stays \c T.
     **/
    CImgList():
      _width(0),_allocated_width(0),_data(0) {}

    //! Construct list containing empty images.
    /**
       \param n Number of empty images.
       \note Useful when you know by advance the number of images you want to manage, as
       it will allocate the right amount of memory for the list, without needs for reallocation
       (that may occur when starting from an empty list and inserting several images in it).
    **/
    explicit CImgList(const unsigned int n):_width(n) {
      if (n) _data = new CImg<T>[_allocated_width = cimg::max(16UL,cimg::nearest_pow2(n))];
      else { _allocated_width = 0; _data = 0; }
    }

    //! Construct list containing images of specified size.
    /**
       \param n Number of images.
       \param width Width of images.
       \param height Height of images.
       \param depth Depth of images.
       \param spectrum Number of channels of images.
       \note Pixel values are not initialized and may probably contain garbage.
    **/
    CImgList(const unsigned int n, const unsigned int width, const unsigned int height=1,
             const unsigned int depth=1, const unsigned int spectrum=1):
      _width(0),_allocated_width(0),_data(0) {
      assign(n);
      cimglist_apply(*this,assign)(width,height,depth,spectrum);
    }

    //! Construct list containing images of specified size, and initialize pixel values.
    /**
       \param n Number of images.
       \param width Width of images.
       \param height Height of images.
       \param depth Depth of images.
       \param spectrum Number of channels of images.
       \param val Initialization value for images pixels.
    **/
    CImgList(const unsigned int n, const unsigned int width, const unsigned int height,
             const unsigned int depth, const unsigned int spectrum, const T val):
      _width(0),_allocated_width(0),_data(0) {
      assign(n);
      cimglist_apply(*this,assign)(width,height,depth,spectrum,val);
    }

    //! Construct list containing images of specified size, and initialize pixel values from a sequence of integers.
    /**
       \param n Number of images.
       \param width Width of images.
       \param height Height of images.
       \param depth Depth of images.
       \param spectrum Number of channels of images.
       \param val0 First value of the initializing integers sequence.
       \param val1 Second value of the initializing integers sequence.
       \warning You must specify at least <tt>width*height*depth*spectrum</tt> values in your argument list, or you will probably segfault.
    **/
    CImgList(const unsigned int n, const unsigned int width, const unsigned int height,
             const unsigned int depth, const unsigned int spectrum, const int val0, const int val1, ...):
      _width(0),_allocated_width(0),_data(0) {
#define _CImgList_stdarg(t) { \
	assign(n,width,height,depth,spectrum); \
	const unsigned long siz = (unsigned long)width*height*depth*spectrum, nsiz = siz*n; \
	T *ptrd = _data->_data; \
	va_list ap; \
	va_start(ap,val1); \
	for (unsigned long l = 0, s = 0, i = 0; i<nsiz; ++i) { \
	  *(ptrd++) = (T)(i==0?val0:(i==1?val1:va_arg(ap,t))); \
	  if ((++s)==siz) { ptrd = _data[++l]._data; s = 0; } \
	} \
	va_end(ap); \
      }
      _CImgList_stdarg(int);
    }

    //! Construct list containing images of specified size, and initialize pixel values from a sequence of doubles.
    /**
       \param n Number of images.
       \param width Width of images.
       \param height Height of images.
       \param depth Depth of images.
       \param spectrum Number of channels of images.
       \param val0 First value of the initializing doubles sequence.
       \param val1 Second value of the initializing doubles sequence.
       \warning You must specify at least <tt>width*height*depth*spectrum</tt> values in your argument list, or you will probably segfault.
    **/
    CImgList(const unsigned int n, const unsigned int width, const unsigned int height,
             const unsigned int depth, const unsigned int spectrum, const double val0, const double val1, ...):
      _width(0),_allocated_width(0),_data(0) {
      _CImgList_stdarg(double);
    }

    //! Construct list containing copies of an input image.
    /**
       \param n Number of images.
       \param img Input image to copy in the constructed list.
       \param is_shared Tells if the elements of the list are shared or non-shared copies of \c img.
    **/
    template<typename t>
    CImgList(const unsigned int n, const CImg<t>& img, const bool is_shared=false):
      _width(0),_allocated_width(0),_data(0) {
      assign(n);
      cimglist_apply(*this,assign)(img,is_shared);
    }

    //! Construct list from one image.
    /**
       \param img Input image to copy in the constructed list.
       \param is_shared Tells if the element of the list is a shared or non-shared copy of \c img.
     **/
    template<typename t>
    explicit CImgList(const CImg<t>& img, const bool is_shared=false):
      _width(0),_allocated_width(0),_data(0) {
      assign(1);
      _data[0].assign(img,is_shared);
    }

    //! Construct list from two images.
    /**
       \param img1 First input image to copy in the constructed list.
       \param img2 Second input image to copy in the constructed list.
       \param is_shared Tells if the elements of the list are shared or non-shared copies of input images.
     **/
    template<typename t1, typename t2>
    CImgList(const CImg<t1>& img1, const CImg<t2>& img2, const bool is_shared=false):
      _width(0),_allocated_width(0),_data(0) {
      assign(2);
      _data[0].assign(img1,is_shared); _data[1].assign(img2,is_shared);
    }

    //! Construct list from three images.
    /**
       \param img1 First input image to copy in the constructed list.
       \param img2 Second input image to copy in the constructed list.
       \param img3 Third input image to copy in the constructed list.
       \param is_shared Tells if the elements of the list are shared or non-shared copies of input images.
    **/
    template<typename t1, typename t2, typename t3>
    CImgList(const CImg<t1>& img1, const CImg<t2>& img2, const CImg<t3>& img3, const bool is_shared=false):
      _width(0),_allocated_width(0),_data(0) {
      assign(3);
      _data[0].assign(img1,is_shared); _data[1].assign(img2,is_shared); _data[2].assign(img3,is_shared);
    }

    //! Construct list from four images.
    /**
       \param img1 First input image to copy in the constructed list.
       \param img2 Second input image to copy in the constructed list.
       \param img3 Third input image to copy in the constructed list.
       \param img4 Fourth input image to copy in the constructed list.
       \param is_shared Tells if the elements of the list are shared or non-shared copies of input images.
    **/
    template<typename t1, typename t2, typename t3, typename t4>
    CImgList(const CImg<t1>& img1, const CImg<t2>& img2, const CImg<t3>& img3, const CImg<t4>& img4, const bool is_shared=false):
      _width(0),_allocated_width(0),_data(0) {
      assign(4);
      _data[0].assign(img1,is_shared); _data[1].assign(img2,is_shared); _data[2].assign(img3,is_shared); _data[3].assign(img4,is_shared);
    }

    //! Construct list from five images.
    /**
       \param img1 First input image to copy in the constructed list.
       \param img2 Second input image to copy in the constructed list.
       \param img3 Third input image to copy in the constructed list.
       \param img4 Fourth input image to copy in the constructed list.
       \param img5 Fifth input image to copy in the constructed list.
       \param is_shared Tells if the elements of the list are shared or non-shared copies of input images.
    **/
    template<typename t1, typename t2, typename t3, typename t4, typename t5>
    CImgList(const CImg<t1>& img1, const CImg<t2>& img2, const CImg<t3>& img3, const CImg<t4>& img4,
             const CImg<t5>& img5, const bool is_shared=false):
      _width(0),_allocated_width(0),_data(0) {
      assign(5);
      _data[0].assign(img1,is_shared); _data[1].assign(img2,is_shared); _data[2].assign(img3,is_shared); _data[3].assign(img4,is_shared);
      _data[4].assign(img5,is_shared);
    }

    //! Construct list from six images.
    /**
       \param img1 First input image to copy in the constructed list.
       \param img2 Second input image to copy in the constructed list.
       \param img3 Third input image to copy in the constructed list.
       \param img4 Fourth input image to copy in the constructed list.
       \param img5 Fifth input image to copy in the constructed list.
       \param img6 Sixth input image to copy in the constructed list.
       \param is_shared Tells if the elements of the list are shared or non-shared copies of input images.
    **/
    template<typename t1, typename t2, typename t3, typename t4, typename t5, typename t6>
    CImgList(const CImg<t1>& img1, const CImg<t2>& img2, const CImg<t3>& img3, const CImg<t4>& img4,
             const CImg<t5>& img5, const CImg<t6>& img6, const bool is_shared=false):
      _width(0),_allocated_width(0),_data(0) {
      assign(6);
      _data[0].assign(img1,is_shared); _data[1].assign(img2,is_shared); _data[2].assign(img3,is_shared); _data[3].assign(img4,is_shared);
      _data[4].assign(img5,is_shared); _data[5].assign(img6,is_shared);
    }

    //! Construct list from seven images.
    /**
       \param img1 First input image to copy in the constructed list.
       \param img2 Second input image to copy in the constructed list.
       \param img3 Third input image to copy in the constructed list.
       \param img4 Fourth input image to copy in the constructed list.
       \param img5 Fifth input image to copy in the constructed list.
       \param img6 Sixth input image to copy in the constructed list.
       \param img7 Seventh input image to copy in the constructed list.
       \param is_shared Tells if the elements of the list are shared or non-shared copies of input images.
    **/
    template<typename t1, typename t2, typename t3, typename t4, typename t5, typename t6, typename t7>
    CImgList(const CImg<t1>& img1, const CImg<t2>& img2, const CImg<t3>& img3, const CImg<t4>& img4,
             const CImg<t5>& img5, const CImg<t6>& img6, const CImg<t7>& img7, const bool is_shared=false):
      _width(0),_allocated_width(0),_data(0) {
      assign(7);
      _data[0].assign(img1,is_shared); _data[1].assign(img2,is_shared); _data[2].assign(img3,is_shared); _data[3].assign(img4,is_shared);
      _data[4].assign(img5,is_shared); _data[5].assign(img6,is_shared); _data[6].assign(img7,is_shared);
    }

    //! Construct list from eight images.
    /**
       \param img1 First input image to copy in the constructed list.
       \param img2 Second input image to copy in the constructed list.
       \param img3 Third input image to copy in the constructed list.
       \param img4 Fourth input image to copy in the constructed list.
       \param img5 Fifth input image to copy in the constructed list.
       \param img6 Sixth input image to copy in the constructed list.
       \param img7 Seventh input image to copy in the constructed list.
       \param img8 Eighth input image to copy in the constructed list.
       \param is_shared Tells if the elements of the list are shared or non-shared copies of input images.
    **/
    template<typename t1, typename t2, typename t3, typename t4, typename t5, typename t6, typename t7, typename t8>
    CImgList(const CImg<t1>& img1, const CImg<t2>& img2, const CImg<t3>& img3, const CImg<t4>& img4,
             const CImg<t5>& img5, const CImg<t6>& img6, const CImg<t7>& img7, const CImg<t8>& img8, const bool is_shared=false):
      _width(0),_allocated_width(0),_data(0) {
      assign(8);
      _data[0].assign(img1,is_shared); _data[1].assign(img2,is_shared); _data[2].assign(img3,is_shared); _data[3].assign(img4,is_shared);
      _data[4].assign(img5,is_shared); _data[5].assign(img6,is_shared); _data[6].assign(img7,is_shared); _data[7].assign(img8,is_shared);
    }

    //! Construct list copy.
    /**
       \param list Input list to copy.
       \note The shared state of each element of the constructed list is kept the same as in \c list.
    **/
    template<typename t>
    CImgList(const CImgList<t>& list):_width(0),_allocated_width(0),_data(0) {
      assign(list._width);
      cimglist_for(*this,l) _data[l].assign(list[l],false);
    }

    //! Construct list copy \specialization.
    CImgList(const CImgList<T>& list):_width(0),_allocated_width(0),_data(0) {
      assign(list._width);
      cimglist_for(*this,l) _data[l].assign(list[l],list[l]._is_shared);
    }

    //! Construct list copy, and force the shared state of the list elements.
    /**
       \param list Input list to copy.
       \param is_shared Tells if the elements of the list are shared or non-shared copies of input images.
    **/
    template<typename t>
    CImgList(const CImgList<t>& list, const bool is_shared):_width(0),_allocated_width(0),_data(0) {
      assign(list._width);
      cimglist_for(*this,l) _data[l].assign(list[l],is_shared);
    }

    //! Construct list by reading the content of a file.
    /**
       \param filename Filename, as a C-string.
    **/
    explicit CImgList(const char *const filename):_width(0),_allocated_width(0),_data(0) {
      assign(filename);
    }

    //! Construct list from the content of a display window.
    /**
       \param disp Display window to get content from.
       \note Constructed list contains a single image only.
    **/
    explicit CImgList(const CImgDisplay& disp):_width(0),_allocated_width(0),_data(0) {
      assign(disp);
    }

    //! Return a list with elements being shared copies of images in the list instance.
    /**
      \note <tt>list2 = list1.get_shared()</tt> is equivalent to <tt>list2.assign(list1,true)</tt>.
    **/
    CImgList<T> get_shared() {
      CImgList<T> res(_width);
      cimglist_for(*this,l) res[l].assign(_data[l],true);
      return res;
    }

    //! Return a list with elements being shared copies of images in the list instance \const.
    const CImgList<T> get_shared() const {
      CImgList<T> res(_width);
      cimglist_for(*this,l) res[l].assign(_data[l],true);
      return res;
    }

    //! Destructor \inplace.
    /**
       \see CImgList().
    **/
    CImgList<T>& assign() {
      delete[] _data;
      _width = _allocated_width = 0;
      _data = 0;
      return *this;
    }

    //! Destructor \inplace.
    /**
       Equivalent to assign().
       \note Only here for compatibility with STL naming conventions.
    **/
    CImgList<T>& clear() {
      return assign();
    }

    //! Construct list containing empty images \inplace.
    /**
       \see CImgList(unsigned int).
    **/
    CImgList<T>& assign(const unsigned int n) {
      if (!n) return assign();
      if (_allocated_width<n || _allocated_width>(n<<2)) {
        delete[] _data;
        _data = new CImg<T>[_allocated_width=cimg::max(16UL,cimg::nearest_pow2(n))];
      }
      _width = n;
      return *this;
    }

    //! Construct list containing images of specified size \inplace.
    /**
       \see CImgList(unsigned int, unsigned int, unsigned int, unsigned int, unsigned int).
    **/
    CImgList<T>& assign(const unsigned int n, const unsigned int width, const unsigned int height=1,
                        const unsigned int depth=1, const unsigned int spectrum=1) {
      assign(n);
      cimglist_apply(*this,assign)(width,height,depth,spectrum);
      return *this;
    }

    //! Construct list containing images of specified size, and initialize pixel values \inplace.
    /**
       \see CImgList(unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, const T).
    **/
    CImgList<T>& assign(const unsigned int n, const unsigned int width, const unsigned int height,
                        const unsigned int depth, const unsigned int spectrum, const T val) {
      assign(n);
      cimglist_apply(*this,assign)(width,height,depth,spectrum,val);
      return *this;
    }

    //! Construct list containing images of specified size, and initialize pixel values from a sequence of integers \inplace.
    /**
       \see CImgList(unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, const int, const int, ...).
    **/
    CImgList<T>& assign(const unsigned int n, const unsigned int width, const unsigned int height,
                        const unsigned int depth, const unsigned int spectrum, const int val0, const int val1, ...) {
      _CImgList_stdarg(int);
      return *this;
    }

    //! Construct list containing images of specified size, and initialize pixel values from a sequence of doubles \inplace.
    /**
       \see CImgList(unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, const double, const double, ...).
    **/
    CImgList<T>& assign(const unsigned int n, const unsigned int width, const unsigned int height,
                        const unsigned int depth, const unsigned int spectrum, const double val0, const double val1, ...) {
      _CImgList_stdarg(double);
      return *this;
    }

    //! Construct list containing copies of an input image \inplace.
    /**
       \see CImgList(unsigned int, const CImg<t>&, bool).
    **/
    template<typename t>
    CImgList<T>& assign(const unsigned int n, const CImg<t>& img, const bool is_shared=false) {
      assign(n);
      cimglist_apply(*this,assign)(img,is_shared);
      return *this;
    }

    //! Construct list from one image \inplace.
    /**
       \see CImgList(const CImg<t>&, bool).
    **/
    template<typename t>
    CImgList<T>& assign(const CImg<t>& img, const bool is_shared=false) {
      assign(1);
      _data[0].assign(img,is_shared);
      return *this;
    }

    //! Construct list from two images \inplace.
    /**
       \see CImgList(const CImg<t>&, const CImg<t>&, bool).
    **/
    template<typename t1, typename t2>
    CImgList<T>& assign(const CImg<t1>& img1, const CImg<t2>& img2, const bool is_shared=false) {
      assign(2);
      _data[0].assign(img1,is_shared); _data[1].assign(img2,is_shared);
      return *this;
    }

    //! Construct list from three images \inplace.
    /**
       \see CImgList(const CImg<t>&, const CImg<t>&, const CImg<t>&, bool).
    **/
    template<typename t1, typename t2, typename t3>
    CImgList<T>& assign(const CImg<t1>& img1, const CImg<t2>& img2, const CImg<t3>& img3, const bool is_shared=false) {
      assign(3);
      _data[0].assign(img1,is_shared); _data[1].assign(img2,is_shared); _data[2].assign(img3,is_shared);
      return *this;
    }

    //! Construct list from four images \inplace.
    /**
       \see CImgList(const CImg<t>&, const CImg<t>&, const CImg<t>&, const CImg<t>&, bool).
    **/
    template<typename t1, typename t2, typename t3, typename t4>
    CImgList<T>& assign(const CImg<t1>& img1, const CImg<t2>& img2, const CImg<t3>& img3, const CImg<t4>& img4,
                        const bool is_shared=false) {
      assign(4);
      _data[0].assign(img1,is_shared); _data[1].assign(img2,is_shared); _data[2].assign(img3,is_shared); _data[3].assign(img4,is_shared);
      return *this;
    }

    //! Construct list from five images \inplace.
    /**
       \see CImgList(const CImg<t>&, const CImg<t>&, const CImg<t>&, const CImg<t>&, const CImg<t>&, bool).
    **/
    template<typename t1, typename t2, typename t3, typename t4, typename t5>
    CImgList<T>& assign(const CImg<t1>& img1, const CImg<t2>& img2, const CImg<t3>& img3, const CImg<t4>& img4,
                        const CImg<t5>& img5, const bool is_shared=false) {
      assign(5);
      _data[0].assign(img1,is_shared); _data[1].assign(img2,is_shared); _data[2].assign(img3,is_shared); _data[3].assign(img4,is_shared);
      _data[4].assign(img5,is_shared);
      return *this;
    }

    //! Construct list from six images \inplace.
    /**
       \see CImgList(const CImg<t>&, const CImg<t>&, const CImg<t>&, const CImg<t>&, const CImg<t>&, const CImg<t>&, bool).
    **/
    template<typename t1, typename t2, typename t3, typename t4, typename t5, typename t6>
    CImgList<T>& assign(const CImg<t1>& img1, const CImg<t2>& img2, const CImg<t3>& img3, const CImg<t4>& img4,
                        const CImg<t5>& img5, const CImg<t6>& img6, const bool is_shared=false) {
      assign(6);
      _data[0].assign(img1,is_shared); _data[1].assign(img2,is_shared); _data[2].assign(img3,is_shared); _data[3].assign(img4,is_shared);
      _data[4].assign(img5,is_shared); _data[5].assign(img6,is_shared);
      return *this;
    }

    //! Construct list from seven images \inplace.
    /**
       \see CImgList(const CImg<t>&, const CImg<t>&, const CImg<t>&, const CImg<t>&, const CImg<t>&, const CImg<t>&, const CImg<t>&, bool).
    **/
    template<typename t1, typename t2, typename t3, typename t4, typename t5, typename t6, typename t7>
    CImgList<T>& assign(const CImg<t1>& img1, const CImg<t2>& img2, const CImg<t3>& img3, const CImg<t4>& img4,
                        const CImg<t5>& img5, const CImg<t6>& img6, const CImg<t7>& img7, const bool is_shared=false) {
      assign(7);
      _data[0].assign(img1,is_shared); _data[1].assign(img2,is_shared); _data[2].assign(img3,is_shared); _data[3].assign(img4,is_shared);
      _data[4].assign(img5,is_shared); _data[5].assign(img6,is_shared); _data[6].assign(img7,is_shared);
      return *this;
    }

    //! Construct list from eight images \inplace.
    /**
       \see CImgList(const CImg<t>&, const CImg<t>&, const CImg<t>&, const CImg<t>&, const CImg<t>&, const CImg<t>&, const CImg<t>&, const CImg<t>&, bool).
    **/
    template<typename t1, typename t2, typename t3, typename t4, typename t5, typename t6, typename t7, typename t8>
    CImgList<T>& assign(const CImg<t1>& img1, const CImg<t2>& img2, const CImg<t3>& img3, const CImg<t4>& img4,
                        const CImg<t5>& img5, const CImg<t6>& img6, const CImg<t7>& img7, const CImg<t8>& img8,
                        const bool is_shared=false) {
      assign(8);
      _data[0].assign(img1,is_shared); _data[1].assign(img2,is_shared); _data[2].assign(img3,is_shared); _data[3].assign(img4,is_shared);
      _data[4].assign(img5,is_shared); _data[5].assign(img6,is_shared); _data[6].assign(img7,is_shared); _data[7].assign(img8,is_shared);
      return *this;
    }

    //! Construct list as a copy of an existing list and force the shared state of the list elements \inplace.
    /**
      \see CImgList(const CImgList<t>&, bool is_shared).
    **/
    template<typename t>
    CImgList<T>& assign(const CImgList<t>& list, const bool is_shared=false) {
      cimg::unused(is_shared);
      assign(list._width);
      cimglist_for(*this,l) _data[l].assign(list[l],false);
      return *this;
    }

    //! Construct list as a copy of an existing list and force the shared state of the list elements \inplace \specialization.
    CImgList<T>& assign(const CImgList<T>& list, const bool is_shared=false) {
      if (this==&list) return *this;
      CImgList<T> res(list._width);
      cimglist_for(res,l) res[l].assign(list[l],is_shared);
      return res.move_to(*this);
    }

    //! Construct list by reading the content of a file \inplace.
    /**
      \see CImgList(const char *const).
    **/
    CImgList<T>& assign(const char *const filename) {
      return load(filename);
    }

    //! Construct list from the content of a display window \inplace.
    /**
      \see CImgList(const CImgDisplay&).
    **/
    CImgList<T>& assign(const CImgDisplay &disp) {
      return assign(CImg<T>(disp));
    }

    //! Transfer the content of the list instance to another list.
    /**
       \param list Destination list.
       \note When returning, the current list instance is empty and the initial content of \c list is destroyed.
    **/
    template<typename t>
    CImgList<t>& move_to(CImgList<t>& list) {
      list.assign(_width);
      bool is_one_shared_element = false;
      cimglist_for(*this,l) is_one_shared_element|=_data[l]._is_shared;
      if (is_one_shared_element) cimglist_for(*this,l) list[l].assign(_data[l]);
      else cimglist_for(*this,l) _data[l].move_to(list[l]);
      assign();
      return list;
    }

    //! Transfer the content of the list instance at a specified position in another list.
    /**
       \param list Destination list.
       \param pos Index of the insertion in the list.
       \note When returning, the list instance is empty and the initial content of \c list is preserved
       (only images indexes may be modified).
     **/
    template<typename t>
    CImgList<t>& move_to(CImgList<t>& list, const unsigned int pos) {
      if (is_empty()) return list;
      const unsigned int npos = pos>list._width?list._width:pos;
      list.insert(_width,npos);
      bool is_one_shared_element = false;
      cimglist_for(*this,l) is_one_shared_element|=_data[l]._is_shared;
      if (is_one_shared_element) cimglist_for(*this,l) list[npos+l].assign(_data[l]);
      else cimglist_for(*this,l) _data[l].move_to(list[npos+l]);
      assign();
      return list;
    }

    //! Swap all fields between two list instances.
    /**
       \param list List to swap fields with.
       \note Can be used to exchange the content of two lists in a fast way.
    **/
    CImgList<T>& swap(CImgList<T>& list) {
      cimg::swap(_width,list._width);
      cimg::swap(_allocated_width,list._allocated_width);
      cimg::swap(_data,list._data);
      return list;
    }

    //! Return a reference to an empty list.
    /**
      \note Can be used to define default values in a function taking a CImgList<T> as an argument.
      \code
      void f(const CImgList<char>& list=CImgList<char>::empty());
      \endcode
    **/
    static CImgList<T>& empty() {
      static CImgList<T> _empty;
      return _empty.assign();
    }

    //@}
    //------------------------------------------
    //
    //! \name Overloaded Operators
    //@{
    //------------------------------------------

    //! Return a reference to one image element of the list.
    /**
       \param pos Indice of the image element.
    **/
    CImg<T>& operator()(const unsigned int pos) {
#if cimg_verbosity>=3
      if (pos>=_width) {
        cimg::warn(_cimglist_instance
                   "operator(): Invalid image request, at position [%u].",
                   cimglist_instance,
                   pos);
        return *_data;
      }
#endif
# 42483 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      return _data[pos];
    }

    //! Return a reference to one image of the list.
    /**
       \param pos Indice of the image element.
    **/
    const CImg<T>& operator()(const unsigned int pos) const {
      return const_cast<CImgList<T>*>(this)->operator()(pos);
    }

    //! Return a reference to one pixel value of one image of the list.
    /**
       \param pos Indice of the image element.
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \note <tt>list(n,x,y,z,c)</tt> is equivalent to <tt>list[n](x,y,z,c)</tt>.
    **/
    T& operator()(const unsigned int pos, const unsigned int x, const unsigned int y=0,
                  const unsigned int z=0, const unsigned int c=0) {
      return (*this)[pos](x,y,z,c);
    }

    //! Return a reference to one pixel value of one image of the list \const.
    const T& operator()(const unsigned int pos, const unsigned int x, const unsigned int y=0,
                        const unsigned int z=0, const unsigned int c=0) const {
      return (*this)[pos](x,y,z,c);
    }

    //! Return pointer to the first image of the list.
    /**
       \note Images in a list are stored as a buffer of \c CImg<T>.
    **/
    operator CImg<T>*() {
      return _data;
    }

    //! Return pointer to the first image of the list \const.
    operator const CImg<T>*() const {
      return _data;
    }

    //! Construct list from one image \inplace.
    /**
        \param img Input image to copy in the constructed list.
        \note <tt>list = img;</tt> is equivalent to <tt>list.assign(img);</tt>.
    **/
    template<typename t>
    CImgList<T>& operator=(const CImg<t>& img) {
      return assign(img);
    }

    //! Construct list from another list.
    /**
       \param list Input list to copy.
       \note <tt>list1 = list2</tt> is equivalent to <tt>list1.assign(list2);</tt>.
    **/
    template<typename t>
    CImgList<T>& operator=(const CImgList<t>& list) {
      return assign(list);
    }

    //! Construct list from another list \specialization.
    CImgList<T>& operator=(const CImgList<T>& list) {
      return assign(list);
    }

    //! Construct list by reading the content of a file \inplace.
    /**
       \see CImgList(const char *const).
    **/
    CImgList<T>& operator=(const char *const filename) {
      return assign(filename);
    }

    //! Construct list from the content of a display window \inplace.
    /**
        \see CImgList(const CImgDisplay&).
    **/
    CImgList<T>& operator=(const CImgDisplay& disp) {
      return assign(disp);
    }

    //! Return a non-shared copy of a list.
    /**
        \note <tt>+list</tt> is equivalent to <tt>CImgList<T>(list,false)</tt>. It forces the copy to have non-shared elements.
    **/
    CImgList<T> operator+() const {
      return CImgList<T>(*this,false);
    }

    //! Return a copy of the list instance, where image \c img has been inserted at the end.
    /**
       \param img Image inserted at the end of the instance copy.
       \note Define a convenient way to create temporary lists of images, as in the following code:
       \code
       (img1,img2,img3,img4).display("My four images");
       \endcode
    **/
    template<typename t>
    CImgList<T>& operator,(const CImg<t>& img) {
      return insert(img);
    }

    //! Return a copy of the list instance, where all elements of input list \c list have been inserted at the end.
    /**
       \param list List inserted at the end of the instance copy.
    **/
    template<typename t>
    CImgList<T>& operator,(const CImgList<t>& list) {
      return insert(list);
    }

    //! Return image corresponding to the appending of all images of the instance list along specified axis.
    /**
      \param axis Appending axis. Can be <tt>{ 'x' | 'y' | 'z' | 'c' }</tt>.
      \note <tt>list>'x'</tt> is equivalent to <tt>list.get_append('x')</tt>.
    **/
    CImg<T> operator>(const char axis) const {
      return get_append(axis,0);
    }

    //! Return list corresponding to the splitting of all images of the instance list along specified axis.
    /**
      \param axis Axis used for image splitting.
      \note <tt>list<'x'</tt> is equivalent to <tt>list.get_split('x')</tt>.
    **/
    CImgList<T> operator<(const char axis) const {
      return get_split(axis);
    }

    //@}
    //-------------------------------------
    //
    //! \name Instance Characteristics
    //@{
    //-------------------------------------

    //! Return the type of image pixel values as a C string.
    /**
       Return a \c char* string containing the usual type name of the image pixel values
       (i.e. a stringified version of the template parameter \c T).
       \note
       - The returned string may contain spaces (as in \c "unsigned char").
       - If the pixel type \c T does not correspond to a registered type, the string <tt>"unknown"</tt> is returned.
    **/
    static const char* pixel_type() {
      return cimg::type<T>::string();
    }

    //! Return the size of the list, i.e. the number of images contained in it.
    /**
      \note Similar to size() but returns result as a (signed) integer.
    **/
    int width() const {
      return (int)_width;
    }

    //! Return the size of the list, i.e. the number of images contained in it.
    /**
      \note Similar to width() but returns result as an unsigned integer.
    **/
    unsigned int size() const {
      return _width;
    }

    //! Return pointer to the first image of the list.
    /**
       \note Images in a list are stored as a buffer of \c CImg<T>.
    **/
    CImg<T> *data() {
      return _data;
    }

    //! Return pointer to the first image of the list \const.
    const CImg<T> *data() const {
      return _data;
    }

    //! Return pointer to the pos-th image of the list.
    /**
       \param pos Indice of the image element to access.
       \note <tt>list.data(n);</tt> is equivalent to <tt>list.data + n;</tt>.
    **/
#if cimg_verbosity>=3
    CImg<T> *data(const unsigned int pos) {
      if (pos>=size())
        cimg::warn(_cimglist_instance
                   "data(): Invalid pointer request, at position [%u].",
                   cimglist_instance,
                   pos);
      return _data + pos;
    }

    const CImg<T> *data(const unsigned int l) const {
      return const_cast<CImgList<T>*>(this)->data(l);
    }
#else
# 42683 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    CImg<T> *data(const unsigned int l) {
      return _data + l;
    }

    //! Return pointer to the pos-th image of the list \const.
    const CImg<T> *data(const unsigned int l) const {
      return _data + l;
    }
#endif
# 42692 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

    //! Return iterator to the first image of the list.
    /**
    **/
    iterator begin() {
      return _data;
    }

    //! Return iterator to the first image of the list \const.
    const_iterator begin() const {
      return _data;
    }

    //! Return iterator to one position after the last image of the list.
    /**
    **/
    iterator end() {
      return _data + _width;
    }

    //! Return iterator to one position after the last image of the list \const.
    const_iterator end() const {
      return _data + _width;
    }

    //! Return reference to the first image of the list.
    /**
    **/
    CImg<T>& front() {
      return *_data;
    }

    //! Return reference to the first image of the list \const.
    const CImg<T>& front() const {
      return *_data;
    }

    //! Return a reference to the last image of the list.
    /**
    **/
    const CImg<T>& back() const {
      return *(_data + _width - 1);
    }

    //! Return a reference to the last image of the list \const.
    CImg<T>& back() {
      return *(_data + _width - 1);
    }

    //! Return pos-th image of the list.
    /**
       \param pos Indice of the image element to access.
    **/
    CImg<T>& at(const int pos) {
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "at(): Empty instance.",
                                    cimglist_instance);

      return _data[pos<0?0:pos>=(int)_width?(int)_width-1:pos];
    }

    //! Access to pixel value with Dirichlet boundary conditions.
    /**
       \param pos Indice of the image element to access.
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \param out_value Default value returned if \c offset is outside image bounds.
       \note <tt>list.atNXYZC(p,x,y,z,c);</tt> is equivalent to <tt>list[p].atXYZC(x,y,z,c);</tt>.
    **/
    T& atNXYZC(const int pos, const int x, const int y, const int z, const int c, const T out_value) {
      return (pos<0 || pos>=(int)_width)?(cimg::temporary(out_value)=out_value):_data[pos].atXYZC(x,y,z,c,out_value);
    }

    //! Access to pixel value with Dirichlet boundary conditions \const.
    T atNXYZC(const int pos, const int x, const int y, const int z, const int c, const T out_value) const {
      return (pos<0 || pos>=(int)_width)?out_value:_data[pos].atXYZC(x,y,z,c,out_value);
    }

    //! Access to pixel value with Neumann boundary conditions.
    /**
       \param pos Indice of the image element to access.
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \note <tt>list.atNXYZC(p,x,y,z,c);</tt> is equivalent to <tt>list[p].atXYZC(x,y,z,c);</tt>.
    **/
    T& atNXYZC(const int pos, const int x, const int y, const int z, const int c) {
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "atNXYZC(): Empty instance.",
                                    cimglist_instance);

      return _atNXYZC(pos,x,y,z,c);
    }

    //! Access to pixel value with Neumann boundary conditions \const.
    T atNXYZC(const int pos, const int x, const int y, const int z, const int c) const {
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "atNXYZC(): Empty instance.",
                                    cimglist_instance);

      return _atNXYZC(pos,x,y,z,c);
    }

    T& _atNXYZC(const int pos, const int x, const int y, const int z, const int c) {
      return _data[pos<0?0:(pos>=(int)_width?(int)_width-1:pos)].atXYZC(x,y,z,c);
    }

    T _atNXYZC(const int pos, const int x, const int y, const int z, const int c) const {
      return _data[pos<0?0:(pos>=(int)_width?(int)_width-1:pos)].atXYZC(x,y,z,c);
    }

    //! Access to pixel value with Dirichlet boundary conditions for the three first coordinates (\c pos, \c x,\c y,\c z).
    /**
       \param pos Indice of the image element to access.
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \param out_value Default value returned if \c offset is outside image bounds.
       \note <tt>list.atNXYZ(p,x,y,z,c);</tt> is equivalent to <tt>list[p].atXYZ(x,y,z,c);</tt>.
    **/
    T& atNXYZ(const int pos, const int x, const int y, const int z, const int c, const T out_value) {
      return (pos<0 || pos>=(int)_width)?(cimg::temporary(out_value)=out_value):_data[pos].atXYZ(x,y,z,c,out_value);
    }

    //! Access to pixel value with Dirichlet boundary conditions for the three first coordinates (\c pos, \c x,\c y,\c z) \const.
    T atNXYZ(const int pos, const int x, const int y, const int z, const int c, const T out_value) const {
      return (pos<0 || pos>=(int)_width)?out_value:_data[pos].atXYZ(x,y,z,c,out_value);
    }

    //! Access to pixel value with Neumann boundary conditions for the four first coordinates (\c pos, \c x,\c y,\c z).
    /**
       \param pos Indice of the image element to access.
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \note <tt>list.atNXYZ(p,x,y,z,c);</tt> is equivalent to <tt>list[p].atXYZ(x,y,z,c);</tt>.
    **/
   T& atNXYZ(const int pos, const int x, const int y, const int z, const int c=0) {
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "atNXYZ(): Empty instance.",
                                    cimglist_instance);

      return _atNXYZ(pos,x,y,z,c);
    }

    //! Access to pixel value with Neumann boundary conditions for the four first coordinates (\c pos, \c x,\c y,\c z) \const.
    T atNXYZ(const int pos, const int x, const int y, const int z, const int c=0) const {
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "atNXYZ(): Empty instance.",
                                    cimglist_instance);

      return _atNXYZ(pos,x,y,z,c);
    }

    T& _atNXYZ(const int pos, const int x, const int y, const int z, const int c=0) {
      return _data[pos<0?0:(pos>=(int)_width?(int)_width-1:pos)].atXYZ(x,y,z,c);
    }

    T _atNXYZ(const int pos, const int x, const int y, const int z, const int c=0) const {
      return _data[pos<0?0:(pos>=(int)_width?(int)_width-1:pos)].atXYZ(x,y,z,c);
    }

    //! Access to pixel value with Dirichlet boundary conditions for the three first coordinates (\c pos, \c x,\c y).
    /**
       \param pos Indice of the image element to access.
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \param out_value Default value returned if \c offset is outside image bounds.
       \note <tt>list.atNXYZ(p,x,y,z,c);</tt> is equivalent to <tt>list[p].atXYZ(x,y,z,c);</tt>.
    **/
    T& atNXY(const int pos, const int x, const int y, const int z, const int c, const T out_value) {
      return (pos<0 || pos>=(int)_width)?(cimg::temporary(out_value)=out_value):_data[pos].atXY(x,y,z,c,out_value);
    }

    //! Access to pixel value with Dirichlet boundary conditions for the three first coordinates (\c pos, \c x,\c y) \const.
    T atNXY(const int pos, const int x, const int y, const int z, const int c, const T out_value) const {
      return (pos<0 || pos>=(int)_width)?out_value:_data[pos].atXY(x,y,z,c,out_value);
    }

    //! Access to pixel value with Neumann boundary conditions for the three first coordinates (\c pos, \c x,\c y).
    /**
       \param pos Indice of the image element to access.
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \note <tt>list.atNXYZ(p,x,y,z,c);</tt> is equivalent to <tt>list[p].atXYZ(x,y,z,c);</tt>.
    **/
    T& atNXY(const int pos, const int x, const int y, const int z=0, const int c=0) {
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "atNXY(): Empty instance.",
                                    cimglist_instance);

      return _atNXY(pos,x,y,z,c);
    }

    //! Access to pixel value with Neumann boundary conditions for the three first coordinates (\c pos, \c x,\c y) \const.
    T atNXY(const int pos, const int x, const int y, const int z=0, const int c=0) const {
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "atNXY(): Empty instance.",
                                    cimglist_instance);

      return _atNXY(pos,x,y,z,c);
    }

    T& _atNXY(const int pos, const int x, const int y, const int z=0, const int c=0) {
      return _data[pos<0?0:(pos>=(int)_width?(int)_width-1:pos)].atXY(x,y,z,c);
    }

    T _atNXY(const int pos, const int x, const int y, const int z=0, const int c=0) const {
      return _data[pos<0?0:(pos>=(int)_width?(int)_width-1:pos)].atXY(x,y,z,c);
    }

    //! Access to pixel value with Dirichlet boundary conditions for the two first coordinates (\c pos,\c x).
    /**
       \param pos Indice of the image element to access.
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \param out_value Default value returned if \c offset is outside image bounds.
       \note <tt>list.atNXYZ(p,x,y,z,c);</tt> is equivalent to <tt>list[p].atXYZ(x,y,z,c);</tt>.
    **/
    T& atNX(const int pos, const int x, const int y, const int z, const int c, const T out_value) {
      return (pos<0 || pos>=(int)_width)?(cimg::temporary(out_value)=out_value):_data[pos].atX(x,y,z,c,out_value);
    }

    //! Access to pixel value with Dirichlet boundary conditions for the two first coordinates (\c pos,\c x) \const.
    T atNX(const int pos, const int x, const int y, const int z, const int c, const T out_value) const {
      return (pos<0 || pos>=(int)_width)?out_value:_data[pos].atX(x,y,z,c,out_value);
    }

    //! Access to pixel value with Neumann boundary conditions for the two first coordinates (\c pos, \c x).
    /**
       \param pos Indice of the image element to access.
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \note <tt>list.atNXYZ(p,x,y,z,c);</tt> is equivalent to <tt>list[p].atXYZ(x,y,z,c);</tt>.
    **/
    T& atNX(const int pos, const int x, const int y=0, const int z=0, const int c=0) {
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "atNX(): Empty instance.",
                                    cimglist_instance);

      return _atNX(pos,x,y,z,c);
    }

    //! Access to pixel value with Neumann boundary conditions for the two first coordinates (\c pos, \c x) \const.
    T atNX(const int pos, const int x, const int y=0, const int z=0, const int c=0) const {
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "atNX(): Empty instance.",
                                    cimglist_instance);

      return _atNX(pos,x,y,z,c);
    }

    T& _atNX(const int pos, const int x, const int y=0, const int z=0, const int c=0) {
      return _data[pos<0?0:(pos>=(int)_width?(int)_width-1:pos)].atX(x,y,z,c);
    }

    T _atNX(const int pos, const int x, const int y=0, const int z=0, const int c=0) const {
      return _data[pos<0?0:(pos>=(int)_width?(int)_width-1:pos)].atX(x,y,z,c);
    }

    //! Access to pixel value with Dirichlet boundary conditions for the first coordinates (\c pos).
    /**
       \param pos Indice of the image element to access.
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \param out_value Default value returned if \c offset is outside image bounds.
       \note <tt>list.atNXYZ(p,x,y,z,c);</tt> is equivalent to <tt>list[p].atXYZ(x,y,z,c);</tt>.
    **/
    T& atN(const int pos, const int x, const int y, const int z, const int c, const T out_value) {
      return (pos<0 || pos>=(int)_width)?(cimg::temporary(out_value)=out_value):(*this)(pos,x,y,z,c);
    }

    //! Access to pixel value with Dirichlet boundary conditions for the first coordinates (\c pos) \const.
    T atN(const int pos, const int x, const int y, const int z, const int c, const T out_value) const {
      return (pos<0 || pos>=(int)_width)?out_value:(*this)(pos,x,y,z,c);
    }

    //! Return pixel value with Neumann boundary conditions for the first coordinates (\c pos).
    /**
       \param pos Indice of the image element to access.
       \param x X-coordinate of the pixel value.
       \param y Y-coordinate of the pixel value.
       \param z Z-coordinate of the pixel value.
       \param c C-coordinate of the pixel value.
       \note <tt>list.atNXYZ(p,x,y,z,c);</tt> is equivalent to <tt>list[p].atXYZ(x,y,z,c);</tt>.
    **/
    T& atN(const int pos, const int x=0, const int y=0, const int z=0, const int c=0) {
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "atN(): Empty instance.",
                                    cimglist_instance);
      return _atN(pos,x,y,z,c);
    }

    //! Return pixel value with Neumann boundary conditions for the first coordinates (\c pos) \const.
    T atN(const int pos, const int x=0, const int y=0, const int z=0, const int c=0) const {
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "atN(): Empty instance.",
                                    cimglist_instance);
      return _atN(pos,x,y,z,c);
    }

    T& _atN(const int pos, const int x=0, const int y=0, const int z=0, const int c=0) {
      return _data[pos<0?0:(pos>=(int)_width?(int)_width-1:pos)](x,y,z,c);
    }

    T _atN(const int pos, const int x=0, const int y=0, const int z=0, const int c=0) const {
      return _data[pos<0?0:(pos>=(int)_width?(int)_width-1:pos)](x,y,z,c);
    }

    //! Return a C-string containing the values of all images in the instance list.
    /**
       \param separator Character separator set between consecutive pixel values.
       \param max_size Maximum size of the returned string.
       \note The result is returne as a <tt>CImg<char></tt> image whose pixel buffer contains the desired C-string.
    **/
    CImg<charT> value_string(const char separator=',', const unsigned int max_size=0) const {
      if (is_empty()) return CImg<ucharT>(1,1,1,1,0);
      CImgList<charT> items;
      for (unsigned int l = 0; l<_width-1; ++l) {
        CImg<charT> item = _data[l].value_string(separator,0);
        item.back() = separator;
        item.move_to(items);
      }
      _data[_width-1].value_string(separator,0).move_to(items);
      CImg<charT> res; (items>'x').move_to(res);
      if (max_size) { res.crop(0,max_size); res(max_size) = 0; }
      return res;
    }

    //@}
    //-------------------------------------
    //
    //! \name Instance Checking
    //@{
    //-------------------------------------

    //! Return \c true if list is empty.
    /**
    **/
    bool is_empty() const {
      return (!_data || !_width);
    }

    //! Test if number of image elements is equal to specified value.
    /**
        \param size_n Number of image elements to test.
    **/
    bool is_sameN(const unsigned int size_n) const {
      return _width==size_n;
    }

    //! Test if number of image elements is equal between two images lists.
    /**
        \param list Input list to compare with.
    **/
    template<typename t>
    bool is_sameN(const CImgList<t>& list) const {
      return is_sameN(list._width);
    }

    // Define useful functions to check list dimensions.
    // (cannot be documented because macro-generated).
#define _cimglist_def_is_same1(axis) \
    bool is_same##axis(const unsigned int val) const { \
      bool res = true; for (unsigned int l = 0; l<_width && res; ++l) res = _data[l].is_same##axis(val); return res; \
    } \
    bool is_sameN##axis(const unsigned int n, const unsigned int val) const { \
      return is_sameN(n) && is_same##axis(val); \
    } \

#define _cimglist_def_is_same2(axis1,axis2) \
    bool is_same##axis1##axis2(const unsigned int val1, const unsigned int val2) const { \
      bool res = true; for (unsigned int l = 0; l<_width && res; ++l) res = _data[l].is_same##axis1##axis2(val1,val2); return res; \
    } \
    bool is_sameN##axis1##axis2(const unsigned int n, const unsigned int val1, const unsigned int val2) const { \
      return is_sameN(n) && is_same##axis1##axis2(val1,val2); \
    } \

#define _cimglist_def_is_same3(axis1,axis2,axis3) \
    bool is_same##axis1##axis2##axis3(const unsigned int val1, const unsigned int val2, const unsigned int val3) const { \
      bool res = true; for (unsigned int l = 0; l<_width && res; ++l) res = _data[l].is_same##axis1##axis2##axis3(val1,val2,val3); return res; \
    } \
    bool is_sameN##axis1##axis2##axis3(const unsigned int n, const unsigned int val1, const unsigned int val2, const unsigned int val3) const { \
      return is_sameN(n) && is_same##axis1##axis2##axis3(val1,val2,val3); \
    } \

#define _cimglist_def_is_same(axis) \
    template<typename t> bool is_same##axis(const CImg<t>& img) const { \
      bool res = true; for (unsigned int l = 0; l<_width && res; ++l) res = _data[l].is_same##axis(img); return res; \
    } \
    template<typename t> bool is_same##axis(const CImgList<t>& list) const { \
      const unsigned int lmin = cimg::min(_width,list._width); \
      bool res = true; for (unsigned int l = 0; l<lmin && res; ++l) res = _data[l].is_same##axis(list[l]); return res; \
    } \
    template<typename t> bool is_sameN##axis(const unsigned int n, const CImg<t>& img) const { \
      return (is_sameN(n) && is_same##axis(img)); \
    } \
    template<typename t> bool is_sameN##axis(const CImgList<t>& list) const { \
      return (is_sameN(list) && is_same##axis(list)); \
    }

    _cimglist_def_is_same(XY)
    _cimglist_def_is_same(XZ)
    _cimglist_def_is_same(XC)
    _cimglist_def_is_same(YZ)
    _cimglist_def_is_same(YC)
    _cimglist_def_is_same(XYZ)
    _cimglist_def_is_same(XYC)
    _cimglist_def_is_same(YZC)
    _cimglist_def_is_same(XYZC)
    _cimglist_def_is_same1(X)
    _cimglist_def_is_same1(Y)
    _cimglist_def_is_same1(Z)
    _cimglist_def_is_same1(C)
    _cimglist_def_is_same2(X,Y)
    _cimglist_def_is_same2(X,Z)
    _cimglist_def_is_same2(X,C)
    _cimglist_def_is_same2(Y,Z)
    _cimglist_def_is_same2(Y,C)
    _cimglist_def_is_same2(Z,C)
    _cimglist_def_is_same3(X,Y,Z)
    _cimglist_def_is_same3(X,Y,C)
    _cimglist_def_is_same3(X,Z,C)
    _cimglist_def_is_same3(Y,Z,C)

    //! Test if dimensions of each image of the list match specified arguments.
    /**
      \param dx Checked image width.
      \param dy Checked image height.
      \param dz Checked image depth.
      \param dc Checked image spectrum.
    **/
    bool is_sameXYZC(const unsigned int dx, const unsigned int dy, const unsigned int dz, const unsigned int dc) const {
      bool res = true;
      for (unsigned int l = 0; l<_width && res; ++l) res = _data[l].is_sameXYZC(dx,dy,dz,dc);
      return res;
    }

    //! Test if list dimensions match specified arguments.
    /**
       \param n Number of images in the list.
       \param dx Checked image width.
       \param dy Checked image height.
       \param dz Checked image depth.
       \param dc Checked image spectrum.
    **/
    bool is_sameNXYZC(const unsigned int n, const unsigned int dx, const unsigned int dy, const unsigned int dz, const unsigned int dc) const {
      return is_sameN(n) && is_sameXYZC(dx,dy,dz,dc);
    }

    //! Test if list contains one particular pixel location.
    /**
       \param n Index of the image whom checked pixel value belong to.
       \param x X-coordinate of the checked pixel value.
       \param y Y-coordinate of the checked pixel value.
       \param z Z-coordinate of the checked pixel value.
       \param c C-coordinate of the checked pixel value.
    **/
    bool containsNXYZC(const int n, const int x=0, const int y=0, const int z=0, const int c=0) const {
      if (is_empty()) return false;
      return n>=0 && n<(int)_width && x>=0 && x<_data[n].width() && y>=0 && y<_data[n].height() &&
        z>=0 && z<_data[n].depth() && c>=0 && c<_data[n].spectrum();
    }

    //! Test if list contains image with specified indice.
    /**
       \param n Index of the checked image.
    **/
    bool containsN(const int n) const {
      if (is_empty()) return false;
      return n>=0 && n<(int)_width;
    }

    //! Test if one image of the list contains the specified referenced value.
    /**
       \param pixel Reference to pixel value to test.
       \param[out] n Index of image containing the pixel value, if test succeeds.
       \param[out] x X-coordinate of the pixel value, if test succeeds.
       \param[out] y Y-coordinate of the pixel value, if test succeeds.
       \param[out] z Z-coordinate of the pixel value, if test succeeds.
       \param[out] c C-coordinate of the pixel value, if test succeeds.
       \note If true, set coordinates (n,x,y,z,c).
    **/
    template<typename t>
    bool contains(const T& pixel, t& n, t& x, t&y, t& z, t& c) const {
      if (is_empty()) return false;
      cimglist_for(*this,l) if (_data[l].contains(pixel,x,y,z,c)) { n = (t)l; return true; }
      return false;
    }

    //! Test if one of the image list contains the specified referenced value.
    /**
       \param pixel Reference to pixel value to test.
       \param[out] n Index of image containing the pixel value, if test succeeds.
       \param[out] x X-coordinate of the pixel value, if test succeeds.
       \param[out] y Y-coordinate of the pixel value, if test succeeds.
       \param[out] z Z-coordinate of the pixel value, if test succeeds.
       \note If true, set coordinates (n,x,y,z).
    **/
    template<typename t>
    bool contains(const T& pixel, t& n, t& x, t&y, t& z) const {
      t c;
      return contains(pixel,n,x,y,z,c);
    }

    //! Test if one of the image list contains the specified referenced value.
    /**
       \param pixel Reference to pixel value to test.
       \param[out] n Index of image containing the pixel value, if test succeeds.
       \param[out] x X-coordinate of the pixel value, if test succeeds.
       \param[out] y Y-coordinate of the pixel value, if test succeeds.
       \note If true, set coordinates (n,x,y).
    **/
    template<typename t>
    bool contains(const T& pixel, t& n, t& x, t&y) const {
      t z, c;
      return contains(pixel,n,x,y,z,c);
    }

    //! Test if one of the image list contains the specified referenced value.
    /**
       \param pixel Reference to pixel value to test.
       \param[out] n Index of image containing the pixel value, if test succeeds.
       \param[out] x X-coordinate of the pixel value, if test succeeds.
       \note If true, set coordinates (n,x).
    **/
    template<typename t>
    bool contains(const T& pixel, t& n, t& x) const {
      t y, z, c;
      return contains(pixel,n,x,y,z,c);
    }

    //! Test if one of the image list contains the specified referenced value.
    /**
       \param pixel Reference to pixel value to test.
       \param[out] n Index of image containing the pixel value, if test succeeds.
       \note If true, set coordinates (n).
    **/
    template<typename t>
    bool contains(const T& pixel, t& n) const {
      t x, y, z, c;
      return contains(pixel,n,x,y,z,c);
    }

    //! Test if one of the image list contains the specified referenced value.
    /**
       \param pixel Reference to pixel value to test.
    **/
    bool contains(const T& pixel) const {
      unsigned int n, x, y, z, c;
      return contains(pixel,n,x,y,z,c);
    }

    //! Test if the list contains the image 'img'.
    /**
       \param img Reference to image to test.
       \param[out] n Index of image in the list, if test succeeds.
       \note If true, returns the position (n) of the image in the list.
    **/
    template<typename t>
    bool contains(const CImg<T>& img, t& n) const {
      if (is_empty()) return false;
      const CImg<T> *const ptr = &img;
      cimglist_for(*this,i) if (_data+i==ptr) { n = (t)i; return true; }
      return false;
    }

    //! Test if the list contains the image img.
    /**
       \param img Reference to image to test.
    **/
    bool contains(const CImg<T>& img) const {
      unsigned int n;
      return contains(img,n);
    }

    //@}
    //-------------------------------------
    //
    //! \name Mathematical Functions
    //@{
    //-------------------------------------

    //! Return a reference to the minimum pixel value of the instance list.
    /**
    **/
    T& min() {
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "min(): Empty instance.",
                                    cimglist_instance);
      T *ptr_min = _data->_data;
      T min_value = *ptr_min;
      cimglist_for(*this,l) {
        const CImg<T>& img = _data[l];
        cimg_for(img,ptrs,T) if (*ptrs<min_value) min_value = *(ptr_min=ptrs);
      }
      return *ptr_min;
    }

    //! Return a reference to the minimum pixel value of the instance list \const.
    const T& min() const {
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "min(): Empty instance.",
                                    cimglist_instance);
      const T *ptr_min = _data->_data;
      T min_value = *ptr_min;
      cimglist_for(*this,l) {
        const CImg<T>& img = _data[l];
        cimg_for(img,ptrs,T) if (*ptrs<min_value) min_value = *(ptr_min=ptrs);
      }
      return *ptr_min;
    }

    //! Return a reference to the maximum pixel value of the instance list.
    /**
    **/
    T& max() {
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "max(): Empty instance.",
                                    cimglist_instance);
      T *ptr_max = _data->_data;
      T max_value = *ptr_max;
      cimglist_for(*this,l) {
        const CImg<T>& img = _data[l];
        cimg_for(img,ptrs,T) if (*ptrs>max_value) max_value = *(ptr_max=ptrs);
      }
      return *ptr_max;
    }

    //! Return a reference to the maximum pixel value of the instance list \const.
    const T& max() const {
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "max(): Empty instance.",
                                    cimglist_instance);
      const T *ptr_max = _data->_data;
      T max_value = *ptr_max;
      cimglist_for(*this,l) {
        const CImg<T>& img = _data[l];
        cimg_for(img,ptrs,T) if (*ptrs>max_value) max_value = *(ptr_max=ptrs);
      }
      return *ptr_max;
    }

    //! Return a reference to the minimum pixel value of the instance list and return the maximum vvalue as well.
    /**
       \param[out] max_val Value of the maximum value found.
    **/
    template<typename t>
    T& min_max(t& max_val) {
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "min_max(): Empty instance.",
                                    cimglist_instance);
      T *ptr_min = _data->_data;
      T min_value = *ptr_min, max_value = min_value;
      cimglist_for(*this,l) {
        const CImg<T>& img = _data[l];
        cimg_for(img,ptrs,T) {
          const T val = *ptrs;
          if (val<min_value) { min_value = val; ptr_min = ptrs; }
          if (val>max_value) max_value = val;
        }
      }
      max_val = (t)max_value;
      return *ptr_min;
    }

    //! Return a reference to the minimum pixel value of the instance list and return the maximum vvalue as well \const.
    /**
       \param[out] max_val Value of the maximum value found.
    **/
    template<typename t>
    const T& min_max(t& max_val) const {
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "min_max(): Empty instance.",
                                    cimglist_instance);
      const T *ptr_min = _data->_data;
      T min_value = *ptr_min, max_value = min_value;
      cimglist_for(*this,l) {
        const CImg<T>& img = _data[l];
        cimg_for(img,ptrs,T) {
          const T val = *ptrs;
          if (val<min_value) { min_value = val; ptr_min = ptrs; }
          if (val>max_value) max_value = val;
        }
      }
      max_val = (t)max_value;
      return *ptr_min;
    }

    //! Return a reference to the minimum pixel value of the instance list and return the minimum value as well.
    /**
       \param[out] min_val Value of the minimum value found.
    **/
    template<typename t>
    T& max_min(t& min_val) {
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "max_min(): Empty instance.",
                                    cimglist_instance);
      T *ptr_max = _data->_data;
      T min_value = *ptr_max, max_value = min_value;
      cimglist_for(*this,l) {
        const CImg<T>& img = _data[l];
        cimg_for(img,ptrs,T) {
          const T val = *ptrs;
          if (val>max_value) { max_value = val; ptr_max = ptrs; }
          if (val<min_value) min_value = val;
        }
      }
      min_val = (t)min_value;
      return *ptr_max;
    }

    //! Return a reference to the minimum pixel value of the instance list and return the minimum value as well \const.
    template<typename t>
    const T& max_min(t& min_val) const {
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "max_min(): Empty instance.",
                                    cimglist_instance);
      const T *ptr_max = _data->_data;
      T min_value = *ptr_max, max_value = min_value;
      cimglist_for(*this,l) {
        const CImg<T>& img = _data[l];
        cimg_for(img,ptrs,T) {
          const T val = *ptrs;
          if (val>max_value) { max_value = val; ptr_max = ptrs; }
          if (val<min_value) min_value = val;
        }
      }
      min_val = (t)min_value;
      return *ptr_max;
    }

    //@}
    //---------------------------
    //
    //! \name List Manipulation
    //@{
    //---------------------------

    //! Insert a copy of the image \c img into the current image list, at position \c pos.
    /**
        \param img Image to insert a copy to the list.
        \param pos Index of the insertion.
        \param is_shared Tells if the inserted image is a shared copy of \c img or not.
    **/
    template<typename t>
    CImgList<T>& insert(const CImg<t>& img, const unsigned int pos=~0U, const bool is_shared=false) {
      const unsigned int npos = pos==~0U?_width:pos;
      if (npos>_width)
        throw CImgArgumentException(_cimglist_instance
                                    "insert(): Invalid insertion request of specified image (%u,%u,%u,%u,%p) at position %u.",
                                    cimglist_instance,
                                    img._width,img._height,img._depth,img._spectrum,img._data,npos);
      if (is_shared)
        throw CImgArgumentException(_cimglist_instance
                                    "insert(): Invalid insertion request of specified shared image CImg<%s>(%u,%u,%u,%u,%p) at position %u "
                                    "(pixel types are different).",
                                    cimglist_instance,
                                    img.pixel_type(),img._width,img._height,img._depth,img._spectrum,img._data,npos);

      CImg<T> *const new_data = (++_width>_allocated_width)?new CImg<T>[_allocated_width?(_allocated_width<<=1):(_allocated_width=16)]:0;
      if (!_data) { // Insert new element into empty list.
        _data = new_data;
        *_data = img;
      } else {
        if (new_data) { // Insert with re-allocation.
          if (npos) std::memcpy(new_data,_data,sizeof(CImg<T>)*npos);
          if (npos!=_width-1) std::memcpy(new_data+npos+1,_data+npos,sizeof(CImg<T>)*(_width-1-npos));
          std::memset(_data,0,sizeof(CImg<T>)*(_width-1));
          delete[] _data;
          _data = new_data;
        } else if (npos!=_width-1) std::memmove(_data+npos+1,_data+npos,sizeof(CImg<T>)*(_width-1-npos)); // Insert without re-allocation.
        _data[npos]._width = _data[npos]._height = _data[npos]._depth = _data[npos]._spectrum = 0; _data[npos]._data = 0;
        _data[npos] = img;
      }
      return *this;
    }

    //! Insert a copy of the image \c img into the current image list, at position \c pos \specialization.
    CImgList<T>& insert(const CImg<T>& img, const unsigned int pos=~0U, const bool is_shared=false) {
      const unsigned int npos = pos==~0U?_width:pos;
      if (npos>_width)
        throw CImgArgumentException(_cimglist_instance
                                    "insert(): Invalid insertion request of specified image (%u,%u,%u,%u,%p) at position %u.",
                                    cimglist_instance,
                                    img._width,img._height,img._depth,img._spectrum,img._data,npos);
      CImg<T> *const new_data = (++_width>_allocated_width)?new CImg<T>[_allocated_width?(_allocated_width<<=1):(_allocated_width=16)]:0;
      if (!_data) { // Insert new element into empty list.
        _data = new_data;
        if (is_shared && img) {
          _data->_width = img._width; _data->_height = img._height; _data->_depth = img._depth; _data->_spectrum = img._spectrum;
          _data->_is_shared = true; _data->_data = img._data;
        } else *_data = img;
      }
      else {
        if (new_data) { // Insert with re-allocation.
          if (npos) std::memcpy(new_data,_data,sizeof(CImg<T>)*npos);
          if (npos!=_width-1) std::memcpy(new_data+npos+1,_data+npos,sizeof(CImg<T>)*(_width-1-npos));
          if (is_shared && img) {
            new_data[npos]._width = img._width; new_data[npos]._height = img._height; new_data[npos]._depth = img._depth;
            new_data[npos]._spectrum = img._spectrum; new_data[npos]._is_shared = true; new_data[npos]._data = img._data;
          } else {
            new_data[npos]._width = new_data[npos]._height = new_data[npos]._depth = new_data[npos]._spectrum = 0; new_data[npos]._data = 0;
            new_data[npos] = img;
          }
          std::memset(_data,0,sizeof(CImg<T>)*(_width-1));
          delete[] _data;
          _data = new_data;
        } else { // Insert without re-allocation.
          if (npos!=_width-1) std::memmove(_data+npos+1,_data+npos,sizeof(CImg<T>)*(_width-1-npos));
          if (is_shared && img) {
            _data[npos]._width = img._width; _data[npos]._height = img._height; _data[npos]._depth = img._depth; _data[npos]._spectrum = img._spectrum;
            _data[npos]._is_shared = true; _data[npos]._data = img._data;
          } else {
            _data[npos]._width = _data[npos]._height = _data[npos]._depth = _data[npos]._spectrum = 0; _data[npos]._data = 0;
            _data[npos] = img;
          }
        }
      }
      return *this;
    }

    //! Insert a copy of the image \c img into the current image list, at position \c pos \newinstance.
    template<typename t>
    CImgList<T> get_insert(const CImg<t>& img, const unsigned int pos=~0U, const bool is_shared=false) const {
      return (+*this).insert(img,pos,is_shared);
    }

    //! Insert n empty images img into the current image list, at position \p pos.
    /**
       \param n Number of empty images to insert.
       \param pos Index of the insertion.
    **/
    CImgList<T>& insert(const unsigned int n, const unsigned int pos=~0U) {
      CImg<T> empty;
      if (!n) return *this;
      const unsigned int npos = pos==~0U?_width:pos;
      for (unsigned int i = 0; i<n; ++i) insert(empty,npos+i);
      return *this;
    }

    //! Insert n empty images img into the current image list, at position \p pos \newinstance.
    CImgList<T> get_insert(const unsigned int n, const unsigned int pos=~0U) const {
      return (+*this).insert(n,pos);
    }

    //! Insert \c n copies of the image \c img into the current image list, at position \c pos.
    /**
       \param n Number of image copies to insert.
       \param img Image to insert by copy.
       \param pos Index of the insertion.
       \param is_shared Tells if inserted images are shared copies of \c img or not.
    **/
    template<typename t>
    CImgList<T>& insert(const unsigned int n, const CImg<t>& img, const unsigned int pos=~0U, const bool is_shared=false) {
      if (!n) return *this;
      const unsigned int npos = pos==~0U?_width:pos;
      insert(img,npos,is_shared);
      for (unsigned int i = 1; i<n; ++i) insert(_data[npos],npos+i,is_shared);
      return *this;
    }

    //! Insert \c n copies of the image \c img into the current image list, at position \c pos \newinstance.
    template<typename t>
    CImgList<T> get_insert(const unsigned int n, const CImg<t>& img, const unsigned int pos=~0U, const bool is_shared=false) const {
      return (+*this).insert(n,img,pos,is_shared);
    }

    //! Insert a copy of the image list \c list into the current image list, starting from position \c pos.
    /**
      \param list Image list to insert.
      \param pos Index of the insertion.
      \param is_shared Tells if inserted images are shared copies of images of \c list or not.
    **/
    template<typename t>
    CImgList<T>& insert(const CImgList<t>& list, const unsigned int pos=~0U, const bool is_shared=false) {
      const unsigned int npos = pos==~0U?_width:pos;
      if ((void*)this!=(void*)&list) cimglist_for(list,l) insert(list[l],npos+l,is_shared);
      else insert(CImgList<T>(list),npos,is_shared);
      return *this;
    }

    //! Insert a copy of the image list \c list into the current image list, starting from position \c pos \newinstance.
    template<typename t>
    CImgList<T> get_insert(const CImgList<t>& list, const unsigned int pos=~0U, const bool is_shared=false) const {
      return (+*this).insert(list,pos,is_shared);
    }

    //! Insert n copies of the list \c list at position \c pos of the current list.
    /**
      \param n Number of list copies to insert.
      \param list Image list to insert.
      \param pos Index of the insertion.
      \param is_shared Tells if inserted images are shared copies of images of \c list or not.
    **/
    template<typename t>
    CImgList<T>& insert(const unsigned int n, const CImgList<t>& list, const unsigned int pos=~0U, const bool is_shared=false) {
      if (!n) return *this;
      const unsigned int npos = pos==~0U?_width:pos;
      for (unsigned int i = 0; i<n; ++i) insert(list,npos,is_shared);
      return *this;
    }

    //! Insert n copies of the list \c list at position \c pos of the current list \newinstance.
    template<typename t>
    CImgList<T> get_insert(const unsigned int n, const CImgList<t>& list, const unsigned int pos=~0U, const bool is_shared=false) const {
      return (+*this).insert(n,list,pos,is_shared);
    }

    //! Remove all images between from indexes.
    /**
      \param pos1 Starting index of the removal.
      \param pos2 Ending index of the removal.
    **/
    CImgList<T>& remove(const unsigned int pos1, const unsigned int pos2) {
      const unsigned int
        npos1 = pos1<pos2?pos1:pos2,
        tpos2 = pos1<pos2?pos2:pos1,
        npos2 = tpos2<_width?tpos2:_width-1;
      if (npos1>=_width)
        throw CImgArgumentException(_cimglist_instance
                                    "remove(): Invalid remove request at positions %u->%u.",
                                    cimglist_instance,
                                    npos1,tpos2);
      else {
        if (tpos2>=_width)
          throw CImgArgumentException(_cimglist_instance
                                      "remove(): Invalid remove request at positions %u->%u.",
                                      cimglist_instance,
                                      npos1,tpos2);

        for (unsigned int k = npos1; k<=npos2; ++k) _data[k].assign();
        const unsigned int nb = 1 + npos2 - npos1;
        if (!(_width-=nb)) return assign();
        if (_width>(_allocated_width>>2) || _allocated_width<=16) { // Removing items without reallocation.
          if (npos1!=_width) std::memmove(_data+npos1,_data+npos2+1,sizeof(CImg<T>)*(_width - npos1));
          std::memset(_data + _width,0,sizeof(CImg<T>)*nb);
        } else { // Removing items with reallocation.
          _allocated_width>>=2;
          while (_allocated_width>16 && _width<(_allocated_width>>1)) _allocated_width>>=1;
          CImg<T> *const new_data = new CImg<T>[_allocated_width];
          if (npos1) std::memcpy(new_data,_data,sizeof(CImg<T>)*npos1);
          if (npos1!=_width) std::memcpy(new_data+npos1,_data+npos2+1,sizeof(CImg<T>)*(_width-npos1));
          if (_width!=_allocated_width) std::memset(new_data+_width,0,sizeof(_allocated_width - _width));
          std::memset(_data,0,sizeof(CImg<T>)*(_width+nb));
          delete[] _data;
          _data = new_data;
        }
      }
      return *this;
    }

    //! Remove all images between from indexes \newinstance.
    CImgList<T> get_remove(const unsigned int pos1, const unsigned int pos2) const {
      return (+*this).remove(pos1,pos2);
    }

    //! Remove image at index \c pos from the image list.
    /**
      \param pos Index of the image to remove.
    **/
    CImgList<T>& remove(const unsigned int pos) {
      return remove(pos,pos);
    }

    //! Remove image at index \c pos from the image list \newinstance.
    CImgList<T> get_remove(const unsigned int pos) const {
      return (+*this).remove(pos);
    }

    //! Remove last image.
    /**
    **/
    CImgList<T>& remove() {
      return remove(_width-1);
    }

    //! Remove last image \newinstance.
    CImgList<T> get_remove() const {
      return (+*this).remove();
    }

    //! Reverse list order.
    CImgList<T>& reverse() {
      for (unsigned int l = 0; l<_width/2; ++l) (*this)[l].swap((*this)[_width-1-l]);
      return *this;
    }

    //! Reverse list order \newinstance.
    CImgList<T> get_reverse() const {
      return (+*this).reverse();
    }

    //! Return a sublist.
    /**
      \param pos0 Starting index of the sublist.
      \param pos1 Ending index of the sublist.
    **/
    CImgList<T>& images(const unsigned int pos0, const unsigned int pos1) {
      return get_images(pos0,pos1).move_to(*this);
    }

    //! Return a sublist \newinstance.
    CImgList<T> get_images(const unsigned int pos0, const unsigned int pos1) const {
      if (pos0>pos1 || pos1>=_width)
        throw CImgArgumentException(_cimglist_instance
                                    "images(): Specified sub-list indices (%u->%u) are out of bounds.",
                                    cimglist_instance,
                                    pos0,pos1);
      CImgList<T> res(pos1-pos0+1);
      cimglist_for(res,l) res[l].assign(_data[pos0+l]);
      return res;
    }

    //! Return a shared sublist.
    /**
      \param pos0 Starting index of the sublist.
      \param pos1 Ending index of the sublist.
    **/
    CImgList<T> get_shared_images(const unsigned int pos0, const unsigned int pos1) {
      if (pos0>pos1 || pos1>=_width)
        throw CImgArgumentException(_cimglist_instance
                                    "get_shared_images(): Specified sub-list indices (%u->%u) are out of bounds.",
                                    cimglist_instance,
                                    pos0,pos1);
      CImgList<T> res(pos1-pos0+1);
      cimglist_for(res,l) res[l].assign(_data[pos0+l],_data[pos0+l]?true:false);
      return res;
    }

    //! Return a shared sublist \newinstance.
    const CImgList<T> get_shared_images(const unsigned int pos0, const unsigned int pos1) const {
      if (pos0>pos1 || pos1>=_width)
        throw CImgArgumentException(_cimglist_instance
                                    "get_shared_images(): Specified sub-list indices (%u->%u) are out of bounds.",
                                    cimglist_instance,
                                    pos0,pos1);
      CImgList<T> res(pos1-pos0+1);
      cimglist_for(res,l) res[l].assign(_data[pos0+l],_data[pos0+l]?true:false);
      return res;
    }

    //! Return a single image which is the appending of all images of the current CImgList instance.
    /**
       \param axis Appending axis. Can be <tt>{ 'x' | 'y' | 'z' | 'c' }</tt>.
       \param align Appending alignment.
    **/
    CImg<T> get_append(const char axis, const float align=0) const {
      if (is_empty()) return CImg<T>();
      if (_width==1) return +((*this)[0]);
      unsigned int dx = 0, dy = 0, dz = 0, dc = 0, pos = 0;
      CImg<T> res;
      switch (cimg::uncase(axis)) {
      case 'x' : { // Along the X-axis.
        cimglist_for(*this,l) {
          const CImg<T>& img = (*this)[l];
          if (img) { dx+=img._width; dy = cimg::max(dy,img._height); dz = cimg::max(dz,img._depth); dc = cimg::max(dc,img._spectrum); }
        }
        res.assign(dx,dy,dz,dc,0);
        if (res) cimglist_for(*this,l) {
            const CImg<T>& img = (*this)[l];
            if (img) res.draw_image(pos,
                                    (int)(align*(dy-img._height)),
                                    (int)(align*(dz-img._depth)),
                                    (int)(align*(dc-img._spectrum)),
                                    img);
            pos+=img._width;
          }
      } break;
      case 'y' : { // Along the Y-axis.
        cimglist_for(*this,l) {
          const CImg<T>& img = (*this)[l];
          if (img) { dx = cimg::max(dx,img._width); dy+=img._height; dz = cimg::max(dz,img._depth); dc = cimg::max(dc,img._spectrum); }
        }
        res.assign(dx,dy,dz,dc,0);
        if (res) cimglist_for(*this,l) {
            const CImg<T>& img = (*this)[l];
            if (img) res.draw_image((int)(align*(dx-img._width)),
                                    pos,
                                    (int)(align*(dz-img._depth)),
                                    (int)(align*(dc-img._spectrum)),
                                    img);
            pos+=img._height;
          }
      } break;
      case 'z' : { // Along the Z-axis.
        cimglist_for(*this,l) {
          const CImg<T>& img = (*this)[l];
          if (img) { dx = cimg::max(dx,img._width); dy = cimg::max(dy,img._height); dz+=img._depth; dc = cimg::max(dc,img._spectrum); }
        }
        res.assign(dx,dy,dz,dc,0);
        if (res) cimglist_for(*this,l) {
            const CImg<T>& img = (*this)[l];
            if (img) res.draw_image((int)(align*(dx-img._width)),
                                    (int)(align*(dy-img._height)),
                                    pos,
                                    (int)(align*(dc-img._spectrum)),
                                    img);
            pos+=img._depth;
          }
      } break;
      default : { // Along the C-axis.
        cimglist_for(*this,l) {
          const CImg<T>& img = (*this)[l];
          if (img) { dx = cimg::max(dx,img._width); dy = cimg::max(dy,img._height); dz = cimg::max(dz,img._depth); dc+=img._spectrum; }
        }
        res.assign(dx,dy,dz,dc,0);
        if (res) cimglist_for(*this,l) {
            const CImg<T>& img = (*this)[l];
            if (img) res.draw_image((int)(align*(dx-img._width)),
                                    (int)(align*(dy-img._height)),
                                    (int)(align*(dz-img._depth)),
                                    pos,
                                    img);
            pos+=img._spectrum;
          }
      }
      }
      return res;
    }

    //! Return a list where each image has been split along the specified axis.
    /**
        \param axis Axis to split images along.
        \param nb Number of spliting parts for each image.
    **/
    CImgList<T>& split(const char axis, const int nb=0) {
      return get_split(axis,nb).move_to(*this);
    }

    //! Return a list where each image has been split along the specified axis \newinstance.
    CImgList<T> get_split(const char axis, const int nb=0) const {
      CImgList<T> res;
      cimglist_for(*this,l) _data[l].get_split(axis,nb).move_to(res,~0U);
      return res;
    }

    //! Insert image at the end of the list.
    /**
      \param img Image to insert.
    **/
    template<typename t>
    CImgList<T>& push_back(const CImg<t>& img) {
      return insert(img);
    }

    //! Insert image at the front of the list.
    /**
      \param img Image to insert.
    **/
    template<typename t>
    CImgList<T>& push_front(const CImg<t>& img) {
      return insert(img,0);
    }

    //! Insert list at the end of the current list.
    /**
      \param list List to insert.
    **/
    template<typename t>
    CImgList<T>& push_back(const CImgList<t>& list) {
      return insert(list);
    }

    //! Insert list at the front of the current list.
    /**
      \param list List to insert.
    **/
    template<typename t>
    CImgList<T>& push_front(const CImgList<t>& list) {
      return insert(list,0);
    }

    //! Remove last image.
    /**
    **/
    CImgList<T>& pop_back() {
      return remove(_width-1);
    }

    //! Remove first image.
    /**
    **/
    CImgList<T>& pop_front() {
      return remove(0);
    }

    //! Remove image pointed by iterator.
    /**
      \param iter Iterator pointing to the image to remove.
    **/
    CImgList<T>& erase(const iterator iter) {
      return remove(iter-_data);
    }

    //@}
    //----------------------------------
    //
    //! \name Data Input
    //@{
    //----------------------------------

    //! Display a simple interactive interface to select images or sublists.
    /**
       \param disp Window instance to display selection and user interface.
       \param feature_type Can be \c false to select a single image, or \c true to select a sublist.
       \param axis Axis along whom images are appended for visualization.
       \param align Alignment setting when images have not all the same size.
       \return A one-column vector containing the selected image indexes.
    **/
    CImg<intT> get_select(CImgDisplay &disp, const bool feature_type=true,
                          const char axis='x', const float align=0) const {
      return _get_select(disp,0,feature_type,axis,align,0,false,false,false);
    }

    //! Display a simple interactive interface to select images or sublists.
    /**
       \param title Title of a new window used to display selection and user interface.
       \param feature_type Can be \c false to select a single image, or \c true to select a sublist.
       \param axis Axis along whom images are appended for visualization.
       \param align Alignment setting when images have not all the same size.
       \return A one-column vector containing the selected image indexes.
    **/
    CImg<intT> get_select(const char *const title, const bool feature_type=true,
                          const char axis='x', const float align=0) const {
      CImgDisplay disp;
      return _get_select(disp,title,feature_type,axis,align,0,false,false,false);
    }

    CImg<intT> _get_select(CImgDisplay &disp, const char *const title, const bool feature_type,
                           const char axis, const float align,
                           const unsigned int orig, const bool resize_disp,
                           const bool exit_on_rightbutton, const bool exit_on_wheel) const {
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "select(): Empty instance.",
                                    cimglist_instance);

      // Create image correspondence table and get list dimensions for visualization.
      CImgList<uintT> _indices;
      unsigned int max_width = 0, max_height = 0, sum_width = 0, sum_height = 0;
      cimglist_for(*this,l) {
        const CImg<T>& img = _data[l];
        const unsigned int
          w = CImgDisplay::_fitscreen(img._width,img._height,img._depth,128,-85,false),
          h = CImgDisplay::_fitscreen(img._width,img._height,img._depth,128,-85,true);
        if (w>max_width) max_width = w;
        if (h>max_height) max_height = h;
        sum_width+=w; sum_height+=h;
        if (axis=='x') CImg<uintT>(w,1,1,1,(unsigned int)l).move_to(_indices);
        else CImg<uintT>(h,1,1,1,(unsigned int)l).move_to(_indices);
      }
      const CImg<uintT> indices0 = _indices>'x';

      // Create display window.
      if (!disp) {
        if (axis=='x') disp.assign(cimg_fitscreen(sum_width,max_height,1),title?title:0,1);
        else disp.assign(cimg_fitscreen(max_width,sum_height,1),title?title:0,1);
        if (!title) disp.set_title("CImgList<%s> (%u)",pixel_type(),_width);
      } else if (title) disp.set_title("%s",title);
      if (resize_disp) {
        if (axis=='x') disp.resize(cimg_fitscreen(sum_width,max_height,1),false);
        else disp.resize(cimg_fitscreen(max_width,sum_height,1),false);
      }

      const unsigned int old_normalization = disp.normalization();
      bool old_is_resized = disp.is_resized();
      disp._normalization = 0;
      disp.show().set_key(0);
      const unsigned char foreground_color[] = { 255,255,255 }, background_color[] = { 0,0,0 };

      // Enter event loop.
      CImg<ucharT> visu0, visu;
      CImg<uintT> indices;
      CImg<intT> positions(_width,4,1,1,-1);
      int oindice0 = -1, oindice1 = -1, indice0 = -1, indice1 = -1;
      bool is_clicked = false, is_selected = false, text_down = false, update_display = true;
      unsigned int key = 0;
      while (!is_selected && !disp.is_closed() && !key) {

        // Create background image.
        if (!visu0) {
          visu0.assign(disp._width,disp._height,1,3,0); visu.assign();
          (indices0.get_resize(axis=='x'?visu0._width:visu0._height,1)).move_to(indices);
          unsigned int ind = 0;
          if (axis=='x') for (unsigned int x = 0; x<visu0._width; ) {
              const unsigned int x0 = x;
              ind = indices[x];
              while (x<indices._width && indices[x++]==ind) {}
              const CImg<T>
                onexone(1,1,1,1,0),
                &src = _data[ind]?_data[ind]:onexone;
              CImg<ucharT> res;
              src.__get_select(disp,old_normalization,(src._width-1)/2,(src._height-1)/2,(src._depth-1)/2).move_to(res);
              const unsigned int h = CImgDisplay::_fitscreen(res._width,res._height,1,128,-85,true);
              res.resize(x - x0,cimg::max(32U,h*disp._height/max_height),1,res._spectrum==1?3:-100);
              positions(ind,0) = positions(ind,2) = (int)x0;
              positions(ind,1) = positions(ind,3) = (int)(align*(visu0.height()-res.height()));
              positions(ind,2)+=res._width;
              positions(ind,3)+=res._height - 1;
              visu0.draw_image(positions(ind,0),positions(ind,1),res);
            } else for (unsigned int y = 0; y<visu0._height; ) {
              const unsigned int y0 = y;
              ind = indices[y];
              while (y<visu0._height && indices[++y]==ind) {}
              const CImg<T>
                &src = _data[ind],
                _img2d = src._depth>1?src.get_projections2d((src._width-1)/2,(src._height-1)/2,(src._depth-1)/2):CImg<T>(),
                &img2d = _img2d?_img2d:src;
              CImg<ucharT> res = old_normalization==1 || (old_normalization==3 && cimg::type<T>::string()!=cimg::type<unsigned char>::string())?
                CImg<ucharT>(img2d.get_normalize(0,255)):
                CImg<ucharT>(img2d);
              if (res._spectrum>3) res.channels(0,2);
              const unsigned int w = CImgDisplay::_fitscreen(res._width,res._height,1,128,-85,false);
              res.resize(cimg::max(32U,w*disp._width/max_width),y - y0,1,res._spectrum==1?3:-100);
              positions(ind,0) = positions(ind,2) = (int)(align*(visu0.width()-res.width()));
              positions(ind,1) = positions(ind,3) = (int)y0;
              positions(ind,2)+=res._width - 1;
              positions(ind,3)+=res._height;
              visu0.draw_image(positions(ind,0),positions(ind,1),res);
            }
          if (axis=='x') --positions(ind,2); else --positions(ind,3);
          update_display = true;
        }

        if (!visu || oindice0!=indice0 || oindice1!=indice1) {
          if (indice0>=0 && indice1>=0) {
            visu.assign(visu0,false);
            const int indm = cimg::min(indice0,indice1), indM = cimg::max(indice0,indice1);
            for (int ind = indm; ind<=indM; ++ind) if (positions(ind,0)>=0) {
                visu.draw_rectangle(positions(ind,0),positions(ind,1),positions(ind,2),positions(ind,3),background_color,0.2f);
                if ((axis=='x' && positions(ind,2) - positions(ind,0)>=8) ||
                    (axis!='x' && positions(ind,3) - positions(ind,1)>=8))
                  visu.draw_rectangle(positions(ind,0),positions(ind,1),positions(ind,2),positions(ind,3),foreground_color,0.9f,0xAAAAAAAA);
              }
            const int yt = (int)text_down?visu.height()-13:0;
            if (is_clicked) visu.draw_text(0,yt," Images #%u - #%u, Size = %u",foreground_color,background_color,0.7f,13,
                                           orig + indm,orig + indM,indM - indm + 1);
            else visu.draw_text(0,yt," Image #%u (%u,%u,%u,%u)",foreground_color,background_color,0.7f,13,
                                orig + indice0,
                                _data[orig+indice0]._width,
                                _data[orig+indice0]._height,
                                _data[orig+indice0]._depth,
                                _data[orig+indice0]._spectrum);
            update_display = true;
          } else visu.assign();
        }
        if (!visu) { visu.assign(visu0,true); update_display = true; }
        if (update_display) { visu.display(disp); update_display = false; }
        disp.wait();

        // Manage user events.
        const int xm = disp.mouse_x(), ym = disp.mouse_y();
        int indice = -1;

        if (xm>=0) {
          indice = (int)indices(axis=='x'?xm:ym);
          if (disp.button()&1) {
            if (!is_clicked) { is_clicked = true; oindice0 = indice0; indice0 = indice; }
            oindice1 = indice1; indice1 = indice;
            if (!feature_type) is_selected = true;
          } else {
            if (!is_clicked) { oindice0 = oindice1 = indice0; indice0 = indice1 = indice; }
            else is_selected = true;
          }
        } else {
          if (is_clicked) {
            if (!(disp.button()&1)) { is_clicked = is_selected = false; indice0 = indice1 = -1; }
            else indice1 = -1;
          } else indice0 = indice1 = -1;
        }

        if (disp.button()&4) { is_clicked = is_selected = false; indice0 = indice1 = -1; }
        if (disp.button()&2 && exit_on_rightbutton) { is_selected = true; indice1 = indice0 = -1; }
        if (disp.wheel() && exit_on_wheel) is_selected = true;

        switch (key = disp.key()) {
#if cimg_OS!=2
        case cimg::keyCTRLRIGHT :
#endif
# 44106 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        case 0 : case cimg::keyCTRLLEFT : key = 0; break;
        case cimg::keyD : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
            disp.set_fullscreen(false).resize(CImgDisplay::_fitscreen(3*disp.width()/2,3*disp.height()/2,1,128,-100,false),
                                              CImgDisplay::_fitscreen(3*disp.width()/2,3*disp.height()/2,1,128,-100,true),false).
              _is_resized = true;
            disp.set_key(key,false); key = 0; visu0.assign();
          } break;
        case cimg::keyC : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
            disp.set_fullscreen(false).resize(cimg_fitscreen(2*disp.width()/3,2*disp.height()/3,1),false)._is_resized = true;
            disp.set_key(key,false); key = 0; visu0.assign();
          } break;
        case cimg::keyR : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
            disp.set_fullscreen(false).resize(cimg_fitscreen(axis=='x'?sum_width:max_width,axis=='x'?max_height:sum_height,1),false)._is_resized = true;
            disp.set_key(key,false); key = 0; visu0.assign();
          } break;
        case cimg::keyF : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
            disp.resize(disp.screen_width(),disp.screen_height(),false).toggle_fullscreen()._is_resized = true;
            disp.set_key(key,false); key = 0; visu0.assign();
          } break;
        case cimg::keyS : if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
            static unsigned int snap_number = 0;
            char filename[32] = { 0 };
            std::FILE *file;
            do {
              cimg_snprintf(filename,sizeof(filename),cimg_appname "_%.4u.bmp",snap_number++);
              if ((file=std::fopen(filename,"r"))!=0) cimg::fclose(file);
            } while (file);
            if (visu0) {
              visu.draw_text(0,0," Saving snapshot... ",foreground_color,background_color,1,13).display(disp);
              visu0.save(filename);
              visu.draw_text(0,0," Snapshot '%s' saved. ",foreground_color,background_color,1,13,filename).display(disp);
            }
            disp.set_key(key,false).wait(); key = 0;
          } break;
        case cimg::keyO :
          if (disp.is_keyCTRLLEFT() || disp.is_keyCTRLRIGHT()) {
            static unsigned int snap_number = 0;
            char filename[32] = { 0 };
            std::FILE *file;
            do {
#ifdef cimg_use_zlib
              cimg_snprintf(filename,sizeof(filename),cimg_appname "_%.4u.cimgz",snap_number++);
#else
# 44149 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
              cimg_snprintf(filename,sizeof(filename),cimg_appname "_%.4u.cimg",snap_number++);
#endif
# 44151 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
              if ((file=std::fopen(filename,"r"))!=0) cimg::fclose(file);
            } while (file);
            visu.draw_text(0,0," Saving instance... ",foreground_color,background_color,1,13).display(disp);
            save(filename);
            visu.draw_text(0,0," Instance '%s' saved. ",foreground_color,background_color,1,13,filename).display(disp);
            disp.set_key(key,false).wait(); key = 0;
          } break;
        }
        if (disp.is_resized()) { disp.resize(false); visu0.assign(); }
        if (ym>=0 && ym<13) { if (!text_down) { visu.assign(); text_down = true; }}
        else if (ym>=visu.height()-13) { if(text_down) { visu.assign(); text_down = false; }}
      }
      CImg<intT> res(1,2,1,1,-1);
      if (is_selected) { if (feature_type) res.fill(cimg::min(indice0,indice1),cimg::max(indice0,indice1)); else res.fill(indice0); }
      if (!(disp.button()&2)) disp.set_button();
      disp._normalization = old_normalization;
      disp._is_resized = old_is_resized;
      disp.set_key(key);
      return res;
    }

    //! Load a list from a file.
    /**
     \param filename Filename to read data from.
    **/
    CImgList<T>& load(const char *const filename) {
      if (!filename)
        throw CImgArgumentException(_cimglist_instance
                                    "load(): Specified filename is (null).",
                                    cimglist_instance);

      if (!cimg::strncasecmp(filename,"http://",7) || !cimg::strncasecmp(filename,"https://",8)) {
        char filename_local[1024] = { 0 };
        load(cimg::load_network_external(filename,filename_local));
        std::remove(filename_local);
        return *this;
      }

      const char *const ext = cimg::split_filename(filename);
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      try {
#ifdef cimglist_load_plugin
        cimglist_load_plugin(filename);
#endif
# 44196 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_load_plugin1
        cimglist_load_plugin1(filename);
#endif
# 44199 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_load_plugin2
        cimglist_load_plugin2(filename);
#endif
# 44202 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_load_plugin3
        cimglist_load_plugin3(filename);
#endif
# 44205 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_load_plugin4
        cimglist_load_plugin4(filename);
#endif
# 44208 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_load_plugin5
        cimglist_load_plugin5(filename);
#endif
# 44211 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_load_plugin6
        cimglist_load_plugin6(filename);
#endif
# 44214 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_load_plugin7
        cimglist_load_plugin7(filename);
#endif
# 44217 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_load_plugin8
        cimglist_load_plugin8(filename);
#endif
# 44220 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        if (!cimg::strcasecmp(ext,"tif") ||
            !cimg::strcasecmp(ext,"tiff")) load_tiff(filename);
        else if (!cimg::strcasecmp(ext,"gif")) load_gif_external(filename);
        else if (!cimg::strcasecmp(ext,"cimg") ||
                 !cimg::strcasecmp(ext,"cimgz") ||
                 !*ext) load_cimg(filename);
        else if (!cimg::strcasecmp(ext,"rec") ||
                 !cimg::strcasecmp(ext,"par")) load_parrec(filename);
        else if (!cimg::strcasecmp(ext,"avi") ||
                 !cimg::strcasecmp(ext,"mov") ||
                 !cimg::strcasecmp(ext,"asf") ||
                 !cimg::strcasecmp(ext,"divx") ||
                 !cimg::strcasecmp(ext,"flv") ||
                 !cimg::strcasecmp(ext,"mpg") ||
                 !cimg::strcasecmp(ext,"m1v") ||
                 !cimg::strcasecmp(ext,"m2v") ||
                 !cimg::strcasecmp(ext,"m4v") ||
                 !cimg::strcasecmp(ext,"mjp") ||
                 !cimg::strcasecmp(ext,"mkv") ||
                 !cimg::strcasecmp(ext,"mpe") ||
                 !cimg::strcasecmp(ext,"movie") ||
                 !cimg::strcasecmp(ext,"ogm") ||
                 !cimg::strcasecmp(ext,"ogg") ||
                 !cimg::strcasecmp(ext,"qt") ||
                 !cimg::strcasecmp(ext,"rm") ||
                 !cimg::strcasecmp(ext,"vob") ||
                 !cimg::strcasecmp(ext,"wmv") ||
                 !cimg::strcasecmp(ext,"xvid") ||
                 !cimg::strcasecmp(ext,"mpeg")) load_ffmpeg(filename);
        else if (!cimg::strcasecmp(ext,"gz")) load_gzip_external(filename);
        else throw CImgIOException("CImgList<%s>::load()",
                                   pixel_type());
      } catch (CImgIOException&) {
        try {
          cimg::fclose(cimg::fopen(filename,"rb"));
        } catch (CImgIOException&) {
          cimg::exception_mode() = omode;
          throw CImgIOException(_cimglist_instance
                                "load(): Failed to open file '%s'.",
                                cimglist_instance,
                                filename);
        }
        assign(1);
        try {
          _data->load(filename);
        } catch (CImgIOException&) {
          cimg::exception_mode() = omode;
          throw CImgIOException(_cimglist_instance
                                "load(): Failed to recognize format of file '%s'.",
                                cimglist_instance,
                                filename);
        }
      }
      cimg::exception_mode() = omode;
      return *this;
    }

    //! Load a list from a file \newinstance.
    static CImgList<T> get_load(const char *const filename) {
      return CImgList<T>().load(filename);
    }

    //! Load a list from a .cimg file.
    /**
      \param filename Filename to read data from.
    **/
    CImgList<T>& load_cimg(const char *const filename) {
      return _load_cimg(0,filename);
    }

    //! Load a list from a .cimg file \newinstance.
    static CImgList<T> get_load_cimg(const char *const filename) {
      return CImgList<T>().load_cimg(filename);
    }

    //! Load a list from a .cimg file.
    /**
      \param file File to read data from.
    **/
    CImgList<T>& load_cimg(std::FILE *const file) {
      return _load_cimg(file,0);
    }

    //! Load a list from a .cimg file \newinstance.
    static CImgList<T> get_load_cimg(std::FILE *const file) {
      return CImgList<T>().load_cimg(file);
    }

    CImgList<T>& _load_cimg(std::FILE *const file, const char *const filename) {
#ifdef cimg_use_zlib
#define _cimgz_load_cimg_case(Tss) { \
   Bytef *const cbuf = new Bytef[csiz]; \
   cimg::fread(cbuf,csiz,nfile); \
   raw.assign(W,H,D,C); \
   unsigned long destlen = (unsigned long)raw.size()*sizeof(Tss); \
   uncompress((Bytef*)raw._data,&destlen,cbuf,csiz); \
   delete[] cbuf; \
   const Tss *ptrs = raw._data; \
   for (unsigned long off = raw.size(); off; --off) *(ptrd++) = (T)*(ptrs++); \
}
#else
# 44321 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#define _cimgz_load_cimg_case(Tss) \
   throw CImgIOException(_cimglist_instance \
                         "load_cimg(): Unable to load compressed data from file '%s' unless zlib is enabled.", \
                         cimglist_instance, \
                         filename?filename:"(FILE*)");
#endif
# 44327 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

#define _cimg_load_cimg_case(Ts,Tss) \
      if (!loaded && !cimg::strcasecmp(Ts,str_pixeltype)) { \
        for (unsigned int l = 0; l<N; ++l) { \
          j = 0; while ((i=std::fgetc(nfile))!='\n' && i>=0) tmp[j++] = (char)i; tmp[j] = 0; \
          W = H = D = C = 0; csiz = 0; \
          if ((err = std::sscanf(tmp,"%u %u %u %u #%u",&W,&H,&D,&C,&csiz))<4) \
            throw CImgIOException(_cimglist_instance \
                                  "load_cimg(): Invalid specified size (%u,%u,%u,%u) of image %u in file '%s'", \
                                  cimglist_instance, \
                                  W,H,D,C,l,filename?filename:("(FILE*)")); \
          if (W*H*D*C>0) { \
            CImg<Tss> raw; \
            CImg<T> &img = _data[l]; \
            img.assign(W,H,D,C); \
            T *ptrd = img._data; \
            if (err==5) _cimgz_load_cimg_case(Tss) \
            else for (long to_read = (long)img.size(); to_read>0; ) { \
              raw.assign(cimg::min(to_read,cimg_iobuffer)); \
              cimg::fread(raw._data,raw._width,nfile); \
              if (endian!=cimg::endianness()) cimg::invert_endianness(raw._data,raw._width); \
              to_read-=raw._width; \
              const Tss *ptrs = raw._data; \
              for (unsigned long off = (unsigned long)raw._width; off; --off) *(ptrd++) = (T)*(ptrs++); \
            } \
          } \
        } \
        loaded = true; \
      }

      if (!filename && !file)
        throw CImgArgumentException(_cimglist_instance
                                    "load_cimg(): Specified filename is (null).",
                                    cimglist_instance);

      const int cimg_iobuffer = 12*1024*1024;
      std::FILE *const nfile = file?file:cimg::fopen(filename,"rb");
      bool loaded = false, endian = cimg::endianness();
      char tmp[256] = { 0 }, str_pixeltype[256] = { 0 }, str_endian[256] = { 0 };
      unsigned int j, err, N = 0, W, H, D, C, csiz;
      int i;
      do {
        j = 0; while ((i=std::fgetc(nfile))!='\n' && i!=EOF && j<256) tmp[j++] = (char)i; tmp[j] = 0;
      } while (*tmp=='#' && i!=EOF);
      err = std::sscanf(tmp,"%u%*c%255[A-Za-z_]%*c%255[sA-Za-z_ ]",&N,str_pixeltype,str_endian);
      if (err<2) {
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimglist_instance
                              "load_cimg(): CImg header not found in file '%s'.",
                              cimglist_instance,
                              filename?filename:"(FILE*)");
      }
      if (!cimg::strncasecmp("little",str_endian,6)) endian = false;
      else if (!cimg::strncasecmp("big",str_endian,3)) endian = true;
      assign(N);
      _cimg_load_cimg_case("bool",bool);
      _cimg_load_cimg_case("unsigned_char",unsigned char);
      _cimg_load_cimg_case("uchar",unsigned char);
      _cimg_load_cimg_case("char",char);
      _cimg_load_cimg_case("unsigned_short",unsigned short);
      _cimg_load_cimg_case("ushort",unsigned short);
      _cimg_load_cimg_case("short",short);
      _cimg_load_cimg_case("unsigned_int",unsigned int);
      _cimg_load_cimg_case("uint",unsigned int);
      _cimg_load_cimg_case("int",int);
      _cimg_load_cimg_case("unsigned_long",unsigned long);
      _cimg_load_cimg_case("ulong",unsigned long);
      _cimg_load_cimg_case("long",long);
      _cimg_load_cimg_case("float",float);
      _cimg_load_cimg_case("double",double);
      if (!loaded) {
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimglist_instance
                              "load_cimg(): Unsupported pixel type '%s' for file '%s'.",
                              cimglist_instance,
                              str_pixeltype,filename?filename:"(FILE*)");
      }
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Load a sublist list from a (non compressed) .cimg file.
    /**
      \param filename Filename to read data from.
      \param n0 Starting index of images to read (~0U for max).
      \param n1 Ending index of images to read (~0U for max).
      \param x0 Starting X-coordinates of image regions to read.
      \param y0 Starting Y-coordinates of image regions to read.
      \param z0 Starting Z-coordinates of image regions to read.
      \param c0 Starting C-coordinates of image regions to read.
      \param x1 Ending X-coordinates of image regions to read (~0U for max).
      \param y1 Ending Y-coordinates of image regions to read (~0U for max).
      \param z1 Ending Z-coordinates of image regions to read (~0U for max).
      \param c1 Ending C-coordinates of image regions to read (~0U for max).
    **/
    CImgList<T>& load_cimg(const char *const filename,
                           const unsigned int n0, const unsigned int n1,
                           const unsigned int x0, const unsigned int y0, const unsigned int z0, const unsigned int c0,
                           const unsigned int x1, const unsigned int y1, const unsigned int z1, const unsigned int c1) {
      return _load_cimg(0,filename,n0,n1,x0,y0,z0,c0,x1,y1,z1,c1);
    }

    //! Load a sublist list from a (non compressed) .cimg file \newinstance.
    static CImgList<T> get_load_cimg(const char *const filename,
                                     const unsigned int n0, const unsigned int n1,
                                     const unsigned int x0, const unsigned int y0, const unsigned int z0, const unsigned int c0,
                                     const unsigned int x1, const unsigned int y1, const unsigned int z1, const unsigned int c1) {
      return CImgList<T>().load_cimg(filename,n0,n1,x0,y0,z0,c0,x1,y1,z1,c1);
    }

    //! Load a sub-image list from a (non compressed) .cimg file \overloading.
    CImgList<T>& load_cimg(std::FILE *const file,
                           const unsigned int n0, const unsigned int n1,
                           const unsigned int x0, const unsigned int y0, const unsigned int z0, const unsigned int c0,
                           const unsigned int x1, const unsigned int y1, const unsigned int z1, const unsigned int c1) {
      return _load_cimg(file,0,n0,n1,x0,y0,z0,c0,x1,y1,z1,c1);
    }

    //! Load a sub-image list from a (non compressed) .cimg file \newinstance.
    static CImgList<T> get_load_cimg(std::FILE *const file,
                                     const unsigned int n0, const unsigned int n1,
                                     const unsigned int x0, const unsigned int y0, const unsigned int z0, const unsigned int c0,
                                     const unsigned int x1, const unsigned int y1, const unsigned int z1, const unsigned int c1) {
      return CImgList<T>().load_cimg(file,n0,n1,x0,y0,z0,c0,x1,y1,z1,c1);
    }

    CImgList<T>& _load_cimg(std::FILE *const file, const char *const filename,
			    const unsigned int n0, const unsigned int n1,
			    const unsigned int x0, const unsigned int y0, const unsigned int z0, const unsigned int c0,
			    const unsigned int x1, const unsigned int y1, const unsigned int z1, const unsigned int c1) {
#define _cimg_load_cimg_case2(Ts,Tss) \
      if (!loaded && !cimg::strcasecmp(Ts,str_pixeltype)) { \
        for (unsigned int l = 0; l<=nn1; ++l) { \
          j = 0; while ((i=std::fgetc(nfile))!='\n' && i>=0) tmp[j++] = (char)i; tmp[j] = 0; \
          W = H = D = C = 0; \
          if (std::sscanf(tmp,"%u %u %u %u",&W,&H,&D,&C)!=4) \
            throw CImgIOException(_cimglist_instance \
                                  "load_cimg(): Invalid specified size (%u,%u,%u,%u) of image %u in file '%s'", \
                                  cimglist_instance, \
                                  W,H,D,C,l,filename?filename:"(FILE*)"); \
          if (W*H*D*C>0) { \
            if (l<nn0 || nx0>=W || ny0>=H || nz0>=D || nc0>=C) std::fseek(nfile,W*H*D*C*sizeof(Tss),SEEK_CUR); \
            else { \
              const unsigned int \
                _nx1 = nx1==~0U?W-1:nx1, \
                _ny1 = ny1==~0U?H-1:ny1, \
                _nz1 = nz1==~0U?D-1:nz1, \
                _nc1 = nc1==~0U?C-1:nc1; \
              if (_nx1>=W || _ny1>=H || _nz1>=D || _nc1>=C) \
                throw CImgArgumentException(_cimglist_instance \
                                            "load_cimg(): Invalid specified coordinates [%u](%u,%u,%u,%u) -> [%u](%u,%u,%u,%u) " \
                                            "because image [%u] in file '%s' has size (%u,%u,%u,%u).", \
                                            cimglist_instance, \
                                            n0,x0,y0,z0,c0,n1,x1,y1,z1,c1,l,filename?filename:"(FILE*)",W,H,D,C); \
              CImg<Tss> raw(1 + _nx1 - nx0); \
              CImg<T> &img = _data[l - nn0]; \
              img.assign(1 + _nx1 - nx0,1 + _ny1 - ny0,1 + _nz1 - nz0,1 + _nc1 - nc0); \
              T *ptrd = img._data; \
              const unsigned int skipvb = nc0*W*H*D*sizeof(Tss); \
              if (skipvb) std::fseek(nfile,skipvb,SEEK_CUR); \
              for (unsigned int c = 1 + _nc1 - nc0; c; --c) { \
                const unsigned int skipzb = nz0*W*H*sizeof(Tss); \
                if (skipzb) std::fseek(nfile,skipzb,SEEK_CUR); \
                for (unsigned int z = 1 + _nz1 - nz0; z; --z) { \
                  const unsigned int skipyb = ny0*W*sizeof(Tss); \
                  if (skipyb) std::fseek(nfile,skipyb,SEEK_CUR); \
                  for (unsigned int y = 1 + _ny1 - ny0; y; --y) { \
                    const unsigned int skipxb = nx0*sizeof(Tss); \
                    if (skipxb) std::fseek(nfile,skipxb,SEEK_CUR); \
                    cimg::fread(raw._data,raw._width,nfile); \
                    if (endian!=cimg::endianness()) cimg::invert_endianness(raw._data,raw._width); \
                    const Tss *ptrs = raw._data; \
                    for (unsigned int off = raw._width; off; --off) *(ptrd++) = (T)*(ptrs++); \
                    const unsigned int skipxe = (W-1-_nx1)*sizeof(Tss); \
                    if (skipxe) std::fseek(nfile,skipxe,SEEK_CUR); \
                  } \
                  const unsigned int skipye = (H-1-_ny1)*W*sizeof(Tss); \
                  if (skipye) std::fseek(nfile,skipye,SEEK_CUR); \
                } \
                const unsigned int skipze = (D-1-_nz1)*W*H*sizeof(Tss); \
                if (skipze) std::fseek(nfile,skipze,SEEK_CUR); \
              } \
              const unsigned int skipve = (C-1-_nc1)*W*H*D*sizeof(Tss); \
              if (skipve) std::fseek(nfile,skipve,SEEK_CUR); \
            } \
          } \
        } \
        loaded = true; \
      }

      if (!filename && !file)
        throw CImgArgumentException(_cimglist_instance
                                    "load_cimg(): Specified filename is (null).",
                                    cimglist_instance);
      unsigned int
        nn0 = cimg::min(n0,n1), nn1 = cimg::max(n0,n1),
        nx0 = cimg::min(x0,x1), nx1 = cimg::max(x0,x1),
        ny0 = cimg::min(y0,y1), ny1 = cimg::max(y0,y1),
        nz0 = cimg::min(z0,z1), nz1 = cimg::max(z0,z1),
        nc0 = cimg::min(c0,c1), nc1 = cimg::max(c0,c1);

      std::FILE *const nfile = file?file:cimg::fopen(filename,"rb");
      bool loaded = false, endian = cimg::endianness();
      char tmp[256] = { 0 }, str_pixeltype[256] = { 0 }, str_endian[256] = { 0 };
      unsigned int j, err, N, W, H, D, C;
      int i;
      j = 0; while((i=std::fgetc(nfile))!='\n' && i!=EOF && j<256) tmp[j++] = (char)i; tmp[j] = 0;
      err = std::sscanf(tmp,"%u%*c%255[A-Za-z_]%*c%255[sA-Za-z_ ]",&N,str_pixeltype,str_endian);
      if (err<2) {
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimglist_instance
                              "load_cimg(): CImg header not found in file '%s'.",
                              cimglist_instance,
                              filename?filename:"(FILE*)");
      }
      if (!cimg::strncasecmp("little",str_endian,6)) endian = false;
      else if (!cimg::strncasecmp("big",str_endian,3)) endian = true;
      nn1 = n1==~0U?N-1:n1;
      if (nn1>=N)
        throw CImgArgumentException(_cimglist_instance
                                    "load_cimg(): Invalid specified coordinates [%u](%u,%u,%u,%u) -> [%u](%u,%u,%u,%u) "
                                    "because file '%s' contains only %u images.",
                                    cimglist_instance,
                                    n0,x0,y0,z0,c0,n1,x1,y1,z1,c1,filename?filename:"(FILE*)",N);
      assign(1+nn1-n0);
      _cimg_load_cimg_case2("bool",bool);
      _cimg_load_cimg_case2("unsigned_char",unsigned char);
      _cimg_load_cimg_case2("uchar",unsigned char);
      _cimg_load_cimg_case2("char",char);
      _cimg_load_cimg_case2("unsigned_short",unsigned short);
      _cimg_load_cimg_case2("ushort",unsigned short);
      _cimg_load_cimg_case2("short",short);
      _cimg_load_cimg_case2("unsigned_int",unsigned int);
      _cimg_load_cimg_case2("uint",unsigned int);
      _cimg_load_cimg_case2("int",int);
      _cimg_load_cimg_case2("unsigned_long",unsigned long);
      _cimg_load_cimg_case2("ulong",unsigned long);
      _cimg_load_cimg_case2("long",long);
      _cimg_load_cimg_case2("float",float);
      _cimg_load_cimg_case2("double",double);
      if (!loaded) {
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimglist_instance
                              "load_cimg(): Unsupported pixel type '%s' for file '%s'.",
                              cimglist_instance,
                              str_pixeltype,filename?filename:"(FILE*)");
      }
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Load a list from a PAR/REC (Philips) file.
    /**
      \param filename Filename to read data from.
    **/
    CImgList<T>& load_parrec(const char *const filename) {
      if (!filename)
        throw CImgArgumentException(_cimglist_instance
                                    "load_parrec(): Specified filename is (null).",
                                    cimglist_instance);

      char body[1024] = { 0 }, filenamepar[1024] = { 0 }, filenamerec[1024] = { 0 };
      const char *const ext = cimg::split_filename(filename,body);
      if (!std::strcmp(ext,"par")) { std::strncpy(filenamepar,filename,sizeof(filenamepar)-1); cimg_snprintf(filenamerec,sizeof(filenamerec),"%s.rec",body); }
      if (!std::strcmp(ext,"PAR")) { std::strncpy(filenamepar,filename,sizeof(filenamepar)-1); cimg_snprintf(filenamerec,sizeof(filenamerec),"%s.REC",body); }
      if (!std::strcmp(ext,"rec")) { std::strncpy(filenamerec,filename,sizeof(filenamerec)-1); cimg_snprintf(filenamepar,sizeof(filenamepar),"%s.par",body); }
      if (!std::strcmp(ext,"REC")) { std::strncpy(filenamerec,filename,sizeof(filenamerec)-1); cimg_snprintf(filenamepar,sizeof(filenamepar),"%s.PAR",body); }
      std::FILE *file = cimg::fopen(filenamepar,"r");

      // Parse header file
      CImgList<floatT> st_slices;
      CImgList<uintT> st_global;
      int err;
      char line[256] = { 0 };
      do { err=std::fscanf(file,"%255[^\n]%*c",line); } while (err!=EOF && (*line=='#' || *line=='.'));
      do {
        unsigned int sn,size_x,size_y,pixsize;
        float rs,ri,ss;
        err = std::fscanf(file,"%u%*u%*u%*u%*u%*u%*u%u%*u%u%u%g%g%g%*[^\n]",&sn,&pixsize,&size_x,&size_y,&ri,&rs,&ss);
        if (err==7) {
          CImg<floatT>::vector((float)sn,(float)pixsize,(float)size_x,(float)size_y,ri,rs,ss,0).move_to(st_slices);
          unsigned int i; for (i = 0; i<st_global._width && sn<=st_global[i][2]; ++i) {}
          if (i==st_global._width) CImg<uintT>::vector(size_x,size_y,sn).move_to(st_global);
          else {
            CImg<uintT> &vec = st_global[i];
            if (size_x>vec[0]) vec[0] = size_x;
            if (size_y>vec[1]) vec[1] = size_y;
            vec[2] = sn;
          }
          st_slices[st_slices._width-1][7] = (float)i;
        }
      } while (err==7);

      // Read data
      std::FILE *file2 = cimg::fopen(filenamerec,"rb");
      cimglist_for(st_global,l) {
        const CImg<uintT>& vec = st_global[l];
        CImg<T>(vec[0],vec[1],vec[2]).move_to(*this);
      }

      cimglist_for(st_slices,l) {
        const CImg<floatT>& vec = st_slices[l];
        const unsigned int
          sn = (unsigned int)vec[0] - 1,
          pixsize = (unsigned int)vec[1],
          size_x = (unsigned int)vec[2],
          size_y = (unsigned int)vec[3],
          imn = (unsigned int)vec[7];
        const float ri = vec[4], rs = vec[5], ss = vec[6];
        switch (pixsize) {
        case 8 : {
          CImg<ucharT> buf(size_x,size_y);
          cimg::fread(buf._data,size_x*size_y,file2);
          if (cimg::endianness()) cimg::invert_endianness(buf._data,size_x*size_y);
          CImg<T>& img = (*this)[imn];
          cimg_forXY(img,x,y) img(x,y,sn) = (T)(( buf(x,y)*rs + ri )/(rs*ss));
        } break;
        case 16 : {
          CImg<ushortT> buf(size_x,size_y);
          cimg::fread(buf._data,size_x*size_y,file2);
          if (cimg::endianness()) cimg::invert_endianness(buf._data,size_x*size_y);
          CImg<T>& img = (*this)[imn];
          cimg_forXY(img,x,y) img(x,y,sn) = (T)(( buf(x,y)*rs + ri )/(rs*ss));
        } break;
        case 32 : {
          CImg<uintT> buf(size_x,size_y);
          cimg::fread(buf._data,size_x*size_y,file2);
          if (cimg::endianness()) cimg::invert_endianness(buf._data,size_x*size_y);
          CImg<T>& img = (*this)[imn];
          cimg_forXY(img,x,y) img(x,y,sn) = (T)(( buf(x,y)*rs + ri )/(rs*ss));
        } break;
        default :
          cimg::fclose(file);
          cimg::fclose(file2);
          throw CImgIOException(_cimglist_instance
                                "load_parrec(): Unsupported %d-bits pixel type for file '%s'.",
                                cimglist_instance,
                                pixsize,filename);
        }
      }
      cimg::fclose(file);
      cimg::fclose(file2);
      if (!_width)
        throw CImgIOException(_cimglist_instance
                              "load_parrec(): Failed to recognize valid PAR-REC data in file '%s'.",
                              cimglist_instance,
                              filename);
      return *this;
    }

    //! Load a list from a PAR/REC (Philips) file \newinstance.
    static CImgList<T> get_load_parrec(const char *const filename) {
      return CImgList<T>().load_parrec(filename);
    }

    //! Load a list from a YUV image sequence file.
    /**
        \param filename Filename to read data from.
        \param size_x Width of the images.
        \param size_y Height of the images.
        \param first_frame Index of first image frame to read.
        \param last_frame Index of last image frame to read.
        \param step_frame Step applied between each frame.
        \param yuv2rgb Apply YUV to RGB transformation during reading.
    **/
    CImgList<T>& load_yuv(const char *const filename,
                          const unsigned int size_x, const unsigned int size_y,
                          const unsigned int first_frame=0, const unsigned int last_frame=~0U,
                          const unsigned int step_frame=1, const bool yuv2rgb=true) {
      return _load_yuv(0,filename,size_x,size_y,first_frame,last_frame,step_frame,yuv2rgb);
    }

    //! Load a list from a YUV image sequence file \newinstance.
    static CImgList<T> get_load_yuv(const char *const filename,
                                    const unsigned int size_x, const unsigned int size_y=1,
                                    const unsigned int first_frame=0, const unsigned int last_frame=~0U,
                                    const unsigned int step_frame=1, const bool yuv2rgb=true) {
      return CImgList<T>().load_yuv(filename,size_x,size_y,first_frame,last_frame,step_frame,yuv2rgb);
    }

    //! Load a list from an image sequence YUV file \overloading.
    CImgList<T>& load_yuv(std::FILE *const file,
                          const unsigned int size_x, const unsigned int size_y,
                          const unsigned int first_frame=0, const unsigned int last_frame=~0U,
                          const unsigned int step_frame=1, const bool yuv2rgb=true) {
      return _load_yuv(file,0,size_x,size_y,first_frame,last_frame,step_frame,yuv2rgb);
    }

    //! Load a list from an image sequence YUV file \newinstance.
    static CImgList<T> get_load_yuv(std::FILE *const file,
                                    const unsigned int size_x, const unsigned int size_y=1,
                                    const unsigned int first_frame=0, const unsigned int last_frame=~0U,
                                    const unsigned int step_frame=1, const bool yuv2rgb=true) {
      return CImgList<T>().load_yuv(file,size_x,size_y,first_frame,last_frame,step_frame,yuv2rgb);
    }

    CImgList<T>& _load_yuv(std::FILE *const file, const char *const filename,
			   const unsigned int size_x, const unsigned int size_y,
			   const unsigned int first_frame, const unsigned int last_frame,
			   const unsigned int step_frame, const bool yuv2rgb) {
      if (!filename && !file)
        throw CImgArgumentException(_cimglist_instance
                                    "load_yuv(): Specified filename is (null).",
                                    cimglist_instance);
      if (size_x%2 || size_y%2)
        throw CImgArgumentException(_cimglist_instance
                                    "load_yuv(): Invalid odd XY dimensions %ux%u in file '%s'.",
                                    cimglist_instance,
                                    size_x,size_y,filename?filename:"(FILE*)");
      if (!size_x || !size_y)
        throw CImgArgumentException(_cimglist_instance
                                    "load_yuv(): Invalid sequence size (%u,%u) in file '%s'.",
                                    cimglist_instance,
                                    size_x,size_y,filename?filename:"(FILE*)");

      const unsigned int
	nfirst_frame = first_frame<last_frame?first_frame:last_frame,
	nlast_frame = first_frame<last_frame?last_frame:first_frame,
	nstep_frame = step_frame?step_frame:1;

      CImg<ucharT> tmp(size_x,size_y,1,3), UV(size_x/2,size_y/2,1,2);
      std::FILE *const nfile = file?file:cimg::fopen(filename,"rb");
      bool stop_flag = false;
      int err;
      if (nfirst_frame) {
        err = std::fseek(nfile,nfirst_frame*(size_x*size_y + size_x*size_y/2),SEEK_CUR);
        if (err) {
          if (!file) cimg::fclose(nfile);
          throw CImgIOException(_cimglist_instance
                                "load_yuv(): File '%s' doesn't contain frame number %u.",
                                cimglist_instance,
                                filename?filename:"(FILE*)",nfirst_frame);
        }
      }
      unsigned int frame;
      for (frame = nfirst_frame; !stop_flag && frame<=nlast_frame; frame+=nstep_frame) {
        tmp.fill(0);
        // *TRY* to read the luminance part, do not replace by cimg::fread!
        err = (int)std::fread((void*)(tmp._data),1,(unsigned long)tmp._width*tmp._height,nfile);
        if (err!=(int)(tmp._width*tmp._height)) {
          stop_flag = true;
          if (err>0)
            cimg::warn(_cimglist_instance
                       "load_yuv(): File '%s' contains incomplete data or given image dimensions (%u,%u) are incorrect.",
                       cimglist_instance,
                       filename?filename:"(FILE*)",size_x,size_y);
        } else {
          UV.fill(0);
          // *TRY* to read the luminance part, do not replace by cimg::fread!
          err = (int)std::fread((void*)(UV._data),1,(size_t)(UV.size()),nfile);
          if (err!=(int)(UV.size())) {
            stop_flag = true;
            if (err>0)
              cimg::warn(_cimglist_instance
                         "load_yuv(): File '%s' contains incomplete data or given image dimensions (%u,%u) are incorrect.",
                         cimglist_instance,
                         filename?filename:"(FILE*)",size_x,size_y);
          } else {
            cimg_forXY(UV,x,y) {
              const int x2 = x*2, y2 = y*2;
              tmp(x2,y2,1) = tmp(x2+1,y2,1) = tmp(x2,y2+1,1) = tmp(x2+1,y2+1,1) = UV(x,y,0);
              tmp(x2,y2,2) = tmp(x2+1,y2,2) = tmp(x2,y2+1,2) = tmp(x2+1,y2+1,2) = UV(x,y,1);
            }
            if (yuv2rgb) tmp.YCbCrtoRGB();
            insert(tmp);
	    if (nstep_frame>1) std::fseek(nfile,(nstep_frame-1)*(size_x*size_y + size_x*size_y/2),SEEK_CUR);
          }
        }
      }
      if (stop_flag && nlast_frame!=~0U && frame!=nlast_frame)
        cimg::warn(_cimglist_instance
                   "load_yuv(): Frame %d not reached since only %u frames were found in file '%s'.",
                   cimglist_instance,
                   nlast_frame,frame-1,filename?filename:"(FILE*)");

      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Load an image from a video file, using ffmpeg libraries.
    /**
      \param filename Filename, as a C-string.
      \param first_frame Index of the first frame to read.
      \param last_frame Index of the last frame to read.
      \param step_frame Step value for frame reading.
      \param pixel_format To be documented.
      \param resume To be documented.
    **/
    // This piece of code has been firstly created by David Starweather (starkdg(at)users(dot)sourceforge(dot)net)
    // I modified it afterwards for direct inclusion in the library core.
    CImgList<T>& load_ffmpeg(const char *const filename, const unsigned int first_frame=0, const unsigned int last_frame=~0U,
			     const unsigned int step_frame=1, const bool pixel_format=true, const bool resume=false) {
      if (!filename)
        throw CImgArgumentException(_cimglist_instance
                                    "load_ffmpeg(): Specified filename is (null).",
                                    cimglist_instance);

      const unsigned int
	nfirst_frame = first_frame<last_frame?first_frame:last_frame,
	nlast_frame = first_frame<last_frame?last_frame:first_frame,
	nstep_frame = step_frame?step_frame:1;
      assign();

#ifndef cimg_use_ffmpeg
      if ((nfirst_frame || nlast_frame!=~0U || nstep_frame>1) || (resume && (pixel_format || !pixel_format)))
        throw CImgArgumentException(_cimglist_instance
                                    "load_ffmpeg(): Unable to load sub-frames from file '%s' unless libffmpeg is enabled.",
                                    cimglist_instance,
                                    filename);

      return load_ffmpeg_external(filename);
#else
# 44839 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      const PixelFormat ffmpeg_pixfmt = pixel_format?PIX_FMT_RGB24:PIX_FMT_GRAY8;
      avcodec_register_all();
      av_register_all();
      static AVFormatContext *format_ctx = 0;
      static AVCodecContext *codec_ctx = 0;
      static AVCodec *codec = 0;
      static AVFrame *avframe = avcodec_alloc_frame(), *converted_frame = avcodec_alloc_frame();
      static int vstream = 0;

      if (resume) {
        if (!format_ctx || !codec_ctx || !codec || !avframe || !converted_frame)
          throw CImgArgumentException(_cimglist_instance
                                      "load_ffmpeg(): Failed to resume loading of file '%s', due to unallocated FFMPEG structures.",
                                      cimglist_instance,
                                      filename);
      } else {
        // Open video file, find main video stream and codec.
        if (format_ctx) avformat_close_input(&format_ctx);
        if (avformat_open_input(&format_ctx,filename,0,0)!=0)
          throw CImgIOException(_cimglist_instance
                                "load_ffmpeg(): Failed to open file '%s'.",
                                cimglist_instance,
                                filename);

        if (!avframe || !converted_frame || avformat_find_stream_info(format_ctx,NULL)<0) {
          avformat_close_input(&format_ctx); format_ctx = 0;
          return load_ffmpeg_external(filename);
        }
#if cimg_verbosity>=3
        dump_format(format_ctx,0,0,0);
#endif
# 44870 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

        // Special command: Return informations on main video stream.
        // as a vector 1x4 containing: (nb_frames,width,height,fps).
        if (!first_frame && !last_frame && !step_frame) {
          for (vstream = 0; vstream<(int)(format_ctx->nb_streams); ++vstream)
            if (format_ctx->streams[vstream]->codec->codec_type==AVMEDIA_TYPE_VIDEO) break;
          if (vstream==(int)format_ctx->nb_streams) assign();
          else {
            CImgList<doubleT> timestamps;
            int nb_frames;
            AVPacket packet;
            // Count frames and store timestamps.
            for (nb_frames = 0; av_read_frame(format_ctx,&packet)>=0; av_free_packet(&packet))
              if (packet.stream_index==vstream) {
                CImg<doubleT>::vector((double)packet.pts).move_to(timestamps);
                ++nb_frames;
              }
            // Get frame with, height and fps.
            const int
              framew = format_ctx->streams[vstream]->codec->width,
              frameh = format_ctx->streams[vstream]->codec->height;
            const float
              num = (float)(format_ctx->streams[vstream]->r_frame_rate).num,
              den = (float)(format_ctx->streams[vstream]->r_frame_rate).den,
              fps = num/den;
            // Return infos as a list.
            assign(2);
            (*this)[0].assign(1,4).fill((T)nb_frames,(T)framew,(T)frameh,(T)fps);
            (*this)[1] = (timestamps>'y');
          }
          avformat_close_input(&format_ctx); format_ctx = 0;
          return *this;
        }

        for (vstream = 0; vstream<(int)(format_ctx->nb_streams) &&
               format_ctx->streams[vstream]->codec->codec_type!=AVMEDIA_TYPE_VIDEO; ) ++vstream;
        if (vstream==(int)format_ctx->nb_streams) {
          avformat_close_input(&format_ctx); format_ctx = 0;
          return load_ffmpeg_external(filename);
        }
        codec_ctx = format_ctx->streams[vstream]->codec;
        codec = avcodec_find_decoder(codec_ctx->codec_id);
        if (!codec) {
          return load_ffmpeg_external(filename);
        }
        if (avcodec_open2(codec_ctx,codec,NULL)<0) { // Open codec
          return load_ffmpeg_external(filename);
        }
      }

      // Read video frames
      const unsigned int numBytes = avpicture_get_size(ffmpeg_pixfmt,codec_ctx->width,codec_ctx->height);
      uint8_t *const buffer = new uint8_t[numBytes];
      avpicture_fill((AVPicture *)converted_frame,buffer,ffmpeg_pixfmt,codec_ctx->width,codec_ctx->height);
      const T foo = (T)0;
      AVPacket packet;
      for (unsigned int frame = 0, next_frame = nfirst_frame; frame<=nlast_frame && av_read_frame(format_ctx,&packet)>=0; ) {
	if (packet.stream_index==(int)vstream) {
          int decoded = 0;
#if defined(AV_VERSION_INT)
#if LIBAVCODEC_VERSION_INT<AV_VERSION_INT(52,26,0)
          avcodec_decode_video(codec_ctx,avframe,&decoded,packet.data, packet.size);
#else
# 44933 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
          avcodec_decode_video2(codec_ctx,avframe,&decoded,&packet);
#endif
# 44935 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#else
# 44936 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
          avcodec_decode_video(codec_ctx,avframe,&decoded,packet.data, packet.size);
#endif
# 44938 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
	  if (decoded) {
	    if (frame==next_frame) {
	      SwsContext *c = sws_getContext(codec_ctx->width,codec_ctx->height,codec_ctx->pix_fmt,codec_ctx->width,
                                             codec_ctx->height,ffmpeg_pixfmt,1,0,0,0);
	      sws_scale(c,avframe->data,avframe->linesize,0,codec_ctx->height,converted_frame->data,converted_frame->linesize);
	      if (ffmpeg_pixfmt==PIX_FMT_RGB24) {
		CImg<ucharT> next_image(*converted_frame->data,3,codec_ctx->width,codec_ctx->height,1,true);
		next_image._get_permute_axes("yzcx",foo).move_to(*this);
	      } else {
		CImg<ucharT> next_image(*converted_frame->data,1,codec_ctx->width,codec_ctx->height,1,true);
		next_image._get_permute_axes("yzcx",foo).move_to(*this);
	      }
	      next_frame+=nstep_frame;
	    }
	    ++frame;
	  }
	  av_free_packet(&packet);
	  if (next_frame>nlast_frame) break;
	}
      }
      delete[] buffer;
#endif
# 44960 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      return *this;
    }

    //! Load an image from a video file, using ffmpeg libraries \newinstance.
    static CImgList<T> get_load_ffmpeg(const char *const filename, const unsigned int first_frame=0, const unsigned int last_frame=~0U,
				       const unsigned int step_frame=1, const bool pixel_format=true) {
      return CImgList<T>().load_ffmpeg(filename,first_frame,last_frame,step_frame,pixel_format);
    }

    //! Load an image from a video file using the external tool 'ffmpeg'.
    /**
      \param filename Filename to read data from.
    **/
    CImgList<T>& load_ffmpeg_external(const char *const filename) {
      if (!filename)
        throw CImgArgumentException(_cimglist_instance
                                    "load_ffmpeg_external(): Specified filename is (null).",
                                    cimglist_instance);
      std::fclose(cimg::fopen(filename,"rb"));            // Check if file exists.
      char command[1024] = { 0 }, filetmp[512] = { 0 }, filetmp2[512] = { 0 };
      std::FILE *file = 0;
      do {
        cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand());
        cimg_snprintf(filetmp2,sizeof(filetmp2),"%s_000001.ppm",filetmp);
        if ((file=std::fopen(filetmp2,"rb"))!=0) cimg::fclose(file);
      } while (file);
      cimg_snprintf(filetmp2,sizeof(filetmp2),"%s_%%6d.ppm",filetmp);
#if cimg_OS!=2
      cimg_snprintf(command,sizeof(command),"%s -i \"%s\" \"%s\" >/dev/null 2>&1",
                    cimg::ffmpeg_path(),
                    CImg<charT>::string(filename)._system_strescape().data(),
                    CImg<charT>::string(filetmp2)._system_strescape().data());
#else
# 44993 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      cimg_snprintf(command,sizeof(command),"\"%s -i \"%s\" \"%s\"\" >NUL 2>&1",
                    cimg::ffmpeg_path(),
                    CImg<charT>::string(filename)._system_strescape().data(),
                    CImg<charT>::string(filetmp2)._system_strescape().data());
#endif
# 44998 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      cimg::system(command,0);
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      assign();
      unsigned int i = 1;
      for (bool stop_flag = false; !stop_flag; ++i) {
        cimg_snprintf(filetmp2,sizeof(filetmp2),"%s_%.6u.ppm",filetmp,i);
        CImg<T> img;
        try { img.load_pnm(filetmp2); }
        catch (CImgException&) { stop_flag = true; }
        if (img) { img.move_to(*this); std::remove(filetmp2); }
      }
      cimg::exception_mode() = omode;
      if (is_empty())
        throw CImgIOException(_cimglist_instance
                              "load_ffmpeg_external(): Failed to open file '%s' with external command 'ffmpeg'.",
                              cimglist_instance,
                              filename);
      return *this;
    }

    //! Load an image from a video file using the external tool 'ffmpeg' \newinstance.
    static CImgList<T> get_load_ffmpeg_external(const char *const filename) {
      return CImgList<T>().load_ffmpeg_external(filename);
    }

    //! Load gif file, using ImageMagick or GraphicsMagick's external tools.
    /**
      \param filename Filename to read data from.
      \param use_graphicsmagick Tells if GraphicsMagick's tool 'gm' is used instead of ImageMagick's tool 'convert'.
    **/
    CImgList<T>& load_gif_external(const char *const filename) {
      if (!filename)
        throw CImgArgumentException(_cimglist_instance
                                    "load_gif_external(): Specified filename is (null).",
                                    cimglist_instance);
      std::fclose(cimg::fopen(filename,"rb"));            // Check if file exists.
      if (!_load_gif_external(filename,false))
        if (!_load_gif_external(filename,true))
          try { assign(CImg<T>().load_other(filename)); } catch (CImgException&) { assign(); }
      if (is_empty())
        throw CImgIOException(_cimglist_instance
                              "load_gif_external(): Failed to open file '%s'.",
                              cimglist_instance,filename);
      return *this;
    }

    CImgList<T>& _load_gif_external(const char *const filename, const bool use_graphicsmagick=false) {
      char command[1024] = { 0 }, filetmp[512] = { 0 }, filetmp2[512] = { 0 };
      std::FILE *file = 0;
      do {
        cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand());
        if (use_graphicsmagick) cimg_snprintf(filetmp2,sizeof(filetmp2),"%s.png.0",filetmp);
        else cimg_snprintf(filetmp2,sizeof(filetmp2),"%s-0.png",filetmp);
        if ((file=std::fopen(filetmp2,"rb"))!=0) cimg::fclose(file);
      } while (file);
#if cimg_OS!=2
      if (use_graphicsmagick) cimg_snprintf(command,sizeof(command),"%s convert \"%s\" \"%s.png\" >/dev/null 2>&1",
                                            cimg::graphicsmagick_path(),
                                            CImg<charT>::string(filename)._system_strescape().data(),
                                            CImg<charT>::string(filetmp)._system_strescape().data());
      else cimg_snprintf(command,sizeof(command),"%s \"%s\" \"%s.png\" >/dev/null 2>&1",
                         cimg::imagemagick_path(),
                         CImg<charT>::string(filename)._system_strescape().data(),
                         CImg<charT>::string(filetmp)._system_strescape().data());
#else
# 45064 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      if (use_graphicsmagick) cimg_snprintf(command,sizeof(command),"\"%s convert \"%s\" \"%s.png\"\" >NUL 2>&1",
                                            cimg::graphicsmagick_path(),
                                            CImg<charT>::string(filename)._system_strescape().data(),
                                            CImg<charT>::string(filetmp)._system_strescape().data());
      else cimg_snprintf(command,sizeof(command),"\"%s \"%s\" \"%s.png\"\" >NUL 2>&1",
                         cimg::imagemagick_path(),
                         CImg<charT>::string(filename)._system_strescape().data(),
                         CImg<charT>::string(filetmp)._system_strescape().data());
#endif
# 45073 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      cimg::system(command,0);
      const unsigned int omode = cimg::exception_mode();
      cimg::exception_mode() = 0;
      assign();

      // Try to read a single frame gif.
      cimg_snprintf(filetmp2,sizeof(filetmp2),"%s.png",filetmp);
      CImg<T> img;
      try { img.load_png(filetmp2); }
      catch (CImgException&) { }
      if (img) { img.move_to(*this); std::remove(filetmp2); }
      else { // Try to read animated gif.
        unsigned int i = 0;
        for (bool stop_flag = false; !stop_flag; ++i) {
          if (use_graphicsmagick) cimg_snprintf(filetmp2,sizeof(filetmp2),"%s.png.%u",filetmp,i);
          else cimg_snprintf(filetmp2,sizeof(filetmp2),"%s-%u.png",filetmp,i);
          CImg<T> img;
          try { img.load_png(filetmp2); }
          catch (CImgException&) { stop_flag = true; }
          if (img) { img.move_to(*this); std::remove(filetmp2); }
        }
      }
      cimg::exception_mode() = omode;
      return *this;
    }

    //! Load gif file, using ImageMagick or GraphicsMagick's external tools \newinstance.
    static CImgList<T> get_load_gif_external(const char *const filename) {
      return CImgList<T>().load_gif_external(filename);
    }

    //! Load a gzipped list, using external tool 'gunzip'.
    /**
      \param filename Filename to read data from.
    **/
    CImgList<T>& load_gzip_external(const char *const filename) {
      if (!filename)
        throw CImgIOException(_cimglist_instance
                              "load_gzip_external(): Specified filename is (null).",
                              cimglist_instance);
      std::fclose(cimg::fopen(filename,"rb"));            // Check if file exists.
      char command[1024] = { 0 }, filetmp[512] = { 0 }, body[512] = { 0 };
      const char
        *ext = cimg::split_filename(filename,body),
        *ext2 = cimg::split_filename(body,0);
      std::FILE *file = 0;
      do {
        if (!cimg::strcasecmp(ext,"gz")) {
          if (*ext2) cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s.%s",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand(),ext2);
          else cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand());
        } else {
          if (*ext) cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s.%s",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand(),ext);
          else cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand());
        }
        if ((file=std::fopen(filetmp,"rb"))!=0) cimg::fclose(file);
      } while (file);
      cimg_snprintf(command,sizeof(command),"%s -c \"%s\" > \"%s\"",
                    cimg::gunzip_path(),
                    CImg<charT>::string(filename)._system_strescape().data(),
                    CImg<charT>::string(filetmp)._system_strescape().data());
      cimg::system(command);
      if (!(file = std::fopen(filetmp,"rb"))) {
        cimg::fclose(cimg::fopen(filename,"r"));
        throw CImgIOException(_cimglist_instance
                              "load_gzip_external(): Failed to open file '%s'.",
                              cimglist_instance,
                              filename);

      } else cimg::fclose(file);
      load(filetmp);
      std::remove(filetmp);
      return *this;
    }

    //! Load a gzipped list, using external tool 'gunzip' \newinstance.
    static CImgList<T> get_load_gzip_external(const char *const filename) {
      return CImgList<T>().load_gzip_external(filename);
    }

    //! Load a 3d object from a .OFF file.
    /**
      \param filename Filename to read data from.
      \param[out] primitives At return, contains the list of 3d object primitives.
      \param[out] colors At return, contains the list of 3d object colors.
      \return List of 3d object vertices.
    **/
    template<typename tf, typename tc>
    CImgList<T>& load_off(const char *const filename,
			  CImgList<tf>& primitives, CImgList<tc>& colors) {
      return get_load_off(filename,primitives,colors).move_to(*this);
    }

    //! Load a 3d object from a .OFF file \newinstance.
    template<typename tf, typename tc>
      static CImgList<T> get_load_off(const char *const filename,
                                      CImgList<tf>& primitives, CImgList<tc>& colors) {
      return CImg<T>().load_off(filename,primitives,colors)<'x';
    }

    //! Load images from a TIFF file.
    /**
        \param filename Filename to read data from.
        \param first_frame Index of first image frame to read.
        \param last_frame Index of last image frame to read.
        \param step_frame Step applied between each frame.
    **/
    CImgList<T>& load_tiff(const char *const filename,
			   const unsigned int first_frame=0, const unsigned int last_frame=~0U,
			   const unsigned int step_frame=1) {
      const unsigned int
	nfirst_frame = first_frame<last_frame?first_frame:last_frame,
	nstep_frame = step_frame?step_frame:1;
      unsigned int nlast_frame = first_frame<last_frame?last_frame:first_frame;
#ifndef cimg_use_tiff
      if (nfirst_frame || nlast_frame!=~0U || nstep_frame!=1)
        throw CImgArgumentException(_cimglist_instance
                                    "load_tiff(): Unable to load sub-images from file '%s' unless libtiff is enabled.",
                                    cimglist_instance,
                                    filename);

      return assign(CImg<T>::get_load_tiff(filename));
#else
# 45195 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      TIFF *tif = TIFFOpen(filename,"r");
      if (tif) {
        unsigned int nb_images = 0;
        do ++nb_images; while (TIFFReadDirectory(tif));
        if (nfirst_frame>=nb_images || (nlast_frame!=~0U && nlast_frame>=nb_images))
          cimg::warn(_cimglist_instance
                     "load_tiff(): Invalid specified frame range is [%u,%u] (step %u) since file '%s' contains %u image(s).",
                     cimglist_instance,
                     nfirst_frame,nlast_frame,nstep_frame,filename,nb_images);

        if (nfirst_frame>=nb_images) return assign();
        if (nlast_frame>=nb_images) nlast_frame = nb_images-1;
        assign(1+(nlast_frame-nfirst_frame)/nstep_frame);
        TIFFSetDirectory(tif,0);
#if cimg_verbosity>=3
        TIFFSetWarningHandler(0);
        TIFFSetErrorHandler(0);
#endif
# 45213 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
        cimglist_for(*this,l) _data[l]._load_tiff(tif,nfirst_frame + l*nstep_frame);
        TIFFClose(tif);
      } else throw CImgIOException(_cimglist_instance
                                   "load_tiff(): Failed to open file '%s'.",
                                   cimglist_instance,
                                   filename);
      return *this;
#endif
# 45221 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    }

    //! Load a multi-page TIFF file \newinstance.
    static CImgList<T> get_load_tiff(const char *const filename,
				     const unsigned int first_frame=0, const unsigned int last_frame=~0U,
				     const unsigned int step_frame=1) {
      return CImgList<T>().load_tiff(filename,first_frame,last_frame,step_frame);
    }

    //@}
    //----------------------------------
    //
    //! \name Data Output
    //@{
    //----------------------------------

    //! Print informations about the list on the standard output.
    /**
      \param title Label set to the informations displayed.
      \param display_stats Tells if image statistics must be computed and displayed.
    **/
    const CImgList<T>& print(const char *const title=0, const bool display_stats=true) const {
      unsigned int msiz = 0;
      cimglist_for(*this,l) msiz+=_data[l].size();
      msiz*=sizeof(T);
      const unsigned int mdisp = msiz<8*1024?0:(msiz<8*1024*1024?1:2);
      char _title[64] = { 0 };
      if (!title) cimg_snprintf(_title,sizeof(_title),"CImgList<%s>",pixel_type());
      std::fprintf(cimg::output(),"%s%s%s%s: %sthis%s = %p, %ssize%s = %u/%u [%u %s], %sdata%s = (CImg<%s>*)%p",
                   cimg::t_magenta,cimg::t_bold,title?title:_title,cimg::t_normal,
                   cimg::t_bold,cimg::t_normal,(void*)this,
                   cimg::t_bold,cimg::t_normal,_width,_allocated_width,
                   mdisp==0?msiz:(mdisp==1?(msiz>>10):(msiz>>20)),
                   mdisp==0?"b":(mdisp==1?"Kio":"Mio"),
                   cimg::t_bold,cimg::t_normal,pixel_type(),(void*)begin());
      if (_data) std::fprintf(cimg::output(),"..%p.\n",(void*)((char*)end()-1));
      else std::fprintf(cimg::output(),".\n");

      char tmp[16] = { 0 };
      cimglist_for(*this,ll) {
        cimg_snprintf(tmp,sizeof(tmp),"[%d]",ll);
        std::fprintf(cimg::output(),"  ");
        _data[ll].print(tmp,display_stats);
        if (ll==3 && _width>8) { ll = _width-5; std::fprintf(cimg::output(),"  ...\n"); }
      }
      std::fflush(cimg::output());
      return *this;
    }

    //! Display the current CImgList instance in an existing CImgDisplay window (by reference).
    /**
       \param disp Reference to an existing CImgDisplay instance, where the current image list will be displayed.
       \param axis Appending axis. Can be <tt>{ 'x' | 'y' | 'z' | 'c' }</tt>.
       \param align Appending alignmenet.
       \note This function displays the list images of the current CImgList instance into an existing CImgDisplay window.
       Images of the list are appended in a single temporarly image for visualization purposes.
       The function returns immediately.
    **/
    const CImgList<T>& display(CImgDisplay &disp, const char axis='x', const float align=0) const {
      get_append(axis,align).display(disp);
      return *this;
    }

    //! Display the current CImgList instance in a new display window.
    /**
        \param disp Display window.
        \param display_info Tells if image informations are displayed on the standard output.
       \param axis Alignment axis for images viewing.
       \param align Apending alignment.
       \note This function opens a new window with a specific title and displays the list images of the current CImgList instance into it.
       Images of the list are appended in a single temporarly image for visualization purposes.
       The function returns when a key is pressed or the display window is closed by the user.
    **/
    const CImgList<T>& display(CImgDisplay &disp, const bool display_info,
                               const char axis='x', const float align=0,
                               unsigned int *const XYZ=0) const {
      bool is_exit = false;
      return _display(disp,0,display_info,axis,align,XYZ,0,true,is_exit);
    }

    //! Display the current CImgList instance in a new display window.
    /**
      \param title Title of the opening display window.
      \param display_info Tells if list informations must be written on standard output.
      \param axis Appending axis. Can be <tt>{ 'x' | 'y' | 'z' | 'c' }</tt>.
      \param align Appending alignment.
    **/
    const CImgList<T>& display(const char *const title=0, const bool display_info=true,
                               const char axis='x', const float align=0,
                               unsigned int *const XYZ=0) const {
      CImgDisplay disp;
      bool is_exit = false;
      return _display(disp,title,display_info,axis,align,XYZ,0,true,is_exit);
    }

    const CImgList<T>& _display(CImgDisplay &disp, const char *const title, const bool display_info,
                                const char axis, const float align, unsigned int *const XYZ,
                                const unsigned int orig, const bool is_first_call, bool &is_exit) const {
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "display(): Empty instance.",
                                    cimglist_instance);
      if (!disp) {
        if (axis=='x') {
          unsigned int sum_width = 0, max_height = 0;
          cimglist_for(*this,l) {
            const CImg<T> &img = _data[l];
            const unsigned int
              w = CImgDisplay::_fitscreen(img._width,img._height,img._depth,128,-85,false),
              h = CImgDisplay::_fitscreen(img._width,img._height,img._depth,128,-85,true);
            sum_width+=w;
            if (h>max_height) max_height = h;
          }
          disp.assign(cimg_fitscreen(sum_width,max_height,1),title?title:0,1);
        } else {
          unsigned int max_width = 0, sum_height = 0;
          cimglist_for(*this,l) {
            const CImg<T> &img = _data[l];
            const unsigned int
              w = CImgDisplay::_fitscreen(img._width,img._height,img._depth,128,-85,false),
              h = CImgDisplay::_fitscreen(img._width,img._height,img._depth,128,-85,true);
            if (w>max_width) max_width = w;
            sum_height+=h;
          }
          disp.assign(cimg_fitscreen(max_width,sum_height,1),title?title:0,1);
        }
        if (!title) disp.set_title("CImgList<%s> (%u)",pixel_type(),_width);
      } else if (title) disp.set_title("%s",title);
      const CImg<char> dtitle = CImg<char>::string(disp.title());
      if (display_info) print(disp.title());
      disp.show().flush();

      if (_width==1) {
        const unsigned int dw = disp._width, dh = disp._height;
        if (!is_first_call)
          disp.resize(cimg_fitscreen(_data[0]._width,_data[0]._height,_data[0]._depth),false).
            set_title("%s (%ux%ux%ux%u)",dtitle.data(),_data[0]._width,_data[0]._height,_data[0]._depth,_data[0]._spectrum);
        _data[0]._display(disp,0,false,XYZ,!is_first_call);
        if (disp.key()) is_exit = true;
        disp.resize(cimg_fitscreen(dw,dh,1),false).set_title("%s",dtitle.data());
      } else {
        bool disp_resize = !is_first_call;
        while (!disp.is_closed() && !is_exit) {
          const CImg<intT> s = _get_select(disp,0,true,axis,align,orig,disp_resize,!is_first_call,true);
          disp_resize = true;
          if (s[0]<0) { // No selections done.
            if (disp.button()&2) { disp.flush(); break; }
            is_exit = true;
          } else if (disp.wheel()) { // Zoom in/out.
            const int wheel = disp.wheel();
            disp.set_wheel();
            if (!is_first_call && wheel<0) break;
            if (wheel>0 && _width>=4) {
              const unsigned int
                delta = cimg::max(1U,(unsigned int)cimg::round(0.3*_width)),
                ind0 = (unsigned int)cimg::max(0,s[0] - (int)delta),
                ind1 = (unsigned int)cimg::min(width() - 1,s[0] + (int)delta);
              if ((ind0!=0 || ind1!=_width-1) && ind1 - ind0>=3) get_shared_images(ind0,ind1)._display(disp,0,false,axis,align,XYZ,orig + ind0,false,is_exit);
            }
          } else if (s[0]!=0 || s[1]!=width()-1) get_shared_images(s[0],s[1])._display(disp,0,false,axis,align,XYZ,orig+s[0],false,is_exit);
        }
      }
      return *this;
    }

    //! Save list into a file.
    /**
      \param filename Filename to write data to.
      \param number When positive, represents an index added to the filename. Otherwise, no number is added.
      \param digits Number of digits used for adding the number to the filename.
    **/
    const CImgList<T>& save(const char *const filename, const int number=-1, const unsigned int digits=6) const {
      if (!filename)
        throw CImgArgumentException(_cimglist_instance
                                    "save(): Specified filename is (null).",
                                    cimglist_instance);
      // Do not test for empty instances, since .cimg format is able to manage empty instances.
      const char *const ext = cimg::split_filename(filename);
      char nfilename[1024] = { 0 };
      const char *const fn = (number>=0)?cimg::number_filename(filename,number,digits,nfilename):filename;

#ifdef cimglist_save_plugin
      cimglist_save_plugin(fn);
#endif
# 45405 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_save_plugin1
      cimglist_save_plugin1(fn);
#endif
# 45408 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_save_plugin2
      cimglist_save_plugin2(fn);
#endif
# 45411 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_save_plugin3
      cimglist_save_plugin3(fn);
#endif
# 45414 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_save_plugin4
      cimglist_save_plugin4(fn);
#endif
# 45417 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_save_plugin5
      cimglist_save_plugin5(fn);
#endif
# 45420 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_save_plugin6
      cimglist_save_plugin6(fn);
#endif
# 45423 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_save_plugin7
      cimglist_save_plugin7(fn);
#endif
# 45426 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef cimglist_save_plugin8
      cimglist_save_plugin8(fn);
#endif
# 45429 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      if (!cimg::strcasecmp(ext,"cimgz")) return save_cimg(fn,true);
      else if (!cimg::strcasecmp(ext,"cimg") || !*ext) return save_cimg(fn,false);
      else if (!cimg::strcasecmp(ext,"yuv")) return save_yuv(fn,true);
      else if (!cimg::strcasecmp(ext,"avi") ||
               !cimg::strcasecmp(ext,"mov") ||
               !cimg::strcasecmp(ext,"asf") ||
               !cimg::strcasecmp(ext,"divx") ||
               !cimg::strcasecmp(ext,"flv") ||
               !cimg::strcasecmp(ext,"mpg") ||
               !cimg::strcasecmp(ext,"m1v") ||
               !cimg::strcasecmp(ext,"m2v") ||
               !cimg::strcasecmp(ext,"m4v") ||
               !cimg::strcasecmp(ext,"mjp") ||
               !cimg::strcasecmp(ext,"mkv") ||
               !cimg::strcasecmp(ext,"mpe") ||
               !cimg::strcasecmp(ext,"movie") ||
               !cimg::strcasecmp(ext,"ogm") ||
               !cimg::strcasecmp(ext,"ogg") ||
               !cimg::strcasecmp(ext,"qt") ||
               !cimg::strcasecmp(ext,"rm") ||
               !cimg::strcasecmp(ext,"vob") ||
               !cimg::strcasecmp(ext,"wmv") ||
               !cimg::strcasecmp(ext,"xvid") ||
               !cimg::strcasecmp(ext,"mpeg")) return save_ffmpeg(fn);
#ifdef cimg_use_tiff
      else if (!cimg::strcasecmp(ext,"tif") ||
          !cimg::strcasecmp(ext,"tiff")) return save_tiff(fn);
#endif
# 45457 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      else if (!cimg::strcasecmp(ext,"gz")) return save_gzip_external(fn);
      else { if (_width==1) _data[0].save(fn,-1); else cimglist_for(*this,l) _data[l].save(fn,l); }
      return *this;
    }

    //! Tell if an image list can be saved as one single file.
    /**
       \param filename Filename, as a C-string.
       \return \c true if the file format supports multiple images, \c false otherwise.
    **/
    static bool is_saveable(const char *const filename) {
      const char *const ext = cimg::split_filename(filename);
      if (!cimg::strcasecmp(ext,"cimgz") ||
#ifdef cimg_use_tiff
          !cimg::strcasecmp(ext,"tif") ||
          !cimg::strcasecmp(ext,"tiff") ||
#endif
# 45474 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
          !cimg::strcasecmp(ext,"yuv") ||
          !cimg::strcasecmp(ext,"avi") ||
          !cimg::strcasecmp(ext,"mov") ||
          !cimg::strcasecmp(ext,"asf") ||
          !cimg::strcasecmp(ext,"divx") ||
          !cimg::strcasecmp(ext,"flv") ||
          !cimg::strcasecmp(ext,"mpg") ||
          !cimg::strcasecmp(ext,"m1v") ||
          !cimg::strcasecmp(ext,"m2v") ||
          !cimg::strcasecmp(ext,"m4v") ||
          !cimg::strcasecmp(ext,"mjp") ||
          !cimg::strcasecmp(ext,"mkv") ||
          !cimg::strcasecmp(ext,"mpe") ||
          !cimg::strcasecmp(ext,"movie") ||
          !cimg::strcasecmp(ext,"ogm") ||
          !cimg::strcasecmp(ext,"ogg") ||
          !cimg::strcasecmp(ext,"qt") ||
          !cimg::strcasecmp(ext,"rm") ||
          !cimg::strcasecmp(ext,"vob") ||
          !cimg::strcasecmp(ext,"wmv") ||
          !cimg::strcasecmp(ext,"xvid") ||
          !cimg::strcasecmp(ext,"mpeg")) return true;
      return false;
    }

    //! Save image sequence as a GIF animated file.
    /**
       \param filename Filename to write data to.
       \param fps Number of desired frames per second.
       \param nb_loops Number of loops (\c 0 for infinite looping).
    **/
    const CImgList<T>& save_gif_external(const char *const filename, const unsigned int fps=25, const unsigned int nb_loops=0) {
      char command[1024] = { 0 }, filetmp[512] = { 0 }, filetmp2[512] = { 0 };
      CImgList<charT> filenames;
      std::FILE *file = 0;

#ifdef cimg_use_png
#define _cimg_save_gif_ext "png"
#else
# 45513 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#define _cimg_save_gif_ext "ppm"
#endif
# 45515 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

      do {
        cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand());
        cimg_snprintf(filetmp2,sizeof(filetmp2),"%s_000001." _cimg_save_gif_ext,filetmp);
        if ((file=std::fopen(filetmp2,"rb"))!=0) cimg::fclose(file);
      } while (file);
      cimglist_for(*this,l) {
        cimg_snprintf(filetmp2,sizeof(filetmp2),"%s_%.6u." _cimg_save_gif_ext,filetmp,l+1);
        CImg<charT>::string(filetmp2).move_to(filenames);
        if (_data[l]._depth>1 || _data[l]._spectrum!=3) _data[l].get_resize(-100,-100,1,3).save(filetmp2);
        else _data[l].save(filetmp2);
      }

#if cimg_OS!=2
      cimg_snprintf(command,sizeof(command),"%s -delay 1x%u -loop %u",
                    cimg::imagemagick_path(),fps,nb_loops);
      CImg<ucharT>::string(command).move_to(filenames,0);
      cimg_snprintf(command,sizeof(command),"\"%s\" >/dev/null 2>&1",
                    CImg<charT>::string(filename)._system_strescape().data());
      CImg<ucharT>::string(command).move_to(filenames);
#else
# 45536 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      cimg_snprintf(command,sizeof(command),"\"%s -delay 1x%u -loop %u",
                    cimg::imagemagick_path(),fps,nb_loops);
      CImg<ucharT>::string(command).move_to(filenames,0);
      cimg_snprintf(command,sizeof(command),"\"%s\"\" >NUL 2>&1",
                    CImg<charT>::string(filename)._system_strescape().data());
      CImg<ucharT>::string(command).move_to(filenames);
#endif
# 45543 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      CImg<charT> _command = filenames>'x';
      cimg_for(_command,p,char) if (!*p) *p = ' ';
      _command.back() = 0;

      cimg::system(_command);
      file = std::fopen(filename,"rb");
      if (!file)
        throw CImgIOException(_cimglist_instance
                              "save_gif_external(): Failed to save file '%s' with external command 'convert'.",
                              cimglist_instance,
                              filename);
      else cimg::fclose(file);
      cimglist_for_in(*this,1,filenames._width-1,l) std::remove(filenames[l]);
      return *this;
    }

    //! Save image sequence, using FFMPEG library.
    /**
      \param filename Filename to write data to.
      \param fps Desired framerate (in frames per seconds) if chosen format supports it.
      \param bitrate Desired bitrate (in bits per seconds) if chosen format supports it.
    **/
    // This piece of code has been originally written by David. G. Starkweather.
    const CImgList<T>& save_ffmpeg(const char *const filename, const unsigned int fps=25, const unsigned int bitrate=2048) const {
      if (!filename)
        throw CImgArgumentException(_cimglist_instance
                                    "save_ffmpeg(): Specified filename is (null).",
                                    cimglist_instance);
      if (!fps)
        throw CImgArgumentException(_cimglist_instance
                                    "save_ffmpeg(): Invalid specified framerate 0, for file '%s'.",
                                    cimglist_instance,
                                    filename);
      if (is_empty()) { cimg::fempty(0,filename); return *this; }

      cimglist_for(*this,l) if (!_data[l].is_sameXYZ(_data[0]))
        throw CImgInstanceException(_cimglist_instance
                                    "save_ffmpeg(): Invalid instance dimensions, for file '%s'.",
                                    cimglist_instance,
                                    filename);

#ifndef cimg_use_ffmpeg
      return save_ffmpeg_external(filename,0,fps,bitrate);
#else
# 45587 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      avcodec_register_all();
      av_register_all();
      const int
        frame_dimx = _data[0].width(),
        frame_dimy = _data[0].height(),
        frame_dimv = _data[0].spectrum();
      if (frame_dimv!=1 && frame_dimv!=3)
	throw CImgInstanceException(_cimglist_instance
                                    "save_ffmpeg(): Image[0] (%u,%u,%u,%u,%p) has not 1 or 3 channels, for file '%s'.",
                                    cimglist_instance,
                                    _data[0]._width,_data[0]._height,_data[0]._depth,_data[0]._spectrum,_data,filename);

      PixelFormat dest_pxl_fmt = PIX_FMT_YUV420P;
      PixelFormat src_pxl_fmt  = (frame_dimv==3)?PIX_FMT_RGB24:PIX_FMT_GRAY8;

      int sws_flags = SWS_FAST_BILINEAR; // Interpolation method (keeping same size images for now).
      AVOutputFormat *fmt = 0;
#if defined(AV_VERSION_INT)
#if LIBAVFORMAT_VERSION_INT<AV_VERSION_INT(52,45,0)
      fmt = guess_format(0,filename,0);
      if (!fmt) fmt = guess_format("mpeg",0,0); // Default format "mpeg".
#else
# 45609 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      fmt = av_guess_format(0,filename,0);
      if (!fmt) fmt = av_guess_format("mpeg",0,0); // Default format "mpeg".
#endif
# 45612 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#else
# 45613 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      fmt = guess_format(0,filename,0);
      if (!fmt) fmt = guess_format("mpeg",0,0); // Default format "mpeg".
#endif
# 45616 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

      if (!fmt)
        throw CImgArgumentException(_cimglist_instance
                                    "save_ffmpeg(): Unable to determine codec for file '%s'.",
                                    cimglist_instance,
                                    filename);

      AVFormatContext *oc = 0;
#if defined(AV_VERSION_INT)
#if LIBAVFORMAT_VERSION_INT<AV_VERSION_INT(52,36,0)
      oc = av_alloc_format_context();
#else
# 45628 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      oc = avformat_alloc_context();
#endif
# 45630 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#else
# 45631 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      oc = av_alloc_format_context();
#endif
# 45633 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      if (!oc) // Failed to allocate format context.
        throw CImgIOException(_cimglist_instance
                              "save_ffmpeg(): Failed to allocate FFMPEG structure for format context, for file '%s'.",
                              cimglist_instance,
                              filename);

      AVCodec *codec = 0;
      AVFrame *picture = 0;
      AVFrame *tmp_pict = 0;
      oc->oformat = fmt;
      std::sprintf(oc->filename,"%s",filename);

      // Add video stream.
      AVStream *video_str = 0;
      if (fmt->video_codec!=CODEC_ID_NONE) {
	video_str = avformat_new_stream(oc,NULL);
	if (!video_str) { // Failed to allocate stream.
          av_free(oc);
          throw CImgIOException(_cimglist_instance
                                "save_ffmpeg(): Failed to allocate FFMPEG structure for video stream, for file '%s'.",
                                cimglist_instance,
                                filename);
	}
      } else { // No codec identified.
        av_free(oc);
	throw CImgIOException(_cimglist_instance
                              "save_ffmpeg(): Failed to identify proper codec, for file '%s'.",
                              cimglist_instance,
                              filename);
      }

      AVCodecContext *c = video_str->codec;
      c->codec_id = fmt->video_codec;
      c->codec_type = AVMEDIA_TYPE_VIDEO;
      c->bit_rate = 1024*bitrate;
      c->width = frame_dimx;
      c->height = frame_dimy;
      c->time_base.num = 1;
      c->time_base.den = fps;
      c->gop_size = 12;
      c->pix_fmt = dest_pxl_fmt;
      if (c->codec_id==CODEC_ID_MPEG2VIDEO) c->max_b_frames = 2;
      if (c->codec_id==CODEC_ID_MPEG1VIDEO) c->mb_decision = 2;

      // Open codecs and alloc buffers.
      codec = avcodec_find_encoder(c->codec_id);
      if (!codec) { // Failed to find codec.
        av_free(oc);
        throw CImgIOException(_cimglist_instance
                              "save_ffmpeg(): No valid codec found for file '%s'.",
                              cimglist_instance,
                              filename);
      }
      if (avcodec_open2(c,codec,NULL)<0) // Failed to open codec.
	throw CImgIOException(_cimglist_instance
                              "save_ffmpeg(): Failed to open codec for file '%s'.",
                              cimglist_instance,
                              filename);

      tmp_pict = avcodec_alloc_frame();
      if (!tmp_pict) { // Failed to allocate memory for tmp_pict frame.
        avcodec_close(video_str->codec);
        av_free(oc);
        throw CImgIOException(_cimglist_instance
                              "save_ffmpeg(): Failed to allocate memory for file '%s'.",
                              cimglist_instance,
                              filename);
      }
      tmp_pict->linesize[0] = (src_pxl_fmt==PIX_FMT_RGB24)?3*frame_dimx:frame_dimx;
      //      tmp_pict->type = FF_BUFFER_TYPE_USER;
      int tmp_size = avpicture_get_size(src_pxl_fmt,frame_dimx,frame_dimy);
      uint8_t *tmp_buffer = (uint8_t*)av_malloc(tmp_size);
      if (!tmp_buffer) { // Failed to allocate memory for tmp buffer.
        av_free(tmp_pict);
        avcodec_close(video_str->codec);
        av_free(oc);
        throw CImgIOException(_cimglist_instance
                              "save_ffmpeg(): Failed to allocate memory for file '%s'.",
                              cimglist_instance,
                              filename);
      }

      // Associate buffer with tmp_pict.
      avpicture_fill((AVPicture*)tmp_pict,tmp_buffer,src_pxl_fmt,frame_dimx,frame_dimy);
      picture = avcodec_alloc_frame();
      if (!picture) { // Failed to allocate picture frame.
        av_free(tmp_pict->data[0]);
        av_free(tmp_pict);
        avcodec_close(video_str->codec);
        av_free(oc);
        throw CImgIOException(_cimglist_instance
                              "save_ffmpeg(): Failed to allocate memory for file '%s'.",
                              cimglist_instance,
                              filename);
      }

      int size = avpicture_get_size(c->pix_fmt,frame_dimx,frame_dimy);
      uint8_t *buffer = (uint8_t*)av_malloc(size);
      if (!buffer) { // Failed to allocate picture frame buffer.
        av_free(picture);
        av_free(tmp_pict->data[0]);
        av_free(tmp_pict);
        avcodec_close(video_str->codec);
        av_free(oc);
        throw CImgIOException(_cimglist_instance
                              "save_ffmpeg(): Failed to allocate memory for file '%s'.",
                              cimglist_instance,
                              filename);
      }

      // Associate the buffer with picture.
      avpicture_fill((AVPicture*)picture,buffer,c->pix_fmt,frame_dimx,frame_dimy);

      // Open file.
      if (!(fmt->flags&AVFMT_NOFILE)) {
	if (avio_open(&oc->pb,filename,AVIO_FLAG_WRITE)<0)
          throw CImgIOException(_cimglist_instance
                                "save_ffmpeg(): Failed to open file '%s'.",
                                cimglist_instance,
                                filename);
      }

      if (avformat_write_header(oc,NULL)<0)
	throw CImgIOException(_cimglist_instance
                              "save_ffmpeg(): Failed to write header in file '%s'.",
                              cimglist_instance,
                              filename);

      SwsContext *img_convert_context = 0;
      img_convert_context = sws_getContext(frame_dimx,frame_dimy,src_pxl_fmt,
                                           c->width,c->height,c->pix_fmt,sws_flags,0,0,0);
      if (!img_convert_context) { // Failed to get swscale context.
        // if (!(fmt->flags & AVFMT_NOFILE)) url_fclose(&oc->pb);
        av_free(picture->data);
        av_free(picture);
        av_free(tmp_pict->data[0]);
        av_free(tmp_pict);
        avcodec_close(video_str->codec);
        av_free(oc);
        throw CImgIOException(_cimglist_instance
                              "save_ffmpeg(): Failed to get conversion context for file '%s'.",
                              cimglist_instance,
                              filename);
      }
      int ret = 0, out_size;
      uint8_t *video_outbuf = 0;
      int video_outbuf_size = 1000000;
      video_outbuf = (uint8_t*)av_malloc(video_outbuf_size);
      if (!video_outbuf) {
	// if (!(fmt->flags & AVFMT_NOFILE)) url_fclose(&oc->pb);
	av_free(picture->data);
        av_free(picture);
        av_free(tmp_pict->data[0]);
        av_free(tmp_pict);
        avcodec_close(video_str->codec);
        av_free(oc);
        throw CImgIOException(_cimglist_instance
                              "save_ffmpeg(): Failed to allocate memory, for file '%s'.",
                              cimglist_instance,
                              filename);
      }

      // Loop through each desired image in list.
      cimglist_for(*this,i) {
        CImg<uint8_t> currentIm = _data[i], red, green, blue, gray;
        if (src_pxl_fmt==PIX_FMT_RGB24) {
          red = currentIm.get_shared_channel(0);
          green = currentIm.get_shared_channel(1);
          blue = currentIm.get_shared_channel(2);
          cimg_forXY(currentIm,X,Y) { // Assign pizel values to data buffer in interlaced RGBRGB ... format.
            tmp_pict->data[0][Y*tmp_pict->linesize[0] + 3*X] = red(X,Y);
            tmp_pict->data[0][Y*tmp_pict->linesize[0] + 3*X + 1] = green(X,Y);
            tmp_pict->data[0][Y*tmp_pict->linesize[0] + 3*X + 2] = blue(X,Y);
          }
        } else {
          gray = currentIm.get_shared_channel(0);
          cimg_forXY(currentIm,X,Y) tmp_pict->data[0][Y*tmp_pict->linesize[0] + X] = gray(X,Y);
        }
        if (!video_str) break;
        if (sws_scale(img_convert_context,tmp_pict->data,tmp_pict->linesize,0,c->height,picture->data,picture->linesize)<0) break;

        AVPacket pkt;
        int got_packet;
        av_init_packet(&pkt);
        out_size = avcodec_encode_video2(c,&pkt,picture,&got_packet);
        if (got_packet) {
          pkt.pts = av_rescale_q(c->coded_frame->pts,c->time_base,video_str->time_base);
          if (c->coded_frame->key_frame) pkt.flags|=AV_PKT_FLAG_KEY;
          pkt.stream_index = video_str->index;
          pkt.data = video_outbuf;
          pkt.size = out_size;
          ret = av_write_frame(oc,&pkt);
        } else if (out_size<0) break;
        if (ret) break; // Error occured in writing frame.
      }

      // Close codec.
      if (video_str) {
	avcodec_close(video_str->codec);
        av_free(picture->data[0]);
        av_free(picture);
        av_free(tmp_pict->data[0]);
        av_free(tmp_pict);
      }
      if (av_write_trailer(oc)<0)
	throw CImgIOException(_cimglist_instance
                              "save_ffmpeg(): Failed to write trailer for file '%s'.",
                              cimglist_instance,
                              filename);

      av_freep(&oc->streams[0]->codec);
      av_freep(&oc->streams[0]);
      if (!(fmt->flags&AVFMT_NOFILE)) {
        /*if (url_fclose(oc->pb)<0)
          throw CImgIOException(_cimglist_instance
                                "save_ffmpeg(): File '%s', failed to close file.",
                                cimglist_instance,
                                filename);
        */
      }
      av_free(oc);
      av_free(video_outbuf);
#endif
# 45856 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      return *this;
    }

    const CImgList<T>& _save_yuv(std::FILE *const file, const char *const filename, const bool is_rgb) const {
      if (!file && !filename)
        throw CImgArgumentException(_cimglist_instance
                                    "save_yuv(): Specified filename is (null).",
                                    cimglist_instance);
      if (is_empty()) { cimg::fempty(file,filename); return *this; }
      if ((*this)[0].width()%2 || (*this)[0].height()%2)
        throw CImgInstanceException(_cimglist_instance
                                    "save_yuv(): Invalid odd instance dimensions (%u,%u) for file '%s'.",
                                    cimglist_instance,
                                    (*this)[0].width(),(*this)[0].height(),
                                    filename?filename:"(FILE*)");

      std::FILE *const nfile = file?file:cimg::fopen(filename,"wb");
      cimglist_for(*this,l) {
        CImg<ucharT> YCbCr((*this)[l]);
        if (is_rgb) YCbCr.RGBtoYCbCr();
        cimg::fwrite(YCbCr._data,(unsigned long)YCbCr._width*YCbCr._height,nfile);
        cimg::fwrite(YCbCr.get_resize(YCbCr._width/2, YCbCr._height/2,1,3,3).data(0,0,0,1),
                     (unsigned long)YCbCr._width*YCbCr._height/2,nfile);
      }
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Save list as a YUV image sequence file.
    /**
      \param filename Filename to write data to.
      \param is_rgb Tells if the RGB to YUV conversion must be done for saving.
    **/
    const CImgList<T>& save_yuv(const char *const filename=0, const bool is_rgb=true) const {
      return _save_yuv(0,filename,is_rgb);
    }

    //! Save image sequence into a YUV file.
    /**
      \param file File to write data to.
      \param is_rgb Tells if the RGB to YUV conversion must be done for saving.
    **/
    const CImgList<T>& save_yuv(std::FILE *const file, const bool is_rgb=true) const {
      return _save_yuv(file,0,is_rgb);
    }

    const CImgList<T>& _save_cimg(std::FILE *const file, const char *const filename, const bool is_compressed) const {
      if (!file && !filename)
        throw CImgArgumentException(_cimglist_instance
                                    "save_cimg(): Specified filename is (null).",
                                    cimglist_instance);
#ifndef cimg_use_zlib
      if (is_compressed)
        cimg::warn(_cimglist_instance
                   "save_cimg(): Unable to save compressed data in file '%s' unless zlib is enabled, saving them uncompressed.",
                   cimglist_instance,
                   filename?filename:"(FILE*)");
#endif
# 45914 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      std::FILE *const nfile = file?file:cimg::fopen(filename,"wb");
      const char *const ptype = pixel_type(), *const etype = cimg::endianness()?"big":"little";
      if (std::strstr(ptype,"unsigned")==ptype) std::fprintf(nfile,"%u unsigned_%s %s_endian\n",_width,ptype+9,etype);
      else std::fprintf(nfile,"%u %s %s_endian\n",_width,ptype,etype);
      cimglist_for(*this,l) {
        const CImg<T>& img = _data[l];
        std::fprintf(nfile,"%u %u %u %u",img._width,img._height,img._depth,img._spectrum);
        if (img._data) {
          CImg<T> tmp;
          if (cimg::endianness()) { tmp = img; cimg::invert_endianness(tmp._data,tmp.size()); }
          const CImg<T>& ref = cimg::endianness()?tmp:img;
          bool failed_to_compress = true;
          if (is_compressed) {
#ifdef cimg_use_zlib
            const unsigned long siz = sizeof(T)*ref.size();
            unsigned long csiz = siz + siz/100 + 16;
            Bytef *const cbuf = new Bytef[csiz];
            if (compress(cbuf,&csiz,(Bytef*)ref._data,siz))
              cimg::warn(_cimglist_instance
                         "save_cimg(): Failed to save compressed data for file '%s', saving them uncompressed.",
                         cimglist_instance,
                         filename?filename:"(FILE*)");
            else {
              std::fprintf(nfile," #%lu\n",csiz);
              cimg::fwrite(cbuf,csiz,nfile);
              delete[] cbuf;
              failed_to_compress = false;
            }
#endif
# 45943 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
          }
          if (failed_to_compress) { // Write in a non-compressed way.
            std::fputc('\n',nfile);
            cimg::fwrite(ref._data,ref.size(),nfile);
          }
        } else std::fputc('\n',nfile);
      }
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Save list into a .cimg file.
    /**
       \param filename Filename to write data to.
       \param is_compressed Tells if data compression must be enabled.
    **/
    const CImgList<T>& save_cimg(const char *const filename, const bool is_compressed=false) const {
      return _save_cimg(0,filename,is_compressed);
    }

    //! Save list into a .cimg file.
    /**
       \param file File to write data to.
       \param is_compressed Tells if data compression must be enabled.
    **/
    const CImgList<T>& save_cimg(std::FILE *file, const bool is_compressed=false) const {
      return _save_cimg(file,0,is_compressed);
    }

    const CImgList<T>& _save_cimg(std::FILE *const file, const char *const filename,
                                 const unsigned int n0,
                                 const unsigned int x0, const unsigned int y0,
                                 const unsigned int z0, const unsigned int c0) const {
#define _cimg_save_cimg_case(Ts,Tss) \
      if (!saved && !cimg::strcasecmp(Ts,str_pixeltype)) { \
        for (unsigned int l = 0; l<lmax; ++l) { \
          j = 0; while((i=std::fgetc(nfile))!='\n') tmp[j++]=(char)i; tmp[j] = 0; \
          W = H = D = C = 0; \
          if (std::sscanf(tmp,"%u %u %u %u",&W,&H,&D,&C)!=4) \
            throw CImgIOException(_cimglist_instance \
                                  "save_cimg(): Invalid size (%u,%u,%u,%u) of image[%u], for file '%s'.", \
                                  cimglist_instance, \
                                  W,H,D,C,l,filename?filename:"(FILE*)"); \
          if (W*H*D*C>0) { \
            if (l<n0 || x0>=W || y0>=H || z0>=D || c0>=D) std::fseek(nfile,W*H*D*C*sizeof(Tss),SEEK_CUR); \
            else { \
              const CImg<T>& img = (*this)[l - n0]; \
              const T *ptrs = img._data; \
              const unsigned int \
                x1 = x0 + img._width - 1, \
                y1 = y0 + img._height - 1, \
                z1 = z0 + img._depth - 1, \
                c1 = c0 + img._spectrum - 1, \
                nx1 = x1>=W?W-1:x1, \
                ny1 = y1>=H?H-1:y1, \
                nz1 = z1>=D?D-1:z1, \
                nc1 = c1>=C?C-1:c1; \
              CImg<Tss> raw(1+nx1-x0); \
              const unsigned int skipvb = c0*W*H*D*sizeof(Tss); \
              if (skipvb) std::fseek(nfile,skipvb,SEEK_CUR); \
              for (unsigned int v = 1 + nc1 - c0; v; --v) { \
                const unsigned int skipzb = z0*W*H*sizeof(Tss); \
                if (skipzb) std::fseek(nfile,skipzb,SEEK_CUR); \
                for (unsigned int z = 1 + nz1 - z0; z; --z) { \
                  const unsigned int skipyb = y0*W*sizeof(Tss); \
                  if (skipyb) std::fseek(nfile,skipyb,SEEK_CUR); \
                  for (unsigned int y = 1 + ny1 - y0; y; --y) { \
                    const unsigned int skipxb = x0*sizeof(Tss); \
                    if (skipxb) std::fseek(nfile,skipxb,SEEK_CUR); \
                    raw.assign(ptrs, raw._width); \
                    ptrs+=img._width; \
                    if (endian) cimg::invert_endianness(raw._data,raw._width); \
                    cimg::fwrite(raw._data,raw._width,nfile); \
                    const unsigned int skipxe = (W - 1 - nx1)*sizeof(Tss); \
                    if (skipxe) std::fseek(nfile,skipxe,SEEK_CUR); \
                  } \
                  const unsigned int skipye = (H - 1 - ny1)*W*sizeof(Tss); \
                  if (skipye) std::fseek(nfile,skipye,SEEK_CUR); \
                } \
                const unsigned int skipze = (D - 1 - nz1)*W*H*sizeof(Tss); \
                if (skipze) std::fseek(nfile,skipze,SEEK_CUR); \
              } \
              const unsigned int skipve = (C - 1 - nc1)*W*H*D*sizeof(Tss); \
              if (skipve) std::fseek(nfile,skipve,SEEK_CUR); \
            } \
          } \
        } \
        saved = true; \
      }

      if (!file && !filename)
        throw CImgArgumentException(_cimglist_instance
                                    "save_cimg(): Specified filename is (null).",
                                    cimglist_instance);
      if (is_empty())
        throw CImgInstanceException(_cimglist_instance
                                    "save_cimg(): Empty instance, for file '%s'.",
                                    cimglist_instance,
                                    filename?filename:"(FILE*)");

      std::FILE *const nfile = file?file:cimg::fopen(filename,"rb+");
      bool saved = false, endian = cimg::endianness();
      char tmp[256] = { 0 }, str_pixeltype[256] = { 0 }, str_endian[256] = { 0 };
      unsigned int j, err, N, W, H, D, C;
      int i;
      j = 0; while((i=std::fgetc(nfile))!='\n' && i!=EOF && j<256) tmp[j++] = (char)i; tmp[j] = 0;
      err = std::sscanf(tmp,"%u%*c%255[A-Za-z_]%*c%255[sA-Za-z_ ]",&N,str_pixeltype,str_endian);
      if (err<2) {
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimglist_instance
                              "save_cimg(): CImg header not found in file '%s'.",
                              cimglist_instance,
                              filename?filename:"(FILE*)");
      }
      if (!cimg::strncasecmp("little",str_endian,6)) endian = false;
      else if (!cimg::strncasecmp("big",str_endian,3)) endian = true;
      const unsigned int lmax = cimg::min(N,n0+_width);
      _cimg_save_cimg_case("bool",bool);
      _cimg_save_cimg_case("unsigned_char",unsigned char);
      _cimg_save_cimg_case("uchar",unsigned char);
      _cimg_save_cimg_case("char",char);
      _cimg_save_cimg_case("unsigned_short",unsigned short);
      _cimg_save_cimg_case("ushort",unsigned short);
      _cimg_save_cimg_case("short",short);
      _cimg_save_cimg_case("unsigned_int",unsigned int);
      _cimg_save_cimg_case("uint",unsigned int);
      _cimg_save_cimg_case("int",int);
      _cimg_save_cimg_case("unsigned_long",unsigned long);
      _cimg_save_cimg_case("ulong",unsigned long);
      _cimg_save_cimg_case("long",long);
      _cimg_save_cimg_case("float",float);
      _cimg_save_cimg_case("double",double);
      if (!saved) {
        if (!file) cimg::fclose(nfile);
        throw CImgIOException(_cimglist_instance
                              "save_cimg(): Unsupported data type '%s' for file '%s'.",
                              cimglist_instance,
                              filename?filename:"(FILE*)",str_pixeltype);
      }
      if (!file) cimg::fclose(nfile);
      return *this;
    }

    //! Insert the image instance into into an existing .cimg file, at specified coordinates.
    /**
      \param filename Filename to write data to.
      \param n0 Starting index of images to write.
      \param x0 Starting X-coordinates of image regions to write.
      \param y0 Starting Y-coordinates of image regions to write.
      \param z0 Starting Z-coordinates of image regions to write.
      \param c0 Starting C-coordinates of image regions to write.
    **/
    const CImgList<T>& save_cimg(const char *const filename,
                                 const unsigned int n0,
                                 const unsigned int x0, const unsigned int y0,
                                 const unsigned int z0, const unsigned int c0) const {
      return _save_cimg(0,filename,n0,x0,y0,z0,c0);
    }

    //! Insert the image instance into into an existing .cimg file, at specified coordinates.
    /**
      \param file File to write data to.
      \param n0 Starting index of images to write.
      \param x0 Starting X-coordinates of image regions to write.
      \param y0 Starting Y-coordinates of image regions to write.
      \param z0 Starting Z-coordinates of image regions to write.
      \param c0 Starting C-coordinates of image regions to write.
    **/
    const CImgList<T>& save_cimg(std::FILE *const file,
                                 const unsigned int n0,
                                 const unsigned int x0, const unsigned int y0,
                                 const unsigned int z0, const unsigned int c0) const {
      return _save_cimg(file,0,n0,x0,y0,z0,c0);
    }

    static void _save_empty_cimg(std::FILE *const file, const char *const filename,
                                const unsigned int nb,
                                const unsigned int dx, const unsigned int dy,
                                const unsigned int dz, const unsigned int dc) {
      std::FILE *const nfile = file?file:cimg::fopen(filename,"wb");
      const unsigned long siz = (unsigned long)dx*dy*dz*dc*sizeof(T);
      std::fprintf(nfile,"%u %s\n",nb,pixel_type());
      for (unsigned int i=nb; i; --i) {
        std::fprintf(nfile,"%u %u %u %u\n",dx,dy,dz,dc);
	for (unsigned long off=siz; off; --off) std::fputc(0,nfile);
      }
      if (!file) cimg::fclose(nfile);
    }

    //! Save empty (non-compressed) .cimg file with specified dimensions.
    /**
        \param filename Filename to write data to.
        \param nb Number of images to write.
        \param dx Width of images in the written file.
        \param dy Height of images in the written file.
        \param dz Depth of images in the written file.
        \param dc Spectrum of images in the written file.
    **/
    static void save_empty_cimg(const char *const filename,
                                const unsigned int nb,
                                const unsigned int dx, const unsigned int dy=1,
                                const unsigned int dz=1, const unsigned int dc=1) {
      return _save_empty_cimg(0,filename,nb,dx,dy,dz,dc);
    }

    //! Save empty .cimg file with specified dimensions.
    /**
        \param file File to write data to.
        \param nb Number of images to write.
        \param dx Width of images in the written file.
        \param dy Height of images in the written file.
        \param dz Depth of images in the written file.
        \param dc Spectrum of images in the written file.
    **/
    static void save_empty_cimg(std::FILE *const file,
                                const unsigned int nb,
                                const unsigned int dx, const unsigned int dy=1,
                                const unsigned int dz=1, const unsigned int dc=1) {
      return _save_empty_cimg(file,0,nb,dx,dy,dz,dc);
    }

    //! Save list as a TIFF file.
    /**
      \param filename Filename to write data to.
      \param compression_type Compression mode used to write data.
    **/
    const CImgList<T>& save_tiff(const char *const filename, const unsigned int compression_type=0) const {
      if (!filename)
        throw CImgArgumentException(_cimglist_instance
                                    "save_tiff(): Specified filename is (null).",
                                    cimglist_instance);
      if (is_empty()) { cimg::fempty(0,filename); return *this; }

#ifndef cimg_use_tiff
      if (_width==1) _data[0].save_tiff(filename,compression_type);
      else cimglist_for(*this,l) {
          char nfilename[1024] = { 0 };
          cimg::number_filename(filename,l,6,nfilename);
          _data[l].save_tiff(nfilename,compression_type);
        }
#else
# 46184 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      TIFF *tif = TIFFOpen(filename,"w");
      if (tif) {
        for (unsigned int dir = 0, l = 0; l<_width; ++l) {
          const CImg<T>& img = (*this)[l];
          if (img) {
            if (img._depth==1) img._save_tiff(tif,dir++,compression_type);
            else cimg_forZ(img,z) img.get_slice(z)._save_tiff(tif,dir++,compression_type);
          }
        }
        TIFFClose(tif);
      } else
        throw CImgIOException(_cimglist_instance
                              "save_tiff(): Failed to open stream for file '%s'.",
                              cimglist_instance,
                              filename);
#endif
# 46200 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      return *this;
    }


    //! Save list as a gzipped file, using external tool 'gzip'.
    /**
      \param filename Filename to write data to.
    **/
    const CImgList<T>& save_gzip_external(const char *const filename) const {
      if (!filename)
        throw CImgIOException(_cimglist_instance
                              "save_gzip_external(): Specified filename is (null).",
                              cimglist_instance);

      char command[1024] = { 0 }, filetmp[512] = { 0 }, body[512] = { 0 };
      const char
        *ext = cimg::split_filename(filename,body),
        *ext2 = cimg::split_filename(body,0);
      std::FILE *file;
      do {
        if (!cimg::strcasecmp(ext,"gz")) {
          if (*ext2) cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s.%s",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand(),ext2);
          else cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s.cimg",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand());
        } else {
          if (*ext) cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s.%s",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand(),ext);
          else cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s.cimg",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand());
        }
        if ((file=std::fopen(filetmp,"rb"))!=0) cimg::fclose(file);
      } while (file);

      if (is_saveable(body)) {
        save(filetmp);
        cimg_snprintf(command,sizeof(command),"%s -c \"%s\" > \"%s\"",
                      cimg::gzip_path(),
                      CImg<charT>::string(filetmp)._system_strescape().data(),
                      CImg<charT>::string(filename)._system_strescape().data());
        cimg::system(command);
        file = std::fopen(filename,"rb");
        if (!file)
          throw CImgIOException(_cimglist_instance
                                "save_gzip_external(): Failed to save file '%s' with external command 'gzip'.",
                                cimglist_instance,
                                filename);
        else cimg::fclose(file);
        std::remove(filetmp);
      } else {
        char nfilename[1024] = { 0 };
        cimglist_for(*this,l) {
          cimg::number_filename(body,l,6,nfilename);
          if (*ext) std::sprintf(nfilename + std::strlen(nfilename),".%s",ext);
          _data[l].save_gzip_external(nfilename);
        }
      }
      return *this;
    }

    //! Save image sequence, using the external tool 'ffmpeg'.
    /**
      \param filename Filename to write data to.
      \param codec Type of compression.
      \param fps Number of frames per second.
      \param bitrate Output bitrate
    **/
    const CImgList<T>& save_ffmpeg_external(const char *const filename, const char *const codec=0,
                                            const unsigned int fps=25, const unsigned int bitrate=2048) const {
      if (!filename)
        throw CImgArgumentException(_cimglist_instance
                                    "save_ffmpeg_external(): Specified filename is (null).",
                                    cimglist_instance);
      if (is_empty()) { cimg::fempty(0,filename); return *this; }

      const char
        *const ext = cimg::split_filename(filename),
        *const _codec = codec?codec:!cimg::strcasecmp(ext,"flv")?"flv":"mpeg2video";

      char command[1024] = { 0 }, filetmp[512] = { 0 }, filetmp2[512] = { 0 };
      CImgList<charT> filenames;
      std::FILE *file = 0;
      cimglist_for(*this,l) if (!_data[l].is_sameXYZ(_data[0]))
        throw CImgInstanceException(_cimglist_instance
                                    "save_ffmpeg_external(): Invalid instance dimensions for file '%s'.",
                                    cimglist_instance,
                                    filename);
      do {
        cimg_snprintf(filetmp,sizeof(filetmp),"%s%c%s",cimg::temporary_path(),cimg_file_separator,cimg::filenamerand());
        cimg_snprintf(filetmp2,sizeof(filetmp2),"%s_000001.ppm",filetmp);
        if ((file=std::fopen(filetmp2,"rb"))!=0) cimg::fclose(file);
      } while (file);
      cimglist_for(*this,l) {
        cimg_snprintf(filetmp2,sizeof(filetmp2),"%s_%.6u.ppm",filetmp,l+1);
        CImg<charT>::string(filetmp2).move_to(filenames);
        if (_data[l]._depth>1 || _data[l]._spectrum!=3) _data[l].get_resize(-100,-100,1,3).save_pnm(filetmp2);
        else _data[l].save_pnm(filetmp2);
      }
#if cimg_OS!=2
      cimg_snprintf(command,sizeof(command),"%s -i \"%s_%%6d.ppm\" -vcodec %s -b %uk -r %u -y \"%s\" >/dev/null 2>&1",
                    cimg::ffmpeg_path(),
                    CImg<charT>::string(filetmp)._system_strescape().data(),
                    _codec,bitrate,fps,
                    CImg<charT>::string(filename)._system_strescape().data());
#else
# 46301 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      cimg_snprintf(command,sizeof(command),"\"%s -i \"%s_%%6d.ppm\" -vcodec %s -b %uk -r %u -y \"%s\"\" >NUL 2>&1",
                    cimg::ffmpeg_path(),
                    CImg<charT>::string(filetmp)._system_strescape().data(),
                    _codec,bitrate,fps,
                    CImg<charT>::string(filename)._system_strescape().data());
#endif
# 46307 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
      cimg::system(command);
      file = std::fopen(filename,"rb");
      if (!file)
        throw CImgIOException(_cimglist_instance
                              "save_ffmpeg_external(): Failed to save file '%s' with external command 'ffmpeg'.",
                              cimglist_instance,
                              filename);
      else cimg::fclose(file);
      cimglist_for(*this,l) std::remove(filenames[l]);
      return *this;
    }

    //@}
    //----------------------------------
    //
    //! \name Others
    //@{
    //----------------------------------

    //! Crop font along the X-axis.
    /**
    **/
    CImgList<T>& crop_font() {
      return get_crop_font().move_to(*this);
    }

    //! Crop font along the X-axis \newinstance.
    /**
    **/
    CImgList<T> get_crop_font() const {
      CImgList<T> res;
      cimglist_for(*this,l) {
        const CImg<T>& letter = (*this)[l];
        int xmin = letter._width, xmax = 0;
        cimg_forXY(letter,x,y) if (letter(x,y)) { if (x<xmin) xmin = x; if (x>xmax) xmax = x; }
        if (xmin>xmax) CImg<T>(letter._width,letter._height,1,letter._spectrum,0).move_to(res);
        else letter.get_crop(xmin,0,xmax,letter._height-1).move_to(res);
      }
      res[' '].resize(res['f']._width,-100,-100,-100,0);
      if (' '+256<res.size()) res[' '+256].resize(res['f']._width,-100,-100,-100,0);
      return res;
    }


    //! Return a CImg pre-defined font with desired size.
    /**
       \param font_height Height of the desired font (exact match for 11,13,17,19,24,32,38,57)
       \param is_variable_width Decide if the font has a variable (\c true) or fixed (\c false) width.
    **/
    static const CImgList<T>& font(const unsigned int font_height, const bool is_variable_width=true) {

#define _cimg_font(sx,sy) \
      if (!is_variable_width && (!font || font[0]._height!=sy)) cimg::mutex(11); font = _font(cimg::font##sx##x##sy,sx,sy,false); cimg::mutex(11,0); \
      if (is_variable_width  && (!vfont || vfont[0]._height!=sy)) cimg::mutex(11); vfont = _font(cimg::font##sx##x##sy,sx,sy,true); cimg::mutex(11,0); \
      if (font_height==sy) return is_variable_width?vfont:font; \
      if (is_variable_width) { \
        if (cvfont && font_height==cvfont[0]._height) return cvfont; \
        cimg::mutex(11); cvfont = vfont; \
        cimglist_for(cvfont,l) \
          cvfont[l].resize(cimg::max(1U,cvfont[l]._width*font_height/cvfont[l]._height),font_height,-100,-100, \
                           cvfont[0]._height>font_height?2:5); \
        cimg::mutex(11,0); return cvfont; \
      } else { \
        if (cfont && font_height==cfont[0]._height) return cfont; \
        cimg::mutex(11); cfont = font; \
        cimglist_for(cfont,l) \
          cfont[l].resize(cimg::max(1U,cfont[l]._width*font_height/cfont[l]._height),font_height,-100,-100, \
                          cfont[0]._height>font_height?2:5); \
        cimg::mutex(11,0); return cfont; \
      } \

      static CImgList<T> font, vfont, cfont, cvfont;
      if (!font_height) return CImgList<T>::empty();
      if (font_height<=13) { _cimg_font(10,13); } // [1,13] -> ref 13
      if (font_height<=28) { _cimg_font(12,24); } // [14,28] -> ref 24
      if (font_height<=32) { _cimg_font(16,32); } // [29,32] -> ref 32
      _cimg_font(29,57);                          // [33,+inf] -> ref 57
    }

    static CImgList<T> _font(const unsigned int *const font, const unsigned int w, const unsigned int h, const bool is_variable_width) {
      CImgList<T> res(256,w,h,1,1);
      const unsigned int *ptr = font;
      unsigned int m = 0, val = 0;
      for (unsigned int y = 0; y<h; ++y)
        for (unsigned int x = 0; x<256*w; ++x) {
          m>>=1; if (!m) { m = 0x80000000; val = *(ptr++); }
          CImg<T>& img = res[x/w];
          unsigned int xm = x%w;
          img(xm,y) = (T)((val&m)?1:0);
        }
      if (is_variable_width) res.crop_font();
      return  res.insert(res);
    }

    //! Compute a 1d Fast Fourier Transform, along specified axis.
    /**
       \param axis Axis along which the Fourier transform is computed.
       \param invert Tells if the direct (\c false) or inverse transform (\c true) is computed.
    **/
    CImgList<T>& FFT(const char axis, const bool invert=false) {
      if (is_empty()) return *this;
      if (_width==1) insert(1);
      if (_width>2)
        cimg::warn(_cimglist_instance
                   "FFT(): Instance has more than 2 images",
                   cimglist_instance);

      CImg<T>::FFT(_data[0],_data[1],axis,invert);
      return *this;
    }

    //! Compute a 1-D Fast Fourier Transform, along specified axis \newinstance.
    CImgList<Tfloat> get_FFT(const char axis, const bool invert=false) const {
      return CImgList<Tfloat>(*this,false).FFT(axis,invert);
    }

    //! Compute a n-d Fast Fourier Transform.
    /**
      \param invert Tells if the direct (\c false) or inverse transform (\c true) is computed.
    **/
    CImgList<T>& FFT(const bool invert=false) {
      if (is_empty()) return *this;
      if (_width==1) insert(1);
      if (_width>2)
        cimg::warn(_cimglist_instance
                   "FFT(): Instance has more than 2 images",
                   cimglist_instance);

      CImg<T>::FFT(_data[0],_data[1],invert);
      return *this;
    }

    //! Compute a n-d Fast Fourier Transform \newinstance.
    CImgList<Tfloat> get_FFT(const bool invert=false) const {
      return CImgList<Tfloat>(*this,false).FFT(invert);
    }

    //! Reverse primitives orientations of a 3d object.
    /**
    **/
    CImgList<T>& reverse_object3d() {
      cimglist_for(*this,l) {
        CImg<T>& p = _data[l];
        switch (p.size()) {
        case 2: case 3: cimg::swap(p[0],p[1]); break;
        case 6: cimg::swap(p[0],p[1],p[2],p[4],p[3],p[5]); break;
        case 9: cimg::swap(p[0],p[1],p[3],p[5],p[4],p[6]); break;
        case 4: cimg::swap(p[0],p[1],p[2],p[3]); break;
        case 12: cimg::swap(p[0],p[1],p[2],p[3],p[4],p[6],p[5],p[7],p[8],p[10],p[9],p[11]); break;
        }
      }
      return *this;
    }

    //! Reverse primitives orientations of a 3d object \newinstance.
    CImgList<T> get_reverse_object3d() const {
      return (+*this).reverse_object3d();
    }

    //@}
  }; // struct CImgList<T> { ...

  /*
  #---------------------------------------------
  #
   # Completion of previously declared functions
   #
   #----------------------------------------------
  */

namespace cimg {

    // Implement a tic/toc mechanism to display elapsed time of algorithms.
    inline unsigned long tictoc(const bool is_tic) {
      cimg::mutex(2);
      static CImg<unsigned long> times(64);
      static unsigned int pos = 0;
      const unsigned long t1 = cimg::time();
      if (is_tic) { // Tic.
        times[pos++] = t1;
        if (pos>=times._width)
          throw CImgArgumentException("cimg::tic(): Too much calls to 'cimg::tic()' without calls to 'cimg::toc()'.");
        cimg::mutex(2,0);
        return t1;
      }
      // Toc.
      if (!pos)
        throw CImgArgumentException("cimg::toc(): No previous call to 'cimg::tic()' has been made.");
      const unsigned long
        t0 = times[--pos],
        dt = t1>=t0?(t1-t0):cimg::type<unsigned long>::max();
      const unsigned int
        edays = (unsigned int)(dt/86400000.0),
        ehours = (unsigned int)((dt - edays*86400000.0)/3600000.0),
        emin = (unsigned int)((dt - edays*86400000.0 - ehours*3600000.0)/60000.0),
        esec = (unsigned int)((dt - edays*86400000.0 - ehours*3600000.0 - emin*60000.0)/1000.0),
        ems = (unsigned int)(dt - edays*86400000.0 - ehours*3600000.0 - emin*60000.0 - esec*1000.0);
      if (!edays && !ehours && !emin && !esec)
        std::fprintf(cimg::output(),"%s[CImg]%*sElapsed time: %u ms%s\n",cimg::t_red,1+2*pos,"",ems,cimg::t_normal);
      else {
        if (!edays && !ehours && !emin)
          std::fprintf(cimg::output(),"%s[CImg]%*sElapsed time: %u sec %u ms%s\n",cimg::t_red,1+2*pos,"",esec,ems,cimg::t_normal);
        else {
          if (!edays && !ehours)
            std::fprintf(cimg::output(),"%s[CImg]%*sElapsed time: %u min %u sec %u ms%s\n",cimg::t_red,1+2*pos,"",emin,esec,ems,cimg::t_normal);
          else{
            if (!edays)
              std::fprintf(cimg::output(),"%s[CImg]%*sElapsed time: %u hours %u min %u sec %u ms%s\n",cimg::t_red,1+2*pos,"",ehours,emin,esec,ems,cimg::t_normal);
            else{
              std::fprintf(cimg::output(),"%s[CImg]%*sElapsed time: %u days %u hours %u min %u sec %u ms%s\n",cimg::t_red,1+2*pos,"",edays,ehours,emin,esec,ems,cimg::t_normal);
            }
          }
        }
      }
      cimg::mutex(2,0);
      return dt;
    }

  //! Display a simple dialog box, and wait for the user's response.
  /**
     \param title Title of the dialog window.
     \param msg Main message displayed inside the dialog window.
     \param button1_label Label of the 1st button.
     \param button2_label Label of the 2nd button (\c 0 to hide button).
     \param button3_label Label of the 3rd button (\c 0 to hide button).
     \param button4_label Label of the 4th button (\c 0 to hide button).
     \param button5_label Label of the 5th button (\c 0 to hide button).
     \param button6_label Label of the 6th button (\c 0 to hide button).
     \param logo Image logo displayed at the left of the main message.
     \param is_centered Tells if the dialog window must be centered on the screen.
     \return Indice of clicked button (from \c 0 to \c 5), or \c -1 if the dialog window has been closed by the user.
     \note
     - Up to 6 buttons can be defined in the dialog window.
     - The function returns when a user clicked one of the button or closed the dialog window.
     - If a button text is set to 0, the corresponding button (and the followings) will not appear in the dialog box. At least one button must be specified.
  **/
  template<typename t>
  inline int dialog(const char *const title, const char *const msg,
                    const char *const button1_label, const char *const button2_label,
                    const char *const button3_label, const char *const button4_label,
                    const char *const button5_label, const char *const button6_label,
                    const CImg<t>& logo, const bool is_centered = false) {
#if cimg_display==0
    cimg::unused(title,msg,button1_label,button2_label,button3_label,button4_label,button5_label,button6_label,logo._data,is_centered);
    throw CImgIOException("cimg::dialog(): No display available.");
#else
# 46553 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
    const unsigned char
      black[] = { 0,0,0 }, white[] = { 255,255,255 }, gray[] = { 200,200,200 }, gray2[] = { 150,150,150 };

    // Create buttons and canvas graphics
    CImgList<unsigned char> buttons, cbuttons, sbuttons;
    if (button1_label) { CImg<unsigned char>().draw_text(0,0,button1_label,black,gray,1,13).move_to(buttons);
      if (button2_label) { CImg<unsigned char>().draw_text(0,0,button2_label,black,gray,1,13).move_to(buttons);
        if (button3_label) { CImg<unsigned char>().draw_text(0,0,button3_label,black,gray,1,13).move_to(buttons);
          if (button4_label) { CImg<unsigned char>().draw_text(0,0,button4_label,black,gray,1,13).move_to(buttons);
            if (button5_label) { CImg<unsigned char>().draw_text(0,0,button5_label,black,gray,1,13).move_to(buttons);
              if (button6_label) { CImg<unsigned char>().draw_text(0,0,button6_label,black,gray,1,13).move_to(buttons);
              }}}}}}
    if (!buttons._width)
      throw CImgArgumentException("cimg::dialog(): No buttons have been defined.");
    cimglist_for(buttons,l) buttons[l].resize(-100,-100,1,3);

    unsigned int bw = 0, bh = 0;
    cimglist_for(buttons,l) { bw = cimg::max(bw,buttons[l]._width); bh = cimg::max(bh,buttons[l]._height); }
    bw+=8; bh+=8;
    if (bw<64) bw = 64;
    if (bw>128) bw = 128;
    if (bh<24) bh = 24;
    if (bh>48) bh = 48;

    CImg<unsigned char> button(bw,bh,1,3);
    button.draw_rectangle(0,0,bw-1,bh-1,gray);
    button.draw_line(0,0,bw-1,0,white).draw_line(0,bh-1,0,0,white);
    button.draw_line(bw-1,0,bw-1,bh-1,black).draw_line(bw-1,bh-1,0,bh-1,black);
    button.draw_line(1,bh-2,bw-2,bh-2,gray2).draw_line(bw-2,bh-2,bw-2,1,gray2);
    CImg<unsigned char> sbutton(bw,bh,1,3);
    sbutton.draw_rectangle(0,0,bw-1,bh-1,gray);
    sbutton.draw_line(0,0,bw-1,0,black).draw_line(bw-1,0,bw-1,bh-1,black);
    sbutton.draw_line(bw-1,bh-1,0,bh-1,black).draw_line(0,bh-1,0,0,black);
    sbutton.draw_line(1,1,bw-2,1,white).draw_line(1,bh-2,1,1,white);
    sbutton.draw_line(bw-2,1,bw-2,bh-2,black).draw_line(bw-2,bh-2,1,bh-2,black);
    sbutton.draw_line(2,bh-3,bw-3,bh-3,gray2).draw_line(bw-3,bh-3,bw-3,2,gray2);
    sbutton.draw_line(4,4,bw-5,4,black,1,0xAAAAAAAA,true).draw_line(bw-5,4,bw-5,bh-5,black,1,0xAAAAAAAA,false);
    sbutton.draw_line(bw-5,bh-5,4,bh-5,black,1,0xAAAAAAAA,false).draw_line(4,bh-5,4,4,black,1,0xAAAAAAAA,false);
    CImg<unsigned char> cbutton(bw,bh,1,3);
    cbutton.draw_rectangle(0,0,bw-1,bh-1,black).draw_rectangle(1,1,bw-2,bh-2,gray2).draw_rectangle(2,2,bw-3,bh-3,gray);
    cbutton.draw_line(4,4,bw-5,4,black,1,0xAAAAAAAA,true).draw_line(bw-5,4,bw-5,bh-5,black,1,0xAAAAAAAA,false);
    cbutton.draw_line(bw-5,bh-5,4,bh-5,black,1,0xAAAAAAAA,false).draw_line(4,bh-5,4,4,black,1,0xAAAAAAAA,false);

    cimglist_for(buttons,ll) {
      CImg<unsigned char>(cbutton).draw_image(1+(bw-buttons[ll].width())/2,1+(bh-buttons[ll].height())/2,buttons[ll]).
        move_to(cbuttons);
      CImg<unsigned char>(sbutton).draw_image((bw-buttons[ll].width())/2,(bh-buttons[ll].height())/2,buttons[ll]).
        move_to(sbuttons);
      CImg<unsigned char>(button).draw_image((bw-buttons[ll].width())/2,(bh-buttons[ll].height())/2,buttons[ll]).
        move_to(buttons[ll]);
    }

    CImg<unsigned char> canvas;
    if (msg) CImg<unsigned char>().draw_text(0,0,"%s",black,gray,1,13,msg).resize(-100,-100,1,3).move_to(canvas);
    const unsigned int
      bwall = (buttons._width-1)*(12+bw) + bw,
      w = cimg::max(196U,36+logo._width+canvas._width,24+bwall),
      h = cimg::max(96U,36+canvas._height+bh,36+logo._height+bh),
      lx = 12 + (canvas._data?0:((w-24-logo._width)/2)),
      ly = (h-12-bh-logo._height)/2,
      tx = lx+logo._width+12,
      ty = (h-12-bh-canvas._height)/2,
      bx = (w-bwall)/2,
      by = h-12-bh;

    if (canvas._data)
      canvas = CImg<unsigned char>(w,h,1,3).
        draw_rectangle(0,0,w-1,h-1,gray).
        draw_line(0,0,w-1,0,white).draw_line(0,h-1,0,0,white).
        draw_line(w-1,0,w-1,h-1,black).draw_line(w-1,h-1,0,h-1,black).
        draw_image(tx,ty,canvas);
    else
      canvas = CImg<unsigned char>(w,h,1,3).
        draw_rectangle(0,0,w-1,h-1,gray).
        draw_line(0,0,w-1,0,white).draw_line(0,h-1,0,0,white).
        draw_line(w-1,0,w-1,h-1,black).draw_line(w-1,h-1,0,h-1,black);
    if (logo._data) canvas.draw_image(lx,ly,logo);

    unsigned int xbuttons[6] = { 0 };
    cimglist_for(buttons,lll) { xbuttons[lll] = bx+(bw+12)*lll; canvas.draw_image(xbuttons[lll],by,buttons[lll]); }

    // Open window and enter events loop
    CImgDisplay disp(canvas,title?title:" ",0,false,is_centered?true:false);
    if (is_centered) disp.move((CImgDisplay::screen_width() - disp.width())/2,
                             (CImgDisplay::screen_height() - disp.height())/2);
    bool stop_flag = false, refresh = false;
    int oselected = -1, oclicked = -1, selected = -1, clicked = -1;
    while (!disp.is_closed() && !stop_flag) {
      if (refresh) {
        if (clicked>=0) CImg<unsigned char>(canvas).draw_image(xbuttons[clicked],by,cbuttons[clicked]).display(disp);
        else {
          if (selected>=0) CImg<unsigned char>(canvas).draw_image(xbuttons[selected],by,sbuttons[selected]).display(disp);
          else canvas.display(disp);
        }
        refresh = false;
      }
      disp.wait(15);
      if (disp.is_resized()) disp.resize(disp,false);

      if (disp.button()&1)  {
        oclicked = clicked;
        clicked = -1;
        cimglist_for(buttons,l)
          if (disp.mouse_y()>=(int)by && disp.mouse_y()<(int)(by+bh) &&
              disp.mouse_x()>=(int)xbuttons[l] && disp.mouse_x()<(int)(xbuttons[l]+bw)) {
            clicked = selected = l;
            refresh = true;
          }
        if (clicked!=oclicked) refresh = true;
      } else if (clicked>=0) stop_flag = true;

      if (disp.key()) {
        oselected = selected;
        switch (disp.key()) {
        case cimg::keyESC : selected=-1; stop_flag = true; break;
        case cimg::keyENTER : if (selected<0) selected = 0; stop_flag = true; break;
        case cimg::keyTAB :
        case cimg::keyARROWRIGHT :
        case cimg::keyARROWDOWN : selected = (selected+1)%buttons._width; break;
        case cimg::keyARROWLEFT :
        case cimg::keyARROWUP : selected = (selected+buttons._width-1)%buttons._width; break;
        }
        disp.set_key();
        if (selected!=oselected) refresh = true;
      }
    }
    if (!disp) selected = -1;
    return selected;
#endif
# 46682 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
  }

  //! Display a simple dialog box, and wait for the user's response \specialization.
  inline int dialog(const char *const title, const char *const msg,
                    const char *const button1_label, const char *const button2_label, const char *const button3_label,
                    const char *const button4_label, const char *const button5_label, const char *const button6_label,
                    const bool is_centered) {
    return dialog(title,msg,button1_label,button2_label,button3_label,button4_label,button5_label,button6_label,
                  CImg<unsigned char>::_logo40x38(),is_centered);
  }

  //! Evaluate math expression.
  /**
     \param expression C-string describing the formula to evaluate.
     \param x Value of the pre-defined variable \c x.
     \param y Value of the pre-defined variable \c y.
     \param z Value of the pre-defined variable \c z.
     \param c Value of the pre-defined variable \c c.
     \return Result of the formula evaluation.
     \note Set \c expression to \c 0 to keep evaluating the last specified \c expression.
     \par Example
     \code
     const double
       res1 = cimg::eval("cos(x)^2+sin(y)^2",2,2),  // will return '1'.
       res2 = cimg::eval(0,1,1);                    // will return '1' too.
     \endcode
  **/
  inline double eval(const char *const expression, const double x, const double y, const double z, const double c) {
    static const CImg<float> empty;
    return empty.eval(expression,x,y,z,c);
  }

  template<typename t>
  inline CImg<typename cimg::superset<double,t>::type> eval(const char *const expression, const CImg<t>& xyzc) {
    static const CImg<float> empty;
    return empty.eval(expression,xyzc);
  }

  // End of cimg:: namespace
}

  // End of cimg_library:: namespace
}

//! Short alias name.
namespace cil = cimg_library_suffixed;

#ifdef _cimg_redefine_False
#define False 0
#endif
# 46732 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef _cimg_redefine_True
#define True 1
#endif
# 46735 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef _cimg_redefine_None
#define None 0
#endif
# 46738 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef _cimg_redefine_min
#define min(a,b) (((a)<(b))?(a):(b))
#endif
# 46741 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef _cimg_redefine_max
#define max(a,b) (((a)>(b))?(a):(b))
#endif
# 46744 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
#ifdef _cimg_redefine_PI
#define PI 3.141592653589793238462643383
#endif
# 46747 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"

#endif
# 46749 "/s/kde/src/calligra/krita/plugins/extensions/gmic/./CImg.h"
// Local Variables:
// mode: c++
// End:
# 71 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.h" 2
#if cimg_OS==2
#if 0 /* expanded by -frewrite-includes */
#include <process.h>
#endif /* expanded by -frewrite-includes */
# 73 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.h"
#pragma comment(linker,"/STACK:8388608")
#elif cimg_OS==1
# 75 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.h"
#if 0 /* expanded by -frewrite-includes */
#include <cerrno>
#endif /* expanded by -frewrite-includes */
# 76 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.h"
#endif // #if cimg_OS==2
# 77 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.h"

// Define some special character codes used for replacement in double quoted strings.
const char _dollar = 23, _lbrace = 24, _rbrace = 25, _comma = 26, _dquote = 28, _arobace = 29,
  _newline = 30;

// Replace special characters in a string.
inline char *gmic_strreplace(char *const str) {
  for (char *s = str ; *s; ++s) {
    const char c = *s;
    if (c<' ')
      *s = c==_dollar?'$':c==_lbrace?'{':c==_rbrace?'}':c==_comma?',':
        c==_dquote?'\"':c==_arobace?'@':c;
  }
  return str;
}

#else // #ifdef cimg_include_file
# 94 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstdio>
#endif /* expanded by -frewrite-includes */
# 95 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.h"
#if 0 /* expanded by -frewrite-includes */
#include <cstring>
#endif /* expanded by -frewrite-includes */
# 96 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.h"

#ifndef cimg_version
namespace cimg_library {

  // Define the G'MIC image structure.
  //----------------------------------
  template<typename T> struct CImg {
    unsigned int _width;       // Number of image columns (dimension along the X-axis).
    unsigned int _height;      // Number of image lines (dimension along the Y-axis)
    unsigned int _depth;       // Number of image slices (dimension along the Z-axis).
    unsigned int _spectrum;    // Number of image channels (dimension along the C-axis).
    bool _is_shared;           // Tells if the data buffer is shared by another structure.
    T *_data;                  // Pointer to the first pixel value.

    // Destructor.
    ~CImg();
    // Empty constructor.
    CImg():_width(0),_height(0),_depth(0),_spectrum(0),_is_shared(false),_data(0) {}
    // Use to allocate a new image with specified dimension.
    CImg<T>& assign(const unsigned int w, const unsigned int h=1,
                    const unsigned int d=1, const unsigned int s=1);
  };

  // Define the G'MIC image list structure.
  //---------------------------------------
  template<typename T> struct CImgList {
    unsigned int _width;           // Number of images in the list.
    unsigned int _allocated_width; // Allocated items in the list (must be 2^N and >size).
    CImg<T> *_data;                // Pointer to the first image of the list.

    // Destructor.
    ~CImgList();
    // Empty constructor.
    CImgList():_width(0),_allocated_width(0),_data(0) {}
    // Use to allocate a new image list with specified dimension.
    CImgList<T>& assign(const unsigned int n);
  };
}
#endif // #ifndef cimg_version
# 135 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.h"
#endif // #ifdef cimg_include_file
# 136 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.h"
#define gmic_image cimg_library::CImg
#define gmic_list cimg_library::CImgList
#define gmic_display cimg_library::CImgDisplay

// Define the G'MIC exception class.
//----------------------------------
struct gmic_exception {
  gmic_image<char> _command_help, _message;

  gmic_exception() {}

  gmic_exception(const char *const command, const char *const message) {
    if (command) {
      _command_help.assign(std::strlen(command)+1,1,1,1);
      std::strcpy(_command_help._data,command);
    }
    if (message) {
      _message.assign(std::strlen(message)+1,1,1,1);
      std::strcpy(_message._data,message);
    }
  }

  const char *what() const { // Give the error message returned by the G'MIC interpreter.
    return _message._data?_message._data:"";
  }
  const char *command_help() const {
    return _command_help._data?_command_help._data:"";
  }
};

// Define the G'MIC interpreter class.
//------------------------------------
struct gmic {

  // Constructors - Destructors.
  // Use the methods below to create and run the G'MIC interpreter from your C++ source.

#define gmic_new_attr commands(new CImgList<char>[256]), commands_names(new CImgList<char>[256]), commands_has_arguments(new CImgList<char>[256]), \
    _variables(new CImgList<char>[256]), _variables_names(new CImgList<char>[256]), variables(new CImgList<char>*[256]), variables_names(new CImgList<char>*[256])

  // Destructor.
  ~gmic();

  // Constructors.
  gmic();

  gmic(const char *const commands_line, const char *const custom_commands=0,
       const bool include_default_commands=true, float *const p_progress=0, int *const p_cancel=0);

  template<typename T>
  gmic(const int argc, const char *const *const argv, gmic_list<T>& images,
       gmic_list<char>& images_names,
       const char *const custom_commands=0, const bool include_default_commands=true,
       float *const p_progress=0, int *const p_cancel=0);

  template<typename T>
  gmic(const char *const commands_line, gmic_list<T>& images, gmic_list<char>& images_names,
       const char *const custom_commands=0, const bool include_default_commands=true,
       float *const p_progress=0, int *const p_cancel=0);

  // Method to call parser on an already constructed gmic object.
  template<typename T>
  gmic& parse(const char *const commands_line,
              gmic_list<T> &images, gmic_list<char> &images_names) {
    return parse(commands_line_to_CImgList(commands_line),images,images_names);
  }

  //--------------------------------------------------------------------------------------
  // All functions below should be considered as 'private' and thus, should not be used
  // in your own C++ source code. Use them at your own risk.
  //--------------------------------------------------------------------------------------
  template<typename T>
  void _gmic(const char *const commands_line, gmic_list<T>& images, gmic_list<char>& images_names,
             const char *const custom_commands, const bool include_default_commands,
             float *const p_progress, int *const p_cancel);

  gmic& add_commands(const char *const data_commands,
                     gmic_list<char> commands_names[256],
                     gmic_list<char> commands[256],
                     gmic_list<char> commands_has_arguments[256],
                     const char *const commands_file=0);
  gmic& add_commands(std::FILE *const file,
                     const char *const filename,
                     gmic_list<char> commands_names[256],
                     gmic_list<char> commands[256],
                     gmic_list<char> commands_has_arguments[256],
                     const bool add_debug_infos=false);
  gmic_image<char> scope2string(const bool is_last_slash=true) const;
  gmic_image<char> scope2string(const gmic_image<unsigned int>& scope_selection,
                                const bool is_last_slash=true) const;

  gmic_image<unsigned int> selection2cimg(const char *const string, const unsigned int indice_max,
                                          const gmic_list<char>& names,
                                          const char *const command, const bool is_selection,
                                          const bool allow_new_name, gmic_image<char>& new_name);

  gmic_image<char> selection2string(const gmic_image<unsigned int>& selection,
                                    const gmic_list<char>& images_names,
                                    const bool display_selection) const;

  gmic_list<char> commands_line_to_CImgList(const char *const commands_line);

  template<typename T>
  gmic_image<char> substitute_item(const char *const source,
                                   gmic_list<T>& images, gmic_list<char>& images_names,
				   unsigned int variables_sizes[256]);

  gmic& print(const char *format, ...);
  template<typename T>
  gmic& print(const gmic_list<T>& list, const char *format, ...);
  template<typename T>
  gmic& print(const gmic_list<T>& list, const gmic_image<unsigned int>& scope_selection,
	      const char *format, ...);

  gmic& warn(const char *format, ...);
  template<typename T>
  gmic& warn(const gmic_list<T>& list, const char *format, ...);
  template<typename T>
  gmic& warn(const gmic_list<T>& list, const gmic_image<unsigned int>& scope_selection,
             const char *format, ...);

  gmic& error(const char *format, ...);
  template<typename T>
  gmic& error(const gmic_list<T>& list, const char *format, ...);
  template<typename T>
  gmic& error(const char *const command, const gmic_list<T>& list, const char *format, ...);
  template<typename T>
  gmic& error(const gmic_list<T>& list, const gmic_image<unsigned int>& scope_selection,
	      const char *format, ...);
  template<typename T>
  gmic& _arg_error(const gmic_list<T>& list, const char *const command,
		   const char *const argument);

  gmic& debug(const char *format, ...);
  template<typename T>
  gmic& debug(const gmic_list<T>& list, const char *format, ...);

  template<typename T>
  gmic& print_images(const gmic_list<T>& images,
                     const gmic_list<char>& images_names,
                     const gmic_image<unsigned int>& selection,
                     const bool is_header=true);
  template<typename T>
  gmic& display_images(const gmic_list<T>& images,
                       const gmic_list<char>& images_names,
                       const gmic_image<unsigned int>& selection,
                       unsigned int *const XYZ);
  template<typename T>
  gmic& display_plots(const gmic_list<T>& images,
                      const gmic_list<char>& images_names,
                      const gmic_image<unsigned int>& selection,
                      const unsigned int plot_type, const unsigned int vertex_type,
                      const double xmin, const double xmax,
                      const double ymin, const double ymax);
  template<typename T>
  gmic& display_objects3d(const gmic_list<T>& images,
                          const gmic_list<char>& images_names,
                          const gmic_image<unsigned int>& selection);
  template<typename T>
  gmic_image<T>& check_image(const gmic_list<T>& list, gmic_image<T>& img);
  template<typename T>
  const gmic_image<T>& check_image(const gmic_list<T>& list, const gmic_image<T>& img);

  template<typename T>
  gmic& remove_images(gmic_list<T>& images, gmic_list<char>& images_names,
                      const gmic_image<unsigned int>& selection,
                      const unsigned int start, const unsigned int end);

  template<typename T>
  gmic& parse(const gmic_list<char>& commands_line,
	      gmic_list<T> &images, gmic_list<char> &images_names) {
    unsigned int variables_sizes[256] = { 0 };
    unsigned int position = 0;
    setlocale(LC_NUMERIC,"C");
    scope.assign(1U);
    scope._data[0].assign(2,1,1,1);
    scope._data[0]._data[0] = '.';
    scope._data[0]._data[1] = 0;
    dowhiles.assign(0U);
    repeatdones.assign(0U);
    status.assign(0U);
    is_start = true;
    is_quit = false;
    is_return = false;
    is_default_type = true;
    *progress = -1;
    return _parse(commands_line,position,images,images_names,variables_sizes);
  }

  template<typename T>
  gmic& _parse(const gmic_list<char>& commands_line, unsigned int& position,
               gmic_list<T> &images, gmic_list<char> &images_names,
               unsigned int variables_sizes[256]);
  gmic& _parse_bool(const gmic_list<char>& commands_line, unsigned int& position,
                    gmic_list<bool>& images, gmic_list<char> &images_names,
                    unsigned int variables_sizes[256]);
  gmic& _parse_uchar(const gmic_list<char>& commands_line, unsigned int& position,
                     gmic_list<unsigned char>& images, gmic_list<char> &images_names,
                     unsigned int variables_sizes[256]);
  gmic& _parse_char(const gmic_list<char>& commands_line, unsigned int& position,
                    gmic_list<char>& images, gmic_list<char> &images_names,
                    unsigned int variables_sizes[256]);
  gmic& _parse_ushort(const gmic_list<char>& commands_line, unsigned int& position,
                      gmic_list<unsigned short>& images, gmic_list<char> &images_names,
                      unsigned int variables_sizes[256]);
  gmic& _parse_short(const gmic_list<char>& commands_line, unsigned int& position,
                     gmic_list<short>& images, gmic_list<char> &images_names,
                     unsigned int variables_sizes[256]);
  gmic& _parse_uint(const gmic_list<char>& commands_line, unsigned int& position,
                    gmic_list<unsigned int>& images, gmic_list<char> &images_names,
                    unsigned int variables_sizes[256]);
  gmic& _parse_int(const gmic_list<char>& commands_line, unsigned int& position,
                   gmic_list<int>& images, gmic_list<char> &images_names,
                   unsigned int variables_sizes[256]);
  gmic& _parse_float(const gmic_list<char>& commands_line, unsigned int& position,
                     gmic_list<float>& images, gmic_list<char> &images_names,
                     unsigned int variables_sizes[256]);
  gmic& _parse_double(const gmic_list<char>& commands_line, unsigned int& position,
                      gmic_list<double>& images, gmic_list<char> &images_names,
                      unsigned int variables_sizes[256]);

  // Internal environment variables.
#if cimg_display!=0
  gmic_display instant_window[10];
#endif // #if cimg_display!=0
# 361 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.h"
  gmic_list<char> *const commands, *const commands_names, *const commands_has_arguments,
    *const _variables, *const _variables_names, **const variables, **const variables_names,
    commands_files, scope;
  gmic_list<unsigned int> dowhiles, repeatdones;
  gmic_image<unsigned char> background3d, light3d;
  gmic_image<float> pose3d;
  gmic_image<char> status;
  float focale3d, light3d_x, light3d_y, light3d_z, specular_lightness3d, specular_shininess3d,
    _progress, *progress;
  bool is_released, is_debug, is_start, is_quit, is_return, is_double3d, is_default_type,
    is_debug_infos, check_elif;
  int verbosity, render3d, renderd3d;
  volatile int _cancel, *cancel;
  unsigned int nb_carriages, debug_filename, debug_line;
  unsigned long reference_time;

}; // End of the 'gmic' class.

#endif // #ifndef gmic_version
# 380 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.h"

// Local Variables:
// mode: c++
// End:
# 1715 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp" 2
#if defined(gmic_float)
#if 0 /* expanded by -frewrite-includes */
#include "gmic_def.h"
#endif /* expanded by -frewrite-includes */
# 1 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic_def.h" 1
#ifndef gmic_gimp
/* Define image 'gmic_def' of size 1x712959x1x1 and type 'char' */
char data_gmic_def[] = {
  35, 64, 103, 109, 105, 99, 32, 58, 58, 32, 71, 108, 111, 98, 97, 108,
  32, 111, 112, 116, 105, 111, 110, 115, 10, 35, 64, 103, 109, 105, 99, 32,
  100, 101, 98, 117, 103, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 65, 99, 116, 105, 118, 97, 116, 101, 32, 100, 101,
  98, 117, 103, 32, 109, 111, 100, 101, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 87, 104, 101, 110, 32, 97, 99, 116, 105, 118, 97, 116, 101,
  100, 44, 32, 116, 104, 101, 32, 71, 39, 77, 73, 67, 32, 105, 110, 116,
  101, 114, 112, 114, 101, 116, 101, 114, 32, 98, 101, 99, 111, 109, 101, 115,
  32, 118, 101, 114, 121, 32, 118, 101, 114, 98, 111, 115, 101, 32, 97, 110,
  100, 32, 111, 117, 116, 112, 117, 116, 115, 32, 97, 100, 100, 105, 116, 105,
  111, 110, 110, 97, 108, 32, 108, 111, 103, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 109, 101, 115, 115, 97, 103, 101, 115, 32, 97, 98, 111, 117,
  116, 32, 105, 116, 115, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 115,
  116, 97, 116, 101, 32, 111, 110, 32, 116, 104, 101, 32, 115, 116, 97, 110,
  100, 97, 114, 100, 32, 111, 117, 116, 112, 117, 116, 32, 40, 115, 116, 100,
  111, 117, 116, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 84,
  104, 105, 115, 32, 111, 112, 116, 105, 111, 110, 32, 99, 97, 110, 32, 98,
  101, 32, 117, 115, 101, 102, 117, 108, 32, 119, 104, 101, 110, 32, 100, 101,
  98, 117, 103, 103, 105, 110, 103, 32, 116, 104, 101, 32, 101, 120, 101, 99,
  117, 116, 105, 111, 110, 32, 111, 102, 32, 97, 32, 99, 117, 115, 116, 111,
  109, 32, 99, 111, 109, 109, 97, 110, 100, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 104, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 104,
  101, 108, 112, 39, 46, 32, 58, 32, 40, 42, 41, 10, 104, 32, 58, 10,
  45, 104, 101, 108, 112, 32, 36, 42, 10, 35, 64, 103, 109, 105, 99, 32,
  104, 101, 108, 112, 32, 58, 32, 95, 99, 111, 109, 109, 97, 110, 100, 32,
  58, 32, 40, 110, 111, 32, 97, 114, 103, 115, 41, 32, 58, 32, 40, 42,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 105, 115, 112, 108,
  97, 121, 32, 104, 101, 108, 112, 32, 40, 111, 112, 116, 105, 111, 110, 97,
  108, 108, 121, 32, 102, 111, 114, 32, 115, 112, 101, 99, 105, 102, 105, 101,
  100, 32, 99, 111, 109, 109, 97, 110, 100, 32, 111, 110, 108, 121, 41, 32,
  97, 110, 100, 32, 101, 120, 105, 116, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 104, 39, 41,
  46, 10, 104, 101, 108, 112, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 49, 61, 34, 34, 125, 44, 36, 123, 50, 61, 49, 125, 10, 45, 105,
  102, 32, 123, 33, 64, 35, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 121, 32, 45, 97, 32, 121, 10, 45,
  45, 95, 104, 101, 108, 112, 32, 36, 49, 44, 36, 50, 32, 45, 107, 91,
  48, 93, 10, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40, 64, 123, 125,
  41, 125, 32, 45, 95, 104, 101, 108, 112, 91, 48, 93, 32, 64, 123, 125,
  44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 10, 95, 104,
  101, 108, 112, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  34, 34, 125, 10, 45, 118, 32, 45, 49, 10, 45, 105, 102, 32, 123, 33,
  110, 97, 114, 103, 40, 34, 36, 49, 34, 41, 125, 32, 95, 105, 115, 95,
  101, 120, 97, 109, 112, 108, 101, 61, 48, 32, 45, 95, 95, 104, 101, 108,
  112, 32, 97, 115, 99, 105, 105, 32, 45, 118, 32, 43, 32, 45, 101, 91,
  93, 32, 34, 34, 32, 45, 118, 32, 45, 32, 45, 114, 109, 32, 45, 117,
  32, 34, 34, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100,
  105, 102, 10, 40, 123, 39, 34, 36, 49, 34, 39, 125, 41, 32, 45, 97,
  117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 123, 39, 45, 39,
  125, 10, 45, 105, 102, 32, 123, 64, 123, 45, 49, 44, 49, 48, 48, 37,
  125, 61, 61, 123, 39, 93, 39, 125, 34, 32, 38, 38, 32, 34, 105, 33,
  61, 123, 39, 91, 39, 125, 125, 32, 45, 108, 91, 45, 49, 93, 32, 45,
  115, 32, 45, 44, 123, 39, 91, 39, 125, 32, 45, 107, 91, 48, 93, 32,
  45, 101, 110, 100, 108, 32, 45, 101, 110, 100, 105, 102, 10, 99, 111, 109,
  109, 97, 110, 100, 61, 64, 123, 45, 49, 44, 116, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 107, 115, 48, 61, 34, 48, 34, 32, 107, 115, 49,
  61, 34, 45, 107, 91, 48, 93, 34, 10, 45, 105, 102, 32, 36, 50, 32,
  45, 95, 95, 104, 101, 108, 112, 95, 104, 101, 97, 100, 101, 114, 95, 97,
  115, 99, 105, 105, 91, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114,
  32, 49, 44, 123, 104, 43, 49, 125, 44, 49, 44, 49, 44, 48, 44, 48,
  44, 48, 44, 49, 10, 45, 115, 32, 43, 44, 123, 39, 34, 35, 64, 103,
  109, 105, 99, 32, 34, 36, 99, 111, 109, 109, 97, 110, 100, 34, 32, 58,
  34, 39, 125, 10, 45, 105, 102, 32, 123, 64, 35, 61, 61, 49, 125, 32,
  45, 115, 32, 43, 44, 123, 39, 34, 35, 64, 103, 109, 105, 99, 32, 34,
  36, 99, 111, 109, 109, 97, 110, 100, 34, 58, 34, 39, 125, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64, 35, 61, 61, 49, 125,
  32, 45, 115, 32, 43, 44, 123, 39, 34, 35, 64, 103, 109, 105, 99, 32,
  34, 36, 99, 111, 109, 109, 97, 110, 100, 34, 92, 110, 34, 39, 125, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64, 35, 61, 61,
  49, 125, 32, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 110,
  91, 103, 109, 105, 99, 93, 32, 67, 111, 109, 109, 97, 110, 100, 32, 39,
  34, 36, 99, 111, 109, 109, 97, 110, 100, 34, 39, 32, 104, 97, 115, 32,
  110, 111, 32, 100, 101, 115, 99, 114, 105, 112, 116, 105, 111, 110, 46, 32,
  84, 114, 121, 32, 39, 103, 109, 105, 99, 32, 45, 104, 39, 32, 102, 111,
  114, 32, 103, 108, 111, 98, 97, 108, 32, 104, 101, 108, 112, 46, 92, 110,
  92, 110, 34, 32, 45, 118, 32, 45, 32, 45, 114, 109, 32, 45, 117, 32,
  34, 34, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 114, 109, 91, 48, 93, 32, 45, 97, 32, 121, 32, 45, 115,
  32, 45, 44, 49, 48, 10, 115, 116, 111, 112, 102, 108, 97, 103, 61, 48,
  10, 95, 105, 115, 95, 101, 120, 97, 109, 112, 108, 101, 61, 48, 10, 45,
  95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 104,
  101, 97, 100, 101, 114, 95, 97, 115, 99, 105, 105, 91, 93, 32, 48, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 32, 45, 105, 102, 32, 123, 104, 62, 55, 34, 32, 38, 38, 32, 34,
  123, 64, 123, 45, 49, 44, 48, 45, 53, 125, 39, 61, 61, 39, 123, 39,
  34, 35, 64, 103, 109, 105, 99, 34, 39, 125, 125, 125, 10, 45, 114, 111,
  119, 115, 32, 55, 44, 49, 48, 48, 37, 32, 45, 97, 117, 116, 111, 99,
  114, 111, 112, 32, 123, 39, 34, 32, 34, 39, 125, 10, 45, 105, 102, 32,
  123, 105, 33, 61, 123, 39, 58, 39, 125, 125, 10, 45, 115, 32, 45, 44,
  123, 39, 34, 58, 32, 34, 39, 125, 32, 45, 97, 117, 116, 111, 99, 114,
  111, 112, 32, 123, 39, 34, 32, 34, 39, 125, 10, 45, 105, 102, 32, 123,
  64, 123, 48, 44, 116, 125, 39, 61, 61, 39, 36, 99, 111, 109, 109, 97,
  110, 100, 125, 10, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103,
  109, 105, 99, 95, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 95,
  97, 115, 99, 105, 105, 10, 45, 105, 102, 32, 36, 95, 115, 104, 111, 114,
  116, 99, 117, 116, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34,
  92, 110, 32, 32, 32, 32, 45, 34, 36, 99, 111, 109, 109, 97, 110, 100,
  34, 58, 32, 69, 113, 117, 105, 118, 97, 108, 101, 110, 116, 32, 116, 111,
  32, 39, 34, 36, 95, 115, 104, 111, 114, 116, 99, 117, 116, 108, 105, 110,
  107, 48, 34, 39, 46, 34, 32, 45, 118, 32, 45, 10, 45, 117, 32, 36,
  95, 115, 104, 111, 114, 116, 99, 117, 116, 108, 105, 110, 107, 48, 32, 45,
  114, 101, 116, 117, 114, 110, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  108, 115, 101, 32, 115, 116, 111, 112, 102, 108, 97, 103, 61, 49, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101, 10, 45, 114, 111, 119,
  115, 32, 49, 44, 49, 48, 48, 37, 10, 45, 105, 102, 32, 123, 105, 61,
  61, 123, 39, 58, 39, 125, 125, 32, 115, 116, 111, 112, 102, 108, 97, 103,
  61, 49, 10, 45, 101, 108, 115, 101, 10, 45, 97, 117, 116, 111, 99, 114,
  111, 112, 32, 123, 39, 34, 32, 34, 39, 125, 10, 45, 105, 102, 32, 123,
  105, 61, 61, 123, 39, 36, 39, 125, 125, 10, 45, 114, 111, 119, 115, 32,
  49, 44, 49, 48, 48, 37, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112,
  32, 123, 39, 34, 32, 34, 39, 125, 10, 45, 105, 102, 32, 36, 95, 105,
  115, 95, 101, 120, 97, 109, 112, 108, 101, 32, 45, 105, 91, 48, 93, 32,
  40, 123, 39, 34, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  34, 39, 125, 41, 10, 45, 101, 108, 115, 101, 32, 45, 105, 91, 48, 93,
  32, 40, 123, 39, 34, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 69,
  120, 97, 109, 112, 108, 101, 40, 115, 41, 58, 32, 34, 39, 125, 41, 32,
  95, 105, 115, 95, 101, 120, 97, 109, 112, 108, 101, 61, 49, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 121, 91, 48, 93, 32, 45, 97, 32, 121, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 95, 100, 111, 99, 117, 109, 101, 110,
  116, 95, 103, 109, 105, 99, 95, 100, 101, 115, 99, 114, 105, 112, 116, 105,
  111, 110, 95, 97, 115, 99, 105, 105, 32, 48, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101, 32, 115,
  116, 111, 112, 102, 108, 97, 103, 61, 49, 32, 45, 101, 110, 100, 105, 102,
  32, 36, 123, 107, 115, 123, 64, 35, 33, 61, 48, 125, 125, 32, 45, 101,
  110, 100, 108, 32, 45, 105, 102, 32, 36, 115, 116, 111, 112, 102, 108, 97,
  103, 32, 45, 98, 114, 101, 97, 107, 32, 45, 101, 110, 100, 105, 102, 32,
  45, 100, 111, 110, 101, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32,
  34, 92, 110, 34, 32, 45, 118, 32, 45, 32, 45, 114, 109, 10, 45, 117,
  32, 34, 34, 10, 95, 95, 104, 101, 108, 112, 32, 58, 10, 45, 109, 32,
  34, 95, 104, 101, 108, 112, 95, 115, 101, 99, 116, 105, 111, 110, 32, 58,
  32, 45, 95, 104, 101, 108, 112, 95, 115, 101, 99, 116, 105, 111, 110, 95,
  36, 49, 32, 92, 34, 36, 34, 34, 49, 92, 34, 34, 10, 45, 109, 32,
  34, 95, 104, 101, 108, 112, 95, 112, 97, 114, 97, 103, 114, 97, 112, 104,
  32, 58, 32, 45, 95, 104, 101, 108, 112, 95, 112, 97, 114, 97, 103, 114,
  97, 112, 104, 95, 36, 49, 32, 92, 34, 36, 34, 34, 49, 92, 34, 34,
  10, 45, 95, 104, 101, 108, 112, 95, 104, 101, 97, 100, 101, 114, 95, 36,
  49, 91, 93, 10, 45, 95, 104, 101, 108, 112, 95, 117, 115, 97, 103, 101,
  91, 93, 10, 45, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105,
  99, 32, 36, 49, 44, 34, 105, 109, 103, 47, 34, 44, 48, 10, 45, 95,
  104, 101, 108, 112, 95, 101, 120, 97, 109, 112, 108, 101, 115, 91, 93, 10,
  45, 95, 104, 101, 108, 112, 95, 102, 111, 111, 116, 101, 114, 95, 36, 49,
  91, 93, 10, 95, 104, 101, 108, 112, 95, 104, 101, 97, 100, 101, 114, 95,
  108, 97, 116, 101, 120, 32, 58, 10, 45, 105, 102, 32, 123, 110, 97, 114,
  103, 40, 36, 95, 103, 109, 105, 99, 95, 105, 115, 95, 98, 101, 116, 97,
  41, 125, 32, 115, 116, 114, 98, 101, 116, 97, 61, 34, 32, 40, 98, 101,
  116, 97, 41, 34, 32, 45, 101, 108, 115, 101, 32, 115, 116, 114, 98, 101,
  116, 97, 61, 34, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 110, 97, 114, 103, 40, 36, 95, 103, 109, 105, 99, 95, 118, 101,
  114, 115, 105, 111, 110, 41, 125, 32, 115, 116, 114, 118, 101, 114, 61, 36,
  95, 103, 109, 105, 99, 95, 118, 101, 114, 115, 105, 111, 110, 32, 45, 101,
  108, 115, 101, 32, 115, 116, 114, 118, 101, 114, 61, 64, 123, 45, 115, 116,
  114, 118, 101, 114, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32,
  43, 32, 45, 101, 91, 93, 32, 34, 92, 92, 100, 111, 99, 117, 109, 101,
  110, 116, 99, 108, 97, 115, 115, 91, 97, 52, 112, 97, 112, 101, 114, 44,
  49, 49, 112, 116, 44, 116, 119, 111, 115, 105, 100, 101, 93, 123, 98, 111,
  111, 107, 125, 10, 92, 110, 92, 92, 117, 115, 101, 112, 97, 99, 107, 97,
  103, 101, 123, 104, 121, 112, 101, 114, 114, 101, 102, 44, 102, 97, 110, 99,
  121, 104, 100, 114, 44, 103, 114, 97, 112, 104, 105, 99, 120, 44, 97, 109,
  115, 115, 121, 109, 98, 44, 97, 109, 115, 109, 97, 116, 104, 44, 116, 105,
  109, 101, 115, 44, 109, 97, 107, 101, 105, 100, 120, 44, 108, 105, 115, 116,
  105, 110, 103, 115, 125, 10, 92, 110, 92, 92, 103, 114, 97, 112, 104, 105,
  99, 115, 112, 97, 116, 104, 123, 123, 105, 109, 103, 47, 125, 125, 10, 92,
  110, 92, 92, 112, 97, 103, 101, 115, 116, 121, 108, 101, 123, 102, 97, 110,
  99, 121, 112, 108, 97, 105, 110, 125, 10, 92, 110, 92, 92, 108, 104, 101,
  97, 100, 91, 92, 92, 102, 97, 110, 99, 121, 112, 108, 97, 105, 110, 123,
  125, 123, 92, 92, 116, 101, 120, 116, 98, 102, 92, 92, 116, 104, 101, 112,
  97, 103, 101, 125, 93, 123, 92, 92, 102, 97, 110, 99, 121, 112, 108, 97,
  105, 110, 123, 125, 123, 92, 92, 114, 105, 103, 104, 116, 109, 97, 114, 107,
  125, 125, 10, 92, 110, 92, 92, 114, 104, 101, 97, 100, 91, 92, 92, 102,
  97, 110, 99, 121, 112, 108, 97, 105, 110, 123, 125, 123, 92, 92, 108, 101,
  102, 116, 109, 97, 114, 107, 125, 93, 123, 92, 92, 102, 97, 110, 99, 121,
  112, 108, 97, 105, 110, 123, 125, 123, 92, 92, 116, 101, 120, 116, 98, 102,
  92, 92, 116, 104, 101, 112, 97, 103, 101, 125, 125, 10, 92, 110, 92, 92,
  99, 102, 111, 111, 116, 123, 125, 10, 92, 110, 92, 92, 115, 101, 116, 108,
  101, 110, 103, 116, 104, 123, 92, 92, 116, 101, 120, 116, 119, 105, 100, 116,
  104, 125, 123, 53, 46, 56, 55, 53, 105, 110, 125, 10, 92, 110, 92, 92,
  115, 101, 116, 108, 101, 110, 103, 116, 104, 123, 92, 92, 112, 97, 114, 105,
  110, 100, 101, 110, 116, 125, 123, 48, 112, 99, 125, 10, 92, 110, 92, 92,
  115, 101, 116, 108, 101, 110, 103, 116, 104, 123, 92, 92, 104, 111, 102, 102,
  115, 101, 116, 125, 123, 45, 48, 46, 56, 99, 109, 125, 10, 92, 110, 92,
  92, 115, 101, 116, 99, 111, 117, 110, 116, 101, 114, 123, 116, 111, 99, 100,
  101, 112, 116, 104, 125, 123, 49, 125, 10, 92, 110, 92, 92, 115, 108, 111,
  112, 112, 121, 123, 125, 10, 92, 110, 92, 92, 116, 105, 116, 108, 101, 123,
  92, 92, 102, 98, 111, 120, 123, 92, 92, 112, 97, 114, 98, 111, 120, 123,
  92, 92, 116, 101, 120, 116, 119, 105, 100, 116, 104, 125, 123, 92, 92, 98,
  101, 103, 105, 110, 123, 99, 101, 110, 116, 101, 114, 125, 92, 92, 118, 115,
  112, 97, 99, 101, 42, 123, 50, 99, 109, 125, 92, 92, 105, 110, 99, 108,
  117, 100, 101, 103, 114, 97, 112, 104, 105, 99, 115, 91, 119, 105, 100, 116,
  104, 61, 49, 50, 99, 109, 93, 123, 108, 111, 103, 111, 51, 46, 106, 112,
  103, 125, 92, 92, 92, 92, 92, 92, 118, 115, 112, 97, 99, 101, 42, 123,
  49, 99, 109, 125, 123, 92, 92, 72, 117, 103, 101, 32, 92, 92, 116, 101,
  120, 116, 98, 102, 123, 84, 104, 101, 32, 72, 97, 110, 100, 98, 111, 111,
  107, 125, 92, 92, 92, 92, 123, 92, 92, 115, 109, 97, 108, 108, 32, 86,
  101, 114, 115, 105, 111, 110, 32, 34, 36, 115, 116, 114, 118, 101, 114, 36,
  115, 116, 114, 98, 101, 116, 97, 34, 125, 92, 92, 92, 92, 92, 92, 118,
  115, 112, 97, 99, 101, 42, 123, 49, 99, 109, 125, 125, 92, 92, 101, 110,
  100, 123, 99, 101, 110, 116, 101, 114, 125, 125, 125, 125, 10, 92, 110, 92,
  92, 97, 117, 116, 104, 111, 114, 123, 92, 92, 76, 97, 114, 103, 101, 32,
  92, 92, 98, 102, 32, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 92, 92, 39, 101, 125, 10, 92, 110, 92, 92, 114,
  101, 110, 101, 119, 99, 111, 109, 109, 97, 110, 100, 92, 92, 105, 110, 100,
  101, 120, 110, 97, 109, 101, 123, 73, 110, 100, 101, 120, 32, 111, 102, 32,
  99, 111, 109, 109, 97, 110, 100, 115, 125, 10, 92, 110, 92, 92, 109, 97,
  107, 101, 105, 110, 100, 101, 120, 10, 92, 110, 92, 92, 108, 115, 116, 115,
  101, 116, 123, 99, 111, 108, 117, 109, 110, 115, 61, 102, 117, 108, 108, 102,
  108, 101, 120, 105, 98, 108, 101, 44, 98, 97, 115, 105, 99, 115, 116, 121,
  108, 101, 61, 92, 92, 110, 111, 114, 109, 97, 108, 102, 111, 110, 116, 125,
  10, 92, 110, 92, 92, 98, 101, 103, 105, 110, 123, 100, 111, 99, 117, 109,
  101, 110, 116, 125, 10, 92, 110, 92, 92, 109, 97, 107, 101, 116, 105, 116,
  108, 101, 10, 92, 110, 92, 92, 116, 97, 98, 108, 101, 111, 102, 99, 111,
  110, 116, 101, 110, 116, 115, 10, 92, 110, 92, 92, 99, 104, 97, 112, 116,
  101, 114, 42, 123, 80, 114, 101, 97, 109, 98, 108, 101, 125, 10, 92, 110,
  92, 92, 115, 101, 99, 116, 105, 111, 110, 42, 123, 76, 105, 99, 101, 110,
  115, 101, 125, 10, 92, 110, 84, 104, 105, 115, 32, 100, 111, 99, 117, 109,
  101, 110, 116, 32, 105, 115, 32, 100, 105, 115, 116, 114, 105, 98, 117, 116,
  101, 100, 32, 117, 110, 100, 101, 114, 32, 116, 104, 101, 32, 92, 92, 116,
  101, 120, 116, 98, 102, 123, 71, 78, 85, 32, 70, 114, 101, 101, 32, 68,
  111, 99, 117, 109, 101, 110, 116, 97, 116, 105, 111, 110, 32, 76, 105, 99,
  101, 110, 115, 101, 125, 44, 32, 118, 101, 114, 115, 105, 111, 110, 32, 49,
  46, 51, 46, 92, 92, 92, 92, 10, 92, 110, 82, 101, 97, 100, 32, 116,
  104, 101, 32, 102, 117, 108, 108, 32, 108, 105, 99, 101, 110, 115, 101, 32,
  116, 101, 114, 109, 115, 32, 97, 116, 32, 92, 92, 116, 101, 120, 116, 116,
  116, 123, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 103, 110, 117,
  46, 111, 114, 103, 47, 108, 105, 99, 101, 110, 115, 101, 115, 47, 102, 100,
  108, 45, 49, 46, 51, 46, 116, 120, 116, 125, 46, 92, 92, 92, 92, 126,
  92, 92, 92, 92, 10, 92, 110, 65, 110, 32, 111, 110, 108, 105, 110, 101,
  32, 118, 101, 114, 115, 105, 111, 110, 32, 111, 102, 32, 116, 104, 105, 115,
  32, 100, 111, 99, 117, 109, 101, 110, 116, 97, 116, 105, 111, 110, 32, 105,
  115, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 32, 97, 116, 58, 92,
  92, 92, 92, 92, 92, 116, 101, 120, 116, 116, 116, 123, 104, 116, 116, 112,
  58, 47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111,
  114, 103, 101, 46, 110, 101, 116, 47, 114, 101, 102, 101, 114, 101, 110, 99,
  101, 46, 115, 104, 116, 109, 108, 125, 46, 10, 92, 110, 92, 92, 115, 101,
  99, 116, 105, 111, 110, 42, 123, 77, 111, 116, 105, 118, 97, 116, 105, 111,
  110, 115, 125, 10, 92, 110, 71, 39, 77, 73, 67, 32, 105, 115, 32, 97,
  110, 32, 111, 112, 101, 110, 32, 97, 110, 100, 32, 102, 117, 108, 108, 45,
  102, 101, 97, 116, 117, 114, 101, 100, 32, 102, 114, 97, 109, 101, 119, 111,
  114, 107, 32, 102, 111, 114, 32, 105, 109, 97, 103, 101, 32, 112, 114, 111,
  99, 101, 115, 115, 105, 110, 103, 44, 32, 112, 114, 111, 118, 105, 100, 105,
  110, 103, 32, 115, 101, 118, 101, 114, 97, 108, 32, 100, 105, 102, 102, 101,
  114, 101, 110, 116, 32, 117, 115, 101, 114, 32, 105, 110, 116, 101, 114, 102,
  97, 99, 101, 115, 32, 116, 111, 10, 92, 110, 99, 111, 110, 118, 101, 114,
  116, 47, 109, 97, 110, 105, 112, 117, 108, 97, 116, 101, 47, 102, 105, 108,
  116, 101, 114, 47, 118, 105, 115, 117, 97, 108, 105, 122, 101, 32, 103, 101,
  110, 101, 114, 105, 99, 32, 105, 109, 97, 103, 101, 32, 100, 97, 116, 97,
  115, 101, 116, 115, 44, 32, 102, 114, 111, 109, 32, 49, 100, 32, 115, 99,
  97, 108, 97, 114, 32, 115, 105, 103, 110, 97, 108, 101, 115, 32, 116, 111,
  32, 51, 100, 43, 116, 32, 115, 101, 113, 117, 101, 110, 99, 101, 115, 32,
  111, 102, 32, 109, 117, 108, 116, 105, 45, 115, 112, 101, 99, 116, 114, 97,
  108, 32, 118, 111, 108, 117, 109, 101, 116, 114, 105, 99, 32, 105, 109, 97,
  103, 101, 115, 46, 10, 92, 110, 84, 101, 99, 104, 110, 105, 99, 97, 108,
  108, 121, 32, 115, 112, 101, 97, 107, 105, 110, 103, 44, 32, 119, 104, 97,
  116, 32, 105, 116, 32, 100, 111, 101, 115, 32, 105, 115, 58, 10, 92, 110,
  92, 92, 98, 101, 103, 105, 110, 123, 105, 116, 101, 109, 105, 122, 101, 125,
  10, 92, 110, 92, 92, 105, 116, 101, 109, 32, 68, 101, 102, 105, 110, 101,
  32, 97, 32, 108, 105, 103, 104, 116, 119, 101, 105, 103, 104, 116, 32, 98,
  117, 116, 32, 112, 111, 119, 101, 114, 102, 117, 108, 32, 115, 99, 114, 105,
  112, 116, 32, 108, 97, 110, 103, 117, 97, 103, 101, 32, 40, 116, 104, 101,
  32, 71, 39, 77, 73, 67, 32, 108, 97, 110, 103, 117, 97, 103, 101, 41,
  32, 100, 101, 100, 105, 99, 97, 116, 101, 100, 32, 116, 111, 32, 116, 104,
  101, 32, 100, 101, 115, 105, 103, 110, 32, 111, 102, 32, 105, 109, 97, 103,
  101, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 112, 105, 112,
  101, 108, 105, 110, 101, 115, 46, 10, 92, 110, 92, 92, 105, 116, 101, 109,
  32, 80, 114, 111, 118, 105, 100, 101, 32, 115, 101, 118, 101, 114, 97, 108,
  32, 117, 115, 101, 114, 32, 105, 110, 116, 101, 114, 102, 97, 99, 101, 115,
  32, 101, 109, 98, 101, 100, 100, 105, 110, 103, 32, 116, 104, 101, 32, 99,
  111, 114, 114, 101, 115, 112, 111, 110, 100, 105, 110, 103, 32, 105, 110, 116,
  101, 114, 112, 114, 101, 116, 101, 114, 58, 10, 92, 110, 92, 92, 98, 101,
  103, 105, 110, 123, 105, 116, 101, 109, 105, 122, 101, 125, 10, 92, 110, 92,
  92, 105, 116, 101, 109, 32, 65, 32, 99, 111, 109, 109, 97, 110, 100, 45,
  108, 105, 110, 101, 32, 101, 120, 101, 99, 117, 116, 97, 98, 108, 101, 32,
  39, 103, 109, 105, 99, 39, 44, 32, 116, 111, 32, 117, 115, 101, 32, 116,
  104, 101, 32, 71, 39, 77, 73, 67, 32, 102, 114, 97, 109, 101, 119, 111,
  114, 107, 32, 102, 114, 111, 109, 32, 97, 32, 115, 104, 101, 108, 108, 46,
  10, 92, 110, 73, 110, 32, 116, 104, 105, 115, 32, 115, 101, 116, 116, 105,
  110, 103, 44, 32, 71, 39, 77, 73, 67, 32, 109, 97, 121, 32, 98, 101,
  32, 115, 101, 101, 110, 32, 97, 115, 32, 97, 32, 100, 105, 114, 101, 99,
  116, 32, 40, 97, 110, 100, 32, 102, 114, 105, 101, 110, 100, 108, 121, 41,
  32, 99, 111, 109, 112, 101, 116, 105, 116, 111, 114, 32, 111, 102, 32, 116,
  104, 101, 32, 73, 109, 97, 103, 101, 77, 97, 103, 105, 99, 107, 32, 111,
  114, 32, 71, 114, 97, 112, 104, 105, 99, 115, 77, 97, 103, 105, 99, 107,
  32, 115, 111, 102, 116, 119, 97, 114, 101, 32, 115, 117, 105, 116, 101, 115,
  46, 10, 92, 110, 92, 92, 105, 116, 101, 109, 32, 65, 32, 112, 108, 117,
  103, 45, 105, 110, 32, 39, 103, 109, 105, 99, 92, 92, 95, 103, 105, 109,
  112, 39, 44, 32, 116, 111, 32, 98, 114, 105, 110, 103, 32, 71, 39, 77,
  73, 67, 32, 99, 97, 112, 97, 98, 105, 108, 105, 116, 105, 101, 115, 32,
  116, 111, 32, 116, 104, 101, 32, 71, 73, 77, 80, 32, 105, 109, 97, 103,
  101, 32, 114, 101, 116, 111, 117, 99, 104, 105, 110, 103, 32, 115, 111, 102,
  116, 119, 97, 114, 101, 46, 10, 92, 110, 92, 92, 105, 116, 101, 109, 32,
  65, 32, 119, 101, 98, 45, 115, 101, 114, 118, 105, 99, 101, 32, 39, 71,
  39, 77, 73, 67, 32, 79, 110, 108, 105, 110, 101, 39, 44, 32, 116, 111,
  32, 97, 108, 108, 111, 119, 32, 117, 115, 101, 114, 115, 32, 97, 112, 112,
  108, 121, 105, 110, 103, 32, 105, 109, 97, 103, 101, 32, 112, 114, 111, 99,
  101, 115, 115, 105, 110, 103, 32, 97, 108, 103, 111, 114, 105, 116, 104, 109,
  115, 32, 100, 105, 114, 101, 99, 116, 108, 121, 32, 105, 110, 32, 97, 32,
  119, 101, 98, 32, 98, 114, 111, 119, 101, 114, 46, 10, 92, 110, 92, 92,
  105, 116, 101, 109, 32, 65, 32, 81, 116, 45, 98, 97, 115, 101, 100, 32,
  105, 110, 116, 101, 114, 102, 97, 99, 101, 32, 39, 90, 65, 114, 116, 39,
  44, 32, 102, 111, 114, 32, 114, 101, 97, 108, 45, 116, 105, 109, 101, 32,
  109, 97, 110, 105, 112, 117, 108, 97, 116, 105, 111, 110, 32, 111, 102, 32,
  119, 101, 98, 99, 97, 109, 32, 105, 109, 97, 103, 101, 115, 46, 10, 92,
  110, 92, 92, 105, 116, 101, 109, 32, 65, 32, 67, 43, 43, 32, 108, 105,
  98, 114, 97, 114, 121, 32, 39, 108, 105, 98, 103, 109, 105, 99, 39, 44,
  32, 116, 111, 32, 98, 101, 32, 108, 105, 110, 107, 101, 100, 32, 119, 105,
  116, 104, 32, 116, 104, 105, 114, 100, 45, 112, 97, 114, 116, 121, 32, 97,
  112, 112, 108, 105, 99, 97, 116, 105, 111, 110, 115, 46, 10, 92, 110, 92,
  92, 101, 110, 100, 123, 105, 116, 101, 109, 105, 122, 101, 125, 10, 92, 110,
  92, 92, 101, 110, 100, 123, 105, 116, 101, 109, 105, 122, 101, 125, 10, 92,
  110, 71, 39, 77, 73, 67, 32, 105, 115, 32, 102, 111, 99, 117, 115, 101,
  100, 32, 111, 110, 32, 116, 104, 101, 32, 100, 101, 115, 105, 103, 110, 32,
  111, 102, 32, 112, 111, 115, 115, 105, 98, 108, 121, 32, 99, 111, 109, 112,
  108, 101, 120, 32, 112, 105, 112, 101, 108, 105, 110, 101, 115, 32, 102, 111,
  114, 32, 99, 111, 110, 118, 101, 114, 116, 105, 110, 103, 44, 32, 109, 97,
  110, 105, 112, 117, 108, 97, 116, 105, 110, 103, 44, 32, 102, 105, 108, 116,
  101, 114, 105, 110, 103, 32, 97, 110, 100, 32, 118, 105, 115, 117, 97, 108,
  105, 122, 105, 110, 103, 32, 103, 101, 110, 101, 114, 105, 99, 32, 49, 100,
  47, 50, 100, 47, 51, 100, 32, 109, 117, 108, 116, 105, 45, 115, 112, 101,
  99, 116, 114, 97, 108, 32, 105, 109, 97, 103, 101, 32, 100, 97, 116, 97,
  115, 101, 116, 115, 46, 32, 84, 104, 105, 115, 32, 105, 110, 99, 108, 117,
  100, 101, 115, 32, 111, 102, 32, 99, 111, 117, 114, 115, 101, 32, 99, 111,
  108, 111, 114, 32, 105, 109, 97, 103, 101, 115, 44, 32, 98, 117, 116, 32,
  97, 108, 115, 111, 32, 109, 111, 114, 101, 32, 99, 111, 109, 112, 108, 101,
  120, 32, 100, 97, 116, 97, 32, 97, 115, 32, 105, 109, 97, 103, 101, 32,
  115, 101, 113, 117, 101, 110, 99, 101, 115, 32, 111, 114, 32, 51, 100, 40,
  43, 116, 41, 32, 118, 111, 108, 117, 109, 101, 116, 114, 105, 99, 32, 102,
  108, 111, 97, 116, 45, 118, 97, 108, 117, 101, 100, 32, 100, 97, 116, 97,
  115, 101, 116, 115, 46, 92, 92, 92, 92, 10, 92, 110, 10, 92, 110, 71,
  39, 77, 73, 67, 32, 105, 115, 32, 97, 110, 32, 111, 112, 101, 110, 32,
  102, 114, 97, 109, 101, 119, 111, 114, 107, 58, 32, 116, 104, 101, 32, 100,
  101, 102, 97, 117, 108, 116, 32, 108, 97, 110, 103, 117, 97, 103, 101, 32,
  99, 97, 110, 32, 98, 101, 32, 101, 120, 116, 101, 110, 100, 101, 100, 32,
  119, 105, 116, 104, 32, 99, 117, 115, 116, 111, 109, 32, 71, 39, 77, 73,
  67, 45, 119, 114, 105, 116, 116, 101, 110, 32, 99, 111, 109, 109, 97, 110,
  100, 115, 44, 32, 100, 101, 102, 105, 110, 105, 110, 103, 32, 116, 104, 117,
  115, 32, 110, 101, 119, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 32,
  105, 109, 97, 103, 101, 32, 102, 105, 108, 116, 101, 114, 115, 32, 111, 114,
  32, 101, 102, 102, 101, 99, 116, 115, 46, 32, 66, 121, 32, 116, 104, 101,
  32, 119, 97, 121, 44, 32, 71, 39, 77, 73, 67, 32, 97, 108, 114, 101,
  97, 100, 121, 32, 99, 111, 110, 116, 97, 105, 110, 115, 32, 97, 32, 115,
  117, 98, 115, 116, 97, 110, 116, 105, 97, 108, 32, 115, 101, 116, 32, 111,
  102, 32, 112, 114, 101, 45, 100, 101, 102, 105, 110, 101, 100, 32, 105, 109,
  97, 103, 101, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 97,
  108, 103, 111, 114, 105, 116, 104, 109, 115, 32, 97, 110, 100, 32, 112, 105,
  112, 101, 108, 105, 110, 101, 115, 32, 40, 109, 111, 114, 101, 32, 116, 104,
  97, 110, 32, 49, 48, 48, 48, 41, 46, 92, 92, 92, 92, 10, 92, 110,
  10, 92, 110, 71, 39, 77, 73, 67, 32, 104, 97, 115, 32, 98, 101, 101,
  110, 32, 100, 101, 115, 105, 103, 110, 101, 100, 32, 119, 105, 116, 104, 32,
  112, 111, 114, 116, 97, 98, 105, 108, 105, 116, 121, 32, 105, 110, 32, 109,
  105, 110, 100, 32, 97, 110, 100, 32, 114, 117, 110, 115, 32, 111, 110, 32,
  100, 105, 102, 102, 101, 114, 101, 110, 116, 32, 112, 108, 97, 116, 102, 111,
  114, 109, 115, 32, 40, 87, 105, 110, 100, 111, 119, 115, 44, 32, 85, 110,
  105, 120, 44, 32, 77, 97, 99, 79, 83, 88, 41, 46, 32, 73, 116, 32,
  105, 115, 32, 100, 105, 115, 116, 114, 105, 98, 117, 116, 101, 100, 32, 117,
  110, 100, 101, 114, 32, 116, 104, 101, 32, 67, 101, 67, 73, 76, 76, 32,
  108, 105, 99, 101, 110, 115, 101, 32, 40, 71, 80, 76, 45, 99, 111, 109,
  112, 97, 116, 105, 98, 108, 101, 41, 46, 32, 83, 105, 110, 99, 101, 32,
  50, 48, 48, 56, 44, 32, 105, 116, 32, 105, 115, 32, 100, 101, 118, 101,
  108, 111, 112, 101, 100, 32, 105, 110, 32, 116, 104, 101, 32, 73, 109, 97,
  103, 101, 32, 84, 101, 97, 109, 32, 111, 102, 32, 116, 104, 101, 32, 71,
  82, 69, 89, 67, 32, 108, 97, 98, 111, 114, 97, 116, 111, 114, 121, 44,
  32, 105, 110, 32, 67, 97, 101, 110, 47, 70, 114, 97, 110, 99, 101, 44,
  32, 98, 121, 32, 112, 101, 114, 109, 97, 110, 101, 110, 116, 32, 114, 101,
  115, 101, 97, 114, 99, 104, 101, 114, 115, 32, 119, 111, 114, 107, 105, 110,
  103, 32, 105, 110, 32, 116, 104, 101, 32, 102, 105, 101, 108, 100, 32, 111,
  102, 32, 105, 109, 97, 103, 101, 32, 112, 114, 111, 99, 101, 115, 115, 105,
  110, 103, 32, 111, 110, 32, 97, 32, 100, 97, 105, 108, 121, 32, 98, 97,
  115, 105, 115, 46, 10, 92, 110, 92, 92, 115, 101, 99, 116, 105, 111, 110,
  42, 123, 86, 101, 114, 115, 105, 111, 110, 125, 10, 92, 110, 10, 92, 110,
  32, 103, 109, 105, 99, 58, 32, 71, 82, 69, 89, 67, 39, 115, 32, 77,
  97, 103, 105, 99, 32, 102, 111, 114, 32, 73, 109, 97, 103, 101, 32, 67,
  111, 109, 112, 117, 116, 105, 110, 103, 46, 10, 92, 110, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 32, 86, 101, 114, 115, 105, 111, 110, 32, 34,
  36, 115, 116, 114, 118, 101, 114, 36, 115, 116, 114, 98, 101, 116, 97, 34,
  44, 32, 67, 111, 112, 121, 114, 105, 103, 104, 116, 32, 40, 99, 41, 32,
  50, 48, 48, 56, 45, 50, 48, 49, 52, 44, 32, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 92, 92, 39, 101, 10,
  92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 40, 104, 116, 116, 112, 58,
  47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114,
  103, 101, 46, 110, 101, 116, 41, 10, 92, 110, 92, 92, 99, 104, 97, 112,
  116, 101, 114, 123, 85, 115, 97, 103, 101, 125, 10, 34, 10, 45, 118, 32,
  45, 10, 95, 104, 101, 108, 112, 95, 115, 101, 99, 116, 105, 111, 110, 95,
  108, 97, 116, 101, 120, 32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36,
  49, 34, 10, 45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 34, 92, 92,
  115, 101, 99, 116, 105, 111, 110, 123, 36, 49, 125, 34, 10, 45, 118, 32,
  45, 10, 95, 104, 101, 108, 112, 95, 112, 97, 114, 97, 103, 114, 97, 112,
  104, 95, 108, 97, 116, 101, 120, 32, 58, 32, 45, 115, 107, 105, 112, 32,
  34, 36, 49, 34, 10, 45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 34,
  92, 92, 115, 109, 97, 108, 108, 34, 10, 45, 101, 91, 93, 32, 34, 92,
  92, 98, 101, 103, 105, 110, 123, 108, 115, 116, 108, 105, 115, 116, 105, 110,
  103, 125, 34, 10, 45, 101, 91, 93, 32, 34, 36, 49, 34, 10, 45, 101,
  91, 93, 32, 34, 92, 92, 101, 110, 100, 123, 108, 115, 116, 108, 105, 115,
  116, 105, 110, 103, 125, 34, 10, 45, 101, 91, 93, 32, 34, 92, 92, 110,
  111, 114, 109, 97, 108, 115, 105, 122, 101, 34, 10, 45, 118, 32, 45, 10,
  95, 104, 101, 108, 112, 95, 102, 111, 111, 116, 101, 114, 95, 108, 97, 116,
  101, 120, 32, 58, 10, 45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 34,
  10, 92, 110, 92, 92, 112, 114, 105, 110, 116, 105, 110, 100, 101, 120, 10,
  92, 110, 126, 92, 92, 92, 92, 36, 92, 92, 115, 113, 117, 97, 114, 101,
  36, 126, 69, 110, 100, 32, 111, 102, 32, 100, 111, 99, 117, 109, 101, 110,
  116, 46, 10, 92, 110, 92, 110, 92, 92, 101, 110, 100, 123, 100, 111, 99,
  117, 109, 101, 110, 116, 125, 34, 10, 45, 118, 32, 45, 10, 95, 104, 101,
  108, 112, 95, 104, 101, 97, 100, 101, 114, 95, 104, 116, 109, 108, 32, 58,
  10, 95, 115, 101, 99, 116, 105, 111, 110, 61, 48, 10, 45, 105, 102, 32,
  123, 110, 97, 114, 103, 40, 36, 95, 103, 109, 105, 99, 95, 105, 115, 95,
  98, 101, 116, 97, 41, 125, 32, 115, 116, 114, 98, 101, 116, 97, 61, 34,
  32, 40, 98, 101, 116, 97, 41, 34, 32, 45, 101, 108, 115, 101, 32, 115,
  116, 114, 98, 101, 116, 97, 61, 34, 34, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40, 36, 95, 103, 109, 105,
  99, 95, 118, 101, 114, 115, 105, 111, 110, 41, 125, 32, 115, 116, 114, 118,
  101, 114, 61, 36, 95, 103, 109, 105, 99, 95, 118, 101, 114, 115, 105, 111,
  110, 32, 45, 101, 108, 115, 101, 32, 115, 116, 114, 118, 101, 114, 61, 64,
  123, 45, 115, 116, 114, 118, 101, 114, 125, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 34, 60, 33, 68, 79,
  67, 84, 89, 80, 69, 32, 104, 116, 109, 108, 32, 80, 85, 66, 76, 73,
  67, 32, 92, 34, 45, 47, 47, 87, 51, 67, 47, 47, 68, 84, 68, 32,
  88, 72, 84, 77, 76, 32, 49, 46, 48, 32, 84, 114, 97, 110, 115, 105,
  116, 105, 111, 110, 97, 108, 47, 47, 69, 78, 92, 34, 32, 92, 34, 104,
  116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103,
  47, 84, 82, 47, 120, 104, 116, 109, 108, 49, 47, 68, 84, 68, 47, 120,
  104, 116, 109, 108, 49, 45, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110,
  97, 108, 46, 100, 116, 100, 92, 34, 62, 10, 92, 110, 60, 33, 45, 45,
  35, 105, 110, 99, 108, 117, 100, 101, 32, 102, 105, 108, 101, 61, 92, 34,
  104, 101, 97, 100, 101, 114, 46, 104, 116, 109, 108, 92, 34, 32, 45, 45,
  62, 10, 92, 110, 60, 108, 105, 110, 107, 32, 104, 114, 101, 102, 61, 92,
  34, 115, 116, 121, 108, 101, 46, 99, 115, 115, 92, 34, 32, 114, 101, 108,
  61, 92, 34, 115, 116, 121, 108, 101, 115, 104, 101, 101, 116, 92, 34, 32,
  116, 121, 112, 101, 61, 92, 34, 116, 101, 120, 116, 47, 99, 115, 115, 92,
  34, 62, 10, 92, 110, 60, 100, 105, 118, 32, 105, 100, 61, 92, 34, 98,
  108, 111, 99, 95, 111, 112, 116, 105, 111, 110, 92, 34, 62, 10, 92, 110,
  60, 100, 105, 118, 32, 105, 100, 61, 92, 34, 116, 111, 112, 95, 114, 111,
  117, 103, 101, 92, 34, 62, 60, 100, 105, 118, 32, 105, 100, 61, 92, 34,
  116, 101, 120, 116, 95, 116, 111, 112, 92, 34, 62, 82, 101, 102, 101, 114,
  101, 110, 99, 101, 60, 47, 100, 105, 118, 62, 60, 47, 100, 105, 118, 62,
  10, 92, 110, 60, 100, 105, 118, 32, 105, 100, 61, 92, 34, 99, 101, 110,
  116, 101, 114, 92, 34, 62, 60, 100, 105, 118, 32, 105, 100, 61, 92, 34,
  116, 101, 120, 116, 95, 99, 101, 110, 116, 114, 101, 95, 105, 110, 116, 114,
  111, 92, 34, 62, 10, 92, 110, 60, 104, 50, 62, 60, 102, 111, 110, 116,
  32, 99, 111, 108, 111, 114, 61, 92, 34, 98, 114, 111, 119, 110, 92, 34,
  62, 60, 117, 62, 80, 114, 101, 97, 109, 98, 108, 101, 60, 47, 117, 62,
  60, 47, 102, 111, 110, 116, 62, 60, 47, 104, 50, 62, 10, 92, 110, 60,
  117, 108, 62, 10, 92, 110, 60, 108, 105, 62, 84, 104, 105, 115, 32, 100,
  111, 99, 117, 109, 101, 110, 116, 32, 105, 115, 32, 100, 105, 115, 116, 114,
  105, 98, 117, 116, 101, 100, 32, 117, 110, 100, 101, 114, 32, 116, 104, 101,
  32, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 104, 116, 116, 112, 58,
  47, 47, 119, 119, 119, 46, 103, 110, 117, 46, 111, 114, 103, 47, 108, 105,
  99, 101, 110, 115, 101, 115, 47, 102, 100, 108, 45, 49, 46, 51, 46, 116,
  120, 116, 92, 34, 62, 71, 78, 85, 32, 70, 114, 101, 101, 32, 68, 111,
  99, 117, 109, 101, 110, 116, 97, 116, 105, 111, 110, 32, 76, 105, 99, 101,
  110, 115, 101, 60, 47, 97, 62, 44, 32, 118, 101, 114, 115, 105, 111, 110,
  32, 49, 46, 51, 46, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105,
  62, 65, 32, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 103, 109, 105,
  99, 95, 114, 101, 102, 101, 114, 101, 110, 99, 101, 46, 112, 100, 102, 92,
  34, 62, 46, 112, 100, 102, 32, 118, 101, 114, 115, 105, 111, 110, 60, 47,
  97, 62, 32, 111, 102, 32, 116, 104, 105, 115, 32, 100, 111, 99, 117, 109,
  101, 110, 116, 32, 105, 115, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101,
  46, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 87, 101, 32,
  97, 108, 115, 111, 32, 115, 117, 103, 103, 101, 115, 116, 32, 121, 111, 117,
  32, 114, 101, 97, 100, 32, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34,
  104, 116, 116, 112, 58, 47, 47, 112, 97, 114, 116, 105, 99, 117, 108, 97,
  114, 97, 114, 116, 46, 99, 111, 109, 47, 116, 111, 111, 108, 115, 45, 97,
  110, 100, 45, 116, 111, 121, 115, 47, 103, 109, 105, 99, 47, 92, 34, 62,
  116, 104, 105, 115, 32, 112, 97, 103, 101, 60, 47, 97, 62, 44, 32, 119,
  114, 105, 116, 116, 101, 110, 32, 98, 121, 32, 60, 105, 62, 71, 97, 114,
  121, 32, 79, 115, 103, 111, 111, 100, 60, 47, 105, 62, 32, 119, 104, 111,
  32, 112, 114, 111, 118, 105, 100, 101, 115, 32, 97, 32, 118, 101, 114, 121,
  32, 99, 108, 101, 97, 114, 32, 97, 110, 100, 32, 117, 115, 101, 114, 45,
  102, 114, 105, 101, 110, 100, 108, 121, 32, 101, 120, 112, 108, 97, 110, 97,
  116, 105, 111, 110, 32, 111, 102, 32, 109, 111, 115, 116, 32, 111, 102, 32,
  116, 104, 101, 32, 71, 39, 77, 73, 67, 32, 98, 97, 115, 105, 99, 115,
  46, 60, 47, 108, 105, 62, 10, 92, 110, 60, 47, 117, 108, 62, 10, 92,
  110, 60, 104, 50, 62, 60, 97, 32, 105, 100, 61, 92, 34, 116, 111, 99,
  92, 34, 62, 60, 102, 111, 110, 116, 32, 99, 111, 108, 111, 114, 61, 92,
  34, 98, 114, 111, 119, 110, 92, 34, 62, 60, 117, 62, 84, 97, 98, 108,
  101, 32, 111, 102, 32, 99, 111, 110, 116, 101, 110, 116, 115, 60, 47, 117,
  62, 60, 47, 102, 111, 110, 116, 62, 60, 47, 97, 62, 60, 47, 104, 50,
  62, 10, 92, 110, 60, 117, 108, 62, 10, 92, 110, 60, 108, 105, 62, 60,
  97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 101, 99, 116, 105, 111,
  110, 48, 92, 34, 62, 86, 101, 114, 115, 105, 111, 110, 60, 47, 97, 62,
  60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104,
  114, 101, 102, 61, 92, 34, 35, 115, 101, 99, 116, 105, 111, 110, 49, 92,
  34, 62, 85, 115, 97, 103, 101, 60, 47, 97, 62, 60, 47, 108, 105, 62,
  10, 92, 110, 60, 117, 108, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97,
  32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 101, 99, 116, 105, 111, 110,
  50, 92, 34, 62, 79, 118, 101, 114, 97, 108, 108, 32, 99, 111, 110, 116,
  101, 120, 116, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60,
  108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 101,
  99, 116, 105, 111, 110, 51, 92, 34, 62, 73, 109, 97, 103, 101, 32, 100,
  101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 97, 110, 100, 32, 116, 101,
  114, 109, 105, 110, 111, 108, 111, 103, 121, 60, 47, 97, 62, 60, 47, 108,
  105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102,
  61, 92, 34, 35, 115, 101, 99, 116, 105, 111, 110, 52, 92, 34, 62, 73,
  116, 101, 109, 115, 32, 111, 102, 32, 97, 32, 112, 114, 111, 99, 101, 115,
  115, 105, 110, 103, 32, 112, 105, 112, 101, 108, 105, 110, 101, 60, 47, 97,
  62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32,
  104, 114, 101, 102, 61, 92, 34, 35, 115, 101, 99, 116, 105, 111, 110, 53,
  92, 34, 62, 73, 110, 112, 117, 116, 32, 100, 97, 116, 97, 32, 105, 116,
  101, 109, 115, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60,
  108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 101,
  99, 116, 105, 111, 110, 54, 92, 34, 62, 67, 111, 109, 109, 97, 110, 100,
  32, 105, 116, 101, 109, 115, 32, 97, 110, 100, 32, 115, 101, 108, 101, 99,
  116, 105, 111, 110, 115, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92,
  110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35,
  115, 101, 99, 116, 105, 111, 110, 55, 92, 34, 62, 73, 110, 112, 117, 116,
  47, 111, 117, 116, 112, 117, 116, 32, 112, 114, 111, 112, 101, 114, 116, 105,
  101, 115, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108,
  105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 101, 99,
  116, 105, 111, 110, 56, 92, 34, 62, 83, 117, 98, 115, 116, 105, 116, 117,
  116, 105, 111, 110, 32, 114, 117, 108, 101, 115, 60, 47, 97, 62, 60, 47,
  108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101,
  102, 61, 92, 34, 35, 115, 101, 99, 116, 105, 111, 110, 57, 92, 34, 62,
  77, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 32, 101, 120, 112,
  114, 101, 115, 115, 105, 111, 110, 115, 60, 47, 97, 62, 60, 47, 108, 105,
  62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61,
  92, 34, 35, 115, 101, 99, 116, 105, 111, 110, 49, 48, 92, 34, 62, 73,
  109, 97, 103, 101, 32, 97, 110, 100, 32, 100, 97, 116, 97, 32, 118, 105,
  101, 119, 101, 114, 115, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92,
  110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35,
  115, 101, 99, 116, 105, 111, 110, 49, 49, 92, 34, 62, 65, 100, 100, 105,
  110, 103, 32, 99, 117, 115, 116, 111, 109, 32, 99, 111, 109, 109, 97, 110,
  100, 115, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 47,
  117, 108, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101,
  102, 61, 92, 34, 35, 115, 101, 99, 116, 105, 111, 110, 49, 50, 92, 34,
  62, 76, 105, 115, 116, 32, 111, 102, 32, 99, 111, 109, 109, 97, 110, 100,
  115, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 117, 108,
  62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61,
  92, 34, 35, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 49, 92, 34,
  62, 71, 108, 111, 98, 97, 108, 32, 111, 112, 116, 105, 111, 110, 115, 60,
  47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60,
  97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 117, 98, 115, 101, 99,
  116, 105, 111, 110, 50, 92, 34, 62, 73, 110, 112, 117, 116, 115, 47, 111,
  117, 116, 112, 117, 116, 115, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10,
  92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34,
  35, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 51, 92, 34, 62, 76,
  105, 115, 116, 32, 109, 97, 110, 105, 112, 117, 108, 97, 116, 105, 111, 110,
  60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62,
  60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 117, 98, 115, 101,
  99, 116, 105, 111, 110, 52, 92, 34, 62, 77, 97, 116, 104, 101, 109, 97,
  116, 105, 99, 97, 108, 32, 111, 112, 101, 114, 97, 116, 111, 114, 115, 60,
  47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60,
  97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 117, 98, 115, 101, 99,
  116, 105, 111, 110, 53, 92, 34, 62, 86, 97, 108, 117, 101, 115, 32, 109,
  97, 110, 105, 112, 117, 108, 97, 116, 105, 111, 110, 60, 47, 97, 62, 60,
  47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114,
  101, 102, 61, 92, 34, 35, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110,
  54, 92, 34, 62, 67, 111, 108, 111, 114, 115, 32, 109, 97, 110, 105, 112,
  117, 108, 97, 116, 105, 111, 110, 60, 47, 97, 62, 60, 47, 108, 105, 62,
  10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92,
  34, 35, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 55, 92, 34, 62,
  71, 101, 111, 109, 101, 116, 114, 121, 32, 109, 97, 110, 105, 112, 117, 108,
  97, 116, 105, 111, 110, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92,
  110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35,
  115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 56, 92, 34, 62, 70, 105,
  108, 116, 101, 114, 105, 110, 103, 60, 47, 97, 62, 60, 47, 108, 105, 62,
  10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92,
  34, 35, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 57, 92, 34, 62,
  70, 101, 97, 116, 117, 114, 101, 115, 32, 101, 120, 116, 114, 97, 99, 116,
  105, 111, 110, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60,
  108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 117,
  98, 115, 101, 99, 116, 105, 111, 110, 49, 48, 92, 34, 62, 73, 109, 97,
  103, 101, 32, 100, 114, 97, 119, 105, 110, 103, 60, 47, 97, 62, 60, 47,
  108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101,
  102, 61, 92, 34, 35, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 49,
  49, 92, 34, 62, 77, 97, 116, 114, 105, 120, 32, 99, 111, 109, 112, 117,
  116, 97, 116, 105, 111, 110, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10,
  92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34,
  35, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 49, 50, 92, 34, 62,
  51, 100, 32, 114, 101, 110, 100, 101, 114, 105, 110, 103, 60, 47, 97, 62,
  60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104,
  114, 101, 102, 61, 92, 34, 35, 115, 117, 98, 115, 101, 99, 116, 105, 111,
  110, 49, 51, 92, 34, 62, 80, 114, 111, 103, 114, 97, 109, 32, 99, 111,
  110, 116, 114, 111, 108, 115, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10,
  92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34,
  35, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 49, 52, 92, 34, 62,
  65, 114, 114, 97, 121, 115, 44, 116, 105, 108, 101, 115, 32, 97, 110, 100,
  32, 102, 114, 97, 109, 101, 115, 60, 47, 97, 62, 60, 47, 108, 105, 62,
  10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92,
  34, 35, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 49, 53, 92, 34,
  62, 65, 114, 116, 105, 115, 116, 105, 99, 60, 47, 97, 62, 60, 47, 108,
  105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102,
  61, 92, 34, 35, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 49, 54,
  92, 34, 62, 87, 97, 114, 112, 105, 110, 103, 115, 60, 47, 97, 62, 60,
  47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114,
  101, 102, 61, 92, 34, 35, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110,
  49, 55, 92, 34, 62, 68, 101, 103, 114, 97, 100, 97, 116, 105, 111, 110,
  115, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105,
  62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 117, 98, 115,
  101, 99, 116, 105, 111, 110, 49, 56, 92, 34, 62, 66, 108, 101, 110, 100,
  105, 110, 103, 32, 97, 110, 100, 32, 102, 97, 100, 105, 110, 103, 60, 47,
  97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97,
  32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 117, 98, 115, 101, 99, 116,
  105, 111, 110, 49, 57, 92, 34, 62, 73, 109, 97, 103, 101, 32, 115, 101,
  113, 117, 101, 110, 99, 101, 115, 60, 47, 97, 62, 60, 47, 108, 105, 62,
  10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92,
  34, 35, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 50, 48, 92, 34,
  62, 73, 110, 116, 101, 114, 97, 99, 116, 105, 118, 101, 32, 100, 101, 109,
  111, 115, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108,
  105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 117, 98,
  115, 101, 99, 116, 105, 111, 110, 50, 49, 92, 34, 62, 80, 73, 78, 75,
  45, 108, 105, 98, 114, 97, 114, 121, 32, 111, 112, 101, 114, 97, 116, 111,
  114, 115, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108,
  105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 117, 98,
  115, 101, 99, 116, 105, 111, 110, 50, 50, 92, 34, 62, 67, 111, 110, 118,
  101, 110, 105, 101, 110, 99, 101, 32, 102, 117, 110, 99, 116, 105, 111, 110,
  115, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105,
  62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 117, 98, 115,
  101, 99, 116, 105, 111, 110, 50, 51, 92, 34, 62, 79, 116, 104, 101, 114,
  115, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105,
  62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 117, 98, 115,
  101, 99, 116, 105, 111, 110, 50, 52, 92, 34, 62, 67, 111, 109, 109, 97,
  110, 100, 115, 32, 115, 104, 111, 114, 116, 99, 117, 116, 115, 60, 47, 97,
  62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 47, 117, 108, 62, 10, 92,
  110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35,
  115, 101, 99, 116, 105, 111, 110, 49, 51, 92, 34, 62, 69, 120, 97, 109,
  112, 108, 101, 115, 32, 111, 102, 32, 117, 115, 101, 60, 47, 97, 62, 60,
  47, 108, 105, 62, 10, 92, 110, 60, 47, 117, 108, 62, 10, 92, 110, 60,
  97, 32, 105, 100, 61, 92, 34, 115, 101, 99, 116, 105, 111, 110, 48, 92,
  34, 62, 60, 104, 50, 62, 60, 102, 111, 110, 116, 32, 99, 111, 108, 111,
  114, 61, 92, 34, 98, 114, 111, 119, 110, 92, 34, 62, 60, 117, 62, 86,
  101, 114, 115, 105, 111, 110, 60, 47, 117, 62, 60, 47, 102, 111, 110, 116,
  62, 60, 47, 104, 50, 62, 60, 47, 97, 62, 10, 92, 110, 60, 112, 114,
  101, 62, 60, 102, 111, 110, 116, 32, 99, 111, 108, 111, 114, 61, 92, 34,
  98, 108, 117, 101, 92, 34, 62, 103, 109, 105, 99, 60, 47, 102, 111, 110,
  116, 62, 58, 32, 71, 82, 69, 89, 67, 39, 115, 32, 77, 97, 103, 105,
  99, 32, 102, 111, 114, 32, 73, 109, 97, 103, 101, 32, 67, 111, 109, 112,
  117, 116, 105, 110, 103, 46, 10, 92, 110, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 86, 101, 114, 115, 105, 111, 110, 32, 34, 36, 115, 116, 114,
  118, 101, 114, 36, 115, 116, 114, 98, 101, 116, 97, 34, 44, 32, 67, 111,
  112, 121, 114, 105, 103, 104, 116, 32, 40, 99, 41, 32, 50, 48, 48, 56,
  45, 50, 48, 49, 52, 44, 32, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 101, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 40, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 104, 116, 116,
  112, 58, 47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102,
  111, 114, 103, 101, 46, 110, 101, 116, 92, 34, 62, 104, 116, 116, 112, 58,
  47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114,
  103, 101, 46, 110, 101, 116, 60, 47, 97, 62, 41, 10, 92, 110, 60, 47,
  112, 114, 101, 62, 10, 34, 10, 45, 118, 32, 45, 10, 45, 95, 104, 101,
  108, 112, 95, 115, 101, 99, 116, 105, 111, 110, 32, 34, 85, 115, 97, 103,
  101, 34, 10, 95, 104, 101, 108, 112, 95, 115, 101, 99, 116, 105, 111, 110,
  95, 104, 116, 109, 108, 32, 58, 10, 95, 115, 101, 99, 116, 105, 111, 110,
  61, 123, 36, 95, 115, 101, 99, 116, 105, 111, 110, 43, 49, 125, 10, 45,
  118, 32, 43, 10, 45, 101, 91, 93, 32, 34, 60, 104, 50, 62, 60, 97,
  32, 105, 100, 61, 92, 34, 115, 101, 99, 116, 105, 111, 110, 34, 36, 95,
  115, 101, 99, 116, 105, 111, 110, 34, 92, 34, 62, 60, 102, 111, 110, 116,
  32, 99, 111, 108, 111, 114, 61, 92, 34, 98, 114, 111, 119, 110, 92, 34,
  62, 60, 117, 62, 36, 49, 60, 47, 117, 62, 60, 47, 102, 111, 110, 116,
  62, 60, 47, 97, 62, 34, 92, 10, 34, 38, 110, 98, 115, 112, 59, 38,
  110, 98, 115, 112, 59, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35,
  116, 111, 99, 92, 34, 62, 60, 105, 109, 103, 32, 115, 114, 99, 61, 92,
  34, 105, 109, 103, 47, 98, 97, 99, 107, 95, 116, 111, 112, 46, 112, 110,
  103, 92, 34, 62, 60, 47, 105, 109, 103, 62, 60, 47, 97, 62, 60, 47,
  104, 50, 62, 34, 10, 45, 118, 32, 45, 10, 95, 104, 101, 108, 112, 95,
  112, 97, 114, 97, 103, 114, 97, 112, 104, 95, 104, 116, 109, 108, 32, 58,
  10, 45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 34, 60, 112, 114, 101,
  62, 36, 42, 60, 47, 112, 114, 101, 62, 34, 10, 45, 118, 32, 45, 10,
  95, 104, 101, 108, 112, 95, 102, 111, 111, 116, 101, 114, 95, 104, 116, 109,
  108, 32, 58, 10, 45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 34, 10,
  92, 110, 60, 98, 114, 47, 62, 60, 98, 62, 60, 102, 111, 110, 116, 32,
  99, 111, 108, 111, 114, 61, 92, 34, 98, 114, 111, 119, 110, 92, 34, 62,
  42, 42, 32, 71, 39, 77, 73, 67, 32, 99, 111, 109, 101, 115, 32, 119,
  105, 116, 104, 32, 65, 66, 83, 79, 76, 85, 84, 69, 76, 89, 32, 78,
  79, 32, 87, 65, 82, 82, 65, 78, 84, 89, 59, 32, 102, 111, 114, 32,
  100, 101, 116, 97, 105, 108, 115, 32, 118, 105, 115, 105, 116, 32, 60, 97,
  32, 104, 114, 101, 102, 61, 92, 34, 104, 116, 116, 112, 58, 47, 47, 103,
  109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46,
  110, 101, 116, 92, 34, 62, 104, 116, 116, 112, 58, 47, 47, 103, 109, 105,
  99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101,
  116, 32, 42, 42, 60, 47, 97, 62, 60, 47, 102, 111, 110, 116, 62, 60,
  47, 98, 62, 10, 92, 110, 60, 47, 116, 116, 62, 10, 92, 110, 60, 47,
  100, 105, 118, 62, 10, 92, 110, 60, 47, 100, 105, 118, 62, 10, 92, 110,
  60, 100, 105, 118, 32, 105, 100, 61, 92, 34, 102, 111, 111, 116, 101, 114,
  92, 34, 62, 60, 105, 109, 103, 32, 115, 114, 99, 61, 92, 34, 105, 109,
  97, 103, 101, 115, 47, 102, 111, 111, 116, 101, 114, 46, 106, 112, 103, 92,
  34, 32, 47, 62, 60, 47, 100, 105, 118, 62, 10, 92, 110, 60, 47, 100,
  105, 118, 62, 10, 92, 110, 60, 33, 45, 45, 35, 105, 110, 99, 108, 117,
  100, 101, 32, 102, 105, 108, 101, 61, 92, 34, 99, 111, 112, 121, 114, 105,
  103, 104, 116, 46, 104, 116, 109, 108, 92, 34, 32, 45, 45, 62, 10, 92,
  110, 60, 33, 45, 45, 35, 105, 110, 99, 108, 117, 100, 101, 32, 102, 105,
  108, 101, 61, 92, 34, 102, 111, 111, 116, 101, 114, 46, 104, 116, 109, 108,
  92, 34, 32, 45, 45, 62, 10, 34, 10, 45, 118, 32, 45, 10, 95, 104,
  101, 108, 112, 95, 104, 101, 97, 100, 101, 114, 95, 97, 115, 99, 105, 105,
  32, 58, 10, 45, 95, 95, 104, 101, 108, 112, 95, 104, 101, 97, 100, 101,
  114, 95, 97, 115, 99, 105, 105, 10, 95, 115, 101, 99, 116, 105, 111, 110,
  61, 48, 32, 95, 115, 112, 97, 99, 101, 49, 61, 34, 34, 32, 95, 115,
  112, 97, 99, 101, 50, 61, 34, 32, 34, 10, 45, 95, 104, 101, 108, 112,
  95, 115, 101, 99, 116, 105, 111, 110, 32, 34, 85, 115, 97, 103, 101, 34,
  10, 95, 95, 104, 101, 108, 112, 95, 104, 101, 97, 100, 101, 114, 95, 97,
  115, 99, 105, 105, 32, 58, 10, 45, 105, 102, 32, 123, 110, 97, 114, 103,
  40, 36, 95, 103, 109, 105, 99, 95, 105, 115, 95, 98, 101, 116, 97, 41,
  125, 32, 115, 116, 114, 98, 101, 116, 97, 61, 34, 32, 40, 98, 101, 116,
  97, 41, 34, 32, 45, 101, 108, 115, 101, 32, 115, 116, 114, 98, 101, 116,
  97, 61, 34, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 110, 97, 114, 103, 40, 36, 95, 103, 109, 105, 99, 95, 118, 101, 114,
  115, 105, 111, 110, 41, 125, 32, 115, 116, 114, 118, 101, 114, 61, 36, 95,
  103, 109, 105, 99, 95, 118, 101, 114, 115, 105, 111, 110, 32, 45, 101, 108,
  115, 101, 32, 115, 116, 114, 118, 101, 114, 61, 64, 123, 45, 115, 116, 114,
  118, 101, 114, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43,
  10, 45, 101, 91, 93, 32, 34, 10, 92, 110, 32, 103, 109, 105, 99, 58,
  32, 71, 82, 69, 89, 67, 39, 115, 32, 77, 97, 103, 105, 99, 32, 102,
  111, 114, 32, 73, 109, 97, 103, 101, 32, 67, 111, 109, 112, 117, 116, 105,
  110, 103, 46, 10, 92, 110, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  32, 86, 101, 114, 115, 105, 111, 110, 32, 34, 36, 115, 116, 114, 118, 101,
  114, 36, 115, 116, 114, 98, 101, 116, 97, 34, 44, 32, 67, 111, 112, 121,
  114, 105, 103, 104, 116, 32, 40, 99, 41, 32, 50, 48, 48, 56, 45, 50,
  48, 49, 52, 44, 32, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 101, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 32, 40, 104, 116, 116, 112, 58, 47, 47, 103, 109, 105, 99, 46, 115,
  111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 41, 34,
  10, 45, 118, 32, 45, 10, 95, 104, 101, 108, 112, 95, 115, 101, 99, 116,
  105, 111, 110, 95, 97, 115, 99, 105, 105, 32, 58, 10, 95, 115, 101, 99,
  116, 105, 111, 110, 61, 123, 36, 95, 115, 101, 99, 116, 105, 111, 110, 43,
  49, 125, 10, 123, 110, 97, 114, 103, 40, 123, 39, 34, 36, 49, 34, 39,
  125, 41, 125, 44, 49, 44, 49, 44, 49, 44, 123, 39, 45, 39, 125, 10,
  45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 34, 92, 110, 32, 34, 36,
  95, 115, 101, 99, 116, 105, 111, 110, 34, 46, 32, 36, 49, 34, 10, 45,
  101, 91, 93, 32, 34, 32, 32, 32, 32, 34, 36, 123, 95, 115, 112, 97,
  99, 101, 123, 110, 97, 114, 103, 40, 123, 39, 36, 95, 115, 101, 99, 116,
  105, 111, 110, 39, 125, 41, 125, 125, 64, 123, 45, 49, 44, 116, 125, 34,
  92, 110, 34, 10, 45, 118, 32, 45, 10, 45, 114, 109, 91, 45, 49, 93,
  10, 95, 104, 101, 108, 112, 95, 112, 97, 114, 97, 103, 114, 97, 112, 104,
  95, 97, 115, 99, 105, 105, 32, 58, 10, 45, 118, 32, 43, 10, 45, 101,
  91, 93, 32, 34, 36, 42, 34, 10, 45, 118, 32, 45, 10, 95, 104, 101,
  108, 112, 95, 102, 111, 111, 116, 101, 114, 95, 97, 115, 99, 105, 105, 32,
  58, 10, 45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 34, 32, 42, 42,
  32, 71, 39, 77, 73, 67, 32, 99, 111, 109, 101, 115, 32, 119, 105, 116,
  104, 32, 65, 66, 83, 79, 76, 85, 84, 69, 76, 89, 32, 78, 79, 32,
  87, 65, 82, 82, 65, 78, 84, 89, 59, 32, 102, 111, 114, 32, 100, 101,
  116, 97, 105, 108, 115, 32, 118, 105, 115, 105, 116, 32, 104, 116, 116, 112,
  58, 47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111,
  114, 103, 101, 46, 110, 101, 116, 32, 42, 42, 34, 10, 45, 118, 32, 45,
  10, 95, 104, 101, 108, 112, 95, 117, 115, 97, 103, 101, 32, 58, 10, 45,
  95, 104, 101, 108, 112, 95, 112, 97, 114, 97, 103, 114, 97, 112, 104, 32,
  34, 32, 103, 109, 105, 99, 32, 91, 99, 111, 109, 109, 97, 110, 100, 49,
  32, 91, 97, 114, 103, 49, 95, 49, 44, 97, 114, 103, 49, 95, 50, 44,
  46, 46, 93, 93, 32, 46, 46, 32, 91, 99, 111, 109, 109, 97, 110, 100,
  78, 32, 91, 97, 114, 103, 78, 95, 49, 44, 97, 114, 103, 78, 95, 50,
  44, 46, 46, 93, 93, 10, 92, 110, 10, 92, 110, 32, 39, 103, 109, 105,
  99, 39, 32, 105, 115, 32, 97, 110, 32, 111, 112, 101, 110, 45, 115, 111,
  117, 114, 99, 101, 32, 105, 110, 116, 101, 114, 112, 114, 101, 116, 101, 114,
  32, 111, 102, 32, 116, 104, 101, 32, 71, 39, 77, 73, 67, 32, 108, 97,
  110, 103, 117, 97, 103, 101, 44, 32, 97, 32, 115, 99, 114, 105, 112, 116,
  45, 98, 97, 115, 101, 100, 32, 112, 114, 111, 103, 114, 97, 109, 109, 105,
  110, 103, 10, 92, 110, 32, 32, 108, 97, 110, 103, 117, 97, 103, 101, 32,
  100, 101, 100, 105, 99, 97, 116, 101, 100, 32, 116, 111, 32, 100, 101, 115,
  105, 103, 110, 32, 105, 109, 97, 103, 101, 32, 112, 114, 111, 99, 101, 115,
  115, 105, 110, 103, 32, 112, 105, 112, 101, 108, 105, 110, 101, 115, 46, 32,
  73, 116, 32, 99, 97, 110, 32, 98, 101, 32, 117, 115, 101, 100, 32, 116,
  111, 32, 99, 111, 110, 118, 101, 114, 116, 44, 10, 92, 110, 32, 32, 109,
  97, 110, 105, 112, 117, 108, 97, 116, 101, 44, 32, 102, 105, 108, 116, 101,
  114, 32, 97, 110, 100, 32, 118, 105, 115, 117, 97, 108, 105, 122, 101, 32,
  100, 97, 116, 97, 115, 101, 116, 115, 32, 109, 97, 100, 101, 32, 111, 102,
  32, 111, 110, 101, 32, 111, 114, 32, 115, 101, 118, 101, 114, 97, 108, 32,
  49, 100, 47, 50, 100, 32, 111, 114, 32, 51, 100, 32, 109, 117, 108, 116,
  105, 45, 10, 92, 110, 32, 32, 115, 112, 101, 99, 116, 114, 97, 108, 32,
  105, 109, 97, 103, 101, 115, 46, 10, 92, 110, 10, 92, 110, 32, 84, 104,
  105, 115, 32, 100, 111, 99, 117, 109, 101, 110, 116, 97, 116, 105, 111, 110,
  32, 112, 114, 111, 112, 111, 115, 101, 115, 32, 97, 32, 99, 111, 109, 112,
  108, 101, 116, 101, 32, 100, 101, 115, 99, 114, 105, 112, 116, 105, 111, 110,
  32, 111, 102, 32, 116, 104, 101, 32, 71, 39, 77, 73, 67, 32, 108, 97,
  110, 103, 117, 97, 103, 101, 32, 98, 97, 115, 105, 99, 115, 32, 97, 110,
  100, 32, 114, 117, 108, 101, 115, 46, 34, 10, 45, 95, 104, 101, 108, 112,
  95, 115, 101, 99, 116, 105, 111, 110, 32, 34, 79, 118, 101, 114, 97, 108,
  108, 32, 99, 111, 110, 116, 101, 120, 116, 34, 10, 45, 95, 104, 101, 108,
  112, 95, 112, 97, 114, 97, 103, 114, 97, 112, 104, 32, 34, 32, 32, 45,
  32, 65, 116, 32, 97, 110, 121, 32, 116, 105, 109, 101, 44, 32, 71, 39,
  77, 73, 67, 32, 109, 97, 110, 97, 103, 101, 115, 32, 111, 110, 101, 32,
  108, 105, 115, 116, 32, 111, 102, 32, 110, 117, 109, 98, 101, 114, 101, 100,
  32, 40, 97, 110, 100, 32, 111, 112, 116, 105, 111, 110, 97, 108, 108, 121,
  32, 110, 97, 109, 101, 100, 41, 32, 112, 105, 120, 101, 108, 45, 98, 97,
  115, 101, 100, 10, 92, 110, 32, 32, 32, 32, 32, 105, 109, 97, 103, 101,
  115, 44, 32, 101, 110, 116, 105, 114, 101, 108, 121, 32, 115, 116, 111, 114,
  101, 100, 32, 105, 110, 32, 99, 111, 109, 112, 117, 116, 101, 114, 32, 109,
  101, 109, 111, 114, 121, 46, 10, 92, 110, 32, 32, 45, 32, 84, 104, 101,
  32, 102, 105, 114, 115, 116, 32, 105, 109, 97, 103, 101, 32, 111, 102, 32,
  116, 104, 101, 32, 108, 105, 115, 116, 32, 104, 97, 115, 32, 105, 110, 100,
  105, 99, 101, 32, 39, 48, 39, 32, 97, 110, 100, 32, 105, 115, 32, 100,
  101, 110, 111, 116, 101, 100, 32, 98, 121, 32, 39, 91, 48, 93, 39, 46,
  32, 84, 104, 101, 32, 115, 101, 99, 111, 110, 100, 32, 105, 109, 97, 103,
  101, 32, 111, 102, 10, 92, 110, 32, 32, 32, 32, 32, 116, 104, 101, 32,
  108, 105, 115, 116, 32, 105, 115, 32, 100, 101, 110, 111, 116, 101, 100, 32,
  98, 121, 32, 39, 91, 49, 93, 39, 44, 32, 116, 104, 101, 32, 116, 104,
  105, 114, 100, 32, 98, 121, 32, 39, 91, 50, 93, 39, 32, 97, 110, 100,
  32, 115, 111, 32, 111, 110, 46, 10, 92, 110, 32, 32, 45, 32, 78, 101,
  103, 97, 116, 105, 118, 101, 32, 105, 110, 100, 105, 99, 101, 115, 32, 97,
  114, 101, 32, 116, 114, 101, 97, 116, 101, 100, 32, 105, 110, 32, 97, 32,
  99, 121, 99, 108, 105, 99, 32, 119, 97, 121, 58, 32, 39, 91, 45, 49,
  93, 39, 32, 114, 101, 102, 101, 114, 115, 32, 116, 111, 32, 116, 104, 101,
  32, 108, 97, 115, 116, 32, 105, 109, 97, 103, 101, 32, 111, 102, 32, 116,
  104, 101, 10, 92, 110, 32, 32, 32, 32, 32, 108, 105, 115, 116, 44, 32,
  39, 91, 45, 50, 93, 39, 32, 116, 111, 32, 116, 104, 101, 32, 112, 101,
  110, 117, 108, 116, 105, 109, 97, 116, 101, 32, 111, 110, 101, 44, 32, 101,
  116, 99, 46, 32, 84, 104, 117, 115, 44, 32, 105, 102, 32, 116, 104, 101,
  32, 108, 105, 115, 116, 32, 104, 97, 115, 32, 52, 32, 105, 109, 97, 103,
  101, 115, 44, 32, 39, 91, 49, 93, 39, 32, 97, 110, 100, 32, 39, 91,
  45, 51, 93, 39, 10, 92, 110, 32, 32, 32, 32, 32, 98, 111, 116, 104,
  32, 100, 101, 115, 105, 103, 110, 97, 116, 101, 32, 116, 104, 101, 32, 115,
  101, 99, 111, 110, 100, 32, 105, 109, 97, 103, 101, 32, 111, 102, 32, 116,
  104, 101, 32, 108, 105, 115, 116, 46, 10, 92, 110, 32, 32, 45, 32, 65,
  32, 110, 97, 109, 101, 100, 32, 105, 109, 97, 103, 101, 32, 109, 97, 121,
  32, 98, 101, 32, 100, 101, 110, 111, 116, 101, 100, 32, 98, 121, 32, 39,
  91, 110, 97, 109, 101, 93, 39, 32, 105, 102, 32, 39, 110, 97, 109, 101,
  39, 32, 117, 115, 101, 115, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114,
  115, 32, 115, 101, 116, 32, 91, 97, 45, 122, 65, 45, 90, 48, 45, 57,
  95, 93, 32, 97, 110, 100, 10, 92, 110, 32, 32, 32, 32, 32, 100, 111,
  101, 115, 32, 110, 111, 116, 32, 115, 116, 97, 114, 116, 32, 119, 105, 116,
  104, 32, 97, 32, 110, 117, 109, 98, 101, 114, 46, 32, 73, 109, 97, 103,
  101, 32, 110, 97, 109, 101, 115, 32, 99, 97, 110, 32, 98, 101, 32, 115,
  101, 116, 32, 111, 114, 32, 114, 101, 97, 115, 115, 105, 103, 110, 101, 100,
  32, 97, 116, 32, 97, 110, 121, 32, 109, 111, 109, 101, 110, 116, 32, 100,
  117, 114, 105, 110, 103, 10, 92, 110, 32, 32, 32, 32, 32, 116, 104, 101,
  32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 112, 105, 112, 101,
  108, 105, 110, 101, 32, 40, 115, 101, 101, 32, 99, 111, 109, 109, 97, 110,
  100, 115, 32, 39, 45, 110, 97, 109, 101, 39, 32, 97, 110, 100, 32, 39,
  45, 105, 110, 112, 117, 116, 39, 41, 46, 10, 92, 110, 32, 32, 45, 32,
  71, 39, 77, 73, 67, 32, 100, 101, 102, 105, 110, 101, 115, 32, 97, 32,
  115, 101, 116, 32, 111, 102, 32, 118, 97, 114, 105, 111, 117, 115, 32, 99,
  111, 109, 109, 97, 110, 100, 115, 32, 97, 110, 100, 32, 115, 117, 98, 115,
  116, 105, 116, 117, 116, 105, 111, 110, 32, 109, 101, 99, 104, 97, 110, 105,
  115, 109, 115, 32, 116, 111, 32, 97, 108, 108, 111, 119, 32, 116, 104, 101,
  32, 100, 101, 115, 105, 103, 110, 10, 92, 110, 32, 32, 32, 32, 32, 111,
  102, 32, 99, 111, 109, 112, 108, 101, 120, 32, 112, 105, 112, 101, 108, 105,
  110, 101, 115, 32, 109, 97, 110, 97, 103, 105, 110, 103, 32, 116, 104, 105,
  115, 32, 108, 105, 115, 116, 32, 111, 102, 32, 105, 109, 97, 103, 101, 115,
  44, 32, 105, 110, 32, 97, 32, 118, 101, 114, 121, 32, 102, 108, 101, 120,
  105, 98, 108, 101, 32, 119, 97, 121, 58, 10, 92, 110, 32, 32, 32, 32,
  32, 89, 111, 117, 32, 99, 97, 110, 32, 105, 110, 115, 101, 114, 116, 32,
  111, 114, 32, 114, 101, 109, 111, 118, 101, 32, 105, 109, 97, 103, 101, 115,
  32, 105, 110, 32, 116, 104, 101, 32, 108, 105, 115, 116, 44, 32, 114, 101,
  97, 114, 114, 97, 110, 103, 101, 32, 105, 109, 97, 103, 101, 32, 105, 110,
  100, 105, 99, 101, 115, 44, 32, 112, 114, 111, 99, 101, 115, 115, 32, 105,
  109, 97, 103, 101, 115, 10, 92, 110, 32, 32, 32, 32, 32, 40, 105, 110,
  100, 105, 118, 105, 100, 117, 97, 108, 108, 121, 32, 111, 114, 32, 97, 115,
  32, 97, 32, 103, 114, 111, 117, 112, 41, 44, 32, 109, 101, 114, 103, 101,
  32, 105, 109, 97, 103, 101, 32, 100, 97, 116, 97, 32, 116, 111, 103, 101,
  116, 104, 101, 114, 32, 97, 110, 100, 32, 111, 117, 116, 112, 117, 116, 32,
  105, 109, 97, 103, 101, 32, 102, 105, 108, 101, 115, 46, 10, 92, 110, 32,
  32, 45, 32, 83, 117, 99, 104, 32, 97, 32, 112, 105, 112, 101, 108, 105,
  110, 101, 32, 99, 97, 110, 32, 98, 101, 32, 119, 114, 105, 116, 116, 101,
  110, 32, 105, 116, 115, 101, 108, 102, 32, 97, 115, 32, 97, 32, 99, 117,
  115, 116, 111, 109, 32, 71, 39, 77, 73, 67, 32, 99, 111, 109, 109, 97,
  110, 100, 32, 115, 116, 111, 114, 97, 98, 108, 101, 32, 105, 110, 32, 97,
  32, 99, 117, 115, 116, 111, 109, 10, 92, 110, 32, 32, 32, 32, 32, 99,
  111, 109, 109, 97, 110, 100, 115, 32, 102, 105, 108, 101, 44, 32, 119, 104,
  105, 99, 104, 32, 99, 97, 110, 32, 98, 101, 32, 114, 101, 45, 117, 115,
  101, 100, 32, 97, 102, 116, 101, 114, 119, 97, 114, 100, 115, 32, 105, 110,
  32, 97, 110, 111, 116, 104, 101, 114, 32, 98, 105, 103, 103, 101, 114, 32,
  112, 105, 112, 101, 108, 105, 110, 101, 32, 105, 102, 32, 110, 101, 99, 101,
  115, 115, 97, 114, 121, 46, 34, 10, 45, 95, 104, 101, 108, 112, 95, 115,
  101, 99, 116, 105, 111, 110, 32, 34, 73, 109, 97, 103, 101, 32, 100, 101,
  102, 105, 110, 105, 116, 105, 111, 110, 32, 97, 110, 100, 32, 116, 101, 114,
  109, 105, 110, 111, 108, 111, 103, 121, 34, 10, 45, 95, 104, 101, 108, 112,
  95, 112, 97, 114, 97, 103, 114, 97, 112, 104, 32, 34, 32, 32, 45, 32,
  73, 110, 32, 71, 39, 77, 73, 67, 44, 32, 97, 110, 32, 105, 109, 97,
  103, 101, 32, 105, 115, 32, 109, 111, 100, 101, 108, 101, 100, 32, 97, 115,
  32, 97, 32, 49, 100, 44, 32, 50, 100, 44, 32, 51, 100, 32, 111, 114,
  32, 52, 100, 32, 97, 114, 114, 97, 121, 32, 111, 102, 32, 115, 99, 97,
  108, 97, 114, 32, 118, 97, 108, 117, 101, 115, 44, 32, 117, 110, 105, 102,
  111, 114, 109, 108, 121, 10, 92, 110, 32, 32, 32, 32, 32, 100, 105, 115,
  99, 114, 101, 116, 105, 122, 101, 100, 32, 111, 110, 32, 97, 32, 114, 101,
  99, 116, 97, 110, 103, 117, 108, 97, 114, 47, 112, 97, 114, 97, 108, 108,
  101, 108, 101, 112, 105, 112, 101, 100, 105, 99, 32, 100, 111, 109, 97, 105,
  110, 46, 10, 92, 110, 32, 32, 45, 32, 84, 104, 101, 32, 102, 111, 117,
  114, 32, 100, 105, 109, 101, 110, 115, 105, 111, 110, 115, 32, 111, 102, 32,
  116, 104, 101, 115, 101, 32, 97, 114, 114, 97, 121, 115, 32, 97, 114, 101,
  32, 114, 101, 115, 112, 101, 99, 116, 105, 118, 101, 108, 121, 32, 100, 101,
  110, 111, 116, 101, 100, 32, 98, 121, 58, 10, 92, 110, 32, 32, 32, 32,
  46, 32, 39, 119, 105, 100, 116, 104, 39, 44, 32, 116, 104, 101, 32, 110,
  117, 109, 98, 101, 114, 32, 111, 102, 32, 105, 109, 97, 103, 101, 32, 99,
  111, 108, 117, 109, 110, 115, 32, 40, 115, 105, 122, 101, 32, 97, 108, 111,
  110, 103, 32, 116, 104, 101, 32, 39, 120, 39, 45, 97, 120, 105, 115, 41,
  46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 104, 101, 105, 103, 104,
  116, 39, 44, 32, 116, 104, 101, 32, 110, 117, 109, 98, 101, 114, 32, 111,
  102, 32, 105, 109, 97, 103, 101, 32, 114, 111, 119, 115, 32, 40, 115, 105,
  122, 101, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 39, 121, 39,
  45, 97, 120, 105, 115, 41, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32,
  39, 100, 101, 112, 116, 104, 39, 44, 32, 116, 104, 101, 32, 110, 117, 109,
  98, 101, 114, 32, 111, 102, 32, 105, 109, 97, 103, 101, 32, 115, 108, 105,
  99, 101, 115, 32, 40, 115, 105, 122, 101, 32, 97, 108, 111, 110, 103, 32,
  116, 104, 101, 32, 39, 122, 39, 45, 97, 120, 105, 115, 41, 46, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 32, 84, 104, 101, 32, 100, 101, 112,
  116, 104, 32, 105, 115, 32, 101, 113, 117, 97, 108, 32, 116, 111, 32, 49,
  32, 102, 111, 114, 32, 117, 115, 117, 97, 108, 32, 50, 100, 32, 99, 111,
  108, 111, 114, 32, 111, 114, 32, 103, 114, 97, 121, 115, 99, 97, 108, 101,
  32, 105, 109, 97, 103, 101, 115, 46, 10, 92, 110, 32, 32, 32, 32, 46,
  32, 39, 115, 112, 101, 99, 116, 114, 117, 109, 39, 44, 32, 116, 104, 101,
  32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 105, 109, 97, 103, 101,
  32, 99, 104, 97, 110, 110, 101, 108, 115, 32, 40, 115, 105, 122, 101, 32,
  97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 39, 99, 39, 45, 97, 120,
  105, 115, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 84,
  104, 101, 32, 115, 112, 101, 99, 116, 114, 117, 109, 32, 105, 115, 32, 114,
  101, 115, 112, 101, 99, 116, 105, 118, 101, 108, 121, 32, 101, 113, 117, 97,
  108, 32, 116, 111, 32, 51, 32, 97, 110, 100, 32, 52, 32, 102, 111, 114,
  32, 117, 115, 117, 97, 108, 32, 82, 71, 66, 32, 97, 110, 100, 32, 82,
  71, 66, 65, 32, 99, 111, 108, 111, 114, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 92, 110, 32, 32, 45, 32, 84, 104, 101, 114, 101, 32, 97, 114,
  101, 32, 110, 111, 32, 115, 105, 122, 101, 32, 108, 105, 109, 105, 116, 97,
  116, 105, 111, 110, 115, 32, 111, 110, 32, 101, 97, 99, 104, 32, 105, 109,
  97, 103, 101, 32, 100, 105, 109, 101, 110, 115, 105, 111, 110, 115, 46, 32,
  80, 97, 114, 116, 105, 99, 117, 108, 97, 114, 108, 121, 44, 32, 116, 104,
  101, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 105, 109, 97, 103,
  101, 10, 92, 110, 32, 32, 32, 32, 32, 115, 108, 105, 99, 101, 115, 32,
  111, 114, 32, 99, 104, 97, 110, 110, 101, 108, 115, 32, 99, 97, 110, 32,
  98, 101, 32, 111, 102, 32, 97, 114, 98, 105, 116, 114, 97, 114, 121, 32,
  115, 105, 122, 101, 32, 119, 105, 116, 104, 105, 110, 32, 116, 104, 101, 32,
  108, 105, 109, 105, 116, 115, 32, 111, 102, 32, 97, 118, 97, 105, 108, 97,
  98, 108, 101, 32, 109, 101, 109, 111, 114, 121, 46, 10, 92, 110, 32, 32,
  45, 32, 84, 104, 101, 32, 119, 105, 100, 116, 104, 44, 32, 104, 101, 105,
  103, 104, 116, 32, 97, 110, 100, 32, 100, 101, 112, 116, 104, 32, 111, 102,
  32, 97, 110, 32, 105, 109, 97, 103, 101, 32, 97, 114, 101, 32, 99, 111,
  110, 115, 105, 100, 101, 114, 101, 100, 32, 97, 115, 32, 39, 115, 112, 97,
  116, 105, 97, 108, 39, 32, 100, 105, 109, 101, 110, 115, 105, 111, 110, 115,
  44, 32, 119, 104, 105, 108, 101, 32, 116, 104, 101, 10, 92, 110, 32, 32,
  32, 32, 32, 115, 112, 101, 99, 116, 114, 117, 109, 32, 104, 97, 115, 32,
  97, 32, 39, 109, 117, 108, 116, 105, 45, 115, 112, 101, 99, 116, 114, 97,
  108, 39, 32, 109, 101, 97, 110, 105, 110, 103, 46, 32, 84, 104, 117, 115,
  44, 32, 97, 32, 52, 100, 32, 105, 109, 97, 103, 101, 32, 105, 110, 32,
  71, 39, 77, 73, 67, 32, 115, 104, 111, 117, 108, 100, 32, 98, 101, 32,
  109, 111, 115, 116, 32, 111, 102, 116, 101, 110, 10, 92, 110, 32, 32, 32,
  32, 32, 114, 101, 103, 97, 114, 100, 101, 100, 32, 97, 115, 32, 97, 32,
  51, 100, 32, 100, 97, 116, 97, 115, 101, 116, 32, 111, 102, 32, 109, 117,
  108, 116, 105, 45, 115, 112, 101, 99, 116, 114, 97, 108, 32, 118, 111, 120,
  101, 108, 115, 46, 32, 77, 111, 115, 116, 32, 111, 102, 32, 116, 104, 101,
  32, 71, 39, 77, 73, 67, 32, 99, 111, 109, 109, 97, 110, 100, 115, 32,
  119, 105, 108, 108, 32, 115, 116, 105, 99, 107, 10, 92, 110, 32, 32, 32,
  32, 32, 119, 105, 116, 104, 32, 116, 104, 105, 115, 32, 105, 100, 101, 97,
  32, 40, 101, 46, 103, 46, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39,
  45, 98, 108, 117, 114, 39, 32, 119, 105, 108, 108, 32, 98, 108, 117, 114,
  32, 105, 109, 97, 103, 101, 115, 32, 111, 110, 108, 121, 32, 97, 108, 111,
  110, 103, 32, 116, 104, 101, 32, 39, 120, 121, 122, 39, 32, 97, 120, 101,
  115, 41, 46, 10, 92, 110, 32, 32, 45, 32, 65, 108, 108, 32, 112, 105,
  120, 101, 108, 32, 118, 97, 108, 117, 101, 115, 32, 111, 102, 32, 97, 108,
  108, 32, 105, 109, 97, 103, 101, 115, 32, 111, 102, 32, 116, 104, 101, 32,
  108, 105, 115, 116, 32, 104, 97, 118, 101, 32, 116, 104, 101, 32, 115, 97,
  109, 101, 32, 100, 97, 116, 97, 116, 121, 112, 101, 46, 32, 73, 116, 32,
  99, 97, 110, 32, 98, 101, 32, 111, 110, 101, 32, 97, 109, 111, 110, 103,
  58, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 98, 111, 111, 108, 39,
  58, 32, 83, 116, 97, 110, 100, 115, 32, 102, 111, 114, 32, 39, 98, 111,
  111, 108, 101, 97, 110, 39, 46, 32, 86, 97, 108, 117, 101, 32, 114, 97,
  110, 103, 101, 32, 105, 115, 32, 123, 32, 48, 61, 102, 97, 108, 115, 101,
  32, 124, 32, 49, 61, 116, 114, 117, 101, 32, 125, 46, 10, 92, 110, 32,
  32, 32, 32, 46, 32, 39, 117, 99, 104, 97, 114, 39, 58, 32, 83, 116,
  97, 110, 100, 115, 32, 102, 111, 114, 32, 39, 117, 110, 115, 105, 103, 110,
  101, 100, 32, 99, 104, 97, 114, 39, 46, 32, 86, 97, 108, 117, 101, 32,
  114, 97, 110, 103, 101, 32, 105, 115, 32, 91, 48, 44, 50, 53, 53, 93,
  32, 40, 56, 98, 105, 116, 115, 41, 46, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 32, 84, 104, 105, 115, 32, 116, 121, 112, 101, 32, 111, 102,
  32, 112, 105, 120, 101, 108, 32, 99, 111, 100, 105, 110, 103, 32, 105, 115,
  32, 99, 111, 109, 109, 111, 110, 108, 121, 32, 117, 115, 101, 100, 32, 116,
  111, 32, 115, 116, 111, 114, 101, 32, 56, 98, 105, 116, 115, 47, 99, 104,
  97, 110, 110, 101, 108, 115, 32, 82, 71, 66, 91, 65, 93, 32, 105, 109,
  97, 103, 101, 115, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 99,
  104, 97, 114, 39, 58, 32, 86, 97, 108, 117, 101, 32, 114, 97, 110, 103,
  101, 32, 105, 115, 32, 91, 45, 49, 50, 56, 44, 49, 50, 55, 93, 32,
  40, 56, 98, 105, 116, 115, 41, 46, 10, 92, 110, 32, 32, 32, 32, 46,
  32, 39, 117, 115, 104, 111, 114, 116, 39, 58, 32, 83, 116, 97, 110, 100,
  115, 32, 102, 111, 114, 32, 39, 117, 110, 115, 105, 103, 110, 101, 100, 32,
  115, 104, 111, 114, 116, 39, 46, 32, 86, 97, 108, 117, 101, 32, 114, 97,
  110, 103, 101, 32, 105, 115, 32, 91, 48, 44, 54, 53, 53, 51, 53, 93,
  32, 40, 49, 54, 98, 105, 116, 115, 41, 46, 10, 92, 110, 32, 32, 32,
  32, 32, 32, 32, 32, 84, 104, 105, 115, 32, 116, 121, 112, 101, 32, 111,
  102, 32, 112, 105, 120, 101, 108, 32, 99, 111, 100, 105, 110, 103, 32, 105,
  115, 32, 99, 111, 109, 109, 111, 110, 108, 121, 32, 117, 115, 101, 100, 32,
  116, 111, 32, 115, 116, 111, 114, 101, 32, 49, 54, 98, 105, 116, 115, 47,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 82, 71, 66, 91, 65, 93, 32,
  105, 109, 97, 103, 101, 115, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32,
  39, 115, 104, 111, 114, 116, 39, 58, 32, 86, 97, 108, 117, 101, 32, 114,
  97, 110, 103, 101, 32, 105, 115, 32, 91, 45, 51, 50, 55, 54, 56, 44,
  51, 50, 55, 54, 55, 93, 32, 40, 49, 54, 98, 105, 116, 115, 41, 46,
  10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 117, 105, 110, 116, 39, 58,
  32, 83, 116, 97, 110, 100, 115, 32, 102, 111, 114, 32, 39, 117, 110, 115,
  105, 103, 110, 101, 100, 32, 105, 110, 116, 39, 46, 32, 86, 97, 108, 117,
  101, 32, 114, 97, 110, 103, 101, 32, 105, 115, 32, 91, 48, 44, 50, 94,
  51, 50, 45, 49, 93, 32, 40, 51, 50, 98, 105, 116, 115, 41, 46, 10,
  92, 110, 32, 32, 32, 32, 46, 32, 39, 105, 110, 116, 39, 58, 32, 86,
  97, 108, 117, 101, 32, 114, 97, 110, 103, 101, 32, 105, 115, 32, 91, 45,
  50, 94, 51, 49, 44, 50, 94, 51, 49, 45, 49, 93, 32, 40, 51, 50,
  32, 98, 105, 116, 115, 41, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32,
  39, 102, 108, 111, 97, 116, 39, 58, 32, 86, 97, 108, 117, 101, 32, 114,
  97, 110, 103, 101, 32, 105, 115, 32, 91, 45, 51, 46, 52, 69, 51, 56,
  44, 43, 51, 46, 52, 69, 51, 56, 93, 32, 40, 51, 50, 98, 105, 116,
  115, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 84, 104,
  105, 115, 32, 116, 121, 112, 101, 32, 111, 102, 32, 99, 111, 100, 105, 110,
  103, 32, 105, 115, 32, 97, 98, 108, 101, 32, 116, 111, 32, 115, 116, 111,
  114, 101, 32, 112, 105, 120, 101, 108, 115, 32, 97, 115, 32, 51, 50, 32,
  98, 105, 116, 115, 32, 102, 108, 111, 97, 116, 45, 118, 97, 108, 117, 101,
  100, 32, 110, 117, 109, 98, 101, 114, 115, 46, 32, 84, 104, 105, 115, 32,
  105, 115, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 116, 104, 101,
  32, 100, 101, 102, 97, 117, 108, 116, 32, 100, 97, 116, 97, 116, 121, 112,
  101, 32, 117, 115, 101, 100, 32, 98, 121, 32, 71, 39, 77, 73, 67, 32,
  105, 109, 97, 103, 101, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103,
  32, 111, 112, 101, 114, 97, 116, 105, 111, 110, 115, 46, 10, 92, 110, 32,
  32, 32, 32, 46, 32, 39, 100, 111, 117, 98, 108, 101, 39, 58, 32, 86,
  97, 108, 117, 101, 32, 114, 97, 110, 103, 101, 32, 105, 115, 32, 91, 45,
  49, 46, 55, 69, 51, 48, 56, 44, 49, 46, 55, 69, 51, 48, 56, 93,
  32, 40, 54, 52, 98, 105, 116, 115, 41, 46, 10, 92, 110, 32, 32, 32,
  32, 32, 32, 32, 32, 84, 104, 105, 115, 32, 116, 121, 112, 101, 32, 111,
  102, 32, 99, 111, 100, 105, 110, 103, 32, 105, 115, 32, 97, 98, 108, 101,
  32, 116, 111, 32, 115, 116, 111, 114, 101, 32, 112, 105, 120, 101, 108, 115,
  32, 97, 115, 32, 54, 52, 32, 98, 105, 116, 115, 32, 102, 108, 111, 97,
  116, 45, 118, 97, 108, 117, 101, 100, 32, 110, 117, 109, 98, 101, 114, 115,
  46, 10, 92, 110, 32, 32, 45, 32, 67, 111, 110, 115, 105, 100, 101, 114,
  105, 110, 103, 32, 112, 105, 120, 101, 108, 32, 100, 97, 116, 97, 116, 121,
  112, 101, 115, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32, 116, 104,
  97, 110, 32, 39, 102, 108, 111, 97, 116, 39, 32, 105, 115, 32, 103, 101,
  110, 101, 114, 97, 108, 108, 121, 32, 117, 115, 101, 108, 101, 115, 115, 44,
  32, 101, 120, 99, 101, 112, 116, 32, 116, 111, 32, 102, 111, 114, 99, 101,
  10, 92, 110, 32, 32, 32, 32, 32, 116, 104, 101, 32, 105, 110, 112, 117,
  116, 47, 111, 117, 116, 112, 117, 116, 32, 111, 102, 32, 105, 109, 97, 103,
  101, 32, 100, 97, 116, 97, 32, 116, 111, 32, 97, 32, 112, 114, 101, 115,
  99, 114, 105, 98, 101, 100, 32, 98, 105, 110, 97, 114, 121, 32, 102, 111,
  114, 109, 97, 116, 46, 32, 72, 101, 110, 99, 101, 44, 32, 109, 111, 115,
  116, 32, 71, 39, 77, 73, 67, 32, 105, 109, 97, 103, 101, 10, 92, 110,
  32, 32, 32, 32, 32, 105, 109, 97, 103, 101, 32, 112, 114, 111, 99, 101,
  115, 115, 105, 110, 103, 32, 99, 111, 109, 109, 97, 110, 100, 115, 32, 97,
  114, 101, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 32, 111, 110, 108,
  121, 32, 102, 111, 114, 32, 116, 104, 101, 32, 100, 101, 102, 97, 117, 108,
  116, 32, 39, 102, 108, 111, 97, 116, 39, 32, 112, 105, 120, 101, 108, 32,
  100, 97, 116, 97, 116, 121, 112, 101, 10, 92, 110, 32, 32, 32, 32, 32,
  40, 115, 101, 101, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 45, 116,
  121, 112, 101, 39, 32, 105, 102, 32, 121, 111, 117, 32, 110, 101, 101, 100,
  32, 116, 111, 32, 115, 119, 105, 116, 99, 104, 32, 116, 111, 32, 97, 110,
  111, 116, 104, 101, 114, 32, 112, 105, 120, 101, 108, 32, 100, 97, 116, 97,
  116, 121, 112, 101, 41, 46, 34, 10, 45, 95, 104, 101, 108, 112, 95, 115,
  101, 99, 116, 105, 111, 110, 32, 34, 73, 116, 101, 109, 115, 32, 111, 102,
  32, 97, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 112, 105,
  112, 101, 108, 105, 110, 101, 34, 10, 45, 95, 104, 101, 108, 112, 95, 112,
  97, 114, 97, 103, 114, 97, 112, 104, 32, 34, 32, 32, 45, 32, 73, 110,
  32, 71, 39, 77, 73, 67, 44, 32, 97, 110, 32, 105, 109, 97, 103, 101,
  32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 112, 105, 112, 101,
  108, 105, 110, 101, 32, 105, 115, 32, 100, 101, 115, 99, 114, 105, 98, 101,
  100, 32, 97, 115, 32, 97, 32, 115, 101, 113, 117, 101, 110, 99, 101, 32,
  111, 102, 32, 105, 116, 101, 109, 115, 32, 115, 101, 112, 97, 114, 97, 116,
  101, 100, 32, 98, 121, 10, 92, 110, 32, 32, 32, 32, 32, 116, 104, 101,
  32, 115, 112, 97, 99, 101, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114,
  32, 39, 32, 39, 46, 32, 83, 117, 99, 104, 32, 105, 116, 101, 109, 115,
  32, 97, 114, 101, 32, 105, 110, 116, 101, 114, 112, 114, 101, 116, 101, 100,
  32, 97, 110, 100, 32, 101, 120, 101, 99, 117, 116, 101, 100, 32, 102, 114,
  111, 109, 32, 116, 104, 101, 32, 108, 101, 102, 116, 32, 116, 111, 32, 116,
  104, 101, 10, 92, 110, 32, 32, 32, 32, 32, 114, 105, 103, 104, 116, 46,
  32, 70, 111, 114, 32, 105, 110, 115, 116, 97, 110, 99, 101, 44, 32, 116,
  104, 101, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 58, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 39, 105, 110, 112, 117, 116, 46, 106,
  112, 103, 32, 45, 98, 108, 117, 114, 32, 51, 44, 48, 32, 45, 115, 104,
  97, 114, 112, 101, 110, 32, 49, 48, 32, 45, 114, 101, 115, 105, 122, 101,
  32, 50, 48, 48, 37, 44, 50, 48, 48, 37, 32, 45, 111, 117, 116, 112,
  117, 116, 32, 111, 117, 116, 112, 117, 116, 46, 106, 112, 103, 39, 10, 92,
  110, 32, 32, 32, 32, 32, 100, 101, 102, 105, 110, 101, 115, 32, 97, 32,
  118, 97, 108, 105, 100, 32, 112, 105, 112, 101, 108, 105, 110, 101, 32, 99,
  111, 109, 112, 111, 115, 101, 100, 32, 111, 102, 32, 110, 105, 110, 101, 32,
  71, 39, 77, 73, 67, 32, 105, 116, 101, 109, 115, 46, 10, 92, 110, 32,
  32, 45, 32, 65, 32, 71, 39, 77, 73, 67, 32, 105, 116, 101, 109, 32,
  105, 115, 32, 97, 32, 115, 116, 114, 105, 110, 103, 32, 119, 104, 105, 99,
  104, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 115, 32, 101, 105, 116,
  104, 101, 114, 32, 97, 32, 99, 111, 109, 109, 97, 110, 100, 44, 32, 97,
  32, 115, 101, 116, 32, 111, 102, 32, 99, 111, 109, 109, 97, 110, 100, 32,
  97, 114, 103, 117, 109, 101, 110, 116, 115, 44, 10, 92, 110, 32, 32, 32,
  32, 32, 97, 32, 102, 105, 108, 101, 110, 97, 109, 101, 44, 32, 111, 114,
  32, 97, 32, 115, 112, 101, 99, 105, 97, 108, 32, 105, 110, 112, 117, 116,
  32, 115, 116, 114, 105, 110, 103, 46, 10, 92, 110, 32, 32, 45, 32, 69,
  115, 99, 97, 112, 101, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 115,
  32, 39, 92, 92, 39, 32, 97, 110, 100, 32, 100, 111, 117, 98, 108, 101,
  32, 113, 117, 111, 116, 101, 115, 32, 39, 92, 34, 39, 32, 99, 97, 110,
  32, 98, 101, 32, 117, 115, 101, 100, 32, 40, 97, 115, 32, 117, 115, 117,
  97, 108, 41, 32, 116, 111, 32, 100, 101, 102, 105, 110, 101, 32, 105, 116,
  101, 109, 115, 10, 92, 110, 32, 32, 32, 32, 32, 99, 111, 110, 116, 97,
  105, 110, 105, 110, 103, 32, 115, 112, 97, 99, 101, 115, 44, 32, 111, 114,
  32, 97, 110, 121, 32, 111, 116, 104, 101, 114, 32, 99, 104, 97, 114, 97,
  99, 116, 101, 114, 32, 115, 101, 113, 117, 101, 110, 99, 101, 115, 46, 32,
  70, 111, 114, 32, 105, 110, 115, 116, 97, 110, 99, 101, 44, 32, 116, 104,
  101, 32, 115, 116, 114, 105, 110, 103, 115, 10, 92, 110, 32, 32, 32, 32,
  32, 39, 115, 105, 110, 103, 108, 101, 92, 92, 32, 105, 116, 101, 109, 39,
  32, 97, 110, 100, 32, 39, 92, 34, 115, 105, 110, 103, 108, 101, 32, 105,
  116, 101, 109, 92, 34, 39, 32, 100, 101, 102, 105, 110, 101, 32, 116, 104,
  101, 32, 115, 97, 109, 101, 32, 115, 116, 114, 105, 110, 103, 32, 105, 116,
  101, 109, 44, 32, 119, 105, 116, 104, 32, 97, 32, 115, 112, 97, 99, 101,
  32, 105, 110, 32, 105, 116, 46, 34, 10, 45, 95, 104, 101, 108, 112, 95,
  115, 101, 99, 116, 105, 111, 110, 32, 34, 73, 110, 112, 117, 116, 32, 100,
  97, 116, 97, 32, 105, 116, 101, 109, 115, 34, 10, 45, 95, 104, 101, 108,
  112, 95, 112, 97, 114, 97, 103, 114, 97, 112, 104, 32, 34, 32, 32, 45,
  32, 73, 102, 32, 97, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  71, 39, 77, 73, 67, 32, 105, 116, 101, 109, 32, 97, 112, 112, 101, 97,
  114, 115, 32, 116, 111, 32, 98, 101, 32, 97, 110, 32, 101, 120, 105, 115,
  116, 105, 110, 103, 32, 102, 105, 108, 101, 110, 97, 109, 101, 44, 32, 116,
  104, 101, 32, 99, 111, 114, 114, 101, 115, 112, 111, 110, 100, 105, 110, 103,
  32, 105, 109, 97, 103, 101, 10, 92, 110, 32, 32, 32, 32, 32, 100, 97,
  116, 97, 32, 97, 114, 101, 32, 108, 111, 97, 100, 101, 100, 32, 97, 110,
  100, 32, 105, 110, 115, 101, 114, 116, 101, 100, 32, 97, 116, 32, 116, 104,
  101, 32, 101, 110, 100, 32, 111, 102, 32, 116, 104, 101, 32, 105, 109, 97,
  103, 101, 32, 108, 105, 115, 116, 46, 10, 92, 110, 32, 32, 45, 32, 83,
  112, 101, 99, 105, 97, 108, 32, 102, 105, 108, 101, 110, 97, 109, 101, 115,
  32, 39, 45, 39, 32, 97, 110, 100, 32, 39, 45, 46, 101, 120, 116, 39,
  32, 115, 116, 97, 110, 100, 32, 102, 111, 114, 32, 116, 104, 101, 32, 115,
  116, 97, 110, 100, 97, 114, 100, 32, 105, 110, 112, 117, 116, 47, 111, 117,
  116, 112, 117, 116, 32, 115, 116, 114, 101, 97, 109, 115, 44, 32, 111, 112,
  116, 105, 111, 110, 97, 108, 108, 121, 10, 92, 110, 32, 32, 32, 32, 32,
  102, 111, 114, 99, 101, 100, 32, 116, 111, 32, 98, 101, 32, 105, 110, 32,
  97, 32, 115, 112, 101, 99, 105, 102, 105, 99, 32, 39, 101, 120, 116, 39,
  32, 102, 105, 108, 101, 32, 102, 111, 114, 109, 97, 116, 32, 40, 101, 46,
  103, 46, 32, 39, 45, 46, 106, 112, 103, 39, 32, 111, 114, 32, 39, 45,
  46, 112, 110, 103, 39, 41, 46, 10, 92, 110, 32, 32, 45, 32, 84, 104,
  101, 32, 102, 111, 108, 108, 111, 119, 105, 110, 103, 32, 115, 112, 101, 99,
  105, 97, 108, 32, 105, 110, 112, 117, 116, 32, 115, 116, 114, 105, 110, 103,
  115, 32, 109, 97, 121, 32, 98, 101, 32, 117, 115, 101, 100, 32, 97, 115,
  32, 71, 39, 77, 73, 67, 32, 105, 116, 101, 109, 115, 32, 116, 111, 32,
  99, 114, 101, 97, 116, 101, 32, 97, 110, 100, 32, 105, 110, 115, 101, 114,
  116, 32, 110, 101, 119, 10, 92, 110, 32, 32, 32, 32, 32, 105, 109, 97,
  103, 101, 115, 32, 119, 105, 116, 104, 32, 112, 114, 101, 115, 99, 114, 105,
  98, 101, 100, 32, 118, 97, 108, 117, 101, 115, 44, 32, 97, 116, 32, 116,
  104, 101, 32, 101, 110, 100, 32, 111, 102, 32, 116, 104, 101, 32, 105, 109,
  97, 103, 101, 32, 108, 105, 115, 116, 58, 10, 92, 110, 32, 32, 32, 32,
  46, 32, 39, 91, 115, 101, 108, 101, 99, 116, 105, 111, 110, 93, 39, 32,
  111, 114, 32, 39, 91, 115, 101, 108, 101, 99, 116, 105, 111, 110, 93, 120,
  78, 39, 58, 32, 73, 110, 115, 101, 114, 116, 32, 49, 32, 111, 114, 32,
  78, 32, 99, 111, 112, 105, 101, 115, 32, 111, 102, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 101, 120, 105, 115, 116, 105, 110, 103, 32, 105, 109,
  97, 103, 101, 115, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 39,
  115, 101, 108, 101, 99, 116, 105, 111, 110, 39, 32, 109, 97, 121, 32, 99,
  111, 110, 116, 97, 105, 110, 32, 111, 110, 101, 32, 111, 114, 32, 115, 101,
  118, 101, 114, 97, 108, 32, 105, 109, 97, 103, 101, 115, 32, 40, 115, 101,
  101, 32, 110, 101, 120, 116, 32, 115, 101, 99, 116, 105, 111, 110, 32, 102,
  111, 114, 32, 100, 101, 116, 97, 105, 108, 115, 41, 46, 10, 92, 110, 32,
  32, 32, 32, 46, 32, 39, 119, 105, 100, 116, 104, 91, 37, 93, 44, 95,
  104, 101, 105, 103, 104, 116, 91, 37, 93, 44, 95, 100, 101, 112, 116, 104,
  91, 37, 93, 44, 95, 115, 112, 101, 99, 116, 114, 117, 109, 91, 37, 93,
  44, 95, 118, 97, 108, 117, 101, 115, 39, 58, 32, 73, 110, 115, 101, 114,
  116, 32, 97, 32, 110, 101, 119, 32, 105, 109, 97, 103, 101, 32, 119, 105,
  116, 104, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 115, 105, 122, 101, 32, 97, 110, 100, 32, 118,
  97, 108, 117, 101, 115, 32, 40, 97, 100, 100, 105, 110, 103, 32, 39, 37,
  39, 32, 116, 111, 32, 97, 32, 100, 105, 109, 101, 110, 115, 105, 111, 110,
  32, 109, 101, 97, 110, 115, 32, 39, 112, 101, 114, 99, 101, 110, 116, 97,
  103, 101, 32, 111, 102, 32, 116, 104, 101, 32, 115, 105, 122, 101, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 97, 108, 111, 110, 103, 32, 116, 104,
  101, 32, 115, 97, 109, 101, 32, 97, 120, 105, 115, 44, 32, 116, 97, 107,
  101, 110, 32, 102, 114, 111, 109, 32, 116, 104, 101, 32, 108, 97, 115, 116,
  32, 105, 109, 97, 103, 101, 32, 39, 91, 45, 49, 93, 39, 39, 41, 46,
  32, 65, 110, 121, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 100,
  105, 109, 101, 110, 115, 105, 111, 110, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 99, 97, 110, 32, 98, 101, 32, 97, 108, 115, 111, 32, 119, 114,
  105, 116, 116, 101, 110, 32, 97, 115, 32, 39, 91, 105, 109, 97, 103, 101,
  93, 39, 44, 32, 97, 110, 100, 32, 105, 115, 32, 116, 104, 101, 110, 32,
  115, 101, 116, 32, 116, 111, 32, 116, 104, 101, 32, 115, 105, 122, 101, 32,
  40, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32,
  97, 120, 105, 115, 41, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 111,
  102, 32, 116, 104, 101, 32, 101, 120, 105, 115, 116, 105, 110, 103, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 105, 109, 97, 103, 101, 32, 91,
  105, 109, 97, 103, 101, 93, 46, 32, 39, 118, 97, 108, 117, 101, 115, 39,
  32, 99, 97, 110, 32, 98, 101, 32, 101, 105, 116, 104, 101, 114, 32, 97,
  32, 115, 101, 113, 117, 101, 110, 99, 101, 32, 111, 102, 32, 110, 117, 109,
  98, 101, 114, 115, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 115, 101,
  112, 97, 114, 97, 116, 101, 100, 32, 98, 121, 32, 99, 111, 109, 109, 97,
  115, 32, 39, 44, 39, 44, 32, 111, 114, 32, 97, 32, 109, 97, 116, 104,
  101, 109, 97, 116, 105, 99, 97, 108, 32, 101, 120, 112, 114, 101, 115, 115,
  105, 111, 110, 44, 32, 97, 115, 32, 101, 46, 103, 46, 32, 105, 110, 32,
  105, 110, 112, 117, 116, 32, 105, 116, 101, 109, 10, 92, 110, 32, 32, 32,
  32, 32, 32, 32, 39, 50, 53, 54, 44, 50, 53, 54, 44, 49, 44, 51,
  44, 105, 102, 40, 99, 61, 61, 48, 44, 120, 44, 105, 102, 40, 99, 61,
  61, 49, 44, 121, 44, 48, 41, 41, 39, 32, 119, 104, 105, 99, 104, 32,
  99, 114, 101, 97, 116, 101, 115, 32, 97, 32, 50, 53, 54, 120, 50, 53,
  54, 32, 82, 71, 66, 32, 99, 111, 108, 111, 114, 32, 105, 109, 97, 103,
  101, 32, 119, 105, 116, 104, 32, 97, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 115, 112, 97, 116, 105, 97, 108, 32, 115, 104, 97, 100, 105, 110,
  103, 32, 111, 110, 32, 116, 104, 101, 32, 114, 101, 100, 32, 97, 110, 100,
  32, 103, 114, 101, 101, 110, 32, 99, 104, 97, 110, 110, 101, 108, 115, 46,
  10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 40, 118, 49, 44, 118, 50,
  44, 46, 46, 41, 39, 58, 32, 73, 110, 115, 101, 114, 116, 32, 97, 32,
  110, 101, 119, 32, 105, 109, 97, 103, 101, 32, 102, 114, 111, 109, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 112, 114, 101, 115, 99, 114, 105,
  98, 101, 100, 32, 118, 97, 108, 117, 101, 115, 46, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 86, 97, 108, 117, 101, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 32, 105, 110, 115, 105, 100, 101, 32, 112, 97, 114, 101,
  110, 116, 104, 101, 115, 101, 115, 32, 99, 97, 110, 32, 98, 101, 32, 39,
  44, 39, 32, 40, 99, 111, 108, 117, 109, 110, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 46, 41, 44, 32, 39, 59, 39, 32, 40, 114, 111, 119,
  32, 115, 101, 112, 46, 41, 44, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 39, 47, 39, 32, 40, 115, 108, 105, 99, 101, 32, 115, 101, 112, 46,
  41, 32, 111, 114, 32, 39, 94, 39, 32, 40, 99, 104, 97, 110, 110, 101,
  108, 32, 115, 101, 112, 46, 41, 46, 32, 70, 111, 114, 32, 105, 110, 115,
  116, 97, 110, 99, 101, 44, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111,
  110, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 39, 40, 49, 44, 50,
  44, 51, 59, 52, 44, 53, 44, 54, 59, 55, 44, 56, 44, 57, 41, 39,
  32, 99, 114, 101, 97, 116, 101, 115, 32, 97, 32, 51, 120, 51, 32, 109,
  97, 116, 114, 105, 120, 32, 40, 115, 99, 97, 108, 97, 114, 32, 105, 109,
  97, 103, 101, 41, 44, 32, 119, 105, 116, 104, 32, 118, 97, 108, 117, 101,
  115, 32, 102, 114, 111, 109, 32, 49, 32, 116, 111, 32, 57, 46, 10, 92,
  110, 32, 32, 32, 32, 46, 32, 39, 48, 39, 58, 32, 73, 110, 115, 101,
  114, 116, 32, 97, 32, 110, 101, 119, 32, 39, 101, 109, 112, 116, 121, 39,
  32, 105, 109, 97, 103, 101, 44, 32, 99, 111, 110, 116, 97, 105, 110, 105,
  110, 103, 32, 110, 111, 32, 112, 105, 120, 101, 108, 32, 100, 97, 116, 97,
  46, 32, 69, 109, 112, 116, 121, 32, 105, 109, 97, 103, 101, 115, 32, 97,
  114, 101, 32, 117, 115, 101, 100, 32, 111, 110, 108, 121, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 105, 110, 32, 114, 97, 114, 101, 32, 111, 99,
  99, 97, 115, 105, 111, 110, 115, 46, 10, 92, 110, 32, 32, 45, 32, 73,
  110, 112, 117, 116, 32, 105, 116, 101, 109, 32, 39, 110, 97, 109, 101, 61,
  118, 97, 108, 117, 101, 39, 32, 100, 101, 99, 108, 97, 114, 101, 115, 32,
  97, 32, 110, 101, 119, 32, 108, 111, 99, 97, 108, 32, 111, 114, 32, 103,
  108, 111, 98, 97, 108, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 39,
  110, 97, 109, 101, 39, 44, 32, 111, 114, 32, 97, 115, 115, 105, 103, 110,
  32, 97, 32, 110, 101, 119, 10, 92, 110, 32, 32, 32, 32, 32, 118, 97,
  108, 117, 101, 32, 116, 111, 32, 97, 110, 32, 101, 120, 105, 115, 116, 105,
  110, 103, 32, 118, 97, 114, 105, 97, 98, 108, 101, 46, 32, 86, 97, 114,
  105, 97, 98, 108, 101, 32, 110, 97, 109, 101, 115, 32, 117, 115, 101, 32,
  99, 104, 97, 114, 97, 99, 116, 101, 114, 115, 32, 115, 101, 116, 32, 91,
  97, 45, 122, 65, 45, 90, 48, 45, 57, 95, 93, 32, 97, 110, 100, 32,
  99, 97, 110, 110, 111, 116, 10, 92, 110, 32, 32, 32, 32, 32, 115, 116,
  97, 114, 116, 32, 119, 105, 116, 104, 32, 97, 32, 110, 117, 109, 98, 101,
  114, 46, 32, 65, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 100, 101,
  102, 105, 110, 105, 116, 105, 111, 110, 32, 105, 115, 32, 97, 108, 119, 97,
  121, 115, 32, 108, 111, 99, 97, 108, 32, 116, 111, 32, 116, 104, 101, 32,
  99, 117, 114, 114, 101, 110, 116, 32, 99, 111, 109, 109, 97, 110, 100, 32,
  101, 120, 99, 101, 112, 116, 10, 92, 110, 32, 32, 32, 32, 32, 119, 104,
  101, 110, 32, 105, 116, 32, 115, 116, 97, 114, 116, 115, 32, 98, 121, 32,
  116, 104, 101, 32, 117, 110, 100, 101, 114, 115, 99, 111, 114, 101, 32, 99,
  104, 97, 114, 97, 99, 116, 101, 114, 32, 39, 95, 39, 46, 32, 73, 110,
  32, 116, 104, 97, 116, 32, 99, 97, 115, 101, 44, 32, 105, 116, 32, 98,
  101, 99, 111, 109, 101, 115, 32, 97, 108, 115, 111, 32, 97, 99, 99, 101,
  115, 115, 105, 98, 108, 101, 10, 92, 110, 32, 32, 32, 32, 32, 98, 121,
  32, 97, 110, 121, 32, 99, 111, 109, 109, 97, 110, 100, 32, 105, 110, 118,
  111, 107, 101, 100, 32, 111, 117, 116, 115, 105, 100, 101, 32, 116, 104, 101,
  32, 99, 117, 114, 114, 101, 110, 116, 32, 99, 111, 109, 109, 97, 110, 100,
  32, 115, 99, 111, 112, 101, 46, 34, 10, 45, 95, 104, 101, 108, 112, 95,
  115, 101, 99, 116, 105, 111, 110, 32, 34, 67, 111, 109, 109, 97, 110, 100,
  32, 105, 116, 101, 109, 115, 32, 97, 110, 100, 32, 115, 101, 108, 101, 99,
  116, 105, 111, 110, 115, 34, 10, 45, 95, 104, 101, 108, 112, 95, 112, 97,
  114, 97, 103, 114, 97, 112, 104, 32, 34, 32, 32, 45, 32, 65, 32, 71,
  39, 77, 73, 67, 32, 105, 116, 101, 109, 32, 115, 116, 97, 114, 116, 105,
  110, 103, 32, 98, 121, 32, 39, 45, 39, 32, 100, 101, 115, 105, 103, 110,
  97, 116, 101, 115, 32, 97, 32, 99, 111, 109, 109, 97, 110, 100, 44, 32,
  109, 111, 115, 116, 32, 111, 102, 32, 116, 104, 101, 32, 116, 105, 109, 101,
  46, 32, 71, 101, 110, 101, 114, 97, 108, 108, 121, 44, 32, 99, 111, 109,
  109, 97, 110, 100, 115, 10, 92, 110, 32, 32, 32, 32, 32, 112, 101, 114,
  102, 111, 114, 109, 32, 105, 109, 97, 103, 101, 32, 112, 114, 111, 99, 101,
  115, 115, 105, 110, 103, 32, 111, 112, 101, 114, 97, 116, 105, 111, 110, 115,
  32, 111, 110, 32, 111, 110, 101, 32, 111, 114, 32, 115, 101, 118, 101, 114,
  97, 108, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 32, 105, 109, 97,
  103, 101, 115, 32, 111, 102, 32, 116, 104, 101, 32, 108, 105, 115, 116, 46,
  10, 92, 110, 32, 32, 45, 32, 67, 111, 109, 109, 111, 110, 32, 99, 111,
  109, 109, 97, 110, 100, 115, 32, 104, 97, 118, 101, 32, 116, 119, 111, 32,
  101, 113, 117, 105, 118, 97, 108, 101, 110, 116, 32, 110, 97, 109, 101, 115,
  32, 40, 114, 101, 103, 117, 108, 97, 114, 32, 97, 110, 100, 32, 115, 104,
  111, 114, 116, 41, 46, 32, 70, 111, 114, 32, 105, 110, 115, 116, 97, 110,
  99, 101, 44, 32, 99, 111, 109, 109, 97, 110, 100, 10, 92, 110, 32, 32,
  32, 32, 32, 110, 97, 109, 101, 115, 32, 39, 45, 114, 101, 115, 105, 122,
  101, 39, 32, 97, 110, 100, 32, 39, 45, 114, 39, 32, 114, 101, 102, 101,
  114, 32, 116, 111, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 105, 109,
  97, 103, 101, 32, 114, 101, 115, 105, 122, 105, 110, 103, 32, 97, 99, 116,
  105, 111, 110, 46, 10, 92, 110, 32, 32, 45, 32, 65, 32, 71, 39, 77,
  73, 67, 32, 99, 111, 109, 109, 97, 110, 100, 32, 109, 97, 121, 32, 104,
  97, 118, 101, 32, 109, 97, 110, 100, 97, 116, 111, 114, 121, 32, 111, 114,
  32, 111, 112, 116, 105, 111, 110, 97, 108, 32, 97, 114, 103, 117, 109, 101,
  110, 116, 115, 46, 32, 67, 111, 109, 109, 97, 110, 100, 32, 97, 114, 103,
  117, 109, 101, 110, 116, 115, 32, 109, 117, 115, 116, 32, 98, 101, 10, 92,
  110, 32, 32, 32, 32, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  105, 110, 32, 116, 104, 101, 32, 110, 101, 120, 116, 32, 105, 116, 101, 109,
  32, 111, 110, 32, 116, 104, 101, 32, 99, 111, 109, 109, 97, 110, 100, 32,
  108, 105, 110, 101, 46, 32, 67, 111, 109, 109, 97, 115, 32, 39, 44, 39,
  32, 97, 114, 101, 32, 117, 115, 101, 100, 32, 116, 111, 32, 115, 101, 112,
  97, 114, 97, 116, 101, 32, 109, 117, 108, 116, 105, 112, 108, 101, 10, 92,
  110, 32, 32, 32, 32, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 44,
  32, 105, 102, 32, 97, 110, 121, 32, 114, 101, 113, 117, 105, 114, 101, 100,
  46, 10, 92, 110, 32, 32, 45, 32, 84, 104, 101, 32, 101, 120, 101, 99,
  117, 116, 105, 111, 110, 32, 111, 102, 32, 97, 32, 71, 39, 77, 73, 67,
  32, 99, 111, 109, 109, 97, 110, 100, 32, 109, 97, 121, 32, 98, 101, 32,
  114, 101, 115, 116, 114, 105, 99, 116, 101, 100, 32, 111, 110, 108, 121, 32,
  116, 111, 32, 97, 32, 115, 117, 98, 115, 101, 116, 32, 111, 102, 32, 116,
  104, 101, 32, 105, 109, 97, 103, 101, 32, 108, 105, 115, 116, 44, 32, 98,
  121, 10, 92, 110, 32, 32, 32, 32, 32, 97, 112, 112, 101, 110, 100, 105,
  110, 103, 32, 39, 91, 115, 117, 98, 115, 101, 116, 93, 39, 32, 116, 111,
  32, 116, 104, 101, 32, 99, 111, 109, 109, 97, 110, 100, 32, 110, 97, 109,
  101, 46, 32, 69, 120, 97, 109, 112, 108, 101, 115, 32, 111, 102, 32, 118,
  97, 108, 105, 100, 32, 115, 121, 110, 116, 97, 120, 101, 115, 32, 102, 111,
  114, 32, 39, 115, 117, 98, 115, 101, 116, 39, 32, 97, 114, 101, 58, 10,
  92, 110, 32, 32, 32, 32, 46, 32, 39, 45, 99, 111, 109, 91, 48, 44,
  49, 44, 51, 93, 39, 58, 32, 65, 112, 112, 108, 121, 32, 99, 111, 109,
  109, 97, 110, 100, 32, 111, 110, 108, 121, 32, 111, 110, 32, 105, 109, 97,
  103, 101, 115, 32, 91, 48, 93, 44, 91, 49, 93, 32, 97, 110, 100, 32,
  91, 51, 93, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 45, 99,
  111, 109, 91, 51, 45, 53, 93, 39, 58, 32, 65, 112, 112, 108, 121, 32,
  99, 111, 109, 109, 97, 110, 100, 32, 111, 110, 108, 121, 32, 111, 110, 32,
  105, 109, 97, 103, 101, 115, 32, 91, 51, 93, 32, 116, 111, 32, 91, 53,
  93, 32, 40, 105, 46, 101, 44, 32, 91, 51, 93, 44, 91, 52, 93, 32,
  97, 110, 100, 32, 91, 53, 93, 41, 46, 10, 92, 110, 32, 32, 32, 32,
  46, 32, 39, 45, 99, 111, 109, 91, 53, 48, 37, 45, 49, 48, 48, 37,
  93, 39, 58, 32, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110,
  100, 32, 111, 110, 108, 121, 32, 111, 110, 32, 116, 104, 101, 32, 115, 101,
  99, 111, 110, 100, 32, 104, 97, 108, 102, 32, 111, 102, 32, 116, 104, 101,
  32, 105, 109, 97, 103, 101, 32, 108, 105, 115, 116, 46, 10, 92, 110, 32,
  32, 32, 32, 46, 32, 39, 45, 99, 111, 109, 91, 48, 44, 45, 52, 45,
  45, 49, 93, 39, 58, 32, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109,
  97, 110, 100, 32, 111, 110, 108, 121, 32, 111, 110, 32, 116, 104, 101, 32,
  102, 105, 114, 115, 116, 32, 97, 110, 100, 32, 116, 104, 101, 32, 102, 111,
  117, 114, 32, 108, 97, 116, 101, 115, 116, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 45, 99, 111, 109, 91,
  48, 45, 57, 58, 51, 93, 39, 58, 32, 65, 112, 112, 108, 121, 32, 99,
  111, 109, 109, 97, 110, 100, 32, 111, 110, 108, 121, 32, 111, 110, 32, 105,
  109, 97, 103, 101, 115, 32, 91, 48, 93, 32, 116, 111, 32, 91, 57, 93,
  44, 32, 119, 105, 116, 104, 32, 97, 32, 115, 116, 101, 112, 32, 111, 102,
  32, 51, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 40, 105, 46, 101, 46,
  32, 111, 110, 32, 105, 109, 97, 103, 101, 115, 32, 91, 48, 93, 44, 32,
  91, 51, 93, 44, 32, 91, 54, 93, 32, 97, 110, 100, 32, 91, 57, 93,
  41, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 45, 99, 111, 109,
  91, 48, 45, 45, 49, 58, 50, 93, 39, 58, 32, 65, 112, 112, 108, 121,
  32, 99, 111, 109, 109, 97, 110, 100, 32, 111, 110, 108, 121, 32, 111, 110,
  32, 105, 109, 97, 103, 101, 115, 32, 111, 102, 32, 116, 104, 101, 32, 108,
  105, 115, 116, 32, 119, 105, 116, 104, 32, 101, 118, 101, 110, 32, 105, 110,
  100, 105, 99, 101, 115, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39,
  45, 99, 111, 109, 91, 48, 44, 50, 45, 52, 44, 53, 48, 37, 45, 45,
  49, 93, 39, 58, 32, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97,
  110, 100, 32, 111, 110, 32, 105, 109, 97, 103, 101, 115, 32, 91, 48, 93,
  44, 91, 50, 93, 44, 91, 51, 93, 44, 91, 52, 93, 32, 97, 110, 100,
  32, 111, 110, 32, 116, 104, 101, 32, 115, 101, 99, 111, 110, 100, 32, 104,
  97, 108, 102, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 111, 102, 32, 116, 104, 101, 32, 105, 109, 97, 103, 101, 32,
  108, 105, 115, 116, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 45,
  99, 111, 109, 91, 94, 48, 44, 49, 93, 39, 58, 32, 65, 112, 112, 108,
  121, 32, 99, 111, 109, 109, 97, 110, 100, 32, 111, 110, 32, 97, 108, 108,
  32, 105, 109, 97, 103, 101, 115, 32, 101, 120, 99, 101, 112, 116, 32, 116,
  104, 101, 32, 102, 105, 114, 115, 116, 32, 116, 119, 111, 46, 10, 92, 110,
  32, 32, 32, 32, 46, 32, 39, 45, 99, 111, 109, 91, 110, 97, 109, 101,
  49, 44, 110, 97, 109, 101, 50, 93, 39, 58, 32, 65, 112, 112, 108, 121,
  32, 99, 111, 109, 109, 97, 110, 100, 32, 111, 110, 32, 110, 97, 109, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 32, 39, 110, 97, 109, 101, 49, 39,
  32, 97, 110, 100, 32, 39, 110, 97, 109, 101, 50, 39, 46, 10, 92, 110,
  32, 32, 45, 32, 73, 110, 100, 105, 99, 101, 115, 32, 105, 110, 32, 115,
  101, 108, 101, 99, 116, 105, 111, 110, 115, 32, 97, 114, 101, 32, 97, 108,
  119, 97, 121, 115, 32, 115, 111, 114, 116, 101, 100, 32, 105, 110, 32, 105,
  110, 99, 114, 101, 97, 115, 105, 110, 103, 32, 111, 114, 100, 101, 114, 44,
  32, 97, 110, 100, 32, 100, 117, 112, 108, 105, 99, 97, 116, 101, 32, 105,
  110, 100, 105, 99, 101, 115, 32, 97, 114, 101, 10, 92, 110, 32, 32, 32,
  32, 32, 100, 105, 115, 99, 97, 114, 100, 101, 100, 46, 32, 70, 111, 114,
  32, 105, 110, 115, 116, 97, 110, 99, 101, 44, 32, 115, 101, 108, 101, 99,
  116, 105, 111, 110, 115, 32, 39, 91, 51, 45, 49, 44, 49, 45, 51, 93,
  39, 32, 97, 110, 100, 32, 39, 91, 49, 44, 49, 44, 49, 44, 51, 44,
  50, 93, 39, 32, 97, 114, 101, 32, 98, 111, 116, 104, 32, 101, 113, 117,
  105, 118, 97, 108, 101, 110, 116, 32, 116, 111, 10, 92, 110, 32, 32, 32,
  32, 32, 39, 91, 49, 45, 51, 93, 39, 46, 32, 73, 102, 32, 121, 111,
  117, 32, 119, 97, 110, 116, 32, 116, 111, 32, 114, 101, 112, 101, 97, 116,
  32, 97, 32, 115, 105, 110, 103, 108, 101, 32, 99, 111, 109, 109, 97, 110,
  100, 32, 109, 117, 108, 116, 105, 112, 108, 101, 32, 116, 105, 109, 101, 115,
  32, 111, 110, 32, 97, 110, 32, 105, 109, 97, 103, 101, 44, 32, 117, 115,
  101, 32, 97, 10, 92, 110, 32, 32, 32, 32, 32, 39, 45, 114, 101, 112,
  101, 97, 116, 46, 46, 45, 100, 111, 110, 101, 39, 32, 108, 111, 111, 112,
  46, 32, 73, 110, 118, 101, 114, 116, 105, 110, 103, 32, 116, 104, 101, 32,
  111, 114, 100, 101, 114, 32, 111, 102, 32, 105, 109, 97, 103, 101, 115, 32,
  105, 110, 32, 97, 32, 115, 101, 108, 101, 99, 116, 105, 111, 110, 32, 99,
  97, 110, 32, 98, 101, 32, 97, 99, 104, 105, 101, 118, 101, 100, 32, 98,
  121, 10, 92, 110, 32, 32, 32, 32, 32, 105, 110, 118, 101, 114, 116, 105,
  110, 103, 32, 102, 105, 114, 115, 116, 32, 116, 104, 101, 32, 111, 114, 100,
  101, 114, 32, 111, 102, 32, 116, 104, 101, 32, 105, 109, 97, 103, 101, 115,
  32, 105, 110, 32, 116, 104, 101, 32, 108, 105, 115, 116, 44, 32, 119, 105,
  116, 104, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 45, 114, 101, 118,
  101, 114, 115, 101, 91, 115, 101, 108, 101, 99, 116, 105, 111, 110, 93, 39,
  46, 10, 92, 110, 32, 32, 45, 32, 71, 39, 77, 73, 67, 32, 99, 111,
  109, 109, 97, 110, 100, 115, 32, 105, 110, 118, 111, 107, 101, 100, 32, 119,
  105, 116, 104, 111, 117, 116, 32, 39, 91, 115, 117, 98, 115, 101, 116, 93,
  39, 32, 97, 114, 101, 32, 97, 112, 112, 108, 105, 101, 100, 32, 111, 110,
  32, 97, 108, 108, 32, 105, 109, 97, 103, 101, 115, 32, 111, 102, 32, 116,
  104, 101, 32, 108, 105, 115, 116, 46, 10, 92, 110, 32, 32, 45, 32, 65,
  32, 71, 39, 77, 73, 67, 32, 99, 111, 109, 109, 97, 110, 100, 32, 115,
  116, 97, 114, 116, 105, 110, 103, 32, 119, 105, 116, 104, 32, 39, 45, 45,
  39, 32, 105, 110, 115, 116, 101, 97, 100, 32, 111, 102, 32, 39, 45, 39,
  32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 97, 99, 116, 32, 39, 105,
  110, 45, 112, 108, 97, 99, 101, 39, 32, 98, 117, 116, 32, 105, 110, 115,
  101, 114, 116, 115, 32, 105, 116, 115, 10, 92, 110, 32, 32, 32, 32, 32,
  114, 101, 115, 117, 108, 116, 32, 97, 115, 32, 111, 110, 101, 32, 111, 114,
  32, 115, 101, 118, 101, 114, 97, 108, 32, 110, 101, 119, 32, 105, 109, 97,
  103, 101, 115, 32, 97, 116, 32, 116, 104, 101, 32, 101, 110, 100, 32, 111,
  102, 32, 116, 104, 101, 32, 105, 109, 97, 103, 101, 32, 108, 105, 115, 116,
  46, 10, 92, 110, 32, 32, 45, 32, 84, 104, 101, 114, 101, 32, 97, 114,
  101, 32, 116, 119, 111, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32,
  116, 121, 112, 101, 115, 32, 111, 102, 32, 99, 111, 109, 109, 97, 110, 100,
  115, 32, 116, 104, 97, 116, 32, 99, 97, 110, 32, 98, 101, 32, 114, 117,
  110, 32, 98, 121, 32, 116, 104, 101, 32, 71, 39, 77, 73, 67, 32, 105,
  110, 116, 101, 114, 112, 114, 101, 116, 101, 114, 58, 10, 92, 110, 32, 32,
  32, 32, 46, 32, 78, 97, 116, 105, 118, 101, 32, 99, 111, 109, 109, 97,
  110, 100, 115, 44, 32, 97, 114, 101, 32, 104, 97, 114, 100, 45, 99, 111,
  100, 101, 100, 32, 102, 117, 110, 99, 116, 105, 111, 110, 97, 108, 105, 116,
  105, 101, 115, 32, 105, 110, 32, 116, 104, 101, 32, 105, 110, 116, 101, 114,
  112, 114, 101, 116, 101, 114, 32, 99, 111, 114, 101, 46, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 84, 104, 101, 121, 32, 97, 114, 101, 32, 116,
  104, 117, 115, 32, 99, 111, 109, 112, 105, 108, 101, 100, 32, 97, 115, 32,
  109, 97, 99, 104, 105, 110, 101, 32, 99, 111, 100, 101, 32, 97, 110, 100,
  32, 114, 117, 110, 32, 113, 117, 105, 99, 107, 108, 121, 44, 32, 109, 111,
  115, 116, 32, 111, 102, 32, 116, 104, 101, 32, 116, 105, 109, 101, 46, 10,
  92, 110, 32, 32, 32, 32, 32, 32, 32, 79, 109, 105, 116, 116, 105, 110,
  103, 32, 97, 110, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 119, 104,
  101, 110, 32, 105, 110, 118, 111, 107, 105, 110, 103, 32, 97, 32, 110, 97,
  116, 105, 118, 101, 32, 99, 111, 109, 109, 97, 110, 100, 32, 105, 115, 32,
  110, 111, 116, 32, 112, 101, 114, 109, 105, 116, 116, 101, 100, 44, 32, 101,
  120, 99, 101, 112, 116, 32, 105, 102, 32, 97, 108, 108, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 102, 111, 108, 108, 111, 119, 105, 110, 103, 32,
  97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 97, 114, 101, 32, 97, 108,
  115, 111, 32, 111, 109, 105, 116, 116, 101, 100, 46, 32, 70, 111, 114, 32,
  105, 110, 115, 116, 97, 110, 99, 101, 44, 32, 99, 97, 108, 108, 32, 116,
  111, 32, 39, 45, 112, 108, 97, 115, 109, 97, 32, 49, 48, 44, 44, 53,
  39, 32, 105, 115, 32, 105, 110, 118, 97, 108, 105, 100, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 98, 117, 116, 32, 39, 45, 112, 108, 97, 115,
  109, 97, 32, 49, 48, 39, 32, 105, 115, 32, 99, 111, 114, 114, 101, 99,
  116, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 67, 117, 115, 116, 111,
  109, 32, 99, 111, 109, 109, 97, 110, 100, 115, 44, 32, 97, 114, 101, 32,
  100, 101, 102, 105, 110, 101, 100, 32, 97, 115, 32, 71, 39, 77, 73, 67,
  32, 112, 105, 112, 101, 108, 105, 110, 101, 115, 32, 111, 102, 32, 110, 97,
  116, 105, 118, 101, 32, 111, 114, 32, 99, 117, 115, 116, 111, 109, 32, 99,
  111, 109, 109, 97, 110, 100, 115, 46, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 84, 104, 101, 121, 32, 97, 114, 101, 32, 105, 110, 116, 101, 114,
  112, 114, 101, 116, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 71, 39,
  77, 73, 67, 32, 105, 110, 116, 101, 114, 112, 114, 101, 116, 101, 114, 44,
  32, 97, 110, 100, 32, 114, 117, 110, 32, 115, 108, 111, 119, 101, 114, 32,
  116, 104, 97, 110, 32, 110, 97, 116, 105, 118, 101, 32, 99, 111, 109, 109,
  97, 110, 100, 115, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 66,
  117, 116, 32, 111, 109, 105, 116, 116, 105, 110, 103, 32, 97, 114, 103, 117,
  109, 101, 110, 116, 115, 32, 119, 104, 101, 110, 32, 105, 110, 118, 111, 107,
  105, 110, 103, 32, 97, 32, 99, 117, 115, 116, 111, 109, 32, 99, 111, 109,
  109, 97, 110, 100, 32, 105, 115, 32, 112, 101, 114, 109, 105, 116, 116, 101,
  100, 46, 32, 70, 111, 114, 32, 105, 110, 115, 116, 97, 110, 99, 101, 44,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 101, 120, 112, 114, 101, 115,
  115, 105, 111, 110, 115, 32, 39, 45, 102, 108, 111, 119, 101, 114, 32, 44,
  44, 44, 49, 48, 48, 44, 44, 50, 39, 32, 111, 114, 32, 39, 45, 102,
  108, 111, 119, 101, 114, 32, 44, 39, 32, 97, 114, 101, 32, 99, 111, 114,
  114, 101, 99, 116, 46, 10, 92, 110, 32, 32, 45, 32, 65, 32, 117, 115,
  101, 114, 32, 109, 97, 121, 32, 101, 97, 115, 105, 108, 121, 32, 97, 100,
  100, 32, 105, 116, 115, 32, 111, 119, 110, 32, 99, 117, 115, 116, 111, 109,
  32, 99, 111, 109, 109, 97, 110, 100, 115, 32, 116, 111, 32, 116, 104, 101,
  32, 71, 39, 77, 73, 67, 32, 105, 110, 116, 101, 114, 112, 114, 101, 116,
  101, 114, 32, 40, 115, 101, 101, 32, 115, 101, 99, 116, 105, 111, 110, 10,
  92, 110, 32, 32, 32, 32, 32, 39, 65, 100, 100, 105, 110, 103, 32, 99,
  117, 115, 116, 111, 109, 32, 99, 111, 109, 109, 97, 110, 100, 115, 39, 41,
  46, 32, 78, 97, 116, 105, 118, 101, 32, 99, 111, 109, 109, 97, 110, 100,
  115, 32, 99, 97, 110, 110, 111, 116, 32, 98, 101, 32, 97, 100, 100, 101,
  100, 32, 117, 110, 108, 101, 115, 115, 32, 121, 111, 117, 32, 109, 111, 100,
  105, 102, 121, 32, 116, 104, 101, 32, 71, 39, 77, 73, 67, 10, 92, 110,
  32, 32, 32, 32, 32, 105, 110, 116, 101, 114, 112, 114, 101, 116, 101, 114,
  32, 115, 111, 117, 114, 99, 101, 32, 99, 111, 100, 101, 46, 34, 10, 45,
  95, 104, 101, 108, 112, 95, 115, 101, 99, 116, 105, 111, 110, 32, 34, 73,
  110, 112, 117, 116, 115, 47, 111, 117, 116, 112, 117, 116, 115, 32, 112, 114,
  111, 112, 101, 114, 116, 105, 101, 115, 34, 10, 45, 95, 104, 101, 108, 112,
  95, 112, 97, 114, 97, 103, 114, 97, 112, 104, 32, 34, 32, 32, 45, 32,
  71, 39, 77, 73, 67, 32, 105, 115, 32, 97, 98, 108, 101, 32, 116, 111,
  32, 114, 101, 97, 100, 47, 119, 114, 105, 116, 101, 32, 109, 111, 115, 116,
  32, 111, 102, 32, 116, 104, 101, 32, 99, 108, 97, 115, 115, 105, 99, 97,
  108, 32, 105, 109, 97, 103, 101, 32, 102, 105, 108, 101, 32, 102, 111, 114,
  109, 97, 116, 115, 44, 32, 105, 110, 99, 108, 117, 100, 105, 110, 103, 58,
  10, 92, 110, 32, 32, 32, 32, 46, 32, 50, 100, 32, 103, 114, 97, 121,
  115, 99, 97, 108, 101, 47, 99, 111, 108, 111, 114, 32, 102, 105, 108, 101,
  115, 58, 32, 46, 112, 110, 103, 44, 32, 46, 106, 112, 101, 103, 44, 32,
  46, 103, 105, 102, 44, 32, 46, 112, 110, 109, 44, 32, 46, 116, 105, 102,
  44, 32, 46, 98, 109, 112, 44, 32, 46, 46, 10, 92, 110, 32, 32, 32,
  32, 46, 32, 51, 100, 32, 118, 111, 108, 117, 109, 101, 116, 114, 105, 99,
  32, 102, 105, 108, 101, 115, 58, 32, 46, 100, 99, 109, 44, 32, 46, 104,
  100, 114, 44, 32, 46, 110, 105, 105, 44, 32, 46, 112, 97, 110, 44, 32,
  46, 105, 110, 114, 44, 32, 46, 112, 110, 107, 44, 32, 46, 46, 10, 92,
  110, 32, 32, 32, 32, 46, 32, 73, 109, 97, 103, 101, 32, 115, 101, 113,
  117, 101, 110, 99, 101, 115, 58, 32, 46, 109, 112, 101, 103, 44, 32, 46,
  97, 118, 105, 44, 32, 46, 109, 111, 118, 44, 32, 46, 111, 103, 103, 44,
  32, 46, 102, 108, 118, 44, 32, 46, 46, 10, 92, 110, 32, 32, 32, 32,
  46, 32, 71, 101, 110, 101, 114, 105, 99, 32, 97, 115, 99, 105, 105, 32,
  111, 114, 32, 98, 105, 110, 97, 114, 121, 32, 100, 97, 116, 97, 32, 102,
  105, 108, 101, 115, 58, 32, 46, 99, 105, 109, 103, 44, 32, 46, 99, 105,
  109, 103, 122, 44, 32, 46, 100, 108, 109, 44, 32, 46, 97, 115, 99, 44,
  32, 46, 112, 102, 109, 44, 32, 46, 114, 97, 119, 44, 32, 46, 116, 120,
  116, 44, 32, 46, 104, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 51,
  100, 32, 111, 98, 106, 101, 99, 116, 32, 102, 105, 108, 101, 115, 58, 32,
  46, 111, 102, 102, 46, 10, 92, 110, 32, 32, 45, 32, 87, 104, 101, 110,
  32, 100, 101, 97, 108, 105, 110, 103, 32, 119, 105, 116, 104, 32, 99, 111,
  108, 111, 114, 32, 105, 109, 97, 103, 101, 115, 44, 32, 71, 39, 77, 73,
  67, 32, 103, 101, 110, 101, 114, 97, 108, 108, 121, 32, 114, 101, 97, 100,
  115, 44, 32, 119, 114, 105, 116, 101, 115, 32, 97, 110, 100, 32, 100, 105,
  115, 112, 108, 97, 121, 115, 32, 100, 97, 116, 97, 32, 117, 115, 105, 110,
  103, 32, 116, 104, 101, 10, 92, 110, 32, 32, 32, 32, 32, 117, 115, 117,
  97, 108, 32, 82, 71, 66, 32, 99, 111, 108, 111, 114, 32, 115, 112, 97,
  99, 101, 46, 10, 92, 110, 32, 32, 45, 32, 71, 39, 77, 73, 67, 32,
  105, 115, 32, 97, 98, 108, 101, 32, 116, 111, 32, 109, 97, 110, 97, 103,
  101, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 115, 32, 116, 104, 97,
  116, 32, 109, 97, 121, 32, 98, 101, 32, 114, 101, 97, 100, 32, 102, 114,
  111, 109, 32, 102, 105, 108, 101, 115, 32, 111, 114, 32, 103, 101, 110, 101,
  114, 97, 116, 101, 100, 32, 98, 121, 32, 71, 39, 77, 73, 67, 10, 92,
  110, 32, 32, 32, 32, 32, 99, 111, 109, 109, 97, 110, 100, 115, 46, 32,
  84, 104, 101, 121, 32, 97, 114, 101, 32, 115, 116, 111, 114, 101, 100, 32,
  97, 115, 32, 111, 110, 101, 45, 99, 111, 108, 117, 109, 110, 32, 115, 99,
  97, 108, 97, 114, 32, 105, 109, 97, 103, 101, 115, 32, 99, 111, 110, 116,
  97, 105, 110, 105, 110, 103, 32, 116, 104, 101, 32, 111, 98, 106, 101, 99,
  116, 32, 100, 97, 116, 97, 44, 32, 105, 110, 32, 116, 104, 101, 10, 92,
  110, 32, 32, 32, 32, 32, 102, 111, 108, 108, 111, 119, 105, 110, 103, 32,
  111, 114, 100, 101, 114, 58, 32, 123, 32, 109, 97, 103, 105, 99, 95, 110,
  117, 109, 98, 101, 114, 59, 32, 115, 105, 122, 101, 115, 59, 32, 118, 101,
  114, 116, 105, 99, 101, 115, 59, 32, 112, 114, 105, 109, 105, 116, 105, 118,
  101, 115, 59, 32, 99, 111, 108, 111, 114, 115, 59, 32, 111, 112, 97, 99,
  105, 116, 105, 101, 115, 32, 125, 46, 10, 92, 110, 32, 32, 32, 32, 32,
  84, 104, 101, 115, 101, 32, 51, 100, 32, 114, 101, 112, 114, 101, 115, 101,
  110, 116, 97, 116, 105, 111, 110, 115, 32, 99, 97, 110, 32, 98, 101, 32,
  112, 114, 111, 99, 101, 115, 115, 101, 100, 32, 97, 115, 32, 114, 101, 103,
  117, 108, 97, 114, 32, 102, 108, 111, 97, 116, 45, 118, 97, 108, 117, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 92, 110, 32, 32, 32, 32,
  32, 40, 115, 101, 101, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 45,
  115, 112, 108, 105, 116, 51, 100, 39, 32, 102, 111, 114, 32, 97, 99, 99,
  101, 115, 115, 105, 110, 103, 32, 101, 97, 99, 104, 32, 111, 102, 32, 116,
  104, 101, 115, 101, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 32, 100,
  97, 116, 97, 32, 115, 101, 112, 97, 114, 97, 116, 101, 108, 121, 41, 46,
  10, 92, 110, 32, 32, 45, 32, 66, 101, 32, 97, 119, 97, 114, 101, 32,
  116, 104, 97, 116, 32, 117, 115, 117, 97, 108, 32, 102, 105, 108, 101, 32,
  102, 111, 114, 109, 97, 116, 115, 32, 109, 97, 121, 32, 98, 101, 32, 115,
  111, 109, 101, 116, 105, 109, 101, 115, 32, 110, 111, 116, 32, 97, 100, 97,
  112, 116, 101, 100, 32, 116, 111, 32, 115, 116, 111, 114, 101, 32, 97, 108,
  108, 32, 116, 104, 101, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 10,
  92, 110, 32, 32, 32, 32, 32, 105, 109, 97, 103, 101, 32, 100, 97, 116,
  97, 44, 32, 115, 105, 110, 99, 101, 32, 71, 39, 77, 73, 67, 32, 117,
  115, 101, 115, 32, 102, 108, 111, 97, 116, 45, 118, 97, 108, 117, 101, 100,
  32, 99, 111, 100, 105, 110, 103, 32, 111, 102, 32, 105, 109, 97, 103, 101,
  32, 112, 105, 120, 101, 108, 115, 46, 32, 70, 111, 114, 32, 105, 110, 115,
  116, 97, 110, 99, 101, 44, 32, 115, 97, 118, 105, 110, 103, 10, 92, 110,
  32, 32, 32, 32, 32, 97, 110, 32, 105, 109, 97, 103, 101, 32, 116, 104,
  97, 116, 32, 119, 97, 115, 32, 105, 110, 105, 116, 105, 97, 108, 108, 121,
  32, 108, 111, 97, 100, 101, 100, 32, 97, 115, 32, 97, 32, 49, 54, 98,
  105, 116, 115, 47, 99, 104, 97, 110, 110, 101, 108, 32, 105, 109, 97, 103,
  101, 44, 32, 97, 115, 32, 97, 32, 46, 106, 112, 103, 32, 102, 105, 108,
  101, 32, 119, 105, 108, 108, 32, 114, 101, 115, 117, 108, 116, 10, 92, 110,
  32, 32, 32, 32, 32, 105, 110, 32, 108, 111, 115, 115, 32, 111, 102, 32,
  105, 110, 102, 111, 114, 109, 97, 116, 105, 111, 110, 46, 32, 85, 115, 101,
  32, 116, 104, 101, 32, 46, 99, 105, 109, 103, 32, 102, 105, 108, 101, 32,
  101, 120, 116, 101, 110, 115, 105, 111, 110, 32, 40, 111, 114, 32, 46, 99,
  105, 109, 103, 122, 44, 32, 105, 116, 115, 32, 99, 111, 109, 112, 114, 101,
  115, 115, 101, 100, 10, 92, 110, 32, 32, 32, 32, 32, 118, 101, 114, 115,
  105, 111, 110, 41, 32, 116, 111, 32, 101, 110, 115, 117, 114, 101, 32, 116,
  104, 97, 116, 32, 97, 108, 108, 32, 100, 97, 116, 97, 32, 112, 114, 101,
  99, 105, 115, 105, 111, 110, 32, 119, 105, 108, 108, 32, 98, 101, 32, 112,
  114, 101, 115, 101, 114, 118, 101, 100, 32, 119, 104, 101, 110, 32, 115, 97,
  118, 105, 110, 103, 32, 105, 109, 97, 103, 101, 115, 46, 10, 92, 110, 32,
  32, 45, 32, 70, 105, 108, 101, 32, 111, 112, 116, 105, 111, 110, 115, 32,
  99, 97, 110, 47, 109, 117, 115, 116, 32, 98, 101, 32, 115, 101, 116, 32,
  102, 111, 114, 32, 116, 104, 101, 115, 101, 32, 115, 112, 101, 99, 105, 102,
  105, 99, 32, 102, 105, 108, 101, 32, 102, 111, 114, 109, 97, 116, 115, 58,
  10, 92, 110, 32, 32, 32, 32, 46, 32, 86, 105, 100, 101, 111, 32, 102,
  105, 108, 101, 115, 58, 32, 79, 110, 108, 121, 32, 115, 117, 98, 45, 102,
  114, 97, 109, 101, 115, 32, 111, 102, 32, 97, 110, 32, 105, 109, 97, 103,
  101, 32, 115, 101, 113, 117, 101, 110, 99, 101, 32, 109, 97, 121, 32, 98,
  101, 32, 108, 111, 97, 100, 101, 100, 44, 32, 117, 115, 105, 110, 103, 32,
  116, 104, 101, 32, 105, 110, 112, 117, 116, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 39, 102,
  105, 108, 101, 110, 97, 109, 101, 46, 101, 120, 116, 44, 91, 102, 105, 114,
  115, 116, 95, 102, 114, 97, 109, 101, 91, 37, 93, 91, 44, 108, 97, 115,
  116, 95, 102, 114, 97, 109, 101, 91, 37, 93, 91, 44, 115, 116, 101, 112,
  93, 93, 93, 39, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 79,
  117, 116, 112, 117, 116, 32, 102, 114, 97, 109, 101, 114, 97, 116, 101, 32,
  97, 110, 100, 32, 98, 105, 116, 114, 97, 116, 101, 32, 40, 105, 110, 32,
  75, 98, 47, 115, 41, 32, 99, 97, 110, 32, 98, 101, 32, 97, 108, 115,
  111, 32, 115, 101, 116, 32, 98, 121, 32, 117, 115, 105, 110, 103, 32, 116,
  104, 101, 32, 111, 117, 116, 112, 117, 116, 32, 101, 120, 112, 114, 101, 115,
  115, 105, 111, 110, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 39, 102,
  105, 108, 101, 46, 109, 112, 103, 44, 95, 102, 112, 115, 44, 95, 98, 105,
  116, 114, 97, 116, 101, 39, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32,
  46, 99, 105, 109, 103, 32, 102, 105, 108, 101, 115, 32, 58, 32, 79, 110,
  108, 121, 32, 99, 114, 111, 112, 115, 32, 97, 110, 100, 32, 115, 117, 98,
  45, 105, 109, 97, 103, 101, 115, 32, 111, 102, 32, 46, 99, 105, 109, 103,
  32, 102, 105, 108, 101, 115, 32, 99, 97, 110, 32, 98, 101, 32, 108, 111,
  97, 100, 101, 100, 44, 32, 117, 115, 105, 110, 103, 32, 116, 104, 101, 32,
  105, 110, 112, 117, 116, 10, 92, 110, 32, 32, 32, 32, 32, 32, 101, 120,
  112, 114, 101, 115, 115, 105, 111, 110, 115, 32, 39, 102, 105, 108, 101, 110,
  97, 109, 101, 46, 99, 105, 109, 103, 44, 78, 48, 44, 78, 49, 39, 44,
  32, 39, 102, 105, 108, 101, 110, 97, 109, 101, 46, 99, 105, 109, 103, 44,
  78, 48, 44, 78, 49, 44, 120, 48, 44, 120, 49, 39, 44, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 39, 102, 105, 108, 101, 110, 97, 109, 101, 46,
  99, 105, 109, 103, 44, 78, 48, 44, 78, 49, 44, 120, 48, 44, 121, 48,
  44, 120, 49, 44, 121, 49, 39, 44, 32, 39, 102, 105, 108, 101, 110, 97,
  109, 101, 46, 99, 105, 109, 103, 44, 78, 48, 44, 78, 49, 44, 120, 48,
  44, 121, 48, 44, 122, 48, 44, 120, 49, 44, 121, 49, 44, 122, 49, 39,
  44, 10, 92, 110, 32, 32, 32, 32, 32, 32, 39, 102, 105, 108, 101, 110,
  97, 109, 101, 46, 99, 105, 109, 103, 44, 78, 48, 44, 78, 49, 44, 120,
  48, 44, 121, 48, 44, 122, 48, 44, 99, 48, 44, 120, 49, 44, 121, 49,
  44, 122, 49, 44, 99, 49, 39, 46, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 83, 112, 101, 99, 105, 102, 121, 105, 110, 103, 32, 39, 45, 49, 39,
  32, 102, 111, 114, 32, 111, 110, 101, 32, 99, 111, 111, 114, 100, 105, 110,
  97, 116, 101, 115, 32, 115, 116, 97, 110, 100, 115, 32, 102, 111, 114, 32,
  116, 104, 101, 32, 109, 97, 120, 105, 109, 117, 109, 32, 112, 111, 115, 115,
  105, 98, 108, 101, 32, 118, 97, 108, 117, 101, 46, 10, 92, 110, 32, 32,
  32, 32, 46, 32, 46, 114, 97, 119, 32, 98, 105, 110, 97, 114, 121, 32,
  102, 105, 108, 101, 115, 58, 32, 73, 109, 97, 103, 101, 32, 100, 105, 109,
  101, 110, 115, 105, 111, 110, 115, 32, 97, 110, 100, 32, 105, 110, 112, 117,
  116, 32, 112, 105, 120, 101, 108, 32, 116, 121, 112, 101, 32, 109, 97, 121,
  32, 98, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 119, 104,
  101, 110, 32, 108, 111, 97, 100, 105, 110, 103, 10, 92, 110, 32, 32, 32,
  32, 32, 32, 32, 46, 114, 97, 119, 32, 102, 105, 108, 101, 115, 32, 119,
  105, 116, 104, 32, 105, 110, 112, 117, 116, 32, 101, 120, 112, 114, 101, 115,
  115, 115, 105, 111, 110, 32, 39, 102, 105, 108, 101, 110, 97, 109, 101, 46,
  114, 97, 119, 91, 44, 116, 121, 112, 101, 93, 91, 44, 119, 105, 100, 116,
  104, 93, 91, 44, 104, 101, 105, 103, 104, 116, 91, 44, 100, 101, 112, 116,
  104, 91, 44, 100, 105, 109, 93, 93, 93, 93, 39, 46, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 73, 102, 32, 110, 111, 32, 100, 105, 109, 101,
  110, 115, 105, 111, 110, 115, 32, 97, 114, 101, 32, 115, 112, 101, 99, 105,
  102, 105, 101, 100, 44, 32, 116, 104, 101, 32, 114, 101, 115, 117, 108, 116,
  105, 110, 103, 32, 105, 109, 97, 103, 101, 32, 105, 115, 32, 97, 32, 111,
  110, 101, 45, 99, 111, 108, 117, 109, 110, 32, 118, 101, 99, 116, 111, 114,
  32, 119, 105, 116, 104, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 109,
  97, 120, 105, 109, 117, 109, 32, 112, 111, 115, 115, 105, 98, 108, 101, 32,
  104, 101, 105, 103, 104, 116, 46, 32, 80, 105, 120, 101, 108, 32, 116, 121,
  112, 101, 32, 99, 97, 110, 32, 97, 108, 115, 111, 32, 98, 101, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 119, 105, 116, 104, 32, 116, 104,
  101, 32, 111, 117, 116, 112, 117, 116, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 39, 102, 105,
  108, 101, 46, 114, 97, 119, 91, 44, 116, 121, 112, 101, 93, 39, 46, 10,
  92, 110, 32, 32, 32, 32, 32, 32, 32, 39, 116, 121, 112, 101, 39, 32,
  99, 97, 110, 32, 98, 101, 32, 123, 32, 98, 111, 111, 108, 32, 124, 32,
  117, 99, 104, 97, 114, 32, 124, 32, 99, 104, 97, 114, 32, 124, 32, 117,
  115, 104, 111, 114, 116, 32, 124, 32, 115, 104, 111, 114, 116, 32, 124, 32,
  117, 105, 110, 116, 32, 124, 32, 105, 110, 116, 32, 124, 32, 102, 108, 111,
  97, 116, 32, 124, 32, 100, 111, 117, 98, 108, 101, 32, 125, 46, 10, 92,
  110, 32, 32, 32, 32, 46, 32, 46, 121, 117, 118, 32, 102, 105, 108, 101,
  115, 58, 32, 73, 109, 97, 103, 101, 32, 100, 105, 109, 101, 110, 115, 105,
  111, 110, 115, 32, 109, 117, 115, 116, 32, 98, 101, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 44, 32, 97, 110, 100, 32, 111, 110, 108, 121, 32,
  115, 117, 98, 45, 102, 114, 97, 109, 101, 115, 32, 111, 102, 32, 97, 110,
  32, 105, 109, 97, 103, 101, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  115, 101, 113, 117, 101, 110, 99, 101, 32, 109, 97, 121, 32, 98, 101, 32,
  108, 111, 97, 100, 101, 100, 44, 32, 117, 115, 105, 110, 103, 32, 116, 104,
  101, 32, 105, 110, 112, 117, 116, 32, 101, 120, 112, 114, 101, 115, 115, 105,
  111, 110, 10, 92, 110, 32, 32, 32, 32, 32, 32, 39, 102, 105, 108, 101,
  110, 97, 109, 101, 46, 121, 117, 118, 44, 119, 105, 100, 116, 104, 44, 104,
  101, 105, 103, 104, 116, 91, 44, 102, 105, 114, 115, 116, 95, 102, 114, 97,
  109, 101, 91, 44, 108, 97, 115, 116, 95, 102, 114, 97, 109, 101, 91, 44,
  115, 116, 101, 112, 93, 93, 93, 39, 46, 10, 92, 110, 32, 32, 32, 32,
  46, 32, 46, 116, 105, 102, 102, 32, 102, 105, 108, 101, 115, 58, 32, 79,
  110, 108, 121, 32, 115, 117, 98, 45, 105, 109, 97, 103, 101, 115, 32, 111,
  102, 32, 109, 117, 108, 116, 105, 45, 112, 97, 103, 101, 115, 32, 116, 105,
  102, 102, 32, 102, 105, 108, 101, 115, 32, 99, 97, 110, 32, 98, 101, 32,
  108, 111, 97, 100, 101, 100, 44, 32, 117, 115, 105, 110, 103, 32, 116, 104,
  101, 32, 105, 110, 112, 117, 116, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 39, 102, 105, 108,
  101, 110, 97, 109, 101, 46, 116, 105, 102, 44, 91, 102, 105, 114, 115, 116,
  95, 102, 114, 97, 109, 101, 44, 91, 108, 97, 115, 116, 95, 102, 114, 97,
  109, 101, 44, 91, 115, 116, 101, 112, 93, 93, 93, 39, 46, 10, 92, 110,
  32, 32, 32, 32, 46, 32, 46, 103, 105, 102, 32, 102, 105, 108, 101, 115,
  58, 32, 65, 110, 105, 109, 97, 116, 101, 100, 32, 103, 105, 102, 32, 102,
  105, 108, 101, 115, 32, 99, 97, 110, 32, 98, 101, 32, 115, 97, 118, 101,
  100, 44, 32, 117, 115, 105, 110, 103, 32, 116, 104, 101, 32, 105, 110, 112,
  117, 116, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 39, 102, 105, 108, 101, 110, 97, 109, 101, 46,
  103, 105, 102, 44, 102, 112, 115, 44, 110, 98, 95, 108, 111, 111, 112, 115,
  39, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 83, 112, 101, 99, 105,
  102, 121, 32, 39, 110, 98, 95, 108, 111, 111, 112, 115, 61, 48, 39, 32,
  116, 111, 32, 103, 101, 116, 32, 97, 110, 32, 105, 110, 102, 105, 110, 105,
  116, 101, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 97, 110, 105,
  109, 97, 116, 105, 111, 110, 32, 108, 111, 111, 112, 115, 46, 10, 92, 110,
  32, 32, 32, 32, 46, 32, 46, 106, 112, 101, 103, 32, 102, 105, 108, 101,
  115, 58, 32, 84, 104, 101, 32, 111, 117, 116, 112, 117, 116, 32, 113, 117,
  97, 108, 105, 116, 121, 32, 109, 97, 121, 32, 98, 101, 32, 115, 112, 101,
  99, 105, 102, 105, 101, 100, 32, 40, 105, 110, 32, 37, 41, 44, 32, 117,
  115, 105, 110, 103, 32, 116, 104, 101, 32, 111, 117, 116, 112, 117, 116, 32,
  101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 10, 92, 110, 32, 32, 32,
  32, 32, 32, 32, 39, 102, 105, 108, 101, 110, 97, 109, 101, 46, 106, 112,
  103, 44, 51, 48, 39, 32, 40, 104, 101, 114, 101, 44, 32, 116, 111, 32,
  103, 101, 116, 32, 97, 32, 51, 48, 37, 32, 113, 117, 97, 108, 105, 116,
  121, 32, 111, 117, 116, 112, 117, 116, 41, 46, 10, 92, 110, 32, 32, 32,
  32, 46, 32, 46, 109, 110, 99, 32, 102, 105, 108, 101, 115, 58, 32, 84,
  104, 101, 32, 111, 117, 116, 112, 117, 116, 32, 104, 101, 97, 100, 101, 114,
  32, 99, 97, 110, 32, 115, 101, 116, 32, 102, 114, 111, 109, 32, 97, 110,
  111, 116, 104, 101, 114, 32, 102, 105, 108, 101, 44, 32, 117, 115, 105, 110,
  103, 32, 116, 104, 101, 32, 111, 117, 116, 112, 117, 116, 32, 101, 120, 112,
  114, 101, 115, 115, 105, 111, 110, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 39, 102, 105, 108, 101, 110, 97, 109, 101, 46, 109, 110, 99, 44, 104,
  101, 97, 100, 101, 114, 95, 116, 101, 109, 112, 108, 97, 116, 101, 46, 109,
  110, 99, 39, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 46, 103, 109,
  105, 99, 32, 102, 105, 108, 101, 115, 58, 32, 84, 104, 101, 115, 101, 32,
  102, 105, 108, 101, 110, 97, 109, 101, 115, 32, 97, 114, 101, 32, 97, 115,
  115, 117, 109, 101, 100, 32, 116, 111, 32, 98, 101, 32, 71, 39, 77, 73,
  67, 32, 99, 117, 115, 116, 111, 109, 32, 99, 111, 109, 109, 97, 110, 100,
  115, 32, 102, 105, 108, 101, 115, 46, 32, 76, 111, 97, 100, 105, 110, 103,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 115, 117, 99, 104, 32, 97,
  32, 102, 105, 108, 101, 32, 119, 105, 108, 108, 32, 97, 100, 100, 32, 116,
  104, 101, 32, 99, 111, 109, 109, 97, 110, 100, 115, 32, 105, 116, 32, 100,
  101, 102, 105, 110, 101, 115, 32, 116, 111, 32, 116, 104, 101, 32, 105, 110,
  116, 101, 114, 112, 114, 101, 116, 101, 114, 46, 32, 68, 101, 98, 117, 103,
  32, 105, 110, 102, 111, 115, 32, 99, 97, 110, 32, 98, 101, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 101, 110, 97, 98, 108, 101, 100, 47, 100,
  105, 115, 97, 98, 108, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 105,
  110, 112, 117, 116, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32,
  39, 102, 105, 108, 101, 110, 97, 109, 101, 46, 103, 109, 105, 99, 44, 97,
  100, 100, 95, 100, 101, 98, 117, 103, 95, 105, 110, 102, 111, 115, 61, 123,
  32, 48, 32, 124, 32, 49, 32, 125, 39, 46, 10, 92, 110, 32, 32, 32,
  32, 46, 32, 73, 110, 115, 101, 114, 116, 105, 110, 103, 32, 39, 101, 120,
  116, 58, 39, 32, 111, 110, 32, 116, 104, 101, 32, 98, 101, 103, 105, 110,
  110, 105, 110, 103, 32, 111, 102, 32, 97, 32, 102, 105, 108, 101, 110, 97,
  109, 101, 32, 40, 101, 46, 103, 46, 32, 39, 106, 112, 103, 58, 102, 105,
  108, 101, 110, 97, 109, 101, 39, 41, 32, 102, 111, 114, 99, 101, 115, 32,
  71, 39, 77, 73, 67, 32, 116, 111, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 114, 101, 97, 100, 47, 119, 114, 105, 116, 101, 32, 116, 104, 101,
  32, 102, 105, 108, 101, 32, 97, 115, 32, 105, 116, 32, 119, 111, 117, 108,
  100, 32, 104, 97, 118, 101, 32, 98, 101, 101, 110, 32, 100, 111, 110, 101,
  32, 105, 102, 32, 105, 116, 32, 104, 97, 100, 32, 116, 104, 101, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 101, 120, 116, 101, 110, 115, 105,
  111, 110, 46, 10, 92, 110, 32, 32, 45, 32, 83, 111, 109, 101, 32, 105,
  110, 112, 117, 116, 47, 111, 117, 116, 112, 117, 116, 32, 102, 111, 114, 109,
  97, 116, 115, 32, 97, 110, 100, 32, 111, 112, 116, 105, 111, 110, 115, 32,
  109, 97, 121, 32, 110, 111, 116, 32, 98, 101, 32, 115, 117, 112, 112, 111,
  114, 116, 101, 100, 32, 98, 121, 32, 121, 111, 117, 114, 32, 99, 117, 114,
  114, 101, 110, 116, 32, 118, 101, 114, 115, 105, 111, 110, 32, 111, 102, 10,
  92, 110, 32, 32, 32, 32, 32, 39, 103, 109, 105, 99, 39, 44, 32, 100,
  101, 112, 101, 110, 100, 105, 110, 103, 32, 111, 110, 32, 116, 104, 101, 32,
  99, 111, 110, 102, 105, 103, 117, 114, 97, 116, 105, 111, 110, 32, 102, 108,
  97, 103, 115, 32, 115, 101, 116, 32, 102, 111, 114, 32, 116, 104, 101, 32,
  98, 117, 105, 108, 100, 32, 111, 102, 32, 116, 104, 101, 32, 39, 103, 109,
  105, 99, 39, 32, 98, 105, 110, 97, 114, 105, 101, 115, 46, 34, 10, 45,
  95, 104, 101, 108, 112, 95, 115, 101, 99, 116, 105, 111, 110, 32, 34, 83,
  117, 98, 115, 116, 105, 116, 117, 116, 105, 111, 110, 32, 114, 117, 108, 101,
  115, 34, 10, 45, 95, 104, 101, 108, 112, 95, 112, 97, 114, 97, 103, 114,
  97, 112, 104, 32, 34, 32, 32, 45, 32, 71, 39, 77, 73, 67, 32, 105,
  116, 101, 109, 115, 32, 99, 111, 110, 116, 97, 105, 110, 105, 110, 103, 32,
  39, 64, 39, 44, 32, 39, 36, 39, 32, 111, 114, 32, 39, 123, 125, 39,
  32, 109, 97, 121, 32, 98, 101, 32, 115, 117, 98, 115, 116, 105, 116, 117,
  116, 101, 100, 32, 98, 101, 102, 111, 114, 101, 32, 98, 101, 105, 110, 103,
  32, 105, 110, 116, 101, 114, 112, 114, 101, 116, 101, 100, 46, 32, 85, 115,
  101, 10, 92, 110, 32, 32, 32, 32, 32, 116, 104, 101, 32, 115, 117, 98,
  115, 116, 105, 116, 117, 116, 105, 110, 103, 32, 101, 120, 112, 114, 101, 115,
  115, 105, 111, 110, 115, 32, 98, 101, 108, 111, 119, 32, 116, 111, 32, 97,
  99, 99, 101, 115, 115, 32, 100, 97, 116, 97, 32, 102, 114, 111, 109, 32,
  116, 104, 101, 32, 105, 110, 116, 101, 114, 112, 114, 101, 116, 101, 114, 32,
  101, 110, 118, 105, 114, 111, 110, 109, 101, 110, 116, 58, 10, 92, 110, 32,
  32, 32, 32, 46, 32, 39, 64, 35, 39, 32, 105, 115, 32, 115, 117, 98,
  115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32,
  99, 117, 114, 114, 101, 110, 116, 32, 110, 117, 109, 98, 101, 114, 32, 111,
  102, 32, 105, 109, 97, 103, 101, 115, 32, 105, 110, 32, 116, 104, 101, 32,
  108, 105, 115, 116, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 64,
  42, 39, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101,
  100, 32, 98, 121, 32, 116, 104, 101, 32, 110, 117, 109, 98, 101, 114, 32,
  111, 102, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 32, 99, 112, 117,
  115, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 64, 46, 39, 32,
  105, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98,
  121, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 118, 101,
  114, 115, 105, 111, 110, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32,
  116, 104, 101, 32, 71, 39, 77, 73, 67, 32, 105, 110, 116, 101, 114, 112,
  114, 101, 116, 101, 114, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 64,
  94, 39, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101,
  100, 32, 98, 121, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116,
  32, 118, 101, 114, 98, 111, 115, 105, 116, 121, 32, 108, 101, 118, 101, 108,
  46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 64, 37, 39, 32, 105,
  115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121,
  32, 116, 104, 101, 32, 112, 105, 100, 32, 111, 102, 32, 116, 104, 101, 32,
  99, 117, 114, 114, 101, 110, 116, 32, 112, 114, 111, 99, 101, 115, 115, 46,
  10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 64, 124, 39, 32, 105, 115,
  32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32,
  116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 118, 97, 108, 117,
  101, 32, 40, 101, 120, 112, 114, 101, 115, 115, 101, 100, 32, 105, 110, 32,
  115, 101, 99, 111, 110, 100, 115, 41, 32, 111, 102, 32, 97, 32, 109, 105,
  108, 108, 105, 115, 101, 99, 111, 110, 100, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 112, 114, 101, 99, 105, 115, 105, 111, 110, 32, 116, 105, 109,
  101, 114, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 64, 63, 39,
  32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32,
  98, 121, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 100,
  97, 116, 97, 32, 116, 121, 112, 101, 32, 111, 102, 32, 105, 109, 97, 103,
  101, 32, 112, 105, 120, 101, 108, 115, 46, 10, 92, 110, 32, 32, 32, 32,
  46, 32, 39, 64, 47, 39, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105,
  116, 117, 116, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 99, 117, 114,
  114, 101, 110, 116, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 108,
  101, 118, 101, 108, 115, 32, 105, 110, 32, 116, 104, 101, 32, 99, 111, 109,
  109, 97, 110, 100, 32, 115, 99, 111, 112, 101, 46, 10, 92, 110, 32, 32,
  32, 32, 46, 32, 39, 64, 123, 47, 125, 39, 32, 111, 114, 32, 39, 64,
  123, 47, 44, 115, 117, 98, 115, 101, 116, 125, 39, 32, 97, 114, 101, 32,
  115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 116,
  104, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 111, 102, 32, 116, 104,
  101, 32, 103, 108, 111, 98, 97, 108, 32, 115, 99, 111, 112, 101, 44, 32,
  111, 114, 32, 97, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 115, 117,
  98, 115, 101, 116, 32, 111, 102, 32, 105, 116, 46, 32, 73, 102, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 115, 117, 98, 115, 101, 116, 32,
  114, 101, 102, 101, 114, 115, 32, 116, 111, 32, 109, 117, 108, 116, 105, 112,
  108, 101, 32, 115, 99, 111, 112, 101, 32, 105, 116, 101, 109, 115, 44, 32,
  116, 104, 101, 121, 32, 97, 114, 101, 32, 115, 101, 112, 97, 114, 97, 116,
  101, 100, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 98, 121, 32, 115,
  108, 97, 115, 104, 101, 115, 32, 39, 47, 39, 46, 10, 92, 110, 32, 32,
  32, 32, 46, 32, 39, 64, 62, 39, 32, 97, 110, 100, 32, 39, 64, 60,
  39, 32, 97, 114, 101, 32, 101, 113, 117, 105, 118, 97, 108, 101, 110, 116,
  46, 32, 84, 104, 101, 121, 32, 97, 114, 101, 32, 98, 111, 116, 104, 32,
  115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 116,
  104, 101, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 110, 101, 115,
  116, 101, 100, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 39, 114, 101,
  112, 101, 97, 116, 45, 100, 111, 110, 101, 39, 32, 108, 111, 111, 112, 115,
  32, 116, 104, 97, 116, 32, 97, 114, 101, 32, 99, 117, 114, 114, 101, 110,
  116, 108, 121, 32, 114, 117, 110, 110, 105, 110, 103, 46, 10, 92, 110, 32,
  32, 32, 32, 46, 32, 39, 64, 123, 62, 125, 39, 32, 111, 114, 32, 39,
  64, 123, 62, 44, 115, 117, 98, 115, 101, 116, 125, 39, 32, 97, 114, 101,
  32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32,
  116, 104, 101, 32, 105, 110, 100, 105, 99, 101, 32, 118, 97, 108, 117, 101,
  115, 32, 40, 111, 114, 32, 97, 32, 115, 117, 98, 115, 101, 116, 32, 111,
  102, 32, 116, 104, 101, 109, 41, 32, 111, 102, 10, 92, 110, 32, 32, 32,
  32, 32, 32, 32, 116, 104, 101, 32, 114, 117, 110, 110, 105, 110, 103, 32,
  39, 114, 101, 112, 101, 97, 116, 45, 100, 111, 110, 101, 39, 32, 108, 111,
  111, 112, 115, 44, 32, 101, 120, 112, 114, 101, 115, 115, 101, 100, 32, 105,
  110, 32, 116, 104, 101, 32, 97, 115, 99, 101, 110, 100, 105, 110, 103, 32,
  111, 114, 100, 101, 114, 44, 32, 115, 116, 97, 114, 116, 105, 110, 103, 32,
  102, 114, 111, 109, 32, 48, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 73, 102, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 115, 117,
  98, 115, 101, 116, 32, 114, 101, 102, 101, 114, 115, 32, 116, 111, 32, 109,
  117, 108, 116, 105, 112, 108, 101, 32, 105, 110, 100, 105, 99, 101, 115, 44,
  32, 116, 104, 101, 121, 32, 97, 114, 101, 32, 115, 101, 112, 97, 114, 97,
  116, 101, 100, 32, 98, 121, 32, 99, 111, 109, 109, 97, 115, 32, 39, 44,
  39, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 64, 123, 60, 125,
  39, 32, 111, 114, 32, 39, 64, 123, 60, 44, 115, 117, 98, 115, 101, 116,
  125, 39, 32, 100, 111, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 98,
  117, 116, 32, 105, 110, 32, 100, 101, 115, 99, 101, 110, 100, 105, 110, 103,
  32, 111, 114, 100, 101, 114, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32,
  39, 64, 105, 110, 100, 105, 99, 101, 39, 32, 111, 114, 32, 39, 64, 123,
  105, 110, 100, 105, 99, 101, 44, 102, 101, 97, 116, 117, 114, 101, 125, 39,
  32, 97, 114, 101, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100,
  32, 98, 121, 32, 116, 104, 101, 32, 108, 105, 115, 116, 32, 111, 102, 32,
  112, 105, 120, 101, 108, 32, 118, 97, 108, 117, 101, 115, 32, 111, 102, 32,
  116, 104, 101, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 105, 109, 97,
  103, 101, 32, 91, 105, 110, 100, 105, 99, 101, 93, 32, 40, 115, 101, 112,
  97, 114, 97, 116, 101, 100, 32, 98, 121, 32, 99, 111, 109, 109, 97, 115,
  41, 44, 32, 111, 114, 32, 98, 121, 32, 97, 32, 115, 112, 101, 99, 105,
  102, 105, 99, 32, 102, 101, 97, 116, 117, 114, 101, 32, 40, 111, 114, 32,
  115, 117, 98, 115, 101, 116, 41, 32, 111, 102, 32, 105, 116, 46, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 39, 105, 110, 100, 105, 99, 101, 39,
  32, 99, 97, 110, 32, 98, 101, 32, 97, 110, 32, 105, 110, 100, 105, 99,
  101, 32, 111, 114, 32, 97, 110, 32, 105, 109, 97, 103, 101, 32, 110, 97,
  109, 101, 46, 32, 82, 101, 113, 117, 101, 115, 116, 101, 100, 32, 39, 102,
  101, 97, 116, 117, 114, 101, 100, 39, 32, 99, 97, 110, 32, 98, 101, 32,
  111, 110, 101, 32, 111, 102, 58, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 46, 32, 39, 119, 39, 58, 32, 105, 109, 97, 103, 101, 32,
  119, 105, 100, 116, 104, 32, 40, 110, 117, 109, 98, 101, 114, 32, 111, 102,
  32, 105, 109, 97, 103, 101, 32, 99, 111, 108, 117, 109, 110, 115, 41, 46,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 104,
  39, 58, 32, 105, 109, 97, 103, 101, 32, 104, 101, 105, 103, 104, 116, 32,
  40, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 105, 109, 97, 103, 101,
  32, 114, 111, 119, 115, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 46, 32, 39, 100, 39, 58, 32, 105, 109, 97, 103, 101, 32,
  100, 101, 112, 116, 104, 32, 40, 110, 117, 109, 98, 101, 114, 32, 111, 102,
  32, 105, 109, 97, 103, 101, 32, 115, 108, 105, 99, 101, 115, 41, 46, 10,
  92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 115, 39,
  58, 32, 105, 109, 97, 103, 101, 32, 115, 112, 101, 99, 116, 114, 117, 109,
  32, 40, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 105, 109, 97, 103,
  101, 32, 99, 104, 97, 110, 110, 101, 108, 115, 41, 46, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 119, 104, 39, 58, 32,
  105, 109, 97, 103, 101, 32, 119, 105, 100, 116, 104, 32, 120, 32, 105, 109,
  97, 103, 101, 32, 104, 101, 105, 103, 104, 116, 46, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 119, 104, 100, 39, 58, 32,
  105, 109, 97, 103, 101, 32, 119, 105, 100, 116, 104, 32, 120, 32, 105, 109,
  97, 103, 101, 32, 104, 101, 105, 103, 104, 116, 32, 120, 32, 105, 109, 97,
  103, 101, 32, 100, 101, 112, 116, 104, 46, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 46, 32, 39, 119, 104, 100, 115, 39, 58, 32, 105,
  109, 97, 103, 101, 32, 119, 105, 100, 116, 104, 32, 120, 32, 105, 109, 97,
  103, 101, 32, 104, 101, 105, 103, 104, 116, 32, 120, 32, 105, 109, 97, 103,
  101, 32, 100, 101, 112, 116, 104, 32, 120, 32, 105, 109, 97, 103, 101, 32,
  115, 112, 101, 99, 116, 114, 117, 109, 46, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 40,
  105, 46, 101, 46, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 118,
  97, 108, 117, 101, 115, 32, 105, 110, 32, 116, 104, 101, 32, 115, 112, 101,
  99, 105, 102, 105, 101, 100, 32, 105, 109, 97, 103, 101, 44, 32, 101, 113,
  46, 32, 116, 111, 32, 39, 35, 39, 41, 46, 10, 92, 110, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 46, 32, 39, 114, 39, 58, 32, 105, 109, 97,
  103, 101, 32, 115, 104, 97, 114, 101, 100, 32, 115, 116, 97, 116, 101, 32,
  40, 49, 44, 32, 105, 102, 32, 116, 104, 101, 32, 112, 105, 120, 101, 108,
  32, 98, 117, 102, 102, 101, 114, 32, 105, 115, 32, 115, 104, 97, 114, 101,
  100, 44, 32, 48, 32, 111, 116, 104, 101, 114, 119, 105, 115, 101, 41, 46,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 110,
  39, 58, 32, 105, 109, 97, 103, 101, 32, 110, 97, 109, 101, 32, 111, 114,
  32, 102, 105, 108, 101, 110, 97, 109, 101, 32, 40, 105, 102, 32, 116, 104,
  101, 32, 105, 109, 97, 103, 101, 32, 104, 97, 115, 32, 98, 101, 101, 110,
  32, 114, 101, 97, 100, 32, 102, 114, 111, 109, 32, 97, 32, 102, 105, 108,
  101, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46,
  32, 39, 98, 39, 58, 32, 105, 109, 97, 103, 101, 32, 98, 97, 115, 101,
  110, 97, 109, 101, 32, 40, 105, 46, 101, 46, 32, 102, 105, 108, 101, 110,
  97, 109, 101, 32, 119, 105, 116, 104, 111, 117, 116, 32, 116, 104, 101, 32,
  102, 111, 108, 100, 101, 114, 32, 112, 97, 116, 104, 32, 110, 111, 114, 32,
  101, 120, 116, 101, 110, 115, 105, 111, 110, 41, 46, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 120, 39, 58, 32, 105, 109,
  97, 103, 101, 32, 101, 120, 116, 101, 110, 115, 105, 111, 110, 32, 40, 105,
  46, 101, 32, 108, 97, 115, 116, 32, 99, 104, 97, 114, 97, 99, 116, 101,
  114, 115, 32, 97, 102, 116, 101, 114, 32, 116, 104, 101, 32, 108, 97, 115,
  116, 32, 39, 46, 39, 32, 105, 110, 32, 116, 104, 101, 32, 102, 105, 108,
  101, 110, 97, 109, 101, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 46, 32, 39, 102, 39, 58, 32, 105, 109, 97, 103, 101, 32,
  102, 111, 108, 100, 101, 114, 32, 110, 97, 109, 101, 46, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 35, 39, 58, 32, 110,
  117, 109, 98, 101, 114, 32, 111, 102, 32, 105, 109, 97, 103, 101, 32, 118,
  97, 108, 117, 101, 115, 32, 40, 105, 46, 101, 46, 32, 119, 105, 100, 116,
  104, 32, 120, 32, 104, 101, 105, 103, 104, 116, 32, 120, 32, 100, 101, 112,
  116, 104, 32, 120, 32, 115, 112, 101, 99, 116, 114, 117, 109, 41, 46, 10,
  92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 43, 39,
  58, 32, 115, 117, 109, 32, 111, 102, 32, 97, 108, 108, 32, 112, 105, 120,
  101, 108, 32, 118, 97, 108, 117, 101, 115, 46, 10, 92, 110, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 46, 32, 39, 45, 39, 58, 32, 100, 105, 102,
  102, 101, 114, 101, 110, 99, 101, 32, 111, 102, 32, 97, 108, 108, 32, 112,
  105, 120, 101, 108, 32, 118, 97, 108, 117, 101, 115, 46, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 42, 39, 58, 32, 112,
  114, 111, 100, 117, 99, 116, 32, 111, 102, 32, 97, 108, 108, 32, 112, 105,
  120, 101, 108, 32, 118, 97, 108, 117, 101, 115, 46, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 47, 39, 58, 32, 113, 117,
  111, 116, 105, 101, 110, 116, 32, 111, 102, 32, 97, 108, 108, 32, 112, 105,
  120, 101, 108, 32, 118, 97, 108, 117, 101, 115, 46, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 109, 39, 58, 32, 109, 105,
  110, 105, 109, 117, 109, 32, 112, 105, 120, 101, 108, 32, 118, 97, 108, 117,
  101, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32,
  39, 77, 39, 58, 32, 109, 97, 120, 105, 109, 117, 109, 32, 112, 105, 120,
  101, 108, 32, 118, 97, 108, 117, 101, 46, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 46, 32, 39, 97, 39, 58, 32, 97, 118, 101, 114,
  97, 103, 101, 32, 112, 105, 120, 101, 108, 32, 118, 97, 108, 117, 101, 46,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 118,
  39, 58, 32, 118, 97, 114, 105, 97, 110, 99, 101, 32, 111, 102, 32, 112,
  105, 120, 101, 108, 32, 118, 97, 108, 117, 101, 115, 46, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 116, 39, 58, 32, 116,
  101, 120, 116, 32, 115, 116, 114, 105, 110, 103, 32, 98, 117, 105, 108, 116,
  32, 102, 114, 111, 109, 32, 116, 104, 101, 32, 105, 109, 97, 103, 101, 32,
  118, 97, 108, 117, 101, 115, 44, 32, 114, 101, 103, 97, 114, 100, 101, 100,
  32, 97, 115, 32, 97, 115, 99, 105, 105, 32, 99, 111, 100, 101, 115, 46,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 99,
  39, 58, 32, 40, 120, 44, 121, 44, 122, 44, 99, 41, 32, 99, 111, 111,
  114, 100, 105, 110, 97, 116, 101, 115, 32, 111, 102, 32, 116, 104, 101, 32,
  109, 105, 110, 105, 109, 117, 109, 32, 118, 97, 108, 117, 101, 44, 32, 115,
  101, 112, 97, 114, 97, 116, 101, 100, 32, 98, 121, 32, 99, 111, 109, 109,
  97, 115, 32, 39, 44, 39, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 46, 32, 39, 67, 39, 58, 32, 40, 120, 44, 121, 44, 122,
  44, 99, 41, 32, 99, 111, 111, 114, 100, 105, 110, 97, 116, 101, 115, 32,
  111, 102, 32, 116, 104, 101, 32, 109, 97, 120, 105, 109, 117, 109, 32, 118,
  97, 108, 117, 101, 44, 32, 115, 101, 112, 97, 114, 97, 116, 101, 100, 32,
  98, 121, 32, 99, 111, 109, 109, 97, 115, 32, 39, 44, 39, 46, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 40, 120, 91,
  37, 93, 44, 95, 121, 91, 37, 93, 44, 95, 122, 91, 37, 93, 44, 95,
  99, 91, 37, 93, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121, 41, 39,
  58, 32, 112, 105, 120, 101, 108, 32, 118, 97, 108, 117, 101, 32, 97, 116,
  32, 40, 120, 91, 37, 93, 44, 121, 91, 37, 93, 44, 122, 91, 37, 93,
  44, 99, 91, 37, 93, 41, 44, 32, 119, 105, 116, 104, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 115, 112, 101, 99, 105,
  102, 105, 101, 100, 32, 98, 111, 117, 110, 100, 97, 114, 121, 32, 99, 111,
  110, 100, 105, 116, 105, 111, 110, 115, 32, 123, 32, 48, 61, 100, 105, 114,
  105, 99, 104, 108, 101, 116, 32, 124, 32, 49, 61, 110, 101, 117, 109, 97,
  110, 110, 32, 124, 32, 50, 61, 99, 121, 99, 108, 105, 99, 32, 125, 46,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 65, 110,
  121, 32, 111, 116, 104, 101, 114, 32, 39, 102, 101, 97, 116, 117, 114, 101,
  39, 32, 105, 115, 32, 99, 111, 110, 115, 105, 100, 101, 114, 101, 100, 32,
  101, 105, 116, 104, 101, 114, 32, 97, 115, 32, 97, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 115, 117, 98, 115, 101, 116, 32, 111, 102, 32,
  105, 109, 97, 103, 101, 32, 118, 97, 108, 117, 101, 115, 44, 32, 111, 114,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 97,
  115, 32, 97, 32, 109, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108,
  32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 116, 111, 32, 101,
  118, 97, 108, 117, 97, 116, 101, 32, 40, 97, 115, 115, 111, 99, 105, 97,
  116, 101, 100, 32, 116, 111, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 70, 111, 114, 32, 105, 110, 115, 116, 97, 110,
  99, 101, 44, 32, 39, 64, 123, 45, 49, 44, 48, 45, 53, 48, 37, 125,
  39, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100,
  32, 98, 121, 32, 116, 104, 101, 32, 115, 101, 113, 117, 101, 110, 99, 101,
  32, 111, 102, 32, 110, 117, 109, 101, 114, 105, 99, 97, 108, 32, 118, 97,
  108, 117, 101, 115, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 99, 111, 109, 105, 110, 103, 32, 102, 114, 111, 109, 32, 116,
  104, 101, 32, 102, 105, 114, 115, 116, 32, 104, 97, 108, 102, 32, 100, 97,
  116, 97, 32, 111, 102, 32, 116, 104, 101, 32, 108, 97, 115, 116, 32, 105,
  109, 97, 103, 101, 44, 32, 115, 101, 112, 97, 114, 97, 116, 101, 100, 32,
  98, 121, 32, 99, 111, 109, 109, 97, 115, 32, 39, 44, 39, 46, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 69, 120, 112,
  114, 101, 115, 115, 105, 111, 110, 32, 39, 64, 123, 48, 44, 119, 43, 104,
  125, 39, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101,
  100, 32, 98, 121, 32, 116, 104, 101, 32, 115, 117, 109, 32, 111, 102, 32,
  116, 104, 101, 32, 119, 105, 100, 116, 104, 32, 97, 110, 100, 32, 104, 101,
  105, 103, 104, 116, 32, 111, 102, 32, 116, 104, 101, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 102, 105, 114, 115, 116, 32,
  105, 109, 97, 103, 101, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39,
  64, 33, 39, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116,
  101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 118, 105, 115, 105, 98, 105,
  108, 105, 116, 121, 32, 115, 116, 97, 116, 101, 32, 111, 102, 32, 116, 104,
  101, 32, 105, 110, 115, 116, 97, 110, 116, 32, 100, 105, 115, 112, 108, 97,
  121, 32, 119, 105, 110, 100, 111, 119, 32, 91, 48, 93, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 40, 99, 97, 110, 32, 98, 101, 32, 123, 32,
  48, 61, 99, 108, 111, 115, 101, 100, 32, 124, 32, 49, 61, 118, 105, 115,
  105, 98, 108, 101, 32, 125, 41, 46, 10, 92, 110, 32, 32, 32, 32, 46,
  32, 39, 64, 123, 33, 44, 102, 101, 97, 116, 117, 114, 101, 125, 39, 32,
  111, 114, 32, 39, 64, 123, 33, 105, 110, 100, 105, 99, 101, 44, 102, 101,
  97, 116, 117, 114, 101, 125, 39, 32, 105, 115, 32, 115, 117, 98, 115, 116,
  105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 97, 32, 115, 112, 101, 99,
  105, 102, 105, 99, 32, 102, 101, 97, 116, 117, 114, 101, 32, 111, 102, 32,
  116, 104, 101, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 105, 110, 115,
  116, 97, 110, 116, 32, 100, 105, 115, 112, 108, 97, 121, 32, 119, 105, 110,
  100, 111, 119, 32, 91, 48, 93, 32, 40, 111, 114, 32, 91, 105, 110, 100,
  105, 99, 101, 93, 44, 32, 105, 102, 32, 115, 112, 101, 99, 105, 102, 105,
  101, 100, 41, 46, 32, 82, 101, 113, 117, 101, 115, 116, 101, 100, 32, 39,
  102, 101, 97, 116, 117, 114, 101, 39, 32, 99, 97, 110, 32, 98, 101, 58,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 119,
  39, 58, 32, 100, 105, 115, 112, 108, 97, 121, 32, 119, 105, 100, 116, 104,
  32, 40, 105, 46, 101, 46, 32, 119, 105, 100, 116, 104, 32, 111, 102, 32,
  116, 104, 101, 32, 100, 105, 115, 112, 108, 97, 121, 32, 97, 114, 101, 97,
  32, 109, 97, 110, 97, 103, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32,
  119, 105, 110, 100, 111, 119, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 46, 32, 39, 104, 39, 58, 32, 100, 105, 115, 112, 108,
  97, 121, 32, 104, 101, 105, 103, 104, 116, 32, 40, 105, 46, 101, 46, 32,
  104, 101, 105, 103, 104, 116, 32, 111, 102, 32, 116, 104, 101, 32, 100, 105,
  115, 112, 108, 97, 121, 32, 97, 114, 101, 97, 32, 109, 97, 110, 97, 103,
  101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 119, 105, 110, 100, 111, 119,
  41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32,
  39, 119, 104, 39, 58, 32, 100, 105, 115, 112, 108, 97, 121, 32, 119, 105,
  100, 116, 104, 32, 120, 32, 100, 105, 115, 112, 108, 97, 121, 32, 104, 101,
  105, 103, 104, 116, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 46, 32, 39, 100, 39, 58, 32, 119, 105, 110, 100, 111, 119, 32, 119,
  105, 100, 116, 104, 32, 40, 105, 46, 101, 46, 32, 119, 105, 100, 116, 104,
  32, 111, 102, 32, 116, 104, 101, 32, 119, 105, 110, 100, 111, 119, 32, 119,
  105, 100, 103, 101, 116, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 46, 32, 39, 101, 39, 58, 32, 119, 105, 110, 100, 111, 119,
  32, 104, 101, 105, 103, 104, 116, 32, 40, 105, 46, 101, 46, 32, 104, 101,
  105, 103, 104, 116, 32, 111, 102, 32, 116, 104, 101, 32, 119, 105, 110, 100,
  111, 119, 32, 119, 105, 100, 103, 101, 116, 41, 46, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 100, 101, 39, 58, 32, 119,
  105, 110, 100, 111, 119, 32, 119, 105, 100, 116, 104, 32, 120, 32, 119, 105,
  110, 100, 111, 119, 32, 104, 101, 105, 103, 104, 116, 46, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 117, 39, 58, 32, 115,
  99, 114, 101, 101, 110, 32, 119, 105, 100, 116, 104, 32, 40, 97, 99, 116,
  117, 97, 108, 108, 121, 32, 105, 110, 100, 101, 112, 101, 110, 100, 101, 110,
  116, 32, 111, 110, 32, 116, 104, 101, 32, 119, 105, 110, 100, 111, 119, 32,
  115, 105, 122, 101, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 46, 39, 32, 118, 39, 58, 32, 115, 99, 114, 101, 101, 110, 32,
  104, 101, 105, 103, 104, 116, 32, 40, 97, 99, 116, 117, 97, 108, 108, 121,
  32, 105, 110, 100, 101, 112, 101, 110, 100, 101, 110, 116, 32, 111, 110, 32,
  116, 104, 101, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 41,
  46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39,
  117, 118, 39, 58, 32, 115, 99, 114, 101, 101, 110, 32, 119, 105, 100, 116,
  104, 32, 120, 32, 115, 99, 114, 101, 101, 110, 32, 104, 101, 105, 103, 104,
  116, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32,
  39, 120, 39, 58, 32, 88, 45, 99, 111, 111, 114, 100, 105, 110, 97, 116,
  101, 32, 111, 102, 32, 116, 104, 101, 32, 109, 111, 117, 115, 101, 32, 112,
  111, 115, 105, 116, 105, 111, 110, 32, 40, 111, 114, 32, 45, 49, 44, 32,
  105, 102, 32, 111, 117, 116, 115, 105, 100, 101, 32, 116, 104, 101, 32, 100,
  105, 115, 112, 108, 97, 121, 32, 97, 114, 101, 97, 41, 46, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 121, 39, 58, 32,
  89, 45, 99, 111, 111, 114, 100, 105, 110, 97, 116, 101, 32, 111, 102, 32,
  116, 104, 101, 32, 109, 111, 117, 115, 101, 32, 112, 111, 115, 105, 116, 105,
  111, 110, 32, 40, 111, 114, 32, 45, 49, 44, 32, 105, 102, 32, 111, 117,
  116, 115, 105, 100, 101, 32, 116, 104, 101, 32, 100, 105, 115, 112, 108, 97,
  121, 32, 97, 114, 101, 97, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 46, 32, 39, 98, 39, 58, 32, 115, 116, 97, 116, 101,
  32, 111, 102, 32, 116, 104, 101, 32, 109, 111, 117, 115, 101, 32, 98, 117,
  116, 116, 111, 110, 115, 32, 123, 32, 49, 61, 108, 101, 102, 116, 45, 98,
  117, 116, 46, 32, 124, 32, 50, 61, 114, 105, 103, 104, 116, 45, 98, 117,
  116, 46, 32, 124, 32, 52, 61, 109, 105, 100, 100, 108, 101, 45, 98, 117,
  116, 46, 32, 125, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 46, 32, 39, 111, 39, 58, 32, 115, 116, 97, 116, 101, 32, 111, 102,
  32, 116, 104, 101, 32, 109, 111, 117, 115, 101, 32, 119, 104, 101, 101, 108,
  46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39,
  107, 39, 58, 32, 100, 101, 99, 105, 109, 97, 108, 32, 99, 111, 100, 101,
  32, 111, 102, 32, 116, 104, 101, 32, 112, 114, 101, 115, 115, 101, 100, 32,
  107, 101, 121, 32, 105, 102, 32, 97, 110, 121, 44, 32, 48, 32, 111, 116,
  104, 101, 114, 119, 105, 115, 101, 46, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 46, 32, 39, 110, 39, 58, 32, 99, 117, 114, 114, 101,
  110, 116, 32, 110, 111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110,
  32, 116, 121, 112, 101, 32, 111, 102, 32, 116, 104, 101, 32, 105, 110, 115,
  116, 97, 110, 116, 32, 100, 105, 115, 112, 108, 97, 121, 46, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 99, 39, 58, 32,
  98, 111, 111, 108, 101, 97, 110, 32, 40, 48, 32, 111, 114, 32, 49, 41,
  32, 116, 101, 108, 108, 105, 110, 103, 32, 105, 102, 32, 116, 104, 101, 32,
  105, 110, 115, 116, 97, 110, 116, 32, 100, 105, 115, 112, 108, 97, 121, 32,
  104, 97, 115, 32, 98, 101, 101, 110, 32, 99, 108, 111, 115, 101, 100, 32,
  114, 101, 99, 101, 110, 116, 108, 121, 46, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 46, 32, 39, 114, 39, 58, 32, 98, 111, 111, 108,
  101, 97, 110, 32, 116, 101, 108, 108, 105, 110, 103, 32, 105, 102, 32, 116,
  104, 101, 32, 105, 110, 115, 116, 97, 110, 116, 32, 100, 105, 115, 112, 108,
  97, 121, 32, 104, 97, 115, 32, 98, 101, 101, 110, 32, 114, 101, 115, 105,
  122, 101, 100, 32, 114, 101, 99, 101, 110, 116, 108, 121, 46, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 109, 39, 58, 32,
  98, 111, 111, 108, 101, 97, 110, 32, 116, 101, 108, 108, 105, 110, 103, 32,
  105, 102, 32, 116, 104, 101, 32, 105, 110, 115, 116, 97, 110, 116, 32, 100,
  105, 115, 112, 108, 97, 121, 32, 104, 97, 115, 32, 98, 101, 101, 110, 32,
  109, 111, 118, 101, 100, 32, 114, 101, 99, 101, 110, 116, 108, 121, 46, 10,
  92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 65, 110, 121,
  32, 111, 116, 104, 101, 114, 32, 39, 102, 101, 97, 116, 117, 114, 101, 39,
  32, 115, 116, 97, 110, 100, 115, 32, 102, 111, 114, 32, 97, 32, 107, 101,
  121, 99, 111, 100, 101, 32, 110, 97, 109, 101, 32, 105, 110, 32, 99, 97,
  112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 115, 44, 32, 97,
  110, 100, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 45, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 116, 117, 116, 101,
  100, 32, 98, 121, 32, 97, 32, 98, 111, 111, 108, 101, 97, 110, 32, 100,
  101, 115, 99, 114, 105, 98, 105, 110, 103, 32, 116, 104, 101, 32, 99, 117,
  114, 114, 101, 110, 116, 32, 107, 101, 121, 32, 115, 116, 97, 116, 101, 32,
  123, 32, 48, 61, 112, 114, 101, 115, 115, 101, 100, 32, 124, 32, 49, 61,
  114, 101, 108, 101, 97, 115, 101, 100, 32, 125, 46, 10, 92, 110, 32, 32,
  32, 32, 46, 32, 39, 64, 123, 92, 34, 99, 111, 109, 109, 97, 110, 100,
  32, 108, 105, 110, 101, 92, 34, 125, 39, 32, 105, 115, 32, 115, 117, 98,
  115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32,
  115, 116, 97, 116, 117, 115, 32, 118, 97, 108, 117, 101, 32, 115, 101, 116,
  32, 98, 121, 32, 116, 104, 101, 32, 101, 120, 101, 99, 117, 116, 105, 111,
  110, 32, 111, 102, 32, 116, 104, 101, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 99, 111, 109, 109,
  97, 110, 100, 32, 108, 105, 110, 101, 32, 40, 115, 101, 101, 32, 99, 111,
  109, 109, 97, 110, 100, 32, 39, 45, 115, 116, 97, 116, 117, 115, 39, 41,
  46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 69, 120, 112, 114, 101, 115,
  115, 105, 111, 110, 32, 39, 64, 123, 125, 39, 32, 115, 116, 97, 110, 100,
  115, 32, 116, 104, 117, 115, 32, 102, 111, 114, 32, 116, 104, 101, 32, 99,
  117, 114, 114, 101, 110, 116, 32, 115, 116, 97, 116, 117, 115, 32, 118, 97,
  108, 117, 101, 46, 10, 92, 110, 32, 32, 45, 32, 39, 36, 110, 97, 109,
  101, 39, 32, 97, 110, 100, 32, 39, 36, 123, 110, 97, 109, 101, 125, 39,
  32, 97, 114, 101, 32, 98, 111, 116, 104, 32, 115, 117, 98, 115, 116, 105,
  116, 117, 116, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 118, 97, 108,
  117, 101, 32, 111, 102, 32, 116, 104, 101, 32, 115, 112, 101, 99, 105, 102,
  105, 101, 100, 32, 110, 97, 109, 101, 100, 32, 118, 97, 114, 105, 97, 98,
  108, 101, 10, 92, 110, 32, 32, 32, 32, 32, 40, 115, 101, 116, 32, 112,
  114, 101, 118, 105, 111, 117, 115, 108, 121, 32, 98, 121, 32, 105, 116, 101,
  109, 32, 39, 110, 97, 109, 101, 61, 118, 97, 108, 117, 101, 39, 41, 44,
  32, 111, 114, 32, 98, 121, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101,
  110, 116, 32, 112, 111, 115, 105, 116, 105, 118, 101, 32, 105, 110, 100, 105,
  99, 101, 32, 111, 102, 32, 116, 104, 101, 32, 110, 97, 109, 101, 100, 10,
  92, 110, 32, 32, 32, 32, 32, 105, 109, 97, 103, 101, 32, 39, 91, 110,
  97, 109, 101, 93, 39, 44, 32, 111, 114, 32, 98, 121, 32, 116, 104, 101,
  32, 118, 97, 108, 117, 101, 32, 111, 102, 32, 116, 104, 101, 32, 110, 97,
  109, 101, 100, 32, 79, 83, 32, 101, 110, 118, 105, 114, 111, 110, 109, 101,
  110, 116, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 40, 105, 110, 32,
  116, 104, 105, 115, 32, 111, 114, 100, 101, 114, 41, 46, 10, 92, 110, 32,
  32, 45, 32, 39, 36, 62, 39, 32, 97, 110, 100, 32, 39, 36, 60, 39,
  32, 40, 114, 101, 115, 112, 46, 32, 39, 36, 123, 62, 125, 39, 32, 97,
  110, 100, 32, 39, 36, 123, 60, 125, 39, 41, 32, 97, 114, 101, 32, 115,
  104, 111, 114, 116, 99, 117, 116, 115, 32, 114, 101, 115, 112, 101, 99, 116,
  105, 118, 101, 108, 121, 32, 102, 111, 114, 32, 39, 64, 123, 62, 44, 45,
  49, 125, 39, 32, 97, 110, 100, 10, 92, 110, 32, 32, 32, 32, 32, 39,
  64, 123, 60, 44, 45, 49, 125, 39, 46, 32, 84, 104, 101, 121, 32, 114,
  101, 102, 101, 114, 32, 116, 111, 32, 116, 104, 101, 32, 105, 110, 99, 114,
  101, 97, 115, 105, 110, 103, 47, 100, 101, 99, 114, 101, 97, 115, 105, 110,
  103, 32, 105, 110, 100, 105, 99, 101, 32, 111, 102, 32, 116, 104, 101, 32,
  108, 97, 116, 101, 115, 116, 32, 40, 99, 117, 114, 114, 101, 110, 116, 108,
  121, 10, 92, 110, 32, 32, 32, 32, 32, 114, 117, 110, 110, 105, 110, 103,
  41, 32, 39, 114, 101, 112, 101, 97, 116, 46, 46, 100, 111, 110, 101, 39,
  32, 108, 111, 111, 112, 46, 10, 92, 110, 32, 32, 45, 32, 65, 110, 121,
  32, 111, 116, 104, 101, 114, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111,
  110, 32, 105, 110, 115, 105, 100, 101, 32, 98, 114, 97, 99, 101, 115, 32,
  40, 97, 115, 32, 105, 110, 32, 39, 123, 101, 120, 112, 114, 101, 115, 115,
  105, 111, 110, 125, 39, 41, 32, 105, 115, 32, 99, 111, 110, 115, 105, 100,
  101, 114, 101, 100, 32, 97, 115, 32, 97, 32, 109, 97, 116, 104, 101, 109,
  97, 116, 105, 99, 97, 108, 10, 92, 110, 32, 32, 32, 32, 32, 101, 120,
  112, 114, 101, 115, 115, 105, 111, 110, 44, 32, 97, 110, 100, 32, 105, 115,
  32, 101, 118, 97, 108, 117, 97, 116, 101, 100, 44, 32, 101, 120, 99, 101,
  112, 116, 32, 102, 111, 114, 32, 116, 104, 101, 32, 116, 104, 114, 101, 101,
  32, 102, 111, 108, 108, 111, 119, 105, 110, 103, 32, 99, 97, 115, 101, 115,
  58, 10, 92, 110, 32, 32, 32, 32, 46, 32, 73, 102, 32, 101, 120, 112,
  114, 101, 115, 115, 105, 111, 110, 32, 115, 116, 97, 114, 116, 115, 32, 97,
  110, 100, 32, 101, 110, 100, 115, 32, 98, 121, 32, 115, 105, 110, 103, 108,
  101, 32, 113, 117, 111, 116, 101, 115, 44, 32, 105, 116, 32, 105, 115, 32,
  115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 116,
  104, 101, 32, 115, 101, 113, 117, 101, 110, 99, 101, 32, 111, 102, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 97, 115, 99, 105, 105, 32, 99, 111,
  100, 101, 115, 32, 116, 104, 97, 116, 32, 99, 111, 109, 112, 111, 115, 101,
  115, 32, 116, 104, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  115, 116, 114, 105, 110, 103, 44, 32, 115, 101, 112, 97, 114, 97, 116, 101,
  100, 32, 98, 121, 32, 99, 111, 109, 109, 97, 115, 32, 39, 44, 39, 46,
  32, 70, 111, 114, 32, 105, 110, 115, 116, 97, 110, 99, 101, 44, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 105, 116, 101, 109, 32, 39, 123, 39,
  102, 111, 111, 39, 125, 39, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105,
  116, 117, 116, 101, 100, 32, 98, 121, 32, 39, 49, 48, 50, 44, 49, 49,
  49, 44, 49, 49, 49, 39, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32,
  73, 102, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 115, 116,
  97, 114, 116, 115, 32, 97, 110, 100, 32, 101, 110, 100, 115, 32, 119, 105,
  116, 104, 32, 98, 97, 99, 107, 113, 117, 111, 116, 101, 115, 32, 39, 96,
  39, 44, 32, 105, 116, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 116,
  117, 116, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 115, 116, 114, 105,
  110, 103, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 119, 104, 111, 115,
  101, 32, 97, 115, 99, 105, 105, 32, 99, 111, 100, 101, 115, 32, 97, 114,
  101, 32, 103, 105, 118, 101, 110, 32, 98, 121, 32, 116, 104, 101, 32, 108,
  105, 115, 116, 32, 111, 102, 32, 118, 97, 108, 117, 101, 115, 32, 105, 110,
  32, 98, 101, 116, 119, 101, 101, 110, 32, 116, 104, 101, 32, 98, 97, 99,
  107, 113, 117, 111, 116, 101, 115, 46, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 70, 111, 114, 32, 105, 110, 115, 116, 97, 110, 99, 101, 44, 32,
  105, 116, 101, 109, 32, 39, 123, 96, 49, 48, 50, 44, 49, 49, 49, 44,
  49, 49, 49, 96, 125, 39, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105,
  116, 117, 116, 101, 100, 32, 98, 121, 32, 39, 102, 111, 111, 39, 46, 10,
  92, 110, 32, 32, 32, 32, 46, 32, 73, 102, 32, 101, 120, 112, 114, 101,
  115, 115, 105, 111, 110, 32, 99, 111, 110, 116, 97, 105, 110, 115, 32, 111,
  112, 101, 114, 97, 116, 111, 114, 32, 39, 39, 61, 61, 39, 39, 32, 111,
  114, 32, 39, 39, 33, 61, 39, 39, 44, 32, 105, 116, 32, 105, 115, 32,
  115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 48,
  32, 111, 114, 32, 49, 44, 32, 119, 104, 101, 116, 104, 101, 114, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 116, 104, 101, 32, 115, 116, 114, 105,
  110, 103, 115, 32, 98, 101, 115, 105, 100, 101, 32, 116, 104, 101, 32, 111,
  112, 101, 114, 97, 116, 111, 114, 32, 97, 114, 101, 32, 116, 104, 101, 32,
  115, 97, 109, 101, 32, 111, 114, 32, 110, 111, 116, 32, 40, 99, 97, 115,
  101, 45, 115, 101, 110, 115, 105, 116, 105, 118, 101, 41, 46, 32, 70, 111,
  114, 32, 105, 110, 115, 116, 97, 110, 99, 101, 44, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 98, 111, 116, 104, 32, 105, 116, 101, 109, 115, 32,
  39, 123, 102, 111, 111, 39, 61, 61, 39, 102, 111, 111, 125, 39, 32, 97,
  110, 100, 32, 39, 123, 102, 111, 111, 39, 33, 61, 39, 70, 79, 79, 125,
  39, 32, 97, 114, 101, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101,
  100, 32, 98, 121, 32, 39, 49, 39, 46, 10, 92, 110, 32, 32, 32, 32,
  46, 32, 73, 102, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32,
  115, 116, 97, 114, 116, 115, 32, 119, 105, 116, 104, 32, 97, 110, 32, 117,
  110, 100, 101, 114, 115, 99, 111, 114, 101, 32, 39, 95, 39, 44, 32, 105,
  116, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100,
  32, 98, 121, 32, 116, 104, 101, 32, 109, 97, 116, 104, 101, 109, 97, 116,
  105, 99, 97, 108, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 101, 118,
  97, 108, 117, 97, 116, 105, 111, 110, 32, 111, 102, 32, 116, 104, 101, 32,
  101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 44, 32, 116, 114, 117, 110,
  99, 97, 116, 101, 100, 32, 116, 111, 32, 97, 32, 114, 101, 97, 100, 97,
  98, 108, 101, 32, 102, 111, 114, 109, 97, 116, 46, 10, 92, 110, 32, 32,
  45, 32, 73, 116, 101, 109, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116,
  105, 111, 110, 32, 105, 115, 32, 110, 101, 118, 101, 114, 32, 100, 111, 110,
  101, 32, 105, 110, 32, 105, 116, 101, 109, 115, 32, 98, 101, 116, 119, 101,
  101, 110, 32, 100, 111, 117, 98, 108, 101, 32, 113, 117, 111, 116, 101, 115,
  46, 32, 79, 110, 101, 32, 109, 117, 115, 116, 32, 98, 114, 101, 97, 107,
  32, 116, 104, 101, 32, 113, 117, 111, 116, 101, 115, 10, 92, 110, 32, 32,
  32, 32, 116, 111, 32, 101, 110, 97, 98, 108, 101, 32, 115, 117, 98, 115,
  116, 105, 116, 117, 116, 105, 111, 110, 32, 105, 102, 32, 110, 101, 101, 100,
  101, 100, 44, 32, 97, 115, 32, 105, 110, 32, 92, 34, 51, 43, 56, 32,
  107, 103, 32, 61, 32, 92, 34, 123, 51, 43, 56, 125, 92, 34, 32, 107,
  103, 92, 34, 46, 32, 85, 115, 105, 110, 103, 32, 100, 111, 117, 98, 108,
  101, 32, 113, 117, 111, 116, 101, 115, 10, 92, 110, 32, 32, 32, 32, 105,
  115, 32, 116, 104, 101, 110, 32, 97, 32, 99, 111, 110, 118, 101, 110, 105,
  101, 110, 116, 32, 119, 97, 121, 32, 116, 111, 32, 100, 105, 115, 97, 98,
  108, 101, 32, 116, 104, 101, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116,
  105, 111, 110, 115, 32, 109, 101, 99, 104, 97, 110, 105, 115, 109, 32, 105,
  110, 32, 105, 116, 101, 109, 115, 44, 32, 119, 104, 101, 110, 32, 110, 101,
  99, 101, 115, 115, 97, 114, 121, 46, 10, 92, 110, 32, 32, 45, 32, 79,
  110, 101, 32, 99, 97, 110, 32, 97, 108, 115, 111, 32, 100, 105, 115, 97,
  98, 108, 101, 32, 116, 104, 101, 32, 115, 117, 98, 115, 116, 105, 116, 117,
  116, 105, 111, 110, 32, 109, 101, 99, 104, 97, 110, 105, 115, 109, 32, 111,
  110, 32, 105, 116, 101, 109, 115, 32, 111, 117, 116, 115, 105, 100, 101, 32,
  100, 111, 117, 98, 108, 101, 32, 113, 117, 111, 116, 101, 115, 44, 32, 98,
  121, 10, 92, 110, 32, 32, 32, 32, 32, 101, 115, 99, 97, 112, 105, 110,
  103, 32, 116, 104, 101, 32, 39, 64, 39, 44, 39, 123, 39, 44, 39, 125,
  39, 32, 111, 114, 32, 39, 36, 39, 32, 99, 104, 97, 114, 97, 99, 116,
  101, 114, 115, 44, 32, 97, 115, 32, 105, 110, 32, 39, 92, 92, 123, 51,
  43, 52, 92, 92, 125, 92, 92, 32, 100, 111, 101, 115, 110, 39, 116, 92,
  92, 32, 101, 118, 97, 108, 117, 97, 116, 101, 39, 46, 34, 10, 45, 95,
  104, 101, 108, 112, 95, 115, 101, 99, 116, 105, 111, 110, 32, 34, 77, 97,
  116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 32, 101, 120, 112, 114, 101,
  115, 115, 105, 111, 110, 115, 34, 10, 45, 95, 104, 101, 108, 112, 95, 112,
  97, 114, 97, 103, 114, 97, 112, 104, 32, 34, 32, 32, 45, 32, 71, 39,
  77, 73, 67, 32, 104, 97, 115, 32, 97, 110, 32, 101, 109, 98, 101, 100,
  100, 101, 100, 32, 109, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108,
  32, 112, 97, 114, 115, 101, 114, 46, 32, 73, 116, 32, 105, 115, 32, 117,
  115, 101, 100, 32, 116, 111, 32, 101, 118, 97, 108, 117, 97, 116, 101, 32,
  101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 115, 32, 105, 110, 115, 105,
  100, 101, 10, 92, 110, 32, 32, 32, 32, 32, 98, 114, 97, 99, 101, 115,
  32, 39, 123, 125, 39, 44, 32, 111, 114, 32, 102, 111, 114, 109, 117, 108,
  97, 115, 32, 105, 110, 32, 99, 111, 109, 109, 97, 110, 100, 115, 32, 116,
  104, 97, 116, 32, 109, 97, 121, 32, 116, 97, 107, 101, 32, 111, 110, 101,
  32, 97, 115, 32, 97, 110, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32,
  40, 101, 46, 103, 46, 32, 39, 45, 102, 105, 108, 108, 39, 41, 46, 10,
  92, 110, 32, 32, 45, 32, 87, 104, 101, 110, 32, 117, 115, 101, 100, 32,
  105, 110, 32, 99, 111, 109, 109, 97, 110, 100, 115, 44, 32, 97, 32, 102,
  111, 114, 109, 117, 108, 97, 32, 105, 115, 32, 101, 118, 97, 108, 117, 97,
  116, 101, 100, 32, 102, 111, 114, 32, 101, 97, 99, 104, 32, 112, 105, 120,
  101, 108, 32, 111, 102, 32, 116, 104, 101, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 92, 110, 32, 32, 45,
  32, 84, 104, 101, 32, 109, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97,
  108, 32, 112, 97, 114, 115, 101, 114, 32, 117, 110, 100, 101, 114, 115, 116,
  97, 110, 100, 115, 32, 116, 104, 101, 32, 102, 111, 108, 108, 111, 119, 105,
  110, 103, 32, 115, 101, 116, 32, 111, 102, 32, 102, 117, 110, 99, 116, 105,
  111, 110, 115, 44, 32, 111, 112, 101, 114, 97, 116, 111, 114, 115, 32, 97,
  110, 100, 32, 118, 97, 114, 105, 97, 98, 108, 101, 115, 58, 10, 92, 110,
  32, 32, 32, 32, 95, 32, 85, 115, 117, 97, 108, 32, 111, 112, 101, 114,
  97, 116, 111, 114, 115, 58, 32, 124, 124, 32, 40, 108, 111, 103, 105, 99,
  97, 108, 32, 111, 114, 41, 44, 32, 38, 38, 32, 40, 108, 111, 103, 105,
  99, 97, 108, 32, 97, 110, 100, 41, 44, 32, 124, 32, 40, 98, 105, 116,
  119, 105, 115, 101, 32, 111, 114, 41, 44, 32, 38, 32, 40, 98, 105, 116,
  119, 105, 115, 101, 32, 97, 110, 100, 41, 44, 10, 92, 110, 32, 32, 32,
  32, 32, 32, 32, 33, 61, 44, 32, 61, 61, 44, 32, 60, 61, 44, 32,
  62, 61, 44, 32, 60, 44, 32, 62, 44, 32, 60, 60, 32, 40, 108, 101,
  102, 116, 32, 98, 105, 116, 119, 105, 115, 101, 32, 115, 104, 105, 102, 116,
  41, 44, 32, 62, 62, 32, 40, 114, 105, 103, 104, 116, 32, 98, 105, 116,
  119, 105, 115, 101, 32, 115, 104, 105, 102, 116, 41, 44, 32, 45, 44, 32,
  43, 44, 32, 42, 44, 32, 47, 44, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 37, 32, 40, 109, 111, 100, 117, 108, 111, 41, 44, 32, 94, 32,
  40, 112, 111, 119, 101, 114, 41, 44, 32, 33, 32, 40, 108, 111, 103, 105,
  99, 97, 108, 32, 110, 111, 116, 41, 44, 32, 126, 32, 40, 98, 105, 116,
  119, 105, 115, 101, 32, 110, 111, 116, 41, 46, 10, 92, 110, 32, 32, 32,
  32, 95, 32, 85, 115, 117, 97, 108, 32, 102, 117, 110, 99, 116, 105, 111,
  110, 115, 58, 32, 115, 105, 110, 40, 41, 44, 32, 99, 111, 115, 40, 41,
  44, 32, 116, 97, 110, 40, 41, 44, 32, 97, 115, 105, 110, 40, 41, 44,
  32, 97, 99, 111, 115, 40, 41, 44, 32, 97, 116, 97, 110, 40, 41, 44,
  32, 115, 105, 110, 104, 40, 41, 44, 32, 99, 111, 115, 104, 40, 41, 44,
  32, 116, 97, 110, 104, 40, 41, 44, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 108, 111, 103, 40, 41, 44, 32, 108, 111, 103, 50, 40, 41, 44,
  32, 108, 111, 103, 49, 48, 40, 41, 44, 32, 101, 120, 112, 40, 41, 44,
  32, 115, 105, 103, 110, 40, 41, 44, 32, 97, 98, 115, 40, 41, 44, 32,
  97, 116, 97, 110, 50, 40, 41, 44, 32, 114, 111, 117, 110, 100, 40, 41,
  44, 32, 110, 97, 114, 103, 40, 41, 44, 32, 97, 114, 103, 40, 41, 44,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 105, 115, 118, 97, 108, 40,
  41, 44, 32, 105, 115, 110, 97, 110, 40, 41, 44, 32, 105, 115, 105, 110,
  102, 40, 41, 44, 32, 105, 115, 105, 110, 116, 40, 41, 44, 32, 105, 115,
  98, 111, 111, 108, 40, 41, 44, 32, 114, 111, 108, 40, 41, 32, 40, 108,
  101, 102, 116, 32, 98, 105, 116, 32, 114, 111, 116, 97, 116, 105, 111, 110,
  41, 44, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 114, 111, 114, 40,
  41, 32, 40, 114, 105, 103, 104, 116, 32, 98, 105, 116, 32, 114, 111, 116,
  97, 116, 105, 111, 110, 41, 44, 32, 109, 105, 110, 40, 41, 44, 32, 109,
  97, 120, 40, 41, 44, 32, 115, 105, 110, 99, 40, 41, 44, 32, 105, 110,
  116, 40, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 70, 117,
  110, 99, 116, 105, 111, 110, 32, 39, 97, 116, 97, 110, 50, 40, 41, 39,
  32, 105, 115, 32, 116, 104, 101, 32, 118, 101, 114, 115, 105, 111, 110, 32,
  111, 102, 32, 97, 116, 97, 110, 40, 41, 32, 119, 105, 116, 104, 32, 116,
  119, 111, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 39, 121, 44,
  120, 39, 32, 40, 97, 115, 32, 105, 110, 32, 67, 47, 67, 43, 43, 41,
  46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 70, 117, 110, 99, 116,
  105, 111, 110, 32, 39, 110, 97, 114, 103, 40, 41, 39, 32, 114, 101, 116,
  117, 114, 110, 115, 32, 116, 104, 101, 32, 110, 117, 109, 98, 101, 114, 32,
  111, 102, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 97, 114, 103,
  117, 109, 101, 110, 116, 115, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 70, 117, 110, 99, 116, 105, 111, 110, 32, 39, 97, 114, 103, 40, 105,
  44, 97, 95, 49, 44, 46, 46, 44, 97, 95, 110, 41, 39, 32, 114, 101,
  116, 117, 114, 110, 115, 32, 116, 104, 101, 32, 105, 116, 104, 32, 97, 114,
  103, 117, 109, 101, 110, 116, 32, 97, 95, 105, 46, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 70, 117, 110, 99, 116, 105, 111, 110, 115, 32, 39,
  109, 105, 110, 40, 41, 39, 32, 97, 110, 100, 32, 39, 109, 97, 120, 40,
  41, 39, 32, 99, 97, 110, 32, 98, 101, 32, 99, 97, 108, 108, 101, 100,
  32, 119, 105, 116, 104, 32, 97, 110, 32, 97, 114, 98, 105, 116, 114, 97,
  114, 121, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 97, 114, 103,
  117, 109, 101, 110, 116, 115, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 70, 117, 110, 99, 116, 105, 111, 110, 115, 32, 39, 105, 115, 118, 97,
  108, 40, 41, 39, 44, 32, 39, 105, 115, 110, 97, 110, 40, 41, 39, 44,
  32, 39, 105, 115, 105, 110, 102, 40, 41, 39, 44, 32, 39, 105, 115, 98,
  111, 111, 108, 40, 41, 39, 32, 99, 97, 110, 32, 98, 101, 32, 117, 115,
  101, 100, 32, 116, 111, 32, 116, 101, 115, 116, 32, 116, 104, 101, 32, 116,
  121, 112, 101, 32, 111, 102, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  97, 32, 103, 105, 118, 101, 110, 32, 110, 117, 109, 98, 101, 114, 32, 111,
  114, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 46, 10, 92, 110,
  32, 32, 32, 32, 95, 32, 84, 104, 101, 32, 118, 97, 114, 105, 97, 98,
  108, 101, 32, 110, 97, 109, 101, 115, 32, 98, 101, 108, 111, 119, 32, 97,
  114, 101, 32, 112, 114, 101, 45, 100, 101, 102, 105, 110, 101, 100, 46, 32,
  84, 104, 101, 121, 32, 99, 97, 110, 32, 98, 101, 32, 111, 118, 101, 114,
  108, 111, 97, 100, 101, 100, 32, 105, 102, 32, 110, 101, 99, 101, 115, 115,
  97, 114, 121, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  46, 32, 39, 119, 39, 58, 32, 119, 105, 100, 116, 104, 32, 111, 102, 32,
  116, 104, 101, 32, 97, 115, 115, 111, 99, 105, 97, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 44, 32, 105, 102, 32, 97, 110, 121, 32, 40, 48, 32,
  111, 116, 104, 101, 114, 119, 105, 115, 101, 41, 46, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 104, 39, 58, 32, 104, 101,
  105, 103, 104, 116, 32, 111, 102, 32, 116, 104, 101, 32, 97, 115, 115, 111,
  99, 105, 97, 116, 101, 100, 32, 105, 109, 97, 103, 101, 44, 32, 105, 102,
  32, 97, 110, 121, 32, 40, 48, 32, 111, 116, 104, 101, 114, 119, 105, 115,
  101, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46,
  32, 39, 100, 39, 58, 32, 100, 101, 112, 116, 104, 32, 111, 102, 32, 116,
  104, 101, 32, 97, 115, 115, 111, 99, 105, 97, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 44, 32, 105, 102, 32, 97, 110, 121, 32, 40, 48, 32, 111,
  116, 104, 101, 114, 119, 105, 115, 101, 41, 46, 10, 92, 110, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 46, 32, 39, 115, 39, 58, 32, 115, 112, 101,
  99, 116, 114, 117, 109, 32, 111, 102, 32, 116, 104, 101, 32, 97, 115, 115,
  111, 99, 105, 97, 116, 101, 100, 32, 105, 109, 97, 103, 101, 44, 32, 105,
  102, 32, 97, 110, 121, 32, 40, 48, 32, 111, 116, 104, 101, 114, 119, 105,
  115, 101, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  46, 32, 39, 120, 39, 58, 32, 99, 117, 114, 114, 101, 110, 116, 32, 112,
  114, 111, 99, 101, 115, 115, 101, 100, 32, 99, 111, 108, 117, 109, 110, 32,
  111, 102, 32, 116, 104, 101, 32, 97, 115, 115, 111, 99, 105, 97, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 44, 32, 105, 102, 32, 97, 110, 121, 32,
  40, 48, 32, 111, 116, 104, 101, 114, 119, 105, 115, 101, 41, 46, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 121, 39, 58,
  32, 99, 117, 114, 114, 101, 110, 116, 32, 112, 114, 111, 99, 101, 115, 115,
  101, 100, 32, 114, 111, 119, 32, 111, 102, 32, 116, 104, 101, 32, 97, 115,
  115, 111, 99, 105, 97, 116, 101, 100, 32, 105, 109, 97, 103, 101, 44, 32,
  105, 102, 32, 97, 110, 121, 32, 40, 48, 32, 111, 116, 104, 101, 114, 119,
  105, 115, 101, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 46, 32, 39, 122, 39, 58, 32, 99, 117, 114, 114, 101, 110, 116, 32,
  112, 114, 111, 99, 101, 115, 115, 101, 100, 32, 115, 108, 105, 99, 101, 32,
  111, 102, 32, 116, 104, 101, 32, 97, 115, 115, 111, 99, 105, 97, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 44, 32, 105, 102, 32, 97, 110, 121, 32,
  40, 48, 32, 111, 116, 104, 101, 114, 119, 105, 115, 101, 41, 46, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 99, 39, 58,
  32, 99, 117, 114, 114, 101, 110, 116, 32, 112, 114, 111, 99, 101, 115, 115,
  101, 100, 32, 99, 104, 97, 110, 110, 101, 108, 32, 111, 102, 32, 116, 104,
  101, 32, 97, 115, 115, 111, 99, 105, 97, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 44, 32, 105, 102, 32, 97, 110, 121, 32, 40, 48, 32, 111, 116,
  104, 101, 114, 119, 105, 115, 101, 41, 46, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 46, 32, 39, 101, 39, 58, 32, 118, 97, 108, 117,
  101, 32, 111, 102, 32, 101, 44, 32, 105, 46, 101, 46, 32, 50, 46, 55,
  49, 56, 50, 56, 46, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 46, 32, 39, 112, 105, 39, 58, 32, 118, 97, 108, 117, 101, 32,
  111, 102, 32, 112, 105, 44, 32, 105, 46, 101, 46, 32, 51, 46, 49, 52,
  49, 53, 57, 50, 54, 46, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 46, 32, 39, 63, 39, 32, 111, 114, 32, 39, 117, 39, 58,
  32, 97, 32, 114, 97, 110, 100, 111, 109, 32, 118, 97, 108, 117, 101, 32,
  98, 101, 116, 119, 101, 101, 110, 32, 91, 48, 44, 49, 93, 44, 32, 102,
  111, 108, 108, 111, 119, 105, 110, 103, 32, 97, 32, 117, 110, 105, 102, 111,
  114, 109, 32, 100, 105, 115, 116, 114, 105, 98, 117, 116, 105, 111, 110, 46,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 103,
  39, 58, 32, 97, 32, 114, 97, 110, 100, 111, 109, 32, 118, 97, 108, 117,
  101, 44, 32, 102, 111, 108, 108, 111, 119, 105, 110, 103, 32, 97, 32, 103,
  97, 117, 115, 115, 105, 97, 110, 32, 100, 105, 115, 116, 114, 105, 98, 117,
  116, 105, 111, 110, 32, 111, 102, 32, 118, 97, 114, 105, 97, 110, 99, 101,
  32, 49, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 40, 114, 111, 117, 103, 104, 108, 121, 32, 105, 110, 32, 91, 45, 53,
  44, 53, 93, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 46, 32, 39, 105, 39, 58, 32, 99, 117, 114, 114, 101, 110, 116, 32,
  112, 114, 111, 99, 101, 115, 115, 101, 100, 32, 112, 105, 120, 101, 108, 32,
  118, 97, 108, 117, 101, 32, 40, 105, 46, 101, 46, 32, 118, 97, 108, 117,
  101, 32, 108, 111, 99, 97, 116, 101, 100, 32, 97, 116, 32, 40, 120, 44,
  121, 44, 122, 44, 99, 41, 41, 32, 111, 102, 32, 116, 104, 101, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 97, 115, 115,
  111, 99, 105, 97, 116, 101, 100, 32, 105, 109, 97, 103, 101, 44, 32, 105,
  102, 32, 97, 110, 121, 32, 40, 48, 32, 111, 116, 104, 101, 114, 119, 105,
  115, 101, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  46, 32, 39, 105, 109, 39, 44, 39, 105, 77, 39, 44, 39, 105, 97, 39,
  44, 39, 105, 118, 39, 58, 32, 82, 101, 115, 112, 101, 99, 116, 105, 118,
  101, 108, 121, 32, 116, 104, 101, 32, 109, 105, 110, 105, 109, 117, 109, 44,
  32, 109, 97, 120, 105, 109, 117, 109, 44, 32, 97, 118, 101, 114, 97, 103,
  101, 32, 118, 97, 108, 117, 101, 115, 32, 97, 110, 100, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 118, 97, 114, 105, 97,
  110, 99, 101, 32, 111, 102, 32, 116, 104, 101, 32, 97, 115, 115, 111, 99,
  105, 97, 116, 101, 100, 32, 105, 109, 97, 103, 101, 44, 32, 105, 102, 32,
  97, 110, 121, 32, 40, 48, 32, 111, 116, 104, 101, 114, 119, 105, 115, 101,
  41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32,
  39, 120, 109, 39, 44, 39, 121, 109, 39, 44, 39, 122, 109, 39, 44, 39,
  99, 109, 39, 58, 32, 84, 104, 101, 32, 112, 105, 120, 101, 108, 32, 99,
  111, 111, 114, 100, 105, 110, 97, 116, 101, 115, 32, 111, 102, 32, 116, 104,
  101, 32, 109, 105, 110, 105, 109, 117, 109, 32, 118, 97, 108, 117, 101, 32,
  105, 110, 32, 116, 104, 101, 32, 97, 115, 115, 111, 99, 105, 97, 116, 101,
  100, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  105, 109, 97, 103, 101, 44, 32, 105, 102, 32, 97, 110, 121, 32, 40, 48,
  32, 111, 116, 104, 101, 114, 119, 105, 115, 101, 41, 46, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 120, 77, 39, 44, 39,
  121, 77, 39, 44, 39, 122, 77, 39, 44, 39, 99, 77, 39, 58, 32, 84,
  104, 101, 32, 112, 105, 120, 101, 108, 32, 99, 111, 111, 114, 100, 105, 110,
  97, 116, 101, 115, 32, 111, 102, 32, 116, 104, 101, 32, 109, 97, 120, 105,
  109, 117, 109, 32, 118, 97, 108, 117, 101, 32, 105, 110, 32, 116, 104, 101,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 97,
  115, 115, 111, 99, 105, 97, 116, 101, 100, 32, 105, 109, 97, 103, 101, 44,
  32, 105, 102, 32, 97, 110, 121, 32, 40, 48, 32, 111, 116, 104, 101, 114,
  119, 105, 115, 101, 41, 46, 10, 92, 110, 32, 32, 32, 32, 95, 32, 84,
  104, 101, 115, 101, 32, 115, 112, 101, 99, 105, 97, 108, 32, 111, 112, 101,
  114, 97, 116, 111, 114, 115, 32, 99, 97, 110, 32, 98, 101, 32, 117, 115,
  101, 100, 58, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46,
  32, 39, 59, 39, 58, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 46, 32, 84, 104, 101, 32,
  114, 101, 116, 117, 114, 110, 101, 100, 32, 118, 97, 108, 117, 101, 32, 105,
  115, 32, 97, 108, 119, 97, 121, 115, 32, 116, 104, 101, 32, 108, 97, 115,
  116, 32, 101, 110, 99, 111, 117, 110, 116, 101, 114, 101, 100, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 101, 120, 112, 114,
  101, 115, 115, 105, 111, 110, 46, 32, 70, 111, 114, 32, 105, 110, 115, 116,
  97, 110, 99, 101, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32,
  39, 49, 59, 50, 59, 112, 105, 39, 32, 105, 115, 32, 101, 118, 97, 108,
  117, 97, 116, 101, 100, 32, 97, 115, 32, 39, 112, 105, 39, 46, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 61, 39, 58,
  32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 97, 115, 115, 105, 103, 110,
  109, 101, 110, 116, 46, 32, 86, 97, 114, 105, 97, 98, 108, 101, 115, 32,
  105, 110, 32, 109, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 32,
  112, 97, 114, 115, 101, 114, 32, 99, 97, 110, 32, 111, 110, 108, 121, 32,
  114, 101, 102, 101, 114, 32, 116, 111, 46, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 110, 117, 109, 101, 114, 105, 99, 97,
  108, 32, 118, 97, 108, 117, 101, 115, 46, 32, 86, 97, 114, 105, 97, 98,
  108, 101, 32, 110, 97, 109, 101, 115, 32, 97, 114, 101, 32, 99, 97, 115,
  101, 45, 115, 101, 110, 115, 105, 116, 105, 118, 101, 46, 32, 85, 115, 101,
  32, 116, 104, 105, 115, 32, 111, 112, 101, 114, 97, 116, 111, 114, 32, 105,
  110, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  99, 111, 110, 106, 117, 110, 99, 116, 105, 111, 110, 32, 119, 105, 116, 104,
  32, 39, 59, 39, 32, 116, 111, 32, 100, 101, 102, 105, 110, 101, 32, 99,
  111, 109, 112, 108, 101, 120, 32, 101, 118, 97, 108, 117, 97, 98, 108, 101,
  32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 115, 44, 32, 115, 117,
  99, 104, 32, 97, 115, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 39, 116, 61, 99, 111, 115, 40, 120, 41, 59, 51,
  42, 116, 94, 50, 43, 50, 42, 116, 43, 49, 39, 46, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 84, 104, 101, 115, 101,
  32, 118, 97, 114, 105, 97, 98, 108, 101, 115, 32, 114, 101, 109, 97, 105,
  110, 32, 108, 111, 99, 97, 108, 32, 116, 111, 32, 116, 104, 101, 32, 109,
  97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 32, 112, 97, 114, 115,
  101, 114, 32, 97, 110, 100, 32, 99, 97, 110, 110, 111, 116, 32, 98, 101,
  32, 97, 99, 99, 101, 115, 115, 101, 100, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 111, 117, 116, 115, 105, 100, 101, 32,
  116, 104, 101, 32, 101, 118, 97, 108, 117, 97, 116, 101, 100, 32, 101, 120,
  112, 114, 101, 115, 115, 105, 111, 110, 46, 10, 92, 110, 32, 32, 32, 32,
  95, 32, 84, 104, 101, 32, 102, 111, 108, 108, 111, 119, 105, 110, 103, 32,
  115, 112, 101, 99, 105, 102, 105, 99, 32, 102, 117, 110, 99, 116, 105, 111,
  110, 115, 32, 97, 114, 101, 32, 97, 108, 115, 111, 32, 100, 101, 102, 105,
  110, 101, 100, 58, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  46, 32, 39, 105, 102, 40, 101, 120, 112, 114, 95, 99, 111, 110, 100, 44,
  101, 120, 112, 114, 95, 116, 104, 101, 110, 44, 101, 120, 112, 114, 95, 101,
  108, 115, 101, 41, 39, 58, 32, 114, 101, 116, 117, 114, 110, 32, 118, 97,
  108, 117, 101, 32, 111, 102, 32, 39, 101, 120, 112, 114, 95, 116, 104, 101,
  110, 39, 32, 111, 114, 32, 39, 101, 120, 112, 114, 95, 101, 108, 115, 101,
  39, 44, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 100, 101, 112, 101, 110, 100, 105, 110, 103, 32, 111, 110, 32, 116, 104,
  101, 32, 118, 97, 108, 117, 101, 32, 111, 102, 32, 39, 101, 120, 112, 114,
  95, 99, 111, 110, 100, 39, 32, 40, 48, 61, 102, 97, 108, 115, 101, 44,
  32, 111, 116, 104, 101, 114, 61, 116, 114, 117, 101, 41, 46, 32, 70, 111,
  114, 32, 105, 110, 115, 116, 97, 110, 99, 101, 44, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 71, 39, 77, 73, 67, 32,
  99, 111, 109, 109, 97, 110, 100, 32, 39, 45, 102, 105, 108, 108, 32, 105,
  102, 40, 120, 37, 49, 48, 61, 61, 48, 44, 50, 53, 53, 44, 105, 41,
  39, 32, 119, 105, 108, 108, 32, 100, 114, 97, 119, 32, 98, 108, 97, 110,
  107, 32, 118, 101, 114, 116, 105, 99, 97, 108, 32, 108, 105, 110, 101, 115,
  32, 111, 110, 32, 101, 118, 101, 114, 121, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 49, 48, 116, 104, 32, 99, 111, 108,
  117, 109, 110, 32, 111, 102, 32, 97, 110, 32, 105, 109, 97, 103, 101, 46,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 63,
  40, 109, 97, 120, 41, 39, 32, 111, 114, 32, 39, 63, 40, 109, 105, 110,
  44, 109, 97, 120, 41, 39, 58, 32, 114, 101, 116, 117, 114, 110, 32, 97,
  32, 114, 97, 110, 100, 111, 109, 32, 118, 97, 108, 117, 101, 32, 98, 101,
  116, 119, 101, 101, 110, 32, 91, 48, 44, 109, 97, 120, 93, 32, 111, 114,
  32, 91, 109, 105, 110, 44, 109, 97, 120, 93, 44, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 102, 111, 108, 108, 111, 119,
  105, 110, 103, 32, 97, 32, 117, 110, 105, 102, 111, 114, 109, 32, 100, 105,
  115, 116, 114, 105, 98, 117, 116, 105, 111, 110, 46, 32, 39, 117, 40, 109,
  97, 120, 41, 39, 32, 97, 110, 100, 32, 39, 117, 40, 48, 44, 109, 97,
  120, 41, 39, 32, 109, 101, 97, 110, 32, 116, 104, 101, 32, 115, 97, 109,
  101, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32,
  39, 105, 40, 95, 97, 44, 95, 98, 44, 95, 99, 44, 95, 100, 44, 95,
  105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 44, 95, 98,
  111, 117, 110, 100, 97, 114, 121, 41, 39, 58, 32, 114, 101, 116, 117, 114,
  110, 32, 116, 104, 101, 32, 118, 97, 108, 117, 101, 32, 111, 102, 32, 116,
  104, 101, 32, 112, 105, 120, 101, 108, 32, 108, 111, 99, 97, 116, 101, 100,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 97,
  116, 32, 112, 111, 115, 105, 116, 105, 111, 110, 32, 40, 97, 44, 98, 44,
  99, 44, 100, 41, 32, 105, 110, 32, 116, 104, 101, 32, 97, 115, 115, 111,
  99, 105, 97, 116, 101, 100, 32, 105, 109, 97, 103, 101, 44, 32, 105, 102,
  32, 97, 110, 121, 32, 40, 48, 32, 111, 116, 104, 101, 114, 119, 105, 115,
  101, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 32,
  112, 97, 114, 97, 109, 101, 116, 101, 114, 32, 99, 97, 110, 32, 98, 101,
  32, 123, 32, 48, 61, 110, 101, 97, 114, 101, 115, 116, 32, 110, 101, 105,
  103, 104, 98, 111, 114, 32, 124, 32, 111, 116, 104, 101, 114, 61, 108, 105,
  110, 101, 97, 114, 32, 125, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 66, 111, 117, 110, 100, 97, 114, 121, 32, 99,
  111, 110, 100, 105, 116, 105, 111, 110, 115, 32, 99, 97, 110, 32, 98, 101,
  32, 123, 32, 48, 61, 100, 105, 114, 105, 99, 104, 108, 101, 116, 32, 124,
  32, 49, 61, 110, 101, 117, 109, 97, 110, 110, 32, 124, 32, 50, 61, 99,
  121, 99, 108, 105, 99, 32, 125, 46, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 79, 109, 105, 116, 116, 101, 100, 32, 99,
  111, 111, 114, 100, 105, 110, 97, 116, 101, 115, 32, 97, 114, 101, 32, 114,
  101, 112, 108, 97, 99, 101, 100, 32, 98, 121, 32, 116, 104, 101, 105, 114,
  32, 100, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 32,
  119, 104, 105, 99, 104, 32, 97, 114, 101, 32, 114, 101, 115, 112, 101, 99,
  116, 105, 118, 101, 108, 121, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 120, 44, 32, 121, 44, 32, 122, 44, 32, 99, 32,
  97, 110, 100, 32, 48, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 46, 32, 39, 106, 40, 95, 100, 120, 44, 95, 100, 121, 44, 95,
  100, 122, 44, 95, 100, 99, 44, 95, 105, 110, 116, 101, 114, 112, 111, 108,
  97, 116, 105, 111, 110, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121, 41,
  39, 58, 32, 100, 111, 101, 115, 32, 116, 104, 101, 32, 115, 97, 109, 101,
  32, 102, 111, 114, 32, 116, 104, 101, 32, 112, 105, 120, 101, 108, 32, 108,
  111, 99, 97, 116, 101, 100, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 97, 116, 32, 112, 111, 115, 105, 116, 105, 111, 110,
  32, 40, 120, 43, 100, 120, 44, 121, 43, 100, 121, 44, 122, 43, 100, 122,
  44, 99, 43, 100, 99, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 46, 32, 39, 105, 91, 111, 102, 102, 115, 101, 116, 93, 39,
  58, 32, 114, 101, 116, 117, 114, 110, 32, 116, 104, 101, 32, 118, 97, 108,
  117, 101, 32, 111, 102, 32, 116, 104, 101, 32, 112, 105, 120, 101, 108, 32,
  108, 111, 99, 97, 116, 101, 100, 32, 97, 116, 32, 115, 112, 101, 99, 105,
  102, 105, 101, 100, 32, 111, 102, 102, 115, 101, 116, 32, 105, 110, 32, 116,
  104, 101, 32, 97, 115, 115, 111, 99, 105, 97, 116, 101, 100, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 105, 109, 97, 103,
  101, 32, 98, 117, 102, 102, 101, 114, 46, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 46, 32, 39, 106, 91, 111, 102, 102, 115, 101, 116,
  93, 39, 58, 32, 100, 111, 101, 115, 32, 116, 104, 101, 32, 115, 97, 109,
  101, 32, 102, 111, 114, 32, 97, 110, 32, 111, 102, 102, 115, 101, 116, 32,
  114, 101, 108, 97, 116, 105, 118, 101, 32, 116, 111, 32, 116, 104, 101, 32,
  99, 117, 114, 114, 101, 110, 116, 32, 112, 105, 120, 101, 108, 32, 40, 120,
  44, 121, 44, 122, 44, 99, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 70, 111, 114, 32, 105, 110, 115, 116, 97,
  110, 99, 101, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 45, 102, 105,
  108, 108, 32, 48, 46, 53, 42, 40, 105, 40, 120, 43, 49, 41, 45, 105,
  40, 120, 45, 49, 41, 41, 39, 32, 119, 105, 108, 108, 32, 101, 115, 116,
  105, 109, 97, 116, 101, 32, 116, 104, 101, 32, 88, 45, 100, 101, 114, 105,
  118, 97, 116, 105, 118, 101, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 111, 102, 32, 97, 110, 32, 105, 109, 97, 103, 101,
  32, 119, 105, 116, 104, 32, 97, 32, 99, 108, 97, 115, 115, 105, 99, 97,
  108, 32, 102, 105, 110, 105, 116, 101, 32, 100, 105, 102, 102, 101, 114, 101,
  110, 99, 101, 32, 115, 99, 104, 101, 109, 101, 46, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 46, 32, 73, 102, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 102, 111, 114, 109, 117, 108, 97, 32, 115, 116,
  97, 114, 116, 115, 32, 119, 105, 116, 104, 32, 39, 62, 39, 32, 111, 114,
  32, 39, 60, 39, 44, 32, 116, 104, 101, 32, 111, 112, 101, 114, 97, 116,
  111, 114, 115, 32, 39, 105, 40, 46, 46, 41, 39, 32, 97, 110, 100, 32,
  39, 106, 40, 46, 46, 41, 39, 32, 119, 105, 108, 108, 32, 114, 101, 116,
  117, 114, 110, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 118, 97, 108, 117, 101, 115, 32, 111, 102, 32, 116, 104, 101, 32,
  105, 109, 97, 103, 101, 32, 99, 117, 114, 114, 101, 110, 116, 108, 121, 32,
  98, 101, 105, 110, 103, 32, 109, 111, 100, 105, 102, 105, 101, 100, 44, 32,
  105, 110, 32, 102, 111, 114, 119, 97, 114, 100, 32, 40, 39, 62, 39, 41,
  32, 111, 114, 32, 98, 97, 99, 107, 119, 97, 114, 100, 32, 40, 39, 60,
  39, 41, 32, 111, 114, 100, 101, 114, 46, 10, 92, 110, 32, 32, 45, 32,
  84, 104, 101, 32, 108, 97, 115, 116, 32, 105, 109, 97, 103, 101, 32, 111,
  102, 32, 116, 104, 101, 32, 108, 105, 115, 116, 32, 105, 115, 32, 97, 108,
  119, 97, 121, 115, 32, 97, 115, 115, 111, 99, 105, 97, 116, 101, 100, 32,
  116, 111, 32, 116, 104, 101, 32, 101, 118, 97, 108, 117, 97, 116, 105, 111,
  110, 115, 32, 111, 102, 32, 39, 123, 101, 120, 112, 114, 101, 115, 115, 105,
  111, 110, 115, 125, 39, 44, 10, 92, 110, 32, 32, 32, 32, 32, 101, 46,
  103, 46, 32, 71, 39, 77, 73, 67, 32, 115, 101, 113, 117, 101, 110, 99,
  101, 32, 39, 50, 53, 54, 44, 49, 50, 56, 32, 45, 102, 32, 123, 119,
  125, 39, 32, 119, 105, 108, 108, 32, 99, 114, 101, 97, 116, 101, 32, 97,
  32, 50, 53, 54, 120, 49, 50, 56, 32, 105, 109, 97, 103, 101, 32, 102,
  105, 108, 108, 101, 100, 32, 119, 105, 116, 104, 32, 118, 97, 108, 117, 101,
  32, 50, 53, 54, 46, 34, 10, 45, 95, 104, 101, 108, 112, 95, 115, 101,
  99, 116, 105, 111, 110, 32, 34, 73, 109, 97, 103, 101, 32, 97, 110, 100,
  32, 100, 97, 116, 97, 32, 118, 105, 101, 119, 101, 114, 115, 34, 10, 45,
  95, 104, 101, 108, 112, 95, 112, 97, 114, 97, 103, 114, 97, 112, 104, 32,
  34, 32, 32, 45, 32, 71, 39, 77, 73, 67, 32, 104, 97, 115, 32, 115,
  111, 109, 101, 32, 118, 101, 114, 121, 32, 104, 97, 110, 100, 121, 32, 101,
  109, 98, 101, 100, 100, 101, 100, 32, 118, 105, 115, 117, 97, 108, 105, 122,
  97, 116, 105, 111, 110, 32, 109, 111, 100, 117, 108, 101, 115, 44, 32, 102,
  111, 114, 32, 49, 100, 32, 115, 105, 103, 110, 97, 108, 115, 10, 92, 110,
  32, 32, 32, 32, 32, 40, 99, 111, 109, 109, 97, 110, 100, 32, 39, 45,
  112, 108, 111, 116, 39, 41, 44, 32, 49, 100, 47, 50, 100, 47, 51, 100,
  32, 105, 109, 97, 103, 101, 115, 32, 40, 99, 111, 109, 109, 97, 110, 100,
  32, 39, 45, 100, 105, 115, 112, 108, 97, 121, 39, 41, 32, 97, 110, 100,
  32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 115, 10, 92, 110, 32, 32,
  32, 32, 32, 40, 99, 111, 109, 109, 97, 110, 100, 32, 39, 45, 100, 105,
  115, 112, 108, 97, 121, 51, 100, 39, 41, 46, 32, 73, 116, 32, 101, 110,
  97, 98, 108, 101, 115, 32, 97, 110, 32, 105, 110, 116, 101, 114, 97, 99,
  116, 105, 118, 101, 32, 118, 105, 101, 119, 32, 111, 102, 32, 116, 104, 101,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 32,
  100, 97, 116, 97, 46, 10, 92, 110, 32, 32, 45, 32, 84, 104, 101, 32,
  102, 111, 108, 108, 111, 119, 105, 110, 103, 32, 107, 101, 121, 98, 111, 97,
  114, 100, 32, 115, 104, 111, 114, 116, 99, 117, 116, 115, 32, 97, 114, 101,
  32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 32, 105, 110, 32, 116, 104,
  101, 32, 105, 110, 116, 101, 114, 97, 99, 116, 105, 118, 101, 32, 118, 105,
  101, 119, 101, 114, 115, 58, 10, 92, 110, 32, 32, 32, 32, 46, 32, 67,
  84, 82, 76, 43, 68, 58, 32, 73, 110, 99, 114, 101, 97, 115, 101, 32,
  119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 10, 92, 110, 32,
  32, 32, 32, 46, 32, 67, 84, 82, 76, 43, 67, 58, 32, 68, 101, 99,
  114, 101, 97, 115, 101, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122,
  101, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 67, 84, 82, 76, 43,
  82, 58, 32, 82, 101, 115, 101, 116, 32, 119, 105, 110, 100, 111, 119, 32,
  115, 105, 122, 101, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 67, 84,
  82, 76, 43, 70, 58, 32, 84, 111, 103, 103, 108, 101, 32, 102, 117, 108,
  108, 115, 99, 114, 101, 101, 110, 32, 109, 111, 100, 101, 46, 10, 92, 110,
  32, 32, 32, 32, 46, 32, 67, 84, 82, 76, 43, 83, 58, 32, 83, 97,
  118, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 119, 105, 110, 100, 111,
  119, 32, 115, 110, 97, 112, 115, 104, 111, 116, 32, 97, 115, 32, 110, 117,
  109, 98, 101, 114, 101, 100, 32, 102, 105, 108, 101, 32, 39, 103, 109, 105,
  99, 95, 120, 120, 120, 120, 46, 98, 109, 112, 39, 46, 10, 92, 110, 32,
  32, 32, 32, 46, 32, 67, 84, 82, 76, 43, 79, 58, 32, 83, 97, 118,
  101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 105, 110, 115, 116, 97, 110,
  99, 101, 32, 111, 102, 32, 116, 104, 101, 32, 118, 105, 101, 119, 101, 100,
  32, 100, 97, 116, 97, 44, 32, 97, 115, 32, 110, 117, 109, 98, 101, 114,
  101, 100, 32, 102, 105, 108, 101, 32, 39, 103, 109, 105, 99, 95, 120, 120,
  120, 120, 46, 99, 105, 109, 103, 122, 39, 46, 10, 92, 110, 32, 32, 45,
  32, 83, 104, 111, 114, 116, 99, 117, 116, 115, 32, 115, 112, 101, 99, 105,
  102, 105, 99, 32, 116, 111, 32, 116, 104, 101, 32, 49, 100, 47, 50, 100,
  47, 51, 100, 32, 105, 109, 97, 103, 101, 32, 118, 105, 101, 119, 101, 114,
  32, 97, 114, 101, 58, 10, 92, 110, 32, 32, 32, 32, 46, 32, 67, 84,
  82, 76, 43, 65, 58, 32, 83, 119, 105, 116, 99, 104, 32, 99, 117, 114,
  115, 111, 114, 32, 109, 111, 100, 101, 46, 10, 92, 110, 32, 32, 32, 32,
  46, 32, 67, 84, 82, 76, 43, 80, 58, 32, 80, 108, 97, 121, 32, 122,
  45, 115, 116, 97, 99, 107, 32, 111, 102, 32, 102, 114, 97, 109, 101, 115,
  32, 97, 115, 32, 97, 32, 109, 111, 118, 105, 101, 32, 40, 102, 111, 114,
  32, 118, 111, 108, 117, 109, 101, 116, 114, 105, 99, 32, 51, 100, 32, 105,
  109, 97, 103, 101, 115, 41, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32,
  67, 84, 82, 76, 43, 86, 58, 32, 83, 104, 111, 119, 47, 104, 105, 100,
  101, 32, 51, 68, 32, 118, 105, 101, 119, 32, 40, 102, 111, 114, 32, 118,
  111, 108, 117, 109, 101, 116, 114, 105, 99, 32, 51, 100, 32, 105, 109, 97,
  103, 101, 115, 41, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 67, 84,
  82, 76, 43, 40, 109, 111, 117, 115, 101, 119, 104, 101, 101, 108, 41, 58,
  32, 90, 111, 111, 109, 32, 105, 110, 47, 111, 117, 116, 46, 10, 92, 110,
  32, 32, 32, 32, 46, 32, 83, 72, 73, 70, 84, 43, 40, 109, 111, 117,
  115, 101, 119, 104, 101, 101, 108, 41, 58, 32, 71, 111, 32, 108, 101, 102,
  116, 47, 114, 105, 103, 104, 116, 46, 10, 92, 110, 32, 32, 32, 32, 46,
  32, 65, 76, 84, 43, 40, 109, 111, 117, 115, 101, 119, 104, 101, 101, 108,
  41, 58, 32, 71, 111, 32, 117, 112, 47, 100, 111, 119, 110, 46, 10, 92,
  110, 32, 32, 32, 32, 46, 32, 78, 117, 109, 101, 114, 105, 99, 32, 80,
  65, 68, 58, 32, 90, 111, 111, 109, 32, 105, 110, 47, 111, 117, 116, 32,
  40, 43, 47, 45, 41, 32, 97, 110, 100, 32, 109, 111, 118, 101, 32, 116,
  104, 114, 111, 117, 103, 104, 32, 122, 111, 111, 109, 101, 100, 32, 105, 109,
  97, 103, 101, 32, 40, 100, 105, 103, 105, 116, 115, 41, 46, 10, 92, 110,
  32, 32, 32, 32, 46, 32, 66, 65, 67, 75, 83, 80, 65, 67, 69, 58,
  32, 82, 101, 115, 101, 116, 32, 122, 111, 111, 109, 32, 115, 99, 97, 108,
  101, 46, 10, 92, 110, 32, 32, 45, 32, 83, 104, 111, 114, 116, 99, 117,
  116, 115, 32, 115, 112, 101, 99, 105, 102, 105, 99, 32, 116, 111, 32, 116,
  104, 101, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 32, 118, 105, 101,
  119, 101, 114, 32, 97, 114, 101, 58, 10, 92, 110, 32, 32, 32, 32, 46,
  32, 40, 109, 111, 117, 115, 101, 41, 43, 40, 108, 101, 102, 116, 32, 109,
  111, 117, 115, 101, 32, 98, 117, 116, 116, 111, 110, 41, 58, 32, 82, 111,
  116, 97, 116, 101, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 46, 10,
  92, 110, 32, 32, 32, 32, 46, 32, 40, 109, 111, 117, 115, 101, 41, 43,
  40, 114, 105, 103, 104, 116, 32, 109, 111, 117, 115, 101, 32, 98, 117, 116,
  116, 111, 110, 41, 58, 32, 90, 111, 111, 109, 32, 51, 100, 32, 111, 98,
  106, 101, 99, 116, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 40, 109,
  111, 117, 115, 101, 41, 43, 40, 109, 105, 100, 100, 108, 101, 32, 109, 111,
  117, 115, 101, 32, 98, 117, 116, 116, 111, 110, 41, 58, 32, 83, 104, 105,
  102, 116, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 46, 10, 92, 110,
  32, 32, 32, 32, 46, 32, 40, 109, 111, 117, 115, 101, 119, 104, 101, 101,
  108, 41, 58, 32, 90, 111, 111, 109, 32, 105, 110, 47, 111, 117, 116, 46,
  10, 92, 110, 32, 32, 32, 32, 46, 32, 67, 84, 82, 76, 43, 70, 49,
  32, 46, 46, 32, 67, 84, 82, 76, 43, 70, 54, 58, 32, 83, 119, 105,
  116, 99, 104, 32, 98, 101, 116, 119, 101, 101, 110, 32, 100, 105, 102, 102,
  101, 114, 101, 110, 116, 32, 51, 100, 32, 114, 101, 110, 100, 101, 114, 105,
  110, 103, 32, 109, 111, 100, 101, 115, 46, 10, 92, 110, 32, 32, 32, 32,
  46, 32, 67, 84, 82, 76, 43, 90, 58, 32, 69, 110, 97, 98, 108, 101,
  47, 100, 105, 115, 97, 98, 108, 101, 32, 122, 45, 98, 117, 102, 102, 101,
  114, 101, 100, 32, 114, 101, 110, 100, 101, 114, 105, 110, 103, 46, 10, 92,
  110, 32, 32, 32, 32, 46, 32, 67, 84, 82, 76, 43, 65, 58, 32, 83,
  104, 111, 119, 47, 104, 105, 100, 101, 32, 51, 100, 32, 97, 120, 101, 115,
  46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 67, 84, 82, 76, 43, 71,
  58, 32, 83, 97, 118, 101, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116,
  44, 32, 97, 115, 32, 110, 117, 109, 98, 101, 114, 101, 100, 32, 102, 105,
  108, 101, 32, 39, 103, 109, 105, 99, 95, 120, 120, 120, 120, 46, 111, 102,
  102, 39, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 67, 84, 82, 76,
  43, 84, 58, 32, 83, 119, 105, 116, 99, 104, 32, 98, 101, 116, 119, 101,
  101, 110, 32, 115, 105, 110, 103, 108, 101, 47, 100, 111, 117, 98, 108, 101,
  45, 115, 105, 100, 101, 100, 32, 51, 100, 32, 109, 111, 100, 101, 115, 46,
  34, 10, 45, 95, 104, 101, 108, 112, 95, 115, 101, 99, 116, 105, 111, 110,
  32, 34, 65, 100, 100, 105, 110, 103, 32, 99, 117, 115, 116, 111, 109, 32,
  99, 111, 109, 109, 97, 110, 100, 115, 34, 10, 45, 95, 104, 101, 108, 112,
  95, 112, 97, 114, 97, 103, 114, 97, 112, 104, 32, 34, 32, 32, 45, 32,
  67, 117, 115, 116, 111, 109, 32, 99, 111, 109, 109, 97, 110, 100, 115, 32,
  99, 97, 110, 32, 98, 101, 32, 100, 101, 102, 105, 110, 101, 100, 32, 98,
  121, 32, 97, 32, 117, 115, 101, 114, 44, 32, 116, 104, 114, 111, 117, 103,
  104, 32, 116, 104, 101, 32, 117, 115, 101, 32, 111, 102, 32, 71, 39, 77,
  73, 67, 32, 99, 117, 115, 116, 111, 109, 32, 99, 111, 109, 109, 97, 110,
  100, 115, 32, 102, 105, 108, 101, 115, 46, 10, 92, 110, 32, 32, 45, 32,
  65, 32, 99, 111, 109, 109, 97, 110, 100, 32, 102, 105, 108, 101, 32, 105,
  115, 32, 97, 32, 115, 105, 109, 112, 108, 101, 32, 97, 115, 99, 105, 105,
  32, 116, 101, 120, 116, 32, 102, 105, 108, 101, 44, 32, 119, 104, 101, 114,
  101, 32, 101, 97, 99, 104, 32, 108, 105, 110, 101, 32, 115, 116, 97, 114,
  116, 115, 32, 101, 105, 116, 104, 101, 114, 32, 98, 121, 10, 92, 110, 32,
  32, 32, 32, 32, 39, 99, 111, 109, 109, 97, 110, 100, 95, 110, 97, 109,
  101, 58, 32, 99, 111, 109, 109, 97, 110, 100, 95, 100, 101, 102, 105, 110,
  105, 116, 105, 111, 110, 39, 32, 111, 114, 32, 39, 99, 111, 109, 109, 97,
  110, 100, 95, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 40, 99,
  111, 110, 116, 105, 110, 117, 97, 116, 105, 111, 110, 41, 39, 46, 10, 92,
  110, 32, 32, 45, 32, 67, 117, 115, 116, 111, 109, 32, 99, 111, 109, 109,
  97, 110, 100, 32, 110, 97, 109, 101, 115, 32, 109, 117, 115, 116, 32, 117,
  115, 101, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 115, 32, 91, 97,
  45, 122, 65, 45, 90, 48, 45, 57, 95, 93, 32, 97, 110, 100, 32, 99,
  97, 110, 110, 111, 116, 32, 115, 116, 97, 114, 116, 32, 119, 105, 116, 104,
  32, 97, 32, 110, 117, 109, 98, 101, 114, 46, 10, 92, 110, 32, 32, 45,
  32, 65, 110, 121, 32, 39, 32, 92, 35, 32, 99, 111, 109, 109, 101, 110,
  116, 39, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 102, 111,
  117, 110, 100, 32, 105, 110, 32, 97, 32, 99, 117, 115, 116, 111, 109, 32,
  99, 111, 109, 109, 97, 110, 100, 115, 32, 102, 105, 108, 101, 32, 105, 115,
  32, 100, 105, 115, 99, 97, 114, 100, 101, 100, 32, 98, 121, 32, 116, 104,
  101, 32, 71, 39, 77, 73, 67, 10, 92, 110, 32, 32, 32, 32, 32, 105,
  110, 116, 101, 114, 112, 114, 101, 116, 101, 114, 44, 32, 119, 104, 101, 114,
  101, 118, 101, 114, 32, 105, 116, 32, 105, 115, 32, 108, 111, 99, 97, 116,
  101, 100, 32, 105, 110, 32, 97, 32, 108, 105, 110, 101, 46, 10, 92, 110,
  32, 32, 45, 32, 73, 110, 32, 99, 117, 115, 116, 111, 109, 32, 99, 111,
  109, 109, 97, 110, 100, 115, 44, 32, 116, 104, 101, 32, 102, 111, 108, 108,
  111, 119, 105, 110, 103, 32, 36, 45, 101, 120, 112, 114, 101, 115, 115, 105,
  111, 110, 115, 32, 97, 114, 101, 32, 115, 117, 98, 115, 116, 105, 116, 117,
  116, 101, 100, 58, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 36, 34,
  34, 42, 39, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116,
  101, 100, 32, 98, 121, 32, 97, 32, 99, 111, 112, 121, 32, 111, 102, 32,
  116, 104, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 115, 116,
  114, 105, 110, 103, 32, 111, 102, 32, 97, 114, 103, 117, 109, 101, 110, 116,
  115, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 36, 92, 34, 42,
  92, 34, 39, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116,
  101, 100, 32, 98, 121, 32, 97, 32, 99, 111, 112, 121, 32, 111, 102, 32,
  116, 104, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 115, 116,
  114, 105, 110, 103, 32, 111, 102, 32, 97, 114, 103, 117, 109, 101, 110, 116,
  115, 44, 32, 101, 97, 99, 104, 32, 98, 101, 105, 110, 103, 32, 97, 114,
  111, 117, 110, 100, 32, 100, 111, 117, 98, 108, 101, 32, 113, 117, 111, 116,
  101, 115, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 36, 34, 34,
  35, 39, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101,
  100, 32, 98, 121, 32, 116, 104, 101, 32, 109, 97, 120, 105, 109, 117, 109,
  32, 105, 110, 100, 105, 99, 101, 32, 111, 102, 32, 107, 110, 111, 119, 110,
  32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 40, 101, 105, 116, 104,
  101, 114, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 98, 121, 32,
  116, 104, 101, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 117, 115, 101,
  114, 32, 111, 114, 32, 115, 101, 116, 32, 116, 111, 32, 97, 32, 100, 101,
  102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 32, 105, 110, 32, 116,
  104, 101, 32, 99, 117, 115, 116, 111, 109, 32, 99, 111, 109, 109, 97, 110,
  100, 41, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 36, 34, 34,
  63, 39, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101,
  100, 32, 98, 121, 32, 97, 32, 115, 116, 114, 105, 110, 103, 32, 116, 101,
  108, 108, 105, 110, 103, 32, 97, 98, 111, 117, 116, 32, 116, 104, 101, 32,
  99, 111, 109, 109, 97, 110, 100, 32, 115, 117, 98, 115, 101, 116, 32, 114,
  101, 115, 116, 114, 105, 99, 116, 105, 111, 110, 32, 40, 111, 110, 108, 121,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 117, 115, 101, 102, 117, 108,
  32, 119, 104, 101, 110, 32, 99, 117, 115, 116, 111, 109, 32, 99, 111, 109,
  109, 97, 110, 100, 115, 32, 110, 101, 101, 100, 32, 116, 111, 32, 111, 117,
  116, 112, 117, 116, 32, 100, 101, 115, 99, 114, 105, 112, 116, 105, 118, 101,
  32, 109, 101, 115, 115, 97, 103, 101, 115, 41, 46, 10, 92, 110, 32, 32,
  32, 32, 46, 32, 39, 36, 105, 39, 32, 97, 110, 100, 32, 39, 36, 123,
  105, 125, 39, 32, 97, 114, 101, 32, 98, 111, 116, 104, 32, 115, 117, 98,
  115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32,
  105, 45, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 97,
  114, 103, 117, 109, 101, 110, 116, 46, 32, 78, 101, 103, 97, 116, 105, 118,
  101, 32, 105, 110, 100, 105, 99, 101, 115, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 115, 117, 99, 104, 32, 97, 115, 32, 39, 36, 123, 45, 106,
  125, 39, 32, 97, 114, 101, 32, 97, 108, 108, 111, 119, 101, 100, 32, 97,
  110, 100, 32, 114, 101, 102, 101, 114, 32, 116, 111, 32, 116, 104, 101, 32,
  106, 94, 116, 104, 32, 108, 97, 116, 101, 115, 116, 32, 97, 114, 103, 117,
  109, 101, 110, 116, 46, 32, 39, 36, 34, 34, 48, 39, 32, 105, 115, 32,
  115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 98, 121, 32, 116, 104, 101, 32, 99, 117, 115, 116,
  111, 109, 32, 99, 111, 109, 109, 97, 110, 100, 32, 110, 97, 109, 101, 46,
  10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 36, 123, 105, 61, 100, 101,
  102, 97, 117, 108, 116, 125, 39, 32, 105, 115, 32, 115, 117, 98, 115, 116,
  105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 118, 97,
  108, 117, 101, 32, 111, 102, 32, 36, 105, 32, 40, 105, 102, 32, 100, 101,
  102, 105, 110, 101, 100, 41, 32, 111, 114, 32, 98, 121, 32, 105, 116, 115,
  32, 110, 101, 119, 32, 118, 97, 108, 117, 101, 32, 115, 101, 116, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 32, 116, 111, 32, 39, 100, 101, 102,
  97, 117, 108, 116, 39, 32, 111, 116, 104, 101, 114, 119, 105, 115, 101, 32,
  40, 39, 100, 101, 102, 97, 117, 108, 116, 39, 32, 109, 97, 121, 32, 98,
  101, 32, 97, 32, 36, 45, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110,
  32, 97, 115, 32, 119, 101, 108, 108, 41, 46, 10, 92, 110, 32, 32, 32,
  32, 46, 32, 39, 36, 123, 115, 117, 98, 115, 101, 116, 125, 39, 32, 105,
  115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121,
  32, 116, 104, 101, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 118,
  97, 108, 117, 101, 115, 32, 40, 115, 101, 112, 97, 114, 97, 116, 101, 100,
  32, 98, 121, 32, 99, 111, 109, 109, 97, 115, 32, 39, 44, 39, 41, 32,
  111, 102, 32, 97, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 97, 114, 103, 117, 109, 101, 110, 116,
  32, 115, 117, 98, 115, 101, 116, 46, 32, 70, 111, 114, 32, 105, 110, 115,
  116, 97, 110, 99, 101, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110,
  32, 39, 36, 34, 34, 123, 50, 45, 45, 50, 125, 39, 32, 105, 115, 32,
  115, 117, 98, 115, 116, 105, 116, 117, 101, 100, 32, 98, 121, 32, 97, 108,
  108, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 115, 112, 101, 99, 105,
  102, 105, 101, 100, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 101,
  120, 99, 101, 112, 116, 32, 116, 104, 101, 32, 102, 105, 114, 115, 116, 32,
  97, 110, 100, 32, 116, 104, 101, 32, 108, 97, 115, 116, 32, 111, 110, 101,
  46, 32, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 39, 36, 34,
  34, 123, 94, 48, 125, 39, 32, 105, 115, 32, 116, 104, 101, 110, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 115, 117, 98, 115, 116, 105, 116, 117,
  116, 101, 100, 32, 98, 121, 32, 97, 108, 108, 32, 97, 114, 103, 117, 109,
  101, 110, 116, 115, 32, 111, 102, 32, 116, 104, 101, 32, 105, 110, 118, 111,
  107, 101, 100, 32, 99, 111, 109, 109, 97, 110, 100, 32, 40, 101, 113, 46,
  32, 116, 111, 32, 39, 36, 34, 34, 42, 39, 32, 105, 102, 32, 97, 108,
  108, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 104,
  97, 118, 101, 32, 105, 110, 100, 101, 101, 100, 32, 97, 32, 118, 97, 108,
  117, 101, 41, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 36, 34,
  34, 61, 118, 97, 114, 39, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105,
  116, 117, 116, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 115, 101, 116,
  32, 111, 102, 32, 105, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115,
  32, 116, 104, 97, 116, 32, 119, 105, 108, 108, 32, 97, 115, 115, 105, 103,
  110, 32, 101, 97, 99, 104, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32,
  36, 105, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 116, 111, 32, 116,
  104, 101, 32, 110, 97, 109, 101, 100, 32, 118, 97, 114, 105, 97, 98, 108,
  101, 32, 39, 118, 97, 114, 36, 105, 39, 32, 40, 102, 111, 114, 32, 105,
  32, 105, 110, 32, 91, 48, 46, 46, 36, 34, 34, 35, 93, 41, 46, 32,
  84, 104, 105, 115, 32, 105, 115, 32, 112, 97, 114, 116, 105, 99, 117, 108,
  97, 114, 108, 121, 32, 117, 115, 101, 102, 117, 108, 32, 119, 104, 101, 110,
  32, 97, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 99, 117, 115, 116,
  111, 109, 32, 99, 111, 109, 109, 97, 110, 100, 32, 119, 97, 110, 116, 32,
  116, 111, 32, 109, 97, 110, 97, 103, 101, 32, 118, 97, 114, 105, 97, 98,
  108, 101, 32, 110, 117, 109, 98, 101, 114, 115, 32, 111, 102, 32, 97, 114,
  103, 117, 109, 101, 110, 116, 115, 46, 32, 86, 97, 114, 105, 97, 98, 108,
  101, 115, 32, 110, 97, 109, 101, 115, 32, 109, 117, 115, 116, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 117, 115, 101, 32, 99, 104, 97, 114, 97,
  99, 116, 101, 114, 115, 32, 91, 97, 45, 122, 65, 45, 90, 48, 45, 57,
  95, 93, 32, 97, 110, 100, 32, 99, 97, 110, 110, 111, 116, 32, 115, 116,
  97, 114, 116, 32, 119, 105, 116, 104, 32, 97, 32, 110, 117, 109, 98, 101,
  114, 46, 10, 92, 110, 32, 32, 45, 32, 84, 104, 101, 115, 101, 32, 112,
  97, 114, 116, 105, 99, 117, 108, 97, 114, 32, 36, 45, 101, 120, 112, 114,
  101, 115, 115, 105, 111, 110, 115, 32, 97, 114, 101, 32, 97, 108, 119, 97,
  121, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 44, 32,
  101, 118, 101, 110, 32, 105, 110, 32, 100, 111, 117, 98, 108, 101, 32, 113,
  117, 111, 116, 101, 100, 32, 105, 116, 101, 109, 115, 32, 111, 114, 10, 92,
  110, 32, 32, 32, 32, 32, 119, 104, 101, 110, 32, 116, 104, 101, 32, 100,
  111, 108, 108, 97, 114, 32, 115, 105, 103, 110, 32, 39, 36, 39, 32, 105,
  115, 32, 101, 115, 99, 97, 112, 101, 100, 32, 119, 105, 116, 104, 32, 97,
  32, 98, 97, 99, 107, 115, 108, 97, 115, 104, 32, 39, 92, 92, 39, 46,
  32, 84, 111, 32, 97, 118, 111, 105, 100, 32, 115, 117, 98, 115, 116, 105,
  116, 117, 116, 105, 111, 110, 44, 32, 112, 108, 97, 99, 101, 10, 92, 110,
  32, 32, 32, 32, 32, 97, 110, 32, 101, 109, 112, 116, 121, 32, 100, 111,
  117, 98, 108, 101, 32, 113, 117, 111, 116, 101, 100, 32, 115, 116, 114, 105,
  110, 103, 32, 106, 117, 115, 116, 32, 97, 102, 116, 101, 114, 32, 116, 104,
  101, 32, 39, 36, 39, 32, 40, 97, 115, 32, 105, 110, 32, 39, 36, 92,
  34, 92, 34, 49, 39, 41, 46, 10, 92, 110, 32, 32, 45, 32, 83, 112,
  101, 99, 105, 102, 121, 105, 110, 103, 32, 97, 114, 103, 117, 109, 101, 110,
  116, 115, 32, 109, 97, 121, 32, 98, 101, 32, 115, 107, 105, 112, 112, 101,
  100, 32, 119, 104, 101, 110, 32, 105, 110, 118, 111, 107, 105, 110, 103, 32,
  97, 32, 99, 117, 115, 116, 111, 109, 32, 99, 111, 109, 109, 97, 110, 100,
  44, 32, 98, 121, 32, 114, 101, 112, 108, 97, 99, 105, 110, 103, 32, 116,
  104, 101, 109, 32, 98, 121, 10, 92, 110, 32, 32, 32, 32, 32, 99, 111,
  109, 109, 97, 115, 32, 39, 44, 39, 32, 97, 115, 32, 105, 110, 32, 101,
  120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 39, 45, 102, 108, 111, 119,
  101, 114, 32, 44, 44, 51, 39, 46, 32, 79, 109, 105, 116, 116, 101, 100,
  32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 97, 114, 101, 32, 115,
  101, 116, 32, 116, 111, 32, 116, 104, 101, 105, 114, 32, 100, 101, 102, 97,
  117, 108, 116, 10, 92, 110, 32, 32, 32, 32, 32, 118, 97, 108, 117, 101,
  115, 44, 32, 119, 104, 105, 99, 104, 32, 109, 117, 115, 116, 32, 98, 101,
  32, 116, 104, 117, 115, 32, 101, 120, 112, 108, 105, 99, 105, 116, 108, 121,
  32, 100, 101, 102, 105, 110, 101, 100, 32, 105, 110, 32, 116, 104, 101, 32,
  99, 111, 100, 101, 32, 111, 102, 32, 116, 104, 101, 32, 99, 111, 114, 114,
  101, 115, 112, 111, 110, 100, 105, 110, 103, 32, 99, 117, 115, 116, 111, 109,
  10, 92, 110, 32, 32, 32, 32, 32, 99, 111, 109, 109, 97, 110, 100, 32,
  40, 117, 115, 105, 110, 103, 32, 100, 101, 102, 97, 117, 108, 116, 32, 97,
  114, 103, 117, 109, 101, 110, 116, 32, 101, 120, 112, 114, 101, 115, 115, 105,
  111, 110, 115, 32, 97, 115, 32, 39, 36, 34, 34, 123, 49, 61, 100, 101,
  102, 97, 117, 108, 116, 125, 39, 41, 46, 10, 92, 110, 32, 32, 45, 32,
  73, 102, 32, 111, 110, 101, 32, 110, 117, 109, 98, 101, 114, 101, 100, 32,
  97, 114, 103, 117, 109, 101, 110, 116, 32, 114, 101, 113, 117, 101, 115, 116,
  101, 100, 32, 105, 110, 32, 97, 32, 99, 117, 115, 116, 111, 109, 32, 99,
  111, 109, 109, 97, 110, 100, 32, 104, 97, 115, 32, 110, 111, 32, 118, 97,
  108, 117, 101, 44, 32, 97, 110, 32, 101, 114, 114, 111, 114, 32, 105, 115,
  32, 116, 104, 114, 111, 119, 110, 10, 92, 110, 32, 32, 32, 32, 32, 98,
  121, 32, 116, 104, 101, 32, 105, 110, 116, 101, 114, 112, 114, 101, 116, 101,
  114, 46, 34, 10, 45, 95, 104, 101, 108, 112, 95, 115, 101, 99, 116, 105,
  111, 110, 32, 34, 76, 105, 115, 116, 32, 111, 102, 32, 99, 111, 109, 109,
  97, 110, 100, 115, 34, 10, 45, 95, 104, 101, 108, 112, 95, 112, 97, 114,
  97, 103, 114, 97, 112, 104, 32, 34, 32, 65, 108, 108, 32, 97, 118, 97,
  105, 108, 97, 98, 108, 101, 32, 71, 39, 77, 73, 67, 32, 99, 111, 109,
  109, 97, 110, 100, 115, 32, 97, 114, 101, 32, 108, 105, 115, 116, 101, 100,
  32, 98, 101, 108, 111, 119, 44, 32, 99, 108, 97, 115, 115, 105, 102, 105,
  101, 100, 32, 98, 121, 32, 116, 104, 101, 109, 101, 115, 46, 10, 92, 110,
  32, 87, 104, 101, 110, 32, 115, 101, 118, 101, 114, 97, 108, 32, 99, 104,
  111, 105, 99, 101, 115, 32, 111, 102, 32, 99, 111, 109, 109, 97, 110, 100,
  32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 97, 114, 101, 32, 112,
  111, 115, 115, 105, 98, 108, 101, 44, 32, 116, 104, 101, 121, 32, 97, 112,
  112, 101, 97, 114, 32, 115, 101, 112, 97, 114, 97, 116, 101, 100, 32, 98,
  121, 32, 39, 124, 39, 46, 10, 92, 110, 32, 65, 110, 32, 97, 114, 103,
  117, 109, 101, 110, 116, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  105, 110, 115, 105, 100, 101, 32, 39, 91, 93, 39, 32, 111, 114, 32, 115,
  116, 97, 114, 116, 105, 110, 103, 32, 98, 121, 32, 39, 95, 39, 32, 105,
  115, 32, 111, 112, 116, 105, 111, 110, 97, 108, 32, 101, 120, 99, 101, 112,
  116, 32, 119, 104, 101, 110, 32, 115, 116, 97, 110, 100, 105, 110, 103, 32,
  102, 111, 114, 32, 97, 110, 10, 92, 110, 32, 101, 120, 105, 115, 116, 105,
  110, 103, 32, 105, 109, 97, 103, 101, 32, 91, 105, 109, 97, 103, 101, 93,
  44, 32, 119, 104, 101, 114, 101, 32, 39, 105, 109, 97, 103, 101, 39, 32,
  99, 97, 110, 32, 98, 101, 32, 101, 105, 116, 104, 101, 114, 32, 97, 110,
  32, 105, 110, 100, 105, 99, 101, 32, 110, 117, 109, 98, 101, 114, 32, 111,
  114, 32, 97, 110, 32, 105, 109, 97, 103, 101, 32, 110, 97, 109, 101, 46,
  10, 92, 110, 32, 73, 110, 32, 116, 104, 105, 115, 32, 99, 97, 115, 101,
  44, 32, 116, 104, 101, 32, 39, 91, 93, 39, 32, 99, 104, 97, 114, 97,
  99, 116, 101, 114, 115, 32, 97, 114, 101, 32, 109, 97, 110, 100, 97, 116,
  111, 114, 121, 32, 119, 104, 101, 110, 32, 119, 114, 105, 116, 105, 110, 103,
  32, 116, 104, 101, 32, 105, 116, 101, 109, 46, 32, 65, 32, 99, 111, 109,
  109, 97, 110, 100, 32, 109, 97, 114, 107, 101, 100, 32, 119, 105, 116, 104,
  10, 92, 110, 32, 39, 40, 42, 41, 39, 32, 111, 114, 32, 39, 40, 43,
  41, 39, 32, 105, 115, 32, 97, 32, 110, 97, 116, 105, 118, 101, 32, 99,
  111, 109, 109, 97, 110, 100, 46, 32, 39, 40, 42, 41, 39, 32, 109, 101,
  97, 110, 115, 32, 116, 104, 101, 32, 99, 111, 109, 109, 97, 110, 100, 32,
  105, 115, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 32, 102, 111, 114,
  32, 97, 108, 108, 32, 112, 105, 120, 101, 108, 32, 116, 121, 112, 101, 115,
  44, 10, 92, 110, 32, 111, 116, 104, 101, 114, 119, 105, 115, 101, 32, 111,
  110, 108, 121, 32, 102, 111, 114, 32, 116, 104, 101, 32, 100, 101, 102, 97,
  117, 108, 116, 32, 39, 102, 108, 111, 97, 116, 39, 32, 112, 105, 120, 101,
  108, 32, 116, 121, 112, 101, 46, 10, 92, 110, 32, 82, 101, 109, 101, 109,
  98, 101, 114, 32, 116, 104, 97, 116, 32, 110, 97, 116, 105, 118, 101, 32,
  99, 111, 109, 109, 97, 110, 100, 115, 32, 114, 117, 110, 32, 102, 97, 115,
  116, 101, 114, 32, 116, 104, 97, 110, 32, 99, 117, 115, 116, 111, 109, 32,
  99, 111, 109, 109, 97, 110, 100, 115, 44, 32, 115, 111, 32, 117, 115, 101,
  32, 116, 104, 101, 110, 32, 119, 104, 101, 110, 32, 112, 111, 115, 115, 105,
  98, 108, 101, 46, 10, 92, 110, 32, 78, 111, 116, 101, 32, 97, 108, 115,
  111, 32, 116, 104, 97, 116, 32, 97, 108, 108, 32, 105, 109, 97, 103, 101,
  115, 32, 105, 110, 32, 116, 104, 105, 115, 32, 114, 101, 102, 101, 114, 101,
  110, 99, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 97, 116, 105, 111,
  110, 32, 97, 114, 101, 32, 110, 111, 114, 109, 97, 108, 105, 122, 101, 100,
  32, 105, 110, 32, 91, 48, 44, 50, 53, 53, 93, 32, 98, 101, 102, 111,
  114, 101, 10, 92, 110, 32, 98, 101, 105, 110, 103, 32, 100, 105, 115, 112,
  108, 97, 121, 101, 100, 46, 32, 89, 111, 117, 32, 109, 97, 121, 32, 110,
  101, 101, 100, 32, 116, 111, 32, 100, 111, 32, 116, 104, 105, 115, 32, 109,
  97, 110, 117, 97, 108, 108, 121, 32, 40, 99, 111, 109, 109, 97, 110, 100,
  32, 39, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 32, 48, 44, 50,
  53, 53, 39, 41, 32, 105, 102, 32, 121, 111, 117, 32, 119, 97, 110, 116,
  10, 92, 110, 32, 115, 97, 118, 101, 32, 105, 109, 97, 103, 101, 32, 102,
  105, 108, 101, 115, 32, 104, 97, 118, 105, 110, 103, 32, 116, 104, 101, 32,
  115, 97, 109, 101, 32, 97, 115, 112, 101, 99, 116, 32, 116, 104, 97, 110,
  32, 116, 104, 111, 115, 101, 32, 100, 105, 115, 112, 108, 97, 121, 101, 100,
  46, 34, 10, 95, 104, 101, 108, 112, 95, 101, 120, 97, 109, 112, 108, 101,
  115, 32, 58, 10, 45, 95, 104, 101, 108, 112, 95, 115, 101, 99, 116, 105,
  111, 110, 32, 34, 69, 120, 97, 109, 112, 108, 101, 115, 32, 111, 102, 32,
  117, 115, 101, 34, 10, 45, 95, 104, 101, 108, 112, 95, 112, 97, 114, 97,
  103, 114, 97, 112, 104, 32, 34, 32, 39, 103, 109, 105, 99, 39, 32, 105,
  115, 32, 97, 32, 103, 101, 110, 101, 114, 105, 99, 32, 105, 109, 97, 103,
  101, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 116, 111, 111,
  108, 32, 119, 104, 105, 99, 104, 32, 99, 97, 110, 32, 98, 101, 32, 117,
  115, 101, 100, 32, 105, 110, 32, 97, 32, 119, 105, 100, 101, 32, 118, 97,
  114, 105, 101, 116, 121, 32, 111, 102, 32, 115, 105, 116, 117, 97, 116, 105,
  111, 110, 115, 46, 10, 92, 110, 32, 84, 104, 101, 32, 102, 101, 119, 32,
  101, 120, 97, 109, 112, 108, 101, 115, 32, 98, 101, 108, 111, 119, 32, 105,
  108, 108, 117, 115, 116, 114, 97, 116, 101, 32, 112, 111, 115, 115, 105, 98,
  108, 101, 32, 117, 115, 101, 115, 32, 111, 102, 32, 116, 104, 105, 115, 32,
  116, 111, 111, 108, 58, 10, 92, 110, 10, 92, 110, 32, 32, 45, 32, 86,
  105, 101, 119, 32, 97, 32, 108, 105, 115, 116, 32, 111, 102, 32, 105, 109,
  97, 103, 101, 115, 58, 10, 92, 110, 32, 32, 32, 32, 32, 103, 109, 105,
  99, 32, 102, 105, 108, 101, 49, 46, 98, 109, 112, 32, 102, 105, 108, 101,
  50, 46, 106, 112, 101, 103, 10, 92, 110, 10, 92, 110, 32, 32, 45, 32,
  67, 111, 110, 118, 101, 114, 116, 32, 97, 110, 32, 105, 109, 97, 103, 101,
  32, 102, 105, 108, 101, 58, 10, 92, 110, 32, 32, 32, 32, 32, 103, 109,
  105, 99, 32, 105, 110, 112, 117, 116, 46, 98, 109, 112, 32, 45, 111, 32,
  111, 117, 116, 112, 117, 116, 46, 106, 112, 103, 10, 92, 110, 10, 92, 110,
  32, 32, 45, 32, 67, 114, 101, 97, 116, 101, 32, 97, 32, 118, 111, 108,
  117, 109, 101, 116, 114, 105, 99, 32, 105, 109, 97, 103, 101, 32, 102, 114,
  111, 109, 32, 97, 32, 109, 111, 118, 105, 101, 32, 115, 101, 113, 117, 101,
  110, 99, 101, 58, 10, 92, 110, 32, 32, 32, 32, 32, 103, 109, 105, 99,
  32, 105, 110, 112, 117, 116, 46, 109, 112, 103, 32, 45, 97, 32, 122, 32,
  45, 111, 32, 111, 117, 116, 112, 117, 116, 46, 104, 100, 114, 10, 92, 110,
  10, 92, 110, 32, 32, 45, 32, 67, 111, 109, 112, 117, 116, 101, 32, 105,
  109, 97, 103, 101, 32, 103, 114, 97, 100, 105, 101, 110, 116, 32, 110, 111,
  114, 109, 58, 10, 92, 110, 32, 32, 32, 32, 32, 103, 109, 105, 99, 32,
  105, 110, 112, 117, 116, 46, 98, 109, 112, 32, 45, 103, 114, 97, 100, 105,
  101, 110, 116, 95, 110, 111, 114, 109, 10, 92, 110, 10, 92, 110, 32, 32,
  45, 32, 68, 101, 110, 111, 105, 115, 101, 32, 97, 32, 99, 111, 108, 111,
  114, 32, 105, 109, 97, 103, 101, 58, 10, 92, 110, 32, 32, 32, 32, 32,
  103, 109, 105, 99, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  100, 101, 110, 111, 105, 115, 101, 32, 51, 48, 44, 49, 48, 32, 45, 111,
  32, 100, 101, 110, 111, 105, 115, 101, 100, 46, 106, 112, 103, 10, 92, 110,
  10, 92, 110, 32, 32, 45, 32, 67, 111, 109, 112, 111, 115, 101, 32, 116,
  119, 111, 32, 105, 109, 97, 103, 101, 115, 32, 117, 115, 105, 110, 103, 32,
  111, 118, 101, 114, 108, 97, 121, 32, 108, 97, 121, 101, 114, 32, 98, 108,
  101, 110, 100, 105, 110, 103, 58, 10, 92, 110, 32, 32, 32, 32, 32, 103,
  109, 105, 99, 32, 105, 109, 97, 103, 101, 49, 46, 106, 112, 103, 32, 105,
  109, 97, 103, 101, 50, 46, 106, 112, 103, 32, 45, 98, 108, 101, 110, 100,
  32, 111, 118, 101, 114, 108, 97, 121, 32, 45, 111, 32, 98, 108, 101, 110,
  100, 101, 100, 46, 106, 112, 103, 10, 92, 110, 10, 92, 110, 32, 32, 45,
  32, 69, 118, 97, 108, 117, 97, 116, 101, 32, 97, 32, 109, 97, 116, 104,
  101, 109, 97, 116, 105, 99, 97, 108, 32, 101, 120, 112, 114, 101, 115, 115,
  105, 111, 110, 58, 10, 92, 110, 32, 32, 32, 32, 32, 103, 109, 105, 99,
  32, 45, 101, 32, 92, 34, 99, 111, 115, 40, 112, 105, 47, 52, 41, 94,
  50, 43, 115, 105, 110, 40, 112, 105, 47, 52, 41, 94, 50, 61, 123, 99,
  111, 115, 40, 112, 105, 47, 52, 41, 94, 50, 43, 115, 105, 110, 40, 112,
  105, 47, 52, 41, 94, 50, 125, 92, 34, 10, 92, 110, 10, 92, 110, 32,
  32, 45, 32, 80, 108, 111, 116, 32, 97, 32, 50, 100, 32, 102, 117, 110,
  99, 116, 105, 111, 110, 58, 10, 92, 110, 32, 32, 32, 32, 32, 103, 109,
  105, 99, 32, 49, 48, 48, 48, 44, 49, 44, 49, 44, 50, 32, 45, 102,
  32, 92, 34, 88, 61, 51, 42, 40, 120, 45, 53, 48, 48, 41, 47, 53,
  48, 48, 59, 88, 94, 50, 42, 115, 105, 110, 40, 51, 42, 88, 94, 50,
  41, 43, 105, 102, 40, 99, 61, 61, 48, 44, 117, 40, 48, 44, 45, 49,
  41, 44, 99, 111, 115, 40, 88, 42, 49, 48, 41, 41, 92, 34, 32, 45,
  112, 108, 111, 116, 10, 92, 110, 10, 92, 110, 32, 32, 45, 32, 80, 108,
  111, 116, 32, 97, 32, 51, 100, 32, 101, 108, 101, 118, 97, 116, 101, 100,
  32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 105, 110, 32, 114, 97, 110,
  100, 111, 109, 32, 99, 111, 108, 111, 114, 115, 58, 10, 92, 110, 32, 32,
  32, 32, 32, 103, 109, 105, 99, 32, 49, 50, 56, 44, 49, 50, 56, 44,
  49, 44, 51, 44, 92, 34, 63, 40, 48, 44, 50, 53, 53, 41, 92, 34,
  32, 45, 112, 108, 97, 115, 109, 97, 32, 49, 48, 44, 51, 32, 45, 98,
  108, 117, 114, 32, 52, 32, 45, 115, 104, 97, 114, 112, 101, 110, 32, 49,
  48, 48, 48, 48, 32, 92, 92, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  45, 101, 108, 101, 118, 97, 116, 105, 111, 110, 51, 100, 91, 45, 49, 93,
  32, 92, 34, 39, 88, 61, 40, 120, 45, 54, 52, 41, 47, 54, 59, 89,
  61, 40, 121, 45, 54, 52, 41, 47, 54, 59, 49, 48, 48, 42, 101, 120,
  112, 40, 45, 40, 88, 94, 50, 43, 89, 94, 50, 41, 47, 51, 48, 41,
  42, 97, 98, 115, 40, 99, 111, 115, 40, 88, 41, 42, 115, 105, 110, 40,
  89, 41, 41, 39, 92, 34, 10, 92, 110, 10, 92, 110, 32, 32, 45, 32,
  80, 108, 111, 116, 32, 116, 104, 101, 32, 105, 115, 111, 115, 117, 114, 102,
  97, 99, 101, 32, 111, 102, 32, 97, 32, 51, 100, 32, 118, 111, 108, 117,
  109, 101, 58, 10, 92, 110, 32, 32, 32, 32, 32, 103, 109, 105, 99, 32,
  45, 109, 51, 100, 32, 53, 32, 45, 109, 100, 51, 100, 32, 53, 32, 45,
  100, 98, 51, 100, 32, 48, 32, 45, 105, 115, 111, 115, 117, 114, 102, 97,
  99, 101, 51, 100, 32, 92, 34, 39, 120, 94, 50, 43, 121, 94, 50, 43,
  97, 98, 115, 40, 122, 41, 94, 97, 98, 115, 40, 52, 42, 99, 111, 115,
  40, 120, 42, 121, 42, 122, 42, 51, 41, 41, 39, 92, 34, 44, 51, 10,
  92, 110, 10, 92, 110, 32, 32, 45, 32, 82, 101, 110, 100, 101, 114, 32,
  97, 32, 71, 39, 77, 73, 67, 32, 51, 100, 32, 108, 111, 103, 111, 58,
  10, 92, 110, 32, 32, 32, 32, 32, 103, 109, 105, 99, 32, 49, 32, 45,
  116, 101, 120, 116, 32, 71, 92, 92, 39, 77, 73, 67, 44, 48, 44, 48,
  44, 53, 55, 44, 49, 44, 49, 44, 49, 44, 49, 32, 45, 101, 120, 112,
  97, 110, 100, 95, 120, 121, 32, 49, 48, 44, 48, 32, 45, 98, 108, 117,
  114, 32, 50, 32, 45, 110, 32, 48, 44, 49, 48, 48, 32, 45, 45, 112,
  108, 97, 115, 109, 97, 32, 48, 46, 52, 32, 45, 43, 32, 92, 92, 10,
  92, 110, 32, 32, 32, 32, 32, 32, 45, 98, 108, 117, 114, 32, 49, 32,
  45, 101, 108, 101, 118, 97, 116, 105, 111, 110, 51, 100, 32, 45, 48, 46,
  49, 32, 45, 109, 100, 51, 100, 32, 52, 10, 92, 110, 10, 92, 110, 32,
  32, 45, 32, 71, 101, 110, 101, 114, 97, 116, 101, 32, 97, 32, 51, 100,
  32, 114, 105, 110, 103, 32, 111, 102, 32, 116, 111, 114, 105, 105, 58, 10,
  92, 110, 32, 32, 32, 32, 32, 103, 109, 105, 99, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 50, 48, 32, 45, 116, 111, 114, 117, 115, 51, 100, 32,
  49, 53, 44, 50, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32,
  92, 34, 123, 63, 40, 54, 48, 44, 50, 53, 53, 41, 125, 44, 123, 63,
  40, 54, 48, 44, 50, 53, 53, 41, 125, 44, 123, 63, 40, 54, 48, 44,
  50, 53, 53, 41, 125, 92, 34, 32, 92, 92, 10, 92, 110, 32, 32, 32,
  32, 32, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 48, 46, 53, 44,
  49, 32, 45, 105, 102, 32, 92, 34, 123, 36, 62, 37, 50, 125, 92, 34,
  32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 49, 44, 48, 44,
  57, 48, 32, 45, 101, 110, 100, 105, 102, 32, 45, 43, 51, 100, 91, 45,
  49, 93, 32, 55, 48, 32, 45, 43, 51, 100, 32, 92, 92, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 45, 114, 51, 100, 32, 48, 44, 48, 44, 49,
  44, 49, 56, 32, 45, 100, 111, 110, 101, 32, 45, 109, 100, 51, 100, 32,
  51, 32, 45, 109, 51, 100, 32, 53, 32, 45, 100, 98, 51, 100, 32, 48,
  10, 92, 110, 10, 92, 110, 32, 32, 45, 32, 67, 114, 101, 97, 116, 101,
  32, 97, 32, 118, 97, 115, 101, 32, 102, 114, 111, 109, 32, 97, 32, 51,
  100, 32, 105, 115, 111, 115, 117, 114, 102, 97, 99, 101, 58, 10, 92, 110,
  32, 32, 32, 32, 32, 103, 109, 105, 99, 32, 45, 109, 100, 51, 100, 32,
  52, 32, 45, 105, 115, 111, 115, 117, 114, 102, 97, 99, 101, 51, 100, 32,
  92, 34, 39, 120, 94, 50, 43, 50, 42, 97, 98, 115, 40, 121, 47, 50,
  41, 42, 115, 105, 110, 40, 50, 42, 121, 41, 94, 50, 43, 122, 94, 50,
  45, 51, 39, 44, 48, 92, 34, 32, 45, 115, 112, 104, 101, 114, 101, 51,
  100, 32, 49, 46, 53, 32, 92, 92, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 45, 45, 51, 100, 91, 45, 49, 93, 32, 48, 44, 53, 32, 45, 112,
  108, 97, 110, 101, 51, 100, 32, 49, 53, 44, 49, 53, 32, 45, 114, 51,
  100, 91, 45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 57, 48, 32, 45,
  99, 51, 100, 91, 45, 49, 93, 32, 45, 43, 51, 100, 91, 45, 49, 93,
  32, 48, 44, 51, 46, 50, 32, 92, 92, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 49, 56, 48,
  44, 49, 53, 48, 44, 50, 53, 53, 32, 45, 99, 111, 108, 51, 100, 91,
  45, 50, 93, 32, 49, 50, 56, 44, 50, 53, 53, 44, 48, 32, 45, 99,
  111, 108, 51, 100, 91, 45, 51, 93, 32, 50, 53, 53, 44, 49, 50, 56,
  44, 48, 32, 45, 43, 51, 100, 10, 92, 110, 10, 92, 110, 32, 32, 45,
  32, 68, 105, 115, 112, 108, 97, 121, 32, 102, 105, 108, 116, 101, 114, 101,
  100, 32, 119, 101, 98, 99, 97, 109, 32, 115, 116, 114, 101, 97, 109, 58,
  10, 92, 110, 32, 32, 32, 32, 32, 103, 109, 105, 99, 32, 45, 97, 112,
  112, 108, 121, 95, 99, 97, 109, 101, 114, 97, 32, 92, 92, 92, 34, 45,
  45, 109, 105, 114, 114, 111, 114, 32, 120, 32, 45, 45, 109, 105, 114, 114,
  111, 114, 32, 121, 32, 45, 43, 32, 45, 47, 32, 52, 92, 92, 92, 34,
  10, 92, 110, 10, 92, 110, 32, 32, 45, 32, 76, 97, 117, 110, 99, 104,
  32, 97, 32, 115, 101, 116, 32, 111, 102, 32, 71, 39, 77, 73, 67, 32,
  105, 110, 116, 101, 114, 97, 99, 116, 105, 118, 101, 32, 100, 101, 109, 111,
  115, 58, 10, 92, 110, 32, 32, 32, 32, 32, 103, 109, 105, 99, 32, 45,
  100, 101, 109, 111, 10, 92, 110, 34, 10, 35, 64, 103, 109, 105, 99, 32,
  118, 101, 114, 115, 105, 111, 110, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 105, 115, 112, 108, 97, 121, 32, 99, 117, 114, 114, 101, 110, 116,
  32, 118, 101, 114, 115, 105, 111, 110, 32, 110, 117, 109, 98, 101, 114, 32,
  97, 110, 100, 32, 101, 120, 105, 116, 46, 10, 118, 101, 114, 115, 105, 111,
  110, 32, 58, 10, 45, 118, 32, 45, 32, 45, 95, 95, 104, 101, 108, 112,
  95, 104, 101, 97, 100, 101, 114, 95, 97, 115, 99, 105, 105, 91, 93, 32,
  45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 34, 34, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 58, 32, 73, 110, 112, 117, 116, 115, 47, 111, 117,
  116, 112, 117, 116, 115, 10, 35, 64, 103, 109, 105, 99, 32, 97, 112, 112,
  108, 121, 95, 99, 97, 109, 101, 114, 97, 32, 58, 32, 95, 99, 111, 109,
  109, 97, 110, 100, 44, 95, 99, 97, 109, 101, 114, 97, 95, 105, 110, 100,
  101, 120, 62, 61, 48, 44, 95, 115, 107, 105, 112, 95, 102, 114, 97, 109,
  101, 115, 62, 61, 48, 44, 95, 111, 117, 116, 112, 117, 116, 95, 102, 105,
  108, 101, 110, 97, 109, 101, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  65, 112, 112, 108, 121, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  99, 111, 109, 109, 97, 110, 100, 32, 111, 110, 32, 108, 105, 118, 101, 32,
  99, 97, 109, 101, 114, 97, 32, 115, 116, 114, 101, 97, 109, 44, 32, 97,
  110, 100, 32, 100, 105, 115, 112, 108, 97, 121, 32, 105, 116, 32, 111, 110,
  32, 100, 105, 115, 112, 108, 97, 121, 32, 119, 105, 110, 100, 111, 119, 32,
  91, 48, 93, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101,
  102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 99,
  111, 109, 109, 97, 110, 100, 61, 34, 34, 39, 44, 32, 39, 99, 97, 109,
  101, 114, 97, 95, 105, 110, 100, 101, 120, 61, 48, 39, 32, 40, 100, 101,
  102, 97, 117, 108, 116, 32, 99, 97, 109, 101, 114, 97, 41, 44, 32, 39,
  115, 107, 105, 112, 95, 102, 114, 97, 109, 101, 115, 61, 48, 39, 32, 97,
  110, 100, 32, 39, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 34, 39,
  46, 10, 97, 112, 112, 108, 121, 95, 99, 97, 109, 101, 114, 97, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 34, 36, 123, 49, 61, 125, 44, 36, 123,
  52, 61, 125, 34, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 50,
  61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 51, 61, 48, 125,
  62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112,
  112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 49, 39,
  32, 111, 110, 32, 99, 97, 109, 101, 114, 97, 32, 115, 116, 114, 101, 97,
  109, 32, 92, 35, 36, 50, 44, 32, 119, 105, 116, 104, 32, 36, 51, 32,
  102, 114, 97, 109, 101, 115, 32, 115, 107, 105, 112, 32, 97, 110, 100, 32,
  102, 105, 108, 101, 110, 97, 109, 101, 32, 39, 36, 52, 39, 46, 34, 32,
  45, 118, 32, 45, 10, 45, 108, 91, 93, 32, 102, 114, 97, 109, 101, 61,
  48, 32, 45, 100, 111, 10, 45, 99, 97, 109, 101, 114, 97, 32, 36, 50,
  44, 49, 44, 36, 51, 32, 36, 49, 32, 45, 119, 91, 45, 49, 93, 32,
  45, 49, 44, 45, 49, 44, 34, 40, 67, 97, 109, 101, 114, 97, 32, 34,
  36, 115, 116, 114, 101, 97, 109, 34, 44, 32, 34, 123, 119, 125, 120, 123,
  104, 125, 34, 41, 34, 10, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40,
  34, 36, 52, 34, 41, 125, 32, 45, 111, 91, 45, 49, 93, 32, 64, 123,
  45, 102, 105, 108, 101, 110, 97, 109, 101, 92, 32, 34, 36, 52, 34, 44,
  36, 102, 114, 97, 109, 101, 125, 32, 102, 114, 97, 109, 101, 61, 123, 36,
  102, 114, 97, 109, 101, 43, 49, 125, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 64, 123, 33, 44, 83, 125, 32, 45, 111, 91, 45, 49,
  93, 32, 103, 109, 105, 99, 95, 99, 97, 109, 101, 114, 97, 46, 112, 110,
  103, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 40, 64,
  123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 34, 32, 124, 124,
  32, 34, 64, 123, 33, 44, 67, 84, 82, 76, 82, 73, 71, 72, 84, 125,
  41, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 68, 125, 125, 32, 45,
  119, 91, 93, 32, 123, 64, 123, 33, 44, 119, 125, 42, 49, 46, 53, 125,
  44, 123, 64, 123, 33, 44, 104, 125, 42, 49, 46, 53, 125, 32, 45, 119,
  97, 105, 116, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 40, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84,
  125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 44, 67, 84, 82, 76, 82,
  73, 71, 72, 84, 125, 41, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44,
  67, 125, 125, 32, 45, 119, 91, 93, 32, 123, 64, 123, 33, 44, 119, 125,
  47, 49, 46, 53, 125, 44, 123, 64, 123, 33, 44, 104, 125, 47, 49, 46,
  53, 125, 32, 45, 119, 97, 105, 116, 32, 45, 49, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 40, 64, 123, 33, 44, 67, 84, 82,
  76, 76, 69, 70, 84, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 44,
  67, 84, 82, 76, 82, 73, 71, 72, 84, 125, 41, 34, 32, 38, 38, 32,
  34, 64, 123, 33, 44, 82, 125, 125, 32, 45, 119, 91, 93, 32, 64, 123,
  48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125, 32, 45, 119, 97, 105,
  116, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34, 32,
  38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67, 125, 34, 32, 38,
  38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125, 32, 45, 101, 110, 100,
  108, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 97, 112,
  112, 108, 121, 95, 102, 105, 108, 101, 115, 32, 58, 32, 34, 99, 111, 109,
  109, 97, 110, 100, 34, 44, 108, 105, 115, 116, 95, 111, 102, 95, 102, 105,
  108, 101, 110, 97, 109, 101, 115, 44, 95, 111, 117, 116, 112, 117, 116, 95,
  112, 114, 101, 102, 105, 120, 44, 95, 118, 105, 101, 119, 95, 119, 105, 110,
  100, 111, 119, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 115, 112, 101,
  99, 105, 102, 105, 101, 100, 32, 99, 111, 109, 109, 97, 110, 100, 32, 111,
  110, 32, 97, 108, 108, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  105, 109, 97, 103, 101, 32, 102, 105, 108, 101, 115, 44, 32, 98, 121, 32,
  114, 101, 97, 100, 105, 110, 103, 32, 116, 104, 101, 109, 32, 111, 110, 101,
  32, 98, 121, 32, 111, 110, 101, 44, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 97, 110, 100, 32, 115, 97, 118, 101, 32, 114, 101, 115, 117, 108,
  116, 32, 98, 121, 32, 97, 112, 112, 101, 110, 100, 105, 110, 103, 32, 39,
  111, 117, 116, 112, 117, 116, 95, 112, 114, 101, 102, 105, 120, 39, 32, 116,
  111, 32, 101, 97, 99, 104, 32, 111, 114, 105, 103, 105, 110, 97, 108, 32,
  102, 105, 108, 101, 110, 97, 109, 101, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 39, 108, 105, 115, 116, 95, 111, 102, 95, 102, 105, 108, 101,
  110, 97, 109, 101, 115, 39, 32, 109, 117, 115, 116, 32, 98, 101, 32, 116,
  104, 101, 32, 108, 105, 115, 116, 32, 111, 102, 32, 102, 105, 108, 101, 110,
  97, 109, 101, 115, 44, 32, 115, 101, 112, 97, 114, 97, 116, 101, 100, 32,
  98, 121, 32, 115, 112, 97, 99, 101, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 84, 104, 117, 115, 44, 32, 97, 32, 115, 112, 101, 99, 105,
  102, 105, 101, 100, 32, 102, 105, 108, 101, 110, 97, 109, 101, 32, 99, 97,
  110, 110, 111, 116, 32, 99, 111, 110, 116, 97, 105, 110, 32, 97, 32, 115,
  112, 97, 99, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39,
  111, 117, 116, 112, 117, 116, 95, 112, 114, 101, 102, 105, 120, 61, 103, 109,
  105, 99, 95, 39, 32, 97, 110, 100, 32, 39, 118, 105, 101, 119, 95, 119,
  105, 110, 100, 111, 119, 61, 48, 39, 46, 10, 97, 112, 112, 108, 121, 95,
  102, 105, 108, 101, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36,
  123, 51, 61, 103, 109, 105, 99, 95, 125, 34, 44, 36, 123, 52, 61, 48,
  125, 10, 45, 118, 32, 45, 10, 40, 123, 39, 34, 36, 50, 34, 39, 125,
  41, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32,
  51, 50, 32, 45, 114, 101, 112, 108, 97, 99, 101, 91, 45, 49, 93, 32,
  51, 50, 44, 123, 39, 44, 39, 125, 32, 102, 105, 108, 101, 115, 61, 64,
  123, 45, 49, 44, 116, 125, 10, 45, 105, 102, 32, 123, 119, 62, 49, 50,
  56, 125, 32, 45, 122, 91, 45, 49, 93, 32, 48, 44, 49, 50, 55, 32,
  115, 95, 102, 105, 108, 101, 115, 61, 64, 123, 45, 49, 44, 116, 125, 46,
  46, 46, 32, 45, 101, 108, 115, 101, 32, 115, 95, 102, 105, 108, 101, 115,
  61, 36, 102, 105, 108, 101, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 109, 32, 34, 95, 97, 112, 112, 108,
  121, 95, 102, 105, 108, 101, 115, 32, 58, 32, 36, 34, 34, 61, 95, 102,
  105, 108, 101, 32, 95, 110, 98, 95, 102, 105, 108, 101, 115, 61, 36, 34,
  34, 35, 34, 32, 45, 95, 97, 112, 112, 108, 121, 95, 102, 105, 108, 101,
  115, 32, 36, 102, 105, 108, 101, 115, 32, 45, 117, 110, 99, 111, 109, 109,
  97, 110, 100, 32, 95, 97, 112, 112, 108, 121, 95, 102, 105, 108, 101, 115,
  10, 45, 109, 32, 34, 95, 97, 112, 112, 108, 121, 95, 102, 105, 108, 101,
  115, 32, 58, 32, 36, 49, 34, 10, 45, 118, 32, 43, 32, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109,
  97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110, 32, 102, 105, 108, 101,
  115, 32, 39, 34, 36, 115, 95, 102, 105, 108, 101, 115, 34, 39, 32, 97,
  110, 100, 32, 115, 97, 118, 101, 32, 114, 101, 115, 117, 108, 116, 32, 119,
  105, 116, 104, 32, 112, 114, 101, 102, 105, 120, 32, 39, 36, 51, 39, 46,
  92, 110, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 36, 95, 110, 98, 95, 102, 105, 108, 101, 115, 32, 45, 108, 91, 93,
  10, 102, 105, 108, 101, 61, 36, 123, 95, 102, 105, 108, 101, 123, 36, 62,
  43, 49, 125, 125, 10, 95, 102, 105, 108, 101, 61, 64, 123, 45, 98, 97,
  115, 101, 110, 97, 109, 101, 92, 32, 36, 102, 105, 108, 101, 125, 10, 45,
  118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 114, 32, 45, 32, 73,
  109, 97, 103, 101, 32, 34, 123, 49, 43, 36, 62, 125, 47, 36, 95, 110,
  98, 95, 102, 105, 108, 101, 115, 34, 32, 91, 34, 36, 95, 102, 105, 108,
  101, 34, 93, 32, 32, 32, 32, 32, 32, 32, 32, 34, 32, 45, 118, 32,
  45, 10, 36, 102, 105, 108, 101, 32, 45, 95, 97, 112, 112, 108, 121, 95,
  102, 105, 108, 101, 115, 10, 45, 111, 32, 34, 36, 51, 34, 36, 95, 102,
  105, 108, 101, 10, 45, 105, 102, 32, 36, 52, 32, 45, 119, 91, 45, 49,
  93, 32, 64, 123, 45, 102, 105, 116, 115, 99, 114, 101, 101, 110, 92, 32,
  123, 119, 125, 44, 123, 104, 125, 44, 123, 100, 125, 125, 44, 49, 44, 48,
  44, 45, 49, 44, 45, 49, 44, 36, 95, 102, 105, 108, 101, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 109, 10, 45, 111, 110, 102, 97, 105, 108,
  32, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 110, 32, 45,
  32, 69, 114, 114, 111, 114, 32, 111, 99, 99, 117, 114, 101, 100, 32, 111,
  110, 32, 102, 105, 108, 101, 32, 39, 34, 36, 102, 105, 108, 101, 34, 39,
  46, 92, 110, 34, 32, 45, 118, 32, 45, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 117, 110, 99, 111, 109, 109, 97, 110, 100,
  32, 95, 97, 112, 112, 108, 121, 95, 102, 105, 108, 101, 115, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 99, 97, 109, 101, 114, 97,
  32, 58, 32, 95, 99, 97, 109, 101, 114, 97, 95, 105, 110, 100, 101, 120,
  62, 61, 48, 44, 95, 110, 98, 95, 102, 114, 97, 109, 101, 115, 62, 48,
  44, 95, 115, 107, 105, 112, 95, 102, 114, 97, 109, 101, 115, 62, 61, 48,
  44, 114, 101, 108, 101, 97, 115, 101, 95, 99, 97, 109, 101, 114, 97, 61,
  123, 32, 48, 32, 124, 32, 49, 32, 125, 44, 95, 99, 97, 112, 116, 117,
  114, 101, 95, 119, 105, 100, 116, 104, 62, 61, 48, 44, 95, 99, 97, 112,
  116, 117, 114, 101, 95, 104, 101, 105, 103, 104, 116, 62, 61, 48, 32, 58,
  32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 110,
  115, 101, 114, 116, 32, 111, 110, 101, 32, 111, 114, 32, 115, 101, 118, 101,
  114, 97, 108, 32, 102, 114, 97, 109, 101, 115, 32, 102, 114, 111, 109, 32,
  115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 99, 97, 109, 101, 114, 97,
  44, 32, 119, 105, 116, 104, 32, 99, 117, 115, 116, 111, 109, 32, 100, 101,
  108, 97, 121, 32, 98, 101, 116, 119, 101, 101, 110, 32, 102, 114, 97, 109,
  101, 115, 32, 40, 105, 110, 32, 109, 115, 41, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 87, 104, 101, 110, 32, 39, 114, 101, 108, 101, 97,
  115, 101, 95, 99, 97, 109, 101, 114, 97, 61, 61, 49, 39, 44, 32, 116,
  104, 101, 32, 99, 97, 109, 101, 114, 97, 32, 115, 116, 114, 101, 97, 109,
  32, 105, 115, 32, 114, 101, 108, 101, 97, 115, 101, 100, 32, 105, 110, 115,
  116, 101, 97, 100, 32, 111, 102, 32, 99, 97, 112, 116, 117, 114, 105, 110,
  103, 32, 110, 101, 119, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 99, 97, 109, 101, 114, 97, 95, 105,
  110, 100, 101, 120, 61, 48, 39, 32, 40, 100, 101, 102, 97, 117, 108, 116,
  32, 99, 97, 109, 101, 114, 97, 41, 44, 32, 39, 110, 98, 95, 102, 114,
  97, 109, 101, 115, 61, 49, 39, 44, 32, 39, 115, 107, 105, 112, 95, 102,
  114, 97, 109, 101, 115, 61, 48, 39, 44, 32, 39, 114, 101, 108, 101, 97,
  115, 101, 95, 99, 97, 109, 101, 114, 97, 61, 48, 39, 32, 97, 110, 100,
  32, 39, 99, 97, 112, 116, 117, 114, 101, 95, 119, 105, 100, 116, 104, 61,
  99, 97, 112, 116, 117, 114, 101, 95, 104, 101, 105, 103, 104, 116, 61, 48,
  39, 32, 40, 100, 101, 102, 97, 117, 108, 116, 32, 115, 105, 122, 101, 41,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 109, 32, 58, 32, 101, 113, 46,
  32, 116, 111, 32, 39, 45, 99, 111, 109, 109, 97, 110, 100, 39, 46, 32,
  58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 99, 111, 109,
  109, 97, 110, 100, 32, 58, 32, 95, 97, 100, 100, 95, 100, 101, 98, 117,
  103, 95, 105, 110, 102, 111, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125,
  44, 123, 32, 102, 105, 108, 101, 110, 97, 109, 101, 32, 124, 32, 104, 116,
  116, 112, 91, 115, 93, 58, 47, 47, 85, 82, 76, 32, 124, 32, 34, 115,
  116, 114, 105, 110, 103, 34, 32, 125, 32, 58, 32, 40, 42, 41, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 73, 109, 112, 111, 114, 116, 32, 71,
  39, 77, 73, 67, 32, 99, 117, 115, 116, 111, 109, 32, 99, 111, 109, 109,
  97, 110, 100, 115, 32, 102, 114, 111, 109, 32, 115, 112, 101, 99, 105, 102,
  105, 101, 100, 32, 102, 105, 108, 101, 44, 32, 85, 82, 76, 32, 111, 114,
  32, 115, 116, 114, 105, 110, 103, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 109, 39, 41, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 109, 112, 111, 114, 116,
  101, 100, 32, 99, 111, 109, 109, 97, 110, 100, 115, 32, 97, 114, 101, 32,
  97, 118, 97, 105, 108, 97, 98, 108, 101, 32, 100, 105, 114, 101, 99, 116,
  108, 121, 32, 97, 102, 116, 101, 114, 32, 116, 104, 101, 32, 39, 45, 99,
  111, 109, 109, 97, 110, 100, 39, 32, 105, 110, 118, 111, 99, 97, 116, 105,
  111, 110, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 97, 100, 100,
  95, 100, 101, 98, 117, 103, 95, 105, 110, 102, 111, 61, 49, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 99, 111, 109, 109, 97, 110, 100, 32, 34, 102,
  111, 111, 32, 58, 32, 45, 109, 105, 114, 114, 111, 114, 32, 121, 32, 45,
  100, 101, 102, 111, 114, 109, 32, 36, 34, 34, 49, 34, 32, 45, 45, 102,
  111, 111, 91, 48, 93, 32, 53, 32, 45, 45, 102, 111, 111, 91, 48, 93,
  32, 49, 53, 10, 35, 64, 103, 109, 105, 99, 32, 99, 117, 112, 105, 100,
  32, 58, 32, 95, 115, 105, 122, 101, 62, 48, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 73, 110, 112, 117, 116, 32, 99, 117, 112, 105, 100, 32,
  98, 105, 110, 97, 114, 121, 32, 109, 97, 115, 107, 32, 119, 105, 116, 104,
  32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 115, 105, 122, 101, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 99, 117, 112,
  105, 100, 32, 44, 10, 99, 117, 112, 105, 100, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 36, 123, 49, 61, 52, 56, 48, 125, 62, 61, 49,
  34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116,
  32, 36, 49, 120, 36, 49, 32, 99, 117, 112, 105, 100, 32, 98, 105, 110,
  97, 114, 121, 32, 109, 97, 115, 107, 46, 34, 32, 45, 118, 32, 45, 10,
  45, 108, 91, 93, 10, 40, 52, 56, 48, 44, 52, 56, 48, 44, 49, 44,
  49, 44, 48, 44, 45, 52, 54, 52, 48, 44, 45, 56, 44, 49, 44, 45,
  55, 44, 45, 57, 44, 49, 44, 45, 52, 53, 53, 44, 45, 49, 49, 44,
  49, 44, 45, 51, 44, 45, 49, 50, 44, 49, 44, 45, 52, 53, 51, 44,
  45, 49, 51, 44, 49, 44, 48, 44, 45, 49, 52, 44, 49, 44, 45, 52,
  53, 50, 44, 45, 50, 56, 44, 49, 44, 45, 52, 53, 50, 44, 45, 50,
  57, 44, 49, 44, 45, 52, 53, 48, 44, 45, 51, 48, 44, 49, 44, 45,
  52, 53, 48, 44, 45, 51, 48, 44, 49, 44, 45, 52, 53, 48, 44, 45,
  51, 48, 44, 49, 44, 45, 52, 53, 48, 44, 45, 51, 48, 44, 49, 44,
  45, 52, 53, 48, 44, 45, 51, 48, 44, 49, 44, 45, 52, 53, 48, 44,
  45, 51, 48, 44, 49, 44, 45, 52, 53, 48, 44, 45, 51, 48, 44, 49,
  44, 45, 52, 53, 49, 44, 45, 50, 57, 44, 49, 44, 45, 52, 53, 49,
  44, 45, 50, 56, 44, 49, 44, 45, 52, 53, 50, 44, 45, 50, 56, 44,
  49, 44, 45, 52, 53, 51, 44, 45, 50, 54, 44, 49, 44, 45, 52, 53,
  52, 44, 45, 50, 54, 44, 49, 44, 45, 52, 53, 53, 44, 45, 50, 52,
  44, 49, 44, 45, 52, 53, 54, 44, 45, 50, 52, 44, 49, 44, 45, 52,
  53, 55, 44, 45, 50, 50, 44, 49, 44, 45, 52, 53, 57, 44, 45, 50,
  48, 44, 49, 44, 45, 52, 54, 49, 44, 45, 49, 56, 44, 49, 44, 45,
  52, 54, 50, 44, 45, 49, 55, 44, 49, 44, 45, 52, 54, 52, 44, 45,
  49, 53, 44, 49, 44, 45, 52, 54, 54, 44, 45, 49, 51, 44, 49, 44,
  45, 52, 54, 57, 44, 45, 49, 48, 44, 49, 44, 45, 52, 55, 49, 44,
  45, 56, 44, 49, 44, 45, 52, 55, 51, 44, 45, 54, 44, 49, 44, 45,
  52, 55, 54, 44, 45, 50, 44, 49, 44, 45, 49, 48, 49, 50, 54, 44,
  45, 51, 44, 49, 44, 45, 49, 55, 44, 45, 49, 49, 44, 49, 44, 45,
  52, 52, 53, 44, 45, 49, 49, 44, 49, 44, 45, 49, 49, 44, 45, 49,
  53, 44, 49, 44, 45, 51, 48, 53, 44, 45, 53, 44, 49, 44, 45, 49,
  51, 49, 44, 45, 49, 53, 44, 49, 44, 45, 56, 44, 45, 49, 55, 44,
  49, 44, 45, 51, 48, 51, 44, 45, 57, 44, 49, 44, 45, 49, 53, 44,
  45, 50, 44, 49, 44, 45, 49, 49, 48, 44, 45, 49, 55, 44, 49, 44,
  45, 54, 44, 45, 49, 57, 44, 49, 44, 45, 51, 48, 50, 44, 45, 49,
  49, 44, 49, 44, 45, 49, 50, 44, 45, 52, 44, 49, 44, 45, 49, 48,
  56, 44, 45, 50, 48, 44, 49, 44, 45, 50, 44, 45, 50, 50, 44, 49,
  44, 45, 51, 48, 50, 44, 45, 49, 50, 44, 49, 44, 45, 57, 44, 45,
  53, 44, 49, 44, 45, 49, 52, 44, 45, 50, 44, 49, 44, 45, 57, 50,
  44, 45, 52, 52, 44, 49, 44, 45, 51, 48, 50, 44, 45, 49, 51, 44,
  49, 44, 45, 56, 44, 45, 53, 44, 49, 44, 45, 49, 51, 44, 45, 52,
  44, 49, 44, 45, 57, 48, 44, 45, 52, 54, 44, 49, 44, 45, 51, 48,
  50, 44, 45, 49, 51, 44, 49, 44, 45, 53, 44, 45, 55, 44, 49, 44,
  45, 49, 51, 44, 45, 52, 44, 49, 44, 45, 57, 48, 44, 45, 52, 54,
  44, 49, 44, 45, 51, 48, 50, 44, 45, 49, 52, 44, 49, 44, 45, 51,
  44, 45, 56, 44, 49, 44, 45, 49, 51, 44, 45, 53, 44, 49, 44, 45,
  56, 57, 44, 45, 52, 54, 44, 49, 44, 45, 51, 48, 50, 44, 45, 50,
  53, 44, 49, 44, 45, 49, 51, 44, 45, 55, 44, 49, 44, 45, 56, 54,
  44, 45, 52, 56, 44, 49, 44, 45, 51, 48, 50, 44, 45, 50, 52, 44,
  49, 44, 45, 49, 51, 44, 45, 57, 44, 49, 44, 48, 44, 45, 53, 44,
  49, 44, 45, 55, 56, 44, 45, 52, 56, 44, 49, 44, 45, 51, 48, 50,
  44, 45, 50, 53, 44, 49, 44, 45, 49, 50, 44, 45, 49, 53, 44, 49,
  44, 45, 55, 56, 44, 45, 52, 56, 44, 49, 44, 45, 50, 57, 48, 44,
  45, 50, 44, 49, 44, 45, 49, 48, 44, 45, 50, 53, 44, 49, 44, 45,
  49, 50, 44, 45, 49, 53, 44, 49, 44, 45, 55, 56, 44, 45, 52, 56,
  44, 49, 44, 45, 50, 56, 54, 44, 45, 49, 49, 44, 49, 44, 45, 52,
  44, 45, 51, 51, 44, 49, 44, 45, 52, 44, 45, 49, 54, 44, 49, 44,
  45, 55, 56, 44, 45, 52, 56, 44, 49, 44, 45, 50, 56, 52, 44, 45,
  53, 50, 44, 49, 44, 45, 50, 44, 45, 49, 54, 44, 49, 44, 45, 55,
  56, 44, 45, 52, 56, 44, 49, 44, 45, 50, 56, 50, 44, 45, 55, 50,
  44, 49, 44, 45, 55, 56, 44, 45, 52, 56, 44, 49, 44, 45, 50, 56,
  49, 44, 45, 55, 51, 44, 49, 44, 45, 55, 56, 44, 45, 52, 56, 44,
  49, 44, 45, 50, 56, 48, 44, 45, 55, 52, 44, 49, 44, 45, 55, 56,
  44, 45, 52, 56, 44, 49, 44, 45, 50, 55, 57, 44, 45, 55, 53, 44,
  49, 44, 45, 55, 56, 44, 45, 52, 55, 44, 49, 44, 45, 50, 55, 57,
  44, 45, 55, 55, 44, 49, 44, 45, 55, 55, 44, 45, 52, 55, 44, 49,
  44, 45, 50, 55, 56, 44, 45, 55, 56, 44, 49, 44, 45, 55, 56, 44,
  45, 52, 54, 44, 49, 44, 45, 50, 55, 55, 44, 45, 55, 57, 44, 49,
  44, 45, 55, 56, 44, 45, 52, 53, 44, 49, 44, 45, 50, 55, 55, 44,
  45, 56, 49, 44, 49, 44, 45, 55, 55, 44, 45, 52, 53, 44, 49, 44,
  45, 50, 55, 54, 44, 45, 56, 50, 44, 49, 44, 45, 55, 56, 44, 45,
  52, 52, 44, 49, 44, 45, 50, 55, 53, 44, 45, 56, 52, 44, 49, 44,
  45, 55, 55, 44, 45, 52, 51, 44, 49, 44, 45, 50, 55, 52, 44, 45,
  56, 55, 44, 49, 44, 45, 55, 55, 44, 45, 52, 50, 44, 49, 44, 45,
  50, 55, 50, 44, 45, 57, 48, 44, 49, 44, 45, 55, 54, 44, 45, 52,
  49, 44, 49, 44, 45, 50, 55, 49, 44, 45, 57, 50, 44, 49, 44, 45,
  55, 54, 44, 45, 52, 48, 44, 49, 44, 45, 50, 55, 49, 44, 45, 57,
  52, 44, 49, 44, 45, 55, 54, 44, 45, 51, 57, 44, 49, 44, 45, 50,
  55, 48, 44, 45, 57, 53, 44, 49, 44, 45, 55, 55, 44, 45, 51, 55,
  44, 49, 44, 45, 50, 55, 48, 44, 45, 49, 48, 55, 44, 49, 44, 45,
  54, 54, 44, 45, 51, 55, 44, 49, 44, 45, 50, 54, 57, 44, 45, 49,
  49, 48, 44, 49, 44, 45, 54, 53, 44, 45, 51, 53, 44, 49, 44, 45,
  50, 54, 57, 44, 45, 49, 49, 49, 44, 49, 44, 45, 54, 54, 44, 45,
  51, 51, 44, 49, 44, 45, 50, 54, 56, 44, 45, 49, 49, 53, 44, 49,
  44, 45, 54, 53, 44, 45, 51, 49, 44, 49, 44, 45, 50, 54, 55, 44,
  45, 49, 49, 55, 44, 49, 44, 45, 54, 53, 44, 45, 51, 48, 44, 49,
  44, 45, 50, 54, 54, 44, 45, 49, 50, 48, 44, 49, 44, 45, 54, 53,
  44, 45, 50, 57, 44, 49, 44, 45, 50, 54, 54, 44, 45, 49, 50, 48,
  44, 49, 44, 45, 54, 54, 44, 45, 50, 55, 44, 49, 44, 45, 50, 54,
  54, 44, 45, 49, 50, 49, 44, 49, 44, 45, 54, 55, 44, 45, 50, 53,
  44, 49, 44, 45, 50, 54, 54, 44, 45, 49, 50, 49, 44, 49, 44, 45,
  54, 57, 44, 45, 50, 51, 44, 49, 44, 45, 50, 54, 55, 44, 45, 49,
  49, 50, 44, 49, 44, 45, 55, 57, 44, 45, 50, 49, 44, 49, 44, 45,
  50, 54, 55, 44, 45, 49, 49, 50, 44, 49, 44, 45, 56, 49, 44, 45,
  49, 57, 44, 49, 44, 45, 49, 54, 56, 44, 45, 54, 44, 49, 44, 45,
  57, 52, 44, 45, 49, 49, 49, 44, 49, 44, 45, 56, 52, 44, 45, 49,
  54, 44, 49, 44, 45, 49, 54, 57, 44, 45, 55, 44, 49, 44, 45, 57,
  51, 44, 45, 49, 49, 48, 44, 49, 44, 45, 56, 54, 44, 45, 49, 51,
  44, 49, 44, 45, 49, 55, 48, 44, 45, 57, 44, 49, 44, 45, 57, 50,
  44, 45, 49, 48, 57, 44, 49, 44, 45, 56, 56, 44, 45, 49, 49, 44,
  49, 44, 45, 49, 55, 49, 44, 45, 49, 49, 44, 49, 44, 45, 57, 48,
  44, 45, 49, 48, 57, 44, 49, 44, 45, 56, 57, 44, 45, 57, 44, 49,
  44, 45, 49, 55, 50, 44, 45, 49, 50, 44, 49, 44, 45, 56, 57, 44,
  45, 49, 48, 57, 44, 49, 44, 45, 57, 49, 44, 45, 54, 44, 49, 44,
  45, 49, 55, 51, 44, 45, 49, 51, 44, 49, 44, 45, 56, 56, 44, 45,
  49, 48, 57, 44, 49, 44, 45, 50, 55, 48, 44, 45, 49, 52, 44, 49,
  44, 45, 56, 55, 44, 45, 49, 48, 57, 44, 49, 44, 45, 50, 55, 48,
  44, 45, 49, 53, 44, 49, 44, 45, 56, 54, 44, 45, 49, 49, 48, 44,
  49, 44, 45, 50, 54, 57, 44, 45, 49, 54, 44, 49, 44, 45, 56, 53,
  44, 45, 49, 49, 48, 44, 49, 44, 45, 50, 54, 57, 44, 45, 49, 55,
  44, 49, 44, 45, 56, 52, 44, 45, 49, 49, 48, 44, 49, 44, 45, 50,
  54, 57, 44, 45, 49, 56, 44, 49, 44, 45, 56, 51, 44, 45, 49, 49,
  49, 44, 49, 44, 45, 50, 54, 57, 44, 45, 49, 56, 44, 49, 44, 45,
  56, 50, 44, 45, 49, 49, 49, 44, 49, 44, 45, 50, 54, 57, 44, 45,
  50, 48, 44, 49, 44, 45, 56, 48, 44, 45, 49, 49, 50, 44, 49, 44,
  45, 50, 54, 57, 44, 45, 50, 48, 44, 49, 44, 45, 55, 57, 44, 45,
  49, 49, 50, 44, 49, 44, 45, 50, 54, 57, 44, 45, 50, 49, 44, 49,
  44, 45, 55, 56, 44, 45, 49, 49, 50, 44, 49, 44, 45, 50, 55, 48,
  44, 45, 50, 50, 44, 49, 44, 45, 55, 54, 44, 45, 49, 49, 51, 44,
  49, 44, 45, 50, 54, 57, 44, 45, 50, 51, 44, 49, 44, 45, 55, 53,
  44, 45, 49, 49, 51, 44, 49, 44, 45, 50, 55, 48, 44, 45, 50, 51,
  44, 49, 44, 45, 55, 52, 44, 45, 49, 49, 51, 44, 49, 44, 45, 50,
  55, 49, 44, 45, 50, 51, 44, 49, 44, 45, 55, 51, 44, 45, 49, 49,
  51, 44, 49, 44, 45, 50, 55, 49, 44, 45, 50, 53, 44, 49, 44, 45,
  55, 48, 44, 45, 49, 49, 52, 44, 49, 44, 45, 50, 55, 50, 44, 45,
  50, 54, 44, 49, 44, 45, 54, 55, 44, 45, 49, 49, 53, 44, 49, 44,
  45, 50, 55, 50, 44, 45, 50, 56, 44, 49, 44, 45, 54, 53, 44, 45,
  49, 49, 53, 44, 49, 44, 45, 50, 55, 51, 44, 45, 50, 57, 44, 49,
  44, 45, 54, 50, 44, 45, 49, 49, 54, 44, 49, 44, 45, 50, 55, 51,
  44, 45, 51, 50, 44, 49, 44, 45, 53, 56, 44, 45, 49, 49, 55, 44,
  49, 44, 45, 50, 55, 52, 44, 45, 51, 51, 44, 49, 44, 45, 53, 54,
  44, 45, 49, 49, 55, 44, 49, 44, 45, 50, 55, 53, 44, 45, 51, 52,
  44, 49, 44, 45, 53, 51, 44, 45, 49, 49, 56, 44, 49, 44, 45, 50,
  55, 54, 44, 45, 51, 53, 44, 49, 44, 45, 53, 49, 44, 45, 49, 49,
  56, 44, 49, 44, 45, 50, 55, 55, 44, 45, 51, 55, 44, 49, 44, 45,
  52, 56, 44, 45, 49, 49, 56, 44, 49, 44, 45, 50, 55, 55, 44, 45,
  52, 48, 44, 49, 44, 45, 52, 53, 44, 45, 49, 49, 56, 44, 49, 44,
  45, 50, 55, 56, 44, 45, 52, 49, 44, 49, 44, 45, 52, 51, 44, 45,
  49, 49, 56, 44, 49, 44, 45, 50, 54, 56, 44, 45, 54, 44, 49, 44,
  45, 53, 44, 45, 52, 51, 44, 49, 44, 45, 52, 48, 44, 45, 49, 49,
  55, 44, 49, 44, 45, 50, 54, 56, 44, 45, 49, 48, 44, 49, 44, 45,
  51, 44, 45, 52, 53, 44, 49, 44, 45, 51, 55, 44, 45, 49, 49, 55,
  44, 49, 44, 45, 53, 49, 44, 48, 44, 49, 44, 45, 50, 49, 54, 44,
  45, 49, 49, 44, 49, 44, 45, 51, 44, 45, 52, 55, 44, 49, 44, 45,
  51, 52, 44, 45, 49, 49, 55, 44, 49, 44, 45, 53, 48, 44, 45, 51,
  44, 49, 44, 45, 50, 49, 52, 44, 45, 54, 54, 44, 49, 44, 45, 51,
  48, 44, 45, 49, 49, 55, 44, 49, 44, 45, 52, 57, 44, 45, 52, 44,
  49, 44, 45, 50, 49, 52, 44, 45, 54, 57, 44, 49, 44, 45, 50, 55,
  44, 45, 49, 49, 55, 44, 49, 44, 45, 52, 57, 44, 45, 51, 44, 49,
  44, 45, 50, 49, 53, 44, 45, 55, 49, 44, 49, 44, 45, 50, 54, 44,
  45, 49, 49, 53, 44, 49, 44, 45, 52, 57, 44, 45, 52, 44, 49, 44,
  45, 50, 49, 53, 44, 45, 55, 51, 44, 49, 44, 45, 50, 51, 44, 45,
  49, 49, 54, 44, 49, 44, 45, 52, 57, 44, 45, 52, 44, 49, 44, 45,
  50, 49, 54, 44, 45, 55, 52, 44, 49, 44, 45, 50, 49, 44, 45, 49,
  49, 54, 44, 49, 44, 45, 52, 57, 44, 45, 52, 44, 49, 44, 45, 50,
  49, 54, 44, 45, 55, 53, 44, 49, 44, 45, 50, 48, 44, 45, 49, 49,
  53, 44, 49, 44, 45, 53, 48, 44, 45, 52, 44, 49, 44, 45, 50, 49,
  54, 44, 45, 55, 54, 44, 49, 44, 45, 49, 57, 44, 45, 49, 49, 53,
  44, 49, 44, 45, 53, 48, 44, 45, 52, 44, 49, 44, 45, 50, 49, 55,
  44, 45, 55, 54, 44, 49, 44, 45, 49, 56, 44, 45, 49, 49, 52, 44,
  49, 44, 45, 53, 49, 44, 45, 52, 44, 49, 44, 45, 50, 49, 56, 44,
  45, 55, 54, 44, 49, 44, 45, 49, 55, 44, 45, 49, 49, 52, 44, 49,
  44, 45, 53, 48, 44, 45, 54, 44, 49, 44, 45, 50, 49, 55, 44, 45,
  55, 55, 44, 49, 44, 45, 49, 54, 44, 45, 49, 49, 51, 44, 49, 44,
  45, 53, 49, 44, 45, 54, 44, 49, 44, 45, 50, 49, 57, 44, 45, 55,
  53, 44, 49, 44, 45, 49, 54, 44, 45, 49, 49, 51, 44, 49, 44, 45,
  53, 49, 44, 45, 55, 44, 49, 44, 45, 50, 49, 57, 44, 45, 55, 53,
  44, 49, 44, 45, 49, 53, 44, 45, 49, 49, 51, 44, 49, 44, 45, 53,
  49, 44, 45, 57, 44, 49, 44, 45, 50, 49, 55, 44, 45, 55, 54, 44,
  49, 44, 45, 49, 53, 44, 45, 49, 49, 49, 44, 49, 44, 45, 53, 49,
  44, 45, 49, 49, 44, 49, 44, 45, 50, 49, 55, 44, 45, 55, 53, 44,
  49, 44, 45, 49, 53, 44, 45, 49, 49, 49, 44, 49, 44, 45, 53, 49,
  44, 45, 49, 50, 44, 49, 44, 45, 50, 49, 56, 44, 45, 55, 52, 44,
  49, 44, 45, 49, 53, 44, 45, 49, 49, 48, 44, 49, 44, 45, 53, 48,
  44, 45, 53, 44, 49, 44, 45, 52, 44, 45, 54, 44, 49, 44, 45, 49,
  55, 48, 44, 45, 54, 44, 49, 44, 45, 52, 49, 44, 45, 55, 51, 44,
  49, 44, 45, 49, 54, 44, 45, 49, 48, 56, 44, 49, 44, 45, 53, 48,
  44, 45, 52, 44, 49, 44, 45, 55, 44, 45, 54, 44, 49, 44, 45, 49,
  54, 56, 44, 45, 57, 44, 49, 44, 45, 52, 48, 44, 45, 55, 51, 44,
  49, 44, 45, 49, 53, 44, 45, 49, 48, 56, 44, 49, 44, 45, 52, 57,
  44, 45, 53, 44, 49, 44, 45, 56, 44, 45, 53, 44, 49, 44, 45, 49,
  54, 55, 44, 45, 49, 50, 44, 49, 44, 45, 52, 48, 44, 45, 55, 49,
  44, 49, 44, 45, 49, 53, 44, 45, 49, 48, 55, 44, 49, 44, 45, 52,
  57, 44, 45, 53, 44, 49, 44, 45, 49, 48, 44, 45, 53, 44, 49, 44,
  45, 49, 54, 54, 44, 45, 49, 51, 44, 49, 44, 45, 52, 48, 44, 45,
  55, 48, 44, 49, 44, 45, 49, 54, 44, 45, 49, 48, 54, 44, 49, 44,
  45, 52, 57, 44, 45, 52, 44, 49, 44, 45, 49, 50, 44, 45, 53, 44,
  49, 44, 45, 49, 54, 53, 44, 45, 49, 52, 44, 49, 44, 45, 52, 49,
  44, 45, 54, 57, 44, 49, 44, 45, 49, 53, 44, 45, 49, 48, 53, 44,
  49, 44, 45, 52, 57, 44, 45, 53, 44, 49, 44, 45, 49, 50, 44, 45,
  54, 44, 49, 44, 45, 49, 54, 52, 44, 45, 49, 54, 44, 49, 44, 45,
  51, 48, 44, 45, 55, 44, 49, 44, 45, 51, 44, 45, 54, 56, 44, 49,
  44, 45, 49, 52, 44, 45, 49, 48, 53, 44, 49, 44, 45, 52, 57, 44,
  45, 53, 44, 49, 44, 45, 49, 52, 44, 45, 54, 44, 49, 44, 45, 49,
  54, 51, 44, 45, 49, 56, 44, 49, 44, 45, 50, 54, 44, 45, 56, 48,
  44, 49, 44, 45, 49, 52, 44, 45, 49, 48, 53, 44, 49, 44, 45, 52,
  56, 44, 45, 54, 44, 49, 44, 45, 49, 53, 44, 45, 53, 44, 49, 44,
  45, 49, 54, 51, 44, 45, 50, 48, 44, 49, 44, 45, 50, 52, 44, 45,
  56, 48, 44, 49, 44, 45, 49, 52, 44, 45, 49, 48, 52, 44, 49, 44,
  45, 52, 57, 44, 45, 53, 44, 49, 44, 45, 49, 55, 44, 45, 54, 44,
  49, 44, 45, 49, 54, 50, 44, 45, 50, 49, 44, 49, 44, 45, 50, 49,
  44, 45, 56, 49, 44, 49, 44, 45, 49, 51, 44, 45, 49, 48, 52, 44,
  49, 44, 45, 53, 48, 44, 45, 52, 44, 49, 44, 45, 49, 56, 44, 45,
  55, 44, 49, 44, 45, 49, 54, 49, 44, 45, 50, 51, 44, 49, 44, 45,
  49, 57, 44, 45, 56, 50, 44, 49, 44, 45, 49, 50, 44, 45, 49, 48,
  52, 44, 49, 44, 45, 52, 57, 44, 45, 53, 44, 49, 44, 45, 49, 57,
  44, 45, 55, 44, 49, 44, 45, 49, 54, 48, 44, 45, 50, 53, 44, 49,
  44, 45, 49, 55, 44, 45, 56, 50, 44, 49, 44, 45, 49, 50, 44, 45,
  49, 48, 52, 44, 49, 44, 45, 52, 56, 44, 45, 53, 44, 49, 44, 45,
  50, 49, 44, 45, 55, 44, 49, 44, 45, 49, 54, 48, 44, 45, 50, 54,
  44, 49, 44, 45, 49, 53, 44, 45, 56, 50, 44, 49, 44, 45, 49, 50,
  44, 45, 49, 48, 52, 44, 49, 44, 45, 52, 55, 44, 45, 54, 44, 49,
  44, 45, 50, 50, 44, 45, 55, 44, 49, 44, 45, 49, 53, 57, 44, 45,
  50, 55, 44, 49, 44, 45, 49, 53, 44, 45, 56, 49, 44, 49, 44, 45,
  49, 50, 44, 45, 49, 48, 52, 44, 49, 44, 45, 52, 55, 44, 45, 53,
  44, 49, 44, 45, 50, 51, 44, 45, 56, 44, 49, 44, 45, 49, 53, 57,
  44, 45, 50, 56, 44, 49, 44, 45, 49, 51, 44, 45, 56, 49, 44, 49,
  44, 45, 49, 50, 44, 45, 49, 48, 53, 44, 49, 44, 45, 52, 53, 44,
  45, 53, 44, 49, 44, 45, 50, 53, 44, 45, 55, 44, 49, 44, 45, 49,
  54, 48, 44, 45, 51, 49, 44, 49, 44, 45, 49, 49, 44, 45, 55, 57,
  44, 49, 44, 45, 49, 51, 44, 45, 49, 48, 52, 44, 49, 44, 45, 52,
  53, 44, 45, 53, 44, 49, 44, 45, 50, 54, 44, 45, 55, 44, 49, 44,
  45, 49, 53, 57, 44, 45, 51, 52, 44, 49, 44, 45, 57, 44, 45, 55,
  57, 44, 49, 44, 45, 49, 52, 44, 45, 49, 48, 51, 44, 49, 44, 45,
  52, 51, 44, 45, 53, 44, 49, 44, 45, 50, 56, 44, 45, 54, 44, 49,
  44, 45, 49, 54, 48, 44, 45, 51, 54, 44, 49, 44, 45, 55, 44, 45,
  55, 56, 44, 49, 44, 45, 49, 56, 44, 45, 57, 57, 44, 49, 44, 45,
  52, 50, 44, 45, 53, 44, 49, 44, 45, 51, 48, 44, 45, 54, 44, 49,
  44, 45, 49, 54, 49, 44, 45, 51, 57, 44, 49, 44, 45, 52, 44, 45,
  55, 54, 44, 49, 44, 45, 50, 49, 44, 45, 57, 55, 44, 49, 44, 45,
  52, 48, 44, 45, 53, 44, 49, 44, 45, 51, 50, 44, 45, 54, 44, 49,
  44, 45, 49, 54, 48, 44, 45, 49, 49, 57, 44, 49, 44, 45, 50, 50,
  44, 45, 57, 54, 44, 49, 44, 45, 51, 57, 44, 45, 54, 44, 49, 44,
  45, 51, 51, 44, 45, 54, 44, 49, 44, 45, 49, 54, 48, 44, 45, 49,
  49, 56, 44, 49, 44, 45, 50, 51, 44, 45, 57, 53, 44, 49, 44, 45,
  51, 57, 44, 45, 53, 44, 49, 44, 45, 51, 52, 44, 45, 55, 44, 49,
  44, 45, 49, 54, 48, 44, 45, 49, 49, 56, 44, 49, 44, 45, 50, 51,
  44, 45, 57, 53, 44, 49, 44, 45, 51, 55, 44, 45, 53, 44, 49, 44,
  45, 51, 54, 44, 45, 54, 44, 49, 44, 45, 49, 54, 49, 44, 45, 49,
  49, 55, 44, 49, 44, 45, 50, 51, 44, 45, 57, 53, 44, 49, 44, 45,
  51, 54, 44, 45, 54, 44, 49, 44, 45, 51, 55, 44, 45, 54, 44, 49,
  44, 45, 49, 54, 49, 44, 45, 49, 49, 54, 44, 49, 44, 45, 50, 52,
  44, 45, 57, 52, 44, 49, 44, 45, 51, 54, 44, 45, 53, 44, 49, 44,
  45, 51, 57, 44, 45, 53, 44, 49, 44, 45, 49, 54, 49, 44, 45, 49,
  49, 54, 44, 49, 44, 45, 50, 53, 44, 45, 57, 50, 44, 49, 44, 45,
  51, 54, 44, 45, 53, 44, 49, 44, 45, 52, 48, 44, 45, 54, 44, 49,
  44, 45, 49, 54, 50, 44, 45, 49, 49, 53, 44, 49, 44, 45, 50, 52,
  44, 45, 57, 50, 44, 49, 44, 45, 51, 54, 44, 45, 53, 44, 49, 44,
  45, 52, 49, 44, 45, 54, 44, 49, 44, 45, 49, 54, 50, 44, 45, 49,
  49, 52, 44, 49, 44, 45, 50, 52, 44, 45, 57, 50, 44, 49, 44, 45,
  51, 53, 44, 45, 53, 44, 49, 44, 45, 52, 50, 44, 45, 55, 44, 49,
  44, 45, 49, 54, 49, 44, 45, 49, 49, 52, 44, 49, 44, 45, 50, 53,
  44, 45, 57, 49, 44, 49, 44, 45, 51, 53, 44, 45, 52, 44, 49, 44,
  45, 52, 52, 44, 45, 54, 44, 49, 44, 45, 49, 54, 51, 44, 45, 49,
  49, 51, 44, 49, 44, 45, 50, 52, 44, 45, 57, 48, 44, 49, 44, 45,
  51, 52, 44, 45, 54, 44, 49, 44, 45, 52, 52, 44, 45, 55, 44, 49,
  44, 45, 49, 54, 51, 44, 45, 49, 49, 50, 44, 49, 44, 45, 50, 52,
  44, 45, 57, 48, 44, 49, 44, 45, 51, 52, 44, 45, 53, 44, 49, 44,
  45, 52, 54, 44, 45, 54, 44, 49, 44, 45, 49, 54, 53, 44, 45, 49,
  49, 48, 44, 49, 44, 45, 50, 52, 44, 45, 56, 57, 44, 49, 44, 45,
  51, 52, 44, 45, 54, 44, 49, 44, 45, 52, 55, 44, 45, 53, 44, 49,
  44, 45, 49, 54, 55, 44, 45, 49, 48, 57, 44, 49, 44, 45, 50, 51,
  44, 45, 56, 57, 44, 49, 44, 45, 51, 51, 44, 45, 54, 44, 49, 44,
  45, 52, 56, 44, 45, 54, 44, 49, 44, 45, 49, 53, 55, 44, 45, 51,
  44, 49, 44, 45, 55, 44, 45, 49, 48, 56, 44, 49, 44, 45, 50, 51,
  44, 45, 56, 56, 44, 49, 44, 45, 51, 52, 44, 45, 53, 44, 49, 44,
  45, 53, 48, 44, 45, 54, 44, 49, 44, 45, 49, 53, 52, 44, 45, 57,
  44, 49, 44, 45, 52, 44, 45, 49, 48, 55, 44, 49, 44, 45, 50, 50,
  44, 45, 56, 57, 44, 49, 44, 45, 51, 51, 44, 45, 54, 44, 49, 44,
  45, 53, 48, 44, 45, 54, 44, 49, 44, 45, 49, 53, 51, 44, 45, 49,
  50, 50, 44, 49, 44, 45, 50, 49, 44, 45, 56, 57, 44, 49, 44, 45,
  51, 50, 44, 45, 54, 44, 49, 44, 45, 53, 50, 44, 45, 54, 44, 49,
  44, 45, 49, 53, 49, 44, 45, 49, 50, 51, 44, 49, 44, 45, 50, 48,
  44, 45, 56, 57, 44, 49, 44, 45, 51, 51, 44, 45, 53, 44, 49, 44,
  45, 53, 51, 44, 45, 54, 44, 49, 44, 45, 49, 53, 49, 44, 45, 49,
  50, 51, 44, 49, 44, 45, 49, 57, 44, 45, 56, 57, 44, 49, 44, 45,
  51, 51, 44, 45, 54, 44, 49, 44, 45, 53, 52, 44, 45, 54, 44, 49,
  44, 45, 49, 53, 48, 44, 45, 49, 50, 52, 44, 49, 44, 45, 49, 55,
  44, 45, 57, 48, 44, 49, 44, 45, 51, 50, 44, 45, 54, 44, 49, 44,
  45, 53, 53, 44, 45, 54, 44, 49, 44, 45, 49, 53, 48, 44, 45, 49,
  50, 52, 44, 49, 44, 45, 49, 55, 44, 45, 56, 57, 44, 49, 44, 45,
  51, 51, 44, 45, 53, 44, 49, 44, 45, 53, 54, 44, 45, 55, 44, 49,
  44, 45, 49, 52, 57, 44, 45, 49, 50, 52, 44, 49, 44, 45, 49, 54,
  44, 45, 56, 57, 44, 49, 44, 45, 51, 51, 44, 45, 53, 44, 49, 44,
  45, 53, 56, 44, 45, 54, 44, 49, 44, 45, 49, 52, 57, 44, 45, 49,
  50, 52, 44, 49, 44, 45, 49, 53, 44, 45, 56, 57, 44, 49, 44, 45,
  51, 51, 44, 45, 54, 44, 49, 44, 45, 53, 56, 44, 45, 54, 44, 49,
  44, 45, 49, 52, 57, 44, 45, 49, 50, 53, 44, 49, 44, 45, 49, 53,
  44, 45, 56, 55, 44, 49, 44, 45, 51, 52, 44, 45, 53, 44, 49, 44,
  45, 54, 48, 44, 45, 54, 44, 49, 44, 45, 49, 52, 57, 44, 45, 49,
  50, 52, 44, 49, 44, 45, 49, 53, 44, 45, 54, 44, 49, 44, 45, 55,
  44, 45, 55, 51, 44, 49, 44, 45, 51, 52, 44, 45, 53, 44, 49, 44,
  45, 54, 49, 44, 45, 54, 44, 49, 44, 45, 49, 53, 48, 44, 45, 49,
  50, 52, 44, 49, 44, 45, 51, 55, 44, 45, 54, 50, 44, 49, 44, 45,
  51, 52, 44, 45, 54, 44, 49, 44, 45, 54, 49, 44, 45, 54, 44, 49,
  44, 45, 49, 53, 49, 44, 45, 49, 50, 51, 44, 49, 44, 45, 51, 55,
  44, 45, 54, 49, 44, 49, 44, 45, 51, 52, 44, 45, 54, 44, 49, 44,
  45, 54, 51, 44, 45, 54, 44, 49, 44, 45, 49, 53, 49, 44, 45, 49,
  50, 51, 44, 49, 44, 45, 51, 55, 44, 45, 53, 56, 44, 49, 44, 45,
  51, 54, 44, 45, 53, 44, 49, 44, 45, 54, 52, 44, 45, 54, 44, 49,
  44, 45, 49, 53, 51, 44, 45, 49, 50, 51, 44, 49, 44, 45, 51, 53,
  44, 45, 53, 55, 44, 49, 44, 45, 51, 54, 44, 45, 54, 44, 49, 44,
  45, 54, 52, 44, 45, 54, 44, 49, 44, 45, 49, 53, 52, 44, 45, 49,
  51, 49, 44, 49, 44, 45, 50, 54, 44, 45, 53, 54, 44, 49, 44, 45,
  51, 54, 44, 45, 54, 44, 49, 44, 45, 54, 53, 44, 45, 55, 44, 49,
  44, 45, 49, 53, 53, 44, 45, 49, 51, 51, 44, 49, 44, 45, 50, 50,
  44, 45, 53, 53, 44, 49, 44, 45, 51, 54, 44, 45, 54, 44, 49, 44,
  45, 54, 55, 44, 45, 54, 44, 49, 44, 45, 49, 53, 54, 44, 45, 49,
  51, 52, 44, 49, 44, 45, 50, 48, 44, 45, 53, 53, 44, 49, 44, 45,
  51, 54, 44, 45, 54, 44, 49, 44, 45, 54, 55, 44, 45, 54, 44, 49,
  44, 45, 49, 53, 56, 44, 45, 49, 51, 54, 44, 49, 44, 45, 49, 53,
  44, 45, 53, 53, 44, 49, 44, 45, 51, 54, 44, 45, 54, 44, 49, 44,
  45, 54, 56, 44, 45, 54, 44, 49, 44, 45, 49, 54, 48, 44, 45, 49,
  51, 55, 44, 49, 44, 45, 49, 50, 44, 45, 53, 53, 44, 49, 44, 45,
  51, 54, 44, 45, 53, 44, 49, 44, 45, 54, 57, 44, 45, 55, 44, 49,
  44, 45, 49, 54, 49, 44, 45, 49, 51, 55, 44, 49, 44, 45, 57, 44,
  45, 53, 53, 44, 49, 44, 45, 51, 54, 44, 45, 54, 44, 49, 44, 45,
  54, 57, 44, 45, 55, 44, 49, 44, 45, 49, 54, 52, 44, 45, 49, 51,
  54, 44, 49, 44, 45, 55, 44, 45, 53, 53, 44, 49, 44, 45, 51, 53,
  44, 45, 54, 44, 49, 44, 45, 55, 49, 44, 45, 54, 44, 49, 44, 45,
  49, 54, 55, 44, 45, 49, 51, 53, 44, 49, 44, 45, 51, 44, 45, 53,
  54, 44, 49, 44, 45, 51, 54, 44, 45, 54, 44, 49, 44, 45, 55, 49,
  44, 45, 54, 44, 49, 44, 45, 49, 54, 57, 44, 45, 49, 57, 50, 44,
  49, 44, 45, 51, 53, 44, 45, 54, 44, 49, 44, 45, 55, 50, 44, 45,
  54, 44, 49, 44, 45, 49, 53, 55, 44, 45, 50, 48, 51, 44, 49, 44,
  45, 51, 53, 44, 45, 54, 44, 49, 44, 45, 55, 51, 44, 45, 54, 44,
  49, 44, 45, 49, 53, 54, 44, 45, 50, 48, 51, 44, 49, 44, 45, 51,
  54, 44, 45, 54, 44, 49, 44, 45, 55, 51, 44, 45, 55, 44, 49, 44,
  45, 49, 53, 52, 44, 45, 49, 57, 48, 44, 49, 44, 45, 54, 44, 45,
  55, 44, 49, 44, 45, 51, 54, 44, 45, 54, 44, 49, 44, 45, 55, 52,
  44, 45, 55, 44, 49, 44, 45, 49, 53, 51, 44, 45, 49, 57, 48, 44,
  49, 44, 45, 52, 57, 44, 45, 54, 44, 49, 44, 45, 55, 53, 44, 45,
  55, 44, 49, 44, 45, 49, 53, 51, 44, 45, 49, 56, 57, 44, 49, 44,
  45, 53, 48, 44, 45, 53, 44, 49, 44, 45, 55, 54, 44, 45, 55, 44,
  49, 44, 45, 49, 53, 51, 44, 45, 49, 56, 56, 44, 49, 44, 45, 53,
  48, 44, 45, 54, 44, 49, 44, 45, 55, 54, 44, 45, 55, 44, 49, 44,
  45, 49, 53, 51, 44, 45, 49, 56, 56, 44, 49, 44, 45, 52, 57, 44,
  45, 54, 44, 49, 44, 45, 55, 55, 44, 45, 55, 44, 49, 44, 45, 49,
  53, 51, 44, 45, 49, 56, 55, 44, 49, 44, 45, 52, 57, 44, 45, 54,
  44, 49, 44, 45, 55, 56, 44, 45, 55, 44, 49, 44, 45, 49, 53, 52,
  44, 45, 49, 56, 54, 44, 49, 44, 45, 52, 57, 44, 45, 53, 44, 49,
  44, 45, 55, 57, 44, 45, 55, 44, 49, 44, 45, 49, 53, 53, 44, 45,
  49, 56, 53, 44, 49, 44, 45, 52, 56, 44, 45, 54, 44, 49, 44, 45,
  55, 57, 44, 45, 55, 44, 49, 44, 45, 49, 53, 54, 44, 45, 49, 56,
  51, 44, 49, 44, 45, 52, 56, 44, 45, 54, 44, 49, 44, 45, 55, 57,
  44, 45, 56, 44, 49, 44, 45, 49, 53, 56, 44, 45, 49, 56, 49, 44,
  49, 44, 45, 52, 56, 44, 45, 54, 44, 49, 44, 45, 55, 57, 44, 45,
  55, 44, 49, 44, 45, 49, 54, 50, 44, 45, 49, 55, 56, 44, 49, 44,
  45, 52, 55, 44, 45, 54, 44, 49, 44, 45, 56, 48, 44, 45, 55, 44,
  49, 44, 45, 49, 54, 52, 44, 45, 49, 55, 54, 44, 49, 44, 45, 52,
  54, 44, 45, 54, 44, 49, 44, 45, 56, 49, 44, 45, 55, 44, 49, 44,
  45, 49, 54, 56, 44, 45, 49, 55, 51, 44, 49, 44, 45, 52, 53, 44,
  45, 54, 44, 49, 44, 45, 56, 49, 44, 45, 55, 44, 49, 44, 45, 49,
  55, 52, 44, 45, 49, 54, 56, 44, 49, 44, 45, 52, 51, 44, 45, 54,
  44, 49, 44, 45, 56, 49, 44, 45, 56, 44, 49, 44, 45, 49, 55, 49,
  44, 45, 49, 55, 54, 44, 49, 44, 45, 51, 55, 44, 45, 55, 44, 49,
  44, 45, 56, 49, 44, 45, 55, 44, 49, 44, 45, 49, 54, 57, 44, 45,
  49, 56, 51, 44, 49, 44, 45, 51, 50, 44, 45, 55, 44, 49, 44, 45,
  56, 50, 44, 45, 55, 44, 49, 44, 45, 49, 54, 56, 44, 45, 49, 56,
  54, 44, 49, 44, 45, 51, 48, 44, 45, 54, 44, 49, 44, 45, 56, 50,
  44, 45, 56, 44, 49, 44, 45, 49, 54, 55, 44, 45, 49, 56, 56, 44,
  49, 44, 45, 50, 56, 44, 45, 55, 44, 49, 44, 45, 56, 50, 44, 45,
  56, 44, 49, 44, 45, 49, 54, 54, 44, 45, 49, 57, 49, 44, 49, 44,
  45, 50, 53, 44, 45, 55, 44, 49, 44, 45, 56, 51, 44, 45, 55, 44,
  49, 44, 45, 49, 54, 55, 44, 45, 49, 57, 51, 44, 49, 44, 45, 50,
  51, 44, 45, 54, 44, 49, 44, 45, 56, 51, 44, 45, 56, 44, 49, 44,
  45, 49, 54, 56, 44, 45, 49, 57, 52, 44, 49, 44, 45, 50, 49, 44,
  45, 53, 44, 49, 44, 45, 56, 52, 44, 45, 56, 44, 49, 44, 45, 49,
  54, 56, 44, 45, 49, 57, 57, 44, 49, 44, 45, 49, 53, 44, 45, 54,
  44, 49, 44, 45, 56, 51, 44, 45, 56, 44, 49, 44, 45, 49, 54, 57,
  44, 45, 50, 48, 50, 44, 49, 44, 45, 49, 49, 44, 45, 54, 44, 49,
  44, 45, 56, 51, 44, 45, 56, 44, 49, 44, 45, 49, 55, 49, 44, 45,
  50, 48, 51, 44, 49, 44, 45, 57, 44, 45, 53, 44, 49, 44, 45, 56,
  52, 44, 45, 56, 44, 49, 44, 45, 49, 55, 50, 44, 45, 50, 48, 51,
  44, 49, 44, 45, 55, 44, 45, 53, 44, 49, 44, 45, 56, 52, 44, 45,
  56, 44, 49, 44, 45, 49, 55, 53, 44, 45, 50, 48, 51, 44, 49, 44,
  45, 52, 44, 45, 53, 44, 49, 44, 45, 56, 52, 44, 45, 57, 44, 49,
  44, 45, 49, 55, 55, 44, 45, 50, 48, 51, 44, 49, 44, 48, 44, 45,
  54, 44, 49, 44, 45, 56, 51, 44, 45, 57, 44, 49, 44, 45, 49, 56,
  54, 44, 45, 50, 48, 49, 44, 49, 44, 45, 56, 51, 44, 45, 57, 44,
  49, 44, 45, 49, 56, 55, 44, 45, 50, 48, 49, 44, 49, 44, 45, 56,
  50, 44, 45, 57, 44, 49, 44, 45, 49, 56, 56, 44, 45, 50, 48, 48,
  44, 49, 44, 45, 56, 51, 44, 45, 56, 44, 49, 44, 45, 49, 56, 56,
  44, 45, 50, 48, 49, 44, 49, 44, 45, 56, 50, 44, 45, 56, 44, 49,
  44, 45, 49, 56, 57, 44, 45, 50, 48, 49, 44, 49, 44, 45, 56, 49,
  44, 45, 56, 44, 49, 44, 45, 49, 56, 57, 44, 45, 50, 48, 50, 44,
  49, 44, 45, 56, 48, 44, 45, 57, 44, 49, 44, 45, 49, 56, 57, 44,
  45, 50, 48, 50, 44, 49, 44, 45, 55, 57, 44, 45, 57, 44, 49, 44,
  45, 49, 57, 48, 44, 45, 50, 48, 50, 44, 49, 44, 45, 55, 56, 44,
  45, 49, 48, 44, 49, 44, 45, 49, 57, 49, 44, 45, 50, 48, 50, 44,
  49, 44, 45, 55, 55, 44, 45, 57, 44, 49, 44, 45, 49, 57, 51, 44,
  45, 50, 48, 49, 44, 49, 44, 45, 55, 54, 44, 45, 57, 44, 49, 44,
  45, 49, 57, 54, 44, 45, 50, 48, 48, 44, 49, 44, 45, 55, 52, 44,
  45, 57, 44, 49, 44, 45, 50, 48, 51, 44, 45, 49, 57, 53, 44, 49,
  44, 45, 55, 50, 44, 45, 49, 48, 44, 49, 44, 45, 50, 48, 53, 44,
  45, 49, 57, 52, 44, 49, 44, 45, 55, 49, 44, 45, 57, 44, 49, 44,
  45, 50, 48, 53, 44, 45, 49, 57, 55, 44, 49, 44, 45, 54, 56, 44,
  45, 57, 44, 49, 44, 45, 50, 48, 53, 44, 45, 49, 57, 57, 44, 49,
  44, 45, 54, 54, 44, 45, 49, 48, 44, 49, 44, 45, 50, 48, 53, 44,
  45, 50, 48, 50, 44, 49, 44, 45, 54, 50, 44, 45, 49, 49, 44, 49,
  44, 45, 50, 48, 53, 44, 45, 50, 50, 53, 44, 49, 44, 45, 51, 56,
  44, 45, 49, 49, 44, 49, 44, 45, 50, 48, 53, 44, 45, 50, 51, 50,
  44, 49, 44, 45, 51, 49, 44, 45, 49, 50, 44, 49, 44, 45, 50, 48,
  54, 44, 45, 50, 51, 52, 44, 49, 44, 45, 50, 55, 44, 45, 49, 51,
  44, 49, 44, 45, 50, 48, 54, 44, 45, 50, 51, 55, 44, 49, 44, 45,
  50, 50, 44, 45, 49, 53, 44, 49, 44, 45, 50, 48, 56, 44, 45, 50,
  51, 56, 44, 49, 44, 45, 49, 55, 44, 45, 49, 56, 44, 49, 44, 45,
  50, 49, 53, 44, 45, 50, 51, 53, 44, 49, 44, 45, 57, 44, 45, 50,
  49, 44, 49, 44, 45, 50, 49, 53, 44, 45, 50, 54, 54, 44, 49, 44,
  45, 50, 49, 52, 44, 45, 50, 54, 55, 44, 49, 44, 45, 51, 55, 44,
  45, 52, 44, 49, 44, 45, 49, 55, 49, 44, 45, 50, 54, 57, 44, 49,
  44, 45, 51, 52, 44, 45, 57, 44, 49, 44, 45, 49, 54, 56, 44, 45,
  50, 55, 55, 44, 49, 44, 45, 50, 53, 44, 45, 49, 49, 44, 49, 44,
  45, 49, 54, 55, 44, 45, 50, 56, 56, 44, 49, 44, 45, 49, 51, 44,
  45, 49, 52, 44, 49, 44, 45, 49, 54, 53, 44, 45, 50, 57, 52, 44,
  49, 44, 45, 53, 44, 45, 49, 55, 44, 49, 44, 45, 49, 54, 54, 44,
  45, 51, 49, 53, 44, 49, 44, 45, 49, 55, 51, 44, 45, 50, 54, 48,
  44, 49, 44, 45, 49, 48, 44, 45, 51, 56, 44, 49, 44, 45, 49, 55,
  51, 44, 45, 50, 53, 56, 44, 49, 44, 45, 49, 56, 44, 45, 51, 50,
  44, 49, 44, 45, 49, 55, 50, 44, 45, 50, 53, 56, 44, 49, 44, 45,
  50, 57, 44, 45, 50, 49, 44, 49, 44, 45, 49, 55, 51, 44, 45, 50,
  53, 55, 44, 49, 44, 45, 51, 48, 44, 45, 50, 48, 44, 49, 44, 45,
  49, 55, 51, 44, 45, 50, 53, 55, 44, 49, 44, 45, 51, 49, 44, 45,
  49, 56, 44, 49, 44, 45, 49, 55, 54, 44, 45, 50, 53, 53, 44, 49,
  44, 45, 51, 50, 44, 45, 49, 53, 44, 49, 44, 45, 49, 56, 53, 44,
  45, 50, 52, 56, 44, 49, 44, 45, 51, 51, 44, 45, 49, 51, 44, 49,
  44, 45, 49, 56, 55, 44, 45, 50, 52, 55, 44, 49, 44, 45, 51, 52,
  44, 45, 49, 48, 44, 49, 44, 45, 49, 56, 57, 44, 45, 50, 52, 54,
  44, 49, 44, 45, 51, 55, 44, 45, 53, 44, 49, 44, 45, 49, 57, 50,
  44, 45, 50, 52, 54, 44, 49, 44, 45, 50, 51, 52, 44, 45, 50, 52,
  54, 44, 49, 44, 45, 50, 51, 53, 44, 45, 50, 52, 52, 44, 49, 44,
  45, 50, 51, 57, 44, 45, 50, 52, 48, 44, 49, 44, 45, 50, 52, 55,
  44, 45, 50, 51, 50, 44, 49, 44, 45, 50, 52, 56, 44, 45, 50, 51,
  48, 44, 49, 44, 45, 50, 53, 48, 44, 45, 50, 50, 57, 44, 49, 44,
  45, 50, 53, 50, 44, 45, 50, 50, 55, 44, 49, 44, 45, 50, 53, 51,
  44, 45, 50, 50, 55, 44, 49, 44, 45, 50, 53, 53, 44, 45, 50, 50,
  52, 44, 49, 44, 45, 50, 54, 51, 44, 45, 50, 49, 55, 44, 49, 44,
  45, 50, 54, 53, 44, 45, 50, 48, 48, 44, 49, 44, 45, 50, 44, 45,
  49, 51, 44, 49, 44, 45, 50, 54, 54, 44, 45, 49, 50, 50, 44, 49,
  44, 45, 52, 44, 45, 57, 44, 49, 44, 45, 50, 49, 44, 45, 51, 57,
  44, 49, 44, 45, 56, 44, 45, 49, 49, 44, 49, 44, 45, 50, 54, 56,
  44, 45, 49, 49, 57, 44, 49, 44, 45, 55, 44, 45, 53, 44, 49, 44,
  45, 50, 55, 44, 45, 51, 50, 44, 49, 44, 45, 49, 49, 44, 45, 49,
  49, 44, 49, 44, 45, 50, 55, 48, 44, 45, 53, 44, 49, 44, 45, 52,
  44, 45, 49, 55, 44, 49, 44, 45, 51, 44, 45, 56, 56, 44, 49, 44,
  45, 56, 44, 45, 51, 44, 49, 44, 45, 52, 48, 44, 45, 49, 54, 44,
  49, 44, 45, 49, 54, 44, 45, 49, 48, 44, 49, 44, 45, 50, 56, 49,
  44, 45, 49, 52, 44, 49, 44, 45, 54, 44, 45, 56, 54, 44, 49, 44,
  45, 56, 44, 45, 50, 44, 49, 44, 45, 55, 51, 44, 45, 49, 48, 44,
  49, 44, 45, 50, 56, 50, 44, 45, 49, 49, 44, 49, 44, 45, 56, 44,
  45, 56, 54, 44, 49, 44, 45, 57, 44, 48, 44, 49, 44, 45, 55, 52,
  44, 45, 49, 48, 44, 49, 44, 45, 50, 56, 51, 44, 45, 56, 44, 49,
  44, 45, 57, 44, 45, 56, 54, 44, 49, 44, 45, 57, 44, 48, 44, 49,
  44, 45, 55, 52, 44, 45, 49, 48, 44, 49, 44, 45, 51, 48, 48, 44,
  45, 56, 55, 44, 49, 44, 45, 56, 44, 45, 50, 44, 49, 44, 45, 55,
  51, 44, 45, 49, 48, 44, 49, 44, 45, 51, 48, 48, 44, 45, 56, 55,
  44, 49, 44, 45, 56, 44, 45, 50, 44, 49, 44, 45, 55, 51, 44, 45,
  49, 48, 44, 49, 44, 45, 51, 48, 48, 44, 45, 56, 55, 44, 49, 44,
  45, 56, 44, 45, 50, 44, 49, 44, 45, 55, 52, 44, 45, 57, 44, 49,
  44, 45, 50, 57, 57, 44, 45, 56, 56, 44, 49, 44, 45, 57, 44, 48,
  44, 49, 44, 45, 55, 52, 44, 45, 57, 44, 49, 44, 45, 50, 57, 56,
  44, 45, 57, 48, 44, 49, 44, 45, 56, 44, 45, 50, 44, 49, 44, 45,
  55, 51, 44, 45, 57, 44, 49, 44, 45, 50, 57, 55, 44, 45, 57, 49,
  44, 49, 44, 45, 56, 44, 45, 50, 44, 49, 44, 45, 55, 51, 44, 45,
  49, 48, 44, 49, 44, 45, 50, 57, 51, 44, 45, 57, 52, 44, 49, 44,
  45, 56, 44, 45, 50, 44, 49, 44, 45, 55, 52, 44, 45, 57, 44, 49,
  44, 45, 50, 57, 49, 44, 45, 57, 54, 44, 49, 44, 45, 56, 44, 45,
  51, 44, 49, 44, 45, 55, 51, 44, 45, 57, 44, 49, 44, 45, 50, 57,
  48, 44, 45, 57, 55, 44, 49, 44, 45, 57, 44, 45, 50, 44, 49, 44,
  45, 55, 51, 44, 45, 57, 44, 49, 44, 45, 50, 56, 57, 44, 45, 57,
  56, 44, 49, 44, 45, 57, 44, 45, 50, 44, 49, 44, 45, 55, 52, 44,
  45, 57, 44, 49, 44, 45, 50, 56, 55, 44, 45, 57, 57, 44, 49, 44,
  45, 57, 44, 45, 51, 44, 49, 44, 45, 55, 51, 44, 45, 57, 44, 49,
  44, 45, 50, 56, 54, 44, 45, 49, 48, 48, 44, 49, 44, 45, 49, 48,
  44, 45, 50, 44, 49, 44, 45, 55, 52, 44, 45, 56, 44, 49, 44, 45,
  50, 56, 53, 44, 45, 49, 48, 49, 44, 49, 44, 45, 49, 48, 44, 45,
  50, 44, 49, 44, 45, 55, 52, 44, 45, 57, 44, 49, 44, 45, 50, 56,
  51, 44, 45, 49, 48, 50, 44, 49, 44, 45, 49, 48, 44, 45, 50, 44,
  49, 44, 45, 55, 52, 44, 45, 57, 44, 49, 44, 45, 50, 56, 50, 44,
  45, 49, 48, 51, 44, 49, 44, 45, 49, 48, 44, 45, 51, 44, 49, 44,
  45, 55, 52, 44, 45, 56, 44, 49, 44, 45, 50, 56, 50, 44, 45, 49,
  48, 51, 44, 49, 44, 45, 49, 49, 44, 45, 50, 44, 49, 44, 45, 55,
  52, 44, 45, 57, 44, 49, 44, 45, 50, 56, 48, 44, 45, 49, 48, 52,
  44, 49, 44, 45, 49, 49, 44, 45, 50, 44, 49, 44, 45, 55, 52, 44,
  45, 57, 44, 49, 44, 45, 50, 55, 57, 44, 45, 49, 48, 53, 44, 49,
  44, 45, 49, 49, 44, 45, 50, 44, 49, 44, 45, 55, 53, 44, 45, 56,
  44, 49, 44, 45, 50, 55, 56, 44, 45, 49, 48, 54, 44, 49, 44, 45,
  49, 49, 44, 45, 51, 44, 49, 44, 45, 55, 52, 44, 45, 57, 44, 49,
  44, 45, 50, 55, 55, 44, 45, 49, 48, 54, 44, 49, 44, 45, 49, 49,
  44, 45, 51, 44, 49, 44, 45, 55, 52, 44, 45, 57, 44, 49, 44, 45,
  50, 55, 54, 44, 45, 49, 48, 55, 44, 49, 44, 45, 49, 50, 44, 45,
  50, 44, 49, 44, 45, 55, 52, 44, 45, 57, 44, 49, 44, 45, 50, 55,
  54, 44, 45, 49, 48, 55, 44, 49, 44, 45, 49, 50, 44, 45, 50, 44,
  49, 44, 45, 55, 52, 44, 45, 57, 44, 49, 44, 45, 50, 55, 54, 44,
  45, 49, 48, 55, 44, 49, 44, 45, 49, 50, 44, 45, 50, 44, 49, 44,
  45, 55, 52, 44, 45, 57, 44, 49, 44, 45, 50, 55, 53, 44, 45, 49,
  48, 56, 44, 49, 44, 45, 49, 50, 44, 45, 51, 44, 49, 44, 45, 55,
  51, 44, 45, 57, 44, 49, 44, 45, 50, 55, 53, 44, 45, 49, 48, 56,
  44, 49, 44, 45, 49, 51, 44, 45, 50, 44, 49, 44, 45, 55, 51, 44,
  45, 57, 44, 49, 44, 45, 50, 55, 53, 44, 45, 49, 48, 55, 44, 49,
  44, 45, 49, 52, 44, 45, 50, 44, 49, 44, 45, 55, 51, 44, 45, 57,
  44, 49, 44, 45, 50, 55, 53, 44, 45, 49, 48, 55, 44, 49, 44, 45,
  49, 52, 44, 45, 50, 44, 49, 44, 45, 55, 51, 44, 45, 57, 44, 49,
  44, 45, 50, 55, 52, 44, 45, 49, 48, 56, 44, 49, 44, 45, 49, 52,
  44, 45, 51, 44, 49, 44, 45, 55, 50, 44, 45, 57, 44, 49, 44, 45,
  50, 55, 52, 44, 45, 49, 48, 56, 44, 49, 44, 45, 49, 53, 44, 45,
  50, 44, 49, 44, 45, 55, 50, 44, 45, 57, 44, 49, 44, 45, 50, 55,
  52, 44, 45, 49, 48, 56, 44, 49, 44, 45, 49, 53, 44, 45, 50, 44,
  49, 44, 45, 55, 49, 44, 45, 49, 48, 44, 49, 44, 45, 50, 55, 51,
  44, 45, 49, 48, 56, 44, 49, 44, 45, 49, 54, 44, 45, 50, 44, 49,
  44, 45, 55, 49, 44, 45, 57, 44, 49, 44, 45, 49, 57, 49, 44, 45,
  55, 44, 49, 44, 45, 55, 54, 44, 45, 49, 48, 56, 44, 49, 44, 45,
  49, 54, 44, 45, 51, 44, 49, 44, 45, 55, 48, 44, 45, 57, 44, 49,
  44, 45, 49, 56, 55, 44, 45, 49, 52, 44, 49, 44, 45, 55, 51, 44,
  45, 49, 48, 56, 44, 49, 44, 45, 49, 55, 44, 45, 50, 44, 49, 44,
  45, 55, 48, 44, 45, 57, 44, 49, 44, 45, 49, 56, 53, 44, 45, 49,
  56, 44, 49, 44, 45, 55, 49, 44, 45, 49, 48, 56, 44, 49, 44, 45,
  49, 55, 44, 45, 50, 44, 49, 44, 45, 54, 57, 44, 45, 49, 48, 44,
  49, 44, 45, 49, 56, 51, 44, 45, 50, 49, 44, 49, 44, 45, 55, 48,
  44, 45, 49, 48, 55, 44, 49, 44, 45, 49, 56, 44, 45, 51, 44, 49,
  44, 45, 54, 56, 44, 45, 57, 44, 49, 44, 45, 49, 56, 50, 44, 45,
  50, 52, 44, 49, 44, 45, 54, 57, 44, 45, 49, 48, 55, 44, 49, 44,
  45, 49, 56, 44, 45, 51, 44, 49, 44, 45, 54, 56, 44, 45, 57, 44,
  49, 44, 45, 49, 55, 57, 44, 45, 50, 56, 44, 49, 44, 45, 54, 56,
  44, 45, 49, 48, 55, 44, 49, 44, 45, 49, 57, 44, 45, 50, 44, 49,
  44, 45, 54, 55, 44, 45, 49, 48, 44, 49, 44, 45, 49, 54, 53, 44,
  45, 52, 50, 44, 49, 44, 45, 54, 56, 44, 45, 49, 48, 55, 44, 49,
  44, 45, 49, 57, 44, 45, 50, 44, 49, 44, 45, 54, 55, 44, 45, 57,
  44, 49, 44, 45, 49, 54, 52, 44, 45, 52, 53, 44, 49, 44, 45, 54,
  55, 44, 45, 49, 48, 54, 44, 49, 44, 45, 50, 48, 44, 45, 51, 44,
  49, 44, 45, 54, 54, 44, 45, 57, 44, 49, 44, 45, 49, 54, 51, 44,
  45, 52, 54, 44, 49, 44, 45, 54, 55, 44, 45, 49, 48, 54, 44, 49,
  44, 45, 50, 48, 44, 45, 51, 44, 49, 44, 45, 54, 53, 44, 45, 49,
  48, 44, 49, 44, 45, 49, 54, 50, 44, 45, 52, 55, 44, 49, 44, 45,
  54, 55, 44, 45, 49, 48, 54, 44, 49, 44, 45, 50, 48, 44, 45, 51,
  44, 49, 44, 45, 54, 53, 44, 45, 57, 44, 49, 44, 45, 49, 54, 50,
  44, 45, 52, 57, 44, 49, 44, 45, 54, 54, 44, 45, 49, 48, 53, 44,
  49, 44, 45, 50, 50, 44, 45, 50, 44, 49, 44, 45, 54, 52, 44, 45,
  49, 48, 44, 49, 44, 45, 49, 54, 49, 44, 45, 53, 48, 44, 49, 44,
  45, 54, 54, 44, 45, 49, 48, 53, 44, 49, 44, 45, 50, 50, 44, 45,
  51, 44, 49, 44, 45, 54, 51, 44, 45, 57, 44, 49, 44, 45, 49, 54,
  50, 44, 45, 53, 48, 44, 49, 44, 45, 54, 54, 44, 45, 49, 48, 52,
  44, 49, 44, 45, 50, 51, 44, 45, 51, 44, 49, 44, 45, 54, 50, 44,
  45, 49, 48, 44, 49, 44, 45, 49, 54, 49, 44, 45, 53, 49, 44, 49,
  44, 45, 54, 54, 44, 45, 49, 48, 51, 44, 49, 44, 45, 50, 53, 44,
  45, 50, 44, 49, 44, 45, 54, 50, 44, 45, 57, 44, 49, 44, 45, 49,
  54, 50, 44, 45, 53, 49, 44, 49, 44, 45, 54, 54, 44, 45, 49, 48,
  51, 44, 49, 44, 45, 50, 53, 44, 45, 50, 44, 49, 44, 45, 54, 49,
  44, 45, 49, 48, 44, 49, 44, 45, 49, 54, 49, 44, 45, 53, 50, 44,
  49, 44, 45, 54, 53, 44, 45, 49, 48, 51, 44, 49, 44, 45, 50, 54,
  44, 45, 51, 44, 49, 44, 45, 54, 48, 44, 45, 57, 44, 49, 44, 45,
  49, 54, 50, 44, 45, 53, 50, 44, 49, 44, 45, 54, 52, 44, 45, 49,
  48, 51, 44, 49, 44, 45, 50, 55, 44, 45, 51, 44, 49, 44, 45, 53,
  57, 44, 45, 57, 44, 49, 44, 45, 49, 54, 51, 44, 45, 53, 51, 44,
  49, 44, 45, 54, 48, 44, 45, 49, 48, 53, 44, 49, 44, 45, 50, 57,
  44, 45, 50, 44, 49, 44, 45, 53, 57, 44, 45, 57, 44, 49, 44, 45,
  49, 54, 51, 44, 45, 53, 51, 44, 49, 44, 45, 53, 54, 44, 45, 49,
  48, 56, 44, 49, 44, 45, 51, 48, 44, 45, 50, 44, 49, 44, 45, 53,
  56, 44, 45, 57, 44, 49, 44, 45, 49, 54, 52, 44, 45, 53, 52, 44,
  49, 44, 45, 53, 51, 44, 45, 49, 49, 48, 44, 49, 44, 45, 51, 48,
  44, 45, 50, 44, 49, 44, 45, 53, 55, 44, 45, 57, 44, 49, 44, 45,
  49, 54, 53, 44, 45, 53, 54, 44, 49, 44, 45, 53, 48, 44, 45, 49,
  48, 57, 44, 49, 44, 45, 51, 50, 44, 45, 51, 44, 49, 44, 45, 53,
  53, 44, 45, 49, 48, 44, 49, 44, 45, 49, 54, 53, 44, 45, 54, 56,
  44, 49, 44, 45, 51, 55, 44, 45, 49, 49, 48, 44, 49, 44, 45, 51,
  50, 44, 45, 51, 44, 49, 44, 45, 53, 52, 44, 45, 49, 48, 44, 49,
  44, 45, 49, 54, 55, 44, 45, 55, 48, 44, 49, 44, 45, 51, 50, 44,
  45, 49, 49, 50, 44, 49, 44, 45, 51, 51, 44, 45, 50, 44, 49, 44,
  45, 53, 52, 44, 45, 57, 44, 49, 44, 45, 49, 54, 56, 44, 45, 55,
  50, 44, 49, 44, 45, 50, 57, 44, 45, 49, 49, 50, 44, 49, 44, 45,
  51, 52, 44, 45, 50, 44, 49, 44, 45, 53, 51, 44, 45, 57, 44, 49,
  44, 45, 49, 55, 49, 44, 45, 53, 44, 49, 44, 45, 53, 44, 45, 54,
  51, 44, 49, 44, 45, 50, 52, 44, 45, 49, 49, 52, 44, 49, 44, 45,
  51, 52, 44, 45, 51, 44, 49, 44, 45, 53, 49, 44, 45, 49, 48, 44,
  49, 44, 45, 49, 56, 52, 44, 45, 54, 50, 44, 49, 44, 45, 50, 48,
  44, 45, 49, 49, 54, 44, 49, 44, 45, 51, 52, 44, 45, 51, 44, 49,
  44, 45, 53, 48, 44, 45, 49, 48, 44, 49, 44, 45, 49, 56, 54, 44,
  45, 54, 50, 44, 49, 44, 45, 49, 56, 44, 45, 49, 49, 55, 44, 49,
  44, 45, 51, 53, 44, 45, 50, 44, 49, 44, 45, 52, 57, 44, 45, 49,
  48, 44, 49, 44, 45, 49, 56, 56, 44, 45, 54, 51, 44, 49, 44, 45,
  49, 53, 44, 45, 49, 49, 57, 44, 49, 44, 45, 51, 52, 44, 45, 50,
  44, 49, 44, 45, 52, 56, 44, 45, 49, 48, 44, 49, 44, 45, 49, 57,
  50, 44, 45, 54, 49, 44, 49, 44, 45, 49, 51, 44, 45, 49, 50, 48,
  44, 49, 44, 45, 51, 52, 44, 45, 51, 44, 49, 44, 45, 52, 54, 44,
  45, 49, 48, 44, 49, 44, 45, 49, 57, 53, 44, 45, 53, 57, 44, 49,
  44, 45, 49, 50, 44, 45, 49, 50, 50, 44, 49, 44, 45, 51, 51, 44,
  45, 51, 44, 49, 44, 45, 52, 53, 44, 45, 49, 48, 44, 49, 44, 45,
  50, 48, 49, 44, 45, 53, 53, 44, 49, 44, 45, 49, 48, 44, 45, 49,
  50, 51, 44, 49, 44, 45, 51, 52, 44, 45, 50, 44, 49, 44, 45, 52,
  52, 44, 45, 49, 48, 44, 49, 44, 45, 50, 48, 54, 44, 45, 53, 50,
  44, 49, 44, 45, 56, 44, 45, 49, 50, 52, 44, 49, 44, 45, 51, 52,
  44, 45, 51, 44, 49, 44, 45, 52, 50, 44, 45, 49, 48, 44, 49, 44,
  45, 50, 48, 56, 44, 45, 53, 50, 44, 49, 44, 45, 55, 44, 45, 49,
  50, 53, 44, 49, 44, 45, 51, 51, 44, 45, 51, 44, 49, 44, 45, 52,
  48, 44, 45, 49, 49, 44, 49, 44, 45, 50, 49, 48, 44, 45, 53, 50,
  44, 49, 44, 45, 53, 44, 45, 49, 50, 55, 44, 49, 44, 45, 51, 50,
  44, 45, 51, 44, 49, 44, 45, 51, 57, 44, 45, 49, 49, 44, 49, 44,
  45, 50, 49, 50, 44, 45, 53, 50, 44, 49, 44, 45, 51, 44, 45, 49,
  50, 56, 44, 49, 44, 45, 51, 51, 44, 45, 50, 44, 49, 44, 45, 51,
  56, 44, 45, 49, 49, 44, 49, 44, 45, 50, 49, 52, 44, 45, 49, 56,
  50, 44, 49, 44, 45, 51, 51, 44, 45, 51, 44, 49, 44, 45, 51, 53,
  44, 45, 49, 50, 44, 49, 44, 45, 50, 49, 54, 44, 45, 49, 56, 50,
  44, 49, 44, 45, 51, 50, 44, 45, 51, 44, 49, 44, 45, 51, 52, 44,
  45, 49, 50, 44, 49, 44, 45, 50, 49, 56, 44, 45, 49, 56, 49, 44,
  49, 44, 45, 51, 50, 44, 45, 51, 44, 49, 44, 45, 51, 51, 44, 45,
  49, 49, 44, 49, 44, 45, 50, 50, 48, 44, 45, 49, 56, 49, 44, 49,
  44, 45, 51, 51, 44, 45, 50, 44, 49, 44, 45, 51, 49, 44, 45, 49,
  50, 44, 49, 44, 45, 50, 50, 50, 44, 45, 49, 56, 48, 44, 49, 44,
  45, 51, 51, 44, 45, 50, 44, 49, 44, 45, 50, 57, 44, 45, 49, 51,
  44, 49, 44, 45, 50, 50, 52, 44, 45, 49, 56, 48, 44, 49, 44, 45,
  51, 50, 44, 45, 51, 44, 49, 44, 45, 50, 55, 44, 45, 49, 50, 44,
  49, 44, 45, 50, 50, 55, 44, 45, 49, 55, 57, 44, 49, 44, 45, 51,
  50, 44, 45, 51, 44, 49, 44, 45, 50, 53, 44, 45, 49, 50, 44, 49,
  44, 45, 50, 50, 57, 44, 45, 49, 55, 57, 44, 49, 44, 45, 51, 51,
  44, 45, 50, 44, 49, 44, 45, 50, 51, 44, 45, 49, 51, 44, 49, 44,
  45, 50, 51, 49, 44, 45, 49, 55, 56, 44, 49, 44, 45, 51, 51, 44,
  45, 50, 44, 49, 44, 45, 50, 50, 44, 45, 49, 51, 44, 49, 44, 45,
  50, 51, 51, 44, 45, 49, 55, 55, 44, 49, 44, 45, 51, 51, 44, 45,
  50, 44, 49, 44, 45, 50, 48, 44, 45, 49, 51, 44, 49, 44, 45, 50,
  51, 54, 44, 45, 49, 55, 55, 44, 49, 44, 45, 51, 50, 44, 45, 51,
  44, 49, 44, 45, 49, 55, 44, 45, 49, 52, 44, 49, 44, 45, 50, 51,
  56, 44, 45, 49, 55, 54, 44, 49, 44, 45, 51, 51, 44, 45, 50, 44,
  49, 44, 45, 49, 53, 44, 45, 49, 52, 44, 49, 44, 45, 50, 52, 49,
  44, 45, 49, 55, 53, 44, 49, 44, 45, 51, 51, 44, 45, 50, 44, 49,
  44, 45, 49, 51, 44, 45, 49, 53, 44, 49, 44, 45, 50, 52, 51, 44,
  45, 49, 55, 52, 44, 49, 44, 45, 51, 51, 44, 45, 50, 44, 49, 44,
  45, 49, 50, 44, 45, 49, 52, 44, 49, 44, 45, 50, 52, 54, 44, 45,
  49, 55, 52, 44, 49, 44, 45, 51, 51, 44, 45, 50, 44, 49, 44, 45,
  57, 44, 45, 49, 51, 44, 49, 44, 45, 50, 53, 48, 44, 45, 49, 55,
  51, 44, 49, 44, 45, 51, 51, 44, 45, 50, 44, 49, 44, 45, 55, 44,
  45, 49, 51, 44, 49, 44, 45, 50, 53, 51, 44, 45, 49, 55, 50, 44,
  49, 44, 45, 51, 51, 44, 45, 51, 44, 49, 44, 45, 52, 44, 45, 49,
  51, 44, 49, 44, 45, 50, 53, 54, 44, 45, 49, 55, 49, 44, 49, 44,
  45, 51, 51, 44, 45, 49, 57, 44, 49, 44, 45, 50, 53, 56, 44, 45,
  49, 55, 48, 44, 49, 44, 45, 51, 51, 44, 45, 49, 55, 44, 49, 44,
  45, 50, 54, 49, 44, 45, 49, 54, 57, 44, 49, 44, 45, 51, 51, 44,
  45, 49, 52, 44, 49, 44, 45, 50, 54, 53, 44, 45, 49, 54, 56, 44,
  49, 44, 45, 51, 51, 44, 45, 49, 48, 44, 49, 44, 45, 50, 55, 49,
  44, 45, 49, 54, 54, 44, 49, 44, 45, 51, 51, 44, 45, 56, 44, 49,
  44, 45, 50, 55, 52, 44, 45, 49, 54, 53, 44, 49, 44, 45, 51, 51,
  44, 45, 54, 44, 49, 44, 45, 50, 55, 54, 44, 45, 49, 54, 53, 44,
  49, 44, 45, 51, 51, 44, 45, 53, 44, 49, 44, 45, 50, 55, 57, 44,
  45, 49, 54, 51, 44, 49, 44, 45, 51, 51, 44, 45, 52, 44, 49, 44,
  45, 50, 56, 49, 44, 45, 49, 48, 49, 44, 49, 44, 45, 53, 44, 45,
  53, 54, 44, 49, 44, 45, 51, 51, 44, 45, 52, 44, 49, 44, 45, 50,
  56, 51, 44, 45, 57, 55, 44, 49, 44, 45, 57, 44, 45, 53, 52, 44,
  49, 44, 45, 51, 51, 44, 45, 51, 44, 49, 44, 45, 50, 56, 53, 44,
  45, 57, 53, 44, 49, 44, 45, 49, 49, 44, 45, 53, 51, 44, 49, 44,
  45, 51, 51, 44, 45, 51, 44, 49, 44, 45, 50, 56, 55, 44, 45, 57,
  49, 44, 49, 44, 45, 49, 52, 44, 45, 53, 51, 44, 49, 44, 45, 51,
  50, 44, 45, 50, 44, 49, 44, 45, 50, 57, 48, 44, 45, 56, 55, 44,
  49, 44, 45, 49, 55, 44, 45, 53, 50, 44, 49, 44, 45, 51, 50, 54,
  44, 45, 56, 51, 44, 49, 44, 45, 50, 48, 44, 45, 53, 49, 44, 49,
  44, 45, 51, 50, 56, 44, 45, 55, 55, 44, 49, 44, 45, 50, 53, 44,
  45, 53, 48, 44, 49, 44, 45, 51, 51, 48, 44, 45, 55, 51, 44, 49,
  44, 45, 50, 56, 44, 45, 52, 57, 44, 49, 44, 45, 51, 51, 52, 44,
  45, 54, 53, 44, 49, 44, 45, 51, 51, 44, 45, 52, 56, 44, 49, 44,
  45, 51, 51, 55, 44, 45, 53, 56, 44, 49, 44, 45, 51, 56, 44, 45,
  52, 55, 44, 49, 44, 45, 51, 51, 57, 44, 45, 52, 55, 44, 49, 44,
  45, 52, 57, 44, 45, 52, 54, 44, 49, 44, 45, 51, 52, 48, 44, 45,
  51, 54, 44, 49, 44, 45, 53, 57, 44, 45, 52, 53, 44, 49, 44, 45,
  51, 52, 49, 44, 45, 50, 51, 44, 49, 44, 45, 55, 50, 44, 45, 52,
  52, 44, 49, 44, 45, 51, 52, 51, 44, 45, 49, 56, 44, 49, 44, 45,
  55, 54, 44, 45, 52, 51, 44, 49, 44, 45, 51, 52, 52, 44, 45, 49,
  52, 44, 49, 44, 45, 56, 48, 44, 45, 52, 51, 44, 49, 44, 45, 51,
  52, 53, 44, 45, 49, 48, 44, 49, 44, 45, 56, 51, 44, 45, 52, 50,
  44, 49, 44, 45, 51, 52, 56, 44, 45, 52, 44, 49, 44, 45, 56, 54,
  44, 45, 52, 50, 44, 49, 44, 45, 52, 51, 53, 44, 45, 52, 53, 44,
  49, 44, 45, 55, 55, 44, 45, 51, 44, 49, 44, 45, 51, 53, 48, 44,
  45, 53, 48, 44, 49, 44, 45, 54, 48, 44, 45, 55, 44, 49, 44, 45,
  55, 44, 45, 57, 44, 49, 44, 45, 51, 52, 53, 44, 45, 53, 50, 44,
  49, 44, 45, 53, 57, 44, 45, 49, 48, 44, 49, 44, 45, 52, 44, 45,
  49, 49, 44, 49, 44, 45, 51, 52, 51, 44, 45, 53, 51, 44, 49, 44,
  45, 53, 56, 44, 45, 49, 50, 44, 49, 44, 48, 44, 45, 49, 52, 44,
  49, 44, 45, 51, 52, 49, 44, 45, 53, 52, 44, 49, 44, 45, 53, 55,
  44, 45, 50, 57, 44, 49, 44, 45, 51, 51, 57, 44, 45, 53, 53, 44,
  49, 44, 45, 53, 55, 44, 45, 50, 57, 44, 49, 44, 45, 51, 51, 55,
  44, 45, 53, 54, 44, 49, 44, 45, 53, 56, 44, 45, 50, 57, 44, 49,
  44, 45, 51, 51, 54, 44, 45, 53, 55, 44, 49, 44, 45, 53, 55, 44,
  45, 51, 49, 44, 49, 44, 45, 51, 51, 52, 44, 45, 53, 56, 44, 49,
  44, 45, 53, 55, 44, 45, 51, 49, 44, 49, 44, 45, 51, 51, 52, 44,
  45, 53, 55, 44, 49, 44, 45, 53, 56, 44, 45, 51, 49, 44, 49, 44,
  45, 51, 51, 50, 44, 45, 53, 57, 44, 49, 44, 45, 53, 56, 44, 45,
  51, 49, 44, 49, 44, 45, 51, 51, 50, 44, 45, 53, 56, 44, 49, 44,
  45, 53, 57, 44, 45, 51, 48, 44, 49, 44, 45, 51, 51, 50, 44, 45,
  53, 56, 44, 49, 44, 45, 54, 49, 44, 45, 50, 57, 44, 49, 44, 45,
  51, 51, 49, 44, 45, 53, 56, 44, 49, 44, 45, 54, 50, 44, 45, 50,
  57, 44, 49, 44, 45, 51, 51, 49, 44, 45, 53, 56, 44, 49, 44, 45,
  54, 50, 44, 45, 50, 57, 44, 49, 44, 45, 51, 51, 48, 44, 45, 53,
  56, 44, 49, 44, 45, 54, 51, 44, 45, 50, 56, 44, 49, 44, 45, 51,
  51, 49, 44, 45, 53, 55, 44, 49, 44, 45, 54, 53, 44, 45, 50, 55,
  44, 49, 44, 45, 51, 51, 48, 44, 45, 53, 55, 44, 49, 44, 45, 54,
  54, 44, 45, 50, 54, 44, 49, 44, 45, 51, 51, 49, 44, 45, 53, 54,
  44, 49, 44, 45, 54, 56, 44, 45, 50, 53, 44, 49, 44, 45, 51, 51,
  48, 44, 45, 53, 53, 44, 49, 44, 45, 55, 48, 44, 45, 50, 52, 44,
  49, 44, 45, 51, 51, 49, 44, 45, 53, 52, 44, 49, 44, 45, 55, 50,
  44, 45, 50, 50, 44, 49, 44, 45, 51, 51, 49, 44, 45, 53, 52, 44,
  49, 44, 45, 55, 52, 44, 45, 50, 48, 44, 49, 44, 45, 51, 51, 49,
  44, 45, 53, 51, 44, 49, 44, 45, 55, 55, 44, 45, 49, 56, 44, 49,
  44, 45, 51, 51, 50, 44, 45, 53, 50, 44, 49, 44, 45, 55, 56, 44,
  45, 49, 56, 44, 49, 44, 45, 51, 51, 49, 44, 45, 53, 50, 44, 49,
  44, 45, 56, 48, 44, 45, 49, 54, 44, 49, 44, 45, 51, 51, 49, 44,
  45, 53, 50, 44, 49, 44, 45, 56, 50, 44, 45, 49, 52, 44, 49, 44,
  45, 51, 51, 49, 44, 45, 53, 49, 44, 49, 44, 45, 56, 53, 44, 45,
  49, 50, 44, 49, 44, 45, 51, 51, 48, 44, 45, 53, 49, 44, 49, 44,
  45, 56, 57, 44, 45, 56, 44, 49, 44, 45, 51, 51, 50, 44, 45, 52,
  57, 44, 49, 44, 45, 57, 50, 44, 45, 54, 44, 49, 44, 45, 51, 51,
  48, 44, 45, 53, 49, 44, 49, 44, 45, 57, 52, 44, 45, 52, 44, 49,
  44, 45, 51, 50, 57, 44, 45, 53, 49, 44, 49, 44, 45, 52, 50, 54,
  44, 45, 53, 50, 44, 49, 44, 45, 52, 50, 55, 44, 45, 53, 50, 44,
  49, 44, 45, 52, 50, 54, 44, 45, 53, 50, 44, 49, 44, 45, 52, 50,
  55, 44, 45, 53, 49, 44, 49, 44, 45, 52, 50, 56, 44, 45, 53, 49,
  44, 49, 44, 45, 52, 50, 56, 44, 45, 52, 57, 44, 49, 44, 45, 52,
  51, 49, 44, 45, 52, 56, 44, 49, 44, 45, 52, 51, 49, 44, 45, 52,
  55, 44, 49, 44, 45, 52, 51, 51, 44, 45, 52, 53, 44, 49, 44, 45,
  52, 51, 53, 44, 45, 52, 51, 44, 49, 44, 45, 52, 51, 55, 44, 45,
  52, 49, 44, 49, 44, 45, 52, 51, 57, 44, 45, 51, 57, 44, 49, 44,
  45, 52, 52, 49, 44, 45, 51, 55, 44, 49, 44, 45, 52, 52, 51, 44,
  45, 51, 53, 44, 49, 44, 45, 52, 52, 53, 44, 45, 51, 51, 44, 49,
  44, 45, 52, 52, 55, 44, 45, 51, 51, 44, 49, 44, 45, 52, 52, 56,
  44, 45, 51, 49, 44, 49, 44, 45, 52, 52, 57, 44, 45, 51, 49, 44,
  49, 44, 45, 52, 53, 48, 44, 45, 51, 49, 44, 49, 44, 45, 52, 52,
  57, 44, 45, 51, 49, 44, 49, 44, 45, 52, 53, 48, 44, 45, 51, 48,
  44, 49, 44, 45, 52, 53, 49, 44, 45, 50, 57, 44, 49, 44, 45, 52,
  53, 50, 44, 45, 50, 56, 44, 49, 44, 45, 52, 53, 51, 44, 45, 50,
  55, 44, 49, 44, 45, 52, 53, 52, 44, 45, 50, 54, 44, 49, 44, 45,
  52, 53, 54, 44, 45, 50, 52, 44, 49, 44, 45, 52, 53, 55, 44, 45,
  50, 51, 44, 49, 44, 45, 52, 53, 55, 44, 45, 50, 51, 44, 49, 44,
  45, 52, 53, 56, 44, 45, 50, 50, 44, 49, 44, 45, 52, 53, 56, 44,
  45, 50, 50, 44, 49, 44, 45, 52, 53, 56, 44, 45, 50, 51, 44, 49,
  44, 45, 52, 53, 55, 44, 45, 50, 51, 44, 49, 44, 45, 52, 53, 56,
  44, 45, 50, 50, 44, 49, 44, 45, 52, 53, 56, 44, 45, 50, 51, 44,
  49, 44, 45, 52, 53, 55, 44, 45, 50, 52, 44, 49, 44, 45, 52, 53,
  54, 44, 45, 50, 52, 44, 49, 44, 45, 52, 53, 54, 44, 45, 50, 53,
  44, 49, 44, 45, 52, 53, 54, 44, 45, 50, 52, 44, 49, 44, 45, 52,
  53, 54, 44, 45, 50, 53, 44, 49, 44, 45, 52, 53, 55, 44, 45, 50,
  51, 44, 49, 44, 45, 52, 53, 55, 44, 45, 50, 51, 44, 49, 44, 45,
  52, 53, 57, 44, 45, 50, 48, 44, 49, 44, 45, 52, 54, 51, 44, 45,
  49, 55, 44, 49, 44, 45, 52, 54, 55, 44, 45, 49, 48, 44, 49, 44,
  45, 53, 48, 53, 56, 44, 48, 41, 10, 45, 117, 110, 99, 111, 109, 112,
  114, 101, 115, 115, 95, 114, 108, 101, 32, 45, 114, 32, 36, 49, 44, 36,
  49, 44, 49, 44, 49, 44, 53, 32, 45, 105, 102, 32, 123, 36, 49, 62,
  52, 56, 48, 125, 32, 45, 98, 91, 45, 49, 93, 32, 48, 46, 50, 37,
  32, 45, 101, 110, 100, 105, 102, 32, 45, 103, 101, 32, 52, 48, 37, 10,
  45, 110, 109, 32, 34, 91, 67, 117, 112, 105, 100, 32, 98, 105, 110, 97,
  114, 121, 32, 109, 97, 115, 107, 93, 34, 10, 45, 101, 110, 100, 108, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 99, 117, 114, 115,
  111, 114, 32, 58, 32, 95, 109, 111, 100, 101, 32, 61, 32, 123, 32, 48,
  61, 104, 105, 100, 101, 32, 124, 32, 49, 61, 115, 104, 111, 119, 32, 125,
  32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  83, 104, 111, 119, 32, 111, 114, 32, 104, 105, 100, 101, 32, 109, 111, 117,
  115, 101, 32, 99, 117, 114, 115, 111, 114, 32, 102, 111, 114, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 110, 115, 116, 97, 110, 116, 32, 119,
  105, 110, 100, 111, 119, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 67, 111, 109, 109, 97, 110, 100, 32, 115, 117, 98, 115, 101, 116, 32,
  40, 105, 102, 32, 97, 110, 121, 41, 32, 115, 116, 97, 110, 100, 115, 32,
  102, 111, 114, 32, 105, 110, 115, 116, 97, 110, 116, 32, 119, 105, 110, 100,
  111, 119, 32, 105, 110, 100, 105, 99, 101, 115, 32, 105, 110, 115, 116, 101,
  97, 100, 32, 111, 102, 32, 105, 109, 97, 103, 101, 32, 105, 110, 100, 105,
  99, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101,
  102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 109, 111,
  100, 101, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 100, 32,
  58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 100, 105, 115, 112, 108,
  97, 121, 39, 46, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 100, 105, 115, 112, 108, 97, 121, 32, 58, 32, 95, 88, 44, 95,
  89, 44, 95, 90, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 105, 115, 112, 108, 97, 121, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 105, 110, 32, 97,
  110, 32, 105, 110, 116, 101, 114, 97, 99, 116, 105, 118, 101, 32, 118, 105,
  101, 119, 101, 114, 32, 40, 117, 115, 101, 32, 116, 104, 101, 32, 105, 110,
  115, 116, 97, 110, 116, 32, 119, 105, 110, 100, 111, 119, 32, 91, 48, 93,
  32, 105, 102, 32, 111, 112, 101, 110, 101, 100, 41, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 65, 114, 103, 117, 109, 101, 110, 116, 115, 32,
  39, 88, 39, 44, 39, 89, 39, 44, 39, 90, 39, 32, 100, 101, 116, 101,
  114, 109, 105, 110, 101, 32, 116, 104, 101, 32, 105, 110, 105, 116, 105, 97,
  108, 32, 115, 101, 108, 101, 99, 116, 105, 111, 110, 32, 118, 105, 101, 119,
  44, 32, 102, 111, 114, 32, 51, 100, 32, 118, 111, 108, 117, 109, 101, 116,
  114, 105, 99, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 100,
  39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 100, 48, 32, 58, 32,
  101, 113, 46, 32, 116, 111, 32, 39, 45, 100, 105, 115, 112, 108, 97, 121,
  48, 39, 46, 10, 100, 48, 32, 58, 10, 45, 95, 100, 105, 115, 112, 108,
  97, 121, 48, 10, 35, 64, 103, 109, 105, 99, 32, 100, 105, 115, 112, 108,
  97, 121, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 105, 115,
  112, 108, 97, 121, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 32, 119, 105, 116, 104, 111, 117, 116, 32, 118, 97, 108,
  117, 101, 32, 110, 111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32,
  116, 111, 32, 39, 45, 100, 48, 39, 41, 46, 10, 100, 105, 115, 112, 108,
  97, 121, 48, 32, 58, 10, 45, 95, 36, 48, 10, 95, 100, 105, 115, 112,
  108, 97, 121, 48, 32, 58, 10, 45, 118, 32, 45, 10, 119, 61, 48, 32,
  104, 61, 48, 32, 100, 61, 48, 32, 115, 61, 48, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 119, 61,
  123, 36, 119, 43, 119, 125, 32, 104, 61, 123, 109, 97, 120, 40, 36, 104,
  44, 104, 41, 125, 32, 100, 61, 123, 109, 97, 120, 40, 36, 100, 44, 100,
  41, 125, 32, 115, 61, 123, 109, 97, 120, 40, 36, 115, 44, 115, 41, 125,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 105, 102,
  32, 123, 64, 35, 61, 61, 49, 125, 32, 45, 119, 32, 45, 49, 44, 45,
  49, 44, 48, 44, 48, 44, 45, 49, 44, 45, 49, 44, 64, 123, 48, 44,
  110, 125, 92, 32, 40, 36, 119, 120, 36, 104, 120, 36, 100, 120, 36, 115,
  41, 10, 45, 101, 108, 105, 102, 32, 123, 64, 35, 61, 61, 50, 125, 32,
  45, 119, 32, 45, 49, 44, 45, 49, 44, 48, 44, 48, 44, 45, 49, 44,
  45, 49, 44, 64, 123, 48, 44, 110, 125, 44, 64, 123, 45, 49, 44, 110,
  125, 92, 32, 40, 36, 119, 120, 36, 104, 120, 36, 100, 120, 36, 115, 41,
  10, 45, 101, 108, 115, 101, 32, 45, 119, 32, 45, 49, 44, 45, 49, 44,
  48, 44, 48, 44, 45, 49, 44, 45, 49, 44, 64, 123, 48, 44, 110, 125,
  44, 46, 46, 44, 64, 123, 45, 49, 44, 110, 125, 92, 32, 40, 36, 119,
  120, 36, 104, 120, 36, 100, 120, 36, 115, 41, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 118, 32, 43, 32, 45, 100, 10, 45, 118, 32, 45, 32, 45,
  119, 91, 93, 32, 48, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 100, 51, 100, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39,
  45, 100, 105, 115, 112, 108, 97, 121, 51, 100, 39, 46, 32, 58, 32, 40,
  43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 100, 105, 115, 112, 108, 97,
  121, 51, 100, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 105, 115, 112, 108, 97, 121, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 115, 32, 105,
  110, 32, 97, 110, 32, 105, 110, 116, 101, 114, 97, 99, 116, 105, 118, 101,
  32, 118, 105, 101, 119, 101, 114, 32, 40, 117, 115, 101, 32, 116, 104, 101,
  32, 105, 110, 115, 116, 97, 110, 116, 32, 119, 105, 110, 100, 111, 119, 32,
  91, 48, 93, 32, 105, 102, 32, 111, 112, 101, 110, 101, 100, 41, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111,
  32, 39, 45, 100, 51, 100, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 100, 97, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 100,
  105, 115, 112, 108, 97, 121, 95, 97, 114, 114, 97, 121, 39, 46, 10, 100,
  97, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63,
  34, 32, 45, 118, 32, 43, 10, 45, 95, 100, 105, 115, 112, 108, 97, 121,
  95, 97, 114, 114, 97, 121, 32, 36, 42, 10, 35, 64, 103, 109, 105, 99,
  32, 100, 105, 115, 112, 108, 97, 121, 95, 97, 114, 114, 97, 121, 32, 58,
  32, 95, 119, 105, 100, 116, 104, 62, 48, 44, 95, 104, 101, 105, 103, 104,
  116, 62, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 105, 115,
  112, 108, 97, 121, 32, 105, 109, 97, 103, 101, 115, 32, 105, 110, 32, 105,
  110, 116, 101, 114, 97, 99, 116, 105, 118, 101, 32, 119, 105, 110, 100, 111,
  119, 115, 32, 119, 104, 101, 114, 101, 32, 112, 105, 120, 101, 108, 32, 110,
  101, 105, 103, 104, 98, 111, 114, 104, 111, 111, 100, 115, 32, 99, 97, 110,
  32, 98, 101, 32, 101, 120, 112, 108, 111, 114, 101, 100, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 119, 105, 100, 116, 104, 61, 49, 51,
  39, 32, 97, 110, 100, 32, 39, 104, 101, 105, 103, 104, 116, 61, 119, 105,
  100, 116, 104, 39, 46, 10, 100, 105, 115, 112, 108, 97, 121, 95, 97, 114,
  114, 97, 121, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34,
  36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 36, 48, 32, 36, 42,
  10, 95, 100, 105, 115, 112, 108, 97, 121, 95, 97, 114, 114, 97, 121, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 123, 49, 61, 49, 51, 125,
  62, 48, 34, 32, 38, 38, 32, 34, 36, 123, 50, 61, 36, 49, 125, 62,
  48, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 68, 105, 115, 112,
  108, 97, 121, 32, 36, 49, 120, 36, 50, 32, 97, 114, 114, 97, 121, 32,
  111, 102, 32, 112, 105, 120, 101, 108, 32, 118, 97, 108, 117, 101, 115, 32,
  102, 111, 114, 32, 105, 109, 97, 103, 101, 34, 36, 95, 95, 115, 34, 46,
  34, 10, 45, 118, 32, 45, 10, 100, 120, 98, 61, 123, 114, 111, 117, 110,
  100, 40, 36, 49, 47, 50, 44, 49, 44, 49, 41, 125, 32, 100, 120, 102,
  61, 123, 36, 49, 45, 49, 45, 36, 100, 120, 98, 125, 10, 100, 121, 98,
  61, 123, 114, 111, 117, 110, 100, 40, 36, 50, 47, 50, 44, 49, 44, 49,
  41, 125, 32, 100, 121, 102, 61, 123, 36, 50, 45, 49, 45, 36, 100, 121,
  98, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 119, 60, 49, 50, 56, 34,
  32, 38, 38, 32, 34, 104, 60, 49, 50, 56, 125, 32, 45, 114, 32, 49,
  50, 56, 44, 49, 50, 56, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 101, 110,
  100, 105, 102, 10, 120, 48, 61, 48, 32, 121, 48, 61, 48, 32, 119, 61,
  123, 119, 125, 32, 104, 61, 123, 104, 125, 10, 119, 109, 97, 120, 61, 123,
  48, 46, 57, 42, 64, 123, 33, 44, 117, 125, 125, 32, 104, 109, 97, 120,
  61, 123, 48, 46, 57, 42, 64, 123, 33, 44, 118, 125, 125, 10, 45, 100,
  111, 10, 45, 105, 102, 32, 123, 119, 62, 61, 36, 119, 109, 97, 120, 124,
  124, 104, 62, 61, 36, 104, 109, 97, 120, 125, 10, 110, 61, 64, 123, 45,
  49, 44, 110, 125, 32, 45, 110, 109, 91, 45, 49, 93, 32, 34, 73, 109,
  97, 103, 101, 32, 34, 39, 64, 123, 45, 49, 44, 98, 125, 46, 64, 123,
  45, 49, 44, 120, 125, 39, 34, 32, 105, 115, 32, 116, 111, 111, 32, 108,
  97, 114, 103, 101, 44, 32, 112, 108, 101, 97, 115, 101, 32, 115, 101, 108,
  101, 99, 116, 32, 97, 32, 115, 117, 98, 45, 105, 109, 97, 103, 101, 46,
  34, 10, 45, 45, 115, 101, 108, 101, 99, 116, 91, 45, 49, 93, 32, 50,
  32, 120, 48, 61, 123, 105, 91, 48, 93, 125, 32, 121, 48, 61, 123, 105,
  91, 49, 93, 125, 32, 119, 61, 123, 49, 43, 105, 91, 51, 93, 45, 105,
  91, 48, 93, 125, 32, 104, 61, 123, 49, 43, 105, 91, 52, 93, 45, 105,
  91, 49, 93, 125, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 110, 109,
  91, 45, 49, 93, 32, 36, 110, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  45, 122, 91, 45, 49, 93, 32, 36, 120, 48, 44, 36, 121, 48, 44, 48,
  44, 123, 36, 120, 48, 43, 36, 119, 45, 49, 125, 44, 123, 36, 121, 48,
  43, 36, 104, 45, 49, 125, 44, 48, 32, 45, 114, 111, 117, 110, 100, 91,
  45, 49, 93, 32, 49, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 10, 45, 119, 104, 105, 108, 101, 32, 123, 119, 62, 61, 36, 119,
  109, 97, 120, 124, 124, 104, 62, 61, 36, 104, 109, 97, 120, 125, 10, 120,
  49, 61, 45, 49, 32, 121, 49, 61, 45, 49, 32, 99, 49, 61, 48, 32,
  111, 120, 49, 61, 45, 49, 32, 111, 121, 49, 61, 45, 49, 32, 111, 99,
  49, 61, 45, 49, 10, 120, 50, 61, 45, 49, 32, 121, 50, 61, 45, 49,
  32, 99, 50, 61, 48, 32, 111, 120, 50, 61, 45, 49, 32, 111, 121, 50,
  61, 45, 49, 32, 111, 99, 50, 61, 45, 49, 10, 120, 51, 61, 45, 49,
  32, 121, 51, 61, 45, 49, 32, 99, 51, 61, 48, 32, 111, 120, 51, 61,
  45, 49, 32, 111, 121, 51, 61, 45, 49, 32, 111, 99, 51, 61, 45, 49,
  10, 99, 48, 61, 48, 32, 111, 120, 109, 61, 45, 49, 32, 111, 121, 109,
  61, 45, 49, 10, 45, 119, 91, 45, 49, 93, 32, 45, 49, 44, 45, 49,
  44, 48, 44, 48, 44, 45, 49, 44, 45, 49, 44, 64, 123, 45, 50, 44,
  98, 125, 46, 64, 123, 45, 50, 44, 120, 125, 10, 45, 100, 111, 10, 45,
  119, 97, 105, 116, 91, 48, 45, 51, 93, 10, 111, 99, 48, 61, 36, 99,
  48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 52, 10, 45, 105, 102, 32,
  123, 36, 62, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 36, 62, 125,
  34, 32, 38, 38, 32, 34, 36, 123, 120, 36, 62, 125, 62, 61, 48, 125,
  32, 45, 119, 36, 62, 32, 48, 32, 120, 36, 62, 61, 45, 49, 32, 121,
  36, 62, 61, 45, 49, 32, 99, 36, 62, 61, 48, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 64, 123, 33, 36, 62, 44, 111, 125, 32,
  99, 36, 62, 61, 123, 40, 36, 123, 99, 36, 62, 125, 43, 115, 105, 103,
  110, 40, 64, 123, 33, 36, 62, 44, 111, 125, 41, 41, 37, 115, 125, 32,
  45, 119, 97, 105, 116, 91, 36, 62, 93, 32, 45, 49, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 64, 123, 33, 36, 62, 44, 83,
  80, 65, 67, 69, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 36, 62,
  44, 69, 78, 84, 69, 82, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33,
  36, 62, 44, 65, 82, 82, 79, 87, 82, 73, 71, 72, 84, 125, 34, 32,
  124, 124, 32, 34, 64, 123, 33, 36, 62, 44, 65, 82, 82, 79, 87, 68,
  79, 87, 78, 125, 125, 32, 99, 36, 62, 61, 123, 40, 36, 123, 99, 36,
  62, 125, 43, 49, 41, 37, 115, 125, 32, 45, 119, 97, 105, 116, 91, 36,
  62, 93, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 64, 123, 33, 36, 62, 44, 66, 65, 67, 75, 83, 80, 65, 67,
  69, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 36, 62, 44, 65, 82,
  82, 79, 87, 76, 69, 70, 84, 125, 34, 32, 124, 124, 32, 34, 64, 123,
  33, 36, 62, 44, 65, 82, 82, 79, 87, 85, 80, 125, 125, 32, 99, 36,
  62, 61, 123, 40, 36, 123, 99, 36, 62, 125, 45, 49, 41, 37, 115, 125,
  32, 45, 119, 97, 105, 116, 91, 36, 62, 93, 32, 45, 49, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123,
  36, 111, 99, 48, 33, 61, 36, 99, 48, 125, 32, 99, 49, 61, 36, 99,
  48, 32, 99, 50, 61, 36, 99, 48, 32, 99, 51, 61, 36, 99, 48, 32,
  45, 101, 110, 100, 105, 102, 10, 120, 109, 61, 64, 123, 33, 44, 120, 125,
  32, 121, 109, 61, 64, 123, 33, 44, 121, 125, 10, 45, 105, 102, 32, 123,
  36, 120, 109, 62, 61, 48, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44,
  98, 125, 38, 49, 125, 32, 120, 49, 61, 36, 120, 109, 32, 121, 49, 61,
  36, 121, 109, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 120, 109, 62, 61, 48, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44,
  98, 125, 38, 50, 125, 32, 120, 50, 61, 36, 120, 109, 32, 121, 50, 61,
  36, 121, 109, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 120, 109, 62, 61, 48, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44,
  98, 125, 38, 52, 125, 32, 120, 51, 61, 36, 120, 109, 32, 121, 51, 61,
  36, 121, 109, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 120, 109, 62, 61, 48, 34, 32, 38, 38, 32, 34, 40, 36, 111, 120,
  109, 33, 61, 36, 120, 109, 34, 32, 124, 124, 32, 34, 36, 111, 121, 109,
  33, 61, 36, 121, 109, 41, 125, 32, 45, 119, 91, 93, 32, 45, 49, 44,
  45, 49, 44, 45, 49, 44, 45, 49, 44, 45, 49, 44, 45, 49, 44, 64,
  123, 45, 50, 44, 98, 125, 46, 64, 123, 45, 50, 44, 120, 125, 34, 32,
  45, 32, 40, 34, 36, 120, 109, 44, 36, 121, 109, 34, 41, 34, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 120, 49, 33, 61,
  36, 111, 120, 49, 34, 32, 124, 124, 32, 34, 36, 121, 49, 33, 61, 36,
  111, 121, 49, 34, 32, 124, 124, 32, 34, 36, 120, 50, 33, 61, 36, 111,
  120, 50, 34, 32, 124, 124, 32, 34, 36, 121, 50, 33, 61, 36, 111, 121,
  50, 34, 32, 124, 124, 32, 34, 36, 120, 51, 33, 61, 36, 111, 120, 51,
  34, 32, 124, 124, 32, 34, 36, 121, 51, 33, 61, 36, 111, 121, 51, 125,
  10, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 120, 49, 62, 61,
  48, 125, 10, 120, 98, 61, 123, 36, 120, 49, 45, 36, 100, 120, 98, 125,
  32, 121, 98, 61, 123, 36, 121, 49, 45, 36, 100, 121, 98, 125, 32, 120,
  101, 61, 123, 36, 120, 49, 43, 36, 100, 120, 102, 125, 32, 121, 101, 61,
  123, 36, 121, 49, 43, 36, 100, 121, 102, 125, 10, 45, 114, 101, 99, 116,
  97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 36, 120, 98, 44, 36, 121,
  98, 44, 36, 120, 101, 44, 36, 121, 101, 44, 48, 46, 50, 44, 48, 44,
  50, 53, 53, 44, 50, 53, 53, 10, 45, 114, 101, 99, 116, 97, 110, 103,
  108, 101, 91, 45, 49, 93, 32, 36, 120, 98, 44, 36, 121, 98, 44, 36,
  120, 101, 44, 36, 121, 101, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70,
  70, 70, 70, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 120, 50, 62, 61, 48,
  125, 10, 120, 98, 61, 123, 36, 120, 50, 45, 36, 100, 120, 98, 125, 32,
  121, 98, 61, 123, 36, 121, 50, 45, 36, 100, 121, 98, 125, 32, 120, 101,
  61, 123, 36, 120, 50, 43, 36, 100, 120, 102, 125, 32, 121, 101, 61, 123,
  36, 121, 50, 43, 36, 100, 121, 102, 125, 10, 45, 114, 101, 99, 116, 97,
  110, 103, 108, 101, 91, 45, 49, 93, 32, 36, 120, 98, 44, 36, 121, 98,
  44, 36, 120, 101, 44, 36, 121, 101, 44, 48, 46, 50, 44, 50, 53, 53,
  44, 51, 50, 44, 50, 53, 53, 10, 45, 114, 101, 99, 116, 97, 110, 103,
  108, 101, 91, 45, 49, 93, 32, 36, 120, 98, 44, 36, 121, 98, 44, 36,
  120, 101, 44, 36, 121, 101, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70,
  70, 70, 70, 44, 50, 53, 53, 44, 51, 50, 44, 50, 53, 53, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 120, 51, 62, 61,
  48, 125, 10, 120, 98, 61, 123, 36, 120, 51, 45, 36, 100, 120, 98, 125,
  32, 121, 98, 61, 123, 36, 121, 51, 45, 36, 100, 121, 98, 125, 32, 120,
  101, 61, 123, 36, 120, 51, 43, 36, 100, 120, 102, 125, 32, 121, 101, 61,
  123, 36, 121, 51, 43, 36, 100, 121, 102, 125, 10, 45, 114, 101, 99, 116,
  97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 36, 120, 98, 44, 36, 121,
  98, 44, 36, 120, 101, 44, 36, 121, 101, 44, 48, 46, 50, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 48, 10, 45, 114, 101, 99, 116, 97, 110, 103,
  108, 101, 91, 45, 49, 93, 32, 36, 120, 98, 44, 36, 121, 98, 44, 36,
  120, 101, 44, 36, 121, 101, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70,
  70, 70, 70, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 119, 91, 45, 49, 93, 32, 64, 123, 45, 50,
  44, 119, 125, 44, 64, 123, 45, 50, 44, 104, 125, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 111, 120, 109, 61, 36, 120, 109, 32, 111, 121, 109, 61,
  36, 121, 109, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 120, 49, 62, 61, 48, 34, 32, 38, 38, 32, 34, 40, 36, 111, 120,
  49, 33, 61, 36, 120, 49, 34, 32, 124, 124, 32, 34, 36, 111, 121, 49,
  33, 61, 36, 121, 49, 34, 32, 124, 124, 32, 34, 36, 111, 99, 49, 33,
  61, 36, 99, 49, 41, 125, 10, 45, 45, 122, 91, 45, 50, 93, 32, 123,
  36, 120, 49, 45, 36, 100, 120, 98, 125, 44, 123, 36, 121, 49, 45, 36,
  100, 121, 98, 125, 44, 48, 44, 36, 99, 49, 44, 123, 36, 120, 49, 43,
  36, 100, 120, 102, 125, 44, 123, 36, 121, 49, 43, 36, 100, 121, 102, 125,
  44, 48, 44, 36, 99, 49, 10, 45, 45, 122, 91, 45, 50, 93, 32, 123,
  36, 120, 49, 45, 36, 100, 120, 98, 125, 44, 123, 36, 121, 49, 45, 36,
  100, 121, 98, 125, 44, 48, 44, 123, 36, 120, 49, 43, 36, 100, 120, 102,
  125, 44, 123, 36, 121, 49, 43, 36, 100, 121, 102, 125, 44, 48, 10, 45,
  95, 95, 100, 105, 115, 112, 108, 97, 121, 95, 97, 114, 114, 97, 121, 91,
  45, 50, 44, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 48, 44, 50,
  53, 53, 44, 50, 53, 53, 10, 45, 119, 49, 91, 45, 49, 93, 32, 123,
  119, 125, 44, 123, 104, 125, 44, 48, 44, 48, 44, 45, 49, 44, 45, 49,
  44, 64, 123, 45, 51, 44, 98, 125, 34, 32, 45, 32, 40, 34, 36, 120,
  49, 44, 36, 121, 49, 44, 99, 61, 36, 99, 49, 34, 41, 34, 10, 45,
  114, 109, 91, 45, 49, 93, 32, 111, 120, 49, 61, 36, 120, 49, 32, 111,
  121, 49, 61, 36, 121, 49, 32, 111, 99, 49, 61, 36, 99, 49, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 120, 50, 62, 61,
  48, 34, 32, 38, 38, 32, 34, 40, 36, 111, 120, 50, 33, 61, 36, 120,
  50, 34, 32, 124, 124, 32, 34, 36, 111, 121, 50, 33, 61, 36, 121, 50,
  34, 32, 124, 124, 32, 34, 36, 111, 99, 50, 33, 61, 36, 99, 50, 41,
  125, 10, 45, 45, 122, 91, 45, 50, 93, 32, 123, 36, 120, 50, 45, 36,
  100, 120, 98, 125, 44, 123, 36, 121, 50, 45, 36, 100, 121, 98, 125, 44,
  48, 44, 36, 99, 50, 44, 123, 36, 120, 50, 43, 36, 100, 120, 102, 125,
  44, 123, 36, 121, 50, 43, 36, 100, 121, 102, 125, 44, 48, 44, 36, 99,
  50, 10, 45, 45, 122, 91, 45, 50, 93, 32, 123, 36, 120, 50, 45, 36,
  100, 120, 98, 125, 44, 123, 36, 121, 50, 45, 36, 100, 121, 98, 125, 44,
  48, 44, 123, 36, 120, 50, 43, 36, 100, 120, 102, 125, 44, 123, 36, 121,
  50, 43, 36, 100, 121, 102, 125, 44, 48, 10, 45, 95, 95, 100, 105, 115,
  112, 108, 97, 121, 95, 97, 114, 114, 97, 121, 91, 45, 50, 44, 45, 49,
  93, 32, 36, 49, 44, 36, 50, 44, 50, 53, 53, 44, 51, 50, 44, 50,
  53, 53, 10, 45, 119, 50, 91, 45, 49, 93, 32, 123, 119, 125, 44, 123,
  104, 125, 44, 48, 44, 48, 44, 45, 49, 44, 45, 49, 44, 64, 123, 45,
  51, 44, 98, 125, 34, 32, 45, 32, 40, 34, 36, 120, 50, 44, 36, 121,
  50, 44, 99, 61, 36, 99, 50, 34, 41, 34, 10, 45, 114, 109, 91, 45,
  49, 93, 32, 111, 120, 50, 61, 36, 120, 50, 32, 111, 121, 50, 61, 36,
  121, 50, 32, 111, 99, 50, 61, 36, 99, 50, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 120, 51, 62, 61, 48, 34, 32, 38,
  38, 32, 34, 40, 36, 111, 120, 51, 33, 61, 36, 120, 51, 34, 32, 124,
  124, 32, 34, 36, 111, 121, 51, 33, 61, 36, 121, 51, 34, 32, 124, 124,
  32, 34, 36, 111, 99, 51, 33, 61, 36, 99, 51, 41, 125, 10, 45, 45,
  122, 91, 45, 50, 93, 32, 123, 36, 120, 51, 45, 36, 100, 120, 98, 125,
  44, 123, 36, 121, 51, 45, 36, 100, 121, 98, 125, 44, 48, 44, 36, 99,
  51, 44, 123, 36, 120, 51, 43, 36, 100, 120, 102, 125, 44, 123, 36, 121,
  51, 43, 36, 100, 121, 102, 125, 44, 48, 44, 36, 99, 51, 10, 45, 45,
  122, 91, 45, 50, 93, 32, 123, 36, 120, 51, 45, 36, 100, 120, 98, 125,
  44, 123, 36, 121, 51, 45, 36, 100, 121, 98, 125, 44, 48, 44, 123, 36,
  120, 51, 43, 36, 100, 120, 102, 125, 44, 123, 36, 121, 51, 43, 36, 100,
  121, 102, 125, 44, 48, 10, 45, 95, 95, 100, 105, 115, 112, 108, 97, 121,
  95, 97, 114, 114, 97, 121, 91, 45, 50, 44, 45, 49, 93, 32, 36, 49,
  44, 36, 50, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 10, 45, 119,
  51, 91, 45, 49, 93, 32, 123, 119, 125, 44, 123, 104, 125, 44, 48, 44,
  48, 44, 45, 49, 44, 45, 49, 44, 64, 123, 45, 51, 44, 98, 125, 34,
  32, 45, 32, 40, 34, 36, 120, 51, 44, 36, 121, 51, 44, 99, 61, 36,
  99, 51, 34, 41, 34, 10, 45, 114, 109, 91, 45, 49, 93, 32, 111, 120,
  51, 61, 36, 120, 51, 32, 111, 121, 51, 61, 36, 121, 51, 32, 111, 99,
  51, 61, 36, 99, 51, 10, 45, 101, 110, 100, 105, 102, 10, 45, 119, 104,
  105, 108, 101, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34, 92, 10, 33,
  64, 123, 33, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64,
  123, 33, 44, 81, 125, 34, 32, 38, 38, 32, 34, 92, 10, 33, 64, 123,
  33, 49, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123,
  33, 49, 44, 81, 125, 34, 32, 38, 38, 32, 34, 92, 10, 33, 64, 123,
  33, 50, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123,
  33, 50, 44, 81, 125, 34, 32, 38, 38, 32, 34, 92, 10, 33, 64, 123,
  33, 51, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123,
  33, 51, 44, 81, 125, 125, 10, 45, 107, 91, 48, 93, 32, 45, 119, 32,
  48, 32, 45, 119, 49, 32, 48, 32, 45, 119, 50, 32, 48, 32, 45, 119,
  51, 32, 48, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 95, 95, 100, 105, 115, 112, 108, 97, 121, 95, 97,
  114, 114, 97, 121, 32, 58, 10, 45, 114, 111, 117, 110, 100, 91, 45, 50,
  93, 32, 49, 32, 45, 99, 91, 45, 50, 93, 32, 48, 44, 57, 57, 57,
  32, 45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 44, 49, 44, 51, 44, 123, 105, 102, 40, 115, 61, 61, 49, 44, 49,
  44, 48, 41, 125, 10, 45, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101,
  91, 45, 49, 93, 32, 45, 114, 91, 45, 50, 93, 32, 123, 36, 49, 42,
  50, 52, 125, 44, 123, 36, 50, 42, 50, 52, 125, 32, 45, 103, 114, 105,
  100, 91, 45, 50, 93, 32, 123, 49, 48, 48, 47, 36, 49, 125, 37, 44,
  123, 49, 48, 48, 47, 36, 50, 125, 37, 44, 48, 44, 48, 44, 49, 44,
  48, 10, 120, 98, 61, 123, 50, 52, 42, 105, 110, 116, 40, 36, 49, 47,
  50, 41, 125, 32, 121, 98, 61, 123, 50, 52, 42, 105, 110, 116, 40, 36,
  50, 47, 50, 41, 125, 32, 120, 101, 61, 123, 36, 120, 98, 43, 50, 52,
  125, 32, 121, 101, 61, 123, 36, 121, 98, 43, 50, 52, 125, 10, 45, 114,
  101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 50, 93, 32, 36, 120, 98,
  44, 36, 121, 98, 44, 36, 120, 101, 44, 36, 121, 101, 44, 49, 44, 48,
  120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 36, 51, 44, 36, 52, 44,
  36, 53, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 50, 32, 121, 103,
  61, 36, 62, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 32, 120,
  103, 61, 36, 62, 10, 45, 116, 91, 45, 50, 93, 32, 64, 123, 45, 51,
  44, 40, 36, 120, 103, 44, 36, 121, 103, 41, 125, 44, 123, 53, 43, 36,
  120, 103, 42, 50, 52, 125, 44, 123, 53, 43, 36, 121, 103, 42, 50, 52,
  125, 44, 49, 51, 44, 48, 46, 56, 44, 123, 105, 102, 40, 64, 123, 45,
  49, 44, 40, 36, 120, 103, 44, 36, 121, 103, 41, 125, 62, 49, 50, 56,
  44, 48, 44, 50, 53, 53, 41, 125, 10, 45, 100, 111, 110, 101, 10, 45,
  100, 111, 110, 101, 10, 45, 114, 109, 91, 45, 51, 44, 45, 49, 93, 10,
  35, 64, 103, 109, 105, 99, 32, 100, 102, 102, 116, 32, 58, 32, 101, 113,
  46, 32, 116, 111, 32, 39, 45, 100, 105, 115, 112, 108, 97, 121, 95, 102,
  102, 116, 39, 46, 10, 100, 102, 102, 116, 32, 58, 10, 45, 95, 100, 105,
  115, 112, 108, 97, 121, 95, 102, 102, 116, 10, 35, 64, 103, 109, 105, 99,
  32, 100, 105, 115, 112, 108, 97, 121, 95, 102, 102, 116, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 105, 115, 112, 108, 97, 121, 32, 102, 111,
  117, 114, 105, 101, 114, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32,
  111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 44, 32, 119, 105, 116, 104, 32, 99, 101, 110, 116, 101, 114, 101,
  100, 32, 108, 111, 103, 45, 109, 111, 100, 117, 108, 101, 32, 97, 110, 100,
  32, 97, 114, 103, 117, 109, 101, 110, 116, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 100, 102,
  102, 116, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 100, 105, 115,
  112, 108, 97, 121, 95, 102, 102, 116, 10, 100, 105, 115, 112, 108, 97, 121,
  95, 102, 102, 116, 32, 58, 10, 45, 95, 36, 48, 10, 95, 100, 105, 115,
  112, 108, 97, 121, 95, 102, 102, 116, 32, 58, 10, 45, 101, 91, 48, 45,
  45, 51, 93, 32, 34, 82, 101, 110, 100, 101, 114, 32, 102, 111, 117, 114,
  105, 101, 114, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32, 111, 102,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 119, 105, 116, 104, 32, 99, 101,
  110, 116, 101, 114, 101, 100, 32, 108, 111, 103, 45, 109, 111, 100, 117, 108,
  101, 32, 97, 110, 100, 32, 97, 114, 103, 117, 109, 101, 110, 116, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 45, 102, 102, 116, 112, 111, 108, 97,
  114, 32, 45, 43, 91, 45, 50, 93, 32, 49, 32, 45, 108, 111, 103, 91,
  45, 50, 93, 32, 45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 97, 32,
  120, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 115,
  32, 120, 44, 50, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 100, 103, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 100,
  105, 115, 112, 108, 97, 121, 95, 103, 114, 97, 112, 104, 39, 46, 10, 100,
  103, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61,
  54, 52, 48, 125, 62, 51, 50, 32, 38, 38, 32, 36, 123, 50, 61, 52,
  56, 48, 125, 62, 51, 50, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  51, 61, 49, 125, 44, 36, 123, 52, 61, 48, 125, 44, 36, 123, 53, 61,
  48, 125, 44, 36, 123, 54, 61, 48, 125, 44, 36, 123, 55, 61, 48, 125,
  44, 36, 123, 56, 61, 48, 125, 44, 34, 36, 123, 57, 61, 120, 45, 97,
  120, 105, 115, 125, 34, 44, 34, 36, 123, 49, 48, 61, 121, 45, 97, 120,
  105, 115, 125, 34, 10, 45, 95, 100, 105, 115, 112, 108, 97, 121, 95, 103,
  114, 97, 112, 104, 32, 36, 123, 49, 45, 56, 125, 44, 34, 36, 57, 34,
  44, 34, 36, 49, 48, 34, 10, 35, 64, 103, 109, 105, 99, 32, 100, 105,
  115, 112, 108, 97, 121, 95, 103, 114, 97, 112, 104, 32, 58, 32, 95, 119,
  105, 100, 116, 104, 62, 51, 50, 44, 95, 104, 101, 105, 103, 104, 116, 62,
  51, 50, 44, 95, 112, 108, 111, 116, 95, 116, 121, 112, 101, 44, 95, 118,
  101, 114, 116, 101, 120, 95, 116, 121, 112, 101, 44, 95, 120, 109, 105, 110,
  44, 95, 120, 109, 97, 120, 44, 95, 121, 109, 105, 110, 44, 95, 121, 109,
  97, 120, 44, 95, 120, 108, 97, 98, 101, 108, 44, 95, 121, 108, 97, 98,
  101, 108, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 110, 100,
  101, 114, 32, 103, 114, 97, 112, 104, 32, 112, 108, 111, 116, 32, 102, 114,
  111, 109, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 32, 100, 97, 116, 97, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58,
  32, 39, 119, 105, 100, 116, 104, 61, 54, 52, 48, 39, 44, 32, 39, 104,
  101, 105, 103, 104, 116, 61, 52, 56, 48, 39, 44, 32, 39, 112, 108, 111,
  116, 95, 116, 121, 112, 101, 61, 49, 39, 44, 32, 39, 118, 101, 114, 116,
  101, 120, 95, 116, 121, 112, 101, 61, 49, 39, 44, 32, 39, 120, 109, 105,
  110, 61, 120, 109, 97, 120, 61, 121, 109, 105, 110, 61, 121, 109, 97, 120,
  61, 48, 39, 44, 32, 39, 120, 108, 97, 98, 101, 108, 61, 34, 120, 45,
  97, 120, 105, 115, 34, 39, 32, 97, 110, 100, 32, 39, 121, 108, 97, 98,
  101, 108, 61, 34, 121, 45, 97, 120, 105, 115, 34, 39, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 49, 50, 56, 44, 49, 44, 49,
  44, 49, 44, 39, 99, 111, 115, 40, 120, 47, 49, 48, 43, 63, 41, 39,
  32, 45, 45, 100, 105, 115, 112, 108, 97, 121, 95, 103, 114, 97, 112, 104,
  32, 52, 48, 48, 44, 51, 48, 48, 44, 51, 10, 100, 105, 115, 112, 108,
  97, 121, 95, 103, 114, 97, 112, 104, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 34, 36, 123, 49, 61, 54, 52, 48, 125, 62, 51, 50, 32, 38,
  38, 32, 36, 123, 50, 61, 52, 56, 48, 125, 62, 51, 50, 34, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 51, 61, 49, 125, 44, 36, 123, 52, 61,
  48, 125, 44, 36, 123, 53, 61, 48, 125, 44, 36, 123, 54, 61, 48, 125,
  44, 36, 123, 55, 61, 48, 125, 44, 36, 123, 56, 61, 48, 125, 44, 34,
  36, 123, 57, 61, 120, 45, 97, 120, 105, 115, 125, 34, 44, 34, 36, 123,
  49, 48, 61, 121, 45, 97, 120, 105, 115, 125, 34, 10, 45, 95, 100, 105,
  115, 112, 108, 97, 121, 95, 103, 114, 97, 112, 104, 32, 36, 123, 49, 45,
  56, 125, 44, 34, 36, 57, 34, 44, 34, 36, 49, 48, 34, 10, 95, 100,
  105, 115, 112, 108, 97, 121, 95, 103, 114, 97, 112, 104, 32, 58, 32, 45,
  99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 54, 52, 48, 125, 62,
  51, 50, 32, 38, 38, 32, 36, 123, 50, 61, 52, 56, 48, 125, 62, 51,
  50, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 49, 125, 44,
  36, 123, 52, 61, 48, 125, 44, 36, 123, 53, 61, 48, 125, 44, 36, 123,
  54, 61, 48, 125, 44, 36, 123, 55, 61, 48, 125, 44, 36, 123, 56, 61,
  48, 125, 44, 34, 36, 123, 57, 61, 120, 45, 97, 120, 105, 115, 125, 34,
  44, 34, 36, 123, 49, 48, 61, 121, 45, 97, 120, 105, 115, 125, 34, 10,
  45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 82, 101, 110, 100, 101, 114,
  32, 36, 49, 120, 36, 50, 32, 103, 114, 97, 112, 104, 32, 112, 108, 111,
  116, 32, 102, 114, 111, 109, 32, 100, 97, 116, 97, 32, 111, 102, 32, 105,
  109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32,
  110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 111, 110, 101, 61, 123, 36,
  51, 33, 61, 51, 125, 32, 115, 105, 122, 61, 123, 119, 42, 104, 42, 100,
  125, 10, 45, 105, 102, 32, 123, 36, 53, 61, 61, 36, 54, 125, 32, 120,
  109, 105, 110, 61, 48, 32, 120, 109, 97, 120, 61, 123, 36, 115, 105, 122,
  45, 36, 111, 110, 101, 125, 32, 45, 101, 108, 115, 101, 32, 120, 109, 105,
  110, 61, 123, 109, 105, 110, 40, 36, 53, 44, 36, 54, 41, 125, 32, 120,
  109, 97, 120, 61, 123, 109, 97, 120, 40, 36, 53, 44, 36, 54, 41, 125,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 55, 61,
  61, 36, 56, 125, 32, 121, 109, 105, 110, 61, 123, 105, 109, 45, 40, 105,
  77, 45, 105, 109, 41, 47, 50, 48, 125, 32, 121, 109, 97, 120, 61, 123,
  105, 77, 43, 40, 105, 77, 45, 105, 109, 41, 47, 50, 48, 125, 32, 45,
  101, 108, 115, 101, 32, 121, 109, 105, 110, 61, 123, 109, 105, 110, 40, 36,
  55, 44, 36, 56, 41, 125, 32, 121, 109, 97, 120, 61, 123, 109, 97, 120,
  40, 36, 55, 44, 36, 56, 41, 125, 32, 45, 101, 110, 100, 105, 102, 10,
  103, 119, 61, 123, 36, 49, 45, 51, 50, 125, 32, 103, 104, 61, 123, 36,
  50, 45, 51, 50, 125, 32, 103, 103, 61, 123, 40, 36, 103, 119, 45, 36,
  111, 110, 101, 41, 47, 40, 36, 115, 105, 122, 45, 36, 111, 110, 101, 41,
  125, 10, 36, 103, 119, 44, 36, 103, 104, 44, 49, 44, 51, 44, 50, 53,
  53, 10, 45, 105, 102, 32, 123, 36, 115, 105, 122, 60, 51, 50, 125, 32,
  45, 103, 114, 105, 100, 91, 45, 49, 93, 32, 36, 103, 103, 44, 36, 103,
  103, 44, 48, 44, 48, 44, 48, 46, 50, 53, 44, 48, 120, 67, 67, 67,
  67, 67, 67, 67, 67, 44, 48, 10, 45, 101, 108, 115, 101, 32, 45, 103,
  114, 105, 100, 91, 45, 49, 93, 32, 49, 48, 37, 44, 49, 48, 37, 44,
  48, 44, 48, 44, 48, 46, 50, 53, 44, 48, 120, 67, 67, 67, 67, 67,
  67, 67, 67, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 64, 123, 45, 50, 44, 115, 125, 61, 61, 49, 125, 32, 40, 49,
  50, 48, 44, 49, 50, 48, 44, 50, 48, 48, 41, 10, 45, 101, 108, 105,
  102, 32, 123, 64, 123, 45, 50, 44, 115, 125, 60, 61, 51, 125, 32, 40,
  50, 50, 48, 44, 49, 48, 44, 49, 48, 59, 49, 48, 44, 50, 50, 48,
  44, 49, 48, 59, 49, 48, 44, 49, 48, 44, 50, 50, 48, 41, 10, 45,
  101, 108, 115, 101, 10, 40, 48, 44, 50, 53, 53, 41, 32, 45, 114, 91,
  45, 49, 93, 32, 50, 53, 54, 44, 49, 44, 49, 44, 49, 44, 51, 32,
  45, 109, 97, 112, 91, 45, 49, 93, 32, 50, 32, 45, 122, 91, 45, 49,
  93, 32, 50, 44, 49, 48, 48, 37, 32, 45, 112, 101, 114, 109, 117, 116,
  101, 91, 45, 49, 93, 32, 99, 120, 121, 122, 32, 45, 114, 91, 45, 49,
  93, 32, 51, 44, 123, 109, 97, 120, 40, 51, 44, 64, 123, 45, 51, 44,
  115, 125, 41, 125, 44, 49, 44, 49, 44, 48, 44, 50, 10, 45, 115, 104,
  91, 45, 49, 93, 32, 48, 44, 50, 44, 48, 44, 48, 32, 45, 102, 91,
  45, 49, 93, 32, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 50, 53,
  53, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 123, 45, 51, 44, 115, 125, 32, 45, 115, 104, 91, 45,
  51, 93, 32, 36, 62, 44, 36, 62, 32, 45, 103, 114, 97, 112, 104, 91,
  45, 51, 93, 32, 91, 45, 49, 93, 44, 36, 51, 44, 36, 52, 44, 36,
  121, 109, 97, 120, 44, 36, 121, 109, 105, 110, 44, 49, 44, 64, 123, 45,
  50, 44, 48, 45, 50, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 48, 44, 45, 49, 32, 45,
  100, 111, 110, 101, 10, 45, 114, 109, 91, 45, 51, 44, 45, 49, 93, 10,
  45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 49, 48,
  48, 37, 44, 48, 44, 49, 44, 49, 49, 48, 32, 45, 108, 105, 110, 101,
  91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 48, 44, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 44, 49, 49, 48, 10, 45, 108, 105, 110,
  101, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  48, 44, 49, 48, 48, 37, 44, 49, 44, 50, 53, 53, 32, 45, 108, 105,
  110, 101, 91, 45, 49, 93, 32, 48, 44, 49, 48, 48, 37, 44, 48, 44,
  48, 44, 49, 44, 50, 53, 53, 10, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 44, 49, 44, 49, 44, 50, 53, 53, 10, 120, 109, 97, 120, 95, 61,
  123, 36, 120, 109, 105, 110, 43, 40, 36, 120, 109, 97, 120, 45, 36, 120,
  109, 105, 110, 41, 42, 40, 36, 115, 105, 122, 45, 36, 111, 110, 101, 41,
  47, 40, 36, 115, 105, 122, 45, 49, 41, 125, 10, 45, 97, 120, 101, 115,
  91, 45, 49, 93, 32, 36, 120, 109, 105, 110, 44, 36, 120, 109, 97, 120,
  95, 44, 36, 121, 109, 97, 120, 44, 36, 121, 109, 105, 110, 44, 49, 51,
  44, 49, 44, 48, 10, 45, 105, 102, 32, 123, 36, 120, 109, 105, 110, 62,
  48, 125, 32, 45, 97, 120, 101, 115, 91, 45, 49, 93, 32, 48, 44, 48,
  44, 36, 121, 109, 97, 120, 44, 36, 121, 109, 105, 110, 44, 49, 51, 44,
  49, 44, 49, 54, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 120, 109, 97, 120, 60, 48, 125, 32, 45, 97, 120, 101, 115,
  91, 45, 49, 93, 32, 123, 119, 45, 49, 125, 44, 123, 119, 45, 49, 125,
  44, 36, 121, 109, 97, 120, 44, 36, 121, 109, 105, 110, 44, 49, 51, 44,
  49, 44, 49, 54, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 121, 109, 105, 110, 62, 48, 125, 32, 45, 97, 120, 101, 115,
  91, 45, 49, 93, 32, 36, 120, 109, 105, 110, 44, 36, 120, 109, 97, 120,
  95, 44, 123, 104, 45, 49, 125, 44, 123, 104, 45, 49, 125, 44, 49, 51,
  44, 49, 44, 49, 54, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 121, 109, 97, 120, 60, 48, 125, 32, 45, 97, 120, 101,
  115, 91, 45, 49, 93, 32, 36, 120, 109, 105, 110, 44, 36, 120, 109, 97,
  120, 95, 44, 48, 44, 48, 44, 49, 51, 44, 49, 44, 49, 54, 48, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 45, 101, 114, 111, 100, 101, 91, 45,
  49, 93, 32, 51, 32, 45, 110, 101, 113, 91, 45, 49, 93, 32, 50, 53,
  53, 32, 45, 114, 91, 45, 50, 93, 32, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 44, 51, 32, 45, 106, 91, 45, 51, 93, 32, 91, 45,
  50, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49,
  93, 44, 49, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45,
  102, 114, 97, 109, 101, 91, 45, 49, 93, 32, 49, 54, 44, 49, 54, 44,
  50, 50, 48, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 36, 57,
  34, 44, 48, 44, 48, 44, 49, 51, 44, 49, 44, 45, 50, 50, 48, 44,
  45, 50, 50, 48, 44, 45, 50, 50, 48, 32, 45, 106, 91, 45, 50, 93,
  32, 91, 45, 49, 93, 44, 123, 40, 64, 123, 45, 50, 44, 119, 125, 45,
  119, 41, 47, 50, 125, 44, 123, 64, 123, 45, 50, 44, 104, 125, 45, 49,
  54, 125, 44, 48, 44, 48, 44, 45, 49, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 36, 49, 48, 34,
  44, 48, 44, 48, 44, 49, 51, 44, 49, 44, 45, 50, 50, 48, 44, 45,
  50, 50, 48, 44, 45, 50, 50, 48, 32, 45, 114, 111, 116, 97, 116, 101,
  91, 45, 49, 93, 32, 45, 57, 48, 32, 45, 106, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 50, 44, 123, 40, 64, 123, 45, 50, 44, 104, 125,
  45, 104, 41, 47, 50, 125, 44, 48, 44, 48, 44, 45, 49, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 99, 32, 48,
  44, 50, 53, 53, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 100, 104, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 100,
  105, 115, 112, 108, 97, 121, 95, 104, 105, 115, 116, 111, 103, 114, 97, 109,
  39, 46, 10, 100, 104, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115,
  61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 100, 105, 115,
  112, 108, 97, 121, 95, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 36,
  42, 10, 35, 64, 103, 109, 105, 99, 32, 100, 105, 115, 112, 108, 97, 121,
  95, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 58, 32, 95, 119, 105,
  100, 116, 104, 62, 48, 44, 95, 104, 101, 105, 103, 104, 116, 62, 48, 44,
  95, 99, 108, 117, 115, 116, 101, 114, 115, 62, 48, 44, 95, 109, 105, 110,
  95, 118, 97, 108, 117, 101, 91, 37, 93, 44, 95, 109, 97, 120, 95, 118,
  97, 108, 117, 101, 91, 37, 93, 44, 95, 115, 104, 111, 119, 95, 97, 120,
  101, 115, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 44, 95, 99, 117,
  116, 95, 118, 97, 108, 117, 101, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 82, 101, 110, 100, 101, 114, 32, 97, 32, 99, 104, 97, 110, 110,
  101, 108, 45, 98, 121, 45, 99, 104, 97, 110, 110, 101, 108, 32, 104, 105,
  115, 116, 111, 103, 114, 97, 109, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 73, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 32, 104, 97, 115, 32, 115, 101, 118, 101, 114, 97, 108, 32,
  115, 108, 105, 99, 101, 115, 44, 32, 116, 104, 101, 32, 114, 101, 110, 100,
  101, 114, 105, 110, 103, 32, 105, 115, 32, 112, 101, 114, 102, 111, 114, 109,
  101, 100, 32, 102, 111, 114, 32, 97, 108, 108, 32, 105, 110, 112, 117, 116,
  32, 115, 108, 105, 99, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 39, 99, 117, 116, 95, 118, 97, 108, 117, 101, 39, 32, 99, 97,
  110, 32, 98, 101, 32, 123, 32, 45, 49, 61, 110, 111, 45, 99, 117, 116,
  32, 124, 32, 62, 61, 48, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 100, 104, 39,
  41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 119, 105, 100,
  116, 104, 61, 53, 49, 50, 39, 44, 32, 39, 104, 101, 105, 103, 104, 116,
  61, 51, 48, 48, 39, 44, 32, 39, 99, 108, 117, 115, 116, 101, 114, 115,
  61, 50, 53, 54, 39, 44, 32, 39, 109, 105, 110, 95, 118, 97, 108, 117,
  101, 61, 48, 37, 39, 44, 32, 39, 109, 97, 120, 95, 118, 97, 108, 117,
  101, 61, 49, 48, 48, 37, 39, 44, 32, 39, 115, 104, 111, 119, 95, 97,
  120, 101, 115, 61, 49, 39, 32, 97, 110, 100, 32, 39, 99, 117, 116, 95,
  118, 97, 108, 117, 101, 61, 45, 49, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 45, 100, 105, 115, 112, 108, 97, 121, 95, 104, 105, 115, 116, 111, 103,
  114, 97, 109, 32, 53, 49, 50, 44, 51, 48, 48, 10, 100, 105, 115, 112,
  108, 97, 121, 95, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 58, 10,
  45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118,
  32, 43, 10, 45, 95, 36, 48, 32, 36, 42, 10, 95, 100, 105, 115, 112,
  108, 97, 121, 95, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 53, 49, 50, 125,
  62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 51, 48, 48, 125, 62, 48,
  32, 38, 38, 32, 36, 123, 51, 61, 50, 53, 54, 125, 62, 48, 34, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 52, 61, 48, 37, 125, 44, 36, 123,
  53, 61, 49, 48, 48, 37, 125, 44, 36, 123, 54, 61, 49, 125, 44, 36,
  123, 55, 61, 45, 49, 125, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32,
  34, 82, 101, 110, 100, 101, 114, 32, 36, 49, 120, 36, 50, 32, 99, 104,
  97, 110, 110, 101, 108, 45, 98, 121, 45, 99, 104, 97, 110, 110, 101, 108,
  32, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 111, 102, 32, 105, 109,
  97, 103, 101, 34, 36, 95, 95, 115, 34, 44, 32, 119, 105, 116, 104, 32,
  36, 51, 32, 99, 108, 117, 115, 116, 101, 114, 115, 44, 32, 109, 105, 110,
  105, 109, 117, 109, 32, 118, 97, 108, 117, 101, 32, 36, 52, 32, 97, 110,
  100, 32, 109, 97, 120, 105, 109, 117, 109, 32, 118, 97, 108, 117, 101, 32,
  36, 53, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64,
  123, 48, 44, 110, 125, 10, 45, 105, 102, 32, 64, 123, 45, 105, 115, 95,
  112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 52, 125, 32, 109, 61, 123,
  105, 109, 43, 40, 105, 77, 45, 105, 109, 41, 42, 36, 52, 125, 32, 45,
  101, 108, 115, 101, 32, 109, 61, 36, 52, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101,
  110, 116, 92, 32, 36, 53, 125, 32, 77, 61, 123, 105, 109, 43, 40, 105,
  77, 45, 105, 109, 41, 42, 36, 53, 125, 32, 45, 101, 108, 115, 101, 32,
  77, 61, 36, 53, 32, 45, 101, 110, 100, 105, 102, 10, 115, 61, 123, 115,
  125, 32, 45, 115, 32, 99, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36,
  115, 32, 45, 108, 91, 123, 45, 49, 45, 36, 62, 125, 93, 32, 45, 115,
  32, 122, 32, 45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 36, 51,
  44, 36, 109, 44, 36, 77, 32, 45, 97, 32, 122, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 45, 97, 32, 99, 32, 118, 77, 61,
  123, 105, 102, 40, 36, 55, 62, 61, 48, 44, 36, 55, 44, 105, 77, 41,
  125, 32, 45, 115, 32, 122, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 36, 49, 44, 36, 50, 44, 49,
  44, 123, 115, 125, 44, 45, 50, 53, 53, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 115, 125, 32, 45, 115, 104, 91, 45, 50, 44, 45, 49, 93,
  32, 36, 62, 44, 36, 62, 32, 45, 103, 114, 97, 112, 104, 91, 45, 49,
  93, 32, 91, 45, 50, 93, 44, 51, 44, 48, 44, 36, 118, 77, 44, 48,
  44, 49, 44, 48, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 45, 50, 93, 32, 45, 43,
  32, 50, 53, 53, 10, 45, 105, 102, 32, 36, 54, 32, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 32, 45, 97, 120, 101, 115, 91, 45, 49, 93, 32,
  36, 109, 44, 36, 77, 44, 36, 118, 77, 44, 48, 44, 49, 51, 44, 49,
  44, 50, 53, 53, 32, 45, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49,
  93, 32, 51, 32, 45, 114, 91, 45, 50, 93, 32, 91, 45, 51, 93, 32,
  45, 106, 91, 45, 51, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 44, 50, 53, 53, 32, 45,
  114, 109, 91, 45, 50, 44, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 97, 32,
  122, 32, 45, 110, 109, 32, 36, 110, 109, 44, 49, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 100, 105, 115, 112, 108, 97, 121, 95, 112, 97, 114, 97,
  109, 101, 116, 114, 105, 99, 32, 58, 32, 95, 119, 105, 100, 116, 104, 62,
  48, 44, 95, 104, 101, 105, 103, 104, 116, 62, 48, 44, 95, 111, 117, 116,
  108, 105, 110, 101, 95, 111, 112, 97, 99, 105, 116, 121, 44, 95, 118, 101,
  114, 116, 101, 120, 95, 114, 97, 100, 105, 117, 115, 62, 61, 48, 44, 95,
  105, 115, 95, 97, 110, 116, 105, 97, 108, 105, 97, 115, 101, 100, 61, 123,
  32, 48, 32, 124, 32, 49, 32, 125, 44, 95, 105, 115, 95, 100, 101, 99,
  111, 114, 97, 116, 101, 100, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125,
  44, 95, 120, 108, 97, 98, 101, 108, 44, 95, 121, 108, 97, 98, 101, 108,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 110, 100, 101, 114,
  32, 50, 100, 32, 111, 114, 32, 51, 100, 32, 112, 97, 114, 97, 109, 101,
  116, 114, 105, 99, 32, 99, 117, 114, 118, 101, 32, 111, 114, 32, 112, 111,
  105, 110, 116, 32, 99, 108, 111, 117, 100, 115, 32, 102, 114, 111, 109, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 32, 100,
  97, 116, 97, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 117,
  114, 118, 101, 32, 112, 111, 105, 110, 116, 115, 32, 97, 114, 101, 32, 100,
  101, 102, 105, 110, 101, 100, 32, 97, 115, 32, 112, 105, 120, 101, 108, 115,
  32, 111, 102, 32, 97, 32, 50, 32, 111, 114, 32, 51, 45, 99, 104, 97,
  110, 110, 101, 108, 32, 105, 109, 97, 103, 101, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 73, 102, 32, 116, 104, 101, 32, 112, 111, 105, 110,
  116, 32, 105, 109, 97, 103, 101, 32, 99, 111, 110, 116, 97, 105, 110, 115,
  32, 109, 111, 114, 101, 32, 116, 104, 97, 110, 32, 51, 32, 99, 104, 97,
  110, 110, 101, 108, 115, 44, 32, 97, 100, 100, 105, 116, 105, 111, 110, 97,
  108, 32, 99, 104, 97, 110, 110, 101, 108, 115, 32, 100, 101, 102, 105, 110,
  101, 32, 116, 104, 101, 32, 40, 82, 44, 71, 44, 66, 41, 32, 99, 111,
  108, 111, 114, 32, 102, 111, 114, 32, 101, 97, 99, 104, 32, 118, 101, 114,
  116, 101, 120, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 102,
  32, 39, 111, 117, 116, 108, 105, 110, 101, 95, 111, 112, 97, 99, 105, 116,
  121, 62, 49, 39, 44, 32, 116, 104, 101, 32, 111, 117, 116, 108, 105, 110,
  101, 32, 105, 115, 32, 99, 111, 108, 111, 114, 101, 100, 32, 97, 99, 99,
  111, 114, 100, 105, 110, 103, 32, 116, 111, 32, 116, 104, 101, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 118, 101, 114, 116, 101, 120, 32, 99,
  111, 108, 111, 114, 115, 32, 97, 110, 100, 32, 39, 111, 117, 116, 108, 105,
  110, 101, 95, 111, 112, 97, 99, 105, 116, 121, 45, 49, 39, 32, 105, 115,
  32, 117, 115, 101, 100, 32, 97, 115, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 116, 104, 101, 32, 97, 99, 116, 117, 97, 108, 32, 100, 114, 97,
  119, 105, 110, 103, 32, 111, 112, 97, 99, 105, 116, 121, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 119, 105, 100, 116, 104, 61, 53, 49,
  50, 39, 44, 32, 39, 104, 101, 105, 103, 104, 116, 61, 119, 105, 100, 116,
  104, 39, 44, 32, 39, 111, 117, 116, 108, 105, 110, 101, 95, 111, 112, 97,
  99, 105, 116, 121, 61, 51, 39, 44, 32, 39, 118, 101, 114, 116, 101, 120,
  95, 114, 97, 100, 105, 117, 115, 61, 48, 39, 44, 32, 39, 105, 115, 95,
  97, 110, 116, 105, 97, 108, 105, 97, 115, 101, 100, 61, 49, 39, 44, 32,
  39, 105, 115, 95, 100, 101, 99, 111, 114, 97, 116, 101, 100, 61, 49, 39,
  44, 32, 39, 120, 108, 97, 98, 101, 108, 61, 34, 120, 45, 97, 120, 105,
  115, 34, 39, 32, 97, 110, 100, 32, 39, 121, 108, 97, 98, 101, 108, 61,
  34, 121, 45, 97, 120, 105, 115, 34, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 49, 48, 50, 52, 44, 49, 44, 49, 44, 50,
  44, 39, 116, 61, 120, 47, 52, 48, 59, 105, 102, 40, 99, 61, 61, 48,
  44, 115, 105, 110, 40, 116, 41, 44, 99, 111, 115, 40, 116, 41, 41, 42,
  40, 101, 120, 112, 40, 99, 111, 115, 40, 116, 41, 41, 45, 50, 42, 99,
  111, 115, 40, 52, 42, 116, 41, 45, 115, 105, 110, 40, 116, 47, 49, 50,
  41, 94, 53, 41, 39, 32, 45, 100, 105, 115, 112, 108, 97, 121, 95, 112,
  97, 114, 97, 109, 101, 116, 114, 105, 99, 32, 53, 49, 50, 44, 53, 49,
  50, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 49, 48, 48,
  48, 44, 49, 44, 49, 44, 50, 44, 63, 40, 45, 49, 48, 48, 44, 49,
  48, 48, 41, 32, 45, 113, 117, 97, 110, 116, 105, 122, 101, 32, 52, 44,
  49, 32, 45, 110, 111, 105, 115, 101, 32, 49, 50, 32, 45, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 48, 44, 50, 32, 45, 45, 110, 111, 114, 109,
  97, 108, 105, 122, 101, 32, 48, 44, 50, 53, 53, 32, 45, 97, 112, 112,
  101, 110, 100, 32, 99, 32, 45, 100, 105, 115, 112, 108, 97, 121, 95, 112,
  97, 114, 97, 109, 101, 116, 114, 105, 99, 32, 53, 49, 50, 44, 53, 49,
  50, 44, 48, 46, 49, 44, 56, 10, 100, 105, 115, 112, 108, 97, 121, 95,
  112, 97, 114, 97, 109, 101, 116, 114, 105, 99, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 36, 123, 49, 61, 53, 49, 50, 125, 62, 48, 32,
  38, 38, 32, 36, 123, 50, 61, 36, 49, 125, 62, 48, 32, 38, 38, 32,
  36, 123, 52, 61, 48, 125, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 51, 61, 51, 125, 44, 36, 123, 53, 61, 49, 125, 44, 36,
  123, 54, 61, 49, 125, 44, 34, 36, 123, 55, 61, 120, 45, 97, 120, 105,
  115, 125, 34, 44, 34, 36, 123, 56, 61, 121, 45, 97, 120, 105, 115, 125,
  34, 10, 45, 118, 32, 45, 32, 115, 48, 61, 34, 110, 111, 32, 34, 32,
  115, 49, 61, 34, 34, 32, 111, 48, 61, 34, 34, 32, 111, 49, 61, 34,
  99, 111, 108, 111, 114, 101, 100, 32, 34, 10, 45, 118, 32, 43, 32, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 110, 100, 101, 114, 32, 36,
  49, 120, 36, 50, 32, 112, 97, 114, 97, 109, 101, 116, 114, 105, 99, 32,
  103, 114, 97, 112, 104, 32, 112, 108, 111, 116, 32, 102, 114, 111, 109, 32,
  100, 97, 116, 97, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 119, 105, 116, 104, 32, 34, 36, 123, 111, 123, 36, 51, 62, 49, 125,
  125, 34, 111, 117, 116, 108, 105, 110, 101, 32, 111, 112, 97, 99, 105, 116,
  121, 32, 34, 123, 105, 102, 40, 36, 51, 62, 49, 44, 36, 51, 45, 49,
  44, 36, 51, 41, 125, 92, 10, 34, 44, 32, 118, 101, 114, 116, 101, 120,
  32, 114, 97, 100, 105, 117, 115, 32, 36, 52, 44, 32, 34, 36, 123, 115,
  123, 36, 53, 33, 61, 48, 125, 125, 34, 97, 110, 116, 105, 97, 108, 105,
  97, 115, 105, 110, 103, 32, 97, 110, 100, 32, 34, 36, 123, 115, 123, 36,
  54, 33, 61, 48, 125, 125, 34, 100, 101, 99, 111, 114, 97, 116, 105, 111,
  110, 46, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 110, 109, 61, 64, 123,
  48, 44, 110, 125, 32, 78, 61, 123, 119, 42, 104, 42, 100, 125, 10, 45,
  105, 91, 48, 93, 32, 40, 123, 39, 67, 73, 109, 103, 51, 100, 39, 125,
  41, 32, 45, 43, 91, 48, 93, 32, 48, 46, 53, 32, 45, 105, 91, 49,
  93, 32, 40, 36, 78, 59, 36, 78, 41, 10, 45, 105, 102, 32, 123, 115,
  61, 61, 52, 125, 32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91,
  45, 49, 93, 32, 51, 44, 51, 32, 45, 114, 91, 45, 49, 93, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 50, 32, 45, 97, 91,
  45, 50, 44, 45, 49, 93, 32, 99, 32, 105, 115, 95, 103, 114, 97, 121,
  115, 99, 97, 108, 101, 61, 49, 10, 45, 101, 108, 115, 101, 32, 105, 115,
  95, 103, 114, 97, 121, 115, 99, 97, 108, 101, 61, 123, 115, 60, 52, 125,
  32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48,
  44, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 115, 104, 91, 45, 49,
  93, 32, 48, 44, 48, 32, 120, 109, 61, 123, 105, 109, 125, 32, 120, 77,
  61, 123, 105, 77, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115,
  104, 91, 45, 49, 93, 32, 49, 44, 49, 32, 121, 109, 61, 123, 105, 109,
  125, 32, 121, 77, 61, 123, 105, 77, 125, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 115, 104, 91, 45, 49, 93, 32, 50, 44, 50, 32, 122, 109,
  61, 123, 105, 109, 125, 32, 122, 77, 61, 123, 105, 77, 125, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45,
  49, 93, 32, 99, 120, 121, 122, 32, 45, 115, 91, 45, 49, 93, 32, 120,
  44, 50, 10, 45, 105, 91, 45, 50, 93, 32, 40, 49, 44, 48, 59, 49,
  44, 123, 36, 78, 45, 49, 125, 41, 32, 45, 114, 91, 45, 50, 93, 32,
  50, 44, 36, 78, 44, 49, 44, 49, 44, 51, 32, 45, 114, 111, 117, 110,
  100, 91, 45, 50, 93, 32, 49, 44, 36, 78, 44, 49, 44, 49, 44, 49,
  10, 45, 121, 32, 45, 97, 32, 121, 32, 45, 99, 51, 100, 32, 45, 110,
  51, 100, 32, 45, 42, 51, 100, 32, 49, 44, 45, 49, 44, 49, 10, 123,
  105, 102, 40, 36, 54, 44, 109, 97, 120, 40, 49, 44, 36, 49, 45, 51,
  50, 41, 44, 36, 49, 41, 125, 44, 123, 105, 102, 40, 36, 54, 44, 109,
  97, 120, 40, 49, 44, 36, 50, 45, 51, 50, 41, 44, 36, 50, 41, 125,
  44, 49, 44, 123, 105, 102, 40, 36, 105, 115, 95, 103, 114, 97, 121, 115,
  99, 97, 108, 101, 44, 49, 44, 51, 41, 125, 44, 50, 53, 53, 10, 45,
  42, 51, 100, 91, 48, 93, 32, 123, 48, 46, 57, 54, 42, 109, 105, 110,
  40, 119, 44, 104, 41, 125, 10, 45, 105, 102, 32, 36, 54, 32, 76, 61,
  123, 48, 46, 49, 42, 109, 97, 120, 40, 36, 49, 44, 36, 50, 41, 125,
  32, 45, 103, 114, 105, 100, 91, 49, 93, 32, 36, 76, 44, 36, 76, 44,
  48, 44, 48, 44, 48, 46, 50, 53, 44, 48, 120, 67, 67, 67, 67, 67,
  67, 67, 67, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 36, 53, 10, 45, 114, 91, 49, 93, 32, 50, 48, 48, 37, 44, 50,
  48, 48, 37, 44, 49, 44, 49, 48, 48, 37, 44, 49, 32, 45, 42, 51,
  100, 91, 48, 93, 32, 50, 10, 45, 105, 102, 32, 36, 52, 32, 45, 45,
  99, 105, 114, 99, 108, 101, 115, 51, 100, 91, 48, 93, 32, 123, 50, 42,
  36, 52, 125, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 49, 93,
  32, 91, 50, 93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 49,
  44, 51, 44, 48, 44, 48, 32, 45, 114, 109, 91, 50, 93, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 108, 105, 102, 32, 36, 52, 10, 45, 45,
  99, 105, 114, 99, 108, 101, 115, 51, 100, 91, 48, 93, 32, 36, 52, 32,
  45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 49, 93, 32, 91, 50, 93,
  44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 49, 44, 51, 44, 48,
  44, 48, 32, 45, 114, 109, 91, 50, 93, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 36, 51, 32, 45, 108, 91, 48, 93, 32, 45, 115,
  51, 100, 32, 45, 102, 91, 49, 93, 32, 39, 105, 45, 121, 39, 32, 45,
  114, 109, 91, 51, 93, 32, 45, 105, 91, 51, 93, 32, 40, 50, 44, 48,
  44, 49, 59, 50, 44, 123, 36, 78, 45, 50, 125, 44, 123, 36, 78, 45,
  49, 125, 41, 32, 45, 114, 91, 51, 93, 32, 51, 44, 123, 36, 78, 45,
  49, 125, 44, 49, 44, 49, 44, 51, 32, 45, 114, 111, 117, 110, 100, 91,
  51, 93, 10, 45, 114, 91, 53, 93, 32, 49, 44, 123, 104, 45, 49, 125,
  44, 49, 44, 49, 44, 48, 10, 45, 105, 102, 32, 123, 36, 51, 62, 49,
  125, 32, 45, 114, 91, 52, 93, 32, 51, 44, 64, 123, 52, 44, 104, 47,
  51, 125, 44, 49, 44, 49, 44, 45, 49, 32, 45, 114, 91, 52, 93, 32,
  51, 44, 64, 123, 52, 44, 104, 45, 49, 125, 44, 49, 44, 49, 44, 50,
  32, 45, 101, 108, 115, 101, 32, 45, 114, 109, 91, 52, 93, 32, 45, 105,
  91, 52, 93, 32, 51, 44, 123, 36, 78, 45, 49, 125, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 121, 32, 45, 97, 32, 121, 32, 45, 101, 110, 100,
  108, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 49, 93, 32, 91,
  48, 93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 123, 105, 102,
  40, 36, 51, 62, 49, 44, 36, 51, 45, 49, 44, 36, 51, 41, 125, 44,
  50, 44, 48, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109,
  91, 48, 93, 10, 45, 105, 102, 32, 36, 53, 32, 45, 114, 91, 45, 49,
  93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 49, 44, 49, 48, 48, 37,
  44, 50, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 54,
  10, 120, 99, 61, 123, 48, 46, 53, 42, 40, 36, 120, 109, 43, 36, 120,
  77, 41, 125, 32, 121, 99, 61, 123, 48, 46, 53, 42, 40, 36, 121, 109,
  43, 36, 121, 77, 41, 125, 32, 100, 120, 61, 123, 48, 46, 53, 42, 40,
  36, 120, 77, 45, 36, 120, 109, 41, 47, 48, 46, 57, 54, 125, 32, 100,
  121, 61, 123, 48, 46, 53, 42, 40, 36, 121, 77, 45, 36, 121, 109, 41,
  47, 48, 46, 57, 54, 125, 10, 120, 109, 61, 123, 36, 120, 99, 45, 36,
  100, 120, 125, 32, 120, 77, 61, 123, 36, 120, 99, 43, 36, 100, 120, 125,
  32, 121, 109, 61, 123, 36, 121, 99, 45, 36, 100, 121, 125, 32, 121, 77,
  61, 123, 36, 121, 99, 43, 36, 100, 121, 125, 10, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 32, 45, 97, 120, 101, 115, 91, 45, 49, 93, 32, 36,
  120, 109, 44, 36, 120, 77, 44, 36, 121, 77, 44, 36, 121, 109, 44, 49,
  51, 44, 49, 44, 49, 10, 45, 105, 102, 32, 123, 36, 120, 109, 62, 48,
  125, 32, 45, 97, 120, 101, 115, 91, 45, 49, 93, 32, 48, 44, 48, 44,
  36, 121, 77, 44, 36, 121, 109, 44, 49, 51, 44, 49, 44, 49, 54, 48,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 120, 77,
  60, 48, 125, 32, 45, 97, 120, 101, 115, 91, 45, 49, 93, 32, 123, 119,
  45, 49, 125, 44, 123, 119, 45, 49, 125, 44, 36, 121, 77, 44, 36, 121,
  109, 44, 49, 51, 44, 49, 44, 49, 54, 48, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 121, 109, 62, 48, 125, 32, 45, 97,
  120, 101, 115, 91, 45, 49, 93, 32, 36, 120, 109, 44, 36, 120, 77, 44,
  123, 104, 45, 49, 125, 44, 123, 104, 45, 49, 125, 44, 49, 51, 44, 49,
  44, 49, 54, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 121, 77, 60, 48, 125, 32, 45, 97, 120, 101, 115, 91, 45, 49,
  93, 32, 36, 120, 109, 44, 36, 120, 77, 44, 48, 44, 48, 44, 49, 51,
  44, 49, 44, 49, 54, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45,
  100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51, 32, 45, 45, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 42, 91, 45, 49, 93, 32,
  50, 48, 48, 32, 45, 101, 113, 91, 45, 50, 93, 32, 48, 10, 45, 42,
  91, 45, 51, 44, 45, 50, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45,
  102, 114, 97, 109, 101, 32, 49, 44, 49, 44, 49, 50, 56, 32, 45, 102,
  114, 97, 109, 101, 32, 49, 53, 44, 49, 53, 44, 50, 50, 48, 10, 48,
  32, 45, 116, 91, 45, 49, 93, 32, 34, 36, 55, 34, 44, 48, 44, 48,
  44, 49, 51, 44, 49, 44, 45, 50, 50, 48, 44, 45, 50, 50, 48, 44,
  45, 50, 50, 48, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  44, 123, 40, 64, 123, 45, 50, 44, 119, 125, 45, 119, 41, 47, 50, 125,
  44, 123, 64, 123, 45, 50, 44, 104, 125, 45, 49, 54, 125, 44, 48, 44,
  48, 44, 45, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 48, 32, 45,
  116, 91, 45, 49, 93, 32, 34, 36, 56, 34, 44, 48, 44, 48, 44, 49,
  51, 44, 49, 44, 45, 50, 50, 48, 44, 45, 50, 50, 48, 44, 45, 50,
  50, 48, 32, 45, 114, 111, 116, 97, 116, 101, 91, 45, 49, 93, 32, 45,
  57, 48, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 50,
  44, 123, 40, 64, 123, 45, 50, 44, 104, 125, 45, 104, 41, 47, 50, 125,
  44, 48, 44, 48, 44, 45, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 110, 109, 91, 45, 49, 93, 32, 36,
  110, 109, 44, 49, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 100, 112, 32,
  58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 100, 105, 115, 112, 108,
  97, 121, 95, 112, 111, 108, 97, 114, 39, 46, 10, 100, 112, 32, 58, 10,
  45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118,
  32, 43, 10, 45, 95, 100, 105, 115, 112, 108, 97, 121, 95, 112, 111, 108,
  97, 114, 32, 36, 42, 10, 35, 64, 103, 109, 105, 99, 32, 100, 105, 115,
  112, 108, 97, 121, 95, 112, 111, 108, 97, 114, 32, 58, 32, 95, 119, 105,
  100, 116, 104, 62, 51, 50, 44, 95, 104, 101, 105, 103, 104, 116, 62, 51,
  50, 44, 95, 111, 117, 116, 108, 105, 110, 101, 95, 116, 121, 112, 101, 44,
  95, 102, 105, 108, 108, 95, 82, 44, 95, 102, 105, 108, 108, 95, 71, 44,
  95, 102, 105, 108, 108, 95, 66, 44, 95, 116, 104, 101, 116, 97, 95, 115,
  116, 97, 114, 116, 44, 95, 116, 104, 101, 116, 97, 95, 101, 110, 100, 44,
  95, 120, 108, 97, 98, 101, 108, 44, 95, 121, 108, 97, 98, 101, 108, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 110, 100, 101, 114, 32,
  112, 111, 108, 97, 114, 32, 99, 117, 114, 118, 101, 32, 102, 114, 111, 109,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 32,
  100, 97, 116, 97, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40,
  101, 113, 46, 32, 116, 111, 32, 39, 45, 100, 112, 39, 41, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 39, 111, 117, 116, 108, 105, 110, 101,
  95, 116, 121, 112, 101, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32,
  114, 60, 48, 61, 100, 111, 116, 115, 32, 119, 105, 116, 104, 32, 114, 97,
  100, 105, 117, 115, 32, 45, 114, 32, 124, 32, 48, 61, 110, 111, 32, 111,
  117, 116, 108, 105, 110, 101, 32, 124, 32, 114, 62, 48, 61, 108, 105, 110,
  101, 115, 43, 100, 111, 116, 115, 32, 119, 105, 116, 104, 32, 114, 97, 100,
  105, 117, 115, 32, 114, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 39, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 39, 32, 99,
  97, 110, 32, 98, 101, 32, 123, 32, 45, 49, 61, 110, 111, 32, 102, 105,
  108, 108, 32, 124, 32, 82, 44, 71, 44, 66, 61, 102, 105, 108, 108, 32,
  119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 99,
  111, 108, 111, 114, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58,
  32, 39, 119, 105, 100, 116, 104, 61, 53, 48, 48, 39, 44, 32, 39, 104,
  101, 105, 103, 104, 116, 61, 119, 105, 100, 116, 104, 39, 44, 32, 39, 111,
  117, 116, 108, 105, 110, 101, 95, 116, 121, 112, 101, 61, 49, 39, 44, 32,
  39, 102, 105, 108, 108, 95, 82, 61, 102, 105, 108, 108, 95, 71, 61, 102,
  105, 108, 108, 95, 66, 61, 50, 48, 48, 39, 44, 32, 39, 116, 104, 101,
  116, 97, 95, 115, 116, 97, 114, 116, 61, 48, 39, 44, 32, 39, 116, 104,
  101, 116, 97, 95, 101, 110, 100, 61, 51, 54, 48, 39, 44, 32, 39, 120,
  108, 97, 98, 101, 108, 61, 34, 120, 45, 97, 120, 105, 115, 34, 39, 32,
  97, 110, 100, 32, 39, 121, 108, 97, 98, 101, 108, 61, 34, 121, 45, 97,
  120, 105, 115, 34, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 51, 48, 48, 44, 49, 44, 49, 44, 49, 44, 39, 48, 46, 51,
  43, 97, 98, 115, 40, 99, 111, 115, 40, 49, 48, 42, 112, 105, 42, 120,
  47, 119, 41, 41, 43, 63, 40, 48, 46, 52, 41, 39, 32, 45, 100, 105,
  115, 112, 108, 97, 121, 95, 112, 111, 108, 97, 114, 32, 53, 49, 50, 44,
  53, 49, 50, 44, 52, 44, 50, 48, 48, 44, 50, 53, 53, 44, 50, 48,
  48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 51, 48, 48,
  48, 44, 49, 44, 49, 44, 49, 44, 39, 120, 94, 51, 47, 49, 101, 49,
  48, 39, 32, 45, 100, 105, 115, 112, 108, 97, 121, 95, 112, 111, 108, 97,
  114, 32, 52, 48, 48, 44, 52, 48, 48, 44, 49, 44, 45, 49, 44, 44,
  44, 48, 44, 123, 49, 53, 42, 51, 54, 48, 125, 10, 100, 105, 115, 112,
  108, 97, 121, 95, 112, 111, 108, 97, 114, 32, 58, 10, 45, 118, 32, 45,
  32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45,
  95, 36, 48, 32, 36, 42, 10, 95, 100, 105, 115, 112, 108, 97, 121, 95,
  112, 111, 108, 97, 114, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  36, 123, 49, 61, 53, 48, 48, 125, 62, 51, 50, 32, 38, 38, 32, 36,
  123, 50, 61, 36, 49, 125, 62, 51, 50, 34, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 51, 61, 49, 125, 44, 36, 123, 52, 61, 50, 48, 48, 125,
  44, 36, 123, 53, 61, 36, 52, 125, 44, 36, 123, 54, 61, 36, 53, 125,
  44, 36, 123, 55, 61, 48, 125, 44, 36, 123, 56, 61, 51, 54, 48, 125,
  44, 34, 36, 123, 57, 61, 120, 45, 97, 120, 105, 115, 125, 34, 44, 34,
  36, 123, 49, 48, 61, 121, 45, 97, 120, 105, 115, 125, 34, 10, 45, 101,
  91, 48, 45, 45, 51, 93, 32, 34, 82, 101, 110, 100, 101, 114, 32, 36,
  49, 120, 36, 50, 32, 112, 111, 108, 97, 114, 32, 103, 114, 97, 112, 104,
  32, 112, 108, 111, 116, 32, 102, 114, 111, 109, 32, 100, 97, 116, 97, 32,
  111, 102, 32, 105, 109, 97, 103, 101, 34, 36, 95, 95, 115, 34, 44, 32,
  119, 105, 116, 104, 32, 111, 117, 116, 108, 105, 110, 101, 32, 36, 52, 32,
  97, 110, 100, 32, 102, 105, 108, 108, 32, 99, 111, 108, 111, 114, 32, 40,
  36, 52, 44, 36, 53, 44, 36, 54, 41, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 77, 61, 123,
  109, 97, 120, 40, 97, 98, 115, 40, 105, 77, 41, 44, 97, 98, 115, 40,
  105, 109, 41, 41, 125, 10, 45, 42, 32, 123, 48, 46, 52, 56, 42, 109,
  105, 110, 40, 36, 49, 44, 36, 50, 41, 47, 36, 77, 125, 10, 45, 121,
  32, 40, 123, 36, 55, 42, 112, 105, 47, 49, 56, 48, 125, 59, 123, 45,
  36, 56, 42, 112, 105, 47, 49, 56, 48, 125, 41, 32, 45, 114, 91, 45,
  49, 93, 32, 49, 44, 91, 45, 50, 93, 44, 49, 44, 49, 44, 51, 10,
  45, 45, 115, 105, 110, 91, 45, 49, 93, 32, 45, 99, 111, 115, 91, 45,
  50, 93, 32, 45, 42, 91, 45, 49, 93, 32, 91, 45, 51, 93, 32, 45,
  42, 91, 45, 51, 44, 45, 50, 93, 10, 45, 97, 91, 45, 50, 44, 45,
  49, 93, 32, 120, 32, 78, 61, 123, 104, 125, 10, 45, 110, 109, 91, 45,
  49, 93, 32, 99, 111, 111, 114, 100, 115, 10, 45, 105, 102, 32, 36, 51,
  10, 40, 123, 39, 67, 73, 109, 103, 51, 100, 39, 125, 41, 32, 45, 43,
  91, 45, 49, 93, 32, 48, 46, 53, 32, 40, 36, 78, 44, 36, 78, 41,
  10, 45, 45, 122, 91, 99, 111, 111, 114, 100, 115, 93, 32, 48, 44, 50,
  10, 49, 44, 36, 78, 44, 49, 44, 49, 44, 50, 32, 49, 44, 36, 78,
  44, 49, 44, 49, 44, 39, 121, 39, 32, 45, 45, 43, 91, 45, 49, 93,
  32, 49, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 120, 32, 45,
  61, 91, 45, 49, 93, 32, 48, 44, 50, 44, 49, 48, 48, 37, 10, 51,
  44, 36, 78, 44, 49, 44, 49, 44, 48, 32, 49, 44, 36, 78, 44, 49,
  44, 49, 44, 49, 32, 45, 121, 91, 45, 54, 45, 45, 49, 93, 32, 45,
  97, 91, 45, 54, 45, 45, 49, 93, 32, 121, 10, 45, 110, 109, 91, 45,
  49, 93, 32, 95, 112, 108, 111, 116, 95, 112, 111, 108, 97, 114, 95, 111,
  117, 116, 108, 105, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 34, 36, 52, 62, 61, 48, 32, 38, 38, 32, 36, 53, 62,
  61, 48, 32, 38, 38, 32, 36, 54, 62, 61, 48, 34, 125, 10, 40, 123,
  39, 67, 73, 109, 103, 51, 100, 39, 125, 41, 32, 45, 43, 91, 45, 49,
  93, 32, 48, 46, 53, 32, 40, 123, 36, 78, 43, 49, 125, 44, 36, 78,
  41, 10, 45, 45, 122, 91, 99, 111, 111, 114, 100, 115, 93, 32, 48, 44,
  45, 49, 44, 50, 44, 49, 48, 48, 37, 32, 45, 122, 91, 45, 49, 93,
  32, 48, 44, 50, 10, 49, 44, 36, 78, 44, 49, 44, 49, 44, 51, 32,
  49, 44, 36, 78, 32, 49, 44, 36, 78, 44, 49, 44, 49, 44, 39, 49,
  43, 121, 39, 32, 45, 45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 97,
  91, 45, 52, 45, 45, 49, 93, 32, 120, 32, 45, 61, 91, 45, 49, 93,
  32, 49, 44, 51, 44, 49, 48, 48, 37, 10, 51, 44, 36, 78, 44, 49,
  44, 49, 44, 36, 52, 44, 36, 53, 44, 36, 54, 32, 49, 44, 36, 78,
  44, 49, 44, 49, 44, 49, 10, 45, 121, 91, 45, 54, 45, 45, 49, 93,
  32, 45, 97, 91, 45, 54, 45, 45, 49, 93, 32, 121, 10, 45, 110, 109,
  91, 45, 49, 93, 32, 95, 112, 108, 111, 116, 95, 112, 111, 108, 97, 114,
  95, 102, 105, 108, 108, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109,
  91, 99, 111, 111, 114, 100, 115, 93, 10, 123, 36, 49, 45, 51, 50, 125,
  44, 123, 36, 50, 45, 51, 50, 125, 44, 49, 44, 51, 44, 50, 53, 53,
  10, 76, 61, 123, 48, 46, 49, 42, 109, 97, 120, 40, 36, 49, 44, 36,
  50, 41, 125, 32, 45, 103, 114, 105, 100, 91, 45, 49, 93, 32, 36, 76,
  44, 36, 76, 44, 48, 44, 48, 44, 48, 46, 50, 53, 44, 48, 120, 67,
  67, 67, 67, 67, 67, 67, 67, 44, 48, 10, 45, 105, 102, 32, 123, 34,
  36, 52, 62, 61, 48, 32, 38, 38, 32, 36, 53, 62, 61, 48, 32, 38,
  38, 32, 36, 54, 62, 61, 48, 34, 125, 10, 45, 111, 98, 106, 101, 99,
  116, 51, 100, 91, 45, 49, 93, 32, 91, 95, 112, 108, 111, 116, 95, 112,
  111, 108, 97, 114, 95, 102, 105, 108, 108, 93, 44, 53, 48, 37, 44, 53,
  48, 37, 44, 48, 44, 49, 44, 50, 44, 49, 44, 48, 10, 45, 114, 109,
  91, 95, 112, 108, 111, 116, 95, 112, 111, 108, 97, 114, 95, 102, 105, 108,
  108, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 51,
  10, 45, 105, 102, 32, 123, 36, 51, 62, 61, 48, 125, 10, 45, 111, 98,
  106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 95, 112, 108, 111,
  116, 95, 112, 111, 108, 97, 114, 95, 111, 117, 116, 108, 105, 110, 101, 93,
  44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 49, 44, 49, 44, 48,
  44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  51, 33, 61, 48, 125, 10, 45, 105, 102, 32, 123, 97, 98, 115, 40, 36,
  51, 41, 62, 49, 125, 32, 45, 99, 105, 114, 99, 108, 101, 115, 51, 100,
  91, 95, 112, 108, 111, 116, 95, 112, 111, 108, 97, 114, 95, 111, 117, 116,
  108, 105, 110, 101, 93, 32, 123, 97, 98, 115, 40, 36, 51, 41, 125, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 111, 98, 106, 101, 99, 116, 51, 100,
  91, 45, 49, 93, 32, 91, 95, 112, 108, 111, 116, 95, 112, 111, 108, 97,
  114, 95, 111, 117, 116, 108, 105, 110, 101, 93, 44, 53, 48, 37, 44, 53,
  48, 37, 44, 48, 44, 48, 46, 50, 44, 50, 44, 48, 44, 48, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 95, 112, 108, 111, 116, 95,
  112, 111, 108, 97, 114, 95, 111, 117, 116, 108, 105, 110, 101, 93, 10, 45,
  101, 110, 100, 105, 102, 10, 110, 77, 61, 123, 36, 77, 47, 48, 46, 57,
  54, 125, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 97, 120,
  101, 115, 91, 45, 49, 93, 32, 123, 45, 36, 110, 77, 125, 44, 36, 110,
  77, 44, 36, 110, 77, 44, 123, 45, 36, 110, 77, 125, 44, 49, 51, 44,
  49, 44, 49, 10, 45, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93,
  32, 51, 32, 45, 45, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45,
  42, 91, 45, 49, 93, 32, 50, 48, 48, 32, 45, 101, 113, 91, 45, 50,
  93, 32, 48, 10, 45, 42, 91, 45, 51, 44, 45, 50, 93, 32, 45, 43,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 99, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 10, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93, 32,
  49, 44, 49, 44, 49, 50, 56, 32, 45, 102, 114, 97, 109, 101, 91, 45,
  49, 93, 32, 49, 53, 44, 49, 53, 44, 50, 50, 48, 10, 48, 32, 45,
  116, 91, 45, 49, 93, 32, 34, 36, 57, 34, 44, 48, 44, 48, 44, 49,
  51, 44, 49, 44, 45, 50, 50, 48, 44, 45, 50, 50, 48, 44, 45, 50,
  50, 48, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 123,
  40, 64, 123, 45, 50, 44, 119, 125, 45, 119, 41, 47, 50, 125, 44, 123,
  64, 123, 45, 50, 44, 104, 125, 45, 49, 54, 125, 44, 48, 44, 48, 44,
  45, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 48, 32, 45, 116, 91,
  45, 49, 93, 32, 34, 36, 49, 48, 34, 44, 48, 44, 48, 44, 49, 51,
  44, 49, 44, 45, 50, 50, 48, 44, 45, 50, 50, 48, 44, 45, 50, 50,
  48, 32, 45, 114, 111, 116, 97, 116, 101, 91, 45, 49, 93, 32, 45, 57,
  48, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 50, 44,
  123, 40, 64, 123, 45, 50, 44, 104, 125, 45, 104, 41, 47, 50, 125, 44,
  48, 44, 48, 44, 45, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 100, 114, 103, 98, 97, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32,
  39, 45, 100, 105, 115, 112, 108, 97, 121, 95, 114, 103, 98, 97, 39, 46,
  10, 100, 114, 103, 98, 97, 32, 58, 10, 45, 95, 100, 105, 115, 112, 108,
  97, 121, 95, 114, 103, 98, 97, 10, 35, 64, 103, 109, 105, 99, 32, 100,
  105, 115, 112, 108, 97, 121, 95, 114, 103, 98, 97, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 82, 101, 110, 100, 101, 114, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 82, 71, 66, 65, 32, 105, 109, 97, 103, 101, 115,
  32, 111, 118, 101, 114, 32, 97, 32, 99, 104, 101, 99, 107, 101, 114, 98,
  111, 97, 114, 100, 32, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116,
  111, 32, 39, 45, 100, 114, 103, 98, 97, 39, 41, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 45, 110, 111, 114, 109, 32, 45, 116, 104, 114, 101, 115, 104,
  111, 108, 100, 91, 45, 49, 93, 32, 52, 48, 37, 32, 45, 98, 108, 117,
  114, 91, 45, 49, 93, 32, 51, 32, 45, 110, 111, 114, 109, 97, 108, 105,
  122, 101, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 97, 112,
  112, 101, 110, 100, 32, 99, 32, 45, 100, 105, 115, 112, 108, 97, 121, 95,
  114, 103, 98, 97, 10, 100, 105, 115, 112, 108, 97, 121, 95, 114, 103, 98,
  97, 32, 58, 10, 45, 95, 36, 48, 10, 95, 100, 105, 115, 112, 108, 97,
  121, 95, 114, 103, 98, 97, 32, 58, 10, 45, 101, 91, 48, 45, 45, 51,
  93, 32, 34, 82, 101, 110, 100, 101, 114, 32, 82, 71, 66, 65, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 111, 118, 101, 114, 32, 97, 32, 99, 104,
  101, 99, 107, 101, 114, 98, 111, 97, 114, 100, 32, 98, 97, 99, 107, 103,
  114, 111, 117, 110, 100, 46, 34, 10, 45, 118, 32, 45, 32, 45, 116, 111,
  95, 97, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 105, 91, 48, 93, 32, 40, 49, 54, 48, 44,
  49, 50, 56, 59, 49, 50, 56, 44, 49, 54, 48, 41, 32, 45, 110, 109,
  91, 48, 93, 32, 64, 123, 49, 44, 110, 125, 32, 45, 114, 91, 48, 93,
  32, 49, 54, 44, 49, 54, 32, 45, 114, 91, 48, 93, 32, 91, 49, 93,
  44, 91, 49, 93, 44, 49, 44, 123, 115, 45, 49, 125, 44, 48, 44, 50,
  32, 45, 98, 108, 101, 110, 100, 32, 97, 108, 112, 104, 97, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 100, 116, 32, 58, 32, 101, 113, 46, 32, 116,
  111, 32, 39, 45, 100, 105, 115, 112, 108, 97, 121, 95, 116, 101, 110, 115,
  111, 114, 115, 39, 46, 10, 100, 116, 32, 58, 10, 45, 118, 32, 45, 32,
  95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95,
  100, 105, 115, 112, 108, 97, 121, 95, 116, 101, 110, 115, 111, 114, 115, 32,
  36, 42, 10, 35, 64, 103, 109, 105, 99, 32, 100, 105, 115, 112, 108, 97,
  121, 95, 116, 101, 110, 115, 111, 114, 115, 32, 58, 32, 95, 115, 105, 122,
  101, 95, 102, 97, 99, 116, 111, 114, 62, 48, 44, 95, 101, 108, 108, 105,
  112, 115, 101, 95, 102, 97, 99, 116, 111, 114, 62, 61, 48, 44, 95, 99,
  111, 108, 111, 114, 101, 100, 95, 109, 111, 100, 101, 61, 123, 32, 48, 32,
  124, 32, 49, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82,
  101, 110, 100, 101, 114, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 109,
  97, 115, 107, 32, 102, 105, 101, 108, 100, 32, 111, 102, 32, 50, 120, 50,
  32, 116, 101, 110, 115, 111, 114, 115, 32, 119, 105, 116, 104, 32, 101, 108,
  108, 105, 112, 115, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 100, 116, 39, 41, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108,
  116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 115, 105, 122, 101, 95,
  102, 97, 99, 116, 111, 114, 61, 49, 54, 39, 44, 32, 39, 101, 108, 108,
  105, 112, 115, 101, 95, 102, 97, 99, 116, 111, 114, 61, 48, 46, 57, 50,
  39, 44, 32, 39, 99, 111, 108, 111, 114, 95, 109, 111, 100, 101, 61, 49,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 100, 105, 102, 102, 117, 115, 105,
  111, 110, 116, 101, 110, 115, 111, 114, 115, 32, 48, 46, 55, 44, 48, 46,
  54, 32, 45, 99, 114, 111, 112, 32, 54, 48, 44, 49, 48, 44, 57, 48,
  44, 51, 48, 32, 45, 45, 100, 105, 115, 112, 108, 97, 121, 95, 116, 101,
  110, 115, 111, 114, 115, 32, 44, 10, 100, 105, 115, 112, 108, 97, 121, 95,
  116, 101, 110, 115, 111, 114, 115, 32, 58, 10, 45, 118, 32, 45, 32, 95,
  95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 36,
  48, 32, 36, 42, 10, 95, 100, 105, 115, 112, 108, 97, 121, 95, 116, 101,
  110, 115, 111, 114, 115, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  36, 123, 49, 61, 49, 54, 125, 62, 48, 32, 38, 38, 32, 36, 123, 50,
  61, 48, 46, 57, 50, 125, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112,
  32, 34, 36, 123, 51, 61, 49, 125, 34, 10, 45, 101, 91, 48, 45, 45,
  51, 93, 32, 34, 82, 101, 110, 100, 101, 114, 32, 102, 105, 101, 108, 100,
  32, 111, 102, 32, 50, 120, 50, 32, 116, 101, 110, 115, 111, 114, 115, 32,
  102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 34, 36, 95, 95, 115, 34,
  44, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101, 32, 102, 97, 99, 116,
  111, 114, 32, 36, 49, 44, 32, 101, 108, 108, 105, 112, 115, 101, 32, 102,
  97, 99, 116, 111, 114, 32, 36, 50, 32, 105, 110, 32, 34, 64, 123, 45,
  97, 114, 103, 92, 32, 49, 43, 33, 36, 51, 44, 99, 111, 108, 111, 114,
  101, 100, 44, 109, 97, 115, 107, 101, 100, 125, 34, 32, 109, 111, 100, 101,
  46, 34, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 123, 36, 51, 125,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 45, 45, 95, 100, 105, 115, 112, 108, 97, 121, 95, 116, 101,
  110, 115, 111, 114, 115, 32, 36, 49, 44, 36, 50, 44, 48, 10, 45, 115,
  91, 48, 93, 32, 99, 32, 45, 45, 109, 105, 110, 91, 48, 44, 50, 93,
  32, 45, 42, 91, 49, 93, 32, 45, 49, 32, 45, 43, 91, 49, 44, 45,
  49, 93, 32, 45, 97, 91, 48, 45, 50, 93, 32, 99, 10, 45, 114, 91,
  48, 93, 32, 91, 45, 49, 93, 44, 91, 45, 49, 93, 32, 45, 110, 91,
  48, 93, 32, 48, 44, 50, 53, 53, 32, 45, 42, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 101, 108, 115, 101, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 10, 45, 42, 32, 123,
  40, 36, 50, 42, 36, 49, 47, 50, 41, 94, 50, 47, 109, 97, 120, 40,
  97, 98, 115, 40, 105, 109, 41, 44, 97, 98, 115, 40, 105, 77, 41, 41,
  125, 10, 45, 115, 32, 99, 32, 45, 105, 91, 45, 50, 93, 32, 91, 45,
  50, 93, 32, 45, 97, 32, 99, 32, 45, 115, 32, 121, 120, 32, 45, 114,
  32, 50, 44, 50, 44, 49, 44, 49, 44, 45, 49, 10, 40, 48, 46, 53,
  44, 48, 59, 48, 44, 48, 46, 53, 41, 32, 45, 43, 91, 94, 45, 49,
  93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  105, 110, 118, 101, 114, 116, 32, 45, 121, 32, 99, 32, 45, 114, 32, 36,
  49, 44, 36, 49, 10, 36, 49, 44, 36, 49, 44, 49, 44, 49, 44, 39,
  120, 39, 32, 45, 45, 91, 45, 49, 93, 32, 123, 119, 47, 50, 125, 10,
  36, 49, 44, 36, 49, 44, 49, 44, 49, 44, 39, 121, 39, 32, 45, 45,
  91, 45, 49, 93, 32, 123, 104, 47, 50, 125, 10, 45, 45, 115, 113, 114,
  91, 45, 49, 93, 32, 45, 42, 91, 45, 50, 93, 32, 91, 45, 51, 93,
  32, 45, 115, 113, 114, 91, 45, 51, 93, 32, 45, 105, 91, 45, 50, 93,
  32, 91, 45, 50, 93, 32, 45, 97, 91, 45, 52, 45, 45, 49, 93, 32,
  99, 10, 45, 42, 91, 94, 45, 49, 93, 32, 91, 45, 49, 93, 32, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 43, 32, 45, 108, 101, 32, 49,
  10, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 32, 36,
  119, 44, 36, 104, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 100, 119, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32,
  39, 45, 100, 105, 115, 112, 108, 97, 121, 95, 119, 97, 114, 112, 39, 46,
  10, 100, 119, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34,
  36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 100, 105, 115, 112, 108,
  97, 121, 95, 119, 97, 114, 112, 32, 36, 42, 10, 35, 64, 103, 109, 105,
  99, 32, 100, 105, 115, 112, 108, 97, 121, 95, 119, 97, 114, 112, 32, 58,
  32, 95, 99, 101, 108, 108, 95, 115, 105, 122, 101, 62, 48, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 82, 101, 110, 100, 101, 114, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 50, 100, 32, 119, 97, 114, 112, 105, 110,
  103, 32, 102, 105, 101, 108, 100, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 100, 119, 39,
  41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 99, 101, 108, 108,
  95, 115, 105, 122, 101, 61, 49, 53, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 98, 108, 117, 114,
  32, 53, 32, 45, 103, 114, 97, 100, 105, 101, 110, 116, 32, 45, 97, 112,
  112, 101, 110, 100, 32, 99, 32, 45, 100, 105, 115, 112, 108, 97, 121, 95,
  119, 97, 114, 112, 32, 44, 10, 100, 105, 115, 112, 108, 97, 121, 95, 119,
  97, 114, 112, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34,
  36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 36, 48, 32, 36, 42,
  10, 95, 100, 105, 115, 112, 108, 97, 121, 95, 119, 97, 114, 112, 32, 58,
  32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 49, 53, 125,
  62, 48, 34, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 82, 101,
  110, 100, 101, 114, 32, 50, 100, 32, 119, 97, 114, 112, 105, 110, 103, 32,
  102, 105, 101, 108, 100, 34, 36, 95, 95, 115, 34, 44, 32, 119, 105, 116,
  104, 32, 99, 101, 108, 108, 32, 115, 105, 122, 101, 32, 36, 49, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 100, 33, 61,
  49, 124, 124, 115, 33, 61, 50, 125, 10, 45, 101, 114, 114, 111, 114, 91,
  48, 45, 45, 51, 93, 32, 34, 73, 110, 118, 97, 108, 105, 100, 32, 105,
  109, 97, 103, 101, 32, 91, 34, 123, 64, 35, 45, 36, 62, 45, 49, 125,
  34, 93, 58, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110, 115, 32, 34,
  123, 119, 125, 34, 44, 34, 123, 104, 125, 34, 44, 34, 123, 100, 125, 34,
  44, 34, 123, 115, 125, 34, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32,
  114, 101, 112, 114, 101, 115, 101, 110, 116, 32, 97, 32, 50, 100, 32, 102,
  105, 101, 108, 100, 32, 111, 102, 32, 50, 100, 32, 118, 101, 99, 116, 111,
  114, 115, 46, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 91, 48,
  93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44,
  49, 32, 45, 103, 114, 105, 100, 91, 48, 93, 32, 36, 49, 44, 36, 49,
  32, 45, 110, 109, 91, 48, 93, 32, 64, 123, 49, 44, 110, 125, 10, 45,
  119, 97, 114, 112, 91, 48, 93, 32, 91, 49, 93, 44, 49, 44, 49, 44,
  48, 32, 45, 114, 109, 91, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 42, 32, 50, 53, 53, 32, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 100, 111, 99, 117, 109, 101, 110, 116,
  95, 103, 109, 105, 99, 32, 58, 32, 95, 102, 111, 114, 109, 97, 116, 61,
  123, 32, 97, 115, 99, 105, 105, 32, 124, 32, 104, 116, 109, 108, 32, 124,
  32, 108, 97, 116, 101, 120, 32, 124, 32, 120, 109, 108, 32, 124, 32, 98,
  97, 115, 104, 32, 124, 32, 105, 109, 97, 103, 101, 115, 32, 125, 44, 95,
  105, 109, 97, 103, 101, 95, 112, 97, 116, 104, 44, 95, 119, 114, 105, 116,
  101, 95, 119, 114, 97, 112, 112, 101, 114, 61, 123, 32, 48, 32, 124, 32,
  49, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 114, 101,
  97, 116, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 97, 116, 105, 111,
  110, 32, 111, 102, 32, 46, 103, 109, 105, 99, 32, 99, 111, 109, 109, 97,
  110, 100, 32, 102, 105, 108, 101, 115, 32, 40, 108, 111, 97, 100, 101, 100,
  32, 97, 115, 32, 114, 97, 119, 32, 39, 117, 99, 104, 97, 114, 39, 32,
  105, 109, 97, 103, 101, 115, 41, 44, 32, 105, 110, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 102, 111, 114, 109, 97, 116, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 102, 111, 114, 109, 97, 116, 61, 97,
  115, 99, 105, 105, 39, 44, 32, 39, 105, 109, 97, 103, 101, 95, 112, 97,
  116, 104, 61, 34, 34, 39, 32, 97, 110, 100, 32, 39, 119, 114, 105, 116,
  101, 95, 119, 114, 97, 112, 112, 101, 114, 61, 49, 39, 46, 92, 110, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 69, 120, 97, 109, 112, 108, 101,
  40, 115, 41, 32, 58, 32, 114, 97, 119, 58, 102, 105, 108, 101, 46, 103,
  109, 105, 99, 44, 117, 99, 104, 97, 114, 32, 45, 100, 111, 99, 117, 109,
  101, 110, 116, 95, 103, 109, 105, 99, 32, 104, 116, 109, 108, 44, 105, 109,
  103, 10, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 34, 97, 115, 99,
  105, 105, 34, 125, 44, 36, 123, 50, 61, 34, 34, 125, 44, 36, 123, 51,
  61, 49, 125, 10, 45, 105, 102, 32, 123, 33, 64, 35, 125, 32, 45, 114,
  101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32,
  45, 49, 10, 95, 110, 97, 109, 101, 61, 64, 123, 48, 44, 98, 125, 10,
  45, 105, 102, 32, 123, 64, 35, 62, 49, 125, 32, 45, 105, 91, 49, 45,
  45, 50, 93, 32, 40, 49, 48, 41, 32, 45, 101, 110, 100, 105, 102, 32,
  45, 97, 32, 121, 32, 45, 109, 32, 64, 123, 45, 49, 44, 116, 125, 32,
  45, 115, 32, 45, 44, 49, 48, 10, 45, 95, 100, 111, 99, 117, 109, 101,
  110, 116, 95, 103, 109, 105, 99, 95, 104, 101, 97, 100, 101, 114, 95, 36,
  49, 91, 93, 32, 36, 51, 10, 95, 115, 117, 98, 115, 101, 99, 116, 105,
  111, 110, 61, 48, 10, 95, 101, 120, 97, 109, 112, 108, 101, 61, 48, 10,
  95, 99, 111, 109, 109, 97, 110, 100, 61, 48, 10, 95, 112, 97, 116, 104,
  61, 34, 36, 50, 34, 10, 107, 115, 48, 61, 34, 48, 34, 32, 107, 115,
  49, 61, 34, 45, 107, 91, 48, 93, 34, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 105, 102, 32,
  123, 104, 62, 55, 34, 32, 38, 38, 32, 34, 123, 64, 123, 45, 49, 44,
  48, 45, 53, 125, 39, 61, 61, 39, 123, 39, 34, 35, 64, 103, 109, 105,
  99, 34, 39, 125, 125, 34, 32, 38, 38, 32, 34, 40, 105, 91, 54, 93,
  61, 61, 123, 39, 34, 32, 34, 39, 125, 34, 32, 124, 124, 32, 34, 105,
  91, 54, 93, 61, 61, 123, 39, 58, 39, 125, 41, 125, 10, 45, 114, 111,
  119, 115, 32, 55, 44, 49, 48, 48, 37, 32, 45, 97, 117, 116, 111, 99,
  114, 111, 112, 32, 123, 39, 34, 32, 34, 39, 125, 10, 45, 105, 102, 32,
  123, 105, 33, 61, 123, 39, 58, 39, 125, 125, 10, 95, 99, 111, 109, 109,
  97, 110, 100, 61, 123, 36, 95, 99, 111, 109, 109, 97, 110, 100, 43, 49,
  125, 10, 45, 115, 32, 45, 44, 123, 39, 34, 58, 32, 34, 39, 125, 32,
  45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 123, 39, 34, 32, 34, 39,
  125, 10, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105,
  99, 95, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 95, 36, 49,
  10, 45, 101, 108, 115, 101, 10, 45, 114, 111, 119, 115, 32, 49, 44, 49,
  48, 48, 37, 10, 45, 105, 102, 32, 123, 105, 61, 61, 123, 39, 58, 39,
  125, 125, 10, 95, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 61, 123,
  36, 95, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 43, 49, 125, 10,
  45, 114, 111, 119, 115, 32, 49, 44, 49, 48, 48, 37, 32, 45, 97, 117,
  116, 111, 99, 114, 111, 112, 32, 123, 39, 34, 32, 34, 39, 125, 10, 45,
  95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 115,
  117, 98, 115, 101, 99, 116, 105, 111, 110, 95, 36, 49, 10, 45, 101, 108,
  115, 101, 10, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 123, 39, 34,
  32, 34, 39, 125, 10, 45, 105, 102, 32, 123, 105, 61, 61, 123, 39, 36,
  39, 125, 125, 10, 95, 101, 120, 97, 109, 112, 108, 101, 61, 123, 36, 95,
  101, 120, 97, 109, 112, 108, 101, 43, 49, 125, 10, 45, 114, 111, 119, 115,
  32, 49, 44, 49, 48, 48, 37, 32, 45, 97, 117, 116, 111, 99, 114, 111,
  112, 32, 123, 39, 34, 32, 34, 39, 125, 10, 95, 102, 105, 108, 101, 110,
  97, 109, 101, 61, 36, 95, 112, 97, 116, 104, 36, 95, 110, 97, 109, 101,
  36, 95, 101, 120, 97, 109, 112, 108, 101, 46, 106, 112, 103, 10, 45, 95,
  100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 101, 120,
  97, 109, 112, 108, 101, 95, 36, 49, 10, 45, 101, 108, 115, 101, 10, 45,
  95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 100,
  101, 115, 99, 114, 105, 112, 116, 105, 111, 110, 95, 36, 49, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 105, 102, 32, 36, 123, 107, 115, 123, 64,
  35, 33, 61, 48, 125, 125, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 45, 114, 109, 10, 45, 95, 100, 111, 99, 117, 109, 101, 110,
  116, 95, 103, 109, 105, 99, 95, 102, 111, 111, 116, 101, 114, 95, 36, 49,
  91, 93, 32, 36, 51, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95,
  103, 109, 105, 99, 95, 104, 101, 97, 100, 101, 114, 95, 104, 116, 109, 108,
  32, 58, 10, 45, 105, 102, 32, 36, 49, 32, 45, 118, 32, 43, 32, 45,
  101, 91, 93, 32, 34, 60, 33, 68, 79, 67, 84, 89, 80, 69, 32, 104,
  116, 109, 108, 32, 80, 85, 66, 76, 73, 67, 32, 92, 34, 45, 47, 47,
  87, 51, 67, 47, 47, 68, 84, 68, 32, 88, 72, 84, 77, 76, 32, 49,
  46, 48, 32, 84, 114, 97, 110, 115, 105, 116, 105, 111, 110, 97, 108, 47,
  47, 69, 78, 92, 34, 32, 92, 34, 104, 116, 116, 112, 58, 47, 47, 119,
  119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 84, 82, 47, 120, 104, 116,
  109, 108, 49, 47, 68, 84, 68, 47, 120, 104, 116, 109, 108, 49, 45, 116,
  114, 97, 110, 115, 105, 116, 105, 111, 110, 97, 108, 46, 100, 116, 100, 92,
  34, 62, 10, 92, 110, 60, 104, 101, 97, 100, 62, 10, 92, 110, 60, 115,
  99, 114, 105, 112, 116, 32, 116, 121, 112, 101, 61, 92, 34, 116, 101, 120,
  116, 47, 106, 97, 118, 97, 115, 99, 114, 105, 112, 116, 92, 34, 32, 115,
  114, 99, 61, 92, 34, 104, 105, 103, 104, 115, 108, 105, 100, 101, 47, 104,
  105, 103, 104, 115, 108, 105, 100, 101, 46, 106, 115, 92, 34, 62, 60, 47,
  115, 99, 114, 105, 112, 116, 62, 10, 92, 110, 60, 108, 105, 110, 107, 32,
  114, 101, 108, 61, 92, 34, 115, 116, 121, 108, 101, 115, 104, 101, 101, 116,
  92, 34, 32, 116, 121, 112, 101, 61, 92, 34, 116, 101, 120, 116, 47, 99,
  115, 115, 92, 34, 32, 104, 114, 101, 102, 61, 92, 34, 104, 105, 103, 104,
  115, 108, 105, 100, 101, 47, 104, 105, 103, 104, 115, 108, 105, 100, 101, 46,
  99, 115, 115, 92, 34, 32, 47, 62, 10, 92, 110, 60, 115, 99, 114, 105,
  112, 116, 32, 116, 121, 112, 101, 61, 92, 34, 116, 101, 120, 116, 47, 106,
  97, 118, 97, 115, 99, 114, 105, 112, 116, 92, 34, 62, 10, 92, 110, 104,
  115, 46, 103, 114, 97, 112, 104, 105, 99, 115, 68, 105, 114, 32, 61, 32,
  39, 104, 105, 103, 104, 115, 108, 105, 100, 101, 47, 103, 114, 97, 112, 104,
  105, 99, 115, 47, 39, 59, 10, 92, 110, 104, 115, 46, 119, 114, 97, 112,
  112, 101, 114, 67, 108, 97, 115, 115, 78, 97, 109, 101, 32, 61, 32, 39,
  119, 105, 100, 101, 45, 98, 111, 114, 100, 101, 114, 39, 59, 10, 92, 110,
  60, 47, 115, 99, 114, 105, 112, 116, 62, 10, 92, 110, 60, 47, 104, 101,
  97, 100, 62, 10, 92, 110, 60, 98, 111, 100, 121, 62, 10, 92, 110, 34,
  10, 45, 118, 32, 45, 32, 45, 101, 110, 100, 105, 102, 10, 45, 109, 32,
  34, 100, 111, 110, 32, 58, 32, 45, 95, 100, 111, 99, 117, 109, 101, 110,
  116, 95, 103, 109, 105, 99, 95, 100, 101, 115, 99, 95, 111, 110, 95, 104,
  116, 109, 108, 34, 10, 45, 109, 32, 34, 100, 111, 102, 102, 32, 58, 32,
  45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95,
  100, 101, 115, 99, 95, 111, 102, 102, 95, 104, 116, 109, 108, 34, 10, 45,
  109, 32, 34, 101, 111, 110, 32, 58, 32, 45, 95, 100, 111, 99, 117, 109,
  101, 110, 116, 95, 103, 109, 105, 99, 95, 101, 120, 95, 111, 110, 95, 104,
  116, 109, 108, 34, 10, 45, 109, 32, 34, 101, 111, 102, 102, 32, 58, 32,
  45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95,
  101, 120, 95, 111, 102, 102, 95, 104, 116, 109, 108, 34, 10, 95, 105, 115,
  95, 100, 101, 115, 99, 61, 48, 10, 95, 105, 115, 95, 101, 120, 61, 48,
  10, 95, 115, 104, 111, 114, 116, 99, 117, 116, 61, 48, 10, 95, 100, 111,
  99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 100, 101, 115, 99,
  95, 111, 110, 95, 104, 116, 109, 108, 32, 58, 10, 45, 118, 32, 45, 10,
  45, 105, 102, 32, 36, 95, 105, 115, 95, 100, 101, 115, 99, 10, 45, 117,
  32, 34, 60, 98, 114, 47, 62, 34, 10, 45, 101, 108, 115, 101, 10, 45,
  117, 32, 34, 60, 112, 32, 115, 116, 121, 108, 101, 61, 92, 34, 109, 97,
  114, 103, 105, 110, 45, 108, 101, 102, 116, 58, 49, 48, 48, 112, 120, 92,
  34, 62, 60, 116, 116, 62, 34, 10, 95, 105, 115, 95, 100, 101, 115, 99,
  61, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 95,
  100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 100, 101,
  115, 99, 95, 111, 102, 102, 95, 104, 116, 109, 108, 32, 58, 10, 45, 118,
  32, 45, 10, 45, 105, 102, 32, 36, 95, 105, 115, 95, 100, 101, 115, 99,
  10, 45, 117, 32, 34, 60, 47, 116, 116, 62, 60, 47, 112, 62, 34, 10,
  95, 105, 115, 95, 100, 101, 115, 99, 61, 48, 10, 45, 101, 108, 115, 101,
  32, 45, 117, 32, 34, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118,
  32, 43, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105,
  99, 95, 101, 120, 95, 111, 110, 95, 104, 116, 109, 108, 32, 58, 10, 45,
  118, 32, 45, 10, 45, 105, 102, 32, 36, 95, 105, 115, 95, 101, 120, 10,
  45, 117, 32, 34, 34, 10, 45, 101, 108, 115, 101, 10, 45, 117, 32, 34,
  60, 98, 114, 47, 62, 60, 116, 97, 98, 108, 101, 32, 115, 116, 121, 108,
  101, 61, 92, 34, 109, 97, 114, 103, 105, 110, 45, 108, 101, 102, 116, 58,
  49, 48, 48, 112, 120, 92, 34, 32, 119, 105, 100, 116, 104, 61, 92, 34,
  55, 53, 37, 92, 34, 32, 98, 103, 99, 111, 108, 111, 114, 61, 92, 34,
  35, 69, 69, 69, 69, 69, 69, 92, 34, 32, 98, 111, 114, 100, 101, 114,
  99, 111, 108, 111, 114, 61, 92, 34, 98, 108, 97, 99, 107, 92, 34, 32,
  98, 111, 114, 100, 101, 114, 61, 92, 34, 49, 92, 34, 32, 99, 101, 108,
  108, 112, 97, 100, 100, 105, 110, 103, 61, 92, 34, 52, 92, 34, 32, 99,
  101, 108, 108, 115, 112, 97, 99, 105, 110, 103, 61, 92, 34, 48, 92, 34,
  62, 34, 92, 10, 34, 60, 116, 114, 62, 60, 116, 100, 32, 99, 111, 108,
  115, 112, 97, 110, 61, 92, 34, 50, 92, 34, 32, 98, 103, 99, 111, 108,
  111, 114, 61, 92, 34, 35, 55, 55, 55, 55, 55, 55, 92, 34, 62, 60,
  102, 111, 110, 116, 32, 99, 111, 108, 111, 114, 61, 92, 34, 119, 104, 105,
  116, 101, 92, 34, 62, 60, 98, 62, 69, 120, 97, 109, 112, 108, 101, 40,
  115, 41, 32, 111, 102, 32, 117, 115, 101, 58, 60, 47, 98, 62, 60, 47,
  102, 111, 110, 116, 62, 60, 47, 116, 100, 62, 60, 47, 116, 114, 62, 34,
  10, 95, 105, 115, 95, 101, 120, 61, 49, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 118, 32, 43, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95,
  103, 109, 105, 99, 95, 101, 120, 95, 111, 102, 102, 95, 104, 116, 109, 108,
  32, 58, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 36, 95, 105, 115,
  95, 101, 120, 10, 45, 117, 32, 34, 60, 47, 116, 97, 98, 108, 101, 62,
  34, 10, 95, 105, 115, 95, 101, 120, 61, 48, 10, 45, 101, 108, 115, 101,
  10, 45, 117, 32, 34, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118,
  32, 43, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105,
  99, 95, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 95, 104, 116, 109,
  108, 32, 58, 10, 45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 64, 123,
  45, 101, 111, 102, 102, 125, 64, 123, 45, 100, 111, 102, 102, 125, 34, 60,
  98, 114, 47, 62, 60, 104, 51, 62, 60, 97, 32, 105, 100, 61, 92, 34,
  115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 34, 36, 95, 115, 117, 98,
  115, 101, 99, 116, 105, 111, 110, 34, 92, 34, 62, 60, 102, 111, 110, 116,
  32, 99, 111, 108, 111, 114, 61, 92, 34, 112, 117, 114, 112, 108, 101, 92,
  34, 62, 42, 42, 32, 60, 117, 62, 34, 64, 123, 48, 44, 116, 125, 34,
  60, 47, 117, 62, 60, 47, 102, 111, 110, 116, 62, 60, 47, 97, 62, 34,
  92, 10, 34, 38, 110, 98, 115, 112, 59, 38, 110, 98, 115, 112, 59, 60,
  97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 116, 111, 99, 92, 34, 62,
  60, 105, 109, 103, 32, 115, 114, 99, 61, 92, 34, 105, 109, 103, 47, 98,
  97, 99, 107, 95, 116, 111, 112, 46, 112, 110, 103, 92, 34, 62, 60, 47,
  105, 109, 103, 62, 60, 47, 97, 62, 60, 47, 104, 51, 62, 34, 10, 45,
  118, 32, 45, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109,
  105, 99, 95, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 95, 104,
  116, 109, 108, 32, 58, 10, 45, 105, 102, 32, 123, 123, 64, 123, 45, 49,
  44, 116, 125, 39, 61, 61, 39, 34, 40, 42, 41, 34, 125, 34, 32, 124,
  124, 32, 34, 123, 64, 123, 45, 49, 44, 116, 125, 39, 61, 61, 39, 34,
  40, 43, 41, 34, 125, 125, 32, 113, 117, 97, 108, 105, 102, 105, 101, 114,
  61, 34, 32, 34, 64, 123, 45, 49, 44, 116, 125, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 101, 108, 115, 101, 32, 113, 117, 97, 108, 105, 102,
  105, 101, 114, 61, 34, 34, 32, 45, 101, 110, 100, 105, 102, 10, 115, 49,
  61, 34, 92, 110, 34, 32, 115, 48, 61, 34, 32, 124, 60, 98, 114, 47,
  62, 34, 10, 45, 105, 102, 32, 123, 64, 35, 62, 49, 34, 32, 38, 38,
  32, 34, 123, 64, 123, 45, 49, 44, 48, 45, 54, 125, 39, 61, 61, 39,
  123, 39, 34, 101, 113, 46, 32, 116, 111, 32, 34, 39, 125, 125, 125, 10,
  45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 55, 44, 49, 48, 48, 37,
  32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 123,
  39, 46, 39, 125, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45,
  49, 93, 32, 123, 39, 34, 32, 34, 39, 125, 32, 45, 97, 117, 116, 111,
  99, 114, 111, 112, 91, 45, 49, 93, 32, 51, 57, 10, 95, 115, 104, 111,
  114, 116, 99, 117, 116, 36, 95, 115, 104, 111, 114, 116, 99, 117, 116, 61,
  64, 123, 48, 44, 116, 125, 10, 95, 115, 104, 111, 114, 116, 99, 117, 116,
  108, 105, 110, 107, 36, 95, 115, 104, 111, 114, 116, 99, 117, 116, 61, 64,
  123, 45, 49, 44, 116, 125, 10, 95, 115, 104, 111, 114, 116, 99, 117, 116,
  113, 117, 97, 108, 105, 102, 105, 101, 114, 36, 95, 115, 104, 111, 114, 116,
  99, 117, 116, 61, 36, 113, 117, 97, 108, 105, 102, 105, 101, 114, 10, 95,
  115, 104, 111, 114, 116, 99, 117, 116, 61, 123, 36, 95, 115, 104, 111, 114,
  116, 99, 117, 116, 43, 49, 125, 10, 45, 101, 108, 115, 101, 10, 45, 118,
  32, 43, 10, 45, 101, 91, 93, 32, 64, 123, 45, 101, 111, 102, 102, 125,
  64, 123, 45, 100, 111, 102, 102, 125, 34, 60, 112, 32, 115, 116, 121, 108,
  101, 61, 92, 34, 109, 97, 114, 103, 105, 110, 45, 108, 101, 102, 116, 58,
  50, 48, 112, 120, 92, 34, 62, 60, 102, 111, 110, 116, 32, 99, 111, 108,
  111, 114, 61, 92, 34, 103, 114, 101, 101, 110, 92, 34, 62, 38, 110, 98,
  115, 112, 59, 38, 110, 98, 115, 112, 59, 60, 98, 62, 45, 34, 64, 123,
  48, 44, 116, 125, 36, 113, 117, 97, 108, 105, 102, 105, 101, 114, 34, 60,
  47, 98, 62, 58, 60, 47, 102, 111, 110, 116, 62, 34, 10, 45, 105, 102,
  32, 123, 64, 35, 62, 49, 125, 10, 45, 101, 91, 93, 32, 34, 60, 112,
  32, 115, 116, 121, 108, 101, 61, 92, 34, 109, 97, 114, 103, 105, 110, 45,
  108, 101, 102, 116, 58, 49, 53, 48, 112, 120, 92, 34, 62, 60, 116, 116,
  62, 60, 105, 62, 60, 102, 111, 110, 116, 32, 99, 111, 108, 111, 114, 61,
  92, 34, 112, 117, 114, 112, 108, 101, 92, 34, 62, 34, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 10, 45, 101, 91, 93,
  32, 64, 123, 123, 49, 43, 36, 62, 125, 44, 116, 125, 36, 123, 115, 123,
  36, 60, 61, 61, 48, 125, 125, 10, 45, 100, 111, 110, 101, 10, 45, 101,
  91, 93, 32, 34, 60, 47, 102, 111, 110, 116, 62, 60, 47, 105, 62, 60,
  47, 116, 116, 62, 60, 47, 112, 62, 34, 10, 45, 101, 108, 115, 101, 32,
  45, 101, 91, 93, 32, 34, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  118, 32, 45, 10, 45, 101, 110, 100, 105, 102, 10, 95, 100, 111, 99, 117,
  109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 100, 101, 115, 99, 114, 105,
  112, 116, 105, 111, 110, 95, 104, 116, 109, 108, 32, 58, 10, 45, 105, 102,
  32, 123, 64, 123, 45, 49, 44, 48, 45, 49, 50, 125, 39, 61, 61, 39,
  123, 39, 34, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  34, 39, 125, 125, 10, 45, 115, 32, 43, 44, 123, 39, 58, 39, 125, 32,
  45, 108, 91, 94, 48, 93, 32, 45, 97, 32, 121, 32, 45, 101, 110, 100,
  108, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 123, 39, 58, 39,
  125, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 123, 39, 34, 32,
  34, 39, 125, 10, 45, 118, 32, 43, 10, 45, 105, 102, 32, 123, 64, 35,
  62, 49, 125, 32, 45, 101, 91, 93, 32, 64, 123, 45, 100, 111, 110, 125,
  34, 60, 98, 114, 47, 62, 60, 98, 62, 34, 64, 123, 48, 44, 116, 125,
  34, 60, 47, 98, 62, 58, 32, 34, 64, 123, 45, 49, 44, 116, 125, 10,
  45, 101, 108, 115, 101, 32, 45, 101, 91, 93, 32, 64, 123, 45, 100, 111,
  110, 125, 34, 60, 98, 114, 47, 62, 34, 64, 123, 48, 44, 116, 125, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 10, 45, 101, 108, 105,
  102, 32, 123, 64, 123, 45, 49, 44, 48, 45, 55, 125, 39, 61, 61, 39,
  123, 39, 34, 40, 101, 113, 46, 32, 116, 111, 32, 34, 39, 125, 125, 10,
  45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 64, 123, 45, 100, 111, 110,
  125, 34, 60, 105, 62, 60, 102, 111, 110, 116, 32, 99, 111, 108, 111, 114,
  61, 92, 34, 98, 108, 117, 101, 92, 34, 62, 34, 64, 123, 45, 49, 44,
  116, 125, 34, 60, 47, 102, 111, 110, 116, 62, 60, 47, 105, 62, 34, 32,
  45, 118, 32, 45, 10, 45, 101, 108, 115, 101, 10, 45, 105, 102, 32, 123,
  40, 105, 60, 123, 39, 65, 39, 125, 34, 32, 124, 124, 32, 34, 105, 62,
  123, 39, 90, 39, 125, 41, 34, 32, 38, 38, 32, 34, 105, 33, 61, 52,
  48, 34, 32, 38, 38, 32, 34, 105, 33, 61, 51, 57, 125, 32, 45, 118,
  32, 43, 32, 45, 101, 91, 93, 32, 64, 123, 45, 100, 111, 110, 125, 34,
  38, 110, 98, 115, 112, 59, 34, 64, 123, 45, 49, 44, 116, 125, 32, 45,
  118, 32, 45, 10, 45, 101, 108, 115, 101, 32, 45, 118, 32, 43, 32, 45,
  101, 91, 93, 32, 64, 123, 45, 100, 111, 110, 125, 64, 123, 45, 49, 44,
  116, 125, 32, 45, 118, 32, 45, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 105, 102, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95,
  103, 109, 105, 99, 95, 101, 120, 97, 109, 112, 108, 101, 95, 104, 116, 109,
  108, 32, 58, 10, 45, 105, 102, 32, 36, 95, 102, 105, 108, 101, 110, 97,
  109, 101, 32, 45, 101, 108, 115, 101, 10, 45, 109, 32, 34, 102, 111, 111,
  32, 58, 32, 34, 64, 123, 45, 49, 44, 116, 125, 10, 45, 108, 91, 93,
  32, 45, 118, 32, 45, 57, 57, 32, 45, 114, 101, 115, 101, 116, 32, 45,
  102, 111, 111, 32, 45, 118, 32, 45, 49, 32, 45, 95, 100, 111, 99, 117,
  109, 101, 110, 116, 95, 103, 109, 105, 99, 32, 45, 111, 32, 36, 95, 102,
  105, 108, 101, 110, 97, 109, 101, 44, 56, 53, 32, 45, 114, 109, 32, 45,
  101, 110, 100, 108, 10, 45, 117, 110, 99, 111, 109, 109, 97, 110, 100, 32,
  102, 111, 111, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10,
  45, 101, 91, 93, 32, 64, 123, 45, 101, 111, 110, 125, 34, 60, 116, 114,
  62, 60, 116, 100, 32, 119, 105, 100, 116, 104, 61, 92, 34, 52, 48, 92,
  34, 62, 60, 100, 105, 118, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92,
  34, 34, 36, 95, 102, 105, 108, 101, 110, 97, 109, 101, 34, 92, 34, 32,
  99, 108, 97, 115, 115, 61, 92, 34, 104, 105, 103, 104, 115, 108, 105, 100,
  101, 92, 34, 32, 111, 110, 99, 108, 105, 99, 107, 61, 92, 34, 114, 101,
  116, 117, 114, 110, 32, 104, 115, 46, 101, 120, 112, 97, 110, 100, 40, 116,
  104, 105, 115, 41, 92, 34, 62, 34, 92, 10, 34, 60, 102, 111, 110, 116,
  32, 99, 111, 108, 111, 114, 61, 92, 34, 98, 108, 117, 101, 92, 34, 62,
  40, 118, 105, 101, 119, 41, 60, 47, 102, 111, 110, 116, 62, 60, 47, 97,
  62, 60, 100, 105, 118, 32, 99, 108, 97, 115, 115, 61, 92, 34, 104, 105,
  103, 104, 115, 108, 105, 100, 101, 45, 99, 97, 112, 116, 105, 111, 110, 92,
  34, 62, 34, 64, 123, 45, 49, 44, 116, 125, 34, 60, 47, 100, 105, 118,
  62, 60, 47, 100, 105, 118, 62, 60, 47, 116, 100, 62, 60, 116, 100, 62,
  60, 116, 116, 62, 34, 64, 123, 45, 49, 44, 116, 125, 34, 60, 47, 116,
  116, 62, 60, 47, 116, 100, 62, 60, 47, 116, 114, 62, 34, 10, 45, 118,
  32, 45, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105,
  99, 95, 102, 111, 111, 116, 101, 114, 95, 104, 116, 109, 108, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 36, 49, 10, 45, 105, 102, 32, 36, 95, 115,
  104, 111, 114, 116, 99, 117, 116, 10, 95, 115, 117, 98, 115, 101, 99, 116,
  105, 111, 110, 61, 123, 36, 95, 115, 117, 98, 115, 101, 99, 116, 105, 111,
  110, 43, 49, 125, 10, 40, 123, 39, 34, 67, 111, 109, 109, 97, 110, 100,
  115, 32, 115, 104, 111, 114, 116, 99, 117, 116, 115, 34, 39, 125, 41, 32,
  45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95,
  115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 95, 104, 116, 109, 108, 91,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 118, 32, 43,
  32, 45, 101, 91, 93, 32, 34, 60, 112, 32, 115, 116, 121, 108, 101, 61,
  92, 34, 109, 97, 114, 103, 105, 110, 45, 108, 101, 102, 116, 58, 50, 48,
  112, 120, 92, 34, 62, 34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36,
  95, 115, 104, 111, 114, 116, 99, 117, 116, 10, 45, 101, 91, 93, 32, 34,
  60, 102, 111, 110, 116, 32, 99, 111, 108, 111, 114, 61, 92, 34, 103, 114,
  101, 101, 110, 92, 34, 62, 60, 98, 62, 38, 110, 98, 115, 112, 59, 38,
  110, 98, 115, 112, 59, 45, 34, 36, 123, 95, 115, 104, 111, 114, 116, 99,
  117, 116, 36, 62, 125, 34, 32, 34, 36, 123, 95, 115, 104, 111, 114, 116,
  99, 117, 116, 113, 117, 97, 108, 105, 102, 105, 101, 114, 36, 62, 125, 34,
  60, 47, 98, 62, 58, 60, 47, 102, 111, 110, 116, 62, 34, 10, 45, 101,
  91, 93, 32, 34, 60, 102, 111, 110, 116, 32, 99, 111, 108, 111, 114, 61,
  92, 34, 98, 108, 117, 101, 92, 34, 62, 60, 105, 62, 101, 113, 46, 32,
  116, 111, 32, 39, 34, 36, 123, 95, 115, 104, 111, 114, 116, 99, 117, 116,
  108, 105, 110, 107, 36, 62, 125, 34, 39, 60, 47, 105, 62, 60, 47, 102,
  111, 110, 116, 62, 60, 98, 114, 47, 62, 34, 10, 45, 100, 111, 110, 101,
  10, 45, 101, 91, 93, 32, 34, 60, 47, 112, 62, 34, 32, 45, 118, 32,
  45, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 45, 101,
  91, 93, 32, 64, 123, 45, 101, 111, 102, 102, 125, 64, 123, 45, 100, 111,
  102, 102, 125, 34, 60, 112, 32, 115, 116, 121, 108, 101, 61, 92, 34, 109,
  97, 114, 103, 105, 110, 45, 108, 101, 102, 116, 58, 49, 48, 48, 112, 120,
  92, 34, 62, 60, 102, 111, 110, 116, 32, 99, 111, 108, 111, 114, 61, 92,
  34, 98, 108, 117, 101, 92, 34, 62, 60, 98, 62, 91, 32, 84, 111, 116,
  97, 108, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 99, 111, 109,
  109, 97, 110, 100, 115, 58, 32, 34, 36, 95, 99, 111, 109, 109, 97, 110,
  100, 34, 32, 93, 60, 47, 98, 62, 60, 47, 102, 111, 110, 116, 62, 34,
  10, 45, 118, 32, 45, 10, 45, 117, 110, 99, 111, 109, 109, 97, 110, 100,
  32, 100, 111, 110, 10, 45, 117, 110, 99, 111, 109, 109, 97, 110, 100, 32,
  100, 111, 102, 102, 10, 45, 117, 110, 99, 111, 109, 109, 97, 110, 100, 32,
  101, 111, 110, 10, 45, 117, 110, 99, 111, 109, 109, 97, 110, 100, 32, 101,
  111, 102, 102, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109,
  105, 99, 95, 104, 101, 97, 100, 101, 114, 95, 120, 109, 108, 32, 58, 10,
  45, 105, 102, 32, 36, 49, 32, 45, 118, 32, 43, 10, 45, 101, 91, 93,
  32, 34, 60, 63, 120, 109, 108, 32, 118, 101, 114, 115, 105, 111, 110, 61,
  92, 34, 49, 46, 48, 92, 34, 32, 101, 110, 99, 111, 100, 105, 110, 103,
  61, 92, 34, 85, 84, 70, 45, 56, 92, 34, 32, 115, 116, 97, 110, 100,
  97, 108, 111, 110, 101, 61, 92, 34, 121, 101, 115, 92, 34, 63, 62, 10,
  92, 110, 60, 63, 120, 109, 108, 45, 115, 116, 121, 108, 101, 115, 104, 101,
  101, 116, 32, 104, 114, 101, 102, 61, 92, 34, 103, 109, 105, 99, 95, 100,
  111, 99, 46, 120, 115, 108, 92, 34, 32, 116, 121, 112, 101, 61, 92, 34,
  116, 101, 120, 116, 47, 120, 115, 108, 92, 34, 63, 62, 34, 10, 45, 118,
  32, 45, 32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 45,
  101, 91, 93, 32, 34, 60, 103, 109, 105, 99, 45, 112, 97, 99, 107, 97,
  103, 101, 32, 120, 109, 108, 110, 115, 58, 120, 115, 105, 61, 92, 34, 104,
  116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103,
  47, 50, 48, 48, 49, 47, 88, 77, 76, 83, 99, 104, 101, 109, 97, 45,
  105, 110, 115, 116, 97, 110, 99, 101, 92, 34, 32, 120, 115, 105, 58, 110,
  111, 78, 97, 109, 101, 115, 112, 97, 99, 101, 83, 99, 104, 101, 109, 97,
  76, 111, 99, 97, 116, 105, 111, 110, 61, 92, 34, 103, 109, 105, 99, 95,
  100, 111, 99, 46, 120, 115, 100, 92, 34, 62, 10, 92, 110, 60, 110, 97,
  109, 101, 62, 34, 36, 95, 110, 97, 109, 101, 34, 60, 47, 110, 97, 109,
  101, 62, 10, 92, 110, 60, 115, 101, 99, 116, 105, 111, 110, 62, 10, 92,
  110, 32, 32, 60, 110, 97, 109, 101, 62, 76, 105, 115, 116, 32, 111, 102,
  32, 99, 111, 109, 109, 97, 110, 100, 115, 60, 47, 110, 97, 109, 101, 62,
  34, 10, 45, 118, 32, 45, 10, 45, 109, 32, 34, 100, 111, 110, 32, 58,
  32, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99,
  95, 100, 101, 115, 99, 95, 111, 110, 95, 120, 109, 108, 34, 10, 45, 109,
  32, 34, 100, 111, 102, 102, 32, 58, 32, 45, 95, 100, 111, 99, 117, 109,
  101, 110, 116, 95, 103, 109, 105, 99, 95, 100, 101, 115, 99, 95, 111, 102,
  102, 95, 120, 109, 108, 34, 10, 95, 105, 115, 95, 115, 117, 98, 115, 101,
  99, 116, 105, 111, 110, 61, 48, 10, 95, 105, 115, 95, 99, 111, 109, 109,
  97, 110, 100, 61, 48, 10, 95, 105, 115, 95, 100, 101, 115, 99, 61, 48,
  10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95,
  100, 101, 115, 99, 95, 111, 110, 95, 120, 109, 108, 32, 58, 10, 45, 118,
  32, 45, 10, 45, 105, 102, 32, 36, 95, 105, 115, 95, 100, 101, 115, 99,
  10, 45, 117, 32, 34, 34, 10, 45, 101, 108, 115, 101, 10, 45, 117, 32,
  34, 32, 32, 32, 32, 60, 100, 101, 115, 99, 114, 105, 112, 116, 105, 111,
  110, 62, 92, 110, 34, 10, 95, 105, 115, 95, 100, 101, 115, 99, 61, 49,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 95, 100, 111,
  99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 100, 101, 115, 99,
  95, 111, 102, 102, 95, 120, 109, 108, 32, 58, 10, 45, 118, 32, 45, 10,
  45, 105, 102, 32, 36, 95, 105, 115, 95, 100, 101, 115, 99, 10, 45, 117,
  32, 34, 32, 32, 32, 32, 60, 47, 100, 101, 115, 99, 114, 105, 112, 116,
  105, 111, 110, 62, 92, 110, 34, 10, 95, 105, 115, 95, 100, 101, 115, 99,
  61, 48, 10, 45, 101, 108, 115, 101, 32, 45, 117, 32, 34, 34, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 95, 100, 111, 99, 117,
  109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 115, 117, 98, 115, 101, 99,
  116, 105, 111, 110, 95, 120, 109, 108, 32, 58, 10, 45, 118, 32, 43, 10,
  45, 105, 102, 32, 36, 95, 105, 115, 95, 115, 117, 98, 115, 101, 99, 116,
  105, 111, 110, 10, 45, 105, 102, 32, 36, 95, 105, 115, 95, 99, 111, 109,
  109, 97, 110, 100, 32, 45, 101, 91, 93, 32, 64, 123, 45, 100, 111, 102,
  102, 125, 34, 32, 32, 60, 47, 102, 117, 110, 99, 116, 105, 111, 110, 62,
  34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 91, 93, 32, 64, 123,
  45, 100, 111, 102, 102, 125, 34, 60, 47, 115, 117, 98, 115, 101, 99, 116,
  105, 111, 110, 62, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 91,
  93, 32, 64, 123, 45, 100, 111, 102, 102, 125, 34, 60, 115, 117, 98, 115,
  101, 99, 116, 105, 111, 110, 62, 10, 92, 110, 32, 32, 60, 110, 97, 109,
  101, 62, 34, 64, 123, 48, 44, 116, 125, 34, 60, 47, 110, 97, 109, 101,
  62, 34, 10, 45, 118, 32, 45, 10, 95, 105, 115, 95, 115, 117, 98, 115,
  101, 99, 116, 105, 111, 110, 61, 49, 10, 95, 105, 115, 95, 99, 111, 109,
  109, 97, 110, 100, 61, 48, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116,
  95, 103, 109, 105, 99, 95, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111,
  110, 95, 120, 109, 108, 32, 58, 10, 45, 95, 100, 111, 99, 117, 109, 101,
  110, 116, 95, 103, 109, 105, 99, 95, 114, 101, 112, 108, 97, 99, 101, 95,
  120, 109, 108, 10, 45, 118, 32, 43, 10, 45, 105, 102, 32, 36, 95, 105,
  115, 95, 99, 111, 109, 109, 97, 110, 100, 32, 45, 101, 91, 93, 32, 64,
  123, 45, 100, 111, 102, 102, 125, 34, 32, 32, 60, 47, 102, 117, 110, 99,
  116, 105, 111, 110, 62, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  91, 93, 32, 64, 123, 45, 100, 111, 102, 102, 125, 34, 32, 32, 60, 102,
  117, 110, 99, 116, 105, 111, 110, 62, 34, 10, 45, 118, 32, 45, 10, 95,
  105, 115, 95, 99, 111, 109, 109, 97, 110, 100, 61, 49, 10, 45, 105, 102,
  32, 123, 123, 64, 123, 45, 49, 44, 116, 125, 39, 61, 61, 39, 34, 40,
  42, 41, 34, 125, 34, 32, 124, 124, 32, 34, 123, 64, 123, 45, 49, 44,
  116, 125, 39, 61, 61, 39, 34, 40, 43, 41, 34, 125, 125, 32, 113, 117,
  97, 108, 105, 102, 105, 101, 114, 61, 34, 32, 34, 64, 123, 45, 49, 44,
  116, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 108, 115, 101,
  32, 113, 117, 97, 108, 105, 102, 105, 101, 114, 61, 34, 34, 32, 45, 101,
  110, 100, 105, 102, 10, 115, 49, 61, 34, 34, 32, 115, 48, 61, 34, 32,
  124, 34, 10, 45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 34, 32, 32,
  32, 32, 60, 110, 97, 109, 101, 62, 34, 64, 123, 48, 44, 116, 125, 34,
  60, 47, 110, 97, 109, 101, 62, 34, 10, 45, 105, 102, 32, 123, 64, 35,
  62, 49, 125, 10, 45, 101, 91, 93, 32, 34, 32, 32, 32, 32, 60, 97,
  114, 103, 117, 109, 101, 110, 116, 115, 62, 34, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 64, 35, 45, 49, 125, 10, 45, 101, 91, 93, 32, 34,
  32, 32, 32, 32, 32, 32, 34, 64, 123, 123, 49, 43, 36, 62, 125, 44,
  116, 125, 36, 123, 115, 123, 36, 60, 61, 61, 48, 125, 125, 10, 45, 100,
  111, 110, 101, 10, 45, 101, 91, 93, 32, 34, 32, 32, 32, 32, 60, 47,
  97, 114, 103, 117, 109, 101, 110, 116, 115, 62, 34, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 118, 32, 45, 10, 95, 100, 111, 99, 117, 109, 101, 110,
  116, 95, 103, 109, 105, 99, 95, 100, 101, 115, 99, 114, 105, 112, 116, 105,
  111, 110, 95, 120, 109, 108, 32, 58, 10, 45, 95, 100, 111, 99, 117, 109,
  101, 110, 116, 95, 103, 109, 105, 99, 95, 114, 101, 112, 108, 97, 99, 101,
  95, 120, 109, 108, 10, 45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 64,
  123, 45, 100, 111, 110, 125, 34, 32, 32, 32, 32, 32, 32, 34, 64, 123,
  48, 44, 116, 125, 10, 45, 118, 32, 45, 10, 95, 100, 111, 99, 117, 109,
  101, 110, 116, 95, 103, 109, 105, 99, 95, 101, 120, 97, 109, 112, 108, 101,
  95, 120, 109, 108, 32, 58, 10, 45, 95, 100, 111, 99, 117, 109, 101, 110,
  116, 95, 103, 109, 105, 99, 95, 114, 101, 112, 108, 97, 99, 101, 95, 120,
  109, 108, 10, 45, 105, 102, 32, 36, 95, 102, 105, 108, 101, 110, 97, 109,
  101, 32, 45, 101, 108, 115, 101, 10, 45, 109, 32, 34, 102, 111, 111, 32,
  58, 32, 34, 64, 123, 45, 49, 44, 116, 125, 10, 45, 108, 91, 93, 32,
  45, 118, 32, 45, 57, 57, 32, 45, 114, 101, 115, 101, 116, 32, 45, 102,
  111, 111, 32, 45, 118, 32, 45, 49, 32, 45, 95, 100, 111, 99, 117, 109,
  101, 110, 116, 95, 103, 109, 105, 99, 32, 45, 111, 32, 36, 95, 102, 105,
  108, 101, 110, 97, 109, 101, 44, 56, 53, 32, 45, 114, 109, 32, 45, 101,
  110, 100, 108, 10, 45, 117, 110, 99, 111, 109, 109, 97, 110, 100, 32, 102,
  111, 111, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 45,
  101, 91, 93, 32, 64, 123, 45, 100, 111, 102, 102, 125, 34, 32, 32, 32,
  32, 60, 101, 120, 97, 109, 112, 108, 101, 62, 34, 10, 45, 101, 91, 93,
  32, 34, 32, 32, 32, 32, 32, 32, 60, 99, 111, 109, 109, 97, 110, 100,
  62, 34, 64, 123, 48, 44, 116, 125, 34, 60, 47, 99, 111, 109, 109, 97,
  110, 100, 62, 34, 10, 45, 101, 91, 93, 32, 34, 32, 32, 32, 32, 32,
  32, 60, 114, 101, 115, 117, 108, 116, 62, 34, 36, 95, 102, 105, 108, 101,
  110, 97, 109, 101, 34, 60, 47, 114, 101, 115, 117, 108, 116, 62, 34, 10,
  45, 101, 91, 93, 32, 34, 32, 32, 32, 32, 60, 47, 101, 120, 97, 109,
  112, 108, 101, 62, 34, 10, 45, 118, 32, 45, 10, 95, 100, 111, 99, 117,
  109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 102, 111, 111, 116, 101, 114,
  95, 120, 109, 108, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 49, 10,
  45, 118, 32, 43, 10, 45, 105, 102, 32, 36, 95, 105, 115, 95, 99, 111,
  109, 109, 97, 110, 100, 32, 45, 101, 91, 93, 32, 64, 123, 45, 100, 111,
  102, 102, 125, 34, 60, 47, 102, 117, 110, 99, 116, 105, 111, 110, 62, 34,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 95, 105, 115,
  95, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 32, 45, 101, 91, 93,
  32, 64, 123, 45, 100, 111, 102, 102, 125, 34, 60, 47, 115, 117, 98, 115,
  101, 99, 116, 105, 111, 110, 62, 34, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 91, 93, 32, 64, 123, 45, 100, 111, 102, 102, 125, 34, 60, 47,
  115, 101, 99, 116, 105, 111, 110, 62, 10, 92, 110, 60, 47, 103, 109, 105,
  99, 45, 112, 97, 99, 107, 97, 103, 101, 62, 34, 10, 45, 118, 32, 45,
  10, 45, 117, 110, 99, 111, 109, 109, 97, 110, 100, 32, 100, 111, 110, 10,
  45, 117, 110, 99, 111, 109, 109, 97, 110, 100, 32, 100, 111, 102, 102, 10,
  95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 114,
  101, 112, 108, 97, 99, 101, 95, 120, 109, 108, 32, 58, 10, 45, 114, 101,
  112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 123, 39, 38, 39, 125, 44,
  64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 38, 97, 109, 112,
  59, 39, 125, 125, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101,
  113, 32, 123, 39, 60, 39, 125, 44, 64, 123, 45, 113, 117, 111, 116, 101,
  92, 32, 123, 39, 38, 108, 116, 59, 39, 125, 125, 10, 45, 114, 101, 112,
  108, 97, 99, 101, 95, 115, 101, 113, 32, 123, 39, 62, 39, 125, 44, 64,
  123, 45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 38, 103, 116, 59, 39,
  125, 125, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105,
  99, 95, 104, 101, 97, 100, 101, 114, 95, 108, 97, 116, 101, 120, 32, 58,
  10, 45, 105, 102, 32, 36, 49, 32, 45, 118, 32, 43, 10, 45, 101, 91,
  93, 32, 34, 92, 92, 100, 111, 99, 117, 109, 101, 110, 116, 99, 108, 97,
  115, 115, 91, 97, 52, 112, 97, 112, 101, 114, 44, 49, 48, 112, 116, 44,
  116, 119, 111, 115, 105, 100, 101, 93, 123, 98, 111, 111, 107, 125, 10, 92,
  110, 92, 92, 117, 115, 101, 112, 97, 99, 107, 97, 103, 101, 123, 104, 121,
  112, 101, 114, 114, 101, 102, 44, 102, 97, 110, 99, 121, 104, 100, 114, 44,
  103, 114, 97, 112, 104, 105, 99, 120, 44, 97, 109, 115, 115, 121, 109, 98,
  44, 97, 109, 115, 109, 97, 116, 104, 44, 116, 105, 109, 101, 115, 44, 109,
  97, 107, 101, 105, 100, 120, 125, 10, 92, 110, 92, 92, 103, 114, 97, 112,
  104, 105, 99, 115, 112, 97, 116, 104, 123, 123, 34, 36, 95, 112, 97, 116,
  104, 34, 125, 125, 10, 92, 110, 92, 92, 112, 97, 103, 101, 115, 116, 121,
  108, 101, 123, 102, 97, 110, 99, 121, 112, 108, 97, 105, 110, 125, 10, 92,
  110, 92, 92, 108, 104, 101, 97, 100, 91, 92, 92, 102, 97, 110, 99, 121,
  112, 108, 97, 105, 110, 123, 125, 123, 92, 92, 116, 101, 120, 116, 98, 102,
  92, 92, 116, 104, 101, 112, 97, 103, 101, 125, 93, 123, 92, 92, 102, 97,
  110, 99, 121, 112, 108, 97, 105, 110, 123, 125, 123, 92, 92, 114, 105, 103,
  104, 116, 109, 97, 114, 107, 125, 125, 10, 92, 110, 92, 92, 114, 104, 101,
  97, 100, 91, 92, 92, 102, 97, 110, 99, 121, 112, 108, 97, 105, 110, 123,
  125, 123, 92, 92, 108, 101, 102, 116, 109, 97, 114, 107, 125, 93, 123, 92,
  92, 102, 97, 110, 99, 121, 112, 108, 97, 105, 110, 123, 125, 123, 92, 92,
  116, 101, 120, 116, 98, 102, 92, 92, 116, 104, 101, 112, 97, 103, 101, 125,
  125, 10, 92, 110, 92, 92, 99, 102, 111, 111, 116, 123, 125, 10, 92, 110,
  92, 92, 115, 101, 116, 108, 101, 110, 103, 116, 104, 123, 92, 92, 116, 101,
  120, 116, 119, 105, 100, 116, 104, 125, 123, 53, 46, 56, 55, 53, 105, 110,
  125, 10, 92, 110, 92, 92, 115, 101, 116, 108, 101, 110, 103, 116, 104, 123,
  92, 92, 112, 97, 114, 105, 110, 100, 101, 110, 116, 125, 123, 48, 112, 99,
  125, 10, 92, 110, 92, 92, 115, 101, 116, 108, 101, 110, 103, 116, 104, 123,
  92, 92, 104, 111, 102, 102, 115, 101, 116, 125, 123, 45, 48, 46, 56, 99,
  109, 125, 10, 92, 110, 92, 92, 115, 101, 116, 99, 111, 117, 110, 116, 101,
  114, 123, 116, 111, 99, 100, 101, 112, 116, 104, 125, 123, 49, 125, 10, 92,
  110, 92, 92, 115, 108, 111, 112, 112, 121, 123, 125, 10, 92, 110, 92, 92,
  114, 101, 110, 101, 119, 99, 111, 109, 109, 97, 110, 100, 92, 92, 105, 110,
  100, 101, 120, 110, 97, 109, 101, 123, 73, 110, 100, 101, 120, 32, 111, 102,
  32, 99, 111, 109, 109, 97, 110, 100, 115, 125, 10, 92, 110, 92, 92, 109,
  97, 107, 101, 105, 110, 100, 101, 120, 10, 92, 110, 92, 92, 98, 101, 103,
  105, 110, 123, 100, 111, 99, 117, 109, 101, 110, 116, 125, 10, 92, 110, 92,
  92, 116, 97, 98, 108, 101, 111, 102, 99, 111, 110, 116, 101, 110, 116, 115,
  34, 10, 45, 118, 32, 45, 32, 45, 101, 110, 100, 105, 102, 10, 45, 118,
  32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 110, 92, 92, 99, 104, 97,
  112, 116, 101, 114, 123, 76, 105, 115, 116, 32, 111, 102, 32, 99, 111, 109,
  109, 97, 110, 100, 115, 125, 34, 32, 45, 118, 32, 45, 10, 45, 109, 32,
  34, 101, 111, 110, 32, 58, 32, 45, 95, 100, 111, 99, 117, 109, 101, 110,
  116, 95, 103, 109, 105, 99, 95, 101, 120, 95, 111, 110, 95, 108, 97, 116,
  101, 120, 34, 10, 45, 109, 32, 34, 101, 111, 102, 102, 32, 58, 32, 45,
  95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 101,
  120, 95, 111, 102, 102, 95, 108, 97, 116, 101, 120, 34, 10, 95, 105, 115,
  95, 100, 101, 115, 99, 61, 48, 10, 95, 105, 115, 95, 101, 120, 61, 48,
  10, 95, 115, 104, 111, 114, 116, 99, 117, 116, 61, 48, 10, 95, 100, 111,
  99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 101, 120, 95, 111,
  110, 95, 108, 97, 116, 101, 120, 32, 58, 10, 45, 118, 32, 45, 10, 45,
  105, 102, 32, 36, 95, 105, 115, 95, 101, 120, 10, 45, 117, 32, 34, 92,
  92, 92, 92, 34, 10, 45, 101, 108, 115, 101, 10, 45, 117, 32, 34, 92,
  92, 98, 101, 103, 105, 110, 123, 99, 101, 110, 116, 101, 114, 125, 34, 10,
  95, 105, 115, 95, 101, 120, 61, 49, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 118, 32, 43, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103,
  109, 105, 99, 95, 101, 120, 95, 111, 102, 102, 95, 108, 97, 116, 101, 120,
  32, 58, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 36, 95, 105, 115,
  95, 101, 120, 10, 45, 117, 32, 34, 92, 92, 101, 110, 100, 123, 99, 101,
  110, 116, 101, 114, 125, 34, 10, 95, 105, 115, 95, 101, 120, 61, 48, 10,
  45, 101, 108, 115, 101, 10, 45, 117, 32, 34, 34, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 118, 32, 43, 10, 95, 100, 111, 99, 117, 109, 101, 110,
  116, 95, 103, 109, 105, 99, 95, 115, 117, 98, 115, 101, 99, 116, 105, 111,
  110, 95, 108, 97, 116, 101, 120, 32, 58, 10, 95, 105, 115, 95, 100, 101,
  115, 99, 61, 48, 10, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95,
  103, 109, 105, 99, 95, 114, 101, 112, 108, 97, 99, 101, 95, 108, 97, 116,
  101, 120, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 64, 123, 45,
  101, 111, 102, 102, 125, 34, 92, 110, 92, 92, 115, 101, 99, 116, 105, 111,
  110, 123, 34, 64, 123, 48, 44, 116, 125, 34, 125, 34, 32, 45, 118, 32,
  45, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99,
  95, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 95, 108, 97, 116,
  101, 120, 32, 58, 10, 95, 105, 115, 95, 100, 101, 115, 99, 61, 48, 10,
  45, 105, 102, 32, 123, 123, 64, 123, 45, 49, 44, 116, 125, 39, 61, 61,
  39, 34, 40, 42, 41, 34, 125, 34, 32, 124, 124, 32, 34, 123, 64, 123,
  45, 49, 44, 116, 125, 39, 61, 61, 39, 34, 40, 43, 41, 34, 125, 125,
  32, 113, 117, 97, 108, 105, 102, 105, 101, 114, 61, 64, 123, 45, 49, 44,
  116, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 108, 115, 101,
  32, 113, 117, 97, 108, 105, 102, 105, 101, 114, 61, 34, 34, 32, 45, 101,
  110, 100, 105, 102, 10, 101, 49, 61, 34, 92, 92, 92, 92, 126, 92, 92,
  92, 92, 34, 32, 101, 48, 61, 34, 126, 126, 126, 36, 124, 36, 92, 92,
  92, 92, 34, 10, 115, 49, 61, 34, 92, 92, 104, 115, 112, 97, 99, 101,
  42, 123, 50, 46, 50, 99, 109, 125, 34, 32, 115, 48, 61, 34, 34, 10,
  45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95,
  114, 101, 112, 108, 97, 99, 101, 95, 108, 97, 116, 101, 120, 10, 45, 105,
  102, 32, 123, 64, 35, 62, 49, 34, 32, 38, 38, 32, 34, 123, 64, 123,
  45, 49, 44, 48, 45, 54, 125, 39, 61, 61, 39, 123, 39, 34, 101, 113,
  46, 32, 116, 111, 32, 34, 39, 125, 125, 125, 10, 45, 114, 111, 119, 115,
  91, 45, 49, 93, 32, 55, 44, 49, 48, 48, 37, 32, 45, 97, 117, 116,
  111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 123, 39, 46, 39, 125, 32,
  45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 123, 39,
  34, 32, 34, 39, 125, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91,
  45, 49, 93, 32, 51, 57, 10, 95, 115, 104, 111, 114, 116, 99, 117, 116,
  36, 95, 115, 104, 111, 114, 116, 99, 117, 116, 61, 64, 123, 48, 44, 116,
  125, 10, 95, 115, 104, 111, 114, 116, 99, 117, 116, 108, 105, 110, 107, 36,
  95, 115, 104, 111, 114, 116, 99, 117, 116, 61, 64, 123, 45, 49, 44, 116,
  125, 10, 95, 115, 104, 111, 114, 116, 99, 117, 116, 113, 117, 97, 108, 105,
  102, 105, 101, 114, 36, 95, 115, 104, 111, 114, 116, 99, 117, 116, 61, 36,
  113, 117, 97, 108, 105, 102, 105, 101, 114, 10, 95, 115, 104, 111, 114, 116,
  99, 117, 116, 61, 123, 36, 95, 115, 104, 111, 114, 116, 99, 117, 116, 43,
  49, 125, 10, 45, 101, 108, 115, 101, 10, 45, 118, 32, 43, 10, 45, 101,
  91, 93, 32, 64, 123, 45, 101, 111, 102, 102, 125, 34, 92, 110, 92, 110,
  92, 92, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 123, 92, 92, 101,
  109, 112, 104, 123, 45, 34, 64, 123, 48, 44, 116, 125, 34, 92, 92, 105,
  110, 100, 101, 120, 123, 45, 34, 64, 123, 48, 44, 116, 125, 34, 125, 125,
  32, 34, 36, 113, 117, 97, 108, 105, 102, 105, 101, 114, 34, 125, 92, 92,
  118, 115, 112, 97, 99, 101, 42, 123, 45, 48, 46, 53, 101, 109, 125, 34,
  10, 45, 105, 102, 32, 123, 64, 35, 62, 49, 125, 10, 45, 101, 91, 93,
  32, 34, 126, 92, 92, 92, 92, 92, 92, 116, 101, 120, 116, 98, 102, 123,
  65, 114, 103, 117, 109, 101, 110, 116, 115, 58, 32, 125, 32, 34, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 10, 45, 101,
  91, 93, 32, 36, 123, 115, 123, 36, 62, 33, 61, 48, 125, 125, 34, 123,
  92, 92, 115, 109, 97, 108, 108, 32, 92, 92, 116, 101, 120, 116, 116, 116,
  123, 34, 64, 123, 123, 49, 43, 36, 62, 125, 44, 116, 125, 34, 125, 125,
  34, 36, 123, 101, 123, 36, 60, 61, 61, 48, 125, 125, 10, 45, 100, 111,
  110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 10, 45,
  101, 110, 100, 105, 102, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95,
  103, 109, 105, 99, 95, 100, 101, 115, 99, 114, 105, 112, 116, 105, 111, 110,
  95, 108, 97, 116, 101, 120, 32, 58, 10, 115, 48, 61, 34, 34, 32, 115,
  49, 61, 34, 126, 92, 92, 92, 92, 34, 32, 115, 61, 36, 123, 115, 36,
  95, 105, 115, 95, 100, 101, 115, 99, 125, 10, 45, 95, 100, 111, 99, 117,
  109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 114, 101, 112, 108, 97, 99,
  101, 95, 108, 97, 116, 101, 120, 10, 45, 105, 102, 32, 123, 64, 123, 45,
  49, 44, 48, 45, 49, 50, 125, 39, 61, 61, 39, 123, 39, 34, 68, 101,
  102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 34, 39, 125, 125, 10,
  45, 115, 32, 43, 44, 123, 39, 58, 39, 125, 32, 45, 108, 91, 94, 48,
  93, 32, 45, 97, 32, 121, 32, 45, 101, 110, 100, 108, 32, 45, 97, 117,
  116, 111, 99, 114, 111, 112, 32, 123, 39, 58, 39, 125, 32, 45, 97, 117,
  116, 111, 99, 114, 111, 112, 32, 123, 39, 34, 32, 34, 39, 125, 10, 45,
  105, 102, 32, 123, 64, 35, 62, 49, 125, 10, 45, 114, 101, 112, 108, 97,
  99, 101, 95, 115, 101, 113, 91, 49, 93, 32, 64, 123, 45, 113, 117, 111,
  116, 101, 92, 32, 123, 39, 34, 32, 97, 110, 100, 32, 34, 39, 125, 125,
  44, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 34, 125, 32,
  97, 110, 100, 32, 92, 92, 92, 92, 116, 101, 120, 116, 116, 116, 123, 34,
  39, 125, 125, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 64, 123,
  45, 101, 111, 102, 102, 125, 36, 115, 34, 126, 92, 92, 92, 92, 92, 92,
  116, 101, 120, 116, 98, 102, 123, 34, 64, 123, 48, 44, 116, 125, 34, 125,
  58, 32, 123, 92, 92, 115, 109, 97, 108, 108, 32, 92, 92, 116, 101, 120,
  116, 116, 116, 123, 34, 64, 123, 45, 49, 44, 116, 125, 34, 125, 125, 34,
  32, 45, 118, 32, 45, 10, 45, 101, 108, 115, 101, 32, 45, 118, 32, 43,
  32, 45, 101, 91, 93, 32, 64, 123, 45, 101, 111, 102, 102, 125, 36, 115,
  34, 126, 92, 92, 92, 92, 34, 64, 123, 48, 44, 116, 125, 32, 45, 118,
  32, 45, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 105, 102, 32,
  123, 64, 123, 45, 49, 44, 48, 45, 55, 125, 39, 61, 61, 39, 123, 39,
  34, 40, 101, 113, 46, 32, 116, 111, 32, 34, 39, 125, 125, 10, 45, 114,
  111, 119, 115, 91, 45, 49, 93, 32, 56, 44, 49, 48, 48, 37, 32, 45,
  97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 123, 39, 46,
  39, 125, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93,
  32, 123, 39, 41, 39, 125, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112,
  91, 45, 49, 93, 32, 123, 39, 34, 32, 34, 39, 125, 10, 45, 118, 32,
  43, 32, 45, 101, 91, 93, 32, 64, 123, 45, 101, 111, 102, 102, 125, 36,
  115, 34, 40, 92, 92, 101, 109, 112, 104, 123, 101, 113, 46, 32, 116, 111,
  125, 32, 123, 92, 92, 115, 109, 97, 108, 108, 32, 92, 92, 116, 101, 120,
  116, 116, 116, 123, 34, 64, 123, 45, 49, 44, 116, 125, 34, 125, 125, 41,
  46, 34, 32, 45, 118, 32, 45, 10, 45, 101, 108, 115, 101, 10, 45, 105,
  102, 32, 123, 40, 105, 60, 123, 39, 65, 39, 125, 34, 32, 124, 124, 32,
  34, 105, 62, 123, 39, 90, 39, 125, 41, 34, 32, 38, 38, 32, 34, 105,
  33, 61, 52, 48, 34, 32, 38, 38, 32, 34, 105, 33, 61, 51, 57, 125,
  32, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 64, 123, 45, 101, 111,
  102, 102, 125, 64, 123, 45, 49, 44, 116, 125, 32, 45, 118, 32, 45, 10,
  45, 101, 108, 115, 101, 32, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32,
  64, 123, 45, 101, 111, 102, 102, 125, 36, 115, 64, 123, 45, 49, 44, 116,
  125, 32, 45, 118, 32, 45, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  110, 100, 105, 102, 10, 95, 105, 115, 95, 100, 101, 115, 99, 61, 49, 10,
  95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 101,
  120, 97, 109, 112, 108, 101, 95, 108, 97, 116, 101, 120, 32, 58, 10, 95,
  105, 115, 95, 100, 101, 115, 99, 61, 48, 10, 45, 105, 102, 32, 36, 95,
  102, 105, 108, 101, 110, 97, 109, 101, 32, 45, 101, 108, 115, 101, 10, 45,
  109, 32, 34, 102, 111, 111, 32, 58, 32, 34, 64, 123, 45, 49, 44, 116,
  125, 10, 45, 108, 91, 93, 32, 45, 118, 32, 45, 57, 57, 32, 45, 114,
  101, 115, 101, 116, 32, 45, 102, 111, 111, 32, 45, 118, 32, 45, 49, 32,
  45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 32,
  45, 111, 32, 36, 95, 102, 105, 108, 101, 110, 97, 109, 101, 44, 56, 53,
  32, 45, 114, 109, 32, 45, 101, 110, 100, 108, 10, 45, 117, 110, 99, 111,
  109, 109, 97, 110, 100, 32, 102, 111, 111, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99,
  95, 114, 101, 112, 108, 97, 99, 101, 95, 108, 97, 116, 101, 120, 10, 45,
  118, 32, 43, 10, 45, 101, 91, 93, 32, 64, 123, 45, 101, 111, 110, 125,
  34, 92, 92, 105, 110, 99, 108, 117, 100, 101, 103, 114, 97, 112, 104, 105,
  99, 115, 91, 107, 101, 101, 112, 97, 115, 112, 101, 99, 116, 114, 97, 116,
  105, 111, 61, 116, 114, 117, 101, 44, 104, 101, 105, 103, 104, 116, 61, 55,
  99, 109, 44, 119, 105, 100, 116, 104, 61, 92, 92, 116, 101, 120, 116, 119,
  105, 100, 116, 104, 93, 123, 34, 36, 95, 102, 105, 108, 101, 110, 97, 109,
  101, 34, 125, 92, 92, 92, 92, 34, 10, 45, 101, 91, 93, 32, 34, 123,
  92, 92, 102, 111, 111, 116, 110, 111, 116, 101, 115, 105, 122, 101, 32, 92,
  92, 116, 101, 120, 116, 98, 102, 123, 69, 120, 97, 109, 112, 108, 101, 32,
  34, 36, 95, 101, 120, 97, 109, 112, 108, 101, 34, 126, 58, 125, 32, 92,
  92, 116, 101, 120, 116, 116, 116, 123, 34, 64, 123, 45, 49, 44, 116, 125,
  34, 125, 125, 34, 10, 45, 118, 32, 45, 10, 95, 100, 111, 99, 117, 109,
  101, 110, 116, 95, 103, 109, 105, 99, 95, 102, 111, 111, 116, 101, 114, 95,
  108, 97, 116, 101, 120, 32, 58, 10, 45, 105, 102, 32, 36, 95, 115, 104,
  111, 114, 116, 99, 117, 116, 10, 40, 123, 39, 34, 67, 111, 109, 109, 97,
  110, 100, 115, 32, 115, 104, 111, 114, 116, 99, 117, 116, 115, 34, 39, 125,
  41, 32, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105,
  99, 95, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 95, 108, 97, 116,
  101, 120, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  118, 32, 43, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 95, 115, 104,
  111, 114, 116, 99, 117, 116, 10, 45, 101, 91, 93, 32, 34, 36, 92, 92,
  98, 117, 108, 108, 101, 116, 36, 126, 39, 92, 92, 116, 101, 120, 116, 116,
  116, 123, 45, 34, 36, 123, 95, 115, 104, 111, 114, 116, 99, 117, 116, 36,
  62, 125, 34, 125, 39, 32, 34, 36, 123, 95, 115, 104, 111, 114, 116, 99,
  117, 116, 113, 117, 97, 108, 105, 102, 105, 101, 114, 36, 62, 125, 34, 126,
  105, 115, 32, 101, 113, 117, 105, 118, 97, 108, 101, 110, 116, 32, 116, 111,
  126, 126, 39, 92, 92, 116, 101, 120, 116, 116, 116, 123, 34, 36, 123, 95,
  115, 104, 111, 114, 116, 99, 117, 116, 108, 105, 110, 107, 36, 62, 125, 34,
  125, 39, 46, 92, 92, 92, 92, 34, 10, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 45, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36,
  49, 10, 45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 34, 10, 92, 110,
  92, 92, 112, 114, 105, 110, 116, 105, 110, 100, 101, 120, 10, 92, 110, 126,
  92, 92, 92, 92, 36, 92, 92, 115, 113, 117, 97, 114, 101, 36, 126, 69,
  110, 100, 32, 111, 102, 32, 100, 111, 99, 117, 109, 101, 110, 116, 46, 10,
  92, 110, 92, 110, 92, 92, 101, 110, 100, 123, 100, 111, 99, 117, 109, 101,
  110, 116, 125, 34, 10, 45, 118, 32, 45, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 117, 110, 99, 111, 109, 109, 97, 110, 100, 32, 101, 111, 110, 10,
  45, 117, 110, 99, 111, 109, 109, 97, 110, 100, 32, 101, 111, 102, 102, 10,
  95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 114,
  101, 112, 108, 97, 99, 101, 95, 108, 97, 116, 101, 120, 32, 58, 10, 45,
  114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 123, 39, 92, 92,
  39, 125, 44, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 34,
  92, 92, 92, 92, 116, 101, 120, 116, 98, 97, 99, 107, 115, 108, 97, 115,
  104, 32, 34, 39, 125, 125, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95,
  115, 101, 113, 32, 123, 39, 95, 39, 125, 44, 64, 123, 45, 113, 117, 111,
  116, 101, 92, 32, 123, 39, 92, 92, 92, 92, 95, 39, 125, 125, 10, 45,
  114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 123, 39, 37, 39,
  125, 44, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 92, 92,
  92, 92, 37, 39, 125, 125, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95,
  115, 101, 113, 32, 123, 39, 35, 39, 125, 44, 64, 123, 45, 113, 117, 111,
  116, 101, 92, 32, 123, 39, 92, 92, 92, 92, 37, 39, 125, 125, 10, 45,
  114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 123, 39, 94, 39,
  125, 44, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 34, 92,
  92, 92, 92, 116, 101, 120, 116, 97, 115, 99, 105, 105, 99, 105, 114, 99,
  117, 109, 32, 34, 39, 125, 125, 10, 45, 114, 101, 112, 108, 97, 99, 101,
  95, 115, 101, 113, 32, 123, 39, 36, 39, 125, 44, 64, 123, 45, 113, 117,
  111, 116, 101, 92, 32, 123, 39, 92, 92, 92, 92, 36, 39, 125, 125, 10,
  45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 123, 39, 92,
  123, 39, 125, 44, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 123, 39,
  92, 92, 92, 92, 92, 123, 39, 125, 125, 10, 45, 114, 101, 112, 108, 97,
  99, 101, 95, 115, 101, 113, 32, 123, 39, 92, 125, 39, 125, 44, 64, 123,
  45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 92, 92, 92, 92, 92, 125,
  39, 125, 125, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113,
  32, 123, 39, 38, 39, 125, 44, 64, 123, 45, 113, 117, 111, 116, 101, 92,
  32, 123, 39, 92, 92, 92, 92, 38, 39, 125, 125, 10, 45, 114, 101, 112,
  108, 97, 99, 101, 95, 115, 101, 113, 32, 123, 39, 124, 39, 125, 44, 64,
  123, 45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 126, 36, 124, 36, 126,
  39, 125, 125, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113,
  32, 123, 39, 60, 39, 125, 44, 64, 123, 45, 113, 117, 111, 116, 101, 92,
  32, 123, 39, 36, 92, 60, 36, 39, 125, 125, 10, 45, 114, 101, 112, 108,
  97, 99, 101, 95, 115, 101, 113, 32, 123, 39, 62, 39, 125, 44, 64, 123,
  45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 36, 92, 62, 36, 39, 125,
  125, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99,
  95, 104, 101, 97, 100, 101, 114, 95, 105, 109, 97, 103, 101, 115, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 49, 10, 45, 118, 32, 43, 10, 45,
  101, 91, 93, 32, 34, 92, 110, 32, 45, 32, 71, 101, 110, 101, 114, 97,
  116, 101, 32, 101, 120, 97, 109, 112, 108, 101, 32, 105, 109, 97, 103, 101,
  115, 32, 102, 114, 111, 109, 32, 115, 101, 116, 32, 111, 102, 32, 99, 111,
  109, 109, 97, 110, 100, 115, 32, 39, 34, 36, 95, 110, 97, 109, 101, 34,
  39, 46, 92, 110, 34, 10, 45, 118, 32, 45, 10, 95, 100, 111, 99, 117,
  109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 115, 117, 98, 115, 101, 99,
  116, 105, 111, 110, 95, 105, 109, 97, 103, 101, 115, 32, 58, 32, 45, 95,
  100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 115, 117,
  98, 115, 101, 99, 116, 105, 111, 110, 95, 97, 115, 99, 105, 105, 10, 95,
  100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 100, 101,
  99, 108, 97, 114, 97, 116, 105, 111, 110, 95, 105, 109, 97, 103, 101, 115,
  32, 58, 32, 95, 99, 111, 109, 109, 97, 110, 100, 95, 110, 97, 109, 101,
  61, 64, 123, 48, 44, 116, 125, 10, 95, 100, 111, 99, 117, 109, 101, 110,
  116, 95, 103, 109, 105, 99, 95, 100, 101, 115, 99, 114, 105, 112, 116, 105,
  111, 110, 95, 105, 109, 97, 103, 101, 115, 32, 58, 10, 95, 100, 111, 99,
  117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 101, 120, 97, 109, 112,
  108, 101, 95, 105, 109, 97, 103, 101, 115, 32, 58, 10, 45, 118, 32, 43,
  10, 45, 101, 91, 93, 32, 34, 32, 32, 32, 32, 46, 32, 67, 111, 109,
  109, 97, 110, 100, 32, 39, 45, 34, 36, 95, 99, 111, 109, 109, 97, 110,
  100, 95, 110, 97, 109, 101, 34, 39, 58, 32, 36, 32, 34, 64, 123, 45,
  49, 44, 116, 125, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 36, 95,
  102, 105, 108, 101, 110, 97, 109, 101, 32, 45, 101, 108, 115, 101, 10, 45,
  109, 32, 34, 102, 111, 111, 32, 58, 32, 34, 64, 123, 45, 49, 44, 116,
  125, 10, 45, 108, 91, 93, 32, 45, 118, 32, 45, 49, 32, 45, 114, 101,
  115, 101, 116, 32, 45, 118, 32, 45, 57, 57, 32, 45, 102, 111, 111, 32,
  45, 118, 32, 45, 49, 32, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116,
  95, 103, 109, 105, 99, 32, 45, 111, 32, 36, 95, 102, 105, 108, 101, 110,
  97, 109, 101, 44, 56, 53, 32, 45, 114, 109, 32, 45, 101, 110, 100, 108,
  10, 45, 117, 110, 99, 111, 109, 109, 97, 110, 100, 32, 102, 111, 111, 10,
  45, 101, 110, 100, 105, 102, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116,
  95, 103, 109, 105, 99, 95, 102, 111, 111, 116, 101, 114, 95, 105, 109, 97,
  103, 101, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 49, 10, 45,
  118, 32, 43, 10, 45, 101, 91, 93, 32, 34, 92, 110, 32, 45, 32, 91,
  32, 65, 108, 108, 32, 100, 111, 110, 101, 33, 32, 93, 92, 110, 92, 110,
  34, 10, 45, 118, 32, 45, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116,
  95, 103, 109, 105, 99, 95, 104, 101, 97, 100, 101, 114, 95, 97, 115, 99,
  105, 105, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 49, 10, 95, 115,
  104, 111, 114, 116, 99, 117, 116, 61, 48, 10, 95, 100, 111, 99, 117, 109,
  101, 110, 116, 95, 103, 109, 105, 99, 95, 115, 117, 98, 115, 101, 99, 116,
  105, 111, 110, 95, 97, 115, 99, 105, 105, 32, 58, 10, 45, 118, 32, 43,
  10, 45, 101, 91, 93, 32, 34, 92, 110, 32, 42, 42, 32, 34, 64, 123,
  48, 44, 116, 125, 34, 58, 34, 10, 45, 118, 32, 45, 10, 95, 100, 111,
  99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 100, 101, 99, 108,
  97, 114, 97, 116, 105, 111, 110, 95, 97, 115, 99, 105, 105, 32, 58, 10,
  45, 105, 102, 32, 123, 123, 64, 123, 45, 49, 44, 116, 125, 39, 61, 61,
  39, 34, 40, 42, 41, 34, 125, 34, 32, 124, 124, 32, 34, 123, 64, 123,
  45, 49, 44, 116, 125, 39, 61, 61, 39, 34, 40, 43, 41, 34, 125, 125,
  32, 113, 117, 97, 108, 105, 102, 105, 101, 114, 61, 34, 32, 34, 64, 123,
  45, 49, 44, 116, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101,
  108, 115, 101, 32, 113, 117, 97, 108, 105, 102, 105, 101, 114, 61, 34, 34,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64, 35, 62,
  49, 34, 32, 38, 38, 32, 34, 123, 64, 123, 45, 49, 44, 48, 45, 54,
  125, 39, 61, 61, 39, 123, 39, 34, 101, 113, 46, 32, 116, 111, 32, 34,
  39, 125, 125, 125, 10, 45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 55,
  44, 49, 48, 48, 37, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91,
  45, 49, 93, 32, 123, 39, 46, 39, 125, 32, 45, 97, 117, 116, 111, 99,
  114, 111, 112, 91, 45, 49, 93, 32, 123, 39, 34, 32, 34, 39, 125, 32,
  45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 51, 57,
  10, 95, 115, 104, 111, 114, 116, 99, 117, 116, 36, 95, 115, 104, 111, 114,
  116, 99, 117, 116, 61, 64, 123, 48, 44, 116, 125, 10, 95, 115, 104, 111,
  114, 116, 99, 117, 116, 108, 105, 110, 107, 36, 95, 115, 104, 111, 114, 116,
  99, 117, 116, 61, 64, 123, 45, 49, 44, 116, 125, 10, 95, 115, 104, 111,
  114, 116, 99, 117, 116, 113, 117, 97, 108, 105, 102, 105, 101, 114, 36, 95,
  115, 104, 111, 114, 116, 99, 117, 116, 61, 36, 113, 117, 97, 108, 105, 102,
  105, 101, 114, 10, 95, 115, 104, 111, 114, 116, 99, 117, 116, 61, 123, 36,
  95, 115, 104, 111, 114, 116, 99, 117, 116, 43, 49, 125, 10, 45, 101, 108,
  115, 101, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 110,
  32, 32, 32, 32, 45, 34, 64, 123, 48, 44, 116, 125, 36, 123, 113, 117,
  97, 108, 105, 102, 105, 101, 114, 125, 34, 58, 34, 32, 45, 118, 32, 45,
  32, 45, 114, 109, 91, 48, 93, 10, 45, 105, 102, 32, 64, 35, 10, 115,
  61, 34, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 34, 10, 45, 121, 32, 120,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 32,
  40, 123, 39, 34, 32, 124, 34, 39, 125, 41, 32, 45, 97, 91, 36, 62,
  44, 45, 49, 93, 32, 120, 32, 45, 100, 111, 110, 101, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45,
  95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 115,
  112, 108, 105, 116, 95, 97, 115, 99, 105, 105, 32, 56, 48, 44, 48, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 40,
  123, 39, 92, 110, 36, 115, 34, 32, 32, 34, 39, 125, 41, 32, 45, 97,
  91, 36, 62, 44, 45, 49, 93, 32, 120, 32, 45, 100, 111, 110, 101, 10,
  45, 97, 32, 120, 32, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 36,
  115, 64, 123, 48, 44, 116, 125, 32, 45, 118, 32, 45, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 34, 32, 45, 118, 32,
  45, 10, 45, 101, 110, 100, 105, 102, 10, 95, 100, 111, 99, 117, 109, 101,
  110, 116, 95, 103, 109, 105, 99, 95, 100, 101, 115, 99, 114, 105, 112, 116,
  105, 111, 110, 95, 97, 115, 99, 105, 105, 32, 58, 10, 115, 61, 34, 32,
  32, 32, 32, 32, 32, 32, 32, 34, 32, 98, 115, 48, 61, 34, 92, 110,
  34, 32, 98, 115, 49, 61, 34, 92, 92, 92, 92, 92, 110, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 34, 10, 45, 121, 32, 120, 32,
  45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95,
  115, 112, 108, 105, 116, 95, 97, 115, 99, 105, 105, 32, 57, 54, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 40, 123,
  39, 36, 123, 98, 115, 36, 95, 105, 115, 95, 101, 120, 97, 109, 112, 108,
  101, 125, 36, 115, 34, 32, 32, 34, 39, 125, 41, 32, 45, 97, 91, 36,
  62, 44, 45, 49, 93, 32, 120, 32, 45, 100, 111, 110, 101, 32, 45, 97,
  32, 120, 10, 45, 118, 32, 43, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 101, 91, 93, 32, 36, 115, 64, 123, 36, 62, 44, 116,
  125, 32, 45, 118, 32, 45, 32, 45, 100, 111, 110, 101, 10, 95, 100, 111,
  99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 101, 120, 97, 109,
  112, 108, 101, 95, 97, 115, 99, 105, 105, 32, 58, 10, 95, 100, 111, 99,
  117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 102, 111, 111, 116, 101,
  114, 95, 97, 115, 99, 105, 105, 32, 58, 32, 45, 115, 107, 105, 112, 32,
  36, 49, 10, 45, 105, 102, 32, 36, 95, 115, 104, 111, 114, 116, 99, 117,
  116, 10, 40, 123, 39, 34, 67, 111, 109, 109, 97, 110, 100, 115, 32, 115,
  104, 111, 114, 116, 99, 117, 116, 115, 34, 39, 125, 41, 32, 45, 95, 100,
  111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 115, 117, 98,
  115, 101, 99, 116, 105, 111, 110, 95, 97, 115, 99, 105, 105, 91, 45, 49,
  93, 32, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 34, 32, 45,
  118, 32, 45, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 118, 32, 43,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 95, 115, 104, 111, 114, 116,
  99, 117, 116, 10, 45, 101, 91, 93, 32, 34, 32, 32, 32, 32, 45, 34,
  36, 123, 95, 115, 104, 111, 114, 116, 99, 117, 116, 36, 62, 125, 34, 32,
  34, 36, 123, 95, 115, 104, 111, 114, 116, 99, 117, 116, 113, 117, 97, 108,
  105, 102, 105, 101, 114, 36, 62, 125, 34, 58, 32, 101, 113, 46, 32, 116,
  111, 32, 39, 34, 36, 123, 95, 115, 104, 111, 114, 116, 99, 117, 116, 108,
  105, 110, 107, 36, 62, 125, 34, 39, 46, 34, 10, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 45, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32,
  43, 32, 45, 101, 91, 93, 32, 34, 92, 110, 32, 32, 32, 91, 32, 84,
  111, 116, 97, 108, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 99,
  111, 109, 109, 97, 110, 100, 115, 58, 32, 34, 36, 95, 99, 111, 109, 109,
  97, 110, 100, 34, 32, 93, 34, 32, 45, 118, 32, 45, 10, 95, 100, 111,
  99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 115, 112, 108, 105,
  116, 95, 97, 115, 99, 105, 105, 32, 58, 10, 45, 100, 111, 32, 45, 105,
  102, 32, 123, 119, 62, 36, 49, 125, 10, 105, 61, 123, 36, 49, 45, 49,
  125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 49, 47, 50, 125,
  32, 45, 105, 102, 32, 123, 67, 61, 105, 40, 36, 49, 45, 49, 45, 36,
  62, 41, 59, 67, 61, 61, 51, 50, 124, 124, 67, 61, 61, 51, 56, 124,
  124, 67, 61, 61, 52, 50, 124, 124, 67, 61, 61, 52, 51, 124, 124, 67,
  61, 61, 52, 52, 124, 124, 67, 61, 61, 52, 54, 124, 124, 67, 61, 61,
  52, 55, 124, 124, 67, 61, 61, 53, 56, 124, 124, 67, 61, 61, 53, 57,
  124, 124, 67, 61, 61, 54, 51, 124, 124, 67, 61, 61, 57, 50, 124, 124,
  67, 61, 61, 49, 50, 52, 125, 32, 105, 61, 123, 36, 49, 45, 49, 45,
  36, 62, 125, 32, 45, 98, 114, 101, 97, 107, 10, 45, 101, 110, 100, 105,
  102, 32, 45, 100, 111, 110, 101, 10, 45, 45, 122, 91, 45, 49, 93, 32,
  123, 36, 105, 43, 49, 125, 44, 49, 48, 48, 37, 32, 45, 122, 91, 45,
  50, 93, 32, 48, 44, 36, 105, 10, 45, 101, 110, 100, 105, 102, 32, 45,
  119, 104, 105, 108, 101, 32, 123, 119, 62, 36, 49, 125, 10, 95, 100, 111,
  99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 104, 101, 97, 100,
  101, 114, 95, 98, 97, 115, 104, 32, 58, 32, 45, 115, 107, 105, 112, 32,
  36, 49, 10, 45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 34, 92, 35,
  10, 92, 110, 92, 35, 32, 32, 66, 97, 115, 104, 32, 99, 111, 109, 112,
  108, 101, 116, 105, 111, 110, 32, 114, 117, 108, 101, 115, 32, 102, 111, 114,
  32, 39, 103, 109, 105, 99, 39, 46, 10, 92, 110, 92, 35, 10, 92, 110,
  92, 35, 32, 84, 104, 105, 115, 32, 102, 105, 108, 101, 32, 104, 97, 115,
  32, 98, 101, 101, 110, 32, 103, 101, 110, 101, 114, 97, 116, 101, 100, 32,
  97, 117, 116, 111, 109, 97, 116, 105, 99, 97, 108, 108, 121, 46, 10, 92,
  110, 92, 35, 32, 68, 111, 32, 110, 111, 116, 32, 101, 100, 105, 116, 33,
  10, 92, 110, 92, 35, 10, 92, 110, 92, 35, 32, 84, 104, 105, 115, 32,
  102, 105, 108, 101, 32, 115, 104, 111, 117, 108, 100, 32, 98, 101, 32, 99,
  111, 112, 105, 101, 100, 47, 114, 101, 110, 97, 109, 101, 100, 32, 105, 110,
  32, 39, 47, 101, 116, 99, 47, 98, 97, 115, 104, 95, 99, 111, 109, 112,
  108, 101, 116, 105, 111, 110, 46, 100, 47, 103, 109, 105, 99, 39, 46, 10,
  92, 110, 92, 35, 10, 92, 110, 10, 92, 110, 95, 34, 36, 95, 110, 97,
  109, 101, 34, 40, 41, 10, 92, 110, 123, 10, 92, 110, 92, 116, 108, 111,
  99, 97, 108, 32, 99, 117, 114, 32, 112, 114, 101, 118, 32, 111, 112, 116,
  115, 32, 99, 111, 109, 115, 10, 92, 110, 92, 116, 67, 79, 77, 80, 82,
  69, 80, 76, 89, 61, 40, 41, 10, 92, 110, 92, 116, 99, 117, 114, 61,
  92, 34, 36, 123, 67, 79, 77, 80, 95, 87, 79, 82, 68, 83, 91, 67,
  79, 77, 80, 95, 67, 87, 79, 82, 68, 93, 125, 92, 34, 10, 92, 110,
  92, 116, 112, 114, 101, 118, 61, 92, 34, 36, 123, 67, 79, 77, 80, 95,
  87, 79, 82, 68, 83, 91, 67, 79, 77, 80, 95, 67, 87, 79, 82, 68,
  45, 49, 93, 125, 92, 34, 10, 34, 10, 45, 118, 32, 45, 10, 95, 111,
  112, 116, 115, 61, 10, 95, 99, 111, 109, 115, 61, 10, 95, 97, 114, 103,
  99, 111, 109, 109, 97, 110, 100, 61, 48, 10, 95, 115, 104, 111, 114, 116,
  99, 117, 116, 61, 48, 10, 95, 110, 98, 111, 112, 116, 115, 61, 48, 10,
  95, 110, 98, 99, 111, 109, 115, 61, 48, 10, 95, 100, 111, 99, 117, 109,
  101, 110, 116, 95, 103, 109, 105, 99, 95, 115, 117, 98, 115, 101, 99, 116,
  105, 111, 110, 95, 98, 97, 115, 104, 32, 58, 10, 95, 100, 111, 99, 117,
  109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 100, 101, 115, 99, 114, 105,
  112, 116, 105, 111, 110, 95, 98, 97, 115, 104, 32, 58, 10, 95, 100, 111,
  99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 101, 120, 97, 109,
  112, 108, 101, 95, 98, 97, 115, 104, 32, 58, 10, 95, 100, 111, 99, 117,
  109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 100, 101, 99, 108, 97, 114,
  97, 116, 105, 111, 110, 95, 98, 97, 115, 104, 32, 58, 10, 95, 111, 112,
  116, 115, 36, 95, 110, 98, 111, 112, 116, 115, 61, 45, 64, 123, 48, 44,
  116, 125, 34, 32, 34, 45, 45, 64, 123, 48, 44, 116, 125, 10, 95, 110,
  98, 111, 112, 116, 115, 61, 123, 36, 95, 110, 98, 111, 112, 116, 115, 43,
  49, 125, 10, 95, 99, 111, 109, 115, 36, 95, 110, 98, 99, 111, 109, 115,
  61, 64, 123, 48, 44, 116, 125, 10, 95, 110, 98, 99, 111, 109, 115, 61,
  123, 36, 95, 110, 98, 99, 111, 109, 115, 43, 49, 125, 10, 45, 105, 102,
  32, 123, 123, 64, 123, 48, 44, 116, 125, 39, 61, 61, 39, 34, 105, 110,
  112, 117, 116, 34, 125, 34, 32, 124, 124, 32, 34, 123, 64, 123, 48, 44,
  116, 125, 39, 61, 61, 39, 34, 105, 34, 125, 34, 32, 124, 124, 32, 34,
  92, 10, 123, 64, 123, 48, 44, 116, 125, 39, 61, 61, 39, 34, 111, 117,
  116, 112, 117, 116, 34, 125, 34, 32, 124, 124, 32, 34, 123, 64, 123, 48,
  44, 116, 125, 39, 61, 61, 39, 34, 111, 34, 125, 34, 32, 124, 124, 32,
  34, 92, 10, 123, 64, 123, 48, 44, 116, 125, 39, 61, 61, 39, 34, 99,
  111, 109, 109, 97, 110, 100, 34, 125, 34, 32, 124, 124, 32, 34, 123, 64,
  123, 48, 44, 116, 125, 39, 61, 61, 39, 34, 109, 34, 125, 125, 32, 45,
  114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 105, 102, 32, 123, 123, 64,
  123, 36, 60, 44, 116, 125, 39, 61, 61, 39, 34, 40, 42, 41, 34, 125,
  124, 124, 123, 64, 123, 36, 60, 44, 116, 125, 39, 61, 61, 39, 34, 40,
  43, 41, 34, 125, 125, 32, 45, 114, 109, 91, 36, 60, 93, 32, 45, 101,
  110, 100, 105, 102, 32, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123,
  64, 35, 61, 61, 50, 34, 32, 38, 38, 32, 34, 123, 64, 123, 45, 49,
  44, 48, 45, 54, 125, 39, 61, 61, 39, 123, 39, 34, 101, 113, 46, 32,
  116, 111, 32, 34, 39, 125, 125, 125, 10, 45, 114, 111, 119, 115, 91, 45,
  49, 93, 32, 55, 44, 49, 48, 48, 37, 32, 45, 97, 117, 116, 111, 99,
  114, 111, 112, 91, 45, 49, 93, 32, 123, 39, 46, 39, 125, 32, 45, 97,
  117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 123, 39, 34, 32,
  34, 39, 125, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49,
  93, 32, 51, 57, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45,
  49, 93, 32, 123, 39, 45, 39, 125, 10, 95, 115, 104, 111, 114, 116, 99,
  117, 116, 36, 95, 115, 104, 111, 114, 116, 99, 117, 116, 61, 64, 123, 48,
  44, 116, 125, 10, 95, 115, 104, 111, 114, 116, 99, 117, 116, 108, 105, 110,
  107, 36, 95, 115, 104, 111, 114, 116, 99, 117, 116, 61, 64, 123, 45, 115,
  116, 114, 50, 104, 101, 120, 92, 32, 64, 123, 49, 44, 116, 125, 125, 10,
  45, 114, 109, 91, 45, 49, 93, 10, 95, 115, 104, 111, 114, 116, 99, 117,
  116, 61, 123, 36, 95, 115, 104, 111, 114, 116, 99, 117, 116, 43, 49, 125,
  10, 45, 101, 108, 105, 102, 32, 123, 64, 35, 62, 49, 125, 10, 95, 99,
  111, 109, 109, 97, 110, 100, 36, 95, 97, 114, 103, 99, 111, 109, 109, 97,
  110, 100, 61, 64, 123, 48, 44, 116, 125, 10, 45, 105, 102, 32, 123, 64,
  123, 48, 44, 116, 125, 39, 61, 61, 39, 34, 104, 101, 108, 112, 34, 125,
  32, 95, 97, 114, 103, 117, 109, 101, 110, 116, 36, 95, 97, 114, 103, 99,
  111, 109, 109, 97, 110, 100, 61, 34, 36, 99, 111, 109, 115, 92, 34, 32,
  45, 45, 32, 92, 34, 36, 99, 117, 114, 34, 10, 45, 101, 108, 115, 101,
  10, 45, 105, 102, 32, 123, 64, 35, 61, 61, 50, 125, 32, 40, 123, 39,
  62, 39, 125, 41, 32, 45, 101, 110, 100, 105, 102, 10, 45, 100, 105, 115,
  99, 97, 114, 100, 91, 94, 48, 93, 32, 123, 39, 34, 32, 34, 39, 125,
  32, 45, 105, 91, 50, 45, 45, 50, 93, 32, 40, 123, 39, 34, 32, 34,
  39, 125, 41, 32, 45, 97, 91, 94, 48, 93, 32, 121, 10, 95, 97, 114,
  103, 117, 109, 101, 110, 116, 36, 95, 97, 114, 103, 99, 111, 109, 109, 97,
  110, 100, 61, 64, 123, 49, 44, 116, 125, 10, 45, 101, 110, 100, 105, 102,
  10, 95, 97, 114, 103, 117, 109, 101, 110, 116, 108, 105, 110, 107, 64, 123,
  45, 115, 116, 114, 50, 104, 101, 120, 92, 32, 64, 123, 48, 44, 116, 125,
  125, 61, 36, 123, 95, 97, 114, 103, 117, 109, 101, 110, 116, 36, 95, 97,
  114, 103, 99, 111, 109, 109, 97, 110, 100, 125, 10, 95, 97, 114, 103, 99,
  111, 109, 109, 97, 110, 100, 61, 123, 36, 95, 97, 114, 103, 99, 111, 109,
  109, 97, 110, 100, 43, 49, 125, 10, 45, 101, 110, 100, 105, 102, 10, 95,
  100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 102, 111,
  111, 116, 101, 114, 95, 98, 97, 115, 104, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 36, 49, 10, 45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 34,
  92, 116, 111, 112, 116, 115, 61, 92, 34, 92, 92, 34, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 36, 95, 110, 98, 111, 112, 116, 115, 32, 45, 101,
  91, 93, 32, 34, 92, 116, 32, 32, 32, 32, 32, 32, 34, 36, 123, 95,
  111, 112, 116, 115, 36, 62, 125, 92, 92, 32, 45, 100, 111, 110, 101, 32,
  45, 101, 91, 93, 32, 34, 92, 116, 32, 32, 32, 32, 32, 92, 34, 34,
  10, 45, 101, 91, 93, 32, 34, 92, 110, 92, 116, 99, 111, 109, 115, 61,
  92, 34, 92, 92, 34, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 95,
  110, 98, 99, 111, 109, 115, 32, 45, 101, 91, 93, 32, 34, 92, 116, 32,
  32, 32, 32, 32, 32, 34, 36, 123, 95, 99, 111, 109, 115, 36, 62, 125,
  92, 92, 32, 45, 100, 111, 110, 101, 32, 45, 101, 91, 93, 32, 34, 92,
  116, 32, 32, 32, 32, 32, 92, 34, 34, 10, 45, 101, 91, 93, 32, 34,
  92, 110, 92, 116, 99, 97, 115, 101, 32, 92, 34, 36, 123, 112, 114, 101,
  118, 125, 92, 34, 32, 105, 110, 34, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 36, 95, 97, 114, 103, 99, 111, 109, 109, 97, 110, 100, 10, 45, 101,
  91, 93, 32, 34, 92, 116, 92, 116, 92, 34, 45, 34, 36, 123, 95, 99,
  111, 109, 109, 97, 110, 100, 36, 62, 125, 34, 92, 34, 32, 124, 32, 92,
  34, 45, 45, 34, 36, 123, 95, 99, 111, 109, 109, 97, 110, 100, 36, 62,
  125, 34, 92, 34, 41, 34, 10, 45, 101, 91, 93, 32, 34, 92, 116, 92,
  116, 67, 79, 77, 80, 82, 69, 80, 76, 89, 61, 40, 32, 36, 40, 99,
  111, 109, 112, 103, 101, 110, 32, 45, 87, 32, 92, 34, 34, 36, 123, 95,
  97, 114, 103, 117, 109, 101, 110, 116, 36, 62, 125, 34, 92, 34, 41, 32,
  41, 92, 110, 92, 116, 92, 116, 114, 101, 116, 117, 114, 110, 32, 48, 92,
  110, 92, 116, 92, 116, 59, 59, 34, 10, 45, 100, 111, 110, 101, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 36, 95, 115, 104, 111, 114, 116, 99, 117,
  116, 10, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40, 36, 123, 95, 97,
  114, 103, 117, 109, 101, 110, 116, 108, 105, 110, 107, 36, 123, 95, 115, 104,
  111, 114, 116, 99, 117, 116, 108, 105, 110, 107, 36, 62, 125, 125, 41, 125,
  10, 45, 101, 91, 93, 32, 34, 92, 116, 92, 116, 92, 34, 45, 34, 36,
  123, 95, 115, 104, 111, 114, 116, 99, 117, 116, 36, 62, 125, 34, 92, 34,
  32, 124, 32, 92, 34, 45, 45, 34, 36, 123, 95, 115, 104, 111, 114, 116,
  99, 117, 116, 36, 62, 125, 34, 92, 34, 41, 34, 10, 45, 101, 91, 93,
  32, 34, 92, 116, 92, 116, 67, 79, 77, 80, 82, 69, 80, 76, 89, 61,
  40, 32, 36, 40, 99, 111, 109, 112, 103, 101, 110, 32, 45, 87, 32, 92,
  34, 34, 36, 123, 95, 97, 114, 103, 117, 109, 101, 110, 116, 108, 105, 110,
  107, 36, 123, 95, 115, 104, 111, 114, 116, 99, 117, 116, 108, 105, 110, 107,
  36, 62, 125, 125, 34, 92, 34, 41, 32, 41, 92, 110, 92, 116, 92, 116,
  114, 101, 116, 117, 114, 110, 32, 48, 92, 110, 92, 116, 92, 116, 59, 59,
  34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45,
  101, 91, 93, 32, 34, 92, 116, 101, 115, 97, 99, 34, 10, 45, 101, 91,
  93, 32, 34, 92, 110, 92, 116, 105, 102, 32, 91, 91, 32, 92, 34, 36,
  99, 117, 114, 92, 34, 32, 61, 61, 32, 45, 42, 32, 93, 93, 32, 59,
  32, 116, 104, 101, 110, 10, 92, 110, 92, 116, 92, 116, 67, 79, 77, 80,
  82, 69, 80, 76, 89, 61, 40, 32, 36, 40, 99, 111, 109, 112, 103, 101,
  110, 32, 45, 87, 32, 92, 34, 36, 111, 112, 116, 115, 92, 34, 32, 45,
  45, 32, 92, 34, 36, 99, 117, 114, 92, 34, 41, 32, 41, 10, 92, 110,
  92, 116, 101, 108, 115, 101, 10, 92, 110, 92, 116, 92, 116, 95, 102, 105,
  108, 101, 100, 105, 114, 10, 92, 110, 92, 116, 102, 105, 10, 92, 110, 10,
  92, 110, 125, 10, 92, 110, 10, 99, 111, 109, 112, 108, 101, 116, 101, 32,
  45, 70, 32, 95, 34, 36, 95, 110, 97, 109, 101, 34, 32, 45, 111, 32,
  102, 105, 108, 101, 110, 97, 109, 101, 115, 32, 103, 109, 105, 99, 34, 10,
  45, 118, 32, 45, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103,
  109, 105, 99, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 87, 36, 62, 61, 123, 119, 125, 32,
  72, 36, 62, 61, 123, 104, 125, 32, 68, 36, 62, 61, 123, 100, 125, 32,
  83, 36, 62, 61, 123, 115, 125, 32, 73, 83, 95, 51, 68, 36, 62, 61,
  64, 123, 45, 105, 115, 95, 51, 100, 125, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 45, 105, 102, 32, 64, 123, 45, 105,
  115, 95, 51, 100, 125, 32, 45, 114, 51, 100, 32, 49, 44, 49, 44, 48,
  44, 45, 56, 48, 32, 45, 114, 51, 100, 32, 48, 44, 49, 44, 48, 44,
  56, 48, 32, 45, 115, 110, 97, 112, 115, 104, 111, 116, 51, 100, 32, 52,
  48, 48, 32, 45, 101, 108, 115, 101, 32, 45, 110, 32, 48, 44, 50, 53,
  53, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 45, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105,
  108, 101, 115, 32, 44, 32, 45, 105, 102, 32, 123, 119, 62, 57, 48, 48,
  125, 32, 114, 61, 123, 114, 111, 117, 110, 100, 40, 57, 48, 48, 42, 49,
  48, 48, 47, 119, 44, 48, 46, 49, 41, 125, 32, 45, 114, 91, 94, 45,
  49, 93, 32, 36, 114, 37, 44, 36, 114, 37, 44, 49, 44, 49, 48, 48,
  37, 44, 50, 32, 45, 101, 110, 100, 105, 102, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 115, 61, 61, 49, 125, 32,
  45, 114, 32, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 51, 32, 45,
  101, 108, 115, 101, 32, 45, 114, 32, 123, 119, 125, 44, 123, 104, 125, 44,
  49, 44, 51, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 119, 60, 61, 104, 38, 38, 104, 60, 50, 53, 54, 125, 32, 45,
  114, 50, 100, 121, 32, 50, 53, 54, 44, 50, 32, 45, 101, 108, 105, 102,
  32, 123, 104, 60, 61, 119, 38, 38, 119, 60, 50, 53, 54, 125, 32, 45,
  114, 50, 100, 120, 32, 50, 53, 54, 44, 50, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 119, 60, 61, 104, 38, 38, 104, 62, 53,
  49, 50, 125, 32, 45, 114, 50, 100, 121, 32, 53, 49, 50, 44, 50, 32,
  45, 101, 108, 105, 102, 32, 123, 104, 60, 61, 119, 38, 38, 119, 62, 53,
  49, 50, 125, 32, 45, 114, 50, 100, 120, 32, 53, 49, 50, 44, 50, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 104, 60, 52, 56,
  125, 32, 45, 114, 32, 49, 48, 48, 37, 44, 52, 56, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 119, 60, 52, 56, 125, 32, 45,
  114, 32, 52, 56, 44, 49, 48, 48, 37, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 102, 114, 97, 109, 101, 32, 49, 44, 49, 44, 48, 32, 45, 102,
  114, 97, 109, 101, 32, 52, 44, 52, 44, 50, 53, 53, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 78, 61, 64, 35, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 78, 32, 45, 108, 91, 36, 62, 93, 10,
  123, 119, 125, 44, 50, 52, 44, 49, 44, 51, 44, 50, 53, 53, 10, 45,
  105, 102, 32, 123, 119, 62, 55, 53, 125, 10, 45, 105, 102, 32, 123, 36,
  78, 62, 49, 125, 32, 45, 105, 102, 32, 123, 119, 62, 49, 49, 48, 125,
  32, 45, 116, 91, 45, 49, 93, 32, 73, 109, 97, 103, 101, 92, 32, 91,
  36, 62, 93, 58, 44, 51, 44, 51, 44, 49, 55, 32, 45, 101, 108, 115,
  101, 32, 45, 116, 91, 45, 49, 93, 32, 91, 36, 62, 93, 58, 44, 51,
  44, 51, 44, 49, 55, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 36, 123, 73, 83, 95, 51, 68, 36,
  62, 125, 32, 48, 32, 45, 116, 91, 45, 49, 93, 32, 40, 51, 100, 92,
  32, 111, 98, 106, 101, 99, 116, 41, 44, 48, 44, 48, 44, 49, 51, 44,
  49, 44, 50, 53, 53, 10, 45, 101, 108, 115, 101, 32, 48, 32, 45, 116,
  91, 45, 49, 93, 32, 40, 36, 123, 87, 36, 62, 125, 120, 36, 123, 72,
  36, 62, 125, 120, 36, 123, 68, 36, 62, 125, 120, 36, 123, 83, 36, 62,
  125, 41, 44, 48, 44, 48, 44, 49, 51, 44, 49, 44, 50, 53, 53, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 110, 101, 103, 97, 116, 105, 118, 101,
  91, 45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 32, 45, 43, 91, 45, 49, 93, 32, 49, 54, 52, 32, 45, 99, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 116, 111, 95, 114, 103,
  98, 91, 45, 49, 93, 10, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 123, 64, 123, 45, 50, 44, 119, 125, 45, 119, 45, 53, 125, 44,
  123, 64, 123, 45, 50, 44, 104, 125, 45, 104, 45, 53, 125, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 101, 108, 115, 101, 32, 45, 116, 91, 45,
  49, 93, 32, 91, 36, 62, 93, 58, 44, 51, 44, 51, 44, 49, 55, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 114, 118, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 45, 32, 50, 53, 53,
  32, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 32, 44,
  32, 45, 43, 32, 50, 53, 53, 10, 45, 105, 102, 32, 123, 119, 60, 50,
  53, 54, 125, 32, 45, 45, 32, 50, 53, 53, 32, 45, 114, 32, 50, 53,
  54, 44, 49, 48, 48, 37, 44, 49, 44, 51, 44, 48, 44, 48, 44, 48,
  46, 53, 44, 48, 46, 53, 32, 45, 43, 32, 50, 53, 53, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 104, 60, 50, 53, 54, 125,
  32, 45, 45, 32, 50, 53, 53, 32, 45, 114, 32, 49, 48, 48, 37, 44,
  50, 53, 54, 44, 49, 44, 51, 44, 48, 44, 48, 44, 48, 46, 53, 44,
  48, 46, 53, 32, 45, 43, 32, 50, 53, 53, 32, 45, 101, 110, 100, 105,
  102, 10, 35, 64, 103, 109, 105, 99, 32, 101, 32, 58, 32, 101, 113, 46,
  32, 116, 111, 32, 39, 45, 101, 99, 104, 111, 39, 46, 32, 58, 32, 40,
  42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 101, 99, 104, 111, 32, 58,
  32, 109, 101, 115, 115, 97, 103, 101, 32, 58, 32, 40, 42, 41, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 109, 101, 115, 115, 97, 103, 101,
  44, 32, 111, 110, 32, 116, 104, 101, 32, 101, 114, 114, 111, 114, 32, 111,
  117, 116, 112, 117, 116, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 101, 39, 41, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 109, 97, 110, 100, 32,
  115, 117, 98, 115, 101, 116, 32, 40, 105, 102, 32, 97, 110, 121, 41, 32,
  115, 116, 97, 110, 100, 115, 32, 102, 111, 114, 32, 100, 105, 115, 112, 108,
  97, 121, 101, 100, 32, 115, 99, 111, 112, 101, 32, 105, 110, 100, 105, 99,
  101, 115, 32, 105, 110, 115, 116, 101, 97, 100, 32, 111, 102, 32, 105, 109,
  97, 103, 101, 32, 105, 110, 100, 105, 99, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 101, 99, 104, 111, 95, 102, 105, 108, 101, 32, 58, 32,
  102, 105, 108, 101, 110, 97, 109, 101, 44, 109, 101, 115, 115, 97, 103, 101,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 79, 117, 116, 112, 117, 116,
  32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 109, 101, 115, 115, 97,
  103, 101, 44, 32, 97, 112, 112, 101, 110, 100, 105, 110, 103, 32, 105, 116,
  32, 116, 111, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 111, 117,
  116, 112, 117, 116, 32, 102, 105, 108, 101, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 40, 115, 105, 109, 105, 108, 97, 114, 32, 116, 111, 32,
  39, 45, 101, 99, 104, 111, 39, 32, 102, 111, 114, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 111, 117, 116, 112, 117, 116, 32, 102, 105, 108,
  101, 32, 115, 116, 114, 101, 97, 109, 41, 46, 10, 101, 99, 104, 111, 95,
  102, 105, 108, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50,
  61, 39, 92, 110, 39, 125, 10, 45, 118, 32, 45, 32, 40, 123, 34, 39,
  36, 123, 50, 45, 45, 49, 125, 92, 110, 39, 34, 125, 41, 32, 45, 111,
  91, 45, 49, 93, 32, 114, 97, 119, 58, 36, 49, 44, 117, 99, 104, 97,
  114, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 101, 99, 104, 111, 95, 115, 116, 100, 111, 117,
  116, 32, 58, 32, 109, 101, 115, 115, 97, 103, 101, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 109, 101, 115, 115, 97, 103, 101, 44, 32, 111,
  110, 32, 116, 104, 101, 32, 115, 116, 97, 110, 100, 97, 114, 100, 32, 111,
  117, 116, 112, 117, 116, 32, 40, 115, 116, 100, 111, 117, 116, 41, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 115, 105, 109, 105, 108, 97,
  114, 32, 116, 111, 32, 39, 45, 101, 99, 104, 111, 39, 32, 102, 111, 114,
  32, 111, 117, 116, 112, 117, 116, 32, 111, 110, 32, 115, 116, 97, 110, 100,
  97, 114, 100, 32, 111, 117, 116, 112, 117, 116, 32, 105, 110, 115, 116, 101,
  97, 100, 32, 111, 102, 32, 115, 116, 97, 110, 100, 97, 114, 100, 32, 101,
  114, 114, 111, 114, 41, 46, 10, 101, 99, 104, 111, 95, 115, 116, 100, 111,
  117, 116, 32, 58, 10, 45, 118, 32, 45, 32, 40, 123, 39, 34, 36, 42,
  34, 92, 110, 39, 125, 41, 32, 45, 111, 91, 45, 49, 93, 32, 45, 46,
  114, 97, 119, 44, 117, 99, 104, 97, 114, 32, 45, 114, 109, 91, 45, 49,
  93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 102, 117,
  110, 99, 116, 105, 111, 110, 49, 100, 32, 58, 32, 48, 60, 61, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 60, 61, 49, 44, 120, 48, 62, 61,
  48, 44, 121, 48, 44, 120, 49, 62, 61, 48, 44, 121, 49, 44, 46, 46,
  46, 44, 120, 110, 62, 61, 48, 44, 121, 110, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 73, 110, 112, 117, 116, 32, 99, 111, 110, 116, 105, 110,
  117, 111, 117, 115, 32, 49, 100, 32, 102, 117, 110, 99, 116, 105, 111, 110,
  32, 102, 114, 111, 109, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  108, 105, 115, 116, 32, 111, 102, 32, 107, 101, 121, 112, 111, 105, 110, 116,
  115, 32, 40, 120, 107, 44, 121, 107, 41, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 105, 110, 32, 114, 97, 110, 103, 101, 32, 91, 48, 44, 109,
  97, 120, 40, 120, 107, 41, 93, 32, 40, 120, 107, 32, 97, 114, 101, 32,
  112, 111, 115, 105, 116, 105, 118, 101, 32, 105, 110, 116, 101, 103, 101, 114,
  115, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 61, 49, 39, 32, 97, 110, 100, 32,
  39, 120, 48, 61, 121, 48, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 45, 102, 117, 110, 99, 116, 105, 111, 110, 49,
  100, 32, 49, 44, 48, 44, 48, 44, 49, 48, 44, 51, 48, 44, 52, 48,
  44, 50, 48, 44, 55, 48, 44, 51, 48, 44, 56, 48, 44, 48, 32, 45,
  45, 100, 105, 115, 112, 108, 97, 121, 95, 103, 114, 97, 112, 104, 32, 52,
  48, 48, 44, 51, 48, 48, 10, 102, 117, 110, 99, 116, 105, 111, 110, 49,
  100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61,
  49, 125, 62, 61, 48, 32, 38, 38, 32, 36, 49, 60, 61, 49, 34, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 48, 125, 44, 36, 123, 51,
  61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112,
  117, 116, 32, 99, 111, 110, 116, 105, 110, 117, 111, 117, 115, 32, 49, 100,
  32, 102, 117, 110, 99, 116, 105, 111, 110, 44, 32, 119, 105, 116, 104, 32,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 49, 32, 97, 110,
  100, 32, 107, 101, 121, 112, 111, 105, 110, 116, 115, 32, 40, 36, 123, 50,
  45, 45, 49, 125, 41, 46, 34, 10, 45, 118, 32, 45, 10, 45, 105, 102,
  32, 123, 36, 35, 60, 53, 125, 32, 123, 109, 97, 120, 40, 48, 44, 36,
  50, 41, 43, 49, 125, 44, 49, 44, 49, 44, 49, 44, 36, 51, 32, 45,
  118, 32, 43, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100,
  105, 102, 10, 40, 36, 123, 50, 45, 45, 49, 125, 41, 32, 45, 114, 91,
  45, 49, 93, 32, 50, 44, 123, 119, 47, 50, 125, 44, 49, 44, 49, 44,
  45, 49, 32, 45, 115, 111, 114, 116, 91, 45, 49, 93, 32, 43, 44, 121,
  32, 45, 115, 91, 45, 49, 93, 32, 120, 44, 50, 32, 45, 114, 111, 117,
  110, 100, 91, 45, 50, 93, 32, 49, 32, 45, 97, 91, 45, 50, 44, 45,
  49, 93, 32, 120, 10, 45, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93,
  32, 48, 44, 49, 44, 48, 44, 48, 44, 49, 32, 45, 45, 91, 45, 49,
  93, 32, 91, 45, 50, 93, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49,
  10, 45, 45, 115, 104, 105, 102, 116, 91, 45, 50, 93, 32, 48, 44, 45,
  49, 44, 48, 44, 48, 44, 49, 32, 45, 45, 91, 45, 49, 93, 32, 91,
  45, 51, 93, 10, 45, 45, 42, 91, 45, 50, 93, 32, 123, 36, 49, 47,
  50, 125, 32, 45, 45, 42, 91, 45, 50, 93, 32, 123, 49, 45, 36, 49,
  47, 50, 125, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 42,
  91, 45, 51, 93, 32, 123, 49, 45, 36, 49, 47, 50, 125, 32, 45, 42,
  91, 45, 50, 93, 32, 123, 36, 49, 47, 50, 125, 32, 45, 43, 91, 45,
  51, 44, 45, 50, 93, 10, 45, 115, 91, 45, 50, 44, 45, 49, 93, 32,
  120, 32, 45, 43, 91, 45, 52, 44, 45, 50, 93, 32, 49, 101, 45, 49,
  48, 10, 45, 47, 91, 45, 51, 93, 32, 91, 45, 52, 93, 32, 45, 47,
  91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 114, 109, 91, 45, 52,
  44, 45, 50, 93, 10, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 120,
  10, 123, 64, 123, 45, 49, 44, 40, 48, 44, 123, 104, 45, 49, 125, 41,
  125, 43, 49, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 123,
  45, 50, 44, 104, 125, 45, 49, 125, 10, 120, 115, 116, 97, 114, 116, 61,
  123, 105, 102, 40, 36, 62, 44, 64, 123, 45, 50, 44, 48, 125, 44, 48,
  41, 125, 10, 45, 95, 102, 117, 110, 99, 116, 105, 111, 110, 49, 100, 32,
  64, 123, 45, 50, 44, 48, 45, 49, 125, 44, 64, 123, 45, 50, 44, 51,
  125, 44, 64, 123, 45, 50, 44, 52, 45, 54, 125, 44, 36, 120, 115, 116,
  97, 114, 116, 44, 64, 123, 45, 50, 44, 52, 125, 32, 45, 106, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 44, 36, 120, 115, 116, 97, 114, 116, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 105, 102, 116, 91, 45,
  50, 93, 32, 48, 44, 45, 49, 32, 45, 100, 111, 110, 101, 10, 45, 114,
  109, 91, 45, 50, 93, 32, 45, 110, 109, 91, 45, 49, 93, 32, 34, 91,
  49, 100, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 40, 36, 123, 50,
  45, 45, 49, 125, 41, 93, 34, 10, 45, 118, 32, 43, 10, 95, 102, 117,
  110, 99, 116, 105, 111, 110, 49, 100, 32, 58, 10, 40, 123, 36, 49, 94,
  51, 125, 44, 123, 36, 49, 94, 50, 125, 44, 36, 49, 44, 49, 59, 92,
  10, 123, 51, 42, 36, 49, 94, 50, 125, 44, 123, 50, 42, 36, 49, 125,
  44, 49, 44, 48, 59, 92, 10, 123, 36, 52, 94, 51, 125, 44, 123, 36,
  52, 94, 50, 125, 44, 36, 52, 44, 49, 59, 92, 10, 123, 51, 42, 36,
  52, 94, 50, 125, 44, 123, 50, 42, 36, 52, 125, 44, 49, 44, 48, 41,
  10, 40, 36, 50, 59, 36, 51, 59, 36, 53, 59, 36, 54, 41, 32, 45,
  115, 111, 108, 118, 101, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45,
  114, 109, 91, 45, 50, 93, 32, 45, 116, 114, 97, 110, 115, 112, 111, 115,
  101, 91, 45, 49, 93, 10, 40, 36, 55, 44, 36, 56, 41, 32, 45, 114,
  91, 45, 49, 93, 32, 123, 49, 43, 36, 56, 45, 36, 55, 125, 44, 49,
  44, 49, 44, 49, 44, 51, 32, 45, 45, 94, 91, 45, 49, 93, 32, 51,
  32, 45, 45, 94, 91, 45, 50, 93, 32, 50, 32, 45, 45, 102, 91, 45,
  49, 93, 32, 49, 32, 45, 109, 118, 91, 45, 52, 93, 32, 45, 49, 32,
  45, 97, 91, 45, 52, 45, 45, 49, 93, 32, 121, 10, 45, 42, 42, 91,
  45, 50, 44, 45, 49, 93, 10, 35, 64, 103, 109, 105, 99, 32, 103, 109,
  105, 99, 107, 121, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 76, 111,
  97, 100, 32, 97, 32, 110, 101, 119, 32, 105, 109, 97, 103, 101, 32, 111,
  102, 32, 116, 104, 101, 32, 71, 39, 77, 73, 67, 32, 109, 97, 115, 99,
  111, 116, 32, 39, 71, 109, 105, 99, 107, 121, 39, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 45, 103, 109, 105, 99, 107, 121, 10,
  103, 109, 105, 99, 107, 121, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 76, 111, 97, 100, 32, 105, 109, 97, 103, 101, 32, 111, 102, 32,
  116, 104, 101, 32, 71, 39, 77, 73, 67, 32, 109, 97, 115, 99, 111, 116,
  32, 39, 71, 109, 105, 99, 107, 121, 39, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 105, 32, 104, 116, 116, 112, 58, 47, 47, 103, 109, 105, 99, 46,
  115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47,
  105, 109, 103, 47, 103, 109, 105, 99, 107, 121, 95, 108, 97, 114, 103, 101,
  46, 99, 105, 109, 103, 122, 32, 45, 110, 109, 91, 45, 49, 93, 32, 91,
  103, 109, 105, 99, 107, 121, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 103, 109, 105, 99, 107, 121, 95, 119, 105, 108, 98, 101,
  114, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 76, 111, 97, 100, 32,
  97, 32, 110, 101, 119, 32, 105, 109, 97, 103, 101, 32, 111, 102, 32, 116,
  104, 101, 32, 71, 39, 77, 73, 67, 32, 109, 97, 115, 99, 111, 116, 32,
  39, 71, 109, 105, 99, 107, 121, 39, 32, 116, 111, 103, 101, 116, 104, 101,
  114, 32, 119, 105, 116, 104, 32, 71, 73, 77, 80, 32, 109, 97, 115, 99,
  111, 116, 32, 39, 87, 105, 108, 98, 101, 114, 39, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 45, 103, 109, 105, 99, 107, 121, 95,
  119, 105, 108, 98, 101, 114, 10, 103, 109, 105, 99, 107, 121, 95, 119, 105,
  108, 98, 101, 114, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  76, 111, 97, 100, 32, 105, 109, 97, 103, 101, 32, 111, 102, 32, 116, 104,
  101, 32, 71, 39, 77, 73, 67, 32, 109, 97, 115, 99, 111, 116, 32, 39,
  71, 109, 105, 99, 107, 121, 39, 32, 116, 111, 103, 101, 116, 104, 101, 114,
  32, 119, 105, 116, 104, 32, 71, 73, 77, 80, 32, 109, 97, 115, 99, 111,
  116, 32, 39, 87, 105, 108, 98, 101, 114, 39, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 105, 32, 104, 116, 116, 112, 58, 47, 47, 103, 109, 105, 99,
  46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116,
  47, 105, 109, 103, 47, 103, 109, 105, 99, 107, 121, 95, 119, 105, 108, 98,
  101, 114, 95, 108, 97, 114, 103, 101, 46, 99, 105, 109, 103, 122, 32, 45,
  110, 109, 91, 45, 49, 93, 32, 91, 103, 109, 105, 99, 107, 121, 95, 119,
  105, 108, 98, 101, 114, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109,
  105, 99, 32, 104, 101, 97, 114, 116, 32, 58, 32, 95, 119, 105, 100, 116,
  104, 62, 48, 44, 95, 104, 101, 105, 103, 104, 116, 62, 48, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 73, 110, 112, 117, 116, 32, 104, 101, 97,
  114, 116, 32, 98, 105, 110, 97, 114, 121, 32, 109, 97, 115, 107, 32, 119,
  105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 115, 105,
  122, 101, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45,
  104, 101, 97, 114, 116, 32, 44, 10, 104, 101, 97, 114, 116, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 53, 49, 50, 125,
  62, 61, 49, 32, 38, 38, 32, 36, 123, 50, 61, 36, 49, 125, 62, 61,
  49, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117,
  116, 32, 36, 49, 120, 36, 50, 32, 104, 101, 97, 114, 116, 32, 98, 105,
  110, 97, 114, 121, 32, 109, 97, 115, 107, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 108, 91, 93, 10, 50, 48, 52, 56, 44, 49, 44, 49, 44, 49,
  44, 39, 116, 61, 50, 42, 112, 105, 42, 120, 47, 119, 59, 49, 54, 42,
  115, 105, 110, 40, 116, 41, 94, 51, 39, 10, 50, 48, 52, 56, 44, 49,
  44, 49, 44, 49, 44, 39, 116, 61, 50, 42, 112, 105, 42, 120, 47, 119,
  59, 49, 51, 42, 99, 111, 115, 40, 116, 41, 45, 53, 42, 99, 111, 115,
  40, 50, 42, 116, 41, 45, 50, 42, 99, 111, 115, 40, 51, 42, 116, 41,
  45, 99, 111, 115, 40, 52, 42, 116, 41, 39, 10, 45, 97, 32, 99, 32,
  45, 100, 105, 115, 112, 108, 97, 121, 95, 112, 97, 114, 97, 109, 101, 116,
  114, 105, 99, 32, 36, 49, 44, 36, 50, 44, 49, 44, 48, 44, 48, 44,
  48, 10, 45, 102, 108, 111, 111, 100, 32, 53, 48, 37, 44, 53, 48, 37,
  44, 48, 44, 48, 44, 48, 44, 49, 44, 48, 32, 45, 101, 113, 91, 45,
  49, 93, 32, 48, 10, 45, 110, 109, 32, 34, 91, 72, 101, 97, 114, 116,
  32, 98, 105, 110, 97, 114, 121, 32, 109, 97, 115, 107, 93, 34, 10, 45,
  101, 110, 100, 108, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 105, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 105, 110,
  112, 117, 116, 39, 46, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109,
  105, 99, 32, 105, 110, 112, 117, 116, 32, 58, 32, 91, 116, 121, 112, 101,
  58, 93, 102, 105, 108, 101, 110, 97, 109, 101, 32, 58, 32, 91, 116, 121,
  112, 101, 58, 93, 104, 116, 116, 112, 58, 47, 47, 85, 82, 76, 32, 58,
  32, 91, 115, 101, 108, 101, 99, 116, 105, 111, 110, 93, 120, 95, 110, 98,
  95, 99, 111, 112, 105, 101, 115, 62, 48, 32, 58, 32, 123, 32, 119, 105,
  100, 116, 104, 62, 48, 91, 37, 93, 32, 124, 32, 91, 105, 109, 97, 103,
  101, 95, 119, 93, 32, 125, 44, 123, 32, 95, 104, 101, 105, 103, 104, 116,
  62, 48, 91, 37, 93, 32, 124, 32, 91, 105, 109, 97, 103, 101, 95, 104,
  93, 32, 125, 44, 123, 32, 95, 100, 101, 112, 116, 104, 62, 48, 91, 37,
  93, 32, 124, 32, 91, 105, 109, 97, 103, 101, 95, 100, 93, 32, 125, 44,
  123, 32, 95, 115, 112, 101, 99, 116, 114, 117, 109, 62, 48, 91, 37, 93,
  32, 124, 32, 91, 105, 109, 97, 103, 101, 95, 115, 93, 32, 125, 44, 95,
  123, 32, 118, 97, 108, 117, 101, 49, 44, 95, 118, 97, 108, 117, 101, 50,
  44, 46, 46, 32, 124, 32, 39, 102, 111, 114, 109, 117, 108, 97, 39, 32,
  125, 32, 58, 32, 40, 118, 97, 108, 117, 101, 49, 123, 44, 124, 59, 124,
  47, 124, 94, 125, 118, 97, 108, 117, 101, 50, 123, 44, 124, 59, 124, 47,
  124, 94, 125, 46, 46, 41, 32, 58, 32, 48, 32, 58, 32, 40, 42, 41,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 110, 115, 101, 114, 116,
  32, 97, 32, 110, 101, 119, 32, 105, 109, 97, 103, 101, 32, 116, 97, 107,
  101, 110, 32, 102, 114, 111, 109, 32, 97, 32, 102, 105, 108, 101, 110, 97,
  109, 101, 32, 111, 114, 32, 102, 114, 111, 109, 32, 97, 32, 99, 111, 112,
  121, 32, 111, 102, 32, 97, 110, 32, 101, 120, 105, 115, 116, 105, 110, 103,
  32, 105, 109, 97, 103, 101, 32, 91, 39, 105, 110, 100, 105, 99, 101, 39,
  93, 44, 34, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 111, 114, 32,
  105, 110, 115, 101, 114, 116, 32, 110, 101, 119, 32, 105, 109, 97, 103, 101,
  32, 119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  100, 105, 109, 101, 110, 115, 105, 111, 110, 115, 32, 97, 110, 100, 32, 118,
  97, 108, 117, 101, 115, 46, 32, 83, 105, 110, 103, 108, 101, 32, 113, 117,
  111, 116, 101, 115, 32, 109, 97, 121, 32, 98, 101, 32, 111, 109, 105, 116,
  116, 101, 100, 32, 105, 110, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  39, 102, 111, 114, 109, 117, 108, 97, 39, 46, 32, 83, 112, 101, 99, 105,
  102, 121, 105, 110, 103, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 39,
  48, 39, 32, 105, 110, 115, 101, 114, 116, 115, 32, 97, 110, 32, 39, 101,
  109, 112, 116, 121, 39, 32, 105, 109, 97, 103, 101, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45,
  105, 39, 32, 124, 32, 40, 110, 111, 32, 97, 114, 103, 115, 41, 41, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108,
  116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 110, 98, 95, 99, 111,
  112, 105, 101, 115, 61, 49, 39, 44, 32, 39, 104, 101, 105, 103, 104, 116,
  61, 100, 101, 112, 116, 104, 61, 115, 112, 101, 99, 116, 114, 117, 109, 61,
  49, 39, 32, 97, 110, 100, 32, 39, 118, 97, 108, 117, 101, 49, 61, 48,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 105,
  110, 112, 117, 116, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 105, 32, 40, 49, 44,
  50, 44, 51, 59, 52, 44, 53, 44, 54, 59, 55, 44, 56, 44, 57, 94,
  57, 44, 56, 44, 55, 59, 54, 44, 53, 44, 52, 59, 51, 44, 50, 44,
  49, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 40, 49, 44, 50, 44, 51, 59, 52,
  44, 53, 44, 54, 59, 55, 44, 56, 44, 57, 41, 32, 40, 50, 53, 53,
  94, 49, 50, 56, 94, 54, 52, 41, 32, 52, 48, 48, 44, 52, 48, 48,
  44, 49, 44, 51, 44, 39, 105, 102, 40, 120, 62, 119, 47, 50, 44, 120,
  44, 121, 41, 42, 99, 39, 10, 35, 64, 103, 109, 105, 99, 32, 111, 32,
  58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 111, 117, 116, 112, 117,
  116, 39, 46, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99,
  32, 111, 117, 116, 112, 117, 116, 32, 58, 32, 91, 116, 121, 112, 101, 58,
  93, 102, 105, 108, 101, 110, 97, 109, 101, 44, 95, 102, 111, 114, 109, 97,
  116, 95, 111, 112, 116, 105, 111, 110, 115, 32, 58, 32, 40, 42, 41, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32,
  97, 115, 32, 111, 110, 101, 32, 111, 114, 32, 115, 101, 118, 101, 114, 97,
  108, 32, 110, 117, 109, 98, 101, 114, 101, 100, 32, 102, 105, 108, 101, 40,
  115, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113,
  46, 32, 116, 111, 32, 39, 45, 111, 39, 41, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108,
  117, 101, 58, 32, 39, 102, 111, 114, 109, 97, 116, 95, 111, 112, 116, 105,
  111, 110, 115, 39, 61, 40, 117, 110, 100, 101, 102, 105, 110, 101, 100, 41,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 111, 117, 116, 112, 117, 116, 95,
  103, 103, 114, 32, 58, 32, 102, 105, 108, 101, 110, 97, 109, 101, 44, 95,
  103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 97, 109, 101, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 97, 115,
  32, 71, 73, 77, 80, 32, 103, 114, 97, 100, 105, 101, 110, 116, 32, 102,
  105, 108, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73,
  102, 32, 110, 111, 32, 103, 114, 97, 100, 105, 101, 110, 116, 32, 110, 97,
  109, 101, 32, 105, 115, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 44,
  32, 105, 116, 32, 105, 115, 32, 100, 101, 100, 117, 99, 101, 100, 32, 102,
  114, 111, 109, 32, 116, 104, 101, 32, 102, 105, 108, 101, 110, 97, 109, 101,
  46, 10, 111, 117, 116, 112, 117, 116, 95, 103, 103, 114, 32, 58, 32, 45,
  115, 107, 105, 112, 32, 34, 36, 123, 50, 61, 125, 34, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 79, 117, 116, 112, 117, 116, 32, 105, 109, 97,
  103, 101, 36, 63, 32, 97, 115, 32, 71, 73, 77, 80, 32, 103, 114, 97,
  100, 105, 101, 110, 116, 32, 102, 105, 108, 101, 32, 39, 36, 49, 39, 46,
  34, 10, 45, 118, 32, 45, 32, 78, 61, 64, 35, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 36, 78, 32, 45, 45, 108, 91, 36, 62, 93, 32, 45,
  114, 32, 49, 44, 123, 119, 42, 104, 42, 100, 125, 44, 49, 44, 49, 48,
  48, 37, 44, 45, 49, 32, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45,
  47, 32, 50, 53, 53, 10, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40,
  34, 36, 50, 34, 41, 125, 32, 110, 97, 109, 101, 61, 34, 36, 50, 34,
  10, 45, 101, 108, 115, 101, 32, 45, 108, 91, 93, 32, 49, 32, 45, 110,
  109, 91, 45, 49, 93, 32, 34, 36, 49, 34, 32, 40, 123, 39, 64, 123,
  45, 49, 44, 98, 125, 39, 125, 41, 32, 45, 102, 32, 34, 105, 102, 40,
  120, 61, 61, 48, 38, 38, 105, 62, 61, 34, 123, 39, 97, 39, 125, 34,
  38, 38, 105, 60, 61, 34, 123, 39, 122, 39, 125, 34, 44, 105, 45, 34,
  123, 39, 97, 39, 125, 34, 43, 34, 123, 39, 65, 39, 125, 34, 44, 105,
  41, 34, 32, 110, 97, 109, 101, 61, 64, 123, 45, 49, 44, 116, 125, 32,
  45, 114, 109, 32, 45, 101, 110, 100, 108, 10, 45, 101, 110, 100, 105, 102,
  10, 40, 123, 39, 34, 71, 73, 77, 80, 32, 71, 114, 97, 100, 105, 101,
  110, 116, 92, 110, 78, 97, 109, 101, 58, 32, 34, 36, 110, 97, 109, 101,
  92, 110, 64, 123, 48, 44, 104, 125, 92, 110, 39, 125, 41, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 123, 48, 44, 104, 125, 10, 115, 116, 97,
  114, 116, 61, 123, 95, 36, 62, 47, 64, 123, 48, 44, 104, 125, 125, 10,
  101, 110, 100, 61, 123, 95, 40, 36, 62, 43, 49, 41, 47, 64, 123, 48,
  44, 104, 125, 125, 10, 109, 105, 100, 61, 123, 95, 48, 46, 53, 42, 40,
  36, 115, 116, 97, 114, 116, 43, 36, 101, 110, 100, 41, 125, 10, 114, 103,
  98, 97, 61, 64, 123, 45, 97, 116, 91, 48, 93, 92, 32, 48, 44, 36,
  62, 125, 10, 114, 61, 123, 97, 114, 103, 40, 49, 44, 36, 114, 103, 98,
  97, 41, 125, 32, 103, 61, 123, 97, 114, 103, 40, 50, 44, 36, 114, 103,
  98, 97, 41, 125, 32, 98, 61, 123, 97, 114, 103, 40, 51, 44, 36, 114,
  103, 98, 97, 41, 125, 32, 97, 61, 123, 97, 114, 103, 40, 52, 44, 36,
  114, 103, 98, 97, 41, 125, 10, 40, 123, 39, 36, 115, 116, 97, 114, 116,
  34, 32, 34, 36, 109, 105, 100, 34, 32, 34, 36, 101, 110, 100, 34, 32,
  34, 36, 114, 34, 32, 34, 36, 103, 34, 32, 34, 36, 98, 34, 32, 34,
  36, 97, 34, 32, 34, 36, 114, 34, 32, 34, 36, 103, 34, 32, 34, 36,
  98, 34, 32, 34, 36, 97, 34, 32, 48, 32, 48, 92, 110, 34, 39, 125,
  41, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 48, 93, 32, 45,
  97, 32, 120, 10, 45, 105, 102, 32, 123, 36, 78, 62, 49, 125, 32, 45,
  111, 32, 114, 97, 119, 58, 64, 123, 34, 45, 102, 105, 108, 101, 110, 97,
  109, 101, 32, 92, 34, 36, 49, 92, 34, 44, 36, 62, 34, 125, 44, 117,
  99, 104, 97, 114, 32, 45, 101, 108, 115, 101, 32, 45, 111, 32, 114, 97,
  119, 58, 34, 36, 49, 34, 44, 117, 99, 104, 97, 114, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 114, 109, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  111, 110, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 111, 117,
  116, 112, 117, 116, 110, 39, 46, 10, 111, 110, 32, 58, 10, 45, 118, 32,
  45, 32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10,
  45, 95, 111, 117, 116, 112, 117, 116, 110, 32, 36, 42, 10, 35, 64, 103,
  109, 105, 99, 32, 111, 117, 116, 112, 117, 116, 110, 32, 58, 32, 102, 105,
  108, 101, 110, 97, 109, 101, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  79, 117, 116, 112, 117, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 32, 97, 115, 32, 97, 117, 116, 111, 109, 97,
  116, 105, 99, 97, 108, 108, 121, 32, 110, 117, 109, 98, 101, 114, 101, 100,
  32, 102, 105, 108, 101, 110, 97, 109, 101, 115, 32, 105, 110, 32, 114, 101,
  112, 101, 97, 116, 46, 46, 100, 111, 110, 101, 32, 108, 111, 111, 112, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32,
  116, 111, 32, 39, 45, 111, 110, 39, 41, 46, 10, 111, 117, 116, 112, 117,
  116, 110, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36,
  63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 36, 48, 32, 36, 42, 10,
  95, 111, 117, 116, 112, 117, 116, 110, 32, 58, 10, 45, 118, 32, 45, 32,
  102, 105, 108, 101, 110, 97, 109, 101, 61, 64, 123, 45, 102, 105, 108, 101,
  110, 97, 109, 101, 92, 32, 34, 36, 49, 34, 44, 64, 123, 62, 125, 125,
  32, 45, 118, 32, 43, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34,
  79, 117, 116, 112, 117, 116, 32, 105, 109, 97, 103, 101, 34, 36, 95, 95,
  115, 34, 32, 97, 115, 32, 102, 105, 108, 101, 32, 39, 34, 36, 102, 105,
  108, 101, 110, 97, 109, 101, 34, 39, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 111, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 32, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 111, 112, 32, 58, 32, 101, 113,
  46, 32, 116, 111, 32, 39, 45, 111, 117, 116, 112, 117, 116, 112, 39, 46,
  10, 111, 112, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34,
  36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 111, 117, 116, 112, 117,
  116, 112, 32, 36, 42, 10, 35, 64, 103, 109, 105, 99, 32, 111, 117, 116,
  112, 117, 116, 112, 32, 58, 32, 112, 114, 101, 102, 105, 120, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 97, 115,
  32, 112, 114, 101, 102, 105, 120, 101, 100, 32, 118, 101, 114, 115, 105, 111,
  110, 115, 32, 111, 102, 32, 116, 104, 101, 105, 114, 32, 111, 114, 105, 103,
  105, 110, 97, 108, 32, 102, 105, 108, 101, 110, 97, 109, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111,
  32, 39, 45, 111, 112, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58,
  32, 39, 112, 114, 101, 102, 105, 120, 61, 95, 39, 46, 10, 111, 117, 116,
  112, 117, 116, 112, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61,
  34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 36, 48, 32, 36,
  42, 10, 95, 111, 117, 116, 112, 117, 116, 112, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 49, 61, 34, 95, 34, 125, 10, 45, 105, 102, 32,
  123, 64, 35, 62, 49, 125, 32, 45, 101, 91, 48, 45, 45, 52, 93, 32,
  34, 79, 117, 116, 112, 117, 116, 32, 105, 109, 97, 103, 101, 34, 36, 95,
  95, 115, 34, 32, 97, 115, 32, 116, 104, 101, 105, 114, 32, 105, 110, 105,
  116, 105, 97, 108, 32, 108, 111, 99, 97, 116, 105, 111, 110, 115, 44, 32,
  112, 114, 101, 102, 105, 120, 101, 100, 32, 98, 121, 32, 39, 36, 49, 39,
  46, 34, 10, 45, 101, 108, 115, 101, 32, 45, 101, 91, 48, 45, 45, 52,
  93, 32, 34, 79, 117, 116, 112, 117, 116, 32, 105, 109, 97, 103, 101, 34,
  36, 95, 95, 115, 34, 32, 97, 115, 32, 105, 116, 115, 32, 105, 110, 105,
  116, 105, 97, 108, 32, 108, 111, 99, 97, 116, 105, 111, 110, 44, 32, 112,
  114, 101, 102, 105, 120, 101, 100, 32, 98, 121, 32, 39, 36, 49, 39, 46,
  34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 111, 91, 36, 62, 93, 32,
  64, 123, 36, 62, 44, 102, 125, 36, 49, 64, 123, 36, 62, 44, 98, 125,
  46, 64, 123, 36, 62, 44, 120, 125, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 111, 119, 32, 58, 32,
  101, 113, 46, 32, 116, 111, 32, 39, 45, 111, 117, 116, 112, 117, 116, 119,
  39, 46, 10, 111, 119, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115,
  61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 111, 117, 116,
  112, 117, 116, 119, 32, 36, 42, 10, 35, 64, 103, 109, 105, 99, 32, 111,
  117, 116, 112, 117, 116, 119, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  79, 117, 116, 112, 117, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 32, 98, 121, 32, 111, 118, 101, 114, 119, 114,
  105, 116, 116, 105, 110, 103, 32, 116, 104, 101, 105, 114, 32, 111, 114, 105,
  103, 105, 110, 97, 108, 32, 108, 111, 99, 97, 116, 105, 111, 110, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111,
  32, 39, 45, 111, 119, 39, 41, 46, 10, 111, 117, 116, 112, 117, 116, 119,
  32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63, 34,
  32, 45, 118, 32, 43, 10, 45, 95, 36, 48, 32, 36, 42, 10, 95, 111,
  117, 116, 112, 117, 116, 119, 32, 58, 10, 45, 105, 102, 32, 123, 64, 35,
  62, 49, 125, 32, 45, 101, 91, 48, 45, 45, 52, 93, 32, 34, 79, 117,
  116, 112, 117, 116, 32, 105, 109, 97, 103, 101, 34, 36, 95, 95, 115, 34,
  32, 97, 115, 32, 116, 104, 101, 105, 114, 32, 105, 110, 105, 116, 105, 97,
  108, 32, 108, 111, 99, 97, 116, 105, 111, 110, 46, 34, 10, 45, 101, 108,
  115, 101, 32, 45, 101, 91, 48, 45, 45, 52, 93, 32, 34, 79, 117, 116,
  112, 117, 116, 32, 105, 109, 97, 103, 101, 34, 36, 95, 95, 115, 34, 32,
  97, 115, 32, 105, 116, 115, 32, 105, 110, 105, 116, 105, 97, 108, 32, 108,
  111, 99, 97, 116, 105, 111, 110, 46, 34, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 111, 91, 36, 62, 93, 32, 64, 123, 36, 62, 44, 110, 125, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 112, 108, 111, 116, 32, 58, 32, 95, 112, 108, 111, 116, 95, 116,
  121, 112, 101, 44, 95, 118, 101, 114, 116, 101, 120, 95, 116, 121, 112, 101,
  44, 95, 120, 109, 105, 110, 44, 95, 120, 109, 97, 120, 44, 95, 121, 109,
  105, 110, 44, 95, 121, 109, 97, 120, 32, 58, 32, 39, 102, 111, 114, 109,
  117, 108, 97, 39, 44, 95, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110,
  62, 61, 48, 44, 95, 112, 108, 111, 116, 95, 116, 121, 112, 101, 44, 95,
  118, 101, 114, 116, 101, 120, 95, 116, 121, 112, 101, 44, 95, 120, 109, 105,
  110, 44, 120, 109, 97, 120, 44, 95, 121, 109, 105, 110, 44, 95, 121, 109,
  97, 120, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 68, 105, 115, 112, 108, 97, 121, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 32, 111, 114, 32, 102, 111, 114, 109,
  117, 108, 97, 32, 105, 110, 32, 97, 110, 32, 105, 110, 116, 101, 114, 97,
  99, 116, 105, 118, 101, 32, 118, 105, 101, 119, 101, 114, 32, 40, 117, 115,
  101, 32, 116, 104, 101, 32, 105, 110, 115, 116, 97, 110, 116, 32, 119, 105,
  110, 100, 111, 119, 32, 91, 48, 93, 32, 105, 102, 32, 111, 112, 101, 110,
  101, 100, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 112,
  108, 111, 116, 95, 116, 121, 112, 101, 39, 32, 99, 97, 110, 32, 98, 101,
  32, 123, 32, 48, 61, 110, 111, 110, 101, 32, 124, 32, 49, 61, 108, 105,
  110, 101, 115, 32, 124, 32, 50, 61, 115, 112, 108, 105, 110, 101, 115, 32,
  124, 32, 51, 61, 98, 97, 114, 32, 125, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 39, 118, 101, 114, 116, 101, 120, 95, 116, 121, 112, 101,
  39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 110, 111, 110,
  101, 32, 124, 32, 49, 61, 112, 111, 105, 110, 116, 115, 32, 124, 32, 50,
  44, 51, 61, 99, 114, 111, 115, 115, 101, 115, 32, 124, 32, 52, 44, 53,
  61, 99, 105, 114, 99, 108, 101, 115, 32, 124, 32, 54, 44, 55, 61, 115,
  113, 117, 97, 114, 101, 115, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 39, 120, 109, 105, 110, 39, 44, 39, 120, 109, 97, 120, 39,
  44, 39, 121, 109, 105, 110, 39, 44, 39, 121, 109, 97, 120, 39, 32, 115,
  101, 116, 32, 116, 104, 101, 32, 99, 111, 111, 114, 100, 105, 110, 97, 116,
  101, 115, 32, 111, 102, 32, 116, 104, 101, 32, 100, 105, 115, 112, 108, 97,
  121, 101, 100, 32, 120, 121, 45, 97, 120, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 112, 108, 111, 116, 95, 116, 121, 112, 101,
  61, 49, 39, 44, 32, 39, 118, 101, 114, 116, 101, 120, 95, 116, 121, 112,
  101, 61, 49, 39, 32, 97, 110, 100, 32, 39, 120, 109, 105, 110, 61, 120,
  109, 97, 120, 61, 121, 109, 105, 110, 61, 121, 109, 97, 120, 61, 48, 32,
  40, 97, 117, 116, 111, 41, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  112, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 112, 114, 105,
  110, 116, 39, 46, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 112, 114, 105, 110, 116, 32, 58, 32, 40, 42, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 105, 110,
  102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 111, 110, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 44, 32, 111, 110,
  32, 116, 104, 101, 32, 115, 116, 97, 110, 100, 97, 114, 100, 32, 101, 114,
  114, 111, 114, 32, 40, 115, 116, 100, 101, 114, 114, 41, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39,
  45, 112, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 114, 97, 105,
  110, 98, 111, 119, 95, 108, 117, 116, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 73, 110, 112, 117, 116, 32, 97, 32, 50, 53, 54, 45, 101, 110,
  116, 114, 105, 101, 115, 32, 82, 71, 66, 32, 99, 111, 108, 111, 114, 109,
  97, 112, 32, 111, 102, 32, 114, 97, 105, 110, 98, 111, 119, 32, 99, 111,
  108, 111, 114, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114, 97, 105, 110,
  98, 111, 119, 95, 108, 117, 116, 32, 45, 45, 108, 117, 109, 105, 110, 97,
  110, 99, 101, 91, 45, 50, 93, 32, 45, 109, 97, 112, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 10, 114, 97, 105, 110, 98, 111, 119, 95, 108, 117,
  116, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112,
  117, 116, 32, 82, 71, 66, 32, 99, 111, 108, 111, 114, 109, 97, 112, 32,
  111, 102, 32, 50, 53, 54, 32, 114, 97, 105, 110, 98, 111, 119, 32, 99,
  111, 108, 111, 114, 115, 46, 34, 10, 45, 118, 32, 45, 10, 40, 50, 44,
  49, 48, 44, 49, 51, 44, 49, 51, 44, 49, 53, 44, 49, 54, 44, 49,
  53, 44, 49, 53, 44, 49, 56, 44, 50, 51, 44, 50, 54, 44, 51, 49,
  44, 51, 51, 44, 51, 55, 44, 51, 56, 44, 51, 57, 44, 52, 50, 44,
  52, 50, 44, 52, 52, 44, 52, 53, 44, 52, 52, 44, 52, 52, 44, 52,
  53, 44, 52, 53, 44, 52, 52, 44, 52, 50, 44, 52, 52, 44, 52, 53,
  44, 52, 53, 44, 52, 57, 44, 53, 48, 44, 53, 50, 44, 53, 52, 44,
  53, 53, 44, 53, 54, 44, 53, 55, 44, 92, 10, 53, 54, 44, 53, 54,
  44, 53, 55, 44, 53, 55, 44, 53, 56, 44, 53, 55, 44, 53, 56, 44,
  53, 56, 44, 53, 57, 44, 53, 56, 44, 54, 48, 44, 53, 57, 44, 53,
  56, 44, 53, 57, 44, 53, 57, 44, 53, 57, 44, 53, 57, 44, 53, 57,
  44, 54, 48, 44, 54, 48, 44, 53, 57, 44, 53, 57, 44, 53, 57, 44,
  53, 57, 44, 54, 48, 44, 53, 57, 44, 53, 57, 44, 53, 57, 44, 53,
  57, 44, 53, 57, 44, 53, 57, 44, 53, 57, 44, 53, 56, 44, 53, 56,
  44, 53, 56, 44, 53, 54, 44, 92, 10, 53, 54, 44, 53, 52, 44, 53,
  49, 44, 52, 56, 44, 52, 52, 44, 51, 57, 44, 51, 51, 44, 50, 48,
  44, 53, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 49, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 92, 10, 48, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 53,
  44, 50, 53, 44, 53, 48, 44, 54, 54, 44, 56, 49, 44, 57, 48, 44,
  49, 48, 50, 44, 49, 48, 57, 44, 49, 49, 56, 44, 49, 50, 57, 44,
  49, 51, 55, 44, 49, 52, 52, 44, 49, 53, 50, 44, 49, 53, 56, 44,
  49, 54, 56, 44, 49, 55, 56, 44, 49, 56, 51, 44, 49, 57, 48, 44,
  49, 57, 57, 44, 50, 48, 55, 44, 92, 10, 50, 49, 51, 44, 50, 50,
  48, 44, 50, 50, 55, 44, 50, 51, 48, 44, 50, 51, 54, 44, 50, 52,
  50, 44, 50, 52, 54, 44, 50, 53, 48, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 51, 44, 50, 53, 51, 44, 50, 53, 51, 44, 50, 53,
  50, 44, 50, 53, 49, 44, 50, 53, 48, 44, 50, 53, 48, 44, 50, 52,
  57, 44, 50, 52, 56, 44, 50, 52, 56, 44, 50, 52, 55, 44, 50, 52,
  56, 44, 50, 52, 54, 44, 50, 52, 54, 44, 50, 52, 54, 44, 50, 52,
  53, 44, 50, 52, 54, 44, 92, 10, 50, 52, 53, 44, 50, 52, 53, 44,
  50, 52, 53, 44, 50, 52, 54, 44, 50, 52, 54, 44, 50, 52, 54, 44,
  50, 52, 54, 44, 50, 52, 54, 44, 50, 52, 54, 44, 50, 52, 54, 44,
  50, 52, 54, 44, 50, 52, 53, 44, 50, 52, 53, 44, 50, 52, 53, 44,
  50, 52, 53, 44, 50, 52, 53, 44, 50, 52, 52, 44, 50, 52, 53, 44,
  50, 52, 52, 44, 50, 52, 53, 44, 50, 52, 53, 44, 50, 52, 53, 44,
  50, 52, 53, 44, 50, 52, 53, 44, 50, 52, 53, 44, 50, 52, 53, 44,
  50, 52, 53, 44, 92, 10, 50, 52, 53, 44, 50, 52, 52, 44, 50, 52,
  52, 44, 50, 52, 53, 44, 50, 52, 53, 44, 50, 52, 51, 44, 50, 51,
  57, 44, 50, 51, 53, 44, 50, 51, 48, 44, 50, 50, 54, 44, 50, 50,
  48, 44, 50, 49, 54, 44, 50, 49, 49, 44, 50, 48, 52, 44, 50, 48,
  49, 44, 49, 57, 52, 44, 49, 57, 48, 44, 49, 56, 52, 44, 49, 55,
  54, 44, 49, 55, 49, 44, 49, 54, 52, 44, 49, 54, 48, 44, 49, 53,
  50, 44, 49, 52, 52, 44, 49, 51, 56, 44, 49, 51, 48, 44, 49, 50,
  50, 44, 92, 10, 49, 49, 52, 44, 49, 48, 55, 44, 57, 54, 44, 56,
  55, 44, 55, 56, 44, 54, 57, 44, 53, 55, 44, 53, 48, 44, 52, 54,
  44, 51, 56, 44, 51, 49, 44, 49, 57, 44, 53, 94, 51, 44, 49, 48,
  44, 49, 52, 44, 49, 53, 44, 49, 55, 44, 49, 56, 44, 49, 57, 44,
  49, 56, 44, 49, 57, 44, 50, 51, 44, 50, 53, 44, 51, 48, 44, 51,
  49, 44, 51, 53, 44, 51, 55, 44, 51, 57, 44, 52, 50, 44, 52, 52,
  44, 52, 53, 44, 52, 56, 44, 52, 57, 44, 53, 48, 44, 53, 49, 44,
  92, 10, 53, 50, 44, 53, 51, 44, 53, 54, 44, 53, 57, 44, 54, 51,
  44, 54, 54, 44, 54, 54, 44, 54, 56, 44, 54, 57, 44, 55, 49, 44,
  55, 51, 44, 55, 52, 44, 55, 53, 44, 55, 54, 44, 55, 54, 44, 55,
  55, 44, 55, 56, 44, 55, 57, 44, 55, 57, 44, 56, 48, 44, 56, 49,
  44, 56, 49, 44, 56, 50, 44, 56, 50, 44, 56, 51, 44, 56, 52, 44,
  56, 52, 44, 56, 52, 44, 56, 52, 44, 56, 52, 44, 56, 53, 44, 56,
  53, 44, 56, 54, 44, 56, 54, 44, 56, 54, 44, 56, 54, 44, 92, 10,
  56, 55, 44, 56, 56, 44, 56, 55, 44, 56, 54, 44, 56, 54, 44, 56,
  54, 44, 56, 54, 44, 56, 56, 44, 56, 57, 44, 56, 57, 44, 57, 48,
  44, 57, 50, 44, 57, 50, 44, 57, 52, 44, 57, 54, 44, 57, 57, 44,
  49, 48, 50, 44, 49, 48, 52, 44, 49, 48, 55, 44, 49, 49, 49, 44,
  49, 49, 55, 44, 49, 50, 48, 44, 49, 50, 54, 44, 49, 51, 48, 44,
  49, 51, 54, 44, 49, 52, 50, 44, 49, 52, 57, 44, 49, 53, 53, 44,
  49, 54, 49, 44, 49, 54, 55, 44, 49, 55, 50, 44, 92, 10, 49, 55,
  54, 44, 49, 55, 56, 44, 49, 55, 57, 44, 49, 55, 57, 44, 49, 55,
  56, 44, 49, 55, 56, 44, 49, 55, 56, 44, 49, 55, 56, 44, 49, 55,
  55, 44, 49, 55, 55, 44, 49, 55, 55, 44, 49, 55, 54, 44, 49, 55,
  54, 44, 49, 55, 54, 44, 49, 55, 54, 44, 49, 55, 53, 44, 49, 55,
  51, 44, 49, 55, 51, 44, 49, 55, 52, 44, 49, 55, 51, 44, 49, 55,
  50, 44, 49, 55, 49, 44, 49, 55, 49, 44, 49, 55, 49, 44, 49, 55,
  49, 44, 49, 55, 49, 44, 49, 55, 49, 44, 92, 10, 49, 55, 49, 44,
  49, 55, 49, 44, 49, 55, 49, 44, 49, 55, 49, 44, 49, 55, 49, 44,
  49, 55, 49, 44, 49, 55, 49, 44, 49, 55, 49, 44, 49, 55, 49, 44,
  49, 55, 49, 44, 49, 55, 49, 44, 49, 55, 49, 44, 49, 55, 49, 44,
  49, 55, 49, 44, 49, 55, 49, 44, 49, 55, 49, 44, 49, 55, 51, 44,
  49, 55, 51, 44, 49, 55, 51, 44, 49, 55, 53, 44, 49, 55, 54, 44,
  49, 55, 56, 44, 49, 55, 56, 44, 49, 55, 56, 44, 49, 56, 49, 44,
  49, 56, 50, 44, 49, 56, 52, 44, 92, 10, 49, 56, 54, 44, 49, 56,
  54, 44, 49, 57, 48, 44, 49, 57, 50, 44, 49, 57, 51, 44, 49, 57,
  53, 44, 49, 57, 56, 44, 50, 48, 48, 44, 50, 48, 49, 44, 50, 48,
  52, 44, 50, 48, 54, 44, 50, 48, 57, 44, 50, 49, 49, 44, 50, 48,
  56, 44, 50, 48, 54, 44, 50, 48, 50, 44, 49, 57, 55, 44, 49, 57,
  52, 44, 49, 57, 48, 44, 49, 56, 53, 44, 49, 56, 50, 44, 49, 55,
  56, 44, 49, 55, 50, 44, 49, 54, 55, 44, 49, 54, 50, 44, 49, 53,
  55, 44, 49, 53, 50, 44, 92, 10, 49, 52, 52, 44, 49, 51, 57, 44,
  49, 51, 50, 44, 49, 50, 55, 44, 49, 50, 49, 44, 49, 49, 53, 44,
  49, 48, 56, 44, 49, 48, 50, 44, 57, 56, 44, 57, 50, 44, 56, 55,
  44, 55, 57, 44, 55, 53, 44, 54, 57, 44, 54, 52, 44, 54, 50, 44,
  53, 56, 44, 53, 53, 44, 53, 50, 44, 53, 48, 44, 52, 57, 44, 52,
  55, 44, 52, 55, 44, 52, 55, 44, 52, 55, 44, 52, 55, 44, 52, 55,
  44, 52, 55, 44, 52, 55, 44, 52, 54, 44, 52, 54, 44, 52, 54, 44,
  52, 54, 44, 92, 10, 52, 53, 44, 52, 52, 44, 52, 52, 44, 52, 50,
  44, 52, 50, 44, 52, 49, 44, 52, 49, 44, 52, 48, 44, 51, 57, 44,
  51, 56, 44, 51, 55, 44, 51, 54, 44, 51, 52, 44, 51, 49, 44, 51,
  48, 44, 50, 57, 44, 51, 48, 44, 51, 48, 44, 51, 49, 44, 51, 50,
  44, 51, 50, 44, 51, 50, 44, 51, 51, 44, 51, 51, 44, 51, 52, 44,
  51, 52, 44, 51, 51, 44, 51, 52, 44, 51, 51, 44, 51, 50, 44, 51,
  49, 44, 51, 49, 44, 51, 48, 44, 50, 57, 44, 50, 54, 44, 50, 53,
  44, 92, 10, 50, 51, 44, 50, 49, 44, 49, 57, 44, 49, 53, 44, 49,
  51, 44, 49, 51, 44, 49, 54, 44, 49, 56, 44, 49, 56, 44, 49, 56,
  44, 49, 55, 44, 49, 53, 44, 49, 51, 44, 49, 50, 44, 57, 44, 50,
  94, 54, 44, 49, 57, 44, 50, 53, 44, 51, 50, 44, 52, 49, 44, 52,
  57, 44, 53, 53, 44, 54, 53, 44, 55, 49, 44, 55, 57, 44, 56, 52,
  44, 57, 48, 44, 57, 54, 44, 49, 48, 50, 44, 49, 48, 54, 44, 49,
  49, 49, 44, 49, 49, 55, 44, 49, 50, 49, 44, 49, 50, 56, 44, 92,
  10, 49, 51, 50, 44, 49, 51, 52, 44, 49, 51, 57, 44, 49, 52, 51,
  44, 49, 52, 54, 44, 49, 52, 57, 44, 49, 53, 50, 44, 49, 53, 53,
  44, 49, 53, 54, 44, 49, 53, 55, 44, 49, 53, 57, 44, 49, 53, 57,
  44, 49, 54, 48, 44, 49, 54, 49, 44, 49, 54, 50, 44, 49, 54, 51,
  44, 49, 54, 52, 44, 49, 54, 52, 44, 49, 54, 53, 44, 49, 54, 54,
  44, 49, 54, 55, 44, 49, 54, 54, 44, 49, 54, 53, 44, 49, 54, 54,
  44, 49, 54, 54, 44, 49, 54, 55, 44, 49, 54, 55, 44, 92, 10, 49,
  54, 56, 44, 49, 54, 56, 44, 49, 54, 56, 44, 49, 54, 57, 44, 49,
  54, 57, 44, 49, 54, 57, 44, 49, 54, 57, 44, 49, 55, 48, 44, 49,
  55, 48, 44, 49, 55, 48, 44, 49, 55, 48, 44, 49, 55, 48, 44, 49,
  55, 48, 44, 49, 55, 48, 44, 49, 55, 49, 44, 49, 55, 48, 44, 49,
  55, 48, 44, 49, 55, 48, 44, 49, 55, 48, 44, 49, 55, 48, 44, 49,
  55, 49, 44, 49, 55, 49, 44, 49, 55, 50, 44, 49, 55, 51, 44, 49,
  55, 51, 44, 49, 55, 51, 44, 49, 55, 53, 44, 92, 10, 49, 55, 55,
  44, 49, 55, 57, 44, 49, 56, 48, 44, 49, 56, 51, 44, 49, 56, 53,
  44, 49, 56, 55, 44, 49, 57, 48, 44, 49, 57, 51, 44, 49, 57, 56,
  44, 50, 48, 49, 44, 50, 48, 54, 44, 50, 49, 51, 44, 50, 49, 57,
  44, 50, 50, 53, 44, 50, 50, 55, 44, 50, 50, 55, 44, 50, 50, 51,
  44, 50, 49, 56, 44, 50, 49, 52, 44, 50, 48, 52, 44, 49, 57, 57,
  44, 49, 57, 50, 44, 49, 56, 52, 44, 49, 55, 57, 44, 49, 55, 50,
  44, 49, 54, 56, 44, 49, 54, 50, 44, 92, 10, 49, 53, 54, 44, 49,
  53, 49, 44, 49, 52, 53, 44, 49, 51, 57, 44, 49, 51, 51, 44, 49,
  50, 54, 44, 49, 50, 48, 44, 49, 49, 51, 44, 49, 48, 54, 44, 57,
  56, 44, 57, 48, 44, 56, 53, 44, 56, 50, 44, 56, 50, 44, 56, 50,
  44, 56, 50, 44, 56, 50, 44, 56, 50, 44, 56, 50, 44, 56, 50, 44,
  56, 50, 44, 56, 50, 44, 56, 50, 44, 56, 50, 44, 56, 50, 44, 56,
  50, 44, 56, 50, 44, 56, 50, 44, 56, 52, 44, 56, 52, 44, 56, 50,
  44, 56, 50, 44, 56, 50, 44, 92, 10, 56, 50, 44, 56, 50, 44, 56,
  51, 44, 56, 51, 44, 56, 49, 44, 56, 49, 44, 56, 49, 44, 56, 48,
  44, 56, 48, 44, 55, 56, 44, 55, 56, 44, 55, 56, 44, 55, 54, 44,
  55, 52, 44, 55, 51, 44, 55, 51, 44, 55, 49, 44, 55, 50, 44, 54,
  57, 44, 54, 56, 44, 54, 55, 44, 54, 53, 44, 54, 50, 44, 53, 57,
  44, 53, 56, 44, 53, 54, 44, 53, 49, 44, 53, 48, 44, 52, 57, 44,
  52, 53, 44, 52, 51, 44, 52, 48, 44, 51, 56, 44, 51, 55, 44, 51,
  53, 44, 51, 50, 44, 92, 10, 51, 49, 44, 51, 50, 44, 51, 50, 44,
  51, 51, 44, 51, 51, 44, 51, 52, 44, 51, 52, 44, 51, 53, 44, 51,
  54, 44, 51, 54, 44, 51, 55, 44, 51, 56, 44, 51, 57, 44, 52, 50,
  44, 52, 52, 44, 52, 53, 44, 52, 54, 44, 52, 54, 44, 52, 55, 44,
  52, 56, 44, 52, 57, 44, 52, 56, 44, 52, 56, 44, 52, 56, 44, 52,
  56, 44, 52, 56, 44, 52, 56, 44, 52, 56, 44, 52, 56, 44, 52, 56,
  44, 52, 56, 44, 52, 55, 44, 52, 55, 44, 52, 55, 44, 52, 55, 44,
  52, 54, 44, 92, 10, 52, 53, 44, 52, 53, 44, 52, 51, 44, 52, 51,
  44, 52, 50, 44, 52, 49, 44, 52, 48, 44, 51, 57, 44, 51, 56, 44,
  51, 55, 44, 51, 56, 44, 51, 56, 44, 51, 55, 44, 51, 55, 44, 51,
  56, 44, 51, 56, 44, 51, 56, 44, 51, 56, 44, 51, 57, 44, 52, 48,
  44, 51, 57, 44, 52, 48, 44, 51, 57, 44, 52, 48, 44, 52, 48, 44,
  51, 57, 44, 51, 57, 44, 51, 56, 44, 51, 56, 44, 51, 55, 44, 51,
  53, 44, 51, 52, 44, 51, 50, 44, 51, 48, 44, 50, 56, 44, 50, 54,
  44, 92, 10, 50, 51, 44, 50, 48, 44, 49, 54, 44, 49, 52, 44, 49,
  50, 44, 49, 54, 44, 49, 54, 44, 49, 56, 44, 49, 56, 44, 49, 55,
  44, 49, 54, 44, 49, 52, 44, 49, 51, 44, 57, 44, 50, 41, 10, 45,
  110, 109, 91, 45, 49, 93, 32, 91, 114, 97, 105, 110, 98, 111, 119, 92,
  32, 108, 117, 116, 93, 10, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 114, 111, 100, 100, 121, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 76, 111, 97, 100, 32, 97, 32, 110, 101, 119, 32, 105, 109, 97, 103,
  101, 32, 111, 102, 32, 116, 104, 101, 32, 71, 39, 77, 73, 67, 32, 82,
  111, 100, 105, 108, 105, 117, 115, 32, 109, 97, 115, 99, 111, 116, 32, 39,
  82, 111, 100, 100, 121, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 45, 114, 111, 100, 100, 121, 10, 114, 111, 100, 100, 121, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 76, 111, 97, 100, 32,
  105, 109, 97, 103, 101, 32, 111, 102, 32, 116, 104, 101, 32, 71, 39, 77,
  73, 67, 32, 82, 111, 100, 105, 108, 105, 117, 115, 32, 109, 97, 115, 99,
  111, 116, 32, 39, 82, 111, 100, 100, 121, 39, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 105, 32, 104, 116, 116, 112, 58, 47, 47, 103, 109, 105, 99,
  46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116,
  47, 105, 109, 103, 47, 114, 111, 100, 100, 121, 95, 108, 97, 114, 103, 101,
  46, 99, 105, 109, 103, 122, 32, 45, 110, 109, 91, 45, 49, 93, 32, 91,
  114, 111, 100, 100, 121, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109,
  105, 99, 32, 114, 101, 109, 111, 118, 101, 95, 100, 117, 112, 108, 105, 99,
  97, 116, 101, 115, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101,
  109, 111, 118, 101, 32, 100, 117, 112, 108, 105, 99, 97, 116, 101, 115, 32,
  105, 109, 97, 103, 101, 115, 32, 105, 110, 32, 116, 104, 101, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 108, 105,
  115, 116, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 40,
  49, 44, 50, 44, 51, 44, 52, 44, 50, 44, 52, 44, 51, 44, 49, 44,
  51, 44, 52, 44, 50, 44, 49, 41, 32, 45, 115, 112, 108, 105, 116, 32,
  120, 32, 45, 114, 101, 109, 111, 118, 101, 95, 100, 117, 112, 108, 105, 99,
  97, 116, 101, 115, 32, 45, 97, 112, 112, 101, 110, 100, 32, 120, 10, 114,
  101, 109, 111, 118, 101, 95, 100, 117, 112, 108, 105, 99, 97, 116, 101, 115,
  32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 109, 111,
  118, 101, 32, 100, 117, 112, 108, 105, 99, 97, 116, 101, 115, 32, 105, 109,
  97, 103, 101, 115, 32, 105, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 108, 105, 115, 116, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 10, 98, 97, 115, 101, 61, 36, 62, 32, 111, 102, 102, 61, 48,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 36, 62, 45,
  49, 125, 10, 99, 111, 109, 112, 61, 123, 36, 98, 97, 115, 101, 43, 49,
  43, 36, 62, 45, 36, 111, 102, 102, 125, 10, 45, 105, 102, 32, 123, 36,
  99, 111, 109, 112, 62, 61, 64, 35, 125, 32, 45, 98, 114, 101, 97, 107,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 45, 91, 36, 98, 97, 115,
  101, 44, 36, 99, 111, 109, 112, 93, 32, 45, 97, 98, 115, 91, 45, 49,
  93, 32, 105, 115, 95, 100, 117, 112, 108, 105, 99, 97, 116, 101, 61, 123,
  33, 64, 123, 45, 49, 44, 43, 125, 125, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 105, 102, 32, 36, 105, 115, 95, 100, 117, 112, 108, 105, 99,
  97, 116, 101, 32, 45, 114, 109, 91, 36, 99, 111, 109, 112, 93, 32, 111,
  102, 102, 61, 123, 36, 111, 102, 102, 43, 49, 125, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 114, 101, 109, 111, 118,
  101, 95, 101, 109, 112, 116, 121, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 82, 101, 109, 111, 118, 101, 32, 101, 109, 112, 116, 121, 32, 105, 109,
  97, 103, 101, 115, 32, 105, 110, 32, 116, 104, 101, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 32, 108, 105, 115, 116, 46,
  10, 114, 101, 109, 111, 118, 101, 95, 101, 109, 112, 116, 121, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 109, 111, 118, 101, 32,
  101, 109, 112, 116, 121, 32, 105, 109, 97, 103, 101, 115, 32, 105, 110, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 108, 105, 115, 116, 32, 111, 102,
  32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 105, 102, 32, 123,
  33, 64, 123, 36, 60, 44, 119, 104, 100, 115, 125, 125, 32, 45, 114, 109,
  91, 36, 60, 93, 32, 45, 101, 110, 100, 105, 102, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 101,
  108, 101, 99, 116, 32, 58, 32, 102, 101, 97, 116, 117, 114, 101, 95, 116,
  121, 112, 101, 44, 95, 88, 44, 95, 89, 44, 95, 90, 32, 58, 32, 40,
  43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 110, 116, 101,
  114, 97, 99, 116, 105, 118, 101, 108, 121, 32, 115, 101, 108, 101, 99, 116,
  32, 97, 32, 102, 101, 97, 116, 117, 114, 101, 32, 102, 114, 111, 109, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32,
  40, 117, 115, 101, 32, 116, 104, 101, 32, 105, 110, 115, 116, 97, 110, 116,
  32, 119, 105, 110, 100, 111, 119, 32, 91, 48, 93, 32, 105, 102, 32, 111,
  112, 101, 110, 101, 100, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 39, 102, 101, 97, 116, 117, 114, 101, 95, 116, 121, 112, 101, 39, 32,
  99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 112, 111, 105, 110, 116,
  32, 124, 32, 49, 61, 115, 101, 103, 109, 101, 110, 116, 32, 124, 32, 50,
  61, 114, 101, 99, 116, 97, 110, 103, 108, 101, 32, 124, 32, 51, 61, 101,
  108, 108, 105, 112, 115, 101, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 65, 114, 103, 117, 109, 101, 110, 116, 115, 32, 39, 88, 39,
  44, 39, 89, 39, 44, 39, 90, 39, 32, 100, 101, 116, 101, 114, 109, 105,
  110, 101, 32, 116, 104, 101, 32, 105, 110, 105, 116, 105, 97, 108, 32, 115,
  101, 108, 101, 99, 116, 105, 111, 110, 32, 118, 105, 101, 119, 44, 32, 102,
  111, 114, 32, 51, 100, 32, 118, 111, 108, 117, 109, 101, 116, 114, 105, 99,
  32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 84, 104, 101, 32, 114, 101, 116, 114, 105, 101, 118, 101, 100, 32,
  102, 101, 97, 116, 117, 114, 101, 32, 105, 115, 32, 114, 101, 116, 117, 114,
  110, 101, 100, 32, 97, 115, 32, 97, 32, 51, 100, 32, 111, 114, 32, 54,
  100, 32, 118, 101, 99, 116, 111, 114, 32, 99, 111, 110, 116, 97, 105, 110,
  105, 110, 103, 32, 116, 104, 101, 32, 102, 101, 97, 116, 117, 114, 101, 32,
  99, 111, 111, 114, 100, 105, 110, 97, 116, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 115, 104, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32,
  39, 45, 115, 104, 97, 114, 101, 100, 39, 46, 32, 58, 32, 40, 42, 41,
  10, 35, 64, 103, 109, 105, 99, 32, 115, 104, 97, 114, 101, 100, 32, 58,
  32, 120, 48, 91, 37, 93, 44, 120, 49, 91, 37, 93, 44, 121, 91, 37,
  93, 44, 122, 91, 37, 93, 44, 118, 91, 37, 93, 32, 58, 32, 121, 48,
  91, 37, 93, 44, 121, 49, 91, 37, 93, 44, 122, 91, 37, 93, 44, 118,
  91, 37, 93, 32, 58, 32, 122, 48, 91, 37, 93, 44, 122, 49, 91, 37,
  93, 44, 118, 91, 37, 93, 32, 58, 32, 118, 48, 91, 37, 93, 44, 118,
  49, 91, 37, 93, 32, 58, 32, 40, 110, 111, 32, 97, 114, 103, 115, 41,
  32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  73, 110, 115, 101, 114, 116, 32, 115, 104, 97, 114, 101, 100, 32, 98, 117,
  102, 102, 101, 114, 115, 32, 102, 114, 111, 109, 32, 40, 111, 112, 116, 46,
  32, 112, 111, 105, 110, 116, 115, 47, 114, 111, 119, 115, 47, 112, 108, 97,
  110, 101, 115, 47, 99, 104, 97, 110, 110, 101, 108, 115, 32, 111, 102, 41,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32,
  116, 111, 32, 39, 45, 115, 104, 39, 41, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 115, 104, 97, 114, 101, 100, 32, 49, 44, 49, 32, 45, 98, 108, 117,
  114, 91, 45, 49, 93, 32, 51, 32, 45, 114, 101, 109, 111, 118, 101, 91,
  45, 49, 93, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 123, 115, 125, 32, 45, 115, 104, 97, 114, 101, 100, 32, 50, 53, 37,
  44, 55, 53, 37, 44, 48, 44, 36, 62, 32, 45, 109, 105, 114, 114, 111,
  114, 91, 45, 49, 93, 32, 120, 32, 45, 114, 101, 109, 111, 118, 101, 91,
  45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 109, 105, 99,
  32, 115, 114, 97, 110, 100, 32, 58, 32, 118, 97, 108, 117, 101, 32, 58,
  32, 40, 110, 111, 32, 97, 114, 103, 115, 41, 32, 58, 32, 40, 42, 41,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 101, 116, 32, 114, 97,
  110, 100, 111, 109, 32, 103, 101, 110, 101, 114, 97, 116, 111, 114, 32, 115,
  101, 101, 100, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 102,
  32, 110, 111, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 105, 115, 32,
  115, 112, 101, 99, 105, 102, 105, 101, 100, 44, 32, 97, 32, 114, 97, 110,
  100, 111, 109, 32, 118, 97, 108, 117, 101, 32, 105, 115, 32, 117, 115, 101,
  100, 32, 97, 115, 32, 116, 104, 101, 32, 114, 97, 110, 100, 111, 109, 32,
  103, 101, 110, 101, 114, 97, 116, 111, 114, 32, 115, 101, 101, 100, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 116, 101, 115, 116, 105, 109, 97, 103, 101,
  50, 100, 32, 58, 32, 95, 119, 105, 100, 116, 104, 62, 48, 44, 95, 104,
  101, 105, 103, 104, 116, 62, 48, 44, 95, 115, 112, 101, 99, 116, 114, 117,
  109, 62, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 110, 112,
  117, 116, 32, 97, 32, 50, 100, 32, 115, 121, 110, 116, 104, 101, 116, 105,
  99, 32, 105, 109, 97, 103, 101, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115,
  58, 32, 39, 119, 105, 100, 116, 104, 61, 53, 49, 50, 39, 44, 32, 39,
  104, 101, 105, 103, 104, 116, 61, 119, 105, 100, 116, 104, 39, 32, 97, 110,
  100, 32, 39, 115, 112, 101, 99, 116, 114, 117, 109, 61, 51, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 116, 101, 115, 116,
  105, 109, 97, 103, 101, 50, 100, 32, 53, 49, 50, 10, 116, 101, 115, 116,
  105, 109, 97, 103, 101, 50, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 34, 36, 123, 49, 61, 53, 49, 50, 125, 62, 48, 32, 38, 38, 32,
  36, 123, 50, 61, 36, 49, 125, 62, 48, 32, 38, 38, 32, 36, 123, 51,
  61, 51, 125, 62, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  73, 110, 112, 117, 116, 32, 50, 100, 32, 115, 121, 110, 116, 104, 101, 116,
  105, 99, 32, 105, 109, 97, 103, 101, 32, 111, 102, 32, 115, 105, 122, 101,
  32, 36, 49, 120, 36, 50, 120, 36, 51, 46, 34, 10, 45, 118, 32, 45,
  10, 68, 109, 97, 120, 50, 61, 123, 48, 46, 49, 53, 42, 109, 105, 110,
  40, 36, 49, 44, 36, 50, 41, 94, 50, 125, 10, 36, 49, 44, 36, 50,
  44, 49, 44, 36, 51, 44, 39, 88, 61, 120, 45, 119, 47, 50, 59, 89,
  61, 121, 45, 104, 47, 50, 59, 97, 61, 97, 116, 97, 110, 50, 40, 89,
  44, 88, 41, 59, 105, 102, 40, 88, 94, 50, 43, 89, 94, 50, 60, 61,
  36, 68, 109, 97, 120, 50, 44, 50, 53, 53, 42, 97, 98, 115, 40, 99,
  111, 115, 40, 99, 43, 50, 48, 48, 42, 40, 120, 47, 119, 45, 48, 46,
  53, 41, 42, 40, 121, 47, 104, 45, 48, 46, 53, 41, 41, 41, 44, 56,
  53, 48, 42, 40, 97, 37, 40, 48, 46, 49, 42, 40, 99, 43, 49, 41,
  41, 41, 41, 39, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49,
  93, 32, 52, 44, 50, 48, 37, 44, 50, 48, 37, 44, 54, 48, 37, 44,
  50, 48, 37, 44, 55, 48, 37, 44, 55, 48, 37, 44, 51, 53, 37, 44,
  52, 53, 37, 44, 48, 46, 57, 44, 48, 44, 50, 53, 53, 44, 48, 10,
  45, 116, 111, 114, 117, 115, 51, 100, 32, 123, 36, 49, 47, 55, 125, 44,
  123, 36, 49, 47, 50, 48, 125, 32, 45, 114, 51, 100, 91, 45, 49, 93,
  32, 48, 44, 49, 44, 49, 44, 56, 48, 32, 45, 99, 111, 108, 51, 100,
  91, 45, 49, 93, 32, 49, 50, 56, 44, 50, 48, 48, 44, 50, 53, 53,
  10, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 50, 93, 32, 91,
  45, 49, 93, 44, 51, 48, 37, 44, 55, 48, 37, 44, 48, 44, 49, 44,
  53, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 114,
  111, 117, 110, 100, 91, 45, 49, 93, 32, 49, 10, 45, 110, 109, 91, 45,
  49, 93, 32, 34, 91, 50, 100, 32, 116, 101, 115, 116, 32, 105, 109, 97,
  103, 101, 93, 34, 10, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 116, 101, 120, 116, 50, 105, 109, 103, 32, 58, 32, 116, 101, 120, 116,
  44, 95, 108, 105, 110, 101, 95, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 110, 112, 117, 116, 32,
  97, 32, 50, 100, 32, 105, 109, 97, 103, 101, 32, 119, 104, 111, 115, 101,
  32, 118, 97, 108, 117, 101, 115, 32, 97, 114, 101, 32, 65, 83, 67, 73,
  73, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 115, 32, 111, 102, 32,
  115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 105, 110, 112, 117, 116, 32,
  116, 101, 120, 116, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 108,
  105, 110, 101, 95, 115, 101, 112, 97, 114, 97, 116, 111, 114, 61, 32, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 116, 101,
  120, 116, 50, 105, 109, 103, 32, 34, 84, 104, 101, 114, 101, 32, 97, 114,
  101, 32, 52, 32, 119, 111, 114, 100, 115, 34, 10, 116, 101, 120, 116, 50,
  105, 109, 103, 32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36, 123, 50,
  61, 32, 125, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110,
  112, 117, 116, 32, 105, 109, 97, 103, 101, 32, 102, 114, 111, 109, 32, 116,
  101, 120, 116, 32, 92, 34, 36, 49, 92, 34, 44, 32, 119, 105, 116, 104,
  32, 108, 105, 110, 101, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 32,
  39, 36, 50, 39, 46, 34, 10, 45, 118, 32, 45, 32, 40, 123, 39, 34,
  36, 49, 34, 39, 125, 41, 32, 45, 108, 91, 45, 49, 93, 32, 45, 115,
  32, 45, 44, 123, 39, 34, 36, 50, 34, 39, 125, 32, 45, 121, 32, 120,
  32, 45, 97, 32, 121, 32, 45, 110, 109, 32, 34, 91, 92, 34, 36, 49,
  92, 34, 93, 34, 32, 45, 101, 110, 100, 108, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 116, 121, 112, 101, 32, 58, 32, 100, 97,
  116, 97, 116, 121, 112, 101, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 83, 101, 116, 32, 112, 105, 120, 101, 108, 32,
  100, 97, 116, 97, 116, 121, 112, 101, 32, 102, 111, 114, 32, 97, 108, 108,
  32, 105, 109, 97, 103, 101, 115, 32, 111, 102, 32, 116, 104, 101, 32, 108,
  105, 115, 116, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 100,
  97, 116, 97, 116, 121, 112, 101, 39, 32, 99, 97, 110, 32, 98, 101, 32,
  123, 32, 98, 111, 111, 108, 32, 124, 32, 117, 99, 104, 97, 114, 32, 124,
  32, 99, 104, 97, 114, 32, 124, 32, 117, 115, 104, 111, 114, 116, 32, 124,
  32, 115, 104, 111, 114, 116, 32, 124, 32, 117, 105, 110, 116, 32, 124, 32,
  105, 110, 116, 32, 124, 32, 102, 108, 111, 97, 116, 32, 124, 32, 100, 111,
  117, 98, 108, 101, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 112, 101, 110, 100, 105, 110, 103, 32, 111, 110, 32, 104, 111,
  119, 32, 121, 111, 117, 114, 32, 71, 39, 77, 73, 67, 32, 118, 101, 114,
  115, 105, 111, 110, 32, 104, 97, 115, 32, 98, 101, 101, 110, 32, 99, 111,
  109, 112, 105, 108, 101, 100, 44, 32, 115, 111, 109, 101, 32, 100, 97, 116,
  97, 116, 121, 112, 101, 115, 32, 109, 97, 121, 32, 98, 101, 32, 117, 110,
  97, 118, 97, 105, 108, 97, 98, 108, 101, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 40, 116, 121, 112, 105, 99, 97, 108, 108, 121, 32, 100, 97,
  116, 97, 116, 121, 112, 101, 115, 32, 100, 105, 102, 102, 101, 114, 101, 110,
  116, 32, 102, 114, 111, 109, 32, 39, 102, 108, 111, 97, 116, 39, 41, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 117, 110, 99, 111, 109, 109, 97, 110,
  100, 32, 58, 32, 99, 111, 109, 109, 97, 110, 100, 95, 110, 97, 109, 101,
  32, 58, 32, 42, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 105, 115, 99, 97, 114, 100, 32, 108, 97, 115, 116,
  32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 111, 102, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 99, 117, 115, 116, 111, 109, 32,
  99, 111, 109, 109, 97, 110, 100, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 83, 101, 116, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 116,
  111, 32, 39, 42, 39, 32, 102, 111, 114, 32, 100, 105, 115, 99, 97, 114,
  100, 105, 110, 103, 32, 97, 108, 108, 32, 101, 120, 105, 115, 116, 105, 110,
  103, 32, 99, 117, 115, 116, 111, 109, 32, 99, 111, 109, 109, 97, 110, 100,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 117, 110, 105, 102, 111, 114,
  109, 95, 100, 105, 115, 116, 114, 105, 98, 117, 116, 105, 111, 110, 32, 58,
  32, 110, 98, 95, 108, 101, 118, 101, 108, 115, 62, 61, 49, 44, 115, 112,
  101, 99, 116, 114, 117, 109, 62, 61, 49, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 73, 110, 112, 117, 116, 32, 115, 101, 116, 32, 111, 102, 32,
  117, 110, 105, 102, 111, 114, 109, 108, 121, 32, 100, 105, 115, 116, 114, 105,
  98, 117, 116, 101, 100, 32, 78, 45, 100, 32, 112, 111, 105, 110, 116, 115,
  32, 105, 110, 32, 91, 48, 44, 49, 93, 94, 78, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 45, 117, 110, 105, 102, 111, 114, 109,
  95, 100, 105, 115, 116, 114, 105, 98, 117, 116, 105, 111, 110, 32, 54, 52,
  44, 51, 32, 45, 42, 32, 50, 53, 53, 32, 45, 45, 100, 105, 115, 116,
  114, 105, 98, 117, 116, 105, 111, 110, 51, 100, 32, 45, 99, 105, 114, 99,
  108, 101, 115, 51, 100, 91, 45, 49, 93, 32, 49, 48, 10, 117, 110, 105,
  102, 111, 114, 109, 95, 100, 105, 115, 116, 114, 105, 98, 117, 116, 105, 111,
  110, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110,
  116, 40, 36, 49, 41, 32, 38, 38, 32, 36, 49, 62, 48, 32, 38, 38,
  32, 105, 115, 105, 110, 116, 40, 36, 50, 41, 32, 38, 38, 32, 36, 50,
  62, 48, 34, 10, 45, 101, 91, 94, 49, 93, 32, 34, 73, 110, 112, 117,
  116, 32, 115, 101, 116, 32, 111, 102, 32, 36, 49, 32, 117, 110, 105, 102,
  111, 114, 109, 108, 121, 32, 100, 105, 115, 116, 114, 105, 98, 117, 116, 101,
  100, 32, 36, 50, 45, 100, 32, 112, 111, 105, 110, 116, 115, 32, 105, 110,
  32, 91, 48, 44, 49, 93, 94, 36, 50, 46, 34, 10, 45, 118, 32, 45,
  32, 110, 61, 123, 114, 111, 117, 110, 100, 40, 36, 49, 94, 40, 49, 47,
  36, 50, 41, 44, 49, 44, 49, 41, 125, 10, 40, 48, 44, 49, 41, 32,
  45, 114, 91, 45, 49, 93, 32, 36, 110, 44, 49, 44, 49, 44, 49, 44,
  51, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 50, 45, 49, 125,
  32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32,
  49, 48, 48, 37, 32, 45, 114, 91, 45, 49, 93, 32, 123, 36, 110, 42,
  119, 125, 44, 49, 44, 49, 44, 49, 44, 49, 32, 45, 114, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 44, 49, 44, 49, 44, 49, 48, 48, 37, 44,
  48, 44, 50, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32,
  45, 100, 111, 110, 101, 10, 45, 114, 91, 45, 49, 93, 32, 36, 49, 44,
  49, 44, 49, 44, 36, 50, 44, 49, 32, 45, 110, 109, 91, 45, 49, 93,
  32, 34, 91, 117, 110, 105, 102, 111, 114, 109, 32, 36, 50, 100, 32, 100,
  105, 115, 116, 114, 105, 98, 117, 116, 105, 111, 110, 93, 34, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 117, 112, 32, 58, 32, 101,
  113, 46, 32, 116, 111, 32, 39, 45, 117, 112, 100, 97, 116, 101, 39, 46,
  10, 117, 112, 32, 58, 10, 45, 95, 117, 112, 100, 97, 116, 101, 10, 35,
  64, 103, 109, 105, 99, 32, 117, 112, 100, 97, 116, 101, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 85, 112, 100, 97, 116, 101, 32, 99, 111, 109,
  109, 97, 110, 100, 115, 32, 102, 114, 111, 109, 32, 116, 104, 101, 32, 108,
  97, 116, 101, 115, 116, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110,
  32, 102, 105, 108, 101, 32, 111, 110, 32, 116, 104, 101, 32, 71, 39, 77,
  73, 67, 32, 115, 101, 114, 118, 101, 114, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 84, 104, 105, 115, 32, 114, 101, 113, 117, 105, 114, 101,
  115, 32, 97, 110, 32, 97, 99, 116, 105, 118, 101, 32, 73, 110, 116, 101,
  114, 110, 101, 116, 32, 99, 111, 110, 110, 101, 99, 116, 105, 111, 110, 32,
  97, 110, 100, 32, 97, 110, 32, 97, 99, 99, 101, 115, 115, 32, 116, 111,
  32, 116, 104, 101, 32, 101, 120, 116, 101, 114, 110, 97, 108, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 116, 111, 111, 108, 115, 32, 39, 99, 117,
  114, 108, 39, 32, 111, 114, 32, 39, 119, 103, 101, 116, 39, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32,
  39, 45, 117, 112, 39, 41, 46, 10, 117, 112, 100, 97, 116, 101, 32, 58,
  10, 45, 95, 36, 48, 10, 95, 117, 112, 100, 97, 116, 101, 32, 58, 10,
  45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 85, 112, 100, 97, 116, 101,
  32, 99, 111, 109, 109, 97, 110, 100, 115, 32, 102, 114, 111, 109, 32, 116,
  104, 101, 32, 108, 97, 116, 101, 115, 116, 32, 100, 101, 102, 105, 110, 105,
  116, 105, 111, 110, 32, 102, 105, 108, 101, 32, 111, 110, 32, 116, 104, 101,
  32, 71, 39, 77, 73, 67, 32, 115, 101, 114, 118, 101, 114, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 109, 32, 104, 116, 116, 112, 58, 47, 47, 103,
  109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46,
  110, 101, 116, 47, 117, 112, 100, 97, 116, 101, 64, 46, 46, 103, 109, 105,
  99, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 118, 32,
  58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 118, 101, 114, 98, 111,
  115, 101, 39, 46, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 118, 101, 114, 98, 111, 115, 101, 32, 58, 32, 95, 108, 101, 118,
  101, 108, 32, 58, 32, 123, 32, 43, 32, 124, 32, 45, 32, 125, 32, 58,
  32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 101,
  116, 32, 111, 114, 32, 105, 110, 99, 114, 101, 109, 101, 110, 116, 47, 100,
  101, 99, 114, 101, 109, 101, 110, 116, 32, 116, 104, 101, 32, 118, 101, 114,
  98, 111, 115, 105, 116, 121, 32, 108, 101, 118, 101, 108, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39,
  45, 118, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 87,
  104, 101, 110, 32, 39, 108, 101, 118, 101, 108, 39, 62, 61, 48, 44, 32,
  71, 39, 77, 73, 67, 32, 108, 111, 103, 32, 109, 101, 115, 115, 97, 103,
  101, 115, 32, 97, 114, 101, 32, 100, 105, 115, 112, 108, 97, 121, 101, 100,
  32, 111, 110, 32, 116, 104, 101, 32, 115, 116, 97, 110, 100, 97, 114, 100,
  32, 101, 114, 114, 111, 114, 32, 40, 115, 116, 100, 101, 114, 114, 41, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108,
  116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 108, 101, 118, 101, 108, 61,
  48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 119, 97, 105, 116, 32,
  58, 32, 100, 101, 108, 97, 121, 32, 58, 32, 40, 110, 111, 32, 97, 114,
  103, 115, 41, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 87, 97, 105, 116, 32, 102, 111, 114, 32, 97, 32, 103, 105,
  118, 101, 110, 32, 100, 101, 108, 97, 121, 32, 40, 105, 110, 32, 109, 115,
  41, 32, 115, 105, 110, 99, 101, 32, 108, 97, 115, 116, 32, 99, 97, 108,
  108, 44, 32, 111, 114, 32, 115, 108, 101, 101, 112, 32, 100, 117, 114, 105,
  110, 103, 32, 97, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 100,
  101, 108, 97, 121, 44, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 111,
  114, 32, 119, 97, 105, 116, 32, 102, 111, 114, 32, 97, 32, 117, 115, 101,
  114, 32, 101, 118, 101, 110, 116, 32, 111, 99, 99, 117, 114, 105, 110, 103,
  32, 111, 110, 32, 116, 104, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 110, 115, 116, 97, 110, 116, 32, 119, 105, 110, 100, 111, 119, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 100, 101, 108, 97, 121,
  39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 60, 48, 61, 100, 101,
  108, 97, 121, 43, 102, 108, 117, 115, 104, 32, 124, 32, 48, 61, 101, 118,
  101, 110, 116, 32, 124, 32, 62, 48, 61, 100, 101, 108, 97, 121, 32, 125,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 109, 97,
  110, 100, 32, 115, 117, 98, 115, 101, 116, 32, 40, 105, 102, 32, 97, 110,
  121, 41, 32, 115, 116, 97, 110, 100, 115, 32, 102, 111, 114, 32, 105, 110,
  115, 116, 97, 110, 116, 32, 119, 105, 110, 100, 111, 119, 32, 105, 110, 100,
  105, 99, 101, 115, 32, 105, 110, 115, 116, 101, 97, 100, 32, 111, 102, 32,
  105, 109, 97, 103, 101, 32, 105, 110, 100, 105, 99, 101, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 73, 102, 32, 110, 111, 32, 119, 105,
  110, 100, 111, 119, 32, 105, 110, 100, 105, 99, 101, 115, 32, 97, 114, 101,
  32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 97, 110, 100, 32, 105,
  102, 32, 39, 100, 101, 108, 97, 121, 39, 32, 105, 115, 32, 110, 101, 103,
  97, 116, 105, 118, 101, 44, 32, 116, 104, 101, 32, 99, 111, 109, 109, 97,
  110, 100, 32, 114, 101, 115, 117, 108, 116, 115, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 105, 110, 32, 97, 32, 104, 97, 114, 100, 32, 115, 108,
  101, 101, 112, 32, 100, 117, 114, 105, 110, 103, 32, 115, 112, 101, 99, 105,
  102, 105, 101, 100, 32, 100, 101, 108, 97, 121, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108,
  117, 101, 58, 32, 39, 100, 101, 108, 97, 121, 61, 48, 39, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 119, 97, 114, 110, 32, 58, 32, 109, 101, 115,
  115, 97, 103, 101, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 80, 114, 105, 110, 116, 32, 115, 112, 101, 99, 105, 102,
  105, 101, 100, 32, 119, 97, 114, 110, 105, 110, 103, 32, 109, 101, 115, 115,
  97, 103, 101, 44, 32, 111, 110, 32, 116, 104, 101, 32, 115, 116, 97, 110,
  100, 97, 114, 100, 32, 101, 114, 114, 111, 114, 32, 40, 115, 116, 100, 101,
  114, 114, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111,
  109, 109, 97, 110, 100, 32, 115, 117, 98, 115, 101, 116, 32, 40, 105, 102,
  32, 97, 110, 121, 41, 32, 115, 116, 97, 110, 100, 115, 32, 102, 111, 114,
  32, 100, 105, 115, 112, 108, 97, 121, 101, 100, 32, 115, 99, 111, 112, 101,
  32, 105, 110, 100, 105, 99, 101, 115, 32, 105, 110, 115, 116, 101, 97, 100,
  32, 111, 102, 32, 105, 109, 97, 103, 101, 32, 105, 110, 100, 105, 99, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 119, 32, 58, 32, 101, 113,
  46, 32, 116, 111, 32, 39, 45, 119, 105, 110, 100, 111, 119, 39, 46, 32,
  58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 119, 105, 110,
  100, 111, 119, 32, 58, 32, 95, 119, 105, 100, 116, 104, 91, 37, 93, 62,
  61, 45, 49, 44, 95, 104, 101, 105, 103, 104, 116, 91, 37, 93, 62, 61,
  45, 49, 44, 95, 110, 111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111,
  110, 44, 95, 102, 117, 108, 108, 115, 99, 114, 101, 101, 110, 44, 95, 112,
  111, 115, 95, 120, 91, 37, 93, 44, 95, 112, 111, 115, 95, 121, 91, 37,
  93, 44, 95, 116, 105, 116, 108, 101, 32, 58, 32, 40, 43, 41, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 105, 115, 112, 108, 97, 121, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32,
  105, 110, 116, 111, 32, 97, 110, 32, 105, 110, 115, 116, 97, 110, 116, 32,
  119, 105, 110, 100, 111, 119, 32, 119, 105, 116, 104, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 115, 105, 122, 101, 44, 32, 110, 111, 114, 109,
  97, 108, 105, 122, 97, 116, 105, 111, 110, 32, 116, 121, 112, 101, 44, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 102, 117, 108, 108, 115, 99, 114,
  101, 101, 110, 32, 109, 111, 100, 101, 32, 97, 110, 100, 32, 116, 105, 116,
  108, 101, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113,
  46, 32, 116, 111, 32, 39, 45, 119, 39, 41, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 73, 102, 32, 39, 119, 105, 100, 116, 104, 39, 32,
  111, 114, 32, 39, 104, 101, 105, 103, 104, 116, 39, 32, 105, 115, 32, 115,
  101, 116, 32, 116, 111, 32, 45, 49, 44, 32, 116, 104, 101, 32, 99, 111,
  114, 114, 101, 115, 112, 111, 110, 100, 105, 110, 103, 32, 100, 105, 109, 101,
  110, 115, 105, 111, 110, 32, 105, 115, 32, 97, 100, 106, 117, 115, 116, 101,
  100, 32, 116, 111, 32, 116, 104, 101, 32, 119, 105, 110, 100, 111, 119, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 111, 114, 32, 105, 109, 97, 103,
  101, 32, 115, 105, 122, 101, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 87, 104, 101, 110, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 32,
  39, 112, 111, 115, 95, 120, 39, 32, 97, 110, 100, 32, 39, 112, 111, 115,
  95, 121, 39, 32, 97, 114, 101, 32, 98, 111, 116, 104, 32, 100, 105, 102,
  102, 101, 114, 101, 110, 116, 32, 116, 104, 97, 110, 32, 45, 49, 44, 32,
  116, 104, 101, 32, 119, 105, 110, 100, 111, 119, 32, 105, 115, 32, 109, 111,
  118, 101, 100, 32, 116, 111, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  116, 104, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 99, 111,
  111, 114, 100, 105, 110, 97, 116, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 39, 119, 105, 100, 116, 104, 39, 61, 48, 32, 111, 114,
  32, 39, 104, 101, 105, 103, 104, 116, 39, 61, 48, 32, 99, 108, 111, 115,
  101, 115, 32, 116, 104, 101, 32, 105, 110, 115, 116, 97, 110, 116, 32, 119,
  105, 110, 100, 111, 119, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  39, 110, 111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110, 39, 32,
  99, 97, 110, 32, 98, 101, 32, 123, 32, 45, 49, 61, 107, 101, 101, 112,
  32, 115, 97, 109, 101, 32, 124, 32, 48, 61, 110, 111, 110, 101, 32, 124,
  32, 49, 61, 97, 108, 119, 97, 121, 115, 32, 124, 32, 50, 61, 49, 115,
  116, 45, 116, 105, 109, 101, 32, 124, 32, 51, 61, 97, 117, 116, 111, 32,
  125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 102, 117, 108,
  108, 115, 99, 114, 101, 101, 110, 39, 32, 99, 97, 110, 32, 98, 101, 32,
  123, 32, 45, 49, 61, 107, 101, 101, 112, 32, 115, 97, 109, 101, 32, 124,
  32, 48, 61, 110, 111, 32, 124, 32, 49, 61, 121, 101, 115, 32, 125, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 89, 111, 117, 32, 99, 97,
  110, 32, 109, 97, 110, 97, 103, 101, 32, 117, 112, 32, 116, 111, 32, 49,
  48, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32, 105, 110, 115, 116,
  97, 110, 116, 32, 119, 105, 110, 100, 111, 119, 115, 32, 98, 121, 32, 117,
  115, 105, 110, 103, 32, 116, 104, 101, 32, 110, 117, 109, 98, 101, 114, 101,
  100, 32, 118, 97, 114, 105, 97, 110, 116, 115, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 39, 45, 119, 48, 39, 32, 40, 100, 101, 102, 97, 117,
  108, 116, 44, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 119, 39, 41,
  44, 39, 45, 119, 49, 39, 44, 46, 46, 44, 39, 45, 119, 57, 39, 32,
  111, 102, 32, 116, 104, 101, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39,
  45, 119, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101,
  102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 119,
  105, 100, 116, 104, 61, 104, 101, 105, 103, 104, 116, 61, 110, 111, 114, 109,
  97, 108, 105, 122, 97, 116, 105, 111, 110, 61, 102, 117, 108, 108, 115, 99,
  114, 101, 101, 110, 61, 45, 49, 39, 32, 97, 110, 100, 32, 39, 116, 105,
  116, 108, 101, 61, 40, 117, 110, 100, 101, 102, 105, 110, 101, 100, 41, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 58, 32, 76, 105, 115, 116,
  32, 109, 97, 110, 105, 112, 117, 108, 97, 116, 105, 111, 110, 10, 35, 64,
  103, 109, 105, 99, 32, 107, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32,
  39, 45, 107, 101, 101, 112, 39, 46, 32, 58, 32, 40, 42, 41, 10, 35,
  64, 103, 109, 105, 99, 32, 107, 101, 101, 112, 32, 58, 32, 40, 42, 41,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 75, 101, 101, 112, 32, 111,
  110, 108, 121, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101,
  113, 46, 32, 116, 111, 32, 39, 45, 107, 39, 41, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 115, 112, 108, 105, 116, 32, 120, 32, 45, 107, 101, 101, 112,
  91, 48, 45, 53, 48, 37, 58, 50, 93, 32, 45, 97, 112, 112, 101, 110,
  100, 32, 120, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 115, 112, 108, 105, 116, 32,
  120, 32, 45, 107, 101, 101, 112, 91, 94, 51, 48, 37, 45, 55, 48, 37,
  93, 32, 45, 97, 112, 112, 101, 110, 100, 32, 120, 10, 35, 64, 103, 109,
  105, 99, 32, 109, 118, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39,
  45, 109, 111, 118, 101, 39, 46, 32, 58, 32, 40, 42, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 109, 111, 118, 101, 32, 58, 32, 112, 111, 115, 105,
  116, 105, 111, 110, 91, 37, 93, 32, 58, 32, 40, 42, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 77, 111, 118, 101, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 97, 116, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 112, 111, 115, 105, 116, 105, 111,
  110, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46,
  32, 116, 111, 32, 39, 45, 109, 118, 39, 41, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 115, 112, 108, 105, 116, 32, 120, 44, 51, 32, 45, 109, 111, 118,
  101, 91, 49, 93, 32, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 115, 112, 108,
  105, 116, 32, 120, 32, 45, 109, 111, 118, 101, 91, 53, 48, 37, 45, 45,
  49, 58, 50, 93, 32, 48, 32, 45, 97, 112, 112, 101, 110, 100, 32, 120,
  10, 35, 64, 103, 109, 105, 99, 32, 110, 109, 32, 58, 32, 101, 113, 46,
  32, 116, 111, 32, 39, 45, 110, 97, 109, 101, 39, 46, 32, 58, 32, 40,
  42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 110, 97, 109, 101, 32, 58,
  32, 110, 97, 109, 101, 44, 95, 105, 115, 95, 109, 111, 100, 105, 102, 105,
  101, 100, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 32, 58, 32, 40,
  42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 101, 116, 32,
  110, 97, 109, 101, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 110, 109, 39, 41,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 114, 103, 117, 109,
  101, 110, 116, 32, 39, 105, 115, 95, 109, 111, 100, 105, 102, 105, 101, 100,
  39, 32, 116, 101, 108, 108, 115, 32, 97, 98, 111, 117, 116, 32, 116, 104,
  101, 32, 109, 111, 100, 105, 102, 105, 101, 100, 32, 115, 116, 97, 116, 101,
  32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101,
  102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 105, 115,
  95, 109, 111, 100, 105, 102, 105, 101, 100, 61, 48, 39, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 110, 97, 109, 101, 32, 105, 109, 97, 103, 101, 32, 45,
  98, 108, 117, 114, 91, 105, 109, 97, 103, 101, 93, 32, 50, 10, 35, 64,
  103, 109, 105, 99, 32, 114, 109, 32, 58, 32, 101, 113, 46, 32, 116, 111,
  32, 39, 45, 114, 101, 109, 111, 118, 101, 39, 46, 32, 58, 32, 40, 42,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 114, 101, 109, 111, 118, 101, 32,
  58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82,
  101, 109, 111, 118, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 114, 109, 39, 41, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 115, 112, 108, 105, 116, 32, 120, 32, 45, 114,
  101, 109, 111, 118, 101, 91, 51, 48, 37, 45, 55, 48, 37, 93, 32, 45,
  97, 112, 112, 101, 110, 100, 32, 120, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 115,
  112, 108, 105, 116, 32, 120, 32, 45, 114, 101, 109, 111, 118, 101, 91, 48,
  45, 53, 48, 37, 58, 50, 93, 32, 45, 97, 112, 112, 101, 110, 100, 32,
  120, 10, 35, 64, 103, 109, 105, 99, 32, 114, 118, 32, 58, 32, 101, 113,
  46, 32, 116, 111, 32, 39, 45, 114, 101, 118, 101, 114, 115, 101, 39, 46,
  32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 114, 101,
  118, 101, 114, 115, 101, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 82, 101, 118, 101, 114, 115, 101, 32, 112, 111, 115,
  105, 116, 105, 111, 110, 115, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 114, 118,
  39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 115, 112, 108, 105, 116, 32,
  120, 44, 51, 32, 45, 114, 101, 118, 101, 114, 115, 101, 91, 45, 50, 44,
  45, 49, 93, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 115, 112, 108, 105, 116, 32,
  120, 44, 45, 49, 54, 32, 45, 114, 101, 118, 101, 114, 115, 101, 91, 53,
  48, 37, 45, 49, 48, 48, 37, 93, 32, 45, 97, 112, 112, 101, 110, 100,
  32, 120, 10, 35, 64, 103, 109, 105, 99, 32, 115, 111, 114, 116, 95, 108,
  105, 115, 116, 32, 58, 32, 95, 111, 114, 100, 101, 114, 105, 110, 103, 61,
  123, 32, 43, 32, 124, 32, 45, 32, 125, 44, 95, 99, 114, 105, 116, 101,
  114, 105, 111, 110, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 111,
  114, 116, 32, 108, 105, 115, 116, 32, 111, 102, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 97, 99, 99, 111, 114,
  100, 105, 110, 103, 32, 116, 111, 32, 116, 104, 101, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 105, 109, 97, 103, 101, 32, 99, 114, 105, 116,
  101, 114, 105, 111, 110, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 111, 114, 100, 101, 114, 105, 110, 103, 61, 43, 39, 44, 32, 39, 99,
  114, 105, 116, 101, 114, 105, 111, 110, 61, 105, 39, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 40, 49, 59, 52, 59, 55, 59, 51,
  59, 57, 59, 50, 59, 52, 59, 55, 59, 54, 59, 51, 59, 57, 59, 49,
  59, 48, 59, 51, 59, 51, 59, 50, 41, 32, 45, 115, 112, 108, 105, 116,
  32, 121, 32, 45, 115, 111, 114, 116, 95, 108, 105, 115, 116, 32, 43, 32,
  45, 97, 112, 112, 101, 110, 100, 32, 121, 10, 115, 111, 114, 116, 95, 108,
  105, 115, 116, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  43, 125, 44, 36, 123, 50, 61, 105, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 83, 111, 114, 116, 32, 108, 105, 115, 116, 32, 111, 102, 32,
  105, 109, 97, 103, 101, 36, 63, 32, 105, 110, 32, 34, 64, 123, 45, 97,
  114, 103, 92, 32, 49, 43, 123, 36, 49, 39, 61, 61, 39, 43, 125, 44,
  100, 101, 115, 99, 101, 110, 100, 105, 110, 103, 44, 97, 115, 99, 101, 110,
  100, 105, 110, 103, 125, 34, 32, 111, 114, 100, 101, 114, 44, 32, 34, 92,
  10, 34, 97, 99, 99, 111, 114, 100, 105, 110, 103, 32, 116, 111, 32, 116,
  104, 101, 32, 105, 109, 97, 103, 101, 32, 99, 114, 105, 116, 101, 114, 105,
  111, 110, 32, 39, 36, 50, 39, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  105, 102, 32, 64, 35, 10, 105, 61, 64, 35, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 40, 64, 123, 36, 62, 44, 36, 50, 125, 41,
  32, 45, 100, 111, 110, 101, 32, 45, 97, 91, 36, 105, 45, 45, 49, 93,
  32, 121, 32, 45, 45, 102, 91, 45, 49, 93, 32, 39, 121, 39, 32, 45,
  97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 115, 111, 114, 116,
  91, 45, 49, 93, 32, 36, 49, 44, 121, 32, 45, 122, 91, 45, 49, 93,
  32, 49, 44, 49, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 104, 125,
  32, 110, 109, 36, 62, 61, 64, 123, 36, 62, 44, 110, 125, 32, 45, 110,
  109, 91, 36, 62, 93, 32, 115, 111, 114, 116, 108, 105, 115, 116, 36, 62,
  32, 45, 100, 111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  104, 125, 32, 45, 109, 118, 91, 115, 111, 114, 116, 108, 105, 115, 116, 123,
  105, 40, 48, 44, 36, 62, 41, 125, 93, 32, 45, 49, 32, 45, 100, 111,
  110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 104, 125, 32, 45,
  110, 109, 91, 36, 62, 93, 32, 36, 123, 110, 109, 123, 105, 40, 48, 44,
  36, 62, 41, 125, 125, 32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 115, 111, 114, 116, 95, 115, 116, 114, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 111, 114, 116, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 40, 118,
  105, 101, 119, 101, 100, 32, 97, 115, 32, 97, 32, 108, 105, 115, 116, 32,
  111, 102, 32, 115, 116, 114, 105, 110, 103, 115, 41, 32, 105, 110, 32, 108,
  101, 120, 105, 99, 111, 103, 114, 97, 112, 104, 105, 99, 32, 111, 114, 100,
  101, 114, 46, 10, 115, 111, 114, 116, 95, 115, 116, 114, 32, 58, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 83, 111, 114, 116, 32, 105, 109, 97,
  103, 101, 36, 63, 32, 105, 110, 32, 108, 101, 120, 105, 99, 111, 103, 114,
  97, 112, 104, 105, 99, 32, 111, 114, 100, 101, 114, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 121, 32, 45, 97, 32, 120, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 114, 111, 117, 110, 100, 40, 104, 47, 52, 44, 49, 44,
  49, 41, 125, 32, 121, 61, 123, 52, 42, 36, 62, 125, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 60, 93, 10, 45,
  45, 114, 111, 119, 115, 32, 36, 121, 44, 123, 36, 121, 43, 51, 125, 32,
  45, 102, 91, 49, 93, 32, 39, 105, 102, 40, 105, 62, 61, 57, 55, 38,
  38, 105, 60, 61, 49, 50, 50, 44, 105, 45, 51, 50, 44, 105, 41, 39,
  32, 45, 45, 91, 45, 49, 93, 32, 51, 50, 32, 45, 99, 91, 45, 49,
  93, 32, 48, 44, 54, 51, 32, 45, 115, 91, 45, 49, 93, 32, 121, 32,
  45, 42, 91, 45, 50, 93, 32, 54, 52, 32, 45, 42, 91, 45, 51, 93,
  32, 52, 48, 57, 54, 32, 45, 42, 91, 45, 52, 93, 32, 50, 54, 50,
  49, 52, 52, 32, 45, 43, 91, 45, 52, 45, 45, 49, 93, 10, 45, 114,
  118, 32, 45, 97, 32, 121, 32, 45, 115, 111, 114, 116, 32, 43, 44, 120,
  32, 45, 45, 114, 111, 119, 115, 32, 48, 32, 45, 114, 111, 119, 115, 91,
  48, 93, 32, 49, 44, 49, 48, 48, 37, 32, 45, 108, 97, 98, 101, 108,
  91, 49, 93, 32, 45, 37, 91, 49, 93, 32, 50, 10, 45, 115, 91, 49,
  93, 32, 43, 44, 48, 32, 78, 61, 123, 64, 35, 45, 49, 125, 10, 120,
  48, 61, 48, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45,
  49, 125, 32, 120, 49, 61, 123, 36, 120, 48, 43, 64, 123, 123, 49, 43,
  36, 62, 125, 44, 104, 125, 125, 32, 45, 45, 122, 91, 48, 93, 32, 36,
  120, 48, 44, 123, 36, 120, 49, 45, 49, 125, 32, 120, 48, 61, 36, 120,
  49, 32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 48, 45, 36, 78,
  93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 100,
  111, 110, 101, 32, 45, 115, 32, 120, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 58, 32, 77, 97, 116, 104, 101, 109, 97, 116,
  105, 99, 97, 108, 32, 111, 112, 101, 114, 97, 116, 111, 114, 115, 10, 35,
  64, 103, 109, 105, 99, 32, 97, 98, 115, 32, 58, 32, 40, 43, 41, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101,
  32, 116, 104, 101, 32, 112, 111, 105, 110, 116, 119, 105, 115, 101, 32, 97,
  98, 115, 111, 108, 117, 116, 101, 32, 118, 97, 108, 117, 101, 115, 32, 111,
  102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 115, 117, 98, 32, 123, 105,
  97, 125, 32, 45, 97, 98, 115, 91, 45, 49, 93, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 51, 48, 48, 44, 49, 44, 49, 44, 49,
  44, 39, 99, 111, 115, 40, 50, 48, 42, 120, 47, 119, 41, 39, 32, 45,
  45, 97, 98, 115, 32, 45, 100, 105, 115, 112, 108, 97, 121, 95, 103, 114,
  97, 112, 104, 32, 52, 48, 48, 44, 51, 48, 48, 10, 35, 64, 103, 109,
  105, 99, 32, 97, 99, 111, 115, 32, 58, 32, 40, 43, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116,
  104, 101, 32, 112, 111, 105, 110, 116, 119, 105, 115, 101, 32, 97, 114, 99,
  45, 99, 111, 115, 105, 110, 101, 32, 111, 102, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 32, 45, 49, 44,
  49, 32, 45, 97, 99, 111, 115, 91, 45, 49, 93, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 51, 48, 48, 44, 49, 44, 49, 44, 49,
  44, 39, 120, 47, 119, 43, 48, 46, 49, 42, 117, 39, 32, 45, 45, 97,
  99, 111, 115, 32, 45, 100, 105, 115, 112, 108, 97, 121, 95, 103, 114, 97,
  112, 104, 32, 52, 48, 48, 44, 51, 48, 48, 10, 35, 64, 103, 109, 105,
  99, 32, 43, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 97,
  100, 100, 39, 46, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 97, 100, 100, 32, 58, 32, 118, 97, 108, 117, 101, 91, 37, 93,
  32, 58, 32, 91, 105, 109, 97, 103, 101, 93, 32, 58, 32, 39, 102, 111,
  114, 109, 117, 108, 97, 39, 32, 58, 32, 40, 110, 111, 32, 97, 114, 103,
  115, 41, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 65, 100, 100, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  118, 97, 108, 117, 101, 44, 32, 105, 109, 97, 103, 101, 32, 111, 114, 32,
  109, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 32, 101, 120, 112,
  114, 101, 115, 115, 105, 111, 110, 32, 116, 111, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 44, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 111, 114, 32, 99, 111, 109, 112, 117, 116, 101, 32,
  116, 104, 101, 32, 112, 111, 105, 110, 116, 119, 105, 115, 101, 32, 115, 117,
  109, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40,
  101, 113, 46, 32, 116, 111, 32, 39, 45, 43, 39, 41, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 45, 97, 100, 100, 32, 51, 48, 37, 32, 45, 99, 117,
  116, 32, 48, 44, 50, 53, 53, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 98,
  108, 117, 114, 32, 53, 32, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101,
  32, 48, 44, 50, 53, 53, 32, 45, 97, 100, 100, 91, 49, 93, 32, 91,
  48, 93, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 97, 100, 100, 32, 39, 56, 48,
  42, 99, 111, 115, 40, 56, 48, 42, 40, 120, 47, 119, 45, 48, 46, 53,
  41, 42, 40, 121, 47, 119, 45, 48, 46, 53, 41, 43, 99, 41, 39, 32,
  45, 99, 117, 116, 32, 48, 44, 50, 53, 53, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 57, 32, 45, 45, 114, 111, 116, 97,
  116, 101, 91, 48, 93, 32, 123, 36, 62, 42, 51, 54, 125, 44, 49, 44,
  48, 44, 53, 48, 37, 44, 53, 48, 37, 32, 45, 100, 111, 110, 101, 32,
  45, 97, 100, 100, 32, 45, 100, 105, 118, 32, 49, 48, 10, 35, 64, 103,
  109, 105, 99, 32, 97, 110, 100, 32, 58, 32, 118, 97, 108, 117, 101, 91,
  37, 93, 32, 58, 32, 91, 105, 109, 97, 103, 101, 93, 32, 58, 32, 39,
  102, 111, 114, 109, 117, 108, 97, 39, 32, 58, 32, 40, 110, 111, 32, 97,
  114, 103, 115, 41, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32,
  98, 105, 116, 119, 105, 115, 101, 32, 65, 78, 68, 32, 111, 102, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 119,
  105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 118, 97,
  108, 117, 101, 44, 32, 105, 109, 97, 103, 101, 32, 111, 114, 32, 109, 97,
  116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 44, 32,
  111, 114, 32, 99, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 112,
  111, 105, 110, 116, 119, 105, 115, 101, 32, 115, 101, 113, 117, 101, 110, 116,
  105, 97, 108, 32, 98, 105, 116, 119, 105, 115, 101, 32, 65, 78, 68, 32,
  111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 97, 110, 100, 32, 123, 49,
  50, 56, 43, 54, 52, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 109, 105,
  114, 114, 111, 114, 32, 120, 32, 45, 97, 110, 100, 10, 35, 64, 103, 109,
  105, 99, 32, 97, 115, 105, 110, 32, 58, 32, 40, 43, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116,
  104, 101, 32, 112, 111, 105, 110, 116, 119, 105, 115, 101, 32, 97, 114, 99,
  45, 115, 105, 110, 101, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 32, 45, 49, 44, 49, 32,
  45, 97, 115, 105, 110, 91, 45, 49, 93, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 51, 48, 48, 44, 49, 44, 49, 44, 49, 44, 39,
  120, 47, 119, 43, 48, 46, 49, 42, 117, 39, 32, 45, 45, 97, 115, 105,
  110, 32, 45, 100, 105, 115, 112, 108, 97, 121, 95, 103, 114, 97, 112, 104,
  32, 52, 48, 48, 44, 51, 48, 48, 10, 35, 64, 103, 109, 105, 99, 32,
  97, 116, 97, 110, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32,
  112, 111, 105, 110, 116, 119, 105, 115, 101, 32, 97, 114, 99, 45, 116, 97,
  110, 103, 101, 110, 116, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 32, 48, 44, 56, 32, 45,
  97, 116, 97, 110, 91, 45, 49, 93, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 51, 48, 48, 44, 49, 44, 49, 44, 49, 44, 39, 52,
  42, 120, 47, 119, 43, 117, 39, 32, 45, 45, 97, 116, 97, 110, 32, 45,
  100, 105, 115, 112, 108, 97, 121, 95, 103, 114, 97, 112, 104, 32, 52, 48,
  48, 44, 51, 48, 48, 10, 35, 64, 103, 109, 105, 99, 32, 97, 116, 97,
  110, 50, 32, 58, 32, 91, 120, 95, 97, 114, 103, 117, 109, 101, 110, 116,
  93, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 112, 111, 105,
  110, 116, 119, 105, 115, 101, 32, 111, 114, 105, 101, 110, 116, 101, 100, 32,
  97, 114, 99, 45, 116, 97, 110, 103, 101, 110, 116, 32, 111, 102, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 69, 97, 99, 104, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 32, 105, 115, 32,
  114, 101, 103, 97, 114, 100, 101, 100, 32, 97, 115, 32, 116, 104, 101, 32,
  121, 45, 97, 114, 103, 117, 109, 101, 110, 116, 32, 111, 102, 32, 116, 104,
  101, 32, 97, 114, 99, 45, 116, 97, 110, 103, 101, 110, 116, 32, 102, 117,
  110, 99, 116, 105, 111, 110, 44, 32, 119, 104, 105, 108, 101, 32, 116, 104,
  101, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 115, 112, 101, 99, 105,
  102, 105, 101, 100, 32, 105, 109, 97, 103, 101, 32, 103, 105, 118, 101, 115,
  32, 116, 104, 101, 32, 99, 111, 114, 114, 101, 115, 112, 111, 110, 100, 105,
  110, 103, 32, 120, 45, 97, 114, 103, 117, 109, 101, 110, 116, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 40, 45, 49, 44, 49, 41,
  32, 40, 45, 49, 59, 49, 41, 32, 45, 114, 101, 115, 105, 122, 101, 32,
  52, 48, 48, 44, 52, 48, 48, 44, 49, 44, 49, 44, 51, 32, 45, 97,
  116, 97, 110, 50, 91, 49, 93, 32, 91, 48, 93, 32, 45, 107, 101, 101,
  112, 91, 49, 93, 32, 45, 109, 111, 100, 32, 123, 112, 105, 47, 56, 125,
  10, 35, 64, 103, 109, 105, 99, 32, 60, 60, 32, 58, 32, 101, 113, 46,
  32, 116, 111, 32, 39, 45, 98, 115, 108, 39, 46, 32, 58, 32, 40, 43,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 98, 115, 108, 32, 58, 32, 118,
  97, 108, 117, 101, 91, 37, 93, 32, 58, 32, 91, 105, 109, 97, 103, 101,
  93, 32, 58, 32, 39, 102, 111, 114, 109, 117, 108, 97, 39, 32, 58, 32,
  40, 110, 111, 32, 97, 114, 103, 115, 41, 32, 58, 32, 40, 43, 41, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101,
  32, 116, 104, 101, 32, 98, 105, 116, 119, 105, 115, 101, 32, 108, 101, 102,
  116, 32, 115, 104, 105, 102, 116, 32, 111, 102, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 119, 105, 116, 104, 32,
  115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 118, 97, 108, 117, 101, 44,
  32, 105, 109, 97, 103, 101, 32, 111, 114, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 109, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 32,
  101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 44, 32, 111, 114, 32, 99,
  111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 112, 111, 105, 110, 116,
  119, 105, 115, 101, 32, 115, 101, 113, 117, 101, 110, 116, 105, 97, 108, 32,
  98, 105, 116, 119, 105, 115, 101, 32, 108, 101, 102, 116, 32, 115, 104, 105,
  102, 116, 32, 111, 102, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111,
  32, 39, 45, 60, 60, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 98,
  115, 108, 32, 39, 114, 111, 117, 110, 100, 40, 51, 42, 120, 47, 119, 44,
  48, 41, 39, 32, 45, 99, 117, 116, 32, 48, 44, 50, 53, 53, 10, 35,
  64, 103, 109, 105, 99, 32, 62, 62, 32, 58, 32, 101, 113, 46, 32, 116,
  111, 32, 39, 45, 98, 115, 114, 39, 46, 32, 58, 32, 40, 43, 41, 10,
  35, 64, 103, 109, 105, 99, 32, 98, 115, 114, 32, 58, 32, 118, 97, 108,
  117, 101, 91, 37, 93, 32, 58, 32, 91, 105, 109, 97, 103, 101, 93, 32,
  58, 32, 39, 102, 111, 114, 109, 117, 108, 97, 39, 32, 58, 32, 40, 110,
  111, 32, 97, 114, 103, 115, 41, 32, 58, 32, 40, 43, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116,
  104, 101, 32, 98, 105, 116, 119, 105, 115, 101, 32, 114, 105, 103, 104, 116,
  32, 115, 104, 105, 102, 116, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 119, 105, 116, 104, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 118, 97, 108, 117, 101, 44, 32,
  105, 109, 97, 103, 101, 32, 111, 114, 34, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 109, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 32,
  101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 44, 32, 111, 114, 32, 99,
  111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 112, 111, 105, 110, 116,
  119, 105, 115, 101, 32, 115, 101, 113, 117, 101, 110, 116, 105, 97, 108, 32,
  98, 105, 116, 119, 105, 115, 101, 32, 114, 105, 103, 104, 116, 32, 115, 104,
  105, 102, 116, 32, 111, 102, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116,
  111, 32, 39, 45, 62, 62, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  98, 115, 114, 32, 39, 114, 111, 117, 110, 100, 40, 51, 42, 120, 47, 119,
  44, 48, 41, 39, 32, 45, 99, 117, 116, 32, 48, 44, 50, 53, 53, 10,
  35, 64, 103, 109, 105, 99, 32, 99, 111, 115, 32, 58, 32, 40, 43, 41,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116,
  101, 32, 116, 104, 101, 32, 112, 111, 105, 110, 116, 119, 105, 115, 101, 32,
  99, 111, 115, 105, 110, 101, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 32, 48, 44, 123, 50,
  42, 112, 105, 125, 32, 45, 99, 111, 115, 91, 45, 49, 93, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 51, 48, 48, 44, 49, 44, 49,
  44, 49, 44, 39, 50, 48, 42, 120, 47, 119, 43, 117, 39, 32, 45, 45,
  99, 111, 115, 32, 45, 100, 105, 115, 112, 108, 97, 121, 95, 103, 114, 97,
  112, 104, 32, 52, 48, 48, 44, 51, 48, 48, 10, 35, 64, 103, 109, 105,
  99, 32, 99, 111, 115, 104, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104,
  101, 32, 112, 111, 105, 110, 116, 119, 105, 115, 101, 32, 104, 121, 112, 101,
  114, 98, 111, 108, 105, 99, 32, 99, 111, 115, 105, 110, 101, 32, 111, 102,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 45, 110, 111, 114, 109, 97, 108, 105,
  122, 101, 32, 45, 51, 44, 51, 32, 45, 99, 111, 115, 104, 91, 45, 49,
  93, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 51, 48, 48,
  44, 49, 44, 49, 44, 49, 44, 39, 52, 42, 120, 47, 119, 43, 117, 39,
  32, 45, 45, 99, 111, 115, 104, 32, 45, 100, 105, 115, 112, 108, 97, 121,
  95, 103, 114, 97, 112, 104, 32, 52, 48, 48, 44, 51, 48, 48, 10, 35,
  64, 103, 109, 105, 99, 32, 47, 32, 58, 32, 101, 113, 46, 32, 116, 111,
  32, 39, 45, 100, 105, 118, 39, 46, 32, 58, 32, 40, 43, 41, 10, 35,
  64, 103, 109, 105, 99, 32, 100, 105, 118, 32, 58, 32, 118, 97, 108, 117,
  101, 91, 37, 93, 32, 58, 32, 91, 105, 109, 97, 103, 101, 93, 32, 58,
  32, 39, 102, 111, 114, 109, 117, 108, 97, 39, 32, 58, 32, 40, 110, 111,
  32, 97, 114, 103, 115, 41, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 105, 118, 105, 100, 101, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 32, 98, 121, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 118, 97, 108, 117, 101, 44, 32,
  105, 109, 97, 103, 101, 32, 111, 114, 32, 109, 97, 116, 104, 101, 109, 97,
  116, 105, 99, 97, 108, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110,
  44, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 111, 114, 32, 99, 111,
  109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 112, 111, 105, 110, 116, 119,
  105, 115, 101, 32, 113, 117, 111, 116, 105, 101, 110, 116, 32, 111, 102, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116,
  111, 32, 39, 45, 47, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 100,
  105, 118, 32, 39, 49, 43, 97, 98, 115, 40, 99, 111, 115, 40, 120, 47,
  49, 48, 41, 42, 115, 105, 110, 40, 121, 47, 49, 48, 41, 41, 39, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101,
  32, 45, 45, 100, 105, 118, 10, 35, 64, 103, 109, 105, 99, 32, 61, 61,
  32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 101, 113, 39, 46,
  32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 101, 113,
  32, 58, 32, 118, 97, 108, 117, 101, 91, 37, 93, 32, 58, 32, 91, 105,
  109, 97, 103, 101, 93, 32, 58, 32, 39, 102, 111, 114, 109, 117, 108, 97,
  39, 32, 58, 32, 40, 110, 111, 32, 97, 114, 103, 115, 41, 32, 58, 32,
  40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109,
  112, 117, 116, 101, 32, 116, 104, 101, 32, 98, 111, 111, 108, 101, 97, 110,
  32, 101, 113, 117, 97, 108, 105, 116, 121, 32, 111, 102, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 119, 105, 116,
  104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 118, 97, 108, 117,
  101, 44, 32, 105, 109, 97, 103, 101, 32, 111, 114, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 109, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97,
  108, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 44, 32, 111, 114,
  32, 99, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 98, 111, 111,
  108, 101, 97, 110, 32, 101, 113, 117, 97, 108, 105, 116, 121, 32, 111, 102,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32,
  116, 111, 32, 39, 45, 61, 61, 39, 41, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 114, 111, 117, 110, 100, 32, 52, 48, 32, 45, 101, 113, 32, 123, 114,
  111, 117, 110, 100, 40, 105, 97, 44, 52, 48, 41, 125, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 45, 109, 105, 114, 114, 111, 114, 32, 120, 32, 45, 101, 113,
  10, 35, 64, 103, 109, 105, 99, 32, 101, 120, 112, 32, 58, 32, 40, 43,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117,
  116, 101, 32, 116, 104, 101, 32, 112, 111, 105, 110, 116, 119, 105, 115, 101,
  32, 101, 120, 112, 111, 110, 101, 110, 116, 105, 97, 108, 32, 111, 102, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 110, 111, 114, 109, 97, 108, 105, 122,
  101, 32, 48, 44, 50, 32, 45, 101, 120, 112, 91, 45, 49, 93, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 51, 48, 48, 44, 49, 44,
  49, 44, 49, 44, 39, 55, 42, 120, 47, 119, 43, 117, 39, 32, 45, 45,
  101, 120, 112, 32, 45, 100, 105, 115, 112, 108, 97, 121, 95, 103, 114, 97,
  112, 104, 32, 52, 48, 48, 44, 51, 48, 48, 10, 35, 64, 103, 109, 105,
  99, 32, 62, 61, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45,
  103, 101, 39, 46, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 103, 101, 32, 58, 32, 118, 97, 108, 117, 101, 91, 37, 93, 32,
  58, 32, 91, 105, 109, 97, 103, 101, 93, 32, 58, 32, 39, 102, 111, 114,
  109, 117, 108, 97, 39, 32, 58, 32, 40, 110, 111, 32, 97, 114, 103, 115,
  41, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 98, 111, 111,
  108, 101, 97, 110, 32, 39, 103, 114, 101, 97, 116, 101, 114, 32, 111, 114,
  32, 101, 113, 117, 97, 108, 32, 116, 104, 97, 110, 39, 32, 111, 102, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32,
  119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 118,
  97, 108, 117, 101, 44, 32, 105, 109, 97, 103, 101, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 111, 114, 32, 109, 97, 116, 104, 101, 109, 97, 116,
  105, 99, 97, 108, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 44,
  32, 111, 114, 32, 99, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32,
  98, 111, 111, 108, 101, 97, 110, 32, 39, 103, 114, 101, 97, 116, 101, 114,
  32, 111, 114, 32, 101, 113, 117, 97, 108, 32, 116, 104, 97, 110, 39, 32,
  111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113,
  46, 32, 116, 111, 32, 39, 45, 62, 61, 39, 41, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 103, 101, 32, 123, 105, 97, 125, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 45, 109, 105, 114, 114, 111, 114, 32, 120, 32, 45, 103, 101, 10, 35,
  64, 103, 109, 105, 99, 32, 62, 32, 58, 32, 101, 113, 46, 32, 116, 111,
  32, 39, 45, 103, 116, 39, 46, 32, 58, 32, 40, 43, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 103, 116, 32, 58, 32, 118, 97, 108, 117, 101, 91,
  37, 93, 32, 58, 32, 91, 105, 109, 97, 103, 101, 93, 32, 58, 32, 39,
  102, 111, 114, 109, 117, 108, 97, 39, 32, 58, 32, 40, 110, 111, 32, 97,
  114, 103, 115, 41, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32,
  98, 111, 111, 108, 101, 97, 110, 32, 39, 103, 114, 101, 97, 116, 101, 114,
  32, 116, 104, 97, 110, 39, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 119, 105, 116, 104, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 118, 97, 108, 117, 101, 44, 32,
  105, 109, 97, 103, 101, 32, 111, 114, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 109, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 32, 101,
  120, 112, 114, 101, 115, 115, 105, 111, 110, 44, 32, 111, 114, 32, 99, 111,
  109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 98, 111, 111, 108, 101, 97,
  110, 32, 39, 103, 114, 101, 97, 116, 101, 114, 32, 116, 104, 97, 110, 39,
  32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101,
  113, 46, 32, 116, 111, 32, 39, 45, 62, 39, 41, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 103, 116, 32, 123, 105, 97, 125, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 45, 109, 105, 114, 114, 111, 114, 32, 120, 32, 45, 103, 116, 10, 35,
  64, 103, 109, 105, 99, 32, 60, 61, 32, 58, 32, 101, 113, 46, 32, 116,
  111, 32, 39, 45, 108, 101, 39, 46, 32, 58, 32, 40, 43, 41, 10, 35,
  64, 103, 109, 105, 99, 32, 108, 101, 32, 58, 32, 118, 97, 108, 117, 101,
  91, 37, 93, 32, 58, 32, 91, 105, 109, 97, 103, 101, 93, 32, 58, 32,
  39, 102, 111, 114, 109, 117, 108, 97, 39, 32, 58, 32, 40, 110, 111, 32,
  97, 114, 103, 115, 41, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101,
  32, 98, 111, 111, 108, 101, 97, 110, 32, 39, 108, 101, 115, 115, 32, 111,
  114, 32, 101, 113, 117, 97, 108, 32, 116, 104, 97, 110, 39, 32, 111, 102,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  32, 119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  118, 97, 108, 117, 101, 44, 32, 105, 109, 97, 103, 101, 32, 111, 114, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 109, 97, 116, 104, 101, 109, 97,
  116, 105, 99, 97, 108, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110,
  44, 32, 111, 114, 32, 99, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101,
  32, 98, 111, 111, 108, 101, 97, 110, 32, 39, 108, 101, 115, 115, 32, 111,
  114, 32, 101, 113, 117, 97, 108, 32, 116, 104, 97, 110, 39, 32, 111, 102,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32,
  116, 111, 32, 39, 45, 60, 61, 39, 41, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 108, 101, 32, 123, 105, 97, 125, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45,
  109, 105, 114, 114, 111, 114, 32, 120, 32, 45, 108, 101, 10, 35, 64, 103,
  109, 105, 99, 32, 60, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39,
  45, 108, 116, 39, 46, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109,
  105, 99, 32, 108, 116, 32, 58, 32, 118, 97, 108, 117, 101, 91, 37, 93,
  32, 58, 32, 91, 105, 109, 97, 103, 101, 93, 32, 58, 32, 39, 102, 111,
  114, 109, 117, 108, 97, 39, 32, 58, 32, 40, 110, 111, 32, 97, 114, 103,
  115, 41, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 98, 111,
  111, 108, 101, 97, 110, 32, 39, 108, 101, 115, 115, 32, 116, 104, 97, 110,
  39, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 32, 119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102,
  105, 101, 100, 32, 118, 97, 108, 117, 101, 44, 32, 105, 109, 97, 103, 101,
  32, 111, 114, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 109, 97, 116,
  104, 101, 109, 97, 116, 105, 99, 97, 108, 32, 101, 120, 112, 114, 101, 115,
  115, 105, 111, 110, 44, 32, 111, 114, 32, 99, 111, 109, 112, 117, 116, 101,
  32, 116, 104, 101, 32, 98, 111, 111, 108, 101, 97, 110, 32, 39, 108, 101,
  115, 115, 32, 116, 104, 97, 110, 39, 32, 111, 102, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45,
  60, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 108, 116, 32, 123, 105,
  97, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 109, 105, 114, 114, 111, 114,
  32, 120, 32, 45, 108, 116, 10, 35, 64, 103, 109, 105, 99, 32, 108, 111,
  103, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 112, 111, 105,
  110, 116, 119, 105, 115, 101, 32, 98, 97, 115, 101, 45, 101, 32, 108, 111,
  103, 97, 114, 105, 116, 104, 109, 32, 111, 102, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 45, 97, 100, 100, 32, 49, 32, 45, 108, 111, 103, 91, 45, 49,
  93, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 51, 48, 48,
  44, 49, 44, 49, 44, 49, 44, 39, 55, 42, 120, 47, 119, 43, 117, 39,
  32, 45, 45, 108, 111, 103, 32, 45, 100, 105, 115, 112, 108, 97, 121, 95,
  103, 114, 97, 112, 104, 32, 52, 48, 48, 44, 51, 48, 48, 10, 35, 64,
  103, 109, 105, 99, 32, 108, 111, 103, 49, 48, 32, 58, 32, 40, 43, 41,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116,
  101, 32, 116, 104, 101, 32, 112, 111, 105, 110, 116, 119, 105, 115, 101, 32,
  98, 97, 115, 101, 45, 49, 48, 32, 108, 111, 103, 97, 114, 105, 116, 104,
  109, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 97, 100, 100,
  32, 49, 32, 45, 108, 111, 103, 49, 48, 91, 45, 49, 93, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 51, 48, 48, 44, 49, 44, 49,
  44, 49, 44, 39, 55, 42, 120, 47, 119, 43, 117, 39, 32, 45, 45, 108,
  111, 103, 49, 48, 32, 45, 100, 105, 115, 112, 108, 97, 121, 95, 103, 114,
  97, 112, 104, 32, 52, 48, 48, 44, 51, 48, 48, 10, 35, 64, 103, 109,
  105, 99, 32, 108, 111, 103, 50, 32, 58, 32, 40, 43, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116,
  104, 101, 32, 112, 111, 105, 110, 116, 119, 105, 115, 101, 32, 98, 97, 115,
  101, 45, 50, 32, 108, 111, 103, 97, 114, 105, 116, 104, 109, 32, 111, 102,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 97, 100, 100, 32, 49, 32, 45, 108,
  111, 103, 50, 91, 45, 49, 93, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 51, 48, 48, 44, 49, 44, 49, 44, 49, 44, 39, 55, 42,
  120, 47, 119, 43, 117, 39, 32, 45, 45, 108, 111, 103, 50, 32, 45, 100,
  105, 115, 112, 108, 97, 121, 95, 103, 114, 97, 112, 104, 32, 52, 48, 48,
  44, 51, 48, 48, 10, 35, 64, 103, 109, 105, 99, 32, 109, 97, 120, 32,
  58, 32, 118, 97, 108, 117, 101, 91, 37, 93, 32, 58, 32, 91, 105, 109,
  97, 103, 101, 93, 32, 58, 32, 39, 102, 111, 114, 109, 117, 108, 97, 39,
  32, 58, 32, 40, 110, 111, 32, 97, 114, 103, 115, 41, 32, 58, 32, 40,
  43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112,
  117, 116, 101, 32, 116, 104, 101, 32, 109, 97, 120, 105, 109, 117, 109, 32,
  98, 101, 116, 119, 101, 101, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 32, 97, 110, 100, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 118, 97, 108, 117, 101, 44, 32, 105, 109, 97,
  103, 101, 32, 111, 114, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 109,
  97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 32, 101, 120, 112, 114,
  101, 115, 115, 105, 111, 110, 44, 32, 111, 114, 32, 99, 111, 109, 112, 117,
  116, 101, 32, 116, 104, 101, 32, 112, 111, 105, 110, 116, 119, 105, 115, 101,
  32, 109, 97, 120, 105, 109, 97, 32, 98, 101, 116, 119, 101, 101, 110, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 109, 105, 114, 114, 111, 114, 32, 120,
  32, 45, 109, 97, 120, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 109, 97, 120, 32,
  39, 82, 61, 40, 40, 120, 47, 119, 45, 48, 46, 53, 41, 94, 50, 43,
  40, 121, 47, 104, 45, 48, 46, 53, 41, 94, 50, 41, 94, 48, 46, 53,
  59, 50, 53, 53, 42, 82, 39, 10, 35, 64, 103, 109, 105, 99, 32, 47,
  47, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 109, 100, 105,
  118, 39, 46, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99,
  32, 109, 100, 105, 118, 32, 58, 32, 118, 97, 108, 117, 101, 91, 37, 93,
  32, 58, 32, 91, 105, 109, 97, 103, 101, 93, 32, 58, 32, 39, 102, 111,
  114, 109, 117, 108, 97, 39, 32, 58, 32, 40, 110, 111, 32, 97, 114, 103,
  115, 41, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 109, 97,
  116, 114, 105, 120, 32, 100, 105, 118, 105, 115, 105, 111, 110, 32, 111, 102,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 109, 97, 116, 114, 105, 99,
  101, 115, 47, 118, 101, 99, 116, 111, 114, 115, 32, 98, 121, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 118, 97, 108, 117, 101, 44, 32, 105,
  109, 97, 103, 101, 32, 111, 114, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 109, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 32, 101, 120,
  112, 114, 101, 115, 115, 105, 111, 110, 44, 32, 111, 114, 32, 99, 111, 109,
  112, 117, 116, 101, 32, 116, 104, 101, 32, 109, 97, 116, 114, 105, 120, 32,
  100, 105, 118, 105, 115, 105, 111, 110, 32, 111, 102, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45,
  47, 47, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 109, 105, 110,
  32, 58, 32, 118, 97, 108, 117, 101, 91, 37, 93, 32, 58, 32, 91, 105,
  109, 97, 103, 101, 93, 32, 58, 32, 39, 102, 111, 114, 109, 117, 108, 97,
  39, 32, 58, 32, 40, 110, 111, 32, 97, 114, 103, 115, 41, 32, 58, 32,
  40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109,
  112, 117, 116, 101, 32, 116, 104, 101, 32, 109, 105, 110, 105, 109, 117, 109,
  32, 98, 101, 116, 119, 101, 101, 110, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 32, 97, 110, 100, 32, 115, 112, 101,
  99, 105, 102, 105, 101, 100, 32, 118, 97, 108, 117, 101, 44, 32, 105, 109,
  97, 103, 101, 32, 111, 114, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  109, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 32, 101, 120, 112,
  114, 101, 115, 115, 105, 111, 110, 44, 32, 111, 114, 32, 99, 111, 109, 112,
  117, 116, 101, 32, 116, 104, 101, 32, 112, 111, 105, 110, 116, 119, 105, 115,
  101, 32, 109, 105, 110, 105, 109, 97, 32, 98, 101, 116, 119, 101, 101, 110,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 45, 109, 105, 114, 114, 111, 114, 32,
  120, 32, 45, 109, 105, 110, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 109, 105, 110,
  32, 39, 82, 61, 40, 40, 120, 47, 119, 45, 48, 46, 53, 41, 94, 50,
  43, 40, 121, 47, 104, 45, 48, 46, 53, 41, 94, 50, 41, 94, 48, 46,
  53, 59, 50, 53, 53, 42, 82, 39, 10, 35, 64, 103, 109, 105, 99, 32,
  37, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 109, 111, 100,
  39, 46, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32,
  109, 111, 100, 32, 58, 32, 118, 97, 108, 117, 101, 91, 37, 93, 32, 58,
  32, 91, 105, 109, 97, 103, 101, 93, 32, 58, 32, 39, 102, 111, 114, 109,
  117, 108, 97, 39, 32, 58, 32, 40, 110, 111, 32, 97, 114, 103, 115, 41,
  32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 109, 111, 100, 117,
  108, 111, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 32, 119, 105, 116, 104, 32, 115, 112, 101, 99, 105,
  102, 105, 101, 100, 32, 118, 97, 108, 117, 101, 44, 32, 105, 109, 97, 103,
  101, 32, 111, 114, 32, 109, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97,
  108, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 101, 120, 112, 114, 101,
  115, 115, 105, 111, 110, 44, 32, 111, 114, 32, 99, 111, 109, 112, 117, 116,
  101, 32, 116, 104, 101, 32, 112, 111, 105, 110, 116, 119, 105, 115, 101, 32,
  115, 101, 113, 117, 101, 110, 116, 105, 97, 108, 32, 109, 111, 100, 117, 108,
  111, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40,
  101, 113, 46, 32, 116, 111, 32, 39, 45, 37, 39, 41, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 45, 109, 105, 114, 114, 111, 114, 32, 120, 32, 45, 109,
  111, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 109, 111, 100, 32, 39, 82, 61,
  40, 40, 120, 47, 119, 45, 48, 46, 53, 41, 94, 50, 43, 40, 121, 47,
  104, 45, 48, 46, 53, 41, 94, 50, 41, 94, 48, 46, 53, 59, 50, 53,
  53, 42, 82, 39, 10, 35, 64, 103, 109, 105, 99, 32, 42, 42, 32, 58,
  32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 109, 109, 117, 108, 39, 46,
  32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 109, 109,
  117, 108, 32, 58, 32, 118, 97, 108, 117, 101, 91, 37, 93, 32, 58, 32,
  91, 105, 109, 97, 103, 101, 93, 32, 58, 32, 39, 102, 111, 114, 109, 117,
  108, 97, 39, 32, 58, 32, 40, 110, 111, 32, 97, 114, 103, 115, 41, 32,
  58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67,
  111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 109, 97, 116, 114, 105,
  120, 32, 114, 105, 103, 104, 116, 32, 109, 117, 108, 116, 105, 112, 108, 105,
  99, 97, 116, 105, 111, 110, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 109, 97, 116, 114, 105, 99, 101, 115, 47, 118, 101, 99, 116,
  111, 114, 115, 32, 98, 121, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100,
  32, 118, 97, 108, 117, 101, 44, 32, 105, 109, 97, 103, 101, 32, 111, 114,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 109, 97, 116, 104, 101, 109,
  97, 116, 105, 99, 97, 108, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111,
  110, 44, 32, 111, 114, 32, 99, 111, 109, 112, 117, 116, 101, 32, 116, 104,
  101, 32, 109, 97, 116, 114, 105, 120, 32, 114, 105, 103, 104, 116, 32, 109,
  117, 108, 116, 105, 112, 108, 105, 99, 97, 116, 105, 111, 110, 32, 111, 102,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32,
  116, 111, 32, 39, 45, 42, 42, 39, 41, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 40, 48, 44, 49, 44, 48, 59, 48, 44, 48,
  44, 49, 59, 49, 44, 48, 44, 48, 41, 32, 40, 49, 59, 50, 59, 51,
  41, 32, 45, 45, 109, 109, 117, 108, 10, 35, 64, 103, 109, 105, 99, 32,
  42, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 109, 117, 108,
  39, 46, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32,
  109, 117, 108, 32, 58, 32, 118, 97, 108, 117, 101, 91, 37, 93, 32, 58,
  32, 91, 105, 109, 97, 103, 101, 93, 32, 58, 32, 39, 102, 111, 114, 109,
  117, 108, 97, 39, 32, 58, 32, 40, 110, 111, 32, 97, 114, 103, 115, 41,
  32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  77, 117, 108, 116, 105, 112, 108, 121, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 32, 98, 121, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 118, 97, 108, 117, 101, 44, 32, 105, 109, 97,
  103, 101, 32, 111, 114, 32, 109, 97, 116, 104, 101, 109, 97, 116, 105, 99,
  97, 108, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 44, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 111, 114, 32, 99, 111, 109, 112, 117,
  116, 101, 32, 116, 104, 101, 32, 112, 111, 105, 110, 116, 119, 105, 115, 101,
  32, 112, 114, 111, 100, 117, 99, 116, 32, 111, 102, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45,
  42, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 109, 117, 108, 32,
  50, 32, 45, 99, 117, 116, 32, 48, 44, 50, 53, 53, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 40, 49, 44, 50, 44, 51, 44, 52, 44, 53, 44, 54, 44, 55,
  44, 56, 41, 32, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32,
  91, 48, 93, 32, 45, 109, 117, 108, 91, 48, 93, 32, 91, 45, 49, 93,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 109, 117, 108, 32, 39, 49, 45, 51, 42,
  97, 98, 115, 40, 120, 47, 119, 45, 48, 46, 53, 41, 39, 32, 45, 99,
  117, 116, 32, 48, 44, 50, 53, 53, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45,
  108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 110, 101, 103, 97, 116,
  105, 118, 101, 91, 45, 49, 93, 32, 45, 45, 109, 117, 108, 10, 35, 64,
  103, 109, 105, 99, 32, 33, 61, 32, 58, 32, 101, 113, 46, 32, 116, 111,
  32, 39, 45, 110, 101, 113, 39, 46, 32, 58, 32, 40, 43, 41, 10, 35,
  64, 103, 109, 105, 99, 32, 110, 101, 113, 32, 58, 32, 118, 97, 108, 117,
  101, 91, 37, 93, 32, 58, 32, 91, 105, 109, 97, 103, 101, 93, 32, 58,
  32, 39, 102, 111, 114, 109, 117, 108, 97, 39, 32, 58, 32, 40, 110, 111,
  32, 97, 114, 103, 115, 41, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104,
  101, 32, 98, 111, 111, 108, 101, 97, 110, 32, 105, 110, 101, 113, 117, 97,
  108, 105, 116, 121, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 32, 119, 105, 116, 104, 32, 115, 112, 101,
  99, 105, 102, 105, 101, 100, 32, 118, 97, 108, 117, 101, 44, 32, 105, 109,
  97, 103, 101, 32, 111, 114, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  109, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 32, 101, 120, 112,
  114, 101, 115, 115, 105, 111, 110, 44, 32, 111, 114, 32, 99, 111, 109, 112,
  117, 116, 101, 32, 116, 104, 101, 32, 98, 111, 111, 108, 101, 97, 110, 32,
  105, 110, 101, 113, 117, 97, 108, 105, 116, 121, 32, 111, 102, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32,
  39, 45, 33, 61, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114, 111,
  117, 110, 100, 32, 52, 48, 32, 45, 110, 101, 113, 32, 123, 114, 111, 117,
  110, 100, 40, 105, 97, 44, 52, 48, 41, 125, 10, 35, 64, 103, 109, 105,
  99, 32, 111, 114, 32, 58, 32, 118, 97, 108, 117, 101, 91, 37, 93, 32,
  58, 32, 91, 105, 109, 97, 103, 101, 93, 32, 58, 32, 39, 102, 111, 114,
  109, 117, 108, 97, 39, 32, 58, 32, 40, 110, 111, 32, 97, 114, 103, 115,
  41, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 98, 105, 116,
  119, 105, 115, 101, 32, 79, 82, 32, 111, 102, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 119, 105, 116, 104, 32,
  115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 118, 97, 108, 117, 101, 44,
  32, 105, 109, 97, 103, 101, 32, 111, 114, 32, 109, 97, 116, 104, 101, 109,
  97, 116, 105, 99, 97, 108, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 44, 32, 111, 114, 32, 99,
  111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 112, 111, 105, 110, 116,
  119, 105, 115, 101, 32, 115, 101, 113, 117, 101, 110, 116, 105, 97, 108, 32,
  98, 105, 116, 119, 105, 115, 101, 32, 79, 82, 32, 111, 102, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 111, 114, 32, 49, 50, 56, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 45, 109, 105, 114, 114, 111, 114, 32, 120, 32, 45, 111, 114, 10,
  35, 64, 103, 109, 105, 99, 32, 94, 32, 58, 32, 101, 113, 46, 32, 116,
  111, 32, 39, 45, 112, 111, 119, 39, 46, 32, 58, 32, 40, 43, 41, 10,
  35, 64, 103, 109, 105, 99, 32, 112, 111, 119, 32, 58, 32, 118, 97, 108,
  117, 101, 91, 37, 93, 32, 58, 32, 91, 105, 109, 97, 103, 101, 93, 32,
  58, 32, 39, 102, 111, 114, 109, 117, 108, 97, 39, 32, 58, 32, 40, 110,
  111, 32, 97, 114, 103, 115, 41, 32, 58, 32, 40, 43, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 82, 97, 105, 115, 101, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 32, 116, 111, 32, 116,
  104, 101, 32, 112, 111, 119, 101, 114, 32, 111, 102, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 118, 97, 108, 117, 101, 44, 32, 105, 109, 97,
  103, 101, 32, 111, 114, 32, 109, 97, 116, 104, 101, 109, 97, 116, 105, 99,
  97, 108, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 101, 120, 112, 114,
  101, 115, 115, 105, 111, 110, 44, 32, 111, 114, 32, 99, 111, 109, 112, 117,
  116, 101, 32, 116, 104, 101, 32, 112, 111, 105, 110, 116, 119, 105, 115, 101,
  32, 115, 101, 113, 117, 101, 110, 116, 105, 97, 108, 32, 112, 111, 119, 101,
  114, 115, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 94, 39, 41, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 100, 105, 118, 32, 50, 53, 53, 32, 45, 45, 112,
  111, 119, 32, 48, 46, 53, 32, 45, 109, 117, 108, 32, 50, 53, 53, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 103, 114, 97, 100, 105, 101, 110, 116, 32, 45,
  112, 111, 119, 32, 50, 32, 45, 97, 100, 100, 32, 45, 112, 111, 119, 32,
  48, 46, 50, 10, 35, 64, 103, 109, 105, 99, 32, 114, 111, 108, 32, 58,
  32, 118, 97, 108, 117, 101, 91, 37, 93, 32, 58, 32, 91, 105, 109, 97,
  103, 101, 93, 32, 58, 32, 39, 102, 111, 114, 109, 117, 108, 97, 39, 32,
  58, 32, 40, 110, 111, 32, 97, 114, 103, 115, 41, 32, 58, 32, 40, 43,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117,
  116, 101, 32, 116, 104, 101, 32, 98, 105, 116, 119, 105, 115, 101, 32, 108,
  101, 102, 116, 32, 114, 111, 116, 97, 116, 105, 111, 110, 32, 111, 102, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32,
  119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 118,
  97, 108, 117, 101, 44, 32, 105, 109, 97, 103, 101, 32, 111, 114, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 109, 97, 116, 104, 101, 109, 97, 116,
  105, 99, 97, 108, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 44,
  32, 111, 114, 32, 99, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32,
  112, 111, 105, 110, 116, 119, 105, 115, 101, 32, 115, 101, 113, 117, 101, 110,
  116, 105, 97, 108, 32, 98, 105, 116, 119, 105, 115, 101, 32, 108, 101, 102,
  116, 32, 114, 111, 116, 97, 116, 105, 111, 110, 32, 111, 102, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114, 111,
  108, 32, 39, 114, 111, 117, 110, 100, 40, 51, 42, 120, 47, 119, 44, 48,
  41, 39, 32, 45, 99, 117, 116, 32, 48, 44, 50, 53, 53, 10, 35, 64,
  103, 109, 105, 99, 32, 114, 111, 114, 32, 58, 32, 118, 97, 108, 117, 101,
  91, 37, 93, 32, 58, 32, 91, 105, 109, 97, 103, 101, 93, 32, 58, 32,
  39, 102, 111, 114, 109, 117, 108, 97, 39, 32, 58, 32, 40, 110, 111, 32,
  97, 114, 103, 115, 41, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101,
  32, 98, 105, 116, 119, 105, 115, 101, 32, 114, 105, 103, 104, 116, 32, 114,
  111, 116, 97, 116, 105, 111, 110, 32, 111, 102, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 119, 105, 116, 104, 32,
  115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 118, 97, 108, 117, 101, 44,
  32, 105, 109, 97, 103, 101, 32, 111, 114, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 109, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 32,
  101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 44, 32, 111, 114, 32, 99,
  111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 112, 111, 105, 110, 116,
  119, 105, 115, 101, 32, 115, 101, 113, 117, 101, 110, 116, 105, 97, 108, 32,
  98, 105, 116, 119, 105, 115, 101, 32, 114, 105, 103, 104, 116, 32, 114, 111,
  116, 97, 116, 105, 111, 110, 32, 111, 102, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114, 111, 114, 32, 39, 114,
  111, 117, 110, 100, 40, 51, 42, 120, 47, 119, 44, 48, 41, 39, 32, 45,
  99, 117, 116, 32, 48, 44, 50, 53, 53, 10, 35, 64, 103, 109, 105, 99,
  32, 115, 105, 103, 110, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101,
  32, 112, 111, 105, 110, 116, 119, 105, 115, 101, 32, 115, 105, 103, 110, 32,
  111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 115, 117, 98, 32, 123,
  105, 97, 125, 32, 45, 115, 105, 103, 110, 91, 45, 49, 93, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 51, 48, 48, 44, 49, 44, 49,
  44, 49, 44, 39, 99, 111, 115, 40, 50, 48, 42, 120, 47, 119, 43, 117,
  41, 39, 32, 45, 45, 115, 105, 103, 110, 32, 45, 100, 105, 115, 112, 108,
  97, 121, 95, 103, 114, 97, 112, 104, 32, 52, 48, 48, 44, 51, 48, 48,
  10, 35, 64, 103, 109, 105, 99, 32, 115, 105, 110, 32, 58, 32, 40, 43,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117,
  116, 101, 32, 116, 104, 101, 32, 112, 111, 105, 110, 116, 119, 105, 115, 101,
  32, 115, 105, 110, 101, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 32, 48, 44, 123, 50, 42,
  112, 105, 125, 32, 45, 115, 105, 110, 91, 45, 49, 93, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 51, 48, 48, 44, 49, 44, 49, 44,
  49, 44, 39, 50, 48, 42, 120, 47, 119, 43, 117, 39, 32, 45, 45, 115,
  105, 110, 32, 45, 100, 105, 115, 112, 108, 97, 121, 95, 103, 114, 97, 112,
  104, 32, 52, 48, 48, 44, 51, 48, 48, 10, 35, 64, 103, 109, 105, 99,
  32, 115, 105, 110, 99, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101,
  32, 112, 111, 105, 110, 116, 119, 105, 115, 101, 32, 115, 105, 110, 99, 32,
  102, 117, 110, 99, 116, 105, 111, 110, 32, 111, 102, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 32, 123, 45,
  50, 42, 112, 105, 125, 44, 123, 50, 42, 112, 105, 125, 32, 45, 115, 105,
  110, 99, 91, 45, 49, 93, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 51, 48, 48, 44, 49, 44, 49, 44, 49, 44, 39, 50, 48, 42,
  120, 47, 119, 43, 117, 39, 32, 45, 45, 115, 105, 110, 99, 32, 45, 100,
  105, 115, 112, 108, 97, 121, 95, 103, 114, 97, 112, 104, 32, 52, 48, 48,
  44, 51, 48, 48, 10, 35, 64, 103, 109, 105, 99, 32, 115, 105, 110, 104,
  32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 112, 111, 105, 110,
  116, 119, 105, 115, 101, 32, 104, 121, 112, 101, 114, 98, 111, 108, 105, 99,
  32, 115, 105, 110, 101, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 32, 45, 51, 44, 51, 32,
  45, 115, 105, 110, 104, 91, 45, 49, 93, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 51, 48, 48, 44, 49, 44, 49, 44, 49, 44, 39,
  52, 42, 120, 47, 119, 43, 117, 39, 32, 45, 45, 115, 105, 110, 104, 32,
  45, 100, 105, 115, 112, 108, 97, 121, 95, 103, 114, 97, 112, 104, 32, 52,
  48, 48, 44, 51, 48, 48, 10, 35, 64, 103, 109, 105, 99, 32, 115, 113,
  114, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 112, 111, 105,
  110, 116, 119, 105, 115, 101, 32, 115, 113, 117, 97, 114, 101, 32, 102, 117,
  110, 99, 116, 105, 111, 110, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 45, 115, 113, 114, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 51, 48, 48, 44, 49, 44, 49, 44, 49, 44, 39, 52, 48, 42, 120,
  47, 119, 43, 117, 39, 32, 45, 45, 115, 113, 114, 32, 45, 100, 105, 115,
  112, 108, 97, 121, 95, 103, 114, 97, 112, 104, 32, 52, 48, 48, 44, 51,
  48, 48, 10, 35, 64, 103, 109, 105, 99, 32, 115, 113, 114, 116, 32, 58,
  32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111,
  109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 112, 111, 105, 110, 116, 119,
  105, 115, 101, 32, 115, 113, 117, 97, 114, 101, 32, 114, 111, 111, 116, 32,
  111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 115, 113, 114, 116, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 51, 48, 48, 44, 49,
  44, 49, 44, 49, 44, 39, 52, 48, 42, 120, 47, 119, 43, 117, 39, 32,
  45, 45, 115, 113, 114, 116, 32, 45, 100, 105, 115, 112, 108, 97, 121, 95,
  103, 114, 97, 112, 104, 32, 52, 48, 48, 44, 51, 48, 48, 10, 35, 64,
  103, 109, 105, 99, 32, 45, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32,
  39, 45, 115, 117, 98, 39, 46, 32, 58, 32, 40, 43, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 115, 117, 98, 32, 58, 32, 118, 97, 108, 117, 101,
  91, 37, 93, 32, 58, 32, 91, 105, 109, 97, 103, 101, 93, 32, 58, 32,
  39, 102, 111, 114, 109, 117, 108, 97, 39, 32, 58, 32, 40, 110, 111, 32,
  97, 114, 103, 115, 41, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 83, 117, 98, 116, 114, 97, 99, 116, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 118, 97, 108, 117, 101, 44, 32, 105,
  109, 97, 103, 101, 32, 111, 114, 32, 109, 97, 116, 104, 101, 109, 97, 116,
  105, 99, 97, 108, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32,
  116, 111, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 44, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 111, 114, 32,
  99, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 112, 111, 105, 110,
  116, 119, 105, 115, 101, 32, 100, 105, 102, 102, 101, 114, 101, 110, 99, 101,
  32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101,
  113, 46, 32, 116, 111, 32, 39, 45, 45, 39, 41, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 45, 115, 117, 98, 32, 51, 48, 37, 32, 45, 99, 117, 116,
  32, 48, 44, 50, 53, 53, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 109, 105,
  114, 114, 111, 114, 32, 120, 32, 45, 115, 117, 98, 91, 45, 49, 93, 32,
  91, 48, 93, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 115, 117, 98, 32, 39, 105,
  40, 119, 47, 50, 43, 48, 46, 57, 42, 40, 120, 45, 119, 47, 50, 41,
  44, 121, 41, 39, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 109, 105, 114, 114,
  111, 114, 32, 120, 32, 45, 115, 117, 98, 10, 35, 64, 103, 109, 105, 99,
  32, 116, 97, 110, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32,
  112, 111, 105, 110, 116, 119, 105, 115, 101, 32, 116, 97, 110, 103, 101, 110,
  116, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 110, 111, 114,
  109, 97, 108, 105, 122, 101, 32, 123, 45, 48, 46, 52, 55, 42, 112, 105,
  125, 44, 123, 48, 46, 52, 55, 42, 112, 105, 125, 32, 45, 116, 97, 110,
  91, 45, 49, 93, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  51, 48, 48, 44, 49, 44, 49, 44, 49, 44, 39, 50, 48, 42, 120, 47,
  119, 43, 117, 39, 32, 45, 45, 116, 97, 110, 32, 45, 100, 105, 115, 112,
  108, 97, 121, 95, 103, 114, 97, 112, 104, 32, 52, 48, 48, 44, 51, 48,
  48, 10, 35, 64, 103, 109, 105, 99, 32, 116, 97, 110, 104, 32, 58, 32,
  40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109,
  112, 117, 116, 101, 32, 116, 104, 101, 32, 112, 111, 105, 110, 116, 119, 105,
  115, 101, 32, 104, 121, 112, 101, 114, 98, 111, 108, 105, 99, 32, 116, 97,
  110, 103, 101, 110, 116, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 32, 45, 51, 44, 51, 32,
  45, 116, 97, 110, 104, 91, 45, 49, 93, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 51, 48, 48, 44, 49, 44, 49, 44, 49, 44, 39,
  52, 42, 120, 47, 119, 43, 117, 39, 32, 45, 45, 116, 97, 110, 104, 32,
  45, 100, 105, 115, 112, 108, 97, 121, 95, 103, 114, 97, 112, 104, 32, 52,
  48, 48, 44, 51, 48, 48, 10, 35, 64, 103, 109, 105, 99, 32, 120, 111,
  114, 32, 58, 32, 118, 97, 108, 117, 101, 91, 37, 93, 32, 58, 32, 91,
  105, 109, 97, 103, 101, 93, 32, 58, 32, 39, 102, 111, 114, 109, 117, 108,
  97, 39, 32, 58, 32, 40, 110, 111, 32, 97, 114, 103, 115, 41, 32, 58,
  32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111,
  109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 98, 105, 116, 119, 105, 115,
  101, 32, 88, 79, 82, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 32, 119, 105, 116, 104, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 118, 97, 108, 117, 101, 44, 32, 105,
  109, 97, 103, 101, 32, 111, 114, 32, 109, 97, 116, 104, 101, 109, 97, 116,
  105, 99, 97, 108, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 101, 120,
  112, 114, 101, 115, 115, 105, 111, 110, 44, 32, 111, 114, 32, 99, 111, 109,
  112, 117, 116, 101, 32, 116, 104, 101, 32, 112, 111, 105, 110, 116, 119, 105,
  115, 101, 32, 115, 101, 113, 117, 101, 110, 116, 105, 97, 108, 32, 98, 105,
  116, 119, 105, 115, 101, 32, 88, 79, 82, 32, 111, 102, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 120, 111, 114, 32, 49, 50, 56, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 45, 109, 105, 114, 114, 111, 114, 32, 120, 32, 45, 120, 111, 114,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 58, 32, 86, 97, 108, 117, 101,
  115, 32, 109, 97, 110, 105, 112, 117, 108, 97, 116, 105, 111, 110, 10, 35,
  64, 103, 109, 105, 99, 32, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118,
  101, 32, 58, 32, 48, 60, 61, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 60, 61, 49, 44, 120, 48, 44, 121, 48, 44, 120, 49, 44, 121, 49,
  44, 120, 50, 44, 121, 50, 44, 46, 46, 46, 44, 120, 78, 44, 121, 78,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32,
  99, 117, 114, 118, 101, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 97,
  116, 105, 111, 110, 32, 116, 111, 32, 105, 109, 97, 103, 101, 32, 118, 97,
  108, 117, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 49, 39, 44, 32, 39,
  120, 48, 61, 48, 39, 44, 32, 39, 121, 48, 61, 49, 48, 48, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 97, 112, 112, 108, 121, 95, 99, 117,
  114, 118, 101, 32, 49, 44, 48, 44, 48, 44, 49, 50, 56, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 48, 10, 97, 112, 112, 108, 121, 95, 99, 117,
  114, 118, 101, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123,
  49, 61, 49, 125, 62, 61, 48, 32, 38, 38, 32, 36, 49, 60, 61, 49,
  34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 48, 125, 44, 36,
  123, 51, 61, 49, 48, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 65, 112, 112, 108, 121, 32, 105, 110, 116, 101, 110, 115, 105, 116, 121,
  32, 99, 117, 114, 118, 101, 32, 119, 105, 116, 104, 32, 115, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 32, 36, 49, 32, 97, 110, 100, 32, 107, 101,
  121, 112, 111, 105, 110, 116, 115, 32, 40, 36, 123, 50, 45, 45, 49, 125,
  41, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 102, 117, 110, 99, 116, 105, 111, 110, 49, 100, 32,
  36, 123, 94, 48, 125, 32, 45, 109, 97, 112, 91, 94, 45, 49, 93, 32,
  91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 97, 112, 112, 108, 121, 95, 103,
  97, 109, 109, 97, 32, 58, 32, 103, 97, 109, 109, 97, 62, 61, 48, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 103,
  97, 109, 109, 97, 32, 99, 111, 114, 114, 101, 99, 116, 105, 111, 110, 32,
  116, 111, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 97, 112, 112, 108, 121,
  95, 103, 97, 109, 109, 97, 32, 50, 10, 97, 112, 112, 108, 121, 95, 103,
  97, 109, 109, 97, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 49,
  62, 61, 48, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112,
  108, 121, 32, 71, 97, 109, 109, 97, 45, 99, 111, 114, 114, 101, 99, 116,
  105, 111, 110, 32, 116, 111, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32,
  119, 105, 116, 104, 32, 103, 97, 109, 109, 97, 32, 36, 49, 46, 34, 10,
  45, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 32, 45, 114, 101, 116,
  117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 32, 109, 77, 61, 123, 105, 109, 125, 44, 123, 105, 77, 125, 32, 45,
  110, 32, 48, 44, 49, 32, 45, 94, 32, 123, 49, 47, 36, 49, 125, 32,
  45, 110, 32, 36, 109, 77, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 98,
  97, 108, 97, 110, 99, 101, 95, 103, 97, 109, 109, 97, 32, 58, 32, 95,
  114, 101, 102, 95, 99, 111, 108, 111, 114, 49, 44, 46, 46, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 99, 111,
  108, 111, 114, 32, 98, 97, 108, 97, 110, 99, 101, 32, 116, 114, 97, 110,
  115, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 111, 110, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 44, 32, 119, 105,
  116, 104, 32, 114, 101, 115, 112, 101, 99, 116, 32, 116, 111, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 114, 101, 102, 101, 114, 101, 110, 99,
  101, 32, 99, 111, 108, 111, 114, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115,
  58, 32, 39, 114, 101, 102, 95, 99, 111, 108, 111, 114, 49, 61, 49, 50,
  56, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 98, 97, 108, 97, 110,
  99, 101, 95, 103, 97, 109, 109, 97, 32, 49, 50, 56, 44, 54, 52, 44,
  54, 52, 10, 98, 97, 108, 97, 110, 99, 101, 95, 103, 97, 109, 109, 97,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 50, 56,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121,
  32, 99, 111, 108, 111, 114, 32, 98, 97, 108, 97, 110, 99, 101, 32, 116,
  114, 97, 110, 115, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 111, 110,
  32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 103,
  97, 109, 109, 97, 32, 99, 117, 114, 118, 101, 32, 97, 110, 100, 32, 114,
  101, 102, 101, 114, 101, 110, 99, 101, 32, 99, 111, 108, 111, 114, 32, 40,
  34, 36, 123, 94, 48, 125, 34, 41, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 40, 36, 123, 94, 48, 125, 41, 32, 45, 114, 91, 45, 49, 93,
  32, 64, 123, 45, 50, 44, 115, 125, 44, 49, 44, 49, 44, 49, 44, 48,
  44, 49, 32, 45, 115, 91, 45, 50, 93, 32, 99, 32, 45, 47, 91, 45,
  49, 93, 32, 50, 53, 53, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  64, 35, 45, 49, 125, 32, 45, 47, 91, 36, 62, 93, 32, 50, 53, 53,
  32, 45, 94, 91, 36, 62, 93, 32, 123, 108, 111, 103, 40, 64, 123, 45,
  49, 44, 36, 62, 125, 41, 47, 108, 111, 103, 40, 64, 123, 36, 62, 44,
  97, 125, 41, 125, 32, 45, 42, 91, 36, 62, 93, 32, 50, 53, 53, 32,
  45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 97,
  32, 99, 32, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 99, 111, 109, 112, 108, 101, 120, 50, 112, 111, 108, 97,
  114, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117,
  116, 101, 32, 99, 111, 109, 112, 108, 101, 120, 32, 116, 111, 32, 112, 111,
  108, 97, 114, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 115, 32, 111,
  102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 102, 102, 116, 32, 45, 99,
  111, 109, 112, 108, 101, 120, 50, 112, 111, 108, 97, 114, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 108, 111, 103, 91, 45, 50, 93, 32, 45, 115, 104,
  105, 102, 116, 91, 45, 50, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44,
  48, 44, 48, 44, 50, 32, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49,
  93, 10, 99, 111, 109, 112, 108, 101, 120, 50, 112, 111, 108, 97, 114, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117,
  116, 101, 32, 99, 111, 109, 112, 108, 101, 120, 32, 116, 111, 32, 112, 111,
  108, 97, 114, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 115, 32, 111,
  102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35,
  47, 50, 41, 125, 32, 45, 108, 91, 123, 50, 42, 36, 62, 125, 44, 123,
  50, 42, 36, 62, 43, 49, 125, 93, 10, 45, 114, 91, 49, 93, 32, 91,
  48, 93, 44, 51, 32, 45, 45, 97, 116, 97, 110, 50, 91, 49, 93, 32,
  91, 48, 93, 32, 45, 110, 109, 91, 45, 49, 93, 32, 64, 123, 49, 44,
  110, 125, 44, 49, 32, 45, 115, 113, 114, 91, 45, 51, 44, 45, 50, 93,
  32, 45, 43, 91, 45, 51, 44, 45, 50, 93, 32, 45, 115, 113, 114, 116,
  91, 45, 50, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 99, 111, 109,
  112, 114, 101, 115, 115, 95, 114, 108, 101, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 67, 111, 109, 112, 114, 101, 115, 115, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 97, 115, 32, 50,
  120, 78, 32, 100, 97, 116, 97, 32, 109, 97, 116, 114, 105, 99, 101, 115,
  44, 32, 117, 115, 105, 110, 103, 32, 82, 76, 69, 32, 97, 108, 103, 111,
  114, 105, 116, 104, 109, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114, 101, 115,
  105, 122, 101, 50, 100, 121, 32, 49, 48, 48, 32, 45, 113, 117, 97, 110,
  116, 105, 122, 101, 32, 52, 32, 45, 114, 111, 117, 110, 100, 32, 45, 45,
  99, 111, 109, 112, 114, 101, 115, 115, 95, 114, 108, 101, 32, 45, 45, 117,
  110, 99, 111, 109, 112, 114, 101, 115, 115, 95, 114, 108, 101, 91, 45, 49,
  93, 10, 99, 111, 109, 112, 114, 101, 115, 115, 95, 114, 108, 101, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 114, 101,
  115, 115, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 117, 115, 105, 110,
  103, 32, 82, 76, 69, 32, 97, 108, 103, 111, 114, 105, 116, 104, 109, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44,
  110, 125, 32, 105, 109, 61, 123, 105, 109, 125, 32, 119, 104, 100, 115, 61,
  123, 119, 125, 59, 123, 104, 125, 59, 123, 100, 125, 59, 123, 115, 125, 59,
  36, 105, 109, 10, 45, 45, 32, 36, 105, 109, 32, 45, 121, 32, 120, 32,
  40, 123, 64, 123, 48, 44, 45, 49, 125, 43, 49, 125, 41, 32, 45, 97,
  32, 120, 32, 45, 114, 32, 49, 48, 48, 37, 44, 51, 10, 45, 102, 91,
  45, 49, 93, 32, 39, 62, 105, 102, 40, 121, 61, 61, 48, 44, 105, 44,
  105, 102, 40, 121, 61, 61, 49, 44, 105, 102, 40, 105, 40, 120, 44, 48,
  41, 61, 61, 105, 40, 120, 43, 49, 44, 48, 41, 44, 45, 49, 44, 120,
  41, 44, 105, 102, 40, 105, 40, 120, 45, 49, 44, 49, 41, 61, 61, 45,
  49, 44, 105, 40, 120, 45, 49, 44, 50, 41, 43, 49, 44, 49, 41, 41,
  41, 39, 10, 45, 122, 32, 48, 44, 123, 119, 45, 50, 125, 32, 45, 115,
  32, 121, 44, 51, 32, 45, 100, 105, 115, 99, 97, 114, 100, 91, 49, 93,
  32, 45, 49, 32, 45, 119, 97, 114, 112, 91, 48, 44, 50, 93, 32, 91,
  49, 93, 44, 48, 44, 48, 32, 45, 114, 109, 91, 49, 93, 10, 45, 42,
  91, 45, 49, 93, 32, 45, 49, 32, 45, 114, 118, 32, 45, 97, 32, 120,
  32, 45, 121, 32, 45, 100, 105, 115, 99, 97, 114, 100, 32, 45, 49, 32,
  45, 102, 32, 39, 62, 105, 102, 40, 105, 40, 48, 44, 121, 45, 49, 41,
  60, 48, 38, 38, 105, 61, 61, 48, 38, 38, 105, 40, 48, 44, 121, 43,
  49, 41, 60, 48, 44, 45, 49, 44, 105, 41, 39, 32, 45, 100, 105, 115,
  99, 97, 114, 100, 32, 45, 49, 10, 45, 105, 91, 48, 93, 32, 40, 36,
  119, 104, 100, 115, 41, 32, 45, 97, 32, 121, 32, 45, 110, 109, 32, 36,
  110, 109, 44, 49, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 99, 117, 109,
  117, 108, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112,
  117, 116, 101, 32, 116, 104, 101, 32, 99, 117, 109, 117, 108, 97, 116, 105,
  118, 101, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 111, 102, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 105, 109, 97, 103, 101, 32, 100,
  97, 116, 97, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 104, 105, 115, 116,
  111, 103, 114, 97, 109, 32, 45, 45, 99, 117, 109, 117, 108, 91, 45, 49,
  93, 32, 45, 100, 105, 115, 112, 108, 97, 121, 95, 103, 114, 97, 112, 104,
  91, 45, 50, 44, 45, 49, 93, 32, 52, 48, 48, 44, 51, 48, 48, 44,
  51, 10, 99, 117, 109, 117, 108, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 99, 117, 109, 117, 108,
  97, 116, 105, 118, 101, 32, 111, 102, 32, 102, 117, 110, 99, 116, 105, 111,
  110, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 100, 105, 109,
  61, 123, 119, 125, 44, 123, 104, 125, 44, 123, 100, 125, 44, 123, 115, 125,
  32, 45, 121, 32, 120, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 114,
  111, 117, 110, 100, 40, 108, 111, 103, 50, 40, 119, 41, 44, 49, 44, 49,
  41, 125, 32, 45, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 123,
  50, 94, 36, 62, 125, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 100, 111, 110, 101, 10, 45, 114, 32, 36, 100, 105, 109, 44, 45, 49,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 99, 32, 58, 32, 101, 113, 46,
  32, 116, 111, 32, 39, 45, 99, 117, 116, 39, 46, 32, 58, 32, 40, 43,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 99, 117, 116, 32, 58, 32, 123,
  32, 118, 97, 108, 117, 101, 48, 91, 37, 93, 32, 124, 32, 91, 105, 109,
  97, 103, 101, 48, 93, 32, 125, 44, 123, 32, 118, 97, 108, 117, 101, 49,
  91, 37, 93, 32, 124, 32, 91, 105, 109, 97, 103, 101, 49, 93, 32, 125,
  32, 58, 32, 91, 105, 109, 97, 103, 101, 93, 32, 58, 32, 40, 110, 111,
  32, 97, 114, 103, 115, 41, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 67, 117, 116, 32, 118, 97, 108, 117, 101, 115,
  32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 32, 105, 110, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100,
  32, 114, 97, 110, 103, 101, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 99, 39, 41, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 110, 111, 97, 114, 103, 115,
  41, 32, 114, 117, 110, 115, 32, 105, 110, 116, 101, 114, 97, 99, 116, 105,
  118, 101, 32, 109, 111, 100, 101, 32, 40, 117, 115, 101, 115, 32, 116, 104,
  101, 32, 105, 110, 115, 116, 97, 110, 116, 32, 119, 105, 110, 100, 111, 119,
  32, 91, 48, 93, 32, 105, 102, 32, 111, 112, 101, 110, 101, 100, 41, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 97, 100, 100, 32, 51, 48, 37, 32,
  45, 99, 117, 116, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 45, 99, 117, 116, 32, 50, 53, 37, 44, 55, 53,
  37, 10, 35, 64, 103, 109, 105, 99, 32, 100, 105, 115, 99, 97, 114, 100,
  32, 58, 32, 118, 97, 108, 117, 101, 44, 95, 114, 101, 109, 111, 118, 101,
  95, 105, 102, 95, 110, 111, 116, 95, 102, 111, 117, 110, 100, 32, 61, 32,
  123, 32, 48, 32, 124, 32, 49, 32, 125, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 82, 101, 109, 111, 118, 101, 32, 115, 112, 101, 99, 105,
  102, 105, 101, 100, 32, 118, 97, 108, 117, 101, 32, 105, 110, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 97, 110,
  100, 32, 114, 101, 116, 117, 114, 110, 32, 114, 101, 115, 117, 108, 116, 115,
  32, 97, 115, 32, 115, 105, 110, 103, 108, 101, 45, 99, 111, 108, 117, 109,
  110, 32, 118, 101, 99, 116, 111, 114, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  58, 32, 39, 114, 101, 109, 111, 118, 101, 95, 105, 102, 95, 110, 111, 116,
  95, 102, 111, 117, 110, 100, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 40, 49, 59, 50, 59, 51, 59, 52, 59, 51,
  59, 50, 59, 49, 41, 32, 45, 45, 100, 105, 115, 99, 97, 114, 100, 32,
  50, 10, 100, 105, 115, 99, 97, 114, 100, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 50, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 82, 101, 109, 111, 118, 101, 32, 118, 97, 108, 117, 101, 32, 36,
  49, 32, 105, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 115, 32, 45, 44, 36, 49, 32, 45, 97,
  32, 121, 10, 45, 105, 102, 32, 123, 33, 64, 35, 34, 32, 38, 38, 32,
  34, 33, 36, 50, 125, 32, 49, 44, 49, 44, 49, 44, 49, 44, 36, 49,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  101, 105, 103, 101, 110, 50, 116, 101, 110, 115, 111, 114, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 82, 101, 99, 111, 109, 112, 111, 115, 101, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 112, 97, 105, 114, 115, 32, 111,
  102, 32, 101, 105, 103, 101, 110, 118, 97, 108, 117, 101, 115, 47, 101, 105,
  103, 101, 110, 118, 101, 99, 116, 111, 114, 115, 32, 97, 115, 32, 50, 120,
  50, 32, 111, 114, 32, 51, 120, 51, 32, 116, 101, 110, 115, 111, 114, 32,
  102, 105, 101, 108, 100, 115, 46, 10, 101, 105, 103, 101, 110, 50, 116, 101,
  110, 115, 111, 114, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  82, 101, 99, 111, 109, 112, 111, 115, 101, 32, 112, 97, 105, 114, 115, 32,
  105, 110, 32, 101, 105, 103, 101, 110, 32, 102, 105, 101, 108, 100, 36, 63,
  32, 97, 115, 32, 50, 120, 50, 32, 111, 114, 32, 51, 120, 51, 32, 116,
  101, 110, 115, 111, 114, 32, 102, 105, 101, 108, 100, 115, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 47,
  50, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93,
  32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 45, 105, 102, 32, 123,
  115, 61, 61, 50, 125, 10, 45, 115, 91, 45, 49, 93, 32, 99, 10, 45,
  45, 115, 113, 114, 91, 45, 49, 93, 32, 45, 42, 91, 45, 50, 93, 32,
  91, 45, 51, 93, 32, 45, 115, 113, 114, 91, 45, 51, 93, 10, 45, 115,
  104, 91, 45, 49, 93, 32, 45, 45, 42, 91, 45, 51, 93, 32, 45, 49,
  10, 45, 115, 104, 91, 45, 53, 93, 10, 45, 97, 91, 45, 51, 45, 45,
  49, 93, 32, 99, 32, 45, 97, 91, 45, 52, 45, 45, 50, 93, 32, 99,
  10, 45, 115, 104, 91, 45, 51, 93, 32, 48, 44, 48, 32, 45, 42, 91,
  45, 51, 44, 45, 49, 93, 10, 45, 115, 104, 91, 45, 51, 93, 32, 49,
  44, 49, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 10, 45, 114, 109,
  91, 45, 51, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45,
  101, 108, 105, 102, 32, 123, 115, 61, 61, 54, 125, 10, 45, 115, 91, 45,
  49, 93, 32, 99, 10, 45, 108, 91, 45, 54, 45, 45, 52, 93, 32, 45,
  45, 115, 113, 114, 91, 45, 50, 93, 32, 45, 45, 42, 91, 45, 50, 44,
  45, 51, 93, 32, 45, 45, 115, 113, 114, 91, 45, 51, 93, 32, 45, 42,
  91, 45, 53, 93, 32, 91, 45, 54, 93, 32, 45, 42, 91, 45, 52, 93,
  32, 91, 45, 54, 93, 32, 45, 115, 113, 114, 91, 45, 54, 93, 32, 45,
  97, 32, 99, 32, 45, 101, 110, 100, 108, 10, 45, 108, 91, 45, 51, 45,
  45, 49, 93, 32, 45, 45, 115, 113, 114, 91, 45, 50, 93, 32, 45, 45,
  42, 91, 45, 50, 44, 45, 51, 93, 32, 45, 45, 115, 113, 114, 91, 45,
  51, 93, 32, 45, 42, 91, 45, 53, 93, 32, 91, 45, 54, 93, 32, 45,
  42, 91, 45, 52, 93, 32, 91, 45, 54, 93, 32, 45, 115, 113, 114, 91,
  45, 54, 93, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 10, 45,
  115, 91, 45, 51, 93, 32, 99, 10, 45, 45, 91, 45, 53, 93, 32, 91,
  45, 51, 93, 32, 45, 45, 91, 45, 52, 93, 32, 91, 45, 51, 93, 32,
  45, 42, 91, 45, 50, 93, 32, 91, 45, 53, 93, 32, 45, 42, 91, 45,
  49, 93, 32, 91, 45, 52, 93, 10, 40, 49, 94, 48, 94, 48, 94, 49,
  94, 48, 94, 49, 41, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 51,
  93, 32, 45, 42, 91, 45, 49, 93, 32, 91, 45, 52, 93, 32, 45, 114,
  109, 91, 45, 54, 45, 45, 52, 93, 32, 45, 43, 91, 45, 51, 45, 45,
  49, 93, 10, 45, 101, 108, 115, 101, 32, 45, 101, 114, 114, 111, 114, 91,
  48, 45, 45, 51, 93, 32, 34, 73, 110, 118, 97, 108, 105, 100, 32, 105,
  109, 97, 103, 101, 32, 91, 34, 123, 64, 35, 45, 36, 62, 45, 49, 125,
  34, 93, 32, 58, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110, 115, 32,
  34, 123, 119, 125, 34, 44, 34, 123, 104, 125, 34, 44, 34, 123, 100, 125,
  34, 44, 34, 123, 115, 125, 34, 32, 100, 111, 101, 115, 32, 110, 111, 116,
  32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 32, 97, 32, 102, 105, 101,
  108, 100, 32, 111, 102, 32, 50, 100, 32, 111, 114, 32, 51, 100, 32, 101,
  105, 103, 101, 110, 118, 101, 99, 116, 111, 114, 115, 46, 34, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 101, 110, 100, 105, 97, 110, 32, 58, 32,
  40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 118,
  101, 114, 115, 101, 32, 100, 97, 116, 97, 32, 101, 110, 100, 105, 97, 110,
  110, 101, 115, 115, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  101, 113, 117, 97, 108, 105, 122, 101, 32, 58, 32, 95, 110, 98, 95, 108,
  101, 118, 101, 108, 115, 62, 48, 91, 37, 93, 44, 95, 118, 97, 108, 117,
  101, 95, 109, 105, 110, 91, 37, 93, 44, 95, 118, 97, 108, 117, 101, 95,
  109, 97, 120, 91, 37, 93, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  69, 113, 117, 97, 108, 105, 122, 101, 32, 104, 105, 115, 116, 111, 103, 114,
  97, 109, 115, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 73, 102, 32, 118, 97, 108, 117, 101, 32, 114, 97, 110, 103, 101, 32,
  105, 115, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 44, 32, 116, 104,
  101, 32, 101, 113, 117, 97, 108, 105, 122, 97, 116, 105, 111, 110, 32, 105,
  115, 32, 100, 111, 110, 101, 32, 111, 110, 108, 121, 32, 102, 111, 114, 32,
  112, 105, 120, 101, 108, 115, 32, 105, 110, 32, 116, 104, 101, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 118, 97, 108, 117, 101, 32, 114, 97, 110, 103, 101, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 110, 98, 95, 108, 101, 118, 101, 108,
  115, 61, 50, 53, 54, 39, 44, 32, 39, 118, 97, 108, 117, 101, 95, 109,
  105, 110, 61, 48, 37, 39, 32, 97, 110, 100, 32, 39, 118, 97, 108, 117,
  101, 95, 109, 97, 120, 61, 49, 48, 48, 37, 39, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 45, 101, 113, 117, 97, 108, 105, 122, 101, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 45, 101, 113, 117, 97, 108, 105, 122, 101, 32, 52, 44, 48,
  44, 49, 50, 56, 10, 35, 64, 103, 109, 105, 99, 32, 102, 32, 58, 32,
  101, 113, 46, 32, 116, 111, 32, 39, 45, 102, 105, 108, 108, 39, 46, 32,
  58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 102, 105, 108,
  108, 32, 58, 32, 118, 97, 108, 117, 101, 49, 44, 95, 118, 97, 108, 117,
  101, 50, 44, 46, 46, 32, 58, 32, 91, 105, 109, 97, 103, 101, 93, 32,
  58, 32, 39, 102, 111, 114, 109, 117, 108, 97, 39, 32, 58, 32, 40, 43,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 70, 105, 108, 108, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32,
  119, 105, 116, 104, 32, 118, 97, 108, 117, 101, 115, 32, 114, 101, 97, 100,
  32, 102, 114, 111, 109, 32, 116, 104, 101, 32, 115, 112, 101, 99, 105, 102,
  105, 101, 100, 32, 118, 97, 108, 117, 101, 32, 108, 105, 115, 116, 44, 32,
  101, 120, 105, 115, 116, 105, 110, 103, 32, 105, 109, 97, 103, 101, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 111, 114, 32, 109, 97, 116, 104, 101,
  109, 97, 116, 105, 99, 97, 108, 32, 101, 120, 112, 114, 101, 115, 115, 105,
  111, 110, 46, 32, 83, 105, 110, 103, 108, 101, 32, 113, 117, 111, 116, 101,
  115, 32, 109, 97, 121, 32, 98, 101, 32, 111, 109, 105, 116, 116, 101, 100,
  32, 105, 110, 32, 39, 102, 111, 114, 109, 117, 108, 97, 39, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32,
  39, 45, 102, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 52, 44, 52, 32, 45, 102, 105, 108, 108, 32, 49, 44, 50, 44,
  51, 44, 52, 44, 53, 44, 54, 44, 55, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 52, 44, 52, 32, 40, 49, 44, 50, 44, 51, 44,
  52, 44, 53, 44, 54, 44, 55, 41, 32, 45, 102, 105, 108, 108, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 52, 48, 48, 44, 52, 48, 48, 44, 49, 44, 51, 32, 45,
  102, 105, 108, 108, 32, 34, 88, 61, 120, 45, 119, 47, 50, 59, 32, 89,
  61, 121, 45, 104, 47, 50, 59, 32, 82, 61, 115, 113, 114, 116, 40, 88,
  94, 50, 43, 89, 94, 50, 41, 59, 32, 97, 61, 97, 116, 97, 110, 50,
  40, 89, 44, 88, 41, 59, 32, 105, 102, 32, 40, 82, 60, 61, 49, 56,
  48, 44, 50, 53, 53, 42, 97, 98, 115, 40, 99, 111, 115, 40, 99, 43,
  50, 48, 48, 42, 40, 120, 47, 119, 45, 48, 46, 53, 41, 42, 40, 121,
  47, 104, 45, 48, 46, 53, 41, 41, 41, 44, 56, 53, 48, 42, 40, 97,
  37, 40, 48, 46, 49, 42, 40, 99, 43, 49, 41, 41, 41, 41, 34, 10,
  35, 64, 103, 109, 105, 99, 32, 102, 108, 111, 97, 116, 50, 105, 110, 116,
  56, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101,
  114, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 102, 108, 111, 97,
  116, 45, 118, 97, 108, 117, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32,
  116, 111, 32, 56, 98, 105, 116, 115, 32, 105, 110, 116, 101, 103, 101, 114,
  32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 97, 116, 105, 111, 110, 115,
  46, 10, 102, 108, 111, 97, 116, 50, 105, 110, 116, 56, 32, 58, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32,
  102, 108, 111, 97, 116, 45, 118, 97, 108, 117, 101, 100, 32, 105, 109, 97,
  103, 101, 36, 63, 32, 116, 111, 32, 56, 98, 105, 116, 115, 32, 105, 110,
  116, 101, 103, 101, 114, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 97,
  116, 105, 111, 110, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45,
  115, 32, 99, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 109, 61, 123, 105, 109, 125, 32, 77, 61, 123,
  105, 77, 125, 32, 45, 113, 117, 97, 110, 116, 105, 122, 101, 32, 49, 54,
  55, 55, 55, 50, 49, 54, 44, 48, 44, 49, 10, 45, 45, 62, 62, 32,
  56, 32, 45, 97, 110, 100, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45,
  45, 97, 110, 100, 91, 45, 50, 93, 32, 50, 53, 53, 32, 45, 62, 62,
  91, 45, 51, 93, 32, 49, 54, 10, 40, 123, 39, 36, 109, 44, 36, 77,
  39, 125, 41, 32, 45, 97, 32, 121, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 105, 110, 116, 56, 50, 102, 108, 111, 97, 116, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 56, 98, 105, 116, 115, 32, 105, 110, 116,
  101, 103, 101, 114, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 97, 116,
  105, 111, 110, 115, 32, 116, 111, 32, 102, 108, 111, 97, 116, 45, 118, 97,
  108, 117, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 105, 110, 116,
  56, 50, 102, 108, 111, 97, 116, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 56, 98, 105, 116, 115,
  32, 105, 110, 116, 101, 103, 101, 114, 32, 114, 101, 112, 114, 101, 115, 101,
  110, 116, 97, 116, 105, 111, 110, 36, 63, 32, 116, 111, 32, 102, 108, 111,
  97, 116, 45, 118, 97, 108, 117, 101, 100, 32, 105, 109, 97, 103, 101, 36,
  63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 32, 99, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 115, 104, 91, 45, 49, 93, 32, 123, 104, 45, 49, 125, 44,
  123, 104, 45, 49, 125, 44, 48, 44, 48, 32, 109, 61, 64, 123, 45, 49,
  44, 116, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 114, 111, 119,
  115, 32, 48, 44, 123, 104, 45, 50, 125, 32, 45, 115, 32, 121, 44, 51,
  32, 45, 42, 91, 45, 51, 93, 32, 54, 53, 53, 51, 54, 32, 45, 42,
  91, 45, 50, 93, 32, 50, 53, 54, 32, 45, 111, 114, 32, 45, 110, 32,
  36, 109, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 105, 110, 100, 101,
  120, 32, 58, 32, 123, 32, 91, 112, 97, 108, 101, 116, 116, 101, 93, 32,
  124, 32, 112, 114, 101, 100, 101, 102, 105, 110, 101, 100, 95, 112, 97, 108,
  101, 116, 116, 101, 32, 125, 44, 48, 60, 61, 95, 100, 105, 116, 104, 101,
  114, 105, 110, 103, 60, 61, 49, 44, 95, 109, 97, 112, 95, 112, 97, 108,
  101, 116, 116, 101, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 32, 58,
  32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 110,
  100, 101, 120, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 118, 101, 99,
  116, 111, 114, 45, 118, 97, 108, 117, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 32, 98, 121, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 118,
  101, 99, 116, 111, 114, 45, 118, 97, 108, 117, 101, 100, 32, 112, 97, 108,
  101, 116, 116, 101, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39,
  112, 114, 101, 100, 101, 102, 105, 110, 101, 100, 95, 112, 97, 108, 101, 116,
  116, 101, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 100,
  101, 102, 97, 117, 108, 116, 32, 124, 32, 49, 61, 72, 83, 86, 32, 124,
  32, 50, 61, 108, 105, 110, 101, 115, 32, 124, 32, 51, 61, 104, 111, 116,
  32, 124, 32, 52, 61, 99, 111, 111, 108, 32, 124, 32, 53, 61, 106, 101,
  116, 32, 124, 32, 54, 61, 102, 108, 97, 103, 32, 124, 32, 55, 61, 99,
  117, 98, 101, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 100, 105, 116, 104, 101, 114, 105, 110, 103, 61, 48, 39, 32, 97, 110,
  100, 32, 39, 109, 97, 112, 95, 112, 97, 108, 101, 116, 116, 101, 61, 48,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 105, 110, 100, 101, 120, 32,
  49, 44, 49, 44, 49, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 40, 48, 59, 50, 53,
  53, 59, 50, 53, 53, 94, 48, 59, 49, 50, 56, 59, 50, 53, 53, 94,
  48, 59, 48, 59, 50, 53, 53, 41, 32, 45, 45, 105, 110, 100, 101, 120,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 49, 10, 35, 64,
  103, 109, 105, 99, 32, 105, 109, 97, 103, 101, 95, 105, 110, 116, 101, 103,
  114, 97, 108, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109,
  112, 117, 116, 101, 32, 116, 104, 101, 32, 105, 109, 97, 103, 101, 32, 105,
  110, 116, 101, 103, 114, 97, 108, 32, 40, 115, 117, 109, 109, 101, 100, 32,
  97, 114, 101, 97, 32, 116, 97, 98, 108, 101, 41, 32, 111, 102, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 45, 105, 109, 97, 103, 101, 95, 105, 110, 116,
  101, 103, 114, 97, 108, 10, 105, 109, 97, 103, 101, 95, 105, 110, 116, 101,
  103, 114, 97, 108, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 105, 109, 97, 103,
  101, 32, 105, 110, 116, 101, 103, 114, 97, 108, 32, 111, 102, 32, 105, 109,
  97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 102, 32,
  39, 62, 105, 43, 105, 40, 120, 45, 49, 44, 121, 41, 39, 32, 45, 102,
  32, 39, 62, 105, 43, 105, 40, 120, 44, 121, 45, 49, 41, 39, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 109, 97, 112, 32, 58,
  32, 91, 112, 97, 108, 101, 116, 116, 101, 93, 32, 58, 32, 112, 114, 101,
  100, 101, 102, 105, 110, 101, 100, 95, 112, 97, 108, 101, 116, 116, 101, 32,
  58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 77,
  97, 112, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 118, 101, 99,
  116, 111, 114, 45, 118, 97, 108, 117, 101, 100, 32, 112, 97, 108, 101, 116,
  116, 101, 32, 116, 111, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  110, 100, 101, 120, 101, 100, 32, 115, 99, 97, 108, 97, 114, 32, 105, 109,
  97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39,
  112, 114, 101, 100, 101, 102, 105, 110, 101, 100, 95, 112, 97, 108, 101, 116,
  116, 101, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 100,
  101, 102, 97, 117, 108, 116, 32, 124, 32, 49, 61, 72, 83, 86, 32, 124,
  32, 50, 61, 108, 105, 110, 101, 115, 32, 124, 32, 51, 61, 104, 111, 116,
  32, 124, 32, 52, 61, 99, 111, 111, 108, 32, 124, 32, 53, 61, 106, 101,
  116, 32, 124, 32, 54, 61, 102, 108, 97, 103, 32, 124, 32, 55, 61, 99,
  117, 98, 101, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 108, 117,
  109, 105, 110, 97, 110, 99, 101, 32, 45, 109, 97, 112, 91, 45, 49, 93,
  32, 51, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 114, 103, 98, 50, 121, 99,
  98, 99, 114, 32, 45, 115, 112, 108, 105, 116, 91, 45, 49, 93, 32, 99,
  32, 40, 48, 44, 50, 53, 53, 44, 48, 41, 32, 45, 114, 101, 115, 105,
  122, 101, 91, 45, 49, 93, 32, 50, 53, 54, 44, 49, 44, 49, 44, 49,
  44, 51, 32, 45, 109, 97, 112, 91, 45, 52, 93, 32, 91, 45, 49, 93,
  32, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 93, 32, 45, 97, 112,
  112, 101, 110, 100, 91, 45, 51, 45, 45, 49, 93, 32, 99, 32, 45, 121,
  99, 98, 99, 114, 50, 114, 103, 98, 91, 45, 49, 93, 10, 35, 64, 103,
  109, 105, 99, 32, 109, 97, 112, 95, 99, 108, 117, 116, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 77, 97, 112, 32, 82, 71, 66, 32, 99, 111,
  108, 111, 114, 32, 76, 85, 84, 32, 105, 109, 97, 103, 101, 32, 40, 114,
  101, 103, 97, 114, 100, 101, 100, 32, 97, 115, 32, 116, 104, 101, 32, 108,
  97, 115, 116, 32, 105, 109, 97, 103, 101, 41, 32, 116, 111, 32, 97, 108,
  108, 32, 111, 116, 104, 101, 114, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 117,
  110, 105, 102, 111, 114, 109, 95, 100, 105, 115, 116, 114, 105, 98, 117, 116,
  105, 111, 110, 32, 123, 50, 94, 53, 125, 44, 51, 32, 45, 109, 105, 114,
  114, 111, 114, 91, 45, 49, 93, 32, 120, 32, 45, 45, 109, 97, 112, 95,
  99, 108, 117, 116, 10, 109, 97, 112, 95, 99, 108, 117, 116, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 77, 97, 112, 32, 99, 111, 108,
  111, 114, 32, 76, 85, 84, 32, 105, 109, 97, 103, 101, 44, 32, 117, 115,
  105, 110, 103, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 105,
  102, 32, 123, 64, 35, 60, 50, 125, 32, 45, 114, 101, 116, 117, 114, 110,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 32, 45, 116, 111,
  95, 99, 111, 108, 111, 114, 91, 48, 45, 45, 50, 93, 32, 45, 116, 111,
  95, 114, 103, 98, 91, 45, 49, 93, 10, 108, 61, 123, 114, 111, 117, 110,
  100, 40, 40, 119, 42, 104, 42, 100, 41, 94, 40, 49, 47, 51, 41, 41,
  125, 32, 45, 114, 91, 45, 49, 93, 32, 36, 108, 44, 36, 108, 44, 36,
  108, 44, 51, 44, 45, 49, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  64, 35, 45, 49, 125, 32, 45, 108, 91, 36, 62, 44, 45, 49, 93, 32,
  45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 91, 48,
  93, 32, 45, 47, 91, 48, 93, 32, 123, 50, 53, 54, 47, 36, 108, 125,
  10, 45, 45, 119, 97, 114, 112, 91, 45, 49, 93, 32, 91, 48, 93, 44,
  48, 44, 49, 44, 49, 10, 45, 114, 109, 91, 48, 93, 32, 45, 109, 118,
  91, 45, 49, 93, 32, 48, 32, 45, 97, 91, 94, 45, 49, 93, 32, 99,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 109, 105, 120, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 58, 32,
  40, 97, 48, 48, 44, 46, 46, 46, 44, 97, 77, 78, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 115, 112, 101,
  99, 105, 102, 105, 101, 100, 32, 109, 97, 116, 114, 105, 120, 32, 116, 111,
  32, 99, 104, 97, 110, 110, 101, 108, 115, 32, 111, 102, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 45, 109, 105, 120, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 40, 48, 44, 49, 44, 48, 59, 49, 44, 48, 44, 48, 59, 48,
  44, 48, 44, 49, 41, 10, 109, 105, 120, 95, 99, 104, 97, 110, 110, 101,
  108, 115, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112,
  112, 108, 121, 32, 109, 97, 116, 114, 105, 120, 32, 36, 49, 32, 116, 111,
  32, 99, 104, 97, 110, 110, 101, 108, 115, 32, 111, 102, 32, 105, 109, 97,
  103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109,
  61, 64, 123, 48, 44, 110, 125, 10, 119, 104, 100, 61, 123, 119, 125, 44,
  123, 104, 125, 44, 123, 100, 125, 32, 45, 114, 32, 123, 119, 42, 104, 42,
  100, 125, 44, 123, 115, 125, 44, 49, 44, 49, 44, 45, 49, 32, 45, 105,
  91, 48, 93, 32, 36, 123, 94, 48, 125, 32, 45, 42, 42, 32, 45, 114,
  32, 36, 119, 104, 100, 44, 123, 104, 125, 44, 45, 49, 10, 45, 110, 109,
  32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 110,
  101, 103, 97, 116, 105, 118, 101, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 67, 111, 109, 112, 117, 116, 101, 32, 110, 101, 103, 97, 116, 105, 118,
  101, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 110, 101, 103,
  97, 116, 105, 118, 101, 10, 110, 101, 103, 97, 116, 105, 118, 101, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116,
  101, 32, 110, 101, 103, 97, 116, 105, 118, 101, 32, 111, 102, 32, 105, 109,
  97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45,
  45, 32, 123, 105, 77, 125, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 42, 32, 45, 49, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 110, 111, 105, 115, 101, 32, 58, 32, 115, 116, 100,
  95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 62, 61, 48, 91, 37, 93,
  44, 95, 110, 111, 105, 115, 101, 95, 116, 121, 112, 101, 32, 58, 32, 40,
  43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 100, 100, 32,
  114, 97, 110, 100, 111, 109, 32, 110, 111, 105, 115, 101, 32, 116, 111, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 110, 111, 105, 115, 101,
  95, 116, 121, 112, 101, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32,
  48, 61, 103, 97, 117, 115, 115, 105, 97, 110, 32, 124, 32, 49, 61, 117,
  110, 105, 102, 111, 114, 109, 32, 124, 32, 50, 61, 115, 97, 108, 116, 38,
  112, 101, 112, 112, 101, 114, 32, 124, 32, 51, 61, 112, 111, 105, 115, 115,
  111, 110, 32, 124, 32, 52, 61, 114, 105, 99, 101, 32, 125, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32,
  118, 97, 108, 117, 101, 58, 32, 39, 110, 111, 105, 115, 101, 95, 116, 121,
  112, 101, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 110, 111,
  105, 115, 101, 91, 48, 93, 32, 53, 48, 44, 48, 32, 45, 45, 110, 111,
  105, 115, 101, 91, 48, 93, 32, 53, 48, 44, 49, 32, 45, 45, 110, 111,
  105, 115, 101, 91, 48, 93, 32, 49, 48, 44, 50, 32, 45, 99, 117, 116,
  32, 48, 44, 50, 53, 53, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 51, 48, 48, 44, 51, 48, 48, 44, 49, 44, 51, 32, 91, 48,
  93, 32, 45, 110, 111, 105, 115, 101, 91, 48, 93, 32, 50, 48, 44, 48,
  32, 45, 110, 111, 105, 115, 101, 91, 49, 93, 32, 50, 48, 44, 49, 32,
  45, 45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 49, 48, 48, 32,
  45, 100, 105, 115, 112, 108, 97, 121, 95, 103, 114, 97, 112, 104, 91, 45,
  50, 44, 45, 49, 93, 32, 52, 48, 48, 44, 51, 48, 48, 44, 51, 10,
  35, 64, 103, 109, 105, 99, 32, 110, 111, 114, 109, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101,
  32, 112, 111, 105, 110, 116, 119, 105, 115, 101, 32, 101, 117, 99, 108, 105,
  100, 101, 97, 110, 32, 110, 111, 114, 109, 32, 111, 102, 32, 118, 101, 99,
  116, 111, 114, 45, 118, 97, 108, 117, 101, 100, 32, 112, 105, 120, 101, 108,
  115, 32, 105, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 110, 111, 114,
  109, 10, 110, 111, 114, 109, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 112, 111, 105, 110, 116, 119,
  105, 115, 101, 32, 101, 117, 99, 108, 105, 100, 101, 97, 110, 32, 110, 111,
  114, 109, 32, 111, 102, 32, 118, 101, 99, 116, 111, 114, 115, 44, 32, 105,
  110, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 115, 113, 114, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 43, 32, 45, 115, 113, 114, 116, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 110, 32, 58, 32,
  101, 113, 46, 32, 116, 111, 32, 39, 45, 110, 111, 114, 109, 97, 108, 105,
  122, 101, 39, 46, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 110, 111, 114, 109, 97, 108, 105, 122, 101, 32, 58, 32, 123, 32,
  118, 97, 108, 117, 101, 48, 91, 37, 93, 32, 124, 32, 91, 105, 109, 97,
  103, 101, 48, 93, 32, 125, 44, 123, 32, 118, 97, 108, 117, 101, 49, 91,
  37, 93, 32, 124, 32, 91, 105, 109, 97, 103, 101, 49, 93, 32, 125, 32,
  58, 32, 91, 105, 109, 97, 103, 101, 93, 32, 58, 32, 40, 43, 41, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 76, 105, 110, 101, 97, 114, 108,
  121, 32, 110, 111, 114, 109, 97, 108, 105, 122, 101, 32, 118, 97, 108, 117,
  101, 115, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 32, 105, 110, 32, 115, 112, 101, 99, 105, 102, 105,
  101, 100, 32, 114, 97, 110, 103, 101, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 110, 39, 41,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 115, 112, 108, 105, 116, 32, 120, 44,
  50, 32, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 91, 45, 49, 93,
  32, 54, 52, 44, 49, 57, 54, 32, 45, 97, 112, 112, 101, 110, 100, 32,
  120, 10, 35, 64, 103, 109, 105, 99, 32, 110, 111, 114, 109, 97, 108, 105,
  122, 101, 95, 115, 117, 109, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  78, 111, 114, 109, 97, 108, 105, 122, 101, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 119, 105, 116, 104, 32, 97,
  32, 117, 110, 105, 116, 97, 114, 121, 32, 115, 117, 109, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45,
  49, 93, 32, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 115, 117,
  109, 91, 45, 49, 93, 32, 45, 100, 105, 115, 112, 108, 97, 121, 95, 103,
  114, 97, 112, 104, 91, 45, 49, 93, 32, 52, 48, 48, 44, 51, 48, 48,
  10, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 115, 117, 109, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 78, 111, 114, 109, 97, 108,
  105, 122, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 119, 105, 116, 104,
  32, 97, 32, 117, 110, 105, 116, 97, 114, 121, 32, 115, 117, 109, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 115, 117, 109, 61, 64, 123, 36, 62, 44, 43, 125, 32, 45, 105, 102,
  32, 123, 36, 115, 117, 109, 33, 61, 48, 125, 32, 45, 47, 91, 36, 62,
  93, 32, 36, 115, 117, 109, 32, 45, 101, 110, 100, 105, 102, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101,
  32, 112, 111, 105, 110, 116, 119, 105, 115, 101, 32, 111, 114, 105, 101, 110,
  116, 97, 116, 105, 111, 110, 32, 111, 102, 32, 118, 101, 99, 116, 111, 114,
  45, 118, 97, 108, 117, 101, 100, 32, 112, 105, 120, 101, 108, 115, 32, 105,
  110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 111, 114, 105, 101, 110, 116,
  97, 116, 105, 111, 110, 32, 45, 45, 110, 111, 114, 109, 91, 45, 50, 93,
  32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32, 45,
  109, 117, 108, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 101,
  118, 101, 114, 115, 101, 91, 45, 50, 44, 45, 49, 93, 10, 111, 114, 105,
  101, 110, 116, 97, 116, 105, 111, 110, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 112, 111, 105, 110,
  116, 119, 105, 115, 101, 32, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111,
  110, 32, 118, 101, 99, 116, 111, 114, 115, 44, 32, 105, 110, 32, 105, 109,
  97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 45, 110, 111, 114, 109, 91, 36,
  62, 93, 32, 45, 114, 101, 112, 108, 97, 99, 101, 91, 45, 49, 93, 32,
  48, 44, 49, 32, 45, 47, 91, 36, 62, 44, 45, 49, 93, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  111, 116, 115, 117, 32, 58, 32, 95, 110, 98, 95, 108, 101, 118, 101, 108,
  115, 62, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 72, 97, 114,
  100, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 117, 115, 105, 110,
  103, 32, 79, 116, 115, 117, 39, 115, 32, 109, 101, 116, 104, 111, 100, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 84, 104, 101, 32, 99, 111,
  109, 112, 117, 116, 101, 100, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100,
  115, 32, 97, 114, 101, 32, 114, 101, 116, 117, 114, 110, 101, 100, 32, 97,
  115, 32, 97, 32, 108, 105, 115, 116, 32, 111, 102, 32, 118, 97, 108, 117,
  101, 115, 32, 105, 110, 32, 116, 104, 101, 32, 115, 116, 97, 116, 117, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117,
  108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 110, 98, 95, 108, 101,
  118, 101, 108, 115, 61, 50, 53, 54, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 45, 111, 116, 115,
  117, 32, 44, 10, 111, 116, 115, 117, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 50, 53, 54,
  125, 41, 32, 38, 38, 32, 36, 49, 62, 48, 34, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 72, 97, 114, 100, 45, 116, 104, 114, 101, 115, 104,
  111, 108, 100, 32, 105, 109, 97, 103, 101, 36, 63, 32, 117, 115, 105, 110,
  103, 32, 79, 116, 115, 117, 39, 115, 32, 109, 101, 116, 104, 111, 100, 44,
  32, 119, 105, 116, 104, 32, 36, 49, 32, 104, 105, 115, 116, 111, 103, 114,
  97, 109, 32, 108, 101, 118, 101, 108, 115, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 105, 109, 61, 123, 105, 109, 125, 32, 105, 77, 61, 123, 105,
  77, 125, 32, 45, 110, 32, 48, 44, 123, 36, 49, 45, 49, 125, 10, 45,
  45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 36, 49, 32, 116, 111,
  116, 97, 108, 61, 64, 123, 45, 49, 44, 43, 125, 10, 45, 45, 42, 91,
  45, 49, 93, 32, 39, 120, 39, 32, 115, 117, 109, 61, 64, 123, 45, 49,
  44, 43, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 115, 117, 109, 66,
  61, 48, 32, 119, 66, 61, 48, 32, 119, 70, 61, 48, 32, 118, 97, 114,
  77, 97, 120, 61, 48, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 61,
  48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 10, 119, 66, 61,
  123, 36, 119, 66, 43, 64, 123, 45, 49, 44, 36, 62, 125, 125, 10, 45,
  105, 102, 32, 123, 36, 119, 66, 61, 61, 48, 125, 32, 45, 99, 111, 110,
  116, 105, 110, 117, 101, 32, 45, 101, 110, 100, 105, 102, 10, 119, 70, 61,
  123, 36, 116, 111, 116, 97, 108, 45, 36, 119, 66, 125, 10, 45, 105, 102,
  32, 123, 36, 119, 70, 61, 61, 48, 125, 32, 45, 98, 114, 101, 97, 107,
  32, 45, 101, 110, 100, 105, 102, 10, 115, 117, 109, 66, 61, 123, 36, 115,
  117, 109, 66, 43, 36, 62, 42, 64, 123, 45, 49, 44, 36, 62, 125, 125,
  10, 109, 66, 61, 123, 36, 115, 117, 109, 66, 47, 36, 119, 66, 125, 10,
  109, 70, 61, 123, 40, 36, 115, 117, 109, 45, 36, 115, 117, 109, 66, 41,
  47, 36, 119, 70, 125, 10, 118, 97, 114, 66, 101, 116, 119, 101, 101, 110,
  61, 123, 36, 119, 66, 42, 36, 119, 70, 42, 40, 36, 109, 66, 45, 36,
  109, 70, 41, 94, 50, 125, 10, 45, 105, 102, 32, 123, 36, 118, 97, 114,
  66, 101, 116, 119, 101, 101, 110, 62, 36, 118, 97, 114, 77, 97, 120, 125,
  32, 118, 97, 114, 77, 97, 120, 61, 36, 118, 97, 114, 66, 101, 116, 119,
  101, 101, 110, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 61, 36, 62,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 103, 101, 91, 45, 49, 93, 32, 36, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 10, 116, 104, 114, 101, 115, 104, 111,
  108, 100, 61, 123, 36, 105, 109, 43, 36, 116, 104, 114, 101, 115, 104, 111,
  108, 100, 42, 40, 36, 105, 77, 45, 36, 105, 109, 41, 47, 40, 36, 49,
  45, 49, 41, 125, 10, 45, 105, 102, 32, 36, 62, 32, 45, 117, 32, 64,
  123, 125, 44, 36, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 45, 101,
  108, 115, 101, 32, 45, 117, 32, 36, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 112, 111, 108, 97, 114, 50, 99, 111, 109, 112, 108, 101, 120, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32,
  112, 111, 108, 97, 114, 32, 116, 111, 32, 99, 111, 109, 112, 108, 101, 120,
  32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 115, 32, 111, 102, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  112, 111, 108, 97, 114, 50, 99, 111, 109, 112, 108, 101, 120, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101,
  32, 112, 111, 108, 97, 114, 32, 116, 111, 32, 99, 111, 109, 112, 108, 101,
  120, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 115, 32, 111, 102, 32,
  105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50,
  41, 125, 32, 45, 108, 91, 123, 50, 42, 36, 62, 125, 44, 123, 50, 42,
  36, 62, 43, 49, 125, 93, 10, 45, 114, 91, 49, 93, 32, 91, 48, 93,
  44, 51, 32, 45, 45, 115, 105, 110, 91, 45, 49, 93, 32, 45, 99, 111,
  115, 91, 45, 50, 93, 32, 45, 42, 91, 45, 49, 93, 32, 91, 45, 51,
  93, 32, 45, 42, 91, 45, 51, 44, 45, 50, 93, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 113, 117, 97, 110, 116, 105, 122, 101, 32, 58, 32, 110,
  98, 95, 108, 101, 118, 101, 108, 115, 62, 61, 49, 44, 95, 107, 101, 101,
  112, 95, 118, 97, 108, 117, 101, 115, 61, 123, 32, 48, 32, 124, 32, 49,
  32, 125, 44, 95, 105, 115, 95, 117, 110, 105, 102, 111, 114, 109, 61, 123,
  32, 48, 32, 124, 32, 49, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 81, 117, 97, 110, 116, 105, 122, 101, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108,
  117, 101, 58, 32, 39, 107, 101, 101, 112, 95, 118, 97, 108, 117, 101, 115,
  61, 49, 39, 32, 97, 110, 100, 32, 39, 105, 115, 95, 117, 110, 105, 102,
  111, 114, 109, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 108, 117,
  109, 105, 110, 97, 110, 99, 101, 32, 45, 45, 113, 117, 97, 110, 116, 105,
  122, 101, 32, 51, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  50, 48, 48, 44, 50, 48, 48, 44, 49, 44, 49, 44, 39, 99, 111, 115,
  40, 120, 47, 49, 48, 41, 42, 115, 105, 110, 40, 121, 47, 49, 48, 41,
  39, 32, 45, 45, 113, 117, 97, 110, 116, 105, 122, 101, 91, 48, 93, 32,
  54, 32, 45, 45, 113, 117, 97, 110, 116, 105, 122, 101, 91, 48, 93, 32,
  52, 32, 45, 45, 113, 117, 97, 110, 116, 105, 122, 101, 91, 48, 93, 32,
  51, 32, 45, 45, 113, 117, 97, 110, 116, 105, 122, 101, 91, 48, 93, 32,
  50, 10, 113, 117, 97, 110, 116, 105, 122, 101, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 49, 41, 32, 38,
  38, 32, 36, 49, 62, 61, 49, 34, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 50, 61, 49, 125, 44, 36, 123, 51, 61, 48, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 81, 117, 97, 110, 116, 105, 122, 101, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 117, 115, 105, 110, 103, 32, 36, 49, 32,
  108, 101, 118, 101, 108, 115, 44, 32, 34, 64, 123, 45, 97, 114, 103, 92,
  32, 49, 43, 33, 36, 50, 44, 119, 105, 116, 104, 44, 119, 105, 116, 104,
  111, 117, 116, 125, 34, 32, 107, 101, 101, 112, 105, 110, 103, 32, 118, 97,
  108, 117, 101, 32, 114, 97, 110, 103, 101, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 45, 105, 102, 32, 36, 51, 10, 45, 105, 102, 32, 123, 115,
  61, 61, 49, 125, 10, 45, 105, 102, 32, 36, 50, 32, 109, 77, 61, 123,
  105, 109, 125, 44, 123, 105, 77, 125, 32, 45, 110, 32, 48, 44, 36, 49,
  32, 45, 114, 111, 117, 110, 100, 32, 49, 44, 45, 49, 32, 45, 109, 105,
  110, 32, 123, 36, 49, 45, 49, 125, 32, 45, 110, 32, 36, 109, 77, 10,
  45, 101, 108, 115, 101, 32, 45, 110, 32, 48, 44, 36, 49, 32, 45, 114,
  111, 117, 110, 100, 32, 49, 44, 45, 49, 32, 45, 109, 105, 110, 32, 123,
  36, 49, 45, 49, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108,
  115, 101, 32, 109, 77, 61, 123, 105, 109, 125, 44, 123, 105, 77, 125, 32,
  45, 117, 110, 105, 102, 111, 114, 109, 95, 100, 105, 115, 116, 114, 105, 98,
  117, 116, 105, 111, 110, 32, 36, 49, 44, 123, 115, 125, 32, 45, 110, 91,
  45, 49, 93, 32, 36, 109, 77, 32, 45, 105, 110, 100, 101, 120, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 36, 50, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115,
  101, 32, 45, 45, 99, 111, 108, 111, 114, 109, 97, 112, 32, 36, 49, 44,
  48, 32, 45, 105, 110, 100, 101, 120, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 48, 44, 36, 50, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 114, 97,
  110, 100, 32, 58, 32, 123, 32, 118, 97, 108, 117, 101, 48, 91, 37, 93,
  32, 124, 32, 91, 105, 109, 97, 103, 101, 48, 93, 32, 125, 44, 123, 32,
  118, 97, 108, 117, 101, 49, 91, 37, 93, 32, 124, 32, 91, 105, 109, 97,
  103, 101, 49, 93, 32, 125, 32, 58, 32, 91, 105, 109, 97, 103, 101, 93,
  32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  70, 105, 108, 108, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 32, 119, 105, 116, 104, 32, 114, 97, 110, 100, 111, 109,
  32, 118, 97, 108, 117, 101, 115, 32, 117, 110, 105, 102, 111, 114, 109, 108,
  121, 32, 100, 105, 115, 116, 114, 105, 98, 117, 116, 101, 100, 32, 105, 110,
  32, 116, 104, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 114,
  97, 110, 103, 101, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 52, 48, 48, 44, 52, 48, 48, 44, 49, 44, 51, 32, 45, 114, 97,
  110, 100, 32, 45, 49, 48, 44, 49, 48, 32, 45, 45, 98, 108, 117, 114,
  32, 49, 48, 32, 45, 115, 105, 103, 110, 91, 45, 49, 93, 10, 35, 64,
  103, 109, 105, 99, 32, 114, 101, 112, 108, 97, 99, 101, 32, 58, 32, 118,
  97, 108, 117, 101, 95, 115, 114, 99, 44, 118, 97, 108, 117, 101, 95, 100,
  101, 115, 116, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 112,
  108, 97, 99, 101, 32, 112, 105, 120, 101, 108, 32, 118, 97, 108, 117, 101,
  115, 32, 105, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 40, 49, 59, 50, 59, 51, 59, 52, 41, 32, 45, 45, 114, 101, 112,
  108, 97, 99, 101, 32, 50, 44, 51, 10, 114, 101, 112, 108, 97, 99, 101,
  32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 112, 108,
  97, 99, 101, 32, 112, 105, 120, 101, 108, 32, 118, 97, 108, 117, 101, 115,
  32, 36, 49, 32, 119, 105, 116, 104, 32, 36, 50, 32, 105, 110, 32, 105,
  109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32,
  45, 45, 61, 61, 32, 36, 49, 32, 45, 42, 91, 45, 49, 93, 32, 123,
  36, 50, 45, 36, 49, 125, 32, 45, 43, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 114, 101, 112, 108, 97, 99, 101, 95, 105, 110, 102, 32, 58, 32,
  95, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 82, 101, 112, 108, 97, 99, 101, 32, 97, 108, 108,
  32, 105, 110, 102, 105, 110, 105, 116, 101, 32, 118, 97, 108, 117, 101, 115,
  32, 105, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 32, 98, 121, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100,
  32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 40, 48, 59, 49, 59, 50, 41, 32,
  45, 108, 111, 103, 32, 45, 45, 114, 101, 112, 108, 97, 99, 101, 95, 105,
  110, 102, 32, 50, 10, 114, 101, 112, 108, 97, 99, 101, 95, 105, 110, 102,
  32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 112, 108,
  97, 99, 101, 32, 97, 108, 108, 32, 105, 110, 102, 105, 110, 105, 116, 101,
  32, 118, 97, 108, 117, 101, 115, 32, 105, 110, 32, 105, 109, 97, 103, 101,
  36, 63, 32, 98, 121, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110,
  32, 39, 36, 49, 39, 46, 34, 10, 45, 118, 32, 45, 32, 45, 102, 32,
  34, 105, 102, 40, 105, 61, 61, 105, 43, 49, 44, 36, 49, 44, 105, 41,
  34, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 114, 101,
  112, 108, 97, 99, 101, 95, 110, 97, 110, 32, 58, 32, 95, 101, 120, 112,
  114, 101, 115, 115, 105, 111, 110, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 82, 101, 112, 108, 97, 99, 101, 32, 97, 108, 108, 32, 78, 97, 78,
  32, 118, 97, 108, 117, 101, 115, 32, 105, 110, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 98, 121, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 101, 120, 112, 114, 101, 115, 115, 105,
  111, 110, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 40,
  45, 49, 59, 48, 59, 50, 41, 32, 45, 115, 113, 114, 116, 32, 45, 45,
  114, 101, 112, 108, 97, 99, 101, 95, 110, 97, 110, 32, 50, 10, 114, 101,
  112, 108, 97, 99, 101, 95, 110, 97, 110, 32, 58, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 82, 101, 112, 108, 97, 99, 101, 32, 97, 108, 108,
  32, 78, 97, 78, 32, 118, 97, 108, 117, 101, 115, 32, 105, 110, 32, 105,
  109, 97, 103, 101, 115, 36, 63, 32, 98, 121, 32, 101, 120, 112, 114, 101,
  115, 115, 105, 111, 110, 32, 39, 36, 49, 39, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 102, 32, 34, 105, 102, 40, 105, 62, 61, 48, 32, 124, 124,
  32, 105, 60, 61, 48, 44, 105, 44, 36, 49, 41, 34, 32, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 114, 101, 112, 108, 97, 99, 101,
  95, 115, 101, 113, 32, 58, 32, 34, 115, 101, 97, 114, 99, 104, 95, 115,
  101, 113, 34, 44, 34, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113,
  34, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 101, 97, 114, 99,
  104, 32, 97, 110, 100, 32, 114, 101, 112, 108, 97, 99, 101, 32, 97, 32,
  115, 101, 113, 117, 101, 110, 99, 101, 32, 111, 102, 32, 118, 97, 108, 117,
  101, 115, 32, 105, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 40, 49, 59, 50, 59, 51, 59, 52, 59, 53, 41, 32, 45, 45,
  114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 34, 50, 44, 51,
  44, 52, 34, 44, 34, 55, 44, 56, 34, 10, 114, 101, 112, 108, 97, 99,
  101, 95, 115, 101, 113, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 82, 101, 112, 108, 97, 99, 101, 32, 118, 97, 108, 117, 101, 32, 115,
  101, 113, 117, 101, 110, 99, 101, 32, 39, 36, 49, 39, 32, 98, 121, 32,
  118, 97, 108, 117, 101, 32, 115, 101, 113, 117, 101, 110, 99, 101, 32, 39,
  36, 50, 39, 32, 105, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34,
  10, 45, 118, 32, 45, 32, 40, 36, 49, 41, 32, 40, 36, 50, 41, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 50, 125, 32, 45,
  108, 91, 36, 62, 44, 45, 50, 44, 45, 49, 93, 10, 45, 115, 91, 48,
  93, 32, 43, 44, 36, 49, 32, 45, 115, 32, 121, 44, 45, 64, 123, 45,
  50, 44, 119, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35,
  45, 50, 125, 32, 45, 105, 102, 32, 123, 64, 123, 36, 62, 44, 116, 125,
  39, 61, 61, 39, 64, 123, 45, 50, 44, 116, 125, 125, 32, 45, 114, 111,
  119, 115, 91, 36, 62, 93, 32, 48, 44, 123, 119, 45, 49, 125, 32, 45,
  102, 91, 36, 62, 93, 32, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105,
  102, 32, 45, 100, 111, 110, 101, 10, 45, 97, 91, 48, 45, 45, 51, 93,
  32, 121, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  114, 109, 91, 45, 50, 44, 45, 49, 93, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 114, 111, 117, 110, 100, 32, 58, 32, 114, 111,
  117, 110, 100, 105, 110, 103, 95, 118, 97, 108, 117, 101, 62, 61, 48, 44,
  95, 114, 111, 117, 110, 100, 105, 110, 103, 95, 116, 121, 112, 101, 32, 58,
  32, 40, 110, 111, 32, 97, 114, 103, 115, 41, 32, 58, 32, 40, 43, 41,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 111, 117, 110, 100, 32,
  118, 97, 108, 117, 101, 115, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 39, 114, 111, 117, 110, 100, 105, 110, 103, 95, 116, 121,
  112, 101, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 45, 49, 61,
  98, 97, 99, 107, 119, 97, 114, 100, 32, 124, 32, 48, 61, 110, 101, 97,
  114, 101, 115, 116, 32, 124, 32, 49, 61, 102, 111, 114, 119, 97, 114, 100,
  32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 114, 111, 117,
  110, 100, 105, 110, 103, 95, 116, 121, 112, 101, 61, 48, 39, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 45, 114, 111, 117, 110, 100, 32, 49, 48, 48, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 109, 117, 108, 32, 123, 112, 105, 47, 49, 56,
  48, 125, 32, 45, 115, 105, 110, 32, 45, 45, 114, 111, 117, 110, 100, 10,
  35, 64, 103, 109, 105, 99, 32, 114, 111, 117, 110, 100, 105, 102, 121, 32,
  58, 32, 103, 97, 109, 109, 97, 62, 61, 48, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 114, 111, 117, 110, 100, 105,
  102, 121, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 97, 116, 105, 111,
  110, 32, 111, 110, 32, 102, 108, 111, 97, 116, 45, 118, 97, 108, 117, 101,
  100, 32, 100, 97, 116, 97, 44, 32, 119, 105, 116, 104, 32, 115, 112, 101,
  99, 105, 102, 105, 101, 100, 32, 103, 97, 109, 109, 97, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 58, 32, 39, 103, 97, 109, 109, 97, 61, 48, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 49, 48, 48, 48,
  32, 45, 102, 105, 108, 108, 32, 39, 52, 42, 120, 47, 119, 39, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 53, 32, 45, 45, 114, 111, 117, 110, 100,
  105, 102, 121, 91, 48, 93, 32, 123, 36, 62, 42, 48, 46, 50, 125, 32,
  45, 100, 111, 110, 101, 32, 45, 97, 112, 112, 101, 110, 100, 32, 99, 32,
  45, 100, 105, 115, 112, 108, 97, 121, 95, 103, 114, 97, 112, 104, 32, 52,
  48, 48, 44, 51, 48, 48, 10, 114, 111, 117, 110, 100, 105, 102, 121, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 49, 62, 61, 48, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 82, 111, 117, 110, 100, 105, 102, 121,
  32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 103,
  97, 109, 109, 97, 32, 36, 49, 46, 34, 10, 45, 105, 102, 32, 123, 36,
  49, 61, 61, 49, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 114, 111,
  117, 110, 100, 32, 49, 32, 45, 45, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 32, 45, 45, 42, 91, 45, 50, 93, 32, 50, 32, 45, 97, 98, 115,
  91, 45, 49, 93, 32, 45, 94, 91, 45, 49, 93, 32, 36, 49, 32, 45,
  115, 105, 103, 110, 91, 45, 51, 93, 32, 45, 42, 91, 45, 51, 44, 45,
  49, 93, 32, 45, 42, 91, 45, 50, 93, 32, 48, 46, 53, 32, 45, 43,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 61, 32, 58, 32, 101, 113, 46,
  32, 116, 111, 32, 39, 45, 115, 101, 116, 39, 46, 32, 58, 32, 40, 43,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 115, 101, 116, 32, 58, 32, 118,
  97, 108, 117, 101, 44, 95, 120, 91, 37, 93, 44, 95, 121, 91, 37, 93,
  44, 95, 122, 91, 37, 93, 44, 95, 99, 91, 37, 93, 32, 58, 32, 40,
  42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 101, 116, 32,
  112, 105, 120, 101, 108, 32, 118, 97, 108, 117, 101, 32, 105, 110, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 44, 32,
  97, 116, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 99, 111, 111,
  114, 100, 105, 110, 97, 116, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 61, 39, 41,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 102, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 99, 111, 111, 114, 100, 105, 110, 97,
  116, 101, 115, 32, 97, 114, 101, 32, 111, 117, 116, 115, 105, 100, 101, 32,
  116, 104, 101, 32, 105, 109, 97, 103, 101, 32, 98, 111, 117, 110, 100, 115,
  44, 32, 110, 111, 32, 97, 99, 116, 105, 111, 110, 32, 105, 115, 32, 112,
  101, 114, 102, 111, 114, 109, 101, 100, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  115, 58, 32, 39, 120, 61, 121, 61, 122, 61, 99, 61, 48, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 50, 44, 50, 32, 45,
  115, 101, 116, 32, 49, 44, 48, 44, 48, 32, 45, 115, 101, 116, 32, 50,
  44, 49, 44, 48, 32, 45, 115, 101, 116, 32, 51, 44, 48, 44, 49, 32,
  45, 115, 101, 116, 32, 52, 44, 49, 44, 49, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 49, 48, 48, 48, 48, 32, 45, 115,
  101, 116, 32, 50, 53, 53, 44, 123, 63, 40, 49, 48, 48, 41, 125, 37,
  44, 123, 63, 40, 49, 48, 48, 41, 125, 37, 44, 48, 44, 123, 63, 40,
  49, 48, 48, 41, 125, 37, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103,
  109, 105, 99, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 58, 32,
  118, 97, 108, 117, 101, 91, 37, 93, 44, 95, 105, 115, 95, 115, 111, 102,
  116, 32, 58, 32, 40, 110, 111, 32, 97, 114, 103, 115, 41, 32, 58, 32,
  40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 84, 104, 114,
  101, 115, 104, 111, 108, 100, 32, 118, 97, 108, 117, 101, 115, 32, 111, 102,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 115, 111, 102, 116,
  39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 104, 97, 114,
  100, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100, 105, 110, 103, 32, 124,
  32, 49, 61, 115, 111, 102, 116, 45, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 105, 110, 103, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 40, 110, 111, 97, 114, 103, 115, 41, 32, 114, 117, 110, 115, 32, 105,
  110, 116, 101, 114, 97, 99, 116, 105, 118, 101, 32, 109, 111, 100, 101, 32,
  40, 117, 115, 101, 115, 32, 116, 104, 101, 32, 105, 110, 115, 116, 97, 110,
  116, 32, 119, 105, 110, 100, 111, 119, 32, 91, 48, 93, 32, 105, 102, 32,
  111, 112, 101, 110, 101, 100, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58,
  32, 39, 105, 115, 95, 115, 111, 102, 116, 61, 48, 39, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100, 91, 48,
  93, 32, 53, 48, 37, 32, 45, 45, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 91, 48, 93, 32, 53, 48, 37, 44, 49, 10, 35, 64, 103, 109, 105,
  99, 32, 116, 50, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 50, 39, 46, 10, 116, 50, 32,
  58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63, 34, 32,
  45, 118, 32, 43, 10, 45, 95, 116, 104, 114, 101, 115, 104, 111, 108, 100,
  50, 32, 36, 42, 10, 35, 64, 103, 109, 105, 99, 32, 116, 104, 114, 101,
  115, 104, 111, 108, 100, 50, 32, 58, 32, 109, 105, 110, 91, 37, 93, 44,
  109, 97, 120, 91, 37, 93, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  84, 104, 114, 101, 115, 104, 111, 108, 100, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 98, 101, 116, 119, 101, 101,
  110, 32, 116, 104, 101, 32, 116, 119, 111, 32, 103, 105, 118, 101, 110, 32,
  118, 97, 108, 117, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 116, 50, 39, 41, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 50, 32, 50, 53, 37, 44, 55, 53, 37, 10, 116, 104, 114, 101, 115,
  104, 111, 108, 100, 50, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115,
  61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 36, 48, 32,
  36, 42, 10, 95, 116, 104, 114, 101, 115, 104, 111, 108, 100, 50, 32, 58,
  10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 72, 97, 114, 100, 45,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 105, 109, 97, 103, 101, 34,
  36, 95, 95, 115, 34, 32, 98, 101, 116, 119, 101, 101, 110, 32, 118, 97,
  108, 117, 101, 115, 32, 36, 49, 32, 97, 110, 100, 32, 36, 50, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 109, 61, 36, 49, 32, 77, 61, 36,
  50, 10, 45, 105, 102, 32, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99,
  101, 110, 116, 92, 32, 36, 49, 125, 32, 109, 61, 123, 105, 109, 43, 40,
  105, 77, 45, 105, 109, 41, 42, 36, 109, 125, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99,
  101, 110, 116, 92, 32, 36, 50, 125, 32, 77, 61, 123, 105, 109, 43, 40,
  105, 77, 45, 105, 109, 41, 42, 36, 77, 125, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 45, 32, 123, 48, 46, 53, 42, 40, 36, 109, 43, 36, 77,
  41, 125, 32, 45, 97, 98, 115, 32, 45, 108, 101, 32, 123, 48, 46, 53,
  42, 97, 98, 115, 40, 36, 77, 45, 36, 109, 41, 125, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 117, 110, 99, 111, 109, 112, 114, 101, 115, 115, 95,
  114, 108, 101, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 85, 110, 99,
  111, 109, 112, 114, 101, 115, 115, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 50, 120, 78, 32, 100, 97, 116, 97, 32, 109, 97, 116, 114, 105, 99,
  101, 115, 44, 32, 117, 115, 105, 110, 103, 32, 82, 76, 69, 32, 97, 108,
  103, 111, 114, 105, 116, 104, 109, 46, 10, 117, 110, 99, 111, 109, 112, 114,
  101, 115, 115, 95, 114, 108, 101, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 85, 110, 99, 111, 109, 112, 114, 101, 115, 115, 32, 100, 97,
  116, 97, 32, 118, 101, 99, 116, 111, 114, 36, 63, 44, 32, 117, 115, 105,
  110, 103, 32, 82, 76, 69, 32, 97, 108, 103, 111, 114, 105, 116, 104, 109,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 121, 32, 119, 104, 100,
  115, 61, 64, 123, 48, 44, 48, 45, 51, 125, 32, 105, 109, 61, 64, 123,
  48, 44, 52, 125, 32, 45, 114, 111, 119, 115, 32, 53, 44, 49, 48, 48,
  37, 10, 45, 45, 108, 116, 91, 45, 49, 93, 32, 48, 32, 40, 48, 59,
  49, 59, 49, 41, 32, 45, 101, 114, 111, 100, 101, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  45, 91, 45, 49, 93, 32, 49, 32, 45, 97, 32, 120, 32, 45, 100, 105,
  115, 99, 97, 114, 100, 32, 45, 49, 10, 45, 45, 108, 116, 32, 48, 32,
  40, 49, 59, 49, 59, 48, 41, 32, 45, 100, 105, 108, 97, 116, 101, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 42, 91, 45, 49, 93, 32, 45, 50, 32, 45, 43, 91, 45, 49,
  93, 32, 49, 10, 45, 114, 118, 32, 45, 97, 98, 115, 91, 45, 49, 93,
  32, 45, 97, 32, 120, 32, 45, 100, 105, 115, 99, 97, 114, 100, 32, 45,
  49, 10, 45, 114, 32, 50, 44, 123, 104, 47, 50, 125, 44, 49, 44, 49,
  44, 45, 49, 32, 45, 115, 32, 121, 44, 45, 50, 53, 54, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  45, 105, 91, 48, 93, 32, 40, 123, 39, 67, 73, 109, 103, 51, 100, 39,
  125, 41, 32, 45, 43, 91, 48, 93, 32, 48, 46, 53, 10, 45, 105, 91,
  49, 93, 32, 40, 123, 50, 42, 104, 125, 59, 123, 104, 125, 41, 10, 45,
  115, 91, 45, 49, 93, 32, 120, 44, 50, 32, 45, 99, 117, 109, 117, 108,
  91, 45, 50, 93, 32, 115, 105, 122, 61, 64, 123, 45, 50, 44, 45, 49,
  125, 10, 45, 45, 115, 104, 105, 102, 116, 91, 45, 50, 93, 32, 48, 44,
  49, 32, 45, 45, 91, 45, 51, 93, 32, 49, 32, 45, 114, 118, 91, 45,
  51, 44, 45, 49, 93, 32, 45, 122, 91, 45, 51, 44, 45, 49, 93, 32,
  48, 44, 50, 32, 45, 97, 91, 45, 51, 44, 45, 49, 93, 32, 120, 10,
  45, 105, 91, 51, 93, 32, 40, 50, 44, 48, 44, 49, 59, 50, 44, 123,
  50, 42, 104, 45, 50, 125, 44, 123, 50, 42, 104, 45, 49, 125, 41, 32,
  45, 114, 91, 51, 93, 32, 51, 44, 123, 104, 125, 44, 49, 44, 49, 44,
  51, 32, 45, 114, 111, 117, 110, 100, 91, 51, 93, 10, 45, 114, 91, 52,
  93, 32, 51, 32, 49, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 49,
  32, 45, 121, 32, 45, 97, 32, 121, 10, 36, 115, 105, 122, 32, 45, 111,
  98, 106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  44, 48, 44, 48, 44, 48, 44, 49, 44, 50, 44, 48, 44, 48, 32, 45,
  114, 109, 91, 45, 50, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 45, 97, 32, 120, 32, 45, 114, 32, 36, 119, 104, 100, 115,
  44, 45, 49, 32, 45, 43, 32, 36, 105, 109, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109,
  105, 99, 32, 117, 110, 114, 101, 112, 101, 97, 116, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 82, 101, 109, 111, 118, 101, 32, 114, 101, 112, 101,
  116, 105, 116, 105, 111, 110, 32, 111, 102, 32, 97, 100, 106, 97, 99, 101,
  110, 116, 32, 118, 97, 108, 117, 101, 115, 32, 105, 110, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 40, 49, 59, 49, 59, 49, 59,
  49, 59, 49, 59, 50, 59, 50, 59, 50, 59, 51, 59, 52, 59, 52, 59,
  52, 59, 53, 59, 53, 59, 53, 41, 32, 45, 45, 117, 110, 114, 101, 112,
  101, 97, 116, 10, 117, 110, 114, 101, 112, 101, 97, 116, 32, 58, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 109, 111, 118, 101, 32, 114,
  101, 112, 101, 116, 105, 116, 105, 111, 110, 32, 111, 102, 32, 97, 100, 106,
  97, 99, 101, 110, 116, 32, 118, 97, 108, 117, 101, 115, 32, 105, 110, 32,
  105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 45, 121, 32, 120, 32,
  40, 123, 64, 123, 48, 44, 45, 49, 125, 43, 49, 125, 41, 32, 45, 97,
  32, 120, 32, 45, 114, 32, 49, 48, 48, 37, 44, 50, 10, 45, 102, 91,
  45, 49, 93, 32, 39, 62, 105, 102, 40, 121, 61, 61, 48, 44, 105, 44,
  105, 102, 40, 105, 40, 120, 44, 48, 41, 61, 61, 105, 40, 120, 43, 49,
  44, 48, 41, 44, 45, 49, 44, 120, 41, 41, 39, 10, 45, 122, 32, 48,
  44, 123, 119, 45, 50, 125, 32, 45, 115, 32, 121, 44, 50, 32, 45, 100,
  105, 115, 99, 97, 114, 100, 91, 49, 93, 32, 45, 49, 32, 45, 109, 97,
  112, 91, 49, 93, 32, 91, 48, 93, 10, 45, 114, 109, 91, 48, 93, 32,
  45, 110, 109, 32, 36, 110, 109, 44, 49, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 118, 101, 99, 116, 111, 114, 50, 116, 101, 110, 115, 111, 114, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 118, 101, 99, 116, 111, 114,
  32, 102, 105, 101, 108, 100, 115, 32, 116, 111, 32, 99, 111, 114, 114, 101,
  115, 112, 111, 110, 100, 105, 110, 103, 32, 100, 105, 102, 102, 117, 115, 105,
  111, 110, 32, 116, 101, 110, 115, 111, 114, 32, 102, 105, 101, 108, 100, 115,
  46, 10, 118, 101, 99, 116, 111, 114, 50, 116, 101, 110, 115, 111, 114, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101,
  114, 116, 32, 118, 101, 99, 116, 111, 114, 32, 102, 105, 101, 108, 100, 36,
  63, 32, 116, 111, 32, 100, 105, 102, 102, 117, 115, 105, 111, 110, 32, 116,
  101, 110, 115, 111, 114, 32, 102, 105, 101, 108, 100, 36, 63, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 115, 32, 99, 10, 45, 105, 102, 32,
  123, 64, 35, 61, 61, 50, 125, 32, 45, 45, 115, 113, 114, 91, 45, 49,
  93, 32, 45, 42, 91, 45, 50, 93, 32, 91, 45, 51, 93, 32, 45, 115,
  113, 114, 91, 45, 51, 93, 10, 45, 101, 108, 105, 102, 32, 123, 64, 35,
  61, 61, 51, 125, 32, 45, 45, 115, 113, 114, 91, 45, 50, 93, 32, 45,
  45, 42, 91, 45, 51, 93, 32, 91, 45, 50, 93, 32, 45, 45, 115, 113,
  114, 91, 45, 51, 93, 32, 45, 42, 91, 45, 53, 44, 45, 52, 93, 32,
  91, 45, 54, 93, 32, 45, 115, 113, 114, 91, 45, 54, 93, 10, 45, 101,
  108, 115, 101, 32, 45, 101, 114, 114, 111, 114, 91, 48, 45, 45, 52, 93,
  32, 34, 73, 110, 118, 97, 108, 105, 100, 32, 105, 109, 97, 103, 101, 32,
  91, 34, 123, 64, 35, 45, 36, 62, 45, 49, 125, 34, 93, 32, 58, 32,
  68, 105, 109, 101, 110, 115, 105, 111, 110, 115, 32, 34, 123, 119, 125, 34,
  44, 34, 123, 104, 125, 34, 44, 34, 123, 100, 125, 34, 44, 34, 123, 115,
  125, 34, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 114, 101, 112, 114,
  101, 115, 101, 110, 116, 32, 97, 32, 102, 105, 101, 108, 100, 32, 111, 102,
  32, 50, 100, 32, 111, 114, 32, 51, 100, 32, 118, 101, 99, 116, 111, 114,
  115, 46, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 97, 32, 99, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 58, 32, 67, 111, 108, 111, 114,
  115, 32, 109, 97, 110, 105, 112, 117, 108, 97, 116, 105, 111, 110, 10, 35,
  64, 103, 109, 105, 99, 32, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 32, 58, 32, 34, 99, 111, 109, 109, 97, 110, 100, 34,
  44, 95, 99, 104, 97, 110, 110, 101, 108, 115, 61, 123, 32, 97, 108, 108,
  61, 48, 32, 124, 32, 114, 103, 98, 97, 61, 49, 32, 124, 32, 114, 103,
  98, 61, 50, 32, 124, 32, 121, 61, 51, 32, 124, 32, 99, 98, 99, 114,
  61, 52, 32, 124, 32, 99, 98, 61, 53, 32, 124, 32, 99, 114, 61, 54,
  32, 124, 32, 108, 61, 55, 32, 124, 32, 97, 98, 61, 56, 32, 124, 32,
  97, 61, 57, 32, 124, 32, 98, 61, 49, 48, 32, 124, 32, 104, 61, 49,
  49, 32, 124, 32, 115, 61, 49, 50, 32, 124, 32, 118, 61, 49, 51, 32,
  124, 32, 107, 61, 49, 52, 32, 124, 32, 99, 103, 61, 49, 53, 32, 124,
  32, 99, 104, 61, 49, 54, 32, 124, 32, 99, 61, 49, 55, 32, 124, 32,
  72, 61, 49, 56, 32, 124, 32, 114, 61, 49, 57, 32, 124, 32, 103, 61,
  50, 48, 32, 124, 32, 98, 61, 50, 49, 32, 124, 32, 97, 108, 112, 104,
  97, 61, 61, 50, 50, 32, 125, 44, 95, 110, 111, 114, 109, 97, 108, 105,
  122, 101, 61, 123, 32, 48, 61, 99, 117, 116, 32, 124, 32, 49, 61, 110,
  111, 114, 109, 97, 108, 105, 122, 101, 32, 125, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 115, 112, 101, 99, 105, 102,
  105, 101, 100, 32, 99, 111, 109, 109, 97, 110, 100, 32, 111, 110, 32, 99,
  104, 111, 115, 101, 110, 32, 110, 111, 114, 109, 97, 108, 105, 122, 101, 100,
  32, 99, 104, 97, 110, 110, 101, 108, 115, 32, 111, 102, 32, 101, 97, 99,
  104, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 110, 111, 114, 109,
  97, 108, 105, 122, 101, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  34, 45, 101, 113, 117, 97, 108, 105, 122, 101, 32, 45, 98, 108, 117, 114,
  32, 50, 34, 44, 53, 10, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51,
  61, 48, 125, 10, 45, 105, 102, 32, 123, 123, 36, 50, 39, 61, 61, 39,
  97, 108, 108, 125, 34, 32, 124, 124, 32, 34, 123, 36, 50, 39, 61, 61,
  39, 48, 125, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112,
  112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 49, 39,
  32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 32, 45, 118,
  32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 95, 97, 112, 112, 108, 121, 95, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 34, 36, 49, 34, 10, 45, 105, 102, 32, 36,
  51, 32, 45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 115, 101,
  32, 45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108,
  105, 102, 32, 123, 123, 36, 50, 39, 61, 61, 39, 114, 103, 98, 97, 125,
  34, 32, 124, 124, 32, 34, 123, 36, 50, 39, 61, 61, 39, 49, 125, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32,
  99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110, 32,
  82, 71, 66, 65, 32, 99, 104, 97, 110, 110, 101, 108, 115, 32, 111, 102,
  32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 32, 45, 118, 32, 45, 10,
  45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 95, 97, 112, 112,
  108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 36, 49, 34,
  10, 45, 105, 102, 32, 36, 51, 32, 45, 110, 32, 48, 44, 50, 53, 53,
  32, 45, 101, 108, 115, 101, 32, 45, 99, 32, 48, 44, 50, 53, 53, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 45, 101, 108, 105, 102, 32, 123, 123, 36, 50, 39, 61, 61,
  39, 114, 103, 98, 125, 34, 32, 124, 124, 32, 34, 123, 36, 50, 39, 61,
  61, 39, 50, 125, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65,
  112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 49,
  39, 32, 111, 110, 32, 82, 71, 66, 32, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 32, 45,
  118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97,
  99, 105, 116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 10,
  45, 95, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  91, 48, 93, 32, 34, 36, 49, 34, 10, 45, 105, 102, 32, 36, 51, 32,
  45, 110, 91, 48, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 115,
  101, 32, 45, 99, 91, 48, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 10,
  45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 45, 101, 108, 105, 102, 32, 123, 123, 36, 50, 39, 61, 61, 39, 121,
  125, 34, 32, 124, 124, 32, 34, 123, 36, 50, 39, 61, 61, 39, 51, 125,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121,
  32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110,
  32, 108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 89, 32, 111, 102, 32,
  105, 109, 97, 103, 101, 36, 63, 46, 34, 32, 45, 118, 32, 45, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32,
  45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 32, 45, 114, 103, 98, 50,
  121, 99, 98, 99, 114, 91, 48, 93, 32, 45, 115, 91, 48, 93, 32, 99,
  10, 45, 95, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 91, 48, 93, 32, 34, 36, 49, 34, 32, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 91, 48, 93, 32, 48, 10, 45, 105, 102, 32, 36, 51, 32,
  45, 110, 91, 48, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 115,
  101, 32, 45, 99, 91, 48, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 97, 91, 48, 45, 50, 93, 32, 99, 32, 45,
  121, 99, 98, 99, 114, 50, 114, 103, 98, 91, 48, 93, 32, 45, 97, 32,
  99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101,
  108, 105, 102, 32, 123, 123, 36, 50, 39, 61, 61, 39, 99, 98, 99, 114,
  125, 34, 32, 124, 124, 32, 34, 123, 36, 50, 39, 61, 61, 39, 52, 125,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121,
  32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110,
  32, 98, 108, 117, 101, 32, 97, 110, 100, 32, 114, 101, 100, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 32, 67, 98, 67, 114, 32,
  111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 32, 45, 118, 32,
  45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105,
  116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 32, 45, 114,
  103, 98, 50, 121, 99, 98, 99, 114, 91, 48, 93, 32, 45, 115, 91, 48,
  93, 32, 99, 32, 45, 97, 91, 49, 44, 50, 93, 32, 99, 10, 45, 95,
  97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 49,
  93, 32, 34, 36, 49, 34, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115,
  91, 49, 93, 32, 48, 44, 49, 10, 45, 105, 102, 32, 36, 51, 32, 45,
  110, 91, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 115, 101,
  32, 45, 99, 91, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 97, 91, 48, 45, 49, 93, 32, 99, 32, 45, 121,
  99, 98, 99, 114, 50, 114, 103, 98, 91, 48, 93, 32, 45, 97, 32, 99,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108,
  105, 102, 32, 123, 123, 36, 50, 39, 61, 61, 39, 99, 98, 125, 34, 32,
  124, 124, 32, 34, 123, 36, 50, 39, 61, 61, 39, 53, 125, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111,
  109, 109, 97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110, 32, 98, 108,
  117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 32, 67,
  98, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 32, 45,
  118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97,
  99, 105, 116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 32,
  45, 114, 103, 98, 50, 121, 99, 98, 99, 114, 91, 48, 93, 32, 45, 115,
  91, 48, 93, 32, 99, 10, 45, 95, 97, 112, 112, 108, 121, 95, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 49, 93, 32, 34, 36, 49, 34, 32, 45,
  99, 104, 97, 110, 110, 101, 108, 115, 91, 49, 93, 32, 48, 10, 45, 105,
  102, 32, 36, 51, 32, 45, 110, 91, 49, 93, 32, 48, 44, 50, 53, 53,
  32, 45, 101, 108, 115, 101, 32, 45, 99, 91, 49, 93, 32, 48, 44, 50,
  53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 91, 48, 45, 50,
  93, 32, 99, 32, 45, 121, 99, 98, 99, 114, 50, 114, 103, 98, 91, 48,
  93, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 45, 101, 108, 105, 102, 32, 123, 123, 36, 50, 39, 61, 61,
  39, 99, 114, 125, 34, 32, 124, 124, 32, 34, 123, 36, 50, 39, 61, 61,
  39, 54, 125, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112,
  112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 49, 39,
  32, 111, 110, 32, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 32, 67, 114, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36,
  63, 46, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 112, 108, 105,
  116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 116, 111, 95, 114, 103,
  98, 91, 48, 93, 32, 45, 114, 103, 98, 50, 121, 99, 98, 99, 114, 91,
  48, 93, 32, 45, 115, 91, 48, 93, 32, 99, 10, 45, 95, 97, 112, 112,
  108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 50, 93, 32, 34,
  36, 49, 34, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 50, 93,
  32, 48, 10, 45, 105, 102, 32, 36, 51, 32, 45, 110, 91, 50, 93, 32,
  48, 44, 50, 53, 53, 32, 45, 101, 108, 115, 101, 32, 45, 99, 91, 50,
  93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  97, 91, 48, 45, 50, 93, 32, 99, 32, 45, 121, 99, 98, 99, 114, 50,
  114, 103, 98, 91, 48, 93, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32, 123, 123,
  36, 50, 39, 61, 61, 39, 108, 125, 34, 32, 124, 124, 32, 34, 123, 36,
  50, 39, 61, 61, 39, 55, 125, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100, 32,
  39, 36, 49, 39, 32, 111, 110, 32, 108, 105, 103, 104, 116, 110, 101, 115,
  115, 32, 76, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34,
  32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 112, 108, 105, 116, 95, 111,
  112, 97, 99, 105, 116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48,
  93, 32, 45, 114, 103, 98, 50, 108, 97, 98, 91, 48, 93, 32, 45, 115,
  91, 48, 93, 32, 99, 10, 45, 42, 91, 48, 93, 32, 50, 46, 53, 53,
  32, 45, 95, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 91, 48, 93, 32, 34, 36, 49, 34, 32, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 91, 48, 93, 32, 48, 32, 45, 47, 91, 48, 93, 32, 50,
  46, 53, 53, 10, 45, 105, 102, 32, 36, 51, 32, 45, 110, 91, 48, 93,
  32, 48, 44, 49, 48, 48, 32, 45, 101, 108, 115, 101, 32, 45, 99, 91,
  48, 93, 32, 48, 44, 49, 48, 48, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 97, 91, 48, 45, 50, 93, 32, 99, 32, 45, 108, 97, 98, 50, 114,
  103, 98, 91, 48, 93, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32, 123, 123, 36,
  50, 39, 61, 61, 39, 97, 98, 125, 34, 32, 124, 124, 32, 34, 123, 36,
  50, 39, 61, 61, 39, 56, 125, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100, 32,
  39, 36, 49, 39, 32, 111, 110, 32, 97, 45, 98, 32, 99, 104, 97, 110,
  110, 101, 108, 115, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46,
  34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 112, 108, 105, 116, 95,
  111, 112, 97, 99, 105, 116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91,
  48, 93, 32, 45, 114, 103, 98, 50, 108, 97, 98, 91, 48, 93, 32, 45,
  115, 91, 48, 93, 32, 99, 10, 45, 43, 91, 49, 93, 32, 56, 54, 32,
  45, 42, 91, 49, 93, 32, 49, 46, 51, 56, 53, 56, 55, 32, 45, 43,
  91, 50, 93, 32, 49, 48, 56, 32, 45, 42, 91, 50, 93, 32, 49, 46,
  50, 53, 54, 49, 54, 10, 45, 97, 91, 49, 44, 50, 93, 32, 99, 32,
  45, 95, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  91, 49, 93, 32, 34, 36, 49, 34, 32, 45, 99, 104, 97, 110, 110, 101,
  108, 115, 91, 49, 93, 32, 48, 44, 49, 32, 45, 115, 91, 49, 93, 32,
  99, 10, 45, 47, 91, 49, 93, 32, 49, 46, 51, 56, 53, 56, 55, 32,
  45, 45, 91, 49, 93, 32, 56, 54, 32, 45, 47, 91, 50, 93, 32, 49,
  46, 50, 53, 54, 49, 54, 32, 45, 45, 91, 50, 93, 32, 49, 48, 56,
  10, 45, 105, 102, 32, 36, 51, 32, 45, 110, 91, 49, 93, 32, 45, 56,
  54, 44, 57, 56, 32, 45, 110, 91, 50, 93, 32, 45, 49, 48, 56, 44,
  57, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 91, 48, 45, 50,
  93, 32, 99, 32, 45, 108, 97, 98, 50, 114, 103, 98, 91, 48, 93, 32,
  45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 45, 101, 108, 105, 102, 32, 123, 123, 36, 50, 39, 61, 61, 39, 97,
  125, 34, 32, 124, 124, 32, 34, 123, 36, 50, 39, 61, 61, 39, 57, 125,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121,
  32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110,
  32, 97, 45, 99, 104, 97, 110, 110, 101, 108, 32, 111, 102, 32, 105, 109,
  97, 103, 101, 36, 63, 46, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45,
  115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 116,
  111, 95, 114, 103, 98, 91, 48, 93, 32, 45, 114, 103, 98, 50, 108, 97,
  98, 91, 48, 93, 32, 45, 115, 91, 48, 93, 32, 99, 10, 45, 43, 91,
  49, 93, 32, 56, 54, 32, 45, 42, 91, 49, 93, 32, 49, 46, 51, 56,
  53, 56, 55, 32, 45, 95, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 91, 49, 93, 32, 34, 36, 49, 34, 32, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 49, 93, 32, 48, 32, 45, 47, 91, 49,
  93, 32, 49, 46, 51, 56, 53, 56, 55, 32, 45, 45, 91, 49, 93, 32,
  56, 54, 10, 45, 105, 102, 32, 36, 51, 32, 45, 110, 91, 49, 93, 32,
  45, 56, 54, 44, 57, 56, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97,
  91, 48, 45, 50, 93, 32, 99, 32, 45, 108, 97, 98, 50, 114, 103, 98,
  91, 48, 93, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32, 123, 123, 36, 50, 39,
  61, 61, 39, 98, 125, 34, 32, 124, 124, 32, 34, 123, 36, 50, 39, 61,
  61, 39, 49, 48, 125, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36,
  49, 39, 32, 111, 110, 32, 98, 45, 99, 104, 97, 110, 110, 101, 108, 32,
  111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 32, 45, 118, 32,
  45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105,
  116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 32, 45, 114,
  103, 98, 50, 108, 97, 98, 91, 48, 93, 32, 45, 115, 91, 48, 93, 32,
  99, 10, 45, 43, 91, 50, 93, 32, 49, 48, 56, 32, 45, 42, 91, 50,
  93, 32, 49, 46, 50, 53, 54, 49, 54, 32, 45, 95, 97, 112, 112, 108,
  121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 50, 93, 32, 34, 36,
  49, 34, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 50, 93, 32,
  48, 32, 45, 47, 91, 50, 93, 32, 49, 46, 50, 53, 54, 49, 54, 32,
  45, 45, 91, 50, 93, 32, 49, 48, 56, 10, 45, 105, 102, 32, 36, 51,
  32, 45, 110, 91, 49, 93, 32, 45, 49, 48, 56, 44, 57, 53, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 97, 91, 48, 45, 50, 93, 32, 99, 32,
  45, 108, 97, 98, 50, 114, 103, 98, 91, 48, 93, 32, 45, 97, 32, 99,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108,
  105, 102, 32, 123, 123, 36, 50, 39, 61, 61, 39, 104, 125, 34, 32, 124,
  124, 32, 34, 123, 36, 50, 39, 61, 61, 39, 49, 49, 125, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111,
  109, 109, 97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110, 32, 104, 117,
  101, 32, 72, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34,
  32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 112, 108, 105, 116, 95, 111,
  112, 97, 99, 105, 116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48,
  93, 32, 45, 114, 103, 98, 50, 104, 115, 118, 91, 48, 93, 32, 45, 115,
  91, 48, 93, 32, 99, 10, 45, 42, 91, 48, 93, 32, 48, 46, 55, 48,
  56, 51, 51, 51, 32, 45, 95, 97, 112, 112, 108, 121, 95, 99, 104, 97,
  110, 110, 101, 108, 115, 91, 48, 93, 32, 34, 36, 49, 34, 32, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 91, 48, 93, 32, 48, 32, 45, 47, 91,
  48, 93, 32, 48, 46, 55, 48, 56, 51, 51, 51, 10, 45, 105, 102, 32,
  36, 51, 32, 45, 110, 91, 48, 93, 32, 48, 44, 51, 54, 48, 32, 45,
  101, 108, 115, 101, 32, 45, 37, 91, 48, 93, 32, 51, 54, 48, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 97, 91, 48, 45, 50, 93, 32, 99, 32,
  45, 104, 115, 118, 50, 114, 103, 98, 91, 48, 93, 32, 45, 97, 32, 99,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108,
  105, 102, 32, 123, 123, 36, 50, 39, 61, 61, 39, 115, 125, 34, 32, 124,
  124, 32, 34, 123, 36, 50, 39, 61, 61, 39, 49, 50, 125, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111,
  109, 109, 97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110, 32, 115, 97,
  116, 117, 114, 97, 116, 105, 111, 110, 32, 83, 32, 111, 102, 32, 105, 109,
  97, 103, 101, 36, 63, 46, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45,
  115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 116,
  111, 95, 114, 103, 98, 91, 48, 93, 32, 45, 114, 103, 98, 50, 104, 115,
  118, 91, 48, 93, 32, 45, 115, 91, 48, 93, 32, 99, 10, 45, 42, 91,
  49, 93, 32, 50, 53, 53, 32, 45, 95, 97, 112, 112, 108, 121, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 91, 49, 93, 32, 34, 36, 49, 34, 32,
  45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 49, 93, 32, 48, 32, 45,
  47, 91, 49, 93, 32, 50, 53, 53, 10, 45, 105, 102, 32, 36, 51, 32,
  45, 110, 91, 49, 93, 32, 48, 44, 49, 32, 45, 101, 108, 115, 101, 32,
  45, 99, 91, 49, 93, 32, 48, 44, 49, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 97, 91, 48, 45, 50, 93, 32, 99, 32, 45, 104, 115, 118, 50,
  114, 103, 98, 91, 48, 93, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32, 123, 123,
  36, 50, 39, 61, 61, 39, 118, 125, 34, 32, 124, 124, 32, 34, 123, 36,
  50, 39, 61, 61, 39, 49, 51, 125, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100,
  32, 39, 36, 49, 39, 32, 111, 110, 32, 118, 97, 108, 117, 101, 32, 86,
  32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 32, 45, 118,
  32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99,
  105, 116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 32, 45,
  114, 103, 98, 50, 104, 115, 118, 91, 48, 93, 32, 45, 115, 91, 48, 93,
  32, 99, 10, 45, 42, 91, 50, 93, 32, 50, 53, 53, 32, 45, 95, 97,
  112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 50, 93,
  32, 34, 36, 49, 34, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91,
  50, 93, 32, 48, 32, 45, 47, 91, 50, 93, 32, 50, 53, 53, 10, 45,
  105, 102, 32, 36, 51, 32, 45, 110, 91, 50, 93, 32, 48, 44, 49, 32,
  45, 101, 108, 115, 101, 32, 45, 99, 91, 50, 93, 32, 48, 44, 49, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 97, 91, 48, 45, 50, 93, 32, 99,
  32, 45, 104, 115, 118, 50, 114, 103, 98, 91, 48, 93, 32, 45, 97, 32,
  99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101,
  108, 105, 102, 32, 123, 123, 36, 50, 39, 61, 61, 39, 107, 34, 32, 124,
  124, 32, 34, 123, 36, 50, 39, 61, 61, 39, 49, 52, 125, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111,
  109, 109, 97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110, 32, 107, 101,
  121, 32, 99, 104, 97, 110, 110, 101, 108, 32, 75, 32, 111, 102, 32, 105,
  109, 97, 103, 101, 36, 63, 46, 34, 32, 45, 118, 32, 45, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45,
  116, 111, 95, 114, 103, 98, 91, 48, 93, 32, 45, 114, 103, 98, 50, 99,
  109, 121, 107, 91, 48, 93, 32, 45, 115, 91, 48, 93, 32, 99, 10, 45,
  95, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91,
  51, 93, 32, 34, 36, 49, 34, 32, 45, 99, 104, 97, 110, 110, 101, 108,
  115, 91, 51, 93, 32, 48, 10, 45, 105, 102, 32, 36, 51, 32, 45, 110,
  91, 51, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 115, 101, 32,
  45, 99, 91, 51, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 97, 91, 48, 45, 51, 93, 32, 99, 32, 45, 99, 109,
  121, 107, 50, 114, 103, 98, 91, 48, 93, 32, 45, 97, 32, 99, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 105, 102,
  32, 123, 123, 36, 50, 39, 61, 61, 39, 99, 103, 125, 34, 32, 124, 124,
  32, 34, 123, 36, 50, 39, 61, 61, 39, 49, 53, 125, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111, 109,
  109, 97, 110, 100, 40, 115, 41, 32, 39, 36, 49, 39, 32, 111, 110, 32,
  103, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 32, 67, 103, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46,
  34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 112, 108, 105, 116, 95,
  111, 112, 97, 99, 105, 116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91,
  48, 93, 32, 45, 115, 91, 48, 93, 32, 99, 32, 45, 114, 118, 91, 49,
  44, 50, 93, 32, 45, 97, 91, 48, 45, 50, 93, 32, 99, 32, 45, 114,
  103, 98, 50, 121, 99, 98, 99, 114, 91, 48, 93, 32, 45, 115, 91, 48,
  93, 32, 99, 10, 45, 95, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 91, 49, 93, 32, 34, 36, 49, 34, 32, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 49, 93, 32, 48, 10, 45, 105, 102, 32,
  36, 51, 32, 45, 110, 91, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45,
  101, 108, 115, 101, 32, 45, 99, 91, 49, 93, 32, 48, 44, 50, 53, 53,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 91, 48, 45, 50, 93, 32,
  99, 32, 45, 121, 99, 98, 99, 114, 50, 114, 103, 98, 91, 48, 93, 32,
  45, 115, 91, 48, 93, 32, 99, 32, 45, 114, 118, 91, 49, 44, 50, 93,
  32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 45, 101, 108, 105, 102, 32, 123, 123, 36, 50, 39, 61, 61, 39,
  99, 104, 125, 34, 32, 124, 124, 32, 34, 123, 36, 50, 39, 61, 61, 39,
  49, 54, 125, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112,
  112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 49, 39,
  32, 111, 110, 32, 99, 45, 104, 32, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 32, 45, 118,
  32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99,
  105, 116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 32, 45,
  114, 103, 98, 50, 108, 99, 104, 91, 48, 93, 32, 45, 115, 91, 48, 93,
  32, 99, 10, 45, 42, 91, 49, 93, 32, 50, 46, 53, 53, 32, 45, 43,
  91, 50, 93, 32, 123, 112, 105, 125, 32, 45, 42, 91, 50, 93, 32, 123,
  50, 53, 53, 47, 40, 50, 42, 112, 105, 41, 125, 10, 45, 97, 91, 49,
  44, 50, 93, 32, 99, 32, 45, 95, 97, 112, 112, 108, 121, 95, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 49, 93, 32, 34, 36, 49, 34, 32, 45,
  99, 104, 97, 110, 110, 101, 108, 115, 91, 49, 93, 32, 48, 44, 49, 32,
  45, 115, 91, 49, 93, 32, 99, 10, 45, 47, 91, 49, 93, 32, 50, 46,
  53, 53, 32, 45, 47, 91, 50, 93, 32, 123, 50, 53, 53, 47, 40, 50,
  42, 112, 105, 41, 125, 32, 45, 45, 91, 50, 93, 32, 123, 112, 105, 125,
  10, 45, 105, 102, 32, 36, 51, 32, 45, 110, 91, 49, 93, 32, 48, 44,
  49, 48, 48, 32, 45, 110, 91, 50, 93, 32, 45, 123, 112, 105, 125, 44,
  123, 112, 105, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 91, 48,
  45, 50, 93, 32, 99, 32, 45, 108, 99, 104, 50, 114, 103, 98, 91, 48,
  93, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 45, 101, 108, 105, 102, 32, 123, 123, 36, 50, 39, 61, 61,
  39, 99, 125, 34, 32, 124, 124, 32, 34, 123, 36, 50, 39, 61, 61, 39,
  49, 55, 125, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112,
  112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 49, 39,
  32, 111, 110, 32, 99, 45, 99, 104, 97, 110, 110, 101, 108, 32, 111, 102,
  32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 32, 45, 118, 32, 45, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121,
  32, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 32, 45, 114, 103, 98,
  50, 108, 99, 104, 91, 48, 93, 32, 45, 115, 91, 48, 93, 32, 99, 10,
  45, 42, 91, 49, 93, 32, 50, 46, 53, 53, 32, 45, 95, 97, 112, 112,
  108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 49, 93, 32, 34,
  36, 49, 34, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 49, 93,
  32, 48, 32, 45, 47, 91, 49, 93, 32, 50, 46, 53, 53, 10, 45, 105,
  102, 32, 36, 51, 32, 45, 110, 91, 49, 93, 32, 48, 44, 49, 48, 48,
  32, 45, 101, 108, 115, 101, 32, 45, 99, 91, 49, 93, 32, 48, 44, 49,
  48, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 91, 48, 45, 50,
  93, 32, 99, 32, 45, 108, 99, 104, 50, 114, 103, 98, 91, 48, 93, 32,
  45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 45, 101, 108, 105, 102, 32, 123, 123, 36, 50, 39, 61, 61, 39, 104,
  125, 34, 32, 124, 124, 32, 34, 123, 36, 50, 39, 61, 61, 39, 49, 56,
  125, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108,
  121, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 49, 39, 32, 111,
  110, 32, 104, 45, 99, 104, 97, 110, 110, 101, 108, 32, 111, 102, 32, 105,
  109, 97, 103, 101, 36, 63, 46, 34, 32, 45, 118, 32, 45, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45,
  116, 111, 95, 114, 103, 98, 91, 48, 93, 32, 45, 114, 103, 98, 50, 108,
  99, 104, 91, 48, 93, 32, 45, 115, 91, 48, 93, 32, 99, 10, 45, 43,
  91, 50, 93, 32, 123, 112, 105, 125, 32, 45, 42, 91, 50, 93, 32, 123,
  50, 53, 53, 47, 40, 50, 42, 112, 105, 41, 125, 32, 45, 95, 97, 112,
  112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 50, 93, 32,
  34, 36, 49, 34, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 50,
  93, 32, 48, 32, 45, 47, 91, 50, 93, 32, 123, 50, 53, 53, 47, 40,
  50, 42, 112, 105, 41, 125, 32, 45, 45, 91, 50, 93, 32, 123, 112, 105,
  125, 10, 45, 105, 102, 32, 36, 51, 32, 45, 110, 91, 50, 93, 32, 45,
  123, 112, 105, 125, 44, 123, 112, 105, 125, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 97, 91, 48, 45, 50, 93, 32, 99, 32, 45, 108, 99, 104, 50,
  114, 103, 98, 91, 48, 93, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32, 123, 123,
  36, 50, 39, 61, 61, 39, 114, 125, 34, 32, 124, 124, 32, 34, 123, 36,
  50, 39, 61, 61, 39, 49, 57, 125, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100,
  32, 39, 36, 49, 39, 32, 111, 110, 32, 114, 101, 100, 32, 99, 104, 97,
  110, 110, 101, 108, 32, 82, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36,
  63, 46, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 112, 108, 105,
  116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 116, 111, 95, 114, 103,
  98, 91, 48, 93, 32, 45, 115, 91, 48, 93, 32, 99, 10, 45, 95, 97,
  112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48, 93,
  32, 34, 36, 49, 34, 10, 45, 105, 102, 32, 36, 51, 32, 45, 110, 91,
  48, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 115, 101, 32, 45,
  99, 91, 48, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 116, 111, 95, 103, 114, 97, 121, 91, 48, 93, 10, 45, 97,
  32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45,
  101, 108, 105, 102, 32, 123, 123, 36, 50, 39, 61, 61, 39, 103, 125, 34,
  32, 124, 124, 32, 34, 123, 36, 50, 39, 61, 61, 39, 50, 48, 125, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32,
  99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110, 32,
  103, 114, 101, 101, 110, 32, 99, 104, 97, 110, 110, 101, 108, 32, 71, 32,
  111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 32, 45, 118, 32,
  45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105,
  116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 32, 45, 115,
  91, 48, 93, 32, 99, 10, 45, 95, 97, 112, 112, 108, 121, 95, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 49, 93, 32, 34, 36, 49, 34, 10, 45,
  105, 102, 32, 36, 51, 32, 45, 110, 91, 49, 93, 32, 48, 44, 50, 53,
  53, 32, 45, 101, 108, 115, 101, 32, 45, 99, 91, 49, 93, 32, 48, 44,
  50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 103,
  114, 97, 121, 91, 49, 93, 10, 45, 97, 32, 99, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32, 123, 123,
  36, 50, 39, 61, 61, 39, 98, 125, 34, 32, 124, 124, 32, 34, 123, 36,
  50, 39, 61, 61, 39, 50, 49, 125, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100,
  32, 39, 36, 49, 39, 32, 111, 110, 32, 98, 108, 117, 101, 32, 99, 104,
  97, 110, 110, 101, 108, 32, 66, 32, 111, 102, 32, 105, 109, 97, 103, 101,
  36, 63, 46, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 112, 108,
  105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 116, 111, 95, 114,
  103, 98, 91, 48, 93, 32, 45, 115, 91, 48, 93, 32, 99, 10, 45, 95,
  97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 50,
  93, 32, 34, 36, 49, 34, 10, 45, 105, 102, 32, 36, 51, 32, 45, 110,
  91, 50, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 115, 101, 32,
  45, 99, 91, 50, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 116, 111, 95, 103, 114, 97, 121, 91, 50, 93, 10, 45,
  97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  45, 101, 108, 105, 102, 32, 123, 123, 36, 50, 39, 61, 61, 39, 97, 108,
  112, 104, 97, 125, 34, 32, 124, 124, 32, 34, 123, 36, 50, 39, 61, 61,
  39, 50, 50, 125, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65,
  112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 49,
  39, 32, 111, 110, 32, 97, 108, 112, 104, 97, 32, 99, 104, 97, 110, 110,
  101, 108, 32, 65, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46,
  34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 116, 111, 95, 114, 103, 98,
  97, 32, 45, 115, 32, 99, 10, 45, 95, 97, 112, 112, 108, 121, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 91, 51, 93, 32, 34, 36, 49, 34, 10,
  45, 105, 102, 32, 36, 51, 32, 45, 110, 91, 51, 93, 32, 48, 44, 50,
  53, 53, 32, 45, 101, 108, 115, 101, 32, 45, 99, 91, 51, 93, 32, 48,
  44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95,
  103, 114, 97, 121, 91, 51, 93, 10, 45, 97, 32, 99, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 118, 32, 43, 10, 95, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 32, 58, 10, 36, 123, 49, 45, 45, 49, 125, 32, 45,
  107, 91, 48, 93, 10, 35, 64, 103, 109, 105, 99, 32, 97, 117, 116, 111,
  105, 110, 100, 101, 120, 32, 58, 32, 110, 98, 95, 99, 111, 108, 111, 114,
  115, 62, 48, 44, 48, 60, 61, 95, 100, 105, 116, 104, 101, 114, 105, 110,
  103, 60, 61, 49, 44, 95, 109, 101, 116, 104, 111, 100, 61, 123, 32, 48,
  61, 109, 101, 100, 105, 97, 110, 45, 99, 117, 116, 32, 124, 32, 49, 61,
  107, 45, 109, 101, 97, 110, 115, 32, 125, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 73, 110, 100, 101, 120, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 118, 101, 99, 116, 111, 114, 45, 118, 97, 108, 117, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 32, 98, 121, 32, 97, 100, 97, 112, 116, 101,
  100, 32, 99, 111, 108, 111, 114, 109, 97, 112, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 100, 105, 116, 104, 101, 114, 105, 110, 103,
  61, 48, 39, 32, 97, 110, 100, 32, 39, 109, 101, 116, 104, 111, 100, 61,
  48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 97, 117, 116, 111, 105,
  110, 100, 101, 120, 91, 48, 93, 32, 52, 32, 45, 45, 97, 117, 116, 111,
  105, 110, 100, 101, 120, 91, 48, 93, 32, 56, 32, 45, 45, 97, 117, 116,
  111, 105, 110, 100, 101, 120, 91, 48, 93, 32, 49, 54, 10, 97, 117, 116,
  111, 105, 110, 100, 101, 120, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 105, 115, 105, 110, 116, 40, 36, 49, 41, 32, 38, 38, 32, 36, 49,
  62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 48, 125, 62, 61, 48, 34,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 48, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 73, 110, 100, 101, 120, 32, 99, 111, 108,
  111, 114, 115, 32, 105, 110, 32, 105, 109, 97, 103, 101, 115, 36, 63, 32,
  98, 121, 32, 97, 100, 97, 112, 116, 101, 100, 32, 99, 111, 108, 111, 114,
  109, 97, 112, 32, 119, 105, 116, 104, 32, 36, 49, 32, 101, 110, 116, 114,
  105, 101, 115, 44, 32, 100, 105, 116, 104, 101, 114, 105, 110, 103, 32, 108,
  101, 118, 101, 108, 32, 36, 50, 32, 97, 110, 100, 32, 34, 92, 10, 64,
  123, 45, 97, 114, 103, 92, 32, 49, 43, 33, 36, 51, 44, 107, 45, 109,
  101, 97, 110, 115, 44, 109, 101, 100, 105, 97, 110, 45, 99, 117, 116, 125,
  34, 32, 109, 101, 116, 104, 111, 100, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 105, 102, 32, 123, 119, 62, 104, 125, 32, 45, 105, 102, 32,
  123, 119, 62, 50, 53, 54, 125, 32, 45, 45, 114, 50, 100, 120, 32, 50,
  53, 54, 32, 45, 101, 108, 115, 101, 32, 91, 48, 93, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 108, 115, 101, 32, 45, 105, 102, 32, 123, 104,
  62, 50, 53, 54, 125, 32, 45, 45, 114, 50, 100, 121, 32, 50, 53, 54,
  32, 45, 101, 108, 115, 101, 32, 91, 48, 93, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 99, 111, 108, 111, 114, 109,
  97, 112, 91, 49, 93, 32, 36, 49, 44, 36, 51, 44, 48, 10, 45, 105,
  110, 100, 101, 120, 91, 48, 93, 32, 91, 49, 93, 44, 36, 50, 44, 49,
  32, 45, 114, 109, 91, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  98, 97, 121, 101, 114, 50, 114, 103, 98, 32, 58, 32, 95, 71, 77, 95,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 44, 95, 82, 66, 95, 115,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 49, 44, 95, 82, 66, 95, 115,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 50, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 84, 114, 97, 110, 115, 102, 111, 114, 109, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 82, 71, 66, 45, 66, 97, 121, 101, 114,
  32, 115, 97, 109, 112, 108, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32,
  116, 111, 32, 99, 111, 108, 111, 114, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108,
  116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 71, 77, 95, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 61, 82, 66, 95, 115, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 61, 49, 39, 32, 97, 110, 100, 32, 39, 82,
  66, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 50, 61, 48, 46,
  53, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114, 103, 98, 50, 98, 97,
  121, 101, 114, 32, 48, 32, 45, 45, 98, 97, 121, 101, 114, 50, 114, 103,
  98, 32, 49, 44, 49, 44, 48, 46, 53, 10, 98, 97, 121, 101, 114, 50,
  114, 103, 98, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  49, 125, 44, 36, 123, 50, 61, 49, 125, 44, 36, 123, 51, 61, 48, 46,
  53, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 84, 114, 97, 110,
  115, 102, 111, 114, 109, 32, 82, 71, 66, 45, 66, 97, 121, 101, 114, 32,
  105, 109, 97, 103, 101, 36, 63, 32, 116, 111, 32, 99, 111, 108, 111, 114,
  32, 105, 109, 97, 103, 101, 115, 44, 32, 119, 105, 116, 104, 32, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 40, 36, 49, 44, 36, 50, 44,
  36, 51, 41, 46, 34, 10, 45, 118, 32, 45, 32, 45, 99, 104, 97, 110,
  110, 101, 108, 115, 32, 48, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 101, 120, 112, 97, 110, 100,
  95, 120, 32, 123, 34, 50, 32, 43, 32, 52, 42, 36, 49, 34, 125, 44,
  48, 32, 45, 101, 120, 112, 97, 110, 100, 95, 121, 32, 123, 34, 50, 32,
  43, 32, 52, 42, 36, 49, 34, 125, 44, 48, 10, 40, 45, 49, 44, 49,
  59, 49, 44, 45, 49, 41, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 49, 44, 48, 44, 50, 10,
  45, 45, 42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 10, 40, 48, 46,
  50, 53, 44, 48, 46, 53, 44, 48, 46, 50, 53, 41, 32, 45, 99, 111,
  110, 118, 111, 108, 118, 101, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32,
  45, 116, 114, 97, 110, 115, 112, 111, 115, 101, 91, 45, 49, 93, 32, 45,
  99, 111, 110, 118, 111, 108, 118, 101, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 98, 91, 45, 49, 93,
  32, 36, 49, 10, 45, 42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 10,
  45, 45, 91, 45, 51, 44, 45, 50, 93, 10, 40, 49, 44, 45, 49, 41,
  32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50,
  93, 44, 49, 44, 49, 44, 48, 44, 50, 10, 45, 42, 91, 45, 49, 93,
  32, 91, 45, 51, 93, 10, 40, 48, 46, 50, 53, 44, 48, 46, 53, 44,
  48, 46, 50, 53, 41, 32, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 116, 114, 97, 110, 115, 112,
  111, 115, 101, 91, 45, 49, 93, 32, 45, 99, 111, 110, 118, 111, 108, 118,
  101, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 98, 108, 117, 114, 95, 121, 91, 45, 49, 93, 32, 36,
  50, 32, 45, 98, 108, 117, 114, 95, 120, 91, 45, 49, 93, 32, 36, 51,
  10, 40, 49, 59, 45, 49, 41, 32, 45, 114, 91, 45, 49, 93, 32, 91,
  45, 50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 49, 44, 48, 44, 50,
  10, 45, 42, 91, 45, 49, 93, 32, 91, 45, 52, 93, 10, 40, 48, 46,
  50, 53, 44, 48, 46, 53, 44, 48, 46, 50, 53, 41, 32, 45, 99, 111,
  110, 118, 111, 108, 118, 101, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32,
  45, 116, 114, 97, 110, 115, 112, 111, 115, 101, 91, 45, 49, 93, 32, 45,
  99, 111, 110, 118, 111, 108, 118, 101, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 98, 108, 117, 114, 95,
  120, 91, 45, 49, 93, 32, 36, 50, 32, 45, 98, 108, 117, 114, 95, 121,
  91, 45, 49, 93, 32, 36, 51, 10, 45, 43, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 47, 91, 45, 49, 93, 32, 50, 10, 40, 50, 44, 48, 59,
  48, 44, 45, 50, 41, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50,
  93, 44, 91, 45, 50, 93, 44, 49, 44, 49, 44, 48, 44, 50, 10, 45,
  42, 91, 45, 49, 93, 32, 91, 45, 50, 93, 10, 45, 45, 91, 45, 52,
  44, 45, 49, 93, 10, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 99,
  10, 45, 109, 105, 120, 95, 114, 103, 98, 91, 45, 49, 93, 32, 49, 44,
  45, 49, 44, 50, 44, 49, 44, 49, 44, 48, 44, 49, 44, 45, 49, 44,
  45, 50, 10, 45, 115, 104, 114, 105, 110, 107, 95, 120, 32, 123, 34, 50,
  32, 43, 32, 52, 42, 36, 49, 34, 125, 44, 48, 32, 45, 115, 104, 114,
  105, 110, 107, 95, 121, 32, 123, 34, 50, 32, 43, 32, 52, 42, 36, 49,
  34, 125, 44, 48, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 99, 109, 121, 50, 114, 103, 98, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 102,
  114, 111, 109, 32, 67, 77, 89, 32, 116, 111, 32, 82, 71, 66, 32, 99,
  111, 108, 111, 114, 98, 97, 115, 101, 115, 46, 10, 99, 109, 121, 50, 114,
  103, 98, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111,
  110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114,
  111, 109, 32, 67, 77, 89, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111,
  108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 103, 98, 50, 99, 109, 121, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 99, 109, 121, 107, 50, 114, 103, 98, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32,
  102, 114, 111, 109, 32, 67, 77, 89, 75, 32, 116, 111, 32, 82, 71, 66,
  32, 99, 111, 108, 111, 114, 98, 97, 115, 101, 115, 46, 10, 99, 109, 121,
  107, 50, 114, 103, 98, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63,
  32, 102, 114, 111, 109, 32, 67, 77, 89, 75, 32, 116, 111, 32, 82, 71,
  66, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 115, 32, 99, 32, 45, 45, 47, 91,
  45, 49, 93, 32, 45, 50, 53, 53, 32, 45, 43, 91, 45, 49, 93, 32,
  49, 32, 45, 42, 91, 48, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 43, 91, 48, 45, 50, 93, 32, 91,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 97, 32, 99,
  32, 45, 99, 109, 121, 50, 114, 103, 98, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 99, 111, 108, 111, 114, 109, 97, 112, 32, 58, 32, 110, 98, 95,
  108, 101, 118, 101, 108, 115, 62, 61, 49, 44, 95, 109, 101, 116, 104, 111,
  100, 61, 123, 32, 48, 61, 109, 101, 100, 105, 97, 110, 45, 99, 117, 116,
  32, 124, 32, 49, 61, 107, 45, 109, 101, 97, 110, 115, 32, 125, 44, 95,
  115, 111, 114, 116, 95, 118, 101, 99, 116, 111, 114, 115, 61, 123, 32, 48,
  32, 124, 32, 49, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  69, 115, 116, 105, 109, 97, 116, 101, 32, 98, 101, 115, 116, 45, 102, 105,
  116, 116, 105, 110, 103, 32, 99, 111, 108, 111, 114, 109, 97, 112, 32, 119,
  105, 116, 104, 32, 39, 110, 98, 95, 99, 111, 108, 111, 114, 115, 39, 32,
  101, 110, 116, 114, 105, 101, 115, 44, 32, 116, 111, 32, 105, 110, 100, 101,
  120, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 109, 101, 116, 104,
  111, 100, 61, 48, 39, 32, 97, 110, 100, 32, 39, 115, 111, 114, 116, 95,
  118, 101, 99, 116, 111, 114, 115, 61, 49, 39, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 45, 99, 111, 108, 111, 114, 109, 97, 112, 91, 48, 93, 32, 52,
  32, 45, 45, 99, 111, 108, 111, 114, 109, 97, 112, 91, 48, 93, 32, 56,
  32, 45, 45, 99, 111, 108, 111, 114, 109, 97, 112, 91, 48, 93, 32, 49,
  54, 10, 99, 111, 108, 111, 114, 109, 97, 112, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 49, 41, 32, 38,
  38, 32, 36, 49, 62, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  50, 61, 48, 125, 44, 36, 123, 51, 61, 49, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 69, 115, 116, 105, 109, 97, 116, 101, 32, 99, 111,
  108, 111, 114, 109, 97, 112, 32, 119, 105, 116, 104, 32, 36, 49, 32, 101,
  110, 116, 114, 105, 101, 115, 32, 102, 111, 114, 32, 105, 109, 97, 103, 101,
  36, 63, 44, 32, 98, 121, 32, 34, 64, 123, 45, 97, 114, 103, 92, 32,
  49, 43, 33, 36, 50, 44, 107, 45, 109, 101, 97, 110, 115, 44, 109, 101,
  100, 105, 97, 110, 45, 99, 117, 116, 125, 34, 32, 109, 101, 116, 104, 111,
  100, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 114, 32, 123, 119,
  42, 104, 125, 44, 49, 44, 49, 44, 49, 48, 48, 37, 44, 45, 49, 10,
  45, 105, 102, 32, 123, 33, 36, 50, 125, 32, 45, 95, 99, 111, 108, 111,
  114, 109, 97, 112, 32, 36, 49, 10, 45, 101, 108, 115, 101, 10, 109, 61,
  123, 105, 109, 125, 32, 77, 61, 123, 105, 77, 125, 32, 45, 110, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 45, 95, 99, 111, 108, 111,
  114, 109, 97, 112, 32, 36, 49, 32, 45, 45, 105, 110, 100, 101, 120, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32,
  50, 53, 54, 32, 45, 43, 91, 45, 51, 44, 45, 49, 93, 10, 45, 100,
  111, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 115, 125, 10, 45, 115,
  104, 91, 48, 93, 32, 36, 62, 44, 36, 62, 32, 45, 45, 104, 105, 115,
  116, 111, 103, 114, 97, 109, 91, 45, 49, 93, 32, 123, 36, 49, 42, 50,
  53, 54, 125, 44, 48, 44, 123, 36, 49, 42, 50, 53, 54, 45, 49, 125,
  32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 105, 91, 45, 50, 93, 32,
  50, 53, 54, 44, 49, 44, 49, 44, 49, 44, 39, 120, 39, 32, 45, 114,
  91, 45, 50, 93, 32, 123, 119, 125, 44, 49, 44, 49, 44, 49, 44, 48,
  44, 50, 32, 45, 42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45,
  114, 91, 45, 50, 44, 45, 49, 93, 32, 36, 49, 44, 49, 44, 49, 44,
  49, 44, 50, 32, 45, 109, 97, 120, 91, 45, 49, 93, 32, 48, 46, 48,
  49, 32, 45, 47, 91, 45, 50, 44, 45, 49, 93, 10, 45, 100, 111, 110,
  101, 32, 45, 97, 91, 50, 45, 45, 49, 93, 32, 99, 10, 45, 45, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 97, 98, 115, 91, 45, 50,
  93, 32, 100, 105, 102, 102, 61, 123, 64, 123, 45, 50, 44, 43, 125, 47,
  119, 125, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 97, 110, 100, 91,
  45, 50, 93, 32, 50, 53, 53, 32, 45, 45, 105, 110, 100, 101, 120, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 32, 45, 42, 91,
  45, 49, 93, 32, 50, 53, 54, 32, 45, 43, 91, 45, 51, 44, 45, 49,
  93, 10, 45, 119, 104, 105, 108, 101, 32, 123, 36, 100, 105, 102, 102, 62,
  48, 46, 53, 125, 10, 45, 114, 109, 91, 45, 50, 93, 32, 45, 42, 91,
  45, 49, 93, 32, 123, 40, 36, 77, 45, 36, 109, 41, 47, 50, 53, 53,
  125, 32, 45, 43, 91, 45, 49, 93, 32, 36, 109, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 36, 51, 32, 45, 45, 110, 111, 114, 109,
  32, 45, 114, 118, 32, 45, 97, 32, 121, 32, 45, 115, 111, 114, 116, 32,
  43, 44, 120, 32, 45, 114, 111, 119, 115, 32, 49, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 110, 109, 32, 34, 91, 99, 111, 108, 111, 114, 109, 97,
  112, 32, 111, 102, 32, 34, 64, 123, 45, 49, 44, 98, 125, 34, 93, 34,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 95, 99, 111, 108, 111, 114, 109, 97, 112, 32, 58, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 123, 36, 49, 45, 49, 125, 10, 64, 35, 44,
  123, 115, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45,
  49, 125, 10, 110, 61, 36, 62, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 123, 36, 110, 44, 115, 125, 32, 45, 115, 104, 91, 36, 110, 93, 32,
  36, 62, 44, 36, 62, 32, 45, 61, 91, 45, 50, 93, 32, 123, 105, 102,
  40, 119, 62, 49, 44, 105, 118, 44, 45, 49, 41, 125, 44, 36, 110, 44,
  36, 62, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 100, 111, 110, 101,
  10, 45, 100, 111, 110, 101, 10, 99, 61, 64, 123, 45, 49, 44, 67, 125,
  10, 98, 61, 64, 123, 45, 97, 114, 103, 92, 32, 49, 44, 36, 99, 125,
  10, 97, 61, 64, 123, 45, 97, 114, 103, 92, 32, 50, 44, 36, 99, 125,
  10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 115, 104, 105, 102, 116, 91,
  36, 98, 93, 32, 48, 44, 48, 44, 48, 44, 123, 45, 36, 97, 125, 44,
  50, 32, 45, 115, 111, 114, 116, 91, 36, 98, 93, 32, 43, 44, 120, 32,
  45, 115, 104, 105, 102, 116, 91, 36, 98, 93, 32, 48, 44, 48, 44, 48,
  44, 36, 97, 44, 50, 32, 45, 115, 91, 36, 98, 93, 32, 120, 44, 50,
  10, 45, 100, 111, 110, 101, 10, 45, 114, 32, 49, 44, 49, 44, 49, 44,
  49, 48, 48, 37, 44, 50, 32, 45, 97, 32, 120, 10, 35, 64, 103, 109,
  105, 99, 32, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110,
  101, 108, 115, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109,
  112, 111, 115, 101, 32, 97, 108, 108, 32, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 111, 102, 32, 101, 97, 99, 104, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 44, 32, 117, 115, 105, 110, 103, 32,
  115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 97, 114, 105, 116, 104, 109,
  101, 116, 105, 99, 32, 111, 112, 101, 114, 97, 116, 111, 114, 32, 40, 43,
  44, 45, 44, 111, 114, 44, 109, 105, 110, 44, 46, 46, 46, 41, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116,
  32, 118, 97, 108, 117, 101, 58, 32, 39, 49, 61, 43, 39, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 45, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104,
  97, 110, 110, 101, 108, 115, 32, 97, 110, 100, 10, 99, 111, 109, 112, 111,
  115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 49, 61, 34, 43, 34, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 111, 115, 101, 32, 97, 108,
  108, 32, 99, 104, 97, 110, 110, 101, 108, 115, 32, 111, 102, 32, 105, 109,
  97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 111, 112, 101, 114,
  97, 116, 111, 114, 32, 39, 36, 49, 39, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 45, 115, 104, 32, 48, 44, 48, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 64, 123, 45, 50, 44, 115, 125, 45, 49, 125, 32, 45,
  115, 104, 91, 45, 50, 93, 32, 123, 36, 62, 43, 49, 125, 44, 123, 36,
  62, 43, 49, 125, 32, 45, 108, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  36, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 114, 32, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 45, 49, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 100, 105, 114, 101, 99, 116, 105, 111, 110, 50,
  114, 103, 98, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109,
  112, 117, 116, 101, 32, 82, 71, 66, 32, 114, 101, 112, 114, 101, 115, 101,
  110, 116, 97, 116, 105, 111, 110, 32, 111, 102, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 50, 100, 32, 100, 105, 114, 101, 99, 116, 105, 111, 110,
  32, 102, 105, 101, 108, 100, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 108,
  117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 103, 114, 97, 100, 105, 101,
  110, 116, 32, 45, 97, 112, 112, 101, 110, 100, 32, 99, 32, 45, 98, 108,
  117, 114, 32, 50, 32, 45, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111,
  110, 32, 45, 45, 100, 105, 114, 101, 99, 116, 105, 111, 110, 50, 114, 103,
  98, 10, 100, 105, 114, 101, 99, 116, 105, 111, 110, 50, 114, 103, 98, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117,
  116, 101, 32, 82, 71, 66, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116,
  97, 116, 105, 111, 110, 32, 111, 102, 32, 50, 100, 32, 100, 105, 114, 101,
  99, 116, 105, 111, 110, 32, 102, 105, 101, 108, 100, 36, 63, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48,
  44, 49, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 45,
  115, 32, 99, 32, 45, 99, 111, 109, 112, 108, 101, 120, 50, 112, 111, 108,
  97, 114, 32, 45, 114, 111, 117, 110, 100, 91, 45, 50, 93, 32, 48, 46,
  48, 48, 49, 10, 45, 42, 91, 45, 49, 93, 32, 123, 49, 56, 48, 47,
  112, 105, 125, 32, 45, 37, 91, 45, 49, 93, 32, 51, 54, 48, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 49, 32, 45,
  109, 118, 91, 45, 51, 93, 32, 64, 35, 10, 45, 105, 102, 32, 123, 105,
  109, 33, 61, 105, 77, 125, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44,
  49, 32, 45, 101, 108, 115, 101, 32, 45, 102, 91, 45, 49, 93, 32, 49,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 32, 99, 32, 45, 104, 115,
  118, 50, 114, 103, 98, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 100, 105, 116, 104, 101, 114, 101, 100,
  98, 119, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 114, 101, 97,
  116, 101, 32, 100, 105, 116, 104, 101, 114, 101, 100, 32, 66, 38, 87, 32,
  118, 101, 114, 115, 105, 111, 110, 32, 111, 102, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 45, 101, 113, 117, 97, 108, 105, 122, 101, 32, 45, 100, 105, 116,
  104, 101, 114, 101, 100, 98, 119, 91, 45, 49, 93, 10, 100, 105, 116, 104,
  101, 114, 101, 100, 98, 119, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 67, 114, 101, 97, 116, 101, 32, 100, 105, 116, 104, 101, 114, 101,
  100, 32, 66, 38, 87, 32, 118, 101, 114, 115, 105, 111, 110, 32, 111, 102,
  32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121,
  10, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 48, 93, 32, 45,
  110, 91, 48, 93, 32, 48, 44, 50, 53, 53, 32, 40, 48, 44, 50, 53,
  53, 41, 32, 45, 105, 110, 100, 101, 120, 91, 48, 93, 32, 91, 45, 49,
  93, 44, 49, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 97,
  32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 102, 99, 32, 58, 32,
  101, 113, 46, 32, 116, 111, 32, 39, 45, 102, 105, 108, 108, 95, 99, 111,
  108, 111, 114, 39, 46, 10, 102, 99, 32, 58, 10, 45, 118, 32, 45, 32,
  95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95,
  102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 32, 36, 42, 10, 35, 64,
  103, 109, 105, 99, 32, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 32,
  58, 32, 99, 111, 108, 49, 44, 46, 46, 46, 44, 99, 111, 108, 78, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 70, 105, 108, 108, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 119, 105,
  116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 99, 111, 108,
  111, 114, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113,
  46, 32, 116, 111, 32, 39, 45, 102, 99, 39, 41, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 32, 50,
  53, 53, 44, 48, 44, 50, 53, 53, 10, 102, 105, 108, 108, 95, 99, 111,
  108, 111, 114, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34,
  36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 36, 48, 32, 36, 42,
  10, 95, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 32, 58, 10, 45,
  101, 91, 48, 45, 45, 51, 93, 32, 34, 70, 105, 108, 108, 32, 105, 109,
  97, 103, 101, 34, 36, 95, 95, 115, 34, 32, 119, 105, 116, 104, 32, 99,
  111, 108, 111, 114, 32, 40, 36, 123, 94, 48, 125, 41, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 115,
  125, 32, 45, 115, 104, 91, 45, 49, 93, 32, 36, 62, 44, 36, 62, 32,
  45, 102, 91, 45, 49, 93, 32, 123, 97, 114, 103, 40, 49, 43, 36, 62,
  44, 36, 123, 94, 48, 125, 41, 125, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 100, 111, 110, 101, 10, 45, 110, 109, 32, 64, 123, 45, 49, 44,
  110, 125, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 103, 114, 97,
  100, 105, 101, 110, 116, 50, 114, 103, 98, 32, 58, 32, 95, 105, 115, 95,
  111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 61, 123, 32, 48, 32,
  124, 32, 49, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67,
  111, 109, 112, 117, 116, 101, 32, 82, 71, 66, 32, 114, 101, 112, 114, 101,
  115, 101, 110, 116, 97, 116, 105, 111, 110, 32, 111, 102, 32, 50, 100, 32,
  103, 114, 97, 100, 105, 101, 110, 116, 32, 111, 102, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 58, 32, 39, 105, 115, 95, 111, 114, 105, 101, 110, 116, 97,
  116, 105, 111, 110, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45,
  103, 114, 97, 100, 105, 101, 110, 116, 50, 114, 103, 98, 32, 48, 32, 45,
  101, 113, 117, 97, 108, 105, 122, 101, 91, 45, 49, 93, 10, 103, 114, 97,
  100, 105, 101, 110, 116, 50, 114, 103, 98, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 105, 115, 98, 111, 111, 108, 40, 36, 123, 49, 61, 48,
  125, 41, 34, 10, 45, 97, 114, 103, 32, 49, 43, 33, 36, 49, 44, 34,
  111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 32, 34, 44, 34, 34,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116,
  101, 32, 82, 71, 66, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 97,
  116, 105, 111, 110, 32, 111, 102, 32, 50, 100, 32, 103, 114, 97, 100, 105,
  101, 110, 116, 32, 34, 64, 123, 125, 34, 111, 102, 32, 105, 109, 97, 103,
  101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 110, 111, 114, 109,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 45, 105, 102, 32, 36, 49, 32, 45, 103, 114, 97, 100, 105,
  101, 110, 116, 95, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 32,
  50, 32, 45, 101, 108, 115, 101, 32, 45, 103, 32, 120, 121, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 97, 32, 99, 32, 45, 100, 105, 114, 101, 99,
  116, 105, 111, 110, 50, 114, 103, 98, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 104, 115, 105, 50, 114, 103, 98, 32, 58, 32, 40, 43, 41, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32,
  102, 114, 111, 109, 32, 72, 83, 73, 32, 116, 111, 32, 82, 71, 66, 32,
  99, 111, 108, 111, 114, 98, 97, 115, 101, 115, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 104, 115, 105, 56, 50, 114, 103, 98, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 102, 114, 111,
  109, 32, 72, 83, 73, 56, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111,
  108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 10, 104, 115, 105, 56, 50,
  114, 103, 98, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67,
  111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102,
  114, 111, 109, 32, 72, 83, 73, 56, 32, 116, 111, 32, 82, 71, 66, 32,
  99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 95, 104, 115, 120, 56, 50, 114, 103, 98, 32, 45, 104,
  115, 105, 50, 114, 103, 98, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109,
  105, 99, 32, 104, 115, 108, 50, 114, 103, 98, 32, 58, 32, 40, 43, 41,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114,
  116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 32, 102, 114, 111, 109, 32, 72, 83, 76, 32, 116, 111, 32, 82, 71,
  66, 32, 99, 111, 108, 111, 114, 98, 97, 115, 101, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 104, 115, 108, 56, 50, 114, 103, 98, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 102,
  114, 111, 109, 32, 72, 83, 76, 56, 32, 116, 111, 32, 82, 71, 66, 32,
  99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 10, 104, 115, 108,
  56, 50, 114, 103, 98, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63,
  32, 102, 114, 111, 109, 32, 72, 83, 76, 56, 32, 116, 111, 32, 82, 71,
  66, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 95, 104, 115, 120, 56, 50, 114, 103, 98, 32,
  45, 104, 115, 108, 50, 114, 103, 98, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 104, 115, 118, 50, 114, 103, 98, 32, 58, 32, 40,
  43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118,
  101, 114, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 32, 102, 114, 111, 109, 32, 72, 83, 86, 32, 116, 111, 32,
  82, 71, 66, 32, 99, 111, 108, 111, 114, 98, 97, 115, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 40, 48, 44, 51, 54,
  48, 59, 48, 44, 51, 54, 48, 94, 48, 44, 48, 59, 49, 44, 49, 94,
  49, 44, 49, 59, 49, 44, 49, 41, 32, 45, 114, 101, 115, 105, 122, 101,
  32, 52, 48, 48, 44, 52, 48, 48, 44, 49, 44, 51, 44, 51, 32, 45,
  104, 115, 118, 50, 114, 103, 98, 10, 35, 64, 103, 109, 105, 99, 32, 104,
  115, 118, 56, 50, 114, 103, 98, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 32, 102, 114, 111, 109, 32, 72, 83,
  86, 56, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111, 108, 111, 114, 32,
  98, 97, 115, 101, 115, 46, 10, 104, 115, 118, 56, 50, 114, 103, 98, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101,
  114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114, 111, 109, 32,
  72, 83, 86, 56, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111, 108, 111,
  114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  95, 104, 115, 120, 56, 50, 114, 103, 98, 32, 45, 104, 115, 118, 50, 114,
  103, 98, 32, 45, 118, 32, 43, 10, 95, 104, 115, 120, 56, 50, 114, 103,
  98, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45,
  115, 104, 91, 36, 62, 93, 32, 48, 44, 48, 32, 45, 47, 91, 45, 49,
  93, 32, 48, 46, 55, 48, 56, 51, 51, 51, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 115, 104, 91, 36, 62, 93, 32, 49, 44, 50, 32, 45,
  47, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 108, 97, 98, 50, 108, 99, 104, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 102, 114, 111,
  109, 32, 76, 97, 98, 32, 116, 111, 32, 76, 99, 104, 32, 99, 111, 108,
  111, 114, 32, 98, 97, 115, 101, 115, 46, 10, 108, 97, 98, 50, 108, 99,
  104, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110,
  118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114, 111,
  109, 32, 76, 97, 98, 32, 116, 111, 32, 76, 99, 104, 32, 99, 111, 108,
  111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 44, 51, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 115, 32, 99, 32, 45, 99, 111, 109, 112,
  108, 101, 120, 50, 112, 111, 108, 97, 114, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 108, 97,
  98, 50, 114, 103, 98, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 102, 114, 111,
  109, 32, 76, 97, 98, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111, 108,
  111, 114, 98, 97, 115, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 40, 53, 48, 44, 53, 48, 59, 53, 48, 44, 53, 48,
  94, 45, 51, 44, 51, 59, 45, 51, 44, 51, 94, 45, 51, 44, 45, 51,
  59, 51, 44, 51, 41, 32, 45, 114, 101, 115, 105, 122, 101, 32, 52, 48,
  48, 44, 52, 48, 48, 44, 49, 44, 51, 44, 51, 32, 45, 108, 97, 98,
  50, 114, 103, 98, 10, 35, 64, 103, 109, 105, 99, 32, 108, 97, 98, 56,
  50, 114, 103, 98, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111,
  110, 118, 101, 114, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 32, 102, 114, 111, 109, 32, 76, 97, 98, 56, 32,
  116, 111, 32, 82, 71, 66, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115,
  101, 115, 46, 10, 108, 97, 98, 56, 50, 114, 103, 98, 32, 58, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32,
  105, 109, 97, 103, 101, 36, 63, 32, 102, 114, 111, 109, 32, 76, 97, 98,
  56, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111, 108, 111, 114, 32, 98,
  97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 10, 45, 115, 104, 91, 36, 62, 93, 32, 48,
  44, 48, 32, 45, 47, 91, 45, 49, 93, 32, 50, 46, 53, 53, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 36, 62, 93, 32, 49,
  44, 49, 32, 45, 47, 91, 45, 49, 93, 32, 49, 46, 50, 55, 53, 32,
  45, 45, 91, 45, 49, 93, 32, 49, 48, 48, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 115, 104, 91, 36, 62, 93, 32, 50, 44, 50, 32, 45,
  47, 91, 45, 49, 93, 32, 49, 46, 49, 53, 57, 48, 57, 32, 45, 45,
  91, 45, 49, 93, 32, 49, 49, 48, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 100, 111, 110, 101, 32, 45, 108, 97, 98, 50, 114, 103, 98, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 108, 99, 104, 50,
  108, 97, 98, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110,
  118, 101, 114, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 32, 102, 114, 111, 109, 32, 76, 99, 104, 32, 116, 111,
  32, 76, 97, 98, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115,
  46, 10, 108, 99, 104, 50, 108, 97, 98, 32, 58, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97,
  103, 101, 36, 63, 32, 102, 114, 111, 109, 32, 76, 99, 104, 32, 116, 111,
  32, 76, 97, 98, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 32, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 51, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115,
  32, 99, 32, 45, 112, 111, 108, 97, 114, 50, 99, 111, 109, 112, 108, 101,
  120, 91, 45, 50, 44, 45, 49, 93, 32, 45, 97, 32, 99, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 108, 99, 104, 50, 114, 103, 98, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 102,
  114, 111, 109, 32, 76, 99, 104, 32, 116, 111, 32, 82, 71, 66, 32, 99,
  111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 10, 108, 99, 104, 50,
  114, 103, 98, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67,
  111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102,
  114, 111, 109, 32, 76, 99, 104, 32, 116, 111, 32, 82, 71, 66, 32, 99,
  111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 108, 99, 104, 50, 108, 97, 98, 32, 45, 108, 97, 98, 50,
  114, 103, 98, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  108, 99, 104, 56, 50, 114, 103, 98, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 102, 114, 111, 109, 32, 76,
  99, 104, 56, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111, 108, 111, 114,
  32, 98, 97, 115, 101, 115, 46, 10, 108, 99, 104, 56, 50, 114, 103, 98,
  32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118,
  101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114, 111, 109,
  32, 76, 99, 104, 56, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111, 108,
  111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 115, 104, 91, 36,
  62, 93, 32, 48, 44, 48, 32, 45, 47, 91, 45, 49, 93, 32, 50, 46,
  53, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 36,
  62, 93, 32, 49, 44, 49, 32, 45, 47, 91, 45, 49, 93, 32, 49, 46,
  56, 56, 56, 56, 57, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115,
  104, 91, 36, 62, 93, 32, 50, 44, 50, 32, 45, 47, 91, 45, 49, 93,
  32, 52, 48, 46, 53, 56, 52, 53, 32, 45, 45, 91, 45, 49, 93, 32,
  51, 46, 49, 52, 49, 53, 57, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 100, 111, 110, 101, 32, 45, 108, 99, 104, 50, 114, 103, 98, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 108, 117, 109, 105, 110,
  97, 110, 99, 101, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111,
  109, 112, 117, 116, 101, 32, 108, 117, 109, 105, 110, 97, 110, 99, 101, 32,
  111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 115, 82, 71, 66,
  32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45,
  108, 117, 109, 105, 110, 97, 110, 99, 101, 10, 108, 117, 109, 105, 110, 97,
  110, 99, 101, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67,
  111, 109, 112, 117, 116, 101, 32, 108, 117, 109, 105, 110, 97, 110, 99, 101,
  32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105,
  116, 121, 32, 45, 115, 114, 103, 98, 50, 114, 103, 98, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45,
  105, 102, 32, 123, 115, 61, 61, 51, 125, 32, 45, 115, 104, 32, 48, 44,
  48, 32, 45, 115, 104, 91, 48, 93, 32, 49, 44, 49, 32, 45, 115, 104,
  91, 48, 93, 32, 50, 44, 50, 32, 45, 42, 91, 49, 93, 32, 48, 46,
  50, 57, 57, 32, 45, 42, 91, 50, 93, 32, 48, 46, 53, 56, 55, 32,
  45, 42, 91, 51, 93, 32, 48, 46, 49, 49, 52, 32, 45, 43, 91, 49,
  45, 51, 93, 32, 45, 114, 109, 91, 49, 93, 10, 45, 101, 108, 105, 102,
  32, 123, 115, 33, 61, 49, 125, 32, 45, 110, 111, 114, 109, 32, 45, 110,
  32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 32, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 48, 32, 45, 114, 103, 98, 50, 115, 114, 103, 98, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 109, 105, 120, 95,
  114, 103, 98, 32, 58, 32, 97, 49, 49, 44, 97, 49, 50, 44, 97, 49,
  51, 44, 97, 50, 49, 44, 97, 50, 50, 44, 97, 50, 51, 44, 97, 51,
  49, 44, 97, 51, 50, 44, 97, 51, 51, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 65, 112, 112, 108, 121, 32, 51, 120, 51, 32, 115, 112, 101,
  99, 105, 102, 105, 101, 100, 32, 109, 97, 116, 114, 105, 120, 32, 116, 111,
  32, 82, 71, 66, 32, 99, 111, 108, 111, 114, 115, 32, 111, 102, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116,
  32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 97, 49, 49, 61, 49, 39,
  44, 32, 39, 97, 49, 50, 61, 97, 49, 51, 61, 97, 50, 49, 61, 48,
  39, 44, 32, 39, 97, 50, 50, 61, 49, 39, 44, 32, 39, 97, 50, 51,
  61, 97, 51, 49, 61, 97, 51, 50, 61, 48, 39, 32, 97, 110, 100, 32,
  39, 97, 51, 51, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45,
  109, 105, 120, 95, 114, 103, 98, 32, 48, 44, 49, 44, 48, 44, 49, 44,
  48, 44, 48, 44, 48, 44, 48, 44, 49, 10, 109, 105, 120, 95, 114, 103,
  98, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 125,
  44, 36, 123, 50, 61, 48, 125, 44, 36, 123, 51, 61, 48, 125, 44, 36,
  123, 52, 61, 48, 125, 44, 36, 123, 53, 61, 49, 125, 44, 36, 123, 54,
  61, 48, 125, 44, 36, 123, 55, 61, 48, 125, 44, 36, 123, 56, 61, 48,
  125, 44, 36, 123, 57, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 65, 112, 112, 108, 121, 32, 109, 97, 116, 114, 105, 120, 32, 91,
  32, 36, 49, 32, 36, 50, 32, 36, 51, 32, 59, 32, 36, 52, 32, 36,
  53, 32, 36, 54, 32, 59, 32, 36, 55, 32, 36, 56, 32, 36, 57, 32,
  93, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111, 108, 111, 114, 115, 32,
  111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 51, 44, 48, 44, 50, 32, 45, 109, 105, 120, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 32, 40, 36, 49, 44, 36, 50, 44, 36, 51, 59, 36,
  52, 44, 36, 53, 44, 36, 54, 59, 36, 55, 44, 36, 56, 44, 36, 57,
  41, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 112, 115,
  101, 117, 100, 111, 103, 114, 97, 121, 32, 58, 32, 95, 109, 97, 120, 95,
  105, 110, 99, 114, 101, 109, 101, 110, 116, 62, 61, 48, 44, 95, 74, 78,
  68, 95, 116, 104, 114, 101, 115, 104, 111, 108, 100, 62, 61, 48, 44, 95,
  98, 105, 116, 115, 95, 100, 101, 112, 116, 104, 62, 48, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 71, 101, 110, 101, 114, 97, 116, 101, 32, 112,
  115, 101, 117, 100, 111, 103, 114, 97, 121, 32, 99, 111, 108, 111, 114, 109,
  97, 112, 32, 119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101,
  100, 32, 105, 110, 99, 114, 101, 109, 101, 110, 116, 32, 97, 110, 100, 32,
  112, 101, 114, 99, 101, 112, 116, 117, 97, 108, 32, 116, 104, 114, 101, 115,
  104, 111, 108, 100, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73,
  102, 32, 39, 74, 78, 68, 95, 116, 104, 114, 101, 115, 104, 111, 108, 100,
  39, 32, 105, 115, 32, 48, 44, 32, 110, 111, 32, 112, 101, 114, 99, 101,
  112, 116, 117, 97, 108, 32, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116,
  115, 32, 97, 114, 101, 32, 97, 112, 112, 108, 105, 101, 100, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32,
  118, 97, 108, 117, 101, 115, 58, 32, 39, 109, 97, 120, 95, 105, 110, 99,
  114, 101, 109, 101, 110, 116, 61, 53, 39, 44, 32, 39, 74, 78, 68, 95,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 61, 50, 46, 51, 39, 32, 97,
  110, 100, 32, 39, 98, 105, 116, 115, 95, 100, 101, 112, 116, 104, 61, 56,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 112,
  115, 101, 117, 100, 111, 103, 114, 97, 121, 32, 53, 10, 112, 115, 101, 117,
  100, 111, 103, 114, 97, 121, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 53, 125, 41, 32, 38,
  38, 32, 36, 49, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 50,
  46, 51, 125, 62, 61, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40,
  36, 123, 51, 61, 56, 125, 41, 32, 38, 38, 32, 36, 51, 62, 48, 34,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 71, 101, 110, 101, 114, 97,
  116, 101, 32, 112, 115, 101, 117, 100, 111, 103, 114, 97, 121, 32, 99, 111,
  108, 111, 114, 109, 97, 112, 32, 119, 105, 116, 104, 32, 105, 110, 99, 114,
  101, 109, 101, 110, 116, 32, 36, 49, 44, 32, 74, 78, 68, 32, 116, 104,
  114, 101, 115, 104, 111, 108, 100, 32, 36, 50, 32, 97, 110, 100, 32, 36,
  51, 32, 98, 105, 116, 115, 32, 100, 101, 112, 116, 104, 46, 34, 10, 45,
  118, 32, 45, 10, 123, 114, 111, 117, 110, 100, 40, 50, 94, 36, 51, 41,
  125, 44, 49, 44, 49, 44, 51, 44, 39, 120, 39, 10, 45, 105, 102, 32,
  123, 33, 36, 49, 125, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 32, 45, 118, 32, 43, 32, 45, 114, 101, 116, 117, 114, 110, 32,
  45, 101, 110, 100, 105, 102, 10, 123, 36, 49, 43, 49, 125, 44, 123, 36,
  49, 43, 49, 125, 44, 123, 36, 49, 43, 49, 125, 44, 49, 44, 39, 120,
  39, 32, 45, 45, 102, 91, 45, 49, 93, 32, 39, 121, 39, 32, 45, 45,
  102, 91, 45, 49, 93, 32, 39, 122, 39, 32, 45, 97, 91, 45, 51, 45,
  45, 49, 93, 32, 99, 32, 45, 114, 91, 45, 49, 93, 32, 123, 119, 42,
  104, 42, 100, 125, 44, 49, 44, 49, 44, 51, 44, 45, 49, 10, 45, 102,
  91, 45, 49, 93, 32, 39, 82, 61, 105, 40, 120, 44, 48, 44, 48, 44,
  48, 41, 59, 71, 61, 105, 40, 120, 44, 48, 44, 48, 44, 49, 41, 59,
  66, 61, 105, 40, 120, 44, 48, 44, 48, 44, 50, 41, 59, 105, 102, 40,
  109, 105, 110, 40, 82, 44, 71, 44, 66, 41, 44, 45, 49, 44, 105, 41,
  39, 10, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 49, 93, 32, 99,
  120, 121, 122, 32, 45, 100, 105, 115, 99, 97, 114, 100, 91, 45, 49, 93,
  32, 45, 49, 32, 45, 114, 91, 45, 49, 93, 32, 51, 44, 123, 104, 47,
  51, 125, 44, 49, 44, 49, 44, 45, 49, 32, 45, 112, 101, 114, 109, 117,
  116, 101, 91, 45, 49, 93, 32, 121, 122, 99, 120, 10, 45, 114, 91, 45,
  50, 93, 32, 123, 119, 42, 49, 48, 48, 125, 37, 32, 45, 114, 91, 45,
  49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 50, 32, 45, 43, 91, 45,
  50, 44, 45, 49, 93, 10, 45, 102, 91, 45, 49, 93, 32, 39, 82, 61,
  105, 40, 120, 44, 48, 44, 48, 44, 48, 41, 59, 71, 61, 105, 40, 120,
  44, 48, 44, 48, 44, 49, 41, 59, 66, 61, 105, 40, 120, 44, 48, 44,
  48, 44, 50, 41, 59, 105, 102, 40, 109, 97, 120, 40, 82, 44, 71, 44,
  66, 41, 62, 50, 94, 36, 51, 45, 49, 44, 45, 49, 44, 105, 41, 39,
  10, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 49, 93, 32, 99, 120,
  121, 122, 32, 45, 100, 105, 115, 99, 97, 114, 100, 91, 45, 49, 93, 32,
  45, 49, 32, 45, 114, 91, 45, 49, 93, 32, 51, 44, 123, 104, 47, 51,
  125, 44, 49, 44, 49, 44, 45, 49, 32, 45, 112, 101, 114, 109, 117, 116,
  101, 91, 45, 49, 93, 32, 121, 122, 99, 120, 10, 45, 110, 91, 45, 49,
  93, 32, 48, 44, 50, 53, 53, 10, 45, 45, 115, 114, 103, 98, 50, 114,
  103, 98, 91, 45, 49, 93, 32, 45, 114, 103, 98, 50, 108, 97, 98, 91,
  45, 49, 93, 32, 45, 114, 118, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 32, 45, 115, 111, 114, 116,
  91, 45, 49, 93, 32, 43, 44, 120, 10, 45, 105, 102, 32, 123, 33, 36,
  50, 125, 32, 45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 49, 10, 45,
  101, 108, 115, 101, 10, 45, 115, 91, 45, 49, 93, 32, 121, 32, 45, 114,
  118, 91, 45, 50, 44, 45, 49, 93, 32, 91, 45, 49, 93, 32, 45, 115,
  104, 91, 45, 49, 93, 32, 49, 44, 50, 32, 45, 102, 91, 45, 49, 93,
  32, 48, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 45, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 110, 111, 114, 109, 91, 45, 49, 93, 10, 45,
  108, 101, 91, 45, 49, 93, 32, 36, 50, 32, 45, 42, 91, 45, 49, 93,
  32, 39, 120, 43, 49, 39, 32, 45, 100, 105, 115, 99, 97, 114, 100, 91,
  45, 49, 93, 32, 48, 32, 45, 45, 91, 45, 49, 93, 32, 49, 32, 45,
  109, 97, 112, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 114, 109,
  91, 45, 50, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 49, 48, 48,
  48, 48, 10, 45, 45, 115, 114, 103, 98, 50, 114, 103, 98, 91, 45, 49,
  93, 32, 45, 114, 103, 98, 50, 108, 97, 98, 91, 45, 49, 93, 32, 45,
  45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 48, 44, 123, 49, 45,
  50, 42, 40, 36, 62, 37, 50, 41, 125, 44, 48, 44, 48, 44, 49, 32,
  45, 45, 91, 45, 50, 44, 45, 49, 93, 32, 45, 110, 111, 114, 109, 91,
  45, 49, 93, 10, 45, 108, 101, 91, 45, 49, 93, 32, 36, 50, 10, 45,
  105, 102, 32, 123, 105, 109, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 98, 114, 101, 97, 107, 32, 45, 101, 110, 100, 105, 102, 10, 45, 42,
  91, 45, 49, 93, 32, 39, 121, 43, 49, 39, 32, 45, 100, 105, 115, 99,
  97, 114, 100, 91, 45, 49, 93, 32, 48, 32, 45, 45, 91, 45, 49, 93,
  32, 49, 32, 45, 109, 97, 112, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 100, 111, 110, 101, 10, 45,
  116, 114, 97, 110, 115, 112, 111, 115, 101, 91, 45, 49, 93, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 32, 58,
  32, 116, 111, 108, 101, 114, 97, 110, 99, 101, 91, 37, 93, 62, 61, 48,
  44, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 91, 37, 93, 62, 61,
  48, 44, 115, 114, 99, 49, 44, 115, 114, 99, 50, 44, 46, 46, 46, 44,
  100, 101, 115, 116, 49, 44, 100, 101, 115, 116, 50, 44, 46, 46, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 112, 108, 97, 99, 101,
  32, 112, 105, 120, 101, 108, 115, 32, 102, 114, 111, 109, 47, 116, 111, 32,
  115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 99, 111, 108, 111, 114, 115,
  32, 105, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 114, 101, 112, 108,
  97, 99, 101, 95, 99, 111, 108, 111, 114, 32, 52, 48, 44, 51, 44, 50,
  48, 52, 44, 49, 53, 51, 44, 49, 49, 48, 44, 50, 53, 53, 44, 48,
  44, 48, 10, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48,
  32, 38, 38, 32, 36, 50, 62, 61, 48, 34, 10, 45, 118, 32, 45, 32,
  45, 108, 91, 93, 32, 40, 36, 123, 51, 45, 45, 49, 125, 41, 32, 45,
  121, 32, 99, 32, 45, 115, 32, 99, 44, 50, 32, 99, 111, 108, 49, 61,
  64, 48, 32, 99, 111, 108, 50, 61, 64, 49, 32, 45, 114, 109, 32, 45,
  101, 110, 100, 108, 32, 45, 118, 32, 43, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 82, 101, 112, 108, 97, 99, 101, 32, 99, 111, 108, 111, 114,
  32, 40, 34, 36, 99, 111, 108, 49, 34, 41, 32, 98, 121, 32, 99, 111,
  108, 111, 114, 32, 40, 34, 36, 99, 111, 108, 50, 34, 41, 32, 105, 110,
  32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 116,
  111, 108, 101, 114, 97, 110, 99, 101, 32, 36, 49, 32, 97, 110, 100, 32,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 50, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 49, 44, 49, 44, 49, 44, 49, 48, 48,
  37, 44, 36, 99, 111, 108, 49, 32, 45, 114, 91, 49, 93, 32, 91, 48,
  93, 10, 45, 105, 102, 32, 36, 49, 32, 45, 45, 91, 49, 93, 32, 91,
  48, 93, 32, 45, 110, 111, 114, 109, 91, 49, 93, 32, 45, 108, 101, 91,
  49, 93, 32, 36, 49, 32, 45, 101, 108, 115, 101, 32, 45, 61, 61, 91,
  49, 93, 32, 91, 48, 93, 32, 45, 108, 91, 49, 93, 32, 45, 115, 32,
  99, 32, 45, 97, 110, 100, 32, 45, 101, 110, 100, 108, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 98, 91, 49, 93, 32, 36, 50, 10, 49, 44, 49,
  44, 49, 44, 64, 123, 48, 44, 115, 125, 44, 36, 99, 111, 108, 50, 32,
  45, 114, 91, 50, 93, 32, 91, 48, 93, 32, 45, 106, 91, 48, 93, 32,
  91, 50, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 49,
  93, 32, 45, 107, 91, 48, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  114, 103, 98, 50, 98, 97, 121, 101, 114, 32, 58, 32, 95, 115, 116, 97,
  114, 116, 95, 112, 97, 116, 116, 101, 114, 110, 61, 48, 44, 95, 99, 111,
  108, 111, 114, 95, 103, 114, 105, 100, 61, 48, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 84, 114, 97, 110, 115, 102, 111, 114, 109, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 99, 111, 108, 111, 114, 32, 105, 109, 97,
  103, 101, 115, 32, 116, 111, 32, 82, 71, 66, 45, 66, 97, 121, 101, 114,
  32, 115, 97, 109, 112, 108, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108,
  116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 115, 116, 97, 114, 116,
  95, 112, 97, 116, 116, 101, 114, 110, 61, 48, 39, 32, 97, 110, 100, 32,
  39, 99, 111, 108, 111, 114, 95, 103, 114, 105, 100, 61, 48, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 45, 114, 103, 98, 50, 98, 97, 121, 101, 114,
  32, 48, 10, 114, 103, 98, 50, 98, 97, 121, 101, 114, 32, 58, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 125, 44, 36, 123, 50, 61,
  48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 84, 114, 97, 110,
  115, 102, 111, 114, 109, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 111,
  32, 97, 32, 82, 71, 66, 45, 66, 97, 121, 101, 114, 32, 34, 64, 123,
  45, 97, 114, 103, 92, 32, 49, 43, 33, 36, 50, 44, 99, 111, 108, 111,
  114, 44, 109, 111, 110, 111, 99, 104, 114, 111, 109, 101, 125, 34, 32, 103,
  114, 105, 100, 44, 32, 115, 116, 97, 114, 116, 105, 110, 103, 32, 102, 114,
  111, 109, 32, 112, 97, 116, 116, 101, 114, 110, 32, 39, 36, 49, 39, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 95, 114, 103, 98, 50, 98, 97, 121, 101, 114, 36, 49, 32, 45,
  114, 91, 49, 93, 32, 91, 48, 93, 44, 48, 44, 50, 32, 45, 42, 32,
  45, 105, 102, 32, 123, 33, 36, 50, 125, 32, 45, 115, 32, 99, 32, 45,
  43, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 95, 114, 103, 98, 50, 98,
  97, 121, 101, 114, 48, 32, 58, 32, 40, 49, 44, 48, 59, 48, 44, 48,
  94, 48, 44, 49, 59, 49, 44, 48, 94, 48, 44, 48, 59, 48, 44, 49,
  41, 10, 95, 114, 103, 98, 50, 98, 97, 121, 101, 114, 49, 32, 58, 32,
  40, 48, 44, 48, 59, 48, 44, 49, 94, 48, 44, 49, 59, 49, 44, 48,
  94, 49, 44, 48, 59, 48, 44, 48, 41, 10, 95, 114, 103, 98, 50, 98,
  97, 121, 101, 114, 50, 32, 58, 32, 40, 48, 44, 48, 59, 49, 44, 48,
  94, 49, 44, 48, 59, 48, 44, 49, 94, 48, 44, 49, 59, 48, 44, 48,
  41, 10, 95, 114, 103, 98, 50, 98, 97, 121, 101, 114, 51, 32, 58, 32,
  40, 48, 44, 49, 59, 48, 44, 48, 94, 49, 44, 48, 59, 48, 44, 49,
  94, 48, 44, 48, 59, 49, 44, 48, 41, 10, 35, 64, 103, 109, 105, 99,
  32, 114, 103, 98, 50, 99, 109, 121, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 102, 114, 111, 109, 32, 82,
  71, 66, 32, 116, 111, 32, 67, 77, 89, 32, 99, 111, 108, 111, 114, 98,
  97, 115, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114, 103, 98, 50,
  99, 109, 121, 32, 45, 115, 112, 108, 105, 116, 32, 99, 10, 114, 103, 98,
  50, 99, 109, 121, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  102, 114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 67, 77, 89, 32,
  99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 99, 32, 48, 44,
  50, 53, 53, 32, 45, 42, 32, 45, 49, 32, 45, 43, 32, 50, 53, 53,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 114, 103, 98,
  50, 99, 109, 121, 107, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67,
  111, 110, 118, 101, 114, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 32, 102, 114, 111, 109, 32, 82, 71, 66, 32,
  116, 111, 32, 67, 77, 89, 75, 32, 99, 111, 108, 111, 114, 98, 97, 115,
  101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114, 103, 98, 50, 99, 109,
  121, 107, 32, 45, 115, 112, 108, 105, 116, 32, 99, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 114, 103, 98, 50, 99, 109, 121, 107, 32, 45, 115, 112, 108, 105,
  116, 32, 99, 32, 45, 102, 105, 108, 108, 91, 51, 93, 32, 48, 32, 45,
  97, 112, 112, 101, 110, 100, 32, 99, 32, 45, 99, 109, 121, 107, 50, 114,
  103, 98, 10, 114, 103, 98, 50, 99, 109, 121, 107, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 102, 114, 111, 109, 32, 82, 71, 66, 32,
  116, 111, 32, 67, 77, 89, 75, 32, 99, 111, 108, 111, 114, 32, 98, 97,
  115, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 103, 98, 50,
  99, 109, 121, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 115, 32, 99, 32, 45, 45, 109, 105, 110,
  32, 45, 45, 91, 48, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 45,
  47, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 45, 91, 45, 49, 93,
  32, 49, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 45, 101,
  113, 91, 45, 49, 93, 32, 48, 32, 45, 43, 91, 45, 50, 44, 45, 49,
  93, 10, 45, 47, 91, 48, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 114, 103, 98, 50, 104, 115, 105, 32, 58, 32, 40, 43,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101,
  114, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 32, 102, 114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 72,
  83, 73, 32, 99, 111, 108, 111, 114, 98, 97, 115, 101, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 114, 103, 98, 50, 104, 115, 105, 32, 45, 115, 112,
  108, 105, 116, 32, 99, 10, 35, 64, 103, 109, 105, 99, 32, 114, 103, 98,
  50, 104, 115, 105, 56, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67,
  111, 110, 118, 101, 114, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 32, 102, 114, 111, 109, 32, 82, 71, 66, 32,
  116, 111, 32, 72, 83, 73, 56, 32, 99, 111, 108, 111, 114, 32, 98, 97,
  115, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114, 103, 98, 50, 104,
  115, 105, 56, 32, 45, 115, 112, 108, 105, 116, 32, 99, 10, 114, 103, 98,
  50, 104, 115, 105, 56, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63,
  32, 102, 114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 72, 83, 73,
  56, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 103, 98, 50, 104, 115, 105, 32, 45, 95,
  114, 103, 98, 50, 104, 115, 120, 56, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 114, 103, 98, 50, 104, 115, 108, 32, 58, 32, 40,
  43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118,
  101, 114, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 32, 102, 114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32,
  72, 83, 76, 32, 99, 111, 108, 111, 114, 98, 97, 115, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 114, 103, 98, 50, 104, 115, 108, 32, 45, 115,
  112, 108, 105, 116, 32, 99, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114, 103, 98,
  50, 104, 115, 108, 32, 45, 45, 115, 112, 108, 105, 116, 32, 99, 32, 45,
  97, 100, 100, 91, 45, 51, 93, 32, 49, 48, 48, 32, 45, 109, 111, 100,
  91, 45, 51, 93, 32, 51, 54, 48, 32, 45, 97, 112, 112, 101, 110, 100,
  91, 45, 51, 45, 45, 49, 93, 32, 99, 32, 45, 104, 115, 108, 50, 114,
  103, 98, 10, 35, 64, 103, 109, 105, 99, 32, 114, 103, 98, 50, 104, 115,
  108, 56, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118,
  101, 114, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 32, 102, 114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32,
  72, 83, 76, 56, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 114, 103, 98, 50, 104, 115, 108, 56,
  32, 45, 115, 112, 108, 105, 116, 32, 99, 10, 114, 103, 98, 50, 104, 115,
  108, 56, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111,
  110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114,
  111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 72, 83, 76, 56, 32, 99,
  111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 103, 98, 50, 104, 115, 108, 32, 45, 95, 114, 103, 98,
  50, 104, 115, 120, 56, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 114, 103, 98, 50, 104, 115, 118, 32, 58, 32, 40, 43, 41, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  32, 102, 114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 72, 83, 86,
  32, 99, 111, 108, 111, 114, 98, 97, 115, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 114, 103, 98, 50, 104, 115, 118, 32, 45, 115, 112, 108, 105,
  116, 32, 99, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114, 103, 98, 50, 104, 115,
  118, 32, 45, 45, 115, 112, 108, 105, 116, 32, 99, 32, 45, 97, 100, 100,
  91, 45, 50, 93, 32, 48, 46, 51, 32, 45, 99, 117, 116, 91, 45, 50,
  93, 32, 48, 44, 49, 32, 45, 97, 112, 112, 101, 110, 100, 91, 45, 51,
  45, 45, 49, 93, 32, 99, 32, 45, 104, 115, 118, 50, 114, 103, 98, 10,
  35, 64, 103, 109, 105, 99, 32, 114, 103, 98, 50, 104, 115, 118, 56, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  32, 102, 114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 72, 83, 86,
  56, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 114, 103, 98, 50, 104, 115, 118, 56, 32, 45, 115,
  112, 108, 105, 116, 32, 99, 10, 114, 103, 98, 50, 104, 115, 118, 56, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101,
  114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114, 111, 109, 32,
  82, 71, 66, 32, 116, 111, 32, 72, 83, 86, 56, 32, 99, 111, 108, 111,
  114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 103, 98, 50, 104, 115, 118, 32, 45, 95, 114, 103, 98, 50, 104, 115,
  120, 56, 32, 45, 118, 32, 43, 10, 95, 114, 103, 98, 50, 104, 115, 120,
  56, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45,
  115, 104, 91, 36, 62, 93, 32, 48, 44, 48, 32, 45, 42, 91, 45, 49,
  93, 32, 48, 46, 55, 48, 56, 51, 51, 51, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 115, 104, 91, 36, 62, 93, 32, 49, 44, 50, 32, 45,
  42, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 100, 111, 110, 101, 10, 35, 64, 103, 109, 105, 99, 32, 114,
  103, 98, 50, 108, 97, 98, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 102, 114,
  111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 76, 97, 98, 32, 99, 111,
  108, 111, 114, 98, 97, 115, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  114, 103, 98, 50, 108, 97, 98, 32, 45, 115, 112, 108, 105, 116, 32, 99,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 114, 103, 98, 50, 108, 97, 98, 32, 45,
  45, 115, 112, 108, 105, 116, 32, 99, 32, 45, 109, 117, 108, 91, 45, 50,
  44, 45, 49, 93, 32, 50, 46, 53, 32, 45, 97, 112, 112, 101, 110, 100,
  91, 45, 51, 45, 45, 49, 93, 32, 99, 32, 45, 108, 97, 98, 50, 114,
  103, 98, 10, 35, 64, 103, 109, 105, 99, 32, 114, 103, 98, 50, 108, 97,
  98, 56, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118,
  101, 114, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 32, 102, 114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32,
  76, 97, 98, 56, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 114, 103, 98, 50, 108, 97, 98, 56,
  32, 45, 115, 112, 108, 105, 116, 32, 99, 10, 114, 103, 98, 50, 108, 97,
  98, 56, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111,
  110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114,
  111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 76, 97, 98, 56, 32, 99,
  111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 103, 98, 50, 108, 97, 98, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 10, 45, 115, 104, 91, 36, 62, 93, 32, 48, 44,
  48, 32, 45, 42, 91, 45, 49, 93, 32, 50, 46, 53, 53, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 36, 62, 93, 32, 49, 44,
  49, 32, 45, 43, 91, 45, 49, 93, 32, 49, 48, 48, 32, 45, 42, 91,
  45, 49, 93, 32, 49, 46, 50, 55, 53, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 115, 104, 91, 36, 62, 93, 32, 50, 44, 50, 32, 45, 43,
  91, 45, 49, 93, 32, 49, 49, 48, 32, 45, 42, 91, 45, 49, 93, 32,
  49, 46, 49, 53, 57, 48, 57, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 114, 103, 98, 50, 108, 99, 104, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 102, 114, 111, 109, 32,
  82, 71, 66, 32, 116, 111, 32, 76, 99, 104, 32, 99, 111, 108, 111, 114,
  32, 98, 97, 115, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114, 103,
  98, 50, 108, 99, 104, 32, 45, 115, 112, 108, 105, 116, 32, 99, 10, 114,
  103, 98, 50, 108, 99, 104, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36,
  63, 32, 102, 114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 76, 99,
  104, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 103, 98, 50, 108, 97, 98, 32, 45, 108,
  97, 98, 50, 108, 99, 104, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109,
  105, 99, 32, 114, 103, 98, 50, 108, 99, 104, 56, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 102, 114, 111,
  109, 32, 82, 71, 66, 32, 116, 111, 32, 76, 99, 104, 56, 32, 99, 111,
  108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 114, 103, 98, 50, 108, 99, 104, 56, 32, 45, 115, 112, 108, 105, 116,
  32, 99, 10, 114, 103, 98, 50, 108, 99, 104, 56, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 102, 114, 111, 109, 32, 82, 71, 66, 32,
  116, 111, 32, 76, 99, 104, 56, 32, 99, 111, 108, 111, 114, 32, 98, 97,
  115, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 103, 98, 50,
  108, 99, 104, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45,
  115, 104, 91, 36, 62, 93, 32, 48, 44, 48, 32, 45, 42, 91, 45, 49,
  93, 32, 50, 46, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  115, 104, 91, 36, 62, 93, 32, 49, 44, 49, 32, 45, 42, 91, 45, 49,
  93, 32, 49, 46, 56, 56, 56, 56, 57, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 115, 104, 91, 36, 62, 93, 32, 50, 44, 50, 32, 45, 43,
  91, 45, 49, 93, 32, 51, 46, 49, 52, 49, 53, 57, 32, 45, 42, 91,
  45, 49, 93, 32, 52, 48, 46, 53, 56, 52, 53, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 114, 103, 98, 50, 108, 117, 118, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 102,
  114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 76, 85, 86, 32, 99,
  111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 114, 103, 98, 50, 108, 117, 118, 32, 45, 115, 112, 108, 105, 116,
  32, 99, 10, 114, 103, 98, 50, 108, 117, 118, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 102, 114, 111, 109, 32, 82, 71, 66, 32, 116,
  111, 32, 76, 85, 86, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101,
  115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 114, 103, 98,
  50, 120, 121, 122, 32, 45, 114, 103, 98, 50, 108, 97, 98, 91, 45, 50,
  93, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 50, 93, 32,
  48, 32, 45, 115, 91, 45, 49, 93, 32, 99, 10, 45, 42, 91, 45, 49,
  93, 32, 51, 32, 45, 45, 42, 91, 45, 50, 93, 32, 49, 53, 32, 45,
  43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 43, 91, 45, 49, 93, 32,
  91, 45, 51, 93, 32, 45, 43, 91, 45, 49, 93, 32, 49, 101, 45, 56,
  10, 45, 42, 91, 45, 51, 93, 32, 52, 32, 45, 42, 91, 45, 50, 93,
  32, 57, 32, 45, 47, 91, 45, 51, 44, 45, 50, 93, 32, 91, 45, 49,
  93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 45, 91, 45, 50, 93,
  32, 48, 46, 50, 48, 48, 57, 32, 45, 45, 91, 45, 49, 93, 32, 48,
  46, 52, 54, 49, 48, 10, 45, 45, 42, 91, 45, 51, 93, 32, 49, 51,
  32, 45, 42, 91, 45, 51, 93, 32, 91, 45, 49, 93, 32, 45, 42, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 114, 103, 98, 50, 115, 114, 103, 98, 32, 58, 32, 40,
  43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118,
  101, 114, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 32, 102, 114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32,
  115, 82, 71, 66, 32, 99, 111, 108, 111, 114, 98, 97, 115, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 114, 103, 98, 50, 120, 121, 122, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  32, 102, 114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 88, 89, 90,
  32, 99, 111, 108, 111, 114, 98, 97, 115, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 116, 104, 101, 32, 68, 54, 53, 32, 105, 108,
  108, 117, 109, 105, 110, 97, 110, 116, 32, 105, 115, 32, 117, 115, 101, 100,
  32, 97, 115, 32, 116, 104, 101, 32, 119, 104, 105, 116, 101, 32, 112, 111,
  105, 110, 116, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114, 103, 98, 50,
  120, 121, 122, 32, 45, 115, 112, 108, 105, 116, 32, 99, 10, 114, 103, 98,
  50, 120, 121, 122, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  102, 114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 88, 89, 90, 32,
  99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 47, 32, 50, 53, 53, 32, 45, 109, 105, 120, 95, 114,
  103, 98, 32, 48, 46, 52, 49, 50, 52, 53, 51, 44, 48, 46, 51, 53,
  55, 53, 56, 48, 44, 48, 46, 49, 56, 48, 52, 50, 51, 44, 48, 46,
  50, 49, 50, 54, 55, 49, 44, 48, 46, 55, 49, 53, 49, 54, 48, 44,
  48, 46, 48, 55, 50, 49, 54, 57, 44, 48, 46, 48, 49, 57, 51, 51,
  52, 44, 48, 46, 49, 49, 57, 49, 57, 51, 44, 48, 46, 57, 53, 48,
  50, 50, 55, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  114, 103, 98, 50, 120, 121, 122, 56, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 102, 114, 111, 109, 32, 82,
  71, 66, 32, 116, 111, 32, 88, 89, 90, 56, 32, 99, 111, 108, 111, 114,
  32, 98, 97, 115, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114, 103,
  98, 50, 120, 121, 122, 56, 32, 45, 115, 112, 108, 105, 116, 32, 99, 10,
  114, 103, 98, 50, 120, 121, 122, 56, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103,
  101, 36, 63, 32, 102, 114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32,
  88, 89, 90, 56, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 103, 98, 50, 120, 121, 122,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 115, 104, 91,
  36, 62, 93, 32, 48, 44, 48, 32, 45, 42, 91, 45, 49, 93, 32, 50,
  53, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 36,
  62, 93, 32, 49, 44, 49, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53,
  53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 36, 62,
  93, 32, 50, 44, 50, 32, 45, 42, 91, 45, 49, 93, 32, 50, 51, 49,
  46, 56, 49, 56, 50, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  114, 103, 98, 50, 121, 99, 98, 99, 114, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 102, 114, 111, 109, 32,
  82, 71, 66, 32, 116, 111, 32, 89, 67, 98, 67, 114, 32, 99, 111, 108,
  111, 114, 98, 97, 115, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114,
  103, 98, 50, 121, 99, 98, 99, 114, 32, 45, 115, 112, 108, 105, 116, 32,
  99, 10, 114, 103, 98, 50, 121, 99, 98, 99, 114, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 102, 114, 111, 109, 32, 82, 71, 66, 32,
  116, 111, 32, 89, 67, 98, 67, 114, 32, 99, 111, 108, 111, 114, 32, 98,
  97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 109, 105, 120,
  95, 114, 103, 98, 32, 54, 54, 44, 49, 50, 57, 44, 50, 53, 44, 45,
  51, 56, 44, 45, 55, 52, 44, 49, 49, 50, 44, 49, 49, 50, 44, 45,
  57, 52, 44, 45, 49, 56, 32, 45, 43, 32, 49, 50, 56, 32, 45, 47,
  32, 50, 53, 54, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 32, 45, 115, 104, 32, 48, 44, 48, 32, 45,
  43, 91, 45, 49, 93, 32, 49, 54, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 115, 104, 32, 49, 44, 50, 32, 45, 43, 91, 45, 49, 93, 32,
  49, 50, 56, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 114, 103, 98, 50, 121, 117, 118, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 102, 114, 111,
  109, 32, 82, 71, 66, 32, 116, 111, 32, 89, 85, 86, 32, 99, 111, 108,
  111, 114, 98, 97, 115, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114,
  103, 98, 50, 121, 117, 118, 32, 45, 115, 112, 108, 105, 116, 32, 99, 10,
  114, 103, 98, 50, 121, 117, 118, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101,
  36, 63, 32, 102, 114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 89,
  85, 86, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 47, 32, 50, 53, 53, 32, 45, 109, 105,
  120, 95, 114, 103, 98, 32, 48, 46, 50, 57, 57, 44, 48, 46, 53, 56,
  55, 44, 48, 46, 49, 49, 52, 44, 45, 48, 46, 49, 52, 55, 49, 51,
  44, 45, 48, 46, 50, 56, 56, 56, 54, 44, 48, 46, 52, 51, 54, 44,
  48, 46, 54, 49, 53, 44, 45, 48, 46, 53, 49, 52, 57, 56, 44, 45,
  48, 46, 49, 48, 48, 48, 49, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 114, 103, 98, 50, 121, 117, 118, 56, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 102, 114,
  111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 89, 85, 86, 56, 32, 99,
  111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 114, 103, 98, 50, 121, 117, 118, 56, 32, 45, 115, 112, 108, 105,
  116, 32, 99, 10, 114, 103, 98, 50, 121, 117, 118, 56, 32, 58, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32,
  105, 109, 97, 103, 101, 36, 63, 32, 102, 114, 111, 109, 32, 82, 71, 66,
  32, 116, 111, 32, 89, 85, 86, 56, 32, 99, 111, 108, 111, 114, 32, 98,
  97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 103, 98,
  50, 121, 117, 118, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10,
  45, 115, 104, 91, 36, 62, 93, 32, 48, 44, 48, 32, 45, 42, 91, 45,
  49, 93, 32, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  115, 104, 91, 36, 62, 93, 32, 49, 44, 49, 32, 45, 43, 91, 45, 49,
  93, 32, 48, 46, 52, 52, 32, 45, 42, 91, 45, 49, 93, 32, 50, 56,
  57, 46, 55, 55, 51, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115,
  104, 91, 36, 62, 93, 32, 50, 44, 50, 32, 45, 43, 91, 45, 49, 93,
  32, 48, 46, 54, 50, 32, 45, 42, 91, 45, 49, 93, 32, 50, 48, 53,
  46, 54, 52, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 114,
  101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 82, 101, 109, 111, 118, 101, 32, 111, 112,
  97, 99, 105, 116, 121, 32, 99, 104, 97, 110, 110, 101, 108, 32, 111, 102,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121,
  32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 109, 111,
  118, 101, 32, 111, 112, 97, 99, 105, 116, 121, 32, 99, 104, 97, 110, 110,
  101, 108, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 115, 61, 61, 50,
  125, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48, 10, 45, 101,
  108, 105, 102, 32, 123, 115, 61, 61, 52, 125, 32, 45, 99, 104, 97, 110,
  110, 101, 108, 115, 32, 48, 44, 50, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 110, 109, 32, 64, 123, 45, 49, 44, 110, 125, 44, 49, 32, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 115, 101, 108, 101, 99, 116, 95, 99, 111, 108,
  111, 114, 32, 58, 32, 116, 111, 108, 101, 114, 97, 110, 99, 101, 91, 37,
  93, 62, 61, 48, 44, 99, 111, 108, 49, 44, 46, 46, 44, 99, 111, 108,
  78, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 101, 108, 101, 99,
  116, 32, 112, 105, 120, 101, 108, 115, 32, 119, 105, 116, 104, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 99, 111, 108, 111, 114, 32, 105, 110,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 45, 115, 101, 108, 101, 99, 116, 95,
  99, 111, 108, 111, 114, 32, 52, 48, 44, 50, 48, 52, 44, 49, 53, 51,
  44, 49, 49, 48, 10, 115, 101, 108, 101, 99, 116, 95, 99, 111, 108, 111,
  114, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 83, 101, 108, 101, 99, 116,
  32, 99, 111, 108, 111, 114, 32, 40, 36, 123, 50, 45, 45, 49, 125, 41,
  32, 105, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116,
  104, 32, 116, 111, 108, 101, 114, 97, 110, 99, 101, 32, 36, 49, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 102, 99, 32, 36, 123, 50,
  45, 45, 49, 125, 32, 45, 45, 32, 45, 110, 111, 114, 109, 32, 45, 108,
  101, 32, 36, 49, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 101, 112,
  105, 97, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108,
  121, 32, 115, 101, 112, 105, 97, 32, 116, 111, 110, 101, 115, 32, 101, 102,
  102, 101, 99, 116, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45,
  115, 101, 112, 105, 97, 10, 115, 101, 112, 105, 97, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 115, 101, 112,
  105, 97, 32, 116, 111, 110, 101, 115, 32, 101, 102, 102, 101, 99, 116, 32,
  111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32,
  45, 32, 40, 48, 44, 52, 52, 44, 49, 49, 53, 44, 49, 52, 51, 44,
  49, 57, 54, 44, 50, 52, 52, 94, 48, 44, 50, 48, 44, 56, 52, 44,
  49, 49, 57, 44, 49, 56, 52, 44, 50, 51, 53, 94, 48, 44, 53, 44,
  52, 52, 44, 55, 51, 44, 49, 52, 52, 44, 50, 48, 48, 41, 32, 45,
  114, 91, 45, 49, 93, 32, 50, 53, 54, 44, 49, 44, 49, 44, 51, 44,
  51, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125,
  32, 45, 108, 91, 36, 62, 44, 45, 49, 93, 32, 45, 115, 112, 108, 105,
  116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 117, 109, 105, 110,
  97, 110, 99, 101, 91, 48, 93, 32, 45, 109, 97, 112, 91, 48, 93, 32,
  91, 45, 49, 93, 32, 45, 97, 91, 94, 45, 49, 93, 32, 99, 32, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 45,
  49, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115,
  111, 108, 97, 114, 105, 122, 101, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 83, 111, 108, 97, 114, 105, 122, 101, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 45, 115, 111, 108, 97, 114, 105, 122, 101, 10, 115, 111, 108, 97, 114,
  105, 122, 101, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 83,
  111, 108, 97, 114, 105, 122, 101, 32, 105, 109, 97, 103, 101, 36, 63, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 108, 117, 109, 105, 110, 97, 110, 99,
  101, 32, 45, 110, 32, 48, 44, 49, 50, 56, 32, 45, 109, 97, 112, 32,
  49, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 112,
  108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 83, 112, 108, 105, 116, 32, 99, 111, 108, 111, 114,
  32, 97, 110, 100, 32, 111, 112, 97, 99, 105, 116, 121, 32, 112, 97, 114,
  116, 115, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 46, 10, 115, 112, 108, 105, 116, 95, 111, 112, 97,
  99, 105, 116, 121, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  83, 112, 108, 105, 116, 32, 99, 111, 108, 111, 114, 32, 97, 110, 100, 32,
  111, 112, 97, 99, 105, 116, 121, 32, 112, 97, 114, 116, 115, 32, 111, 102,
  32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 60,
  93, 32, 45, 115, 32, 99, 44, 123, 105, 102, 40, 115, 61, 61, 52, 44,
  45, 51, 44, 105, 102, 40, 115, 61, 61, 50, 44, 45, 49, 44, 45, 115,
  41, 41, 125, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 114, 103, 98,
  50, 114, 103, 98, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 102, 114, 111, 109,
  32, 115, 82, 71, 66, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111, 108,
  111, 114, 98, 97, 115, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  116, 111, 95, 97, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 70, 111,
  114, 99, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 32, 116, 111, 32, 104, 97, 118, 101, 32, 97, 110, 32, 97,
  108, 112, 104, 97, 32, 99, 104, 97, 110, 110, 101, 108, 46, 10, 116, 111,
  95, 97, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 70, 111,
  114, 99, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 111, 32, 104,
  97, 118, 101, 32, 97, 110, 32, 97, 108, 112, 104, 97, 32, 99, 104, 97,
  110, 110, 101, 108, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105,
  102, 32, 123, 115, 61, 61, 49, 124, 124, 115, 61, 61, 51, 125, 32, 45,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 48, 44, 123, 115, 125, 32, 45,
  115, 104, 91, 45, 49, 93, 32, 123, 115, 45, 49, 125, 44, 123, 115, 45,
  49, 125, 32, 45, 102, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 116, 111, 95, 99, 111, 108, 111, 114, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 70, 111, 114, 99, 101, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 116, 111, 32,
  98, 101, 32, 105, 110, 32, 99, 111, 108, 111, 114, 32, 109, 111, 100, 101,
  32, 40, 82, 71, 66, 32, 111, 114, 32, 82, 71, 66, 65, 41, 46, 10,
  116, 111, 95, 99, 111, 108, 111, 114, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 70, 111, 114, 99, 101, 32, 105, 109, 97, 103, 101, 36,
  63, 32, 116, 111, 32, 98, 101, 32, 105, 110, 32, 99, 111, 108, 111, 114,
  32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45,
  105, 102, 32, 123, 115, 62, 52, 125, 32, 45, 101, 114, 114, 111, 114, 91,
  93, 32, 34, 73, 109, 97, 103, 101, 32, 91, 34, 64, 123, 60, 44, 45,
  49, 125, 34, 93, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 71, 44,
  71, 65, 44, 82, 71, 66, 32, 111, 114, 32, 82, 71, 66, 65, 32, 105,
  109, 97, 103, 101, 46, 34, 10, 45, 101, 108, 105, 102, 32, 123, 115, 61,
  61, 50, 125, 32, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 49, 44, 52, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 44, 49,
  10, 45, 101, 108, 105, 102, 32, 123, 115, 61, 61, 49, 125, 32, 45, 114,
  32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 51, 44, 49,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 58, 32, 109,
  111, 100, 101, 61, 123, 32, 48, 61, 97, 100, 97, 112, 116, 105, 118, 101,
  32, 124, 32, 49, 61, 71, 32, 124, 32, 50, 61, 71, 65, 32, 124, 32,
  51, 61, 82, 71, 66, 32, 124, 32, 52, 61, 82, 71, 66, 65, 32, 125,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 70, 111, 114, 99, 101, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32,
  116, 111, 32, 98, 101, 32, 105, 110, 32, 97, 32, 103, 105, 118, 101, 110,
  32, 99, 111, 108, 111, 114, 32, 109, 111, 100, 101, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 58, 32, 39, 109, 111, 100, 101, 61, 48, 39, 46, 10, 116,
  111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 49, 61, 48, 125, 10, 45, 105, 102, 32, 123,
  36, 49, 61, 61, 49, 125, 32, 45, 116, 111, 95, 103, 114, 97, 121, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 50, 125, 32, 45, 116,
  111, 95, 103, 114, 97, 121, 97, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  49, 61, 61, 51, 125, 32, 45, 116, 111, 95, 114, 103, 98, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 49, 61, 61, 52, 125, 32, 45, 116, 111, 95,
  114, 103, 98, 97, 10, 45, 101, 108, 115, 101, 10, 115, 61, 49, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 105, 102, 32, 123, 64,
  123, 36, 62, 44, 115, 125, 62, 52, 125, 32, 45, 101, 114, 114, 111, 114,
  32, 34, 73, 109, 97, 103, 101, 32, 91, 34, 36, 62, 34, 93, 32, 105,
  115, 32, 110, 111, 116, 32, 97, 32, 71, 44, 71, 65, 44, 82, 71, 66,
  32, 111, 114, 32, 82, 71, 66, 65, 32, 105, 109, 97, 103, 101, 46, 34,
  10, 45, 101, 108, 115, 101, 32, 115, 61, 123, 109, 97, 120, 40, 36, 115,
  44, 64, 123, 36, 62, 44, 115, 125, 41, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 100, 111, 110, 101, 32, 45, 116, 111, 95, 99, 111, 108, 111,
  114, 109, 111, 100, 101, 32, 36, 115, 10, 45, 101, 110, 100, 105, 102, 10,
  35, 64, 103, 109, 105, 99, 32, 116, 111, 95, 103, 114, 97, 121, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 70, 111, 114, 99, 101, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 116, 111,
  32, 98, 101, 32, 105, 110, 32, 71, 82, 65, 89, 32, 109, 111, 100, 101,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 45, 116, 111, 95, 103, 114, 97, 121,
  10, 116, 111, 95, 103, 114, 97, 121, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 70, 111, 114, 99, 101, 32, 105, 109, 97, 103, 101, 36,
  63, 32, 116, 111, 32, 98, 101, 32, 105, 110, 32, 71, 82, 65, 89, 32,
  109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105,
  102, 32, 123, 115, 62, 52, 125, 32, 45, 101, 114, 114, 111, 114, 91, 93,
  32, 34, 73, 109, 97, 103, 101, 32, 91, 34, 64, 123, 60, 44, 45, 49,
  125, 34, 93, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 71, 44, 71,
  65, 44, 82, 71, 66, 32, 111, 114, 32, 82, 71, 66, 65, 32, 105, 109,
  97, 103, 101, 46, 34, 10, 45, 101, 108, 105, 102, 32, 123, 115, 62, 61,
  51, 125, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48, 44, 50,
  32, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 10, 45, 101, 108, 105,
  102, 32, 123, 115, 61, 61, 50, 125, 32, 45, 114, 32, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 48, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 116, 111,
  95, 103, 114, 97, 121, 97, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  70, 111, 114, 99, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 32, 116, 111, 32, 98, 101, 32, 105, 110, 32, 71,
  82, 65, 89, 65, 32, 109, 111, 100, 101, 46, 10, 116, 111, 95, 103, 114,
  97, 121, 97, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 70,
  111, 114, 99, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 111, 32,
  98, 101, 32, 105, 110, 32, 71, 82, 65, 89, 65, 32, 109, 111, 100, 101,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 115,
  62, 52, 125, 32, 45, 101, 114, 114, 111, 114, 91, 93, 32, 34, 73, 109,
  97, 103, 101, 32, 91, 34, 64, 123, 60, 44, 45, 49, 125, 34, 93, 32,
  105, 115, 32, 110, 111, 116, 32, 97, 32, 71, 44, 71, 65, 44, 82, 71,
  66, 32, 111, 114, 32, 82, 71, 66, 65, 32, 105, 109, 97, 103, 101, 46,
  34, 10, 45, 101, 108, 105, 102, 32, 123, 115, 61, 61, 52, 125, 32, 45,
  45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 51, 32, 45, 99, 104, 97,
  110, 110, 101, 108, 115, 91, 45, 50, 93, 32, 48, 44, 50, 32, 45, 108,
  117, 109, 105, 110, 97, 110, 99, 101, 91, 45, 50, 93, 32, 45, 97, 32,
  99, 10, 45, 101, 108, 105, 102, 32, 123, 115, 61, 61, 51, 125, 32, 45,
  108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 48, 44, 49, 32, 45, 115, 104, 91, 45, 49, 93, 32,
  49, 44, 49, 32, 45, 102, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123, 115, 61,
  61, 49, 125, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48, 44,
  49, 32, 45, 115, 104, 91, 45, 49, 93, 32, 49, 44, 49, 32, 45, 102,
  91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  116, 111, 95, 112, 115, 101, 117, 100, 111, 103, 114, 97, 121, 32, 58, 32,
  95, 109, 97, 120, 95, 115, 116, 101, 112, 62, 61, 48, 44, 95, 105, 115,
  95, 112, 101, 114, 99, 101, 112, 116, 117, 97, 108, 95, 99, 111, 110, 115,
  116, 114, 97, 105, 110, 116, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125,
  44, 95, 98, 105, 116, 115, 95, 100, 101, 112, 116, 104, 62, 48, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 115, 99, 97, 108, 97, 114, 32,
  105, 109, 97, 103, 101, 115, 32, 40, 91, 48, 45, 50, 53, 53, 93, 45,
  118, 97, 108, 117, 101, 100, 41, 32, 116, 111, 32, 112, 115, 101, 117, 100,
  111, 45, 103, 114, 97, 121, 32, 99, 111, 108, 111, 114, 32, 105, 109, 97,
  103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101,
  102, 97, 117, 108, 116, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115,
  32, 58, 32, 39, 109, 97, 120, 95, 115, 116, 101, 112, 61, 53, 39, 44,
  32, 39, 105, 115, 95, 112, 101, 114, 99, 101, 112, 116, 117, 97, 108, 95,
  99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 61, 49, 39, 32, 97, 110,
  100, 32, 39, 98, 105, 116, 115, 95, 100, 101, 112, 116, 104, 61, 56, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 84, 104, 101, 32, 111,
  114, 105, 103, 105, 110, 97, 108, 32, 112, 115, 101, 117, 100, 111, 45, 103,
  114, 97, 121, 32, 116, 101, 99, 104, 110, 105, 113, 117, 101, 32, 104, 97,
  115, 32, 98, 101, 101, 110, 32, 105, 110, 116, 114, 111, 100, 117, 99, 101,
  100, 32, 98, 121, 32, 82, 105, 99, 104, 32, 70, 114, 97, 110, 122, 101,
  110, 32, 91, 104, 116, 116, 112, 58, 47, 47, 114, 48, 107, 46, 117, 115,
  47, 103, 114, 97, 112, 104, 105, 99, 115, 47, 112, 115, 101, 117, 100, 111,
  71, 114, 101, 121, 46, 104, 116, 109, 108, 93, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 69, 120, 116, 101, 110, 115, 105, 111, 110, 32, 111,
  102, 32, 116, 104, 105, 115, 32, 116, 101, 99, 104, 110, 105, 113, 117, 101,
  32, 116, 111, 32, 97, 114, 98, 105, 116, 114, 97, 114, 121, 32, 105, 110,
  99, 114, 101, 109, 101, 110, 116, 115, 32, 102, 111, 114, 32, 109, 111, 114,
  101, 32, 116, 111, 110, 101, 115, 44, 32, 104, 97, 115, 32, 98, 101, 101,
  110, 32, 100, 111, 110, 101, 32, 98, 121, 32, 68, 97, 118, 105, 100, 32,
  84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 101, 46, 10, 116, 111, 95,
  112, 115, 101, 117, 100, 111, 103, 114, 97, 121, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 53,
  125, 41, 32, 38, 38, 32, 36, 49, 62, 61, 48, 32, 38, 38, 32, 105,
  115, 105, 110, 116, 40, 36, 123, 51, 61, 56, 125, 41, 32, 38, 38, 32,
  36, 51, 62, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61,
  49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118,
  101, 114, 116, 32, 115, 99, 97, 108, 97, 114, 32, 105, 109, 97, 103, 101,
  36, 63, 32, 116, 111, 32, 112, 115, 101, 117, 100, 111, 45, 103, 114, 97,
  121, 32, 99, 111, 108, 111, 114, 32, 105, 109, 97, 103, 101, 115, 44, 32,
  119, 105, 116, 104, 32, 115, 116, 101, 112, 115, 32, 36, 49, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48,
  32, 45, 115, 114, 103, 98, 50, 114, 103, 98, 32, 45, 112, 115, 101, 117,
  100, 111, 103, 114, 97, 121, 32, 36, 49, 44, 123, 50, 46, 51, 42, 36,
  50, 125, 44, 36, 51, 10, 45, 45, 115, 114, 103, 98, 50, 114, 103, 98,
  91, 45, 49, 93, 32, 45, 114, 103, 98, 50, 108, 97, 98, 91, 45, 49,
  93, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32,
  48, 32, 45, 42, 91, 45, 49, 93, 32, 123, 54, 53, 53, 51, 53, 47,
  49, 48, 48, 125, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32,
  45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 48, 44, 50, 10, 45, 114,
  118, 91, 45, 50, 44, 45, 49, 93, 32, 45, 112, 101, 114, 109, 117, 116,
  101, 91, 45, 49, 93, 32, 120, 99, 121, 122, 32, 45, 43, 91, 45, 49,
  93, 32, 49, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 32,
  45, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 91, 45, 49, 93, 32,
  48, 10, 45, 45, 110, 111, 114, 109, 91, 45, 49, 93, 32, 45, 110, 101,
  113, 91, 45, 49, 93, 32, 48, 32, 45, 100, 105, 115, 116, 97, 110, 99,
  101, 91, 45, 49, 93, 32, 49, 32, 45, 42, 91, 45, 49, 93, 32, 45,
  49, 32, 45, 119, 97, 116, 101, 114, 115, 104, 101, 100, 91, 45, 50, 93,
  32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 45,
  91, 45, 49, 93, 32, 49, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  64, 35, 45, 49, 125, 10, 45, 116, 111, 95, 114, 103, 98, 91, 36, 62,
  93, 32, 45, 114, 103, 98, 50, 108, 97, 98, 91, 36, 62, 93, 32, 45,
  99, 104, 97, 110, 110, 101, 108, 115, 91, 36, 62, 93, 32, 48, 32, 45,
  42, 91, 36, 62, 93, 32, 123, 54, 53, 53, 51, 53, 47, 49, 48, 48,
  125, 32, 45, 114, 111, 117, 110, 100, 91, 36, 62, 93, 32, 45, 99, 91,
  36, 62, 93, 32, 48, 44, 54, 53, 53, 51, 53, 10, 45, 109, 97, 112,
  91, 36, 62, 93, 32, 91, 45, 49, 93, 10, 45, 100, 111, 110, 101, 32,
  45, 114, 109, 91, 45, 49, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 116, 111, 95, 114, 103, 98, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 70, 111, 114, 99, 101, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 116, 111, 32, 98, 101, 32,
  105, 110, 32, 82, 71, 66, 32, 109, 111, 100, 101, 46, 10, 116, 111, 95,
  114, 103, 98, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 70,
  111, 114, 99, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 111, 32,
  98, 101, 32, 105, 110, 32, 82, 71, 66, 32, 109, 111, 100, 101, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 115, 62, 52,
  125, 32, 45, 101, 114, 114, 111, 114, 91, 93, 32, 34, 73, 109, 97, 103,
  101, 32, 91, 34, 64, 123, 60, 44, 45, 49, 125, 34, 93, 32, 105, 115,
  32, 110, 111, 116, 32, 97, 32, 71, 44, 71, 65, 44, 82, 71, 66, 32,
  111, 114, 32, 82, 71, 66, 65, 32, 105, 109, 97, 103, 101, 46, 34, 10,
  45, 101, 108, 105, 102, 32, 123, 115, 61, 61, 52, 125, 32, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 32, 48, 44, 50, 10, 45, 101, 108, 105, 102,
  32, 123, 115, 61, 61, 50, 125, 32, 45, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 48, 44, 48, 32, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 51, 10, 45, 101, 108, 105, 102, 32,
  123, 115, 61, 61, 49, 125, 32, 45, 114, 32, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 51, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 116, 111, 95, 114, 103, 98,
  97, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 70, 111, 114, 99, 101,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  32, 116, 111, 32, 98, 101, 32, 105, 110, 32, 82, 71, 66, 65, 32, 109,
  111, 100, 101, 46, 10, 116, 111, 95, 114, 103, 98, 97, 32, 58, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 70, 111, 114, 99, 101, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 116, 111, 32, 98, 101, 32, 105, 110, 32, 82,
  71, 66, 65, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 105, 102, 32, 123, 115, 62, 52, 125, 32, 45, 101, 114, 114,
  111, 114, 91, 93, 32, 34, 73, 109, 97, 103, 101, 32, 91, 34, 64, 123,
  60, 44, 45, 49, 125, 34, 93, 32, 105, 115, 32, 110, 111, 116, 32, 97,
  32, 71, 44, 71, 65, 44, 82, 71, 66, 32, 111, 114, 32, 82, 71, 66,
  65, 32, 105, 109, 97, 103, 101, 46, 34, 10, 45, 101, 108, 105, 102, 32,
  123, 115, 61, 61, 51, 125, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 48, 44, 51, 32, 45, 115, 104, 91, 45, 49, 93, 32, 51, 44, 51,
  32, 45, 102, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123, 115, 61, 61, 50, 125,
  32, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 52, 32, 45, 115, 104, 91, 45, 49, 93, 32, 50, 44, 50,
  32, 45, 102, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123, 115, 61, 61, 49,
  125, 32, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 52, 32, 45, 115, 104, 91, 45, 49, 93, 32, 51, 44,
  51, 32, 45, 102, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 116, 114, 97, 110, 115, 102, 101, 114, 95, 99, 111, 108,
  111, 114, 115, 32, 58, 32, 95, 116, 114, 97, 110, 115, 102, 101, 114, 95,
  98, 114, 105, 103, 104, 116, 110, 101, 115, 115, 61, 123, 32, 48, 32, 124,
  32, 49, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 84, 114,
  97, 110, 115, 102, 101, 114, 32, 99, 111, 108, 111, 114, 115, 32, 111, 102,
  32, 116, 104, 101, 32, 102, 105, 114, 115, 116, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 32, 116, 111, 32, 116, 104, 101,
  32, 111, 116, 104, 101, 114, 32, 111, 110, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 58, 32, 39, 116, 114, 97, 110, 115, 102, 101, 114, 95, 98,
  114, 105, 103, 104, 116, 110, 101, 115, 115, 61, 48, 39, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 45, 114, 97, 110, 100, 32, 48, 44, 50, 53, 53, 32,
  45, 114, 101, 118, 101, 114, 115, 101, 32, 45, 45, 116, 114, 97, 110, 115,
  102, 101, 114, 95, 99, 111, 108, 111, 114, 115, 32, 49, 10, 116, 114, 97,
  110, 115, 102, 101, 114, 95, 99, 111, 108, 111, 114, 115, 32, 58, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 84, 114, 97, 110, 115, 102, 101, 114, 32, 99, 111,
  108, 111, 114, 115, 32, 111, 102, 32, 105, 109, 97, 103, 101, 32, 91, 48,
  93, 32, 116, 111, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45,
  105, 102, 32, 123, 64, 35, 60, 50, 125, 32, 45, 114, 101, 116, 117, 114,
  110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 32, 45, 116,
  111, 95, 114, 103, 98, 91, 48, 93, 32, 45, 116, 111, 95, 99, 111, 108,
  111, 114, 109, 111, 100, 101, 91, 94, 48, 93, 32, 123, 109, 97, 120, 40,
  51, 44, 64, 123, 45, 109, 97, 120, 95, 115, 125, 41, 125, 32, 45, 99,
  32, 48, 44, 50, 53, 53, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95,
  111, 112, 97, 99, 105, 116, 121, 32, 45, 114, 103, 98, 50, 121, 99, 98,
  99, 114, 91, 48, 93, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 45, 108, 91, 48, 93, 32, 45, 115, 32,
  99, 32, 45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 95, 99, 117, 109,
  117, 108, 32, 50, 53, 54, 44, 49, 44, 48, 44, 50, 53, 53, 32, 45,
  97, 32, 99, 32, 45, 42, 32, 50, 53, 53, 32, 45, 101, 110, 100, 108,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 32,
  45, 108, 91, 48, 44, 45, 49, 93, 10, 45, 105, 102, 32, 36, 49, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 51, 32, 45, 115, 104, 91, 48, 44,
  49, 93, 32, 36, 62, 44, 36, 62, 32, 45, 101, 113, 117, 97, 108, 105,
  122, 101, 91, 45, 49, 93, 32, 50, 53, 54, 44, 48, 44, 50, 53, 53,
  32, 45, 105, 110, 100, 101, 120, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 100, 111, 110, 101, 10, 45, 101, 108, 115, 101, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 50, 32, 45, 115, 104, 91, 48, 44, 49, 93, 32, 123,
  36, 62, 43, 49, 125, 44, 123, 36, 62, 43, 49, 125, 32, 45, 101, 113,
  117, 97, 108, 105, 122, 101, 91, 45, 49, 93, 32, 50, 53, 54, 44, 48,
  44, 50, 53, 53, 32, 45, 105, 110, 100, 101, 120, 91, 45, 49, 93, 32,
  91, 45, 50, 93, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 108, 32, 45, 109, 118, 91, 45, 49, 93, 32, 49,
  32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 93, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32,
  45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45,
  121, 99, 98, 99, 114, 50, 114, 103, 98, 91, 48, 93, 32, 45, 97, 32,
  99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 118,
  32, 43, 10, 95, 116, 114, 97, 110, 115, 102, 101, 114, 95, 99, 111, 108,
  111, 114, 115, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 45, 114, 103, 98, 50, 121, 99, 98,
  99, 114, 32, 45, 115, 32, 99, 32, 45, 104, 105, 115, 116, 111, 103, 114,
  97, 109, 32, 50, 53, 54, 44, 48, 44, 50, 53, 53, 32, 45, 97, 32,
  99, 32, 45, 100, 103, 32, 51, 48, 48, 44, 50, 48, 48, 32, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 109, 105, 99,
  32, 120, 121, 122, 50, 114, 103, 98, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 102, 114, 111, 109, 32, 88,
  89, 90, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111, 108, 111, 114, 98,
  97, 115, 101, 115, 46, 10, 120, 121, 122, 50, 114, 103, 98, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114, 111, 109, 32, 88, 89,
  90, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111, 108, 111, 114, 32, 98,
  97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 42, 32, 50,
  53, 53, 32, 45, 109, 105, 120, 95, 114, 103, 98, 32, 51, 46, 50, 52,
  48, 52, 55, 57, 44, 45, 49, 46, 53, 51, 55, 49, 53, 48, 44, 45,
  48, 46, 52, 57, 56, 53, 51, 53, 44, 45, 48, 46, 57, 54, 57, 50,
  53, 54, 44, 49, 46, 56, 55, 53, 57, 57, 50, 44, 48, 46, 48, 52,
  49, 53, 53, 54, 44, 48, 46, 48, 53, 53, 54, 52, 56, 44, 45, 48,
  46, 50, 48, 52, 48, 52, 51, 44, 49, 46, 48, 53, 55, 51, 49, 49,
  32, 45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 120, 121, 122, 56, 50, 114, 103, 98, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32,
  102, 114, 111, 109, 32, 88, 89, 90, 56, 32, 116, 111, 32, 82, 71, 66,
  32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 10, 120, 121,
  122, 56, 50, 114, 103, 98, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36,
  63, 32, 102, 114, 111, 109, 32, 88, 89, 90, 56, 32, 116, 111, 32, 82,
  71, 66, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  10, 45, 115, 104, 91, 36, 62, 93, 32, 48, 44, 48, 32, 45, 47, 91,
  45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 115, 104, 91, 36, 62, 93, 32, 49, 44, 49, 32, 45, 47, 91, 45,
  49, 93, 32, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  115, 104, 91, 36, 62, 93, 32, 50, 44, 50, 32, 45, 47, 91, 45, 49,
  93, 32, 50, 51, 49, 46, 56, 49, 56, 50, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 100, 111, 110, 101, 32, 45, 120, 121, 122, 50, 114, 103,
  98, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 121, 99,
  98, 99, 114, 50, 114, 103, 98, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 32, 102, 114, 111, 109, 32, 89, 67,
  98, 67, 114, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111, 108, 111, 114,
  98, 97, 115, 101, 115, 46, 10, 121, 99, 98, 99, 114, 50, 114, 103, 98,
  32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118,
  101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114, 111, 109,
  32, 89, 67, 98, 67, 114, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111,
  108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 32, 45, 115, 104, 32, 48, 44, 48, 32, 45, 45, 91, 45, 49,
  93, 32, 49, 54, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 115, 104,
  32, 49, 44, 50, 32, 45, 45, 91, 45, 49, 93, 32, 49, 50, 56, 32,
  45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 45, 109, 105, 120, 95, 114, 103, 98, 32, 50, 57, 56,
  44, 48, 44, 52, 48, 57, 44, 50, 57, 56, 44, 45, 49, 48, 48, 44,
  45, 50, 48, 56, 44, 50, 57, 56, 44, 53, 49, 54, 44, 48, 32, 45,
  43, 32, 49, 50, 56, 32, 45, 47, 32, 50, 53, 54, 32, 45, 99, 32,
  48, 44, 50, 53, 53, 10, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 121, 117, 118, 50, 114, 103, 98, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 102, 114, 111, 109, 32,
  89, 85, 86, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111, 108, 111, 114,
  98, 97, 115, 101, 115, 46, 10, 121, 117, 118, 50, 114, 103, 98, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114,
  116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114, 111, 109, 32, 89,
  85, 86, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111, 108, 111, 114, 32,
  98, 97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 109, 105,
  120, 95, 114, 103, 98, 32, 49, 44, 48, 44, 49, 46, 49, 51, 57, 56,
  51, 44, 49, 44, 45, 48, 46, 51, 57, 52, 54, 53, 44, 45, 48, 46,
  53, 56, 48, 54, 44, 49, 44, 50, 46, 48, 51, 50, 49, 49, 44, 48,
  32, 45, 42, 32, 50, 53, 53, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 121, 117, 118, 56, 50, 114, 103, 98, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 102, 114,
  111, 109, 32, 89, 85, 86, 56, 32, 116, 111, 32, 82, 71, 66, 32, 99,
  111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 10, 121, 117, 118, 56,
  50, 114, 103, 98, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  102, 114, 111, 109, 32, 89, 85, 86, 56, 32, 116, 111, 32, 82, 71, 66,
  32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45,
  115, 104, 91, 36, 62, 93, 32, 48, 44, 48, 32, 45, 47, 91, 45, 49,
  93, 32, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115,
  104, 91, 36, 62, 93, 32, 49, 44, 49, 32, 45, 47, 91, 45, 49, 93,
  32, 50, 56, 57, 46, 55, 55, 51, 32, 45, 45, 91, 45, 49, 93, 32,
  48, 46, 52, 52, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104,
  91, 36, 62, 93, 32, 50, 44, 50, 32, 45, 47, 91, 45, 49, 93, 32,
  50, 48, 53, 46, 54, 52, 53, 32, 45, 45, 91, 45, 49, 93, 32, 48,
  46, 54, 50, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 100, 111, 110,
  101, 32, 45, 121, 117, 118, 50, 114, 103, 98, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 58, 32, 71, 101, 111, 109, 101, 116,
  114, 121, 32, 109, 97, 110, 105, 112, 117, 108, 97, 116, 105, 111, 110, 10,
  35, 64, 103, 109, 105, 99, 32, 97, 32, 58, 32, 101, 113, 46, 32, 116,
  111, 32, 39, 45, 97, 112, 112, 101, 110, 100, 39, 32, 58, 32, 40, 42,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 97, 112, 112, 101, 110, 100, 32,
  58, 32, 91, 105, 109, 97, 103, 101, 93, 44, 97, 120, 105, 115, 44, 95,
  97, 108, 105, 103, 110, 109, 101, 110, 116, 32, 58, 32, 97, 120, 105, 115,
  44, 95, 97, 108, 105, 103, 110, 109, 101, 110, 116, 32, 58, 32, 40, 42,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 101, 110,
  100, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 105, 109, 97, 103,
  101, 32, 116, 111, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 44, 32, 111, 114, 32, 97, 108, 108, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 116, 111, 103,
  101, 116, 104, 101, 114, 44, 32, 97, 108, 111, 110, 103, 32, 115, 112, 101,
  99, 105, 102, 105, 101, 100, 32, 97, 120, 105, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45,
  97, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 97,
  120, 105, 115, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 120, 32,
  124, 32, 121, 32, 124, 32, 122, 32, 124, 32, 99, 32, 125, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 85, 115, 117, 97, 108, 32, 39, 97,
  108, 105, 103, 110, 109, 101, 110, 116, 39, 32, 118, 97, 108, 117, 101, 115,
  32, 97, 114, 101, 32, 123, 32, 48, 61, 108, 101, 102, 116, 45, 106, 117,
  115, 116, 105, 102, 105, 101, 100, 32, 124, 32, 48, 46, 53, 61, 99, 101,
  110, 116, 101, 114, 101, 100, 32, 124, 32, 49, 61, 114, 105, 103, 104, 116,
  45, 106, 117, 115, 116, 105, 102, 105, 101, 100, 32, 125, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 58, 32, 39, 97, 108, 105, 103, 110, 109, 101, 110, 116,
  61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 115, 112, 108, 105, 116,
  32, 121, 44, 49, 48, 32, 45, 114, 101, 118, 101, 114, 115, 101, 32, 45,
  97, 112, 112, 101, 110, 100, 32, 121, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 53, 32, 45, 45, 114, 111, 119, 115, 91, 48,
  93, 32, 48, 44, 123, 49, 48, 43, 49, 56, 42, 36, 62, 125, 37, 32,
  45, 100, 111, 110, 101, 32, 45, 114, 101, 109, 111, 118, 101, 91, 48, 93,
  32, 45, 97, 112, 112, 101, 110, 100, 32, 120, 44, 48, 46, 53, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 97, 112, 112, 101, 110, 100, 91, 48, 93, 32, 91,
  48, 93, 44, 121, 10, 35, 64, 103, 109, 105, 99, 32, 97, 112, 112, 101,
  110, 100, 95, 116, 105, 108, 101, 115, 32, 58, 32, 95, 77, 62, 61, 48,
  44, 95, 78, 62, 61, 48, 44, 48, 60, 61, 95, 120, 95, 97, 108, 105,
  103, 110, 109, 101, 110, 116, 60, 61, 49, 44, 48, 60, 61, 95, 121, 95,
  97, 108, 105, 103, 110, 109, 101, 110, 116, 60, 61, 49, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 65, 112, 112, 101, 110, 100, 32, 77, 120, 78,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 116, 105, 108, 101, 115, 32,
  97, 115, 32, 110, 101, 119, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 73, 102, 32, 39, 78, 39, 32, 105,
  115, 32, 115, 101, 116, 32, 116, 111, 32, 48, 44, 32, 110, 117, 109, 98,
  101, 114, 32, 111, 102, 32, 114, 111, 119, 115, 32, 105, 115, 32, 101, 115,
  116, 105, 109, 97, 116, 101, 100, 32, 97, 117, 116, 111, 109, 97, 116, 105,
  99, 97, 108, 108, 121, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  73, 102, 32, 39, 77, 39, 32, 105, 115, 32, 115, 101, 116, 32, 116, 111,
  32, 48, 44, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 99, 111,
  108, 117, 109, 110, 115, 32, 105, 115, 32, 101, 115, 116, 105, 109, 97, 116,
  101, 100, 32, 97, 117, 116, 111, 109, 97, 116, 105, 99, 97, 108, 108, 121,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 102, 32, 39, 77,
  39, 32, 97, 110, 100, 32, 39, 78, 39, 32, 97, 114, 101, 32, 98, 111,
  116, 104, 32, 115, 101, 116, 32, 116, 111, 32, 39, 48, 39, 44, 32, 97,
  117, 116, 111, 45, 109, 111, 100, 101, 32, 105, 115, 32, 117, 115, 101, 100,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 102, 32, 39, 77,
  39, 32, 111, 114, 32, 39, 78, 39, 32, 105, 115, 32, 115, 101, 116, 32,
  116, 111, 32, 48, 44, 32, 111, 110, 108, 121, 32, 97, 32, 115, 105, 110,
  103, 108, 101, 32, 105, 109, 97, 103, 101, 32, 105, 115, 32, 112, 114, 111,
  100, 117, 99, 101, 100, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  39, 120, 95, 97, 108, 105, 103, 110, 109, 101, 110, 116, 39, 32, 97, 110,
  100, 32, 39, 121, 95, 97, 108, 105, 103, 109, 101, 110, 116, 39, 32, 116,
  101, 108, 108, 115, 32, 97, 98, 111, 117, 116, 32, 116, 104, 101, 32, 97,
  108, 105, 103, 110, 109, 101, 110, 116, 32, 111, 102, 32, 116, 105, 108, 101,
  115, 32, 119, 104, 101, 110, 32, 116, 104, 101, 121, 32, 104, 97, 118, 101,
  32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32, 115, 105, 122, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117,
  108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 77, 61, 48, 39,
  44, 32, 39, 78, 61, 48, 39, 44, 32, 39, 120, 95, 97, 108, 105, 103,
  110, 109, 101, 110, 116, 61, 121, 95, 97, 108, 105, 103, 110, 109, 101, 110,
  116, 61, 48, 46, 53, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 115, 112,
  108, 105, 116, 32, 120, 121, 44, 52, 32, 45, 97, 112, 112, 101, 110, 100,
  95, 116, 105, 108, 101, 115, 32, 44, 10, 97, 112, 112, 101, 110, 100, 95,
  116, 105, 108, 101, 115, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 48, 125, 41, 32, 38, 38,
  32, 105, 115, 105, 110, 116, 40, 36, 123, 50, 61, 48, 125, 41, 32, 38,
  38, 32, 36, 123, 51, 61, 48, 46, 53, 125, 62, 61, 48, 32, 38, 38,
  32, 36, 51, 60, 61, 49, 32, 38, 38, 32, 36, 123, 52, 61, 36, 51,
  125, 62, 61, 48, 32, 38, 38, 32, 36, 52, 60, 61, 49, 34, 10, 45,
  105, 102, 32, 123, 33, 64, 35, 125, 32, 45, 101, 91, 48, 45, 45, 51,
  93, 32, 34, 65, 112, 112, 101, 110, 100, 32, 105, 109, 97, 103, 101, 36,
  63, 32, 97, 115, 32, 97, 32, 48, 120, 48, 45, 116, 105, 108, 101, 100,
  32, 105, 109, 97, 103, 101, 46, 34, 32, 45, 114, 101, 116, 117, 114, 110,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 33, 36, 49,
  38, 38, 33, 36, 50, 125, 10, 45, 118, 32, 45, 32, 78, 61, 123, 105,
  110, 116, 40, 115, 113, 114, 116, 40, 64, 35, 41, 41, 125, 32, 77, 61,
  123, 114, 111, 117, 110, 100, 40, 64, 35, 47, 36, 78, 44, 49, 44, 49,
  41, 125, 10, 45, 118, 32, 43, 32, 45, 101, 91, 48, 45, 45, 51, 93,
  32, 34, 65, 112, 112, 101, 110, 100, 32, 105, 109, 97, 103, 101, 36, 63,
  32, 97, 115, 32, 97, 32, 34, 36, 123, 77, 125, 120, 36, 123, 78, 125,
  34, 45, 116, 105, 108, 101, 100, 32, 105, 109, 97, 103, 101, 32, 40, 97,
  117, 116, 111, 45, 109, 111, 100, 101, 41, 46, 34, 32, 45, 118, 32, 45,
  10, 77, 78, 61, 123, 36, 77, 42, 36, 78, 125, 32, 45, 105, 102, 32,
  123, 64, 35, 37, 36, 77, 78, 125, 32, 123, 36, 77, 78, 45, 40, 64,
  35, 37, 36, 77, 78, 41, 125, 32, 45, 115, 91, 45, 49, 93, 32, 120,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 105, 102, 32, 123, 33,
  36, 50, 125, 10, 45, 118, 32, 45, 32, 77, 61, 36, 49, 32, 78, 61,
  123, 114, 111, 117, 110, 100, 40, 64, 35, 47, 36, 49, 44, 49, 44, 49,
  41, 125, 10, 45, 118, 32, 43, 32, 45, 101, 91, 48, 45, 45, 51, 93,
  32, 34, 65, 112, 112, 101, 110, 100, 32, 105, 109, 97, 103, 101, 36, 63,
  32, 97, 115, 32, 97, 32, 34, 36, 123, 77, 125, 120, 36, 123, 78, 125,
  34, 45, 116, 105, 108, 101, 100, 32, 105, 109, 97, 103, 101, 46, 34, 32,
  45, 118, 32, 45, 10, 45, 105, 102, 32, 123, 36, 77, 62, 64, 35, 125,
  32, 45, 118, 32, 43, 32, 45, 119, 97, 114, 110, 91, 48, 45, 45, 51,
  93, 32, 34, 77, 105, 115, 115, 105, 110, 103, 32, 105, 109, 97, 103, 101,
  115, 32, 102, 111, 114, 32, 104, 97, 118, 105, 110, 103, 32, 111, 110, 101,
  32, 114, 111, 119, 32, 105, 110, 32, 97, 32, 34, 36, 123, 77, 125, 120,
  36, 123, 78, 125, 34, 45, 116, 105, 108, 101, 100, 32, 105, 109, 97, 103,
  101, 46, 34, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 64, 35, 37, 36, 77, 125, 32, 123,
  36, 77, 45, 40, 64, 35, 37, 36, 77, 41, 125, 32, 45, 115, 91, 45,
  49, 93, 32, 120, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 105,
  102, 32, 123, 33, 36, 49, 125, 10, 45, 118, 32, 45, 32, 77, 61, 123,
  114, 111, 117, 110, 100, 40, 64, 35, 47, 36, 50, 44, 49, 44, 49, 41,
  125, 32, 78, 61, 36, 50, 10, 45, 118, 32, 43, 32, 45, 101, 91, 48,
  45, 45, 51, 93, 32, 34, 65, 112, 112, 101, 110, 100, 32, 105, 109, 97,
  103, 101, 36, 63, 32, 97, 115, 32, 97, 32, 34, 36, 123, 77, 125, 120,
  36, 123, 78, 125, 34, 45, 116, 105, 108, 101, 100, 32, 105, 109, 97, 103,
  101, 46, 34, 32, 45, 118, 32, 45, 10, 45, 105, 102, 32, 123, 36, 78,
  62, 64, 35, 125, 32, 45, 118, 32, 43, 32, 45, 119, 97, 114, 110, 91,
  48, 45, 45, 51, 93, 32, 34, 77, 105, 115, 115, 105, 110, 103, 32, 105,
  109, 97, 103, 101, 115, 32, 102, 111, 114, 32, 104, 97, 118, 105, 110, 103,
  32, 111, 110, 101, 32, 99, 111, 108, 117, 109, 110, 32, 105, 110, 32, 97,
  32, 34, 36, 123, 77, 125, 120, 36, 123, 78, 125, 34, 45, 116, 105, 108,
  101, 100, 32, 105, 109, 97, 103, 101, 46, 34, 32, 45, 114, 101, 116, 117,
  114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64,
  35, 37, 36, 77, 125, 32, 123, 36, 77, 45, 40, 64, 35, 37, 36, 77,
  41, 125, 32, 45, 115, 91, 45, 49, 93, 32, 120, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 108, 115, 101, 10, 45, 101, 91, 48, 45, 45, 51,
  93, 32, 34, 65, 112, 112, 101, 110, 100, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 97, 115, 32, 36, 49, 120, 36, 50, 45, 116, 105, 108, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 34, 32, 45, 118, 32, 45, 10,
  77, 61, 36, 49, 32, 78, 61, 36, 50, 10, 45, 101, 110, 100, 105, 102,
  10, 77, 78, 61, 123, 36, 77, 42, 36, 78, 125, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 36, 77, 78, 41,
  125, 32, 45, 108, 91, 36, 62, 45, 123, 36, 62, 43, 36, 77, 78, 45,
  49, 125, 93, 10, 36, 77, 78, 44, 49, 44, 49, 44, 50, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 77, 78, 32, 45, 112, 111, 105, 110, 116,
  91, 45, 49, 93, 32, 36, 62, 44, 48, 44, 48, 44, 49, 44, 64, 123,
  36, 62, 44, 119, 125, 44, 64, 123, 36, 62, 44, 104, 125, 32, 45, 100,
  111, 110, 101, 32, 45, 114, 91, 45, 49, 93, 32, 36, 77, 44, 36, 78,
  44, 49, 44, 50, 44, 45, 49, 10, 45, 115, 91, 45, 49, 93, 32, 99,
  32, 45, 108, 91, 45, 50, 93, 32, 45, 115, 32, 121, 32, 45, 109, 97,
  120, 32, 45, 101, 110, 100, 108, 32, 45, 108, 91, 45, 49, 93, 32, 45,
  115, 32, 120, 32, 45, 109, 97, 120, 32, 45, 101, 110, 100, 108, 10, 105,
  61, 48, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 78, 32, 121, 61,
  36, 62, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 77, 32, 45, 114,
  91, 36, 105, 93, 32, 64, 123, 45, 50, 44, 36, 62, 125, 44, 64, 123,
  45, 49, 44, 36, 121, 125, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 48, 44, 48, 44, 36, 51, 44, 36, 52, 32, 105, 61, 123, 36, 105,
  43, 49, 125, 32, 45, 100, 111, 110, 101, 32, 45, 100, 111, 110, 101, 10,
  45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 36, 77, 41, 125, 32,
  45, 97, 91, 36, 62, 45, 123, 36, 62, 43, 36, 77, 45, 49, 125, 93,
  32, 120, 32, 45, 100, 111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 123, 105, 110, 116, 40, 64, 35, 47, 36, 78, 41, 125, 32, 45, 97,
  91, 36, 62, 45, 123, 36, 62, 43, 36, 78, 45, 49, 125, 93, 32, 121,
  32, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 97,
  117, 116, 111, 99, 114, 111, 112, 32, 58, 32, 118, 97, 108, 117, 101, 49,
  44, 118, 97, 108, 117, 101, 50, 44, 46, 46, 46, 32, 58, 32, 40, 110,
  111, 32, 97, 114, 103, 115, 41, 32, 58, 32, 40, 42, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 65, 117, 116, 111, 99, 114, 111, 112, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32,
  98, 121, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 118, 101, 99,
  116, 111, 114, 45, 118, 97, 108, 117, 101, 100, 32, 105, 110, 116, 101, 110,
  115, 105, 116, 121, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73,
  102, 32, 110, 111, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 97,
  114, 101, 32, 112, 114, 111, 118, 105, 100, 101, 100, 44, 32, 99, 114, 111,
  112, 112, 105, 110, 103, 32, 118, 97, 108, 117, 101, 32, 105, 115, 32, 103,
  117, 101, 115, 115, 101, 100, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 52, 48, 48, 44, 52, 48, 48, 44, 49, 44, 51, 32, 45,
  102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 32, 54, 52, 44, 49, 50,
  56, 44, 50, 53, 53, 32, 45, 101, 108, 108, 105, 112, 115, 101, 32, 53,
  48, 37, 44, 53, 48, 37, 44, 49, 50, 48, 44, 49, 50, 48, 44, 48,
  44, 49, 44, 50, 53, 53, 32, 45, 45, 97, 117, 116, 111, 99, 114, 111,
  112, 10, 35, 64, 103, 109, 105, 99, 32, 97, 117, 116, 111, 99, 114, 111,
  112, 95, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 32, 58, 32, 95,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 91, 37, 93, 44, 95, 109, 105,
  110, 95, 97, 114, 101, 97, 91, 37, 93, 62, 61, 48, 44, 95, 105, 115,
  95, 104, 105, 103, 104, 95, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105,
  116, 121, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 44, 95, 111, 117,
  116, 112, 117, 116, 95, 116, 121, 112, 101, 61, 123, 32, 48, 61, 99, 114,
  111, 112, 32, 124, 32, 49, 61, 115, 101, 103, 109, 101, 110, 116, 97, 116,
  105, 111, 110, 32, 124, 32, 50, 61, 99, 111, 111, 114, 100, 105, 110, 97,
  116, 101, 115, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65,
  117, 116, 111, 99, 114, 111, 112, 32, 97, 110, 100, 32, 101, 120, 116, 114,
  97, 99, 116, 32, 99, 111, 110, 110, 101, 99, 116, 101, 100, 32, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 115, 32, 105, 110, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 44, 32, 97, 99, 99,
  111, 114, 100, 105, 110, 103, 32, 116, 111, 32, 97, 32, 109, 97, 115, 107,
  32, 103, 105, 118, 101, 110, 32, 97, 115, 32, 116, 104, 101, 32, 108, 97,
  115, 116, 32, 99, 104, 97, 110, 110, 101, 108, 32, 111, 102, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 101, 97, 99, 104, 32, 111, 102, 32, 116,
  104, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 32, 40, 101, 46, 103, 46, 32, 97, 108, 112, 104, 97, 45, 99, 104,
  97, 110, 110, 101, 108, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58,
  32, 39, 116, 104, 114, 101, 115, 104, 111, 108, 100, 61, 48, 37, 39, 44,
  32, 39, 109, 105, 110, 95, 97, 114, 101, 97, 61, 48, 46, 49, 37, 39,
  44, 32, 39, 105, 115, 95, 104, 105, 103, 104, 95, 99, 111, 110, 110, 101,
  99, 116, 105, 118, 105, 116, 121, 61, 48, 39, 32, 97, 110, 100, 32, 39,
  111, 117, 116, 112, 117, 116, 95, 116, 121, 112, 101, 61, 49, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 50, 53, 54, 44, 50,
  53, 54, 32, 45, 110, 111, 105, 115, 101, 32, 48, 46, 49, 44, 50, 32,
  45, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 32, 50, 48, 32,
  45, 108, 97, 98, 101, 108, 95, 102, 103, 32, 48, 44, 49, 32, 45, 110,
  111, 114, 109, 97, 108, 105, 122, 101, 32, 48, 44, 50, 53, 53, 32, 45,
  45, 110, 101, 113, 32, 48, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53,
  53, 32, 45, 97, 112, 112, 101, 110, 100, 32, 99, 32, 45, 45, 97, 117,
  116, 111, 99, 114, 111, 112, 95, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  115, 32, 44, 10, 97, 117, 116, 111, 99, 114, 111, 112, 95, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32,
  36, 123, 49, 61, 48, 37, 125, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  36, 123, 50, 61, 48, 46, 49, 37, 125, 62, 61, 48, 32, 38, 38, 32,
  105, 115, 98, 111, 111, 108, 40, 36, 123, 51, 61, 48, 125, 41, 32, 38,
  38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 52, 61, 49, 125, 41, 32,
  38, 38, 32, 36, 52, 62, 61, 48, 32, 38, 38, 32, 36, 52, 60, 61,
  50, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 117, 116, 111,
  99, 114, 111, 112, 32, 99, 111, 110, 110, 101, 99, 116, 101, 100, 32, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 115, 32, 102, 114, 111, 109, 32, 105,
  109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 116, 104, 114,
  101, 115, 104, 111, 108, 100, 32, 36, 49, 44, 32, 109, 105, 110, 105, 109,
  97, 108, 32, 97, 114, 101, 97, 32, 36, 50, 44, 32, 34, 64, 123, 45,
  97, 114, 103, 92, 32, 49, 43, 36, 51, 44, 108, 111, 119, 44, 104, 105,
  103, 104, 125, 34, 32, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116,
  121, 32, 34, 92, 10, 34, 97, 110, 100, 32, 111, 117, 116, 112, 117, 116,
  32, 116, 121, 112, 101, 32, 115, 101, 116, 32, 116, 111, 32, 39, 34, 64,
  123, 45, 97, 114, 103, 92, 32, 49, 43, 36, 52, 44, 99, 114, 111, 112,
  44, 115, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111, 110, 44, 99, 111,
  111, 114, 100, 105, 110, 97, 116, 101, 115, 125, 34, 39, 46, 92, 110, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 109, 105, 110, 95, 97, 114, 101, 97,
  61, 123, 109, 97, 120, 40, 49, 44, 114, 111, 117, 110, 100, 40, 105, 102,
  40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32,
  36, 50, 125, 44, 36, 50, 42, 119, 42, 104, 44, 36, 50, 41, 41, 41,
  125, 10, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 49, 48, 48,
  37, 32, 45, 103, 116, 91, 45, 49, 93, 32, 36, 49, 32, 45, 97, 114,
  101, 97, 95, 102, 103, 91, 45, 49, 93, 32, 48, 44, 36, 51, 32, 45,
  103, 101, 91, 45, 49, 93, 32, 36, 109, 105, 110, 95, 97, 114, 101, 97,
  10, 45, 45, 97, 114, 101, 97, 91, 45, 49, 93, 32, 48, 44, 49, 32,
  45, 108, 116, 91, 45, 49, 93, 32, 36, 109, 105, 110, 95, 97, 114, 101,
  97, 32, 45, 111, 114, 91, 45, 50, 44, 45, 49, 93, 32, 45, 108, 97,
  98, 101, 108, 95, 102, 103, 91, 45, 49, 93, 32, 48, 44, 49, 10, 78,
  61, 123, 105, 77, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105,
  77, 125, 10, 110, 61, 123, 49, 43, 36, 62, 125, 10, 45, 118, 32, 43,
  32, 45, 101, 91, 93, 32, 34, 92, 114, 32, 32, 62, 32, 34, 36, 110,
  47, 36, 78, 32, 45, 118, 32, 45, 10, 45, 114, 112, 114, 111, 103, 114,
  101, 115, 115, 32, 123, 49, 48, 48, 42, 36, 110, 47, 36, 78, 125, 10,
  45, 45, 61, 61, 91, 49, 93, 32, 36, 110, 32, 45, 45, 42, 91, 48,
  44, 45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 105, 102,
  32, 123, 36, 52, 61, 61, 48, 125, 32, 99, 111, 111, 114, 100, 115, 61,
  64, 123, 45, 97, 117, 116, 111, 99, 114, 111, 112, 95, 99, 111, 111, 114,
  100, 115, 91, 45, 49, 93, 92, 32, 97, 117, 116, 111, 125, 32, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 45, 122, 91, 48, 93, 32, 36, 99, 111,
  111, 114, 100, 115, 10, 45, 101, 108, 105, 102, 32, 123, 36, 52, 61, 61,
  49, 125, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93,
  10, 45, 101, 108, 115, 101, 32, 99, 111, 111, 114, 100, 115, 61, 64, 123,
  45, 97, 117, 116, 111, 99, 114, 111, 112, 95, 99, 111, 111, 114, 100, 115,
  91, 45, 49, 93, 92, 32, 97, 117, 116, 111, 125, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 40, 36, 99, 111, 111, 114, 100, 115, 41, 32, 45, 121,
  91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110,
  101, 10, 45, 114, 109, 91, 48, 44, 49, 93, 10, 45, 105, 102, 32, 123,
  36, 52, 61, 61, 50, 125, 32, 45, 97, 32, 120, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 97, 117, 116, 111, 99,
  114, 111, 112, 95, 115, 101, 113, 32, 58, 32, 118, 97, 108, 117, 101, 49,
  44, 118, 97, 108, 117, 101, 50, 44, 46, 46, 46, 32, 124, 32, 97, 117,
  116, 111, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 117, 116, 111,
  99, 114, 111, 112, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 32, 117, 115, 105, 110, 103, 32, 116, 104, 101, 32, 99,
  114, 111, 112, 32, 103, 101, 111, 109, 101, 116, 114, 121, 32, 111, 102, 32,
  116, 104, 101, 32, 108, 97, 115, 116, 32, 111, 110, 101, 32, 98, 121, 32,
  115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 118, 101, 99, 116, 111, 114,
  45, 118, 97, 108, 117, 101, 100, 32, 105, 110, 116, 101, 110, 115, 105, 116,
  121, 44, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 111, 114, 32, 98,
  121, 32, 97, 117, 116, 111, 109, 97, 116, 105, 99, 32, 103, 117, 101, 115,
  115, 105, 110, 103, 32, 116, 104, 101, 32, 99, 114, 111, 112, 112, 105, 110,
  103, 32, 118, 97, 108, 117, 101, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58,
  32, 97, 117, 116, 111, 32, 109, 111, 100, 101, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 45, 102, 105, 108, 108, 91, 45, 49, 93, 32, 48, 32, 45, 101,
  108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53,
  48, 37, 44, 51, 48, 37, 44, 50, 48, 37, 44, 48, 44, 49, 44, 49,
  32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 95, 115, 101, 113, 32, 48,
  10, 97, 117, 116, 111, 99, 114, 111, 112, 95, 115, 101, 113, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 97, 117, 116, 111, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 117, 116, 111, 45, 99, 114,
  111, 112, 32, 105, 109, 97, 103, 101, 36, 63, 32, 117, 115, 105, 110, 103,
  32, 99, 114, 111, 112, 32, 103, 101, 111, 109, 101, 116, 114, 121, 32, 111,
  102, 32, 108, 97, 115, 116, 32, 105, 109, 97, 103, 101, 32, 98, 121, 32,
  118, 101, 99, 116, 111, 114, 32, 39, 36, 42, 39, 46, 34, 10, 45, 105,
  102, 32, 123, 33, 64, 35, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32,
  123, 64, 35, 61, 61, 49, 125, 32, 45, 95, 97, 117, 116, 111, 99, 114,
  111, 112, 36, 105, 115, 95, 97, 117, 116, 111, 32, 36, 123, 49, 45, 45,
  49, 125, 32, 45, 118, 32, 43, 32, 45, 114, 101, 116, 117, 114, 110, 32,
  45, 101, 110, 100, 105, 102, 10, 99, 111, 111, 114, 100, 115, 61, 64, 123,
  45, 97, 117, 116, 111, 99, 114, 111, 112, 95, 99, 111, 111, 114, 100, 115,
  91, 45, 49, 93, 92, 32, 36, 123, 49, 45, 45, 49, 125, 125, 10, 120,
  48, 61, 123, 97, 114, 103, 40, 49, 44, 36, 99, 111, 111, 114, 100, 115,
  41, 125, 32, 121, 48, 61, 123, 97, 114, 103, 40, 50, 44, 36, 99, 111,
  111, 114, 100, 115, 41, 125, 32, 122, 48, 61, 123, 97, 114, 103, 40, 51,
  44, 36, 99, 111, 111, 114, 100, 115, 41, 125, 10, 120, 49, 61, 123, 97,
  114, 103, 40, 52, 44, 36, 99, 111, 111, 114, 100, 115, 41, 125, 32, 121,
  49, 61, 123, 97, 114, 103, 40, 53, 44, 36, 99, 111, 111, 114, 100, 115,
  41, 125, 32, 122, 49, 61, 123, 97, 114, 103, 40, 54, 44, 36, 99, 111,
  111, 114, 100, 115, 41, 125, 10, 45, 105, 102, 32, 123, 36, 120, 48, 62,
  36, 120, 49, 34, 32, 124, 124, 32, 34, 36, 121, 48, 62, 36, 121, 49,
  34, 32, 124, 124, 32, 34, 36, 122, 48, 62, 36, 122, 49, 125, 32, 45,
  105, 91, 48, 45, 45, 50, 93, 32, 48, 32, 45, 114, 109, 91, 49, 45,
  45, 49, 58, 50, 93, 10, 45, 101, 108, 115, 101, 32, 45, 99, 114, 111,
  112, 32, 36, 120, 48, 44, 36, 121, 48, 44, 36, 122, 48, 44, 36, 120,
  49, 44, 36, 121, 49, 44, 36, 122, 49, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 58, 32, 123, 32, 91, 105, 109, 97, 103, 101,
  48, 93, 32, 124, 32, 99, 48, 91, 37, 93, 32, 125, 44, 95, 123, 32,
  91, 105, 109, 97, 103, 101, 49, 93, 32, 124, 32, 99, 49, 91, 37, 93,
  32, 125, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 75, 101, 101, 112, 32, 111, 110, 108, 121, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 99, 104, 97, 110, 110, 101, 108, 115, 32, 111,
  102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 105, 114, 105,
  99, 104, 108, 101, 116, 32, 98, 111, 117, 110, 100, 97, 114, 121, 32, 105,
  115, 32, 117, 115, 101, 100, 32, 119, 104, 101, 110, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 99, 104, 97, 110, 110, 101, 108, 115, 32, 97,
  114, 101, 32, 111, 117, 116, 32, 111, 102, 32, 114, 97, 110, 103, 101, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  48, 44, 49, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 108, 117, 109, 105, 110, 97,
  110, 99, 101, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48, 44,
  50, 10, 35, 64, 103, 109, 105, 99, 32, 99, 111, 108, 117, 109, 110, 115,
  32, 58, 32, 123, 32, 91, 105, 109, 97, 103, 101, 48, 93, 32, 124, 32,
  120, 48, 91, 37, 93, 32, 125, 44, 95, 123, 32, 91, 105, 109, 97, 103,
  101, 49, 93, 32, 124, 32, 120, 49, 91, 37, 93, 32, 125, 32, 58, 32,
  40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 75, 101, 101,
  112, 32, 111, 110, 108, 121, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100,
  32, 99, 111, 108, 117, 109, 110, 115, 32, 111, 102, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 105, 114, 105, 99, 104, 108, 101, 116, 32,
  98, 111, 117, 110, 100, 97, 114, 121, 32, 105, 115, 32, 117, 115, 101, 100,
  32, 119, 104, 101, 110, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  99, 111, 108, 117, 109, 110, 115, 32, 97, 114, 101, 32, 111, 117, 116, 32,
  111, 102, 32, 114, 97, 110, 103, 101, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  99, 111, 108, 117, 109, 110, 115, 32, 45, 50, 53, 37, 44, 53, 48, 37,
  10, 35, 64, 103, 109, 105, 99, 32, 122, 32, 58, 32, 101, 113, 46, 32,
  116, 111, 32, 39, 45, 99, 114, 111, 112, 39, 46, 32, 58, 32, 40, 42,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 99, 114, 111, 112, 32, 58, 32,
  120, 48, 91, 37, 93, 44, 120, 49, 91, 37, 93, 44, 95, 98, 111, 117,
  110, 100, 97, 114, 121, 32, 58, 32, 120, 48, 91, 37, 93, 44, 121, 48,
  91, 37, 93, 44, 120, 49, 91, 37, 93, 44, 121, 49, 91, 37, 93, 44,
  95, 98, 111, 117, 110, 100, 97, 114, 121, 32, 58, 32, 120, 48, 91, 37,
  93, 44, 121, 48, 91, 37, 93, 44, 122, 48, 91, 37, 93, 44, 120, 49,
  91, 37, 93, 44, 121, 49, 91, 37, 93, 44, 122, 49, 91, 37, 93, 44,
  95, 98, 111, 117, 110, 100, 97, 114, 121, 32, 58, 32, 120, 48, 91, 37,
  93, 44, 121, 48, 91, 37, 93, 44, 122, 48, 91, 37, 93, 44, 99, 48,
  91, 37, 93, 44, 120, 49, 91, 37, 93, 44, 121, 49, 91, 37, 93, 44,
  122, 49, 91, 37, 93, 44, 99, 49, 91, 37, 93, 44, 95, 98, 111, 117,
  110, 100, 97, 114, 121, 32, 58, 32, 40, 110, 111, 97, 114, 103, 115, 41,
  32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  67, 114, 111, 112, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 32, 119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102,
  105, 101, 100, 32, 114, 101, 103, 105, 111, 110, 32, 99, 111, 111, 114, 100,
  105, 110, 97, 116, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 122, 39, 41, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 98, 111, 117, 110, 100, 97,
  114, 121, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 100,
  105, 114, 105, 99, 104, 108, 101, 116, 32, 124, 32, 49, 61, 110, 101, 117,
  109, 97, 110, 110, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 40, 110, 111, 97, 114, 103, 115, 41, 32, 114, 117, 110, 115, 32, 105,
  110, 116, 101, 114, 97, 99, 116, 105, 118, 101, 32, 109, 111, 100, 101, 32,
  40, 117, 115, 101, 115, 32, 116, 104, 101, 32, 105, 110, 115, 116, 97, 110,
  116, 32, 119, 105, 110, 100, 111, 119, 32, 91, 48, 93, 32, 105, 102, 32,
  111, 112, 101, 110, 101, 100, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58,
  32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 61, 48, 39, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 45, 99, 114, 111, 112, 32, 45, 50, 51, 48, 44,
  45, 50, 51, 48, 44, 50, 56, 48, 44, 50, 56, 48, 44, 49, 32, 45,
  99, 114, 111, 112, 91, 48, 93, 32, 45, 50, 51, 48, 44, 45, 50, 51,
  48, 44, 50, 56, 48, 44, 50, 56, 48, 44, 48, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 99, 114, 111, 112, 32, 50, 53, 37, 44, 50, 53, 37, 44, 55,
  53, 37, 44, 55, 53, 37, 10, 35, 64, 103, 109, 105, 99, 32, 100, 105,
  97, 103, 111, 110, 97, 108, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  84, 114, 97, 110, 115, 102, 111, 114, 109, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 118, 101, 99, 116, 111, 114, 115, 32, 97, 115, 32, 100, 105,
  97, 103, 111, 110, 97, 108, 32, 109, 97, 116, 114, 105, 99, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 49, 44, 49, 48,
  44, 49, 44, 49, 44, 39, 121, 39, 32, 45, 45, 100, 105, 97, 103, 111,
  110, 97, 108, 10, 100, 105, 97, 103, 111, 110, 97, 108, 32, 58, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 84, 114, 97, 110, 115, 102, 111, 114,
  109, 32, 118, 101, 99, 116, 111, 114, 36, 63, 32, 97, 115, 32, 100, 105,
  97, 103, 111, 110, 97, 108, 32, 109, 97, 116, 114, 105, 120, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 121, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 114, 91, 36, 62, 93, 32, 64, 123, 36, 62, 44, 104,
  43, 49, 125, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 48, 32, 45,
  114, 91, 36, 62, 93, 32, 64, 123, 36, 62, 44, 104, 125, 44, 49, 48,
  48, 37, 44, 49, 44, 49, 44, 45, 49, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 101, 108, 101, 118,
  97, 116, 101, 32, 58, 32, 95, 100, 101, 112, 116, 104, 44, 95, 105, 115,
  95, 112, 108, 97, 105, 110, 44, 95, 105, 115, 95, 99, 111, 108, 111, 114,
  101, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 69, 108, 101, 118,
  97, 116, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 50, 100, 32,
  105, 109, 97, 103, 101, 115, 32, 105, 110, 116, 111, 32, 51, 100, 32, 118,
  111, 108, 117, 109, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58,
  32, 39, 100, 101, 112, 116, 104, 61, 54, 52, 39, 44, 32, 39, 105, 115,
  95, 112, 108, 97, 105, 110, 61, 49, 39, 32, 97, 110, 100, 32, 39, 105,
  115, 95, 99, 111, 108, 111, 114, 101, 100, 61, 49, 39, 46, 10, 101, 108,
  101, 118, 97, 116, 101, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  36, 123, 49, 61, 54, 52, 125, 62, 48, 34, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 50, 61, 49, 125, 44, 36, 123, 51, 61, 49, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 69, 108, 101, 118, 97, 116, 101, 32,
  50, 100, 32, 105, 109, 97, 103, 101, 36, 63, 32, 105, 110, 116, 111, 32,
  36, 49, 45, 115, 108, 105, 99, 101, 115, 32, 118, 111, 108, 117, 109, 101,
  40, 115, 41, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 32, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 48, 48, 37, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 45, 45, 110, 111, 114,
  109, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 36, 49, 44, 123,
  105, 102, 40, 36, 51, 44, 64, 123, 48, 44, 115, 125, 44, 49, 41, 125,
  10, 109, 61, 64, 123, 45, 50, 44, 109, 125, 32, 100, 61, 123, 64, 123,
  45, 50, 44, 77, 125, 45, 36, 109, 125, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 36, 49, 10, 45, 105, 102, 32, 36, 50, 32, 45, 45, 103, 101,
  91, 49, 93, 32, 123, 36, 109, 43, 36, 100, 42, 40, 36, 62, 43, 49,
  41, 47, 36, 49, 125, 10, 45, 101, 108, 115, 101, 32, 45, 45, 116, 50,
  91, 49, 93, 32, 123, 36, 109, 43, 36, 100, 42, 36, 62, 47, 36, 49,
  125, 44, 123, 36, 109, 43, 36, 100, 42, 40, 36, 62, 43, 49, 41, 47,
  36, 49, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 91, 45, 49,
  93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 91, 45,
  50, 93, 32, 45, 105, 102, 32, 36, 51, 32, 45, 42, 91, 45, 49, 93,
  32, 91, 48, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 106, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 44, 36, 62, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109,
  91, 48, 44, 49, 93, 32, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 101, 120, 112, 97, 110, 100, 95, 120,
  32, 58, 32, 115, 105, 122, 101, 95, 120, 62, 61, 48, 44, 95, 98, 111,
  117, 110, 100, 97, 114, 121, 61, 123, 32, 48, 61, 100, 105, 114, 105, 99,
  104, 108, 101, 116, 32, 124, 32, 49, 61, 110, 101, 117, 109, 97, 110, 110,
  32, 124, 32, 50, 61, 99, 121, 99, 108, 105, 99, 32, 125, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 69, 120, 112, 97, 110, 100, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 97, 108,
  111, 110, 103, 32, 116, 104, 101, 32, 120, 45, 97, 120, 105, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116,
  32, 118, 97, 108, 117, 101, 58, 32, 39, 98, 111, 114, 100, 101, 114, 61,
  49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 101, 120, 112, 97, 110, 100,
  95, 120, 32, 51, 48, 44, 48, 10, 101, 120, 112, 97, 110, 100, 95, 120,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48,
  32, 38, 38, 32, 36, 123, 50, 61, 49, 125, 62, 61, 48, 32, 38, 38,
  32, 36, 50, 60, 61, 50, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 69, 120, 112, 97, 110, 100, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 120, 45, 97, 120, 105, 115,
  32, 119, 105, 116, 104, 32, 115, 105, 122, 101, 32, 36, 49, 32, 97, 110,
  100, 32, 98, 111, 114, 100, 101, 114, 32, 99, 111, 110, 100, 105, 116, 105,
  111, 110, 115, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 114, 91, 36, 62, 93, 32,
  64, 123, 36, 62, 44, 119, 43, 50, 42, 36, 49, 125, 44, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48, 44, 36, 50,
  44, 48, 46, 53, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 101,
  120, 112, 97, 110, 100, 95, 120, 121, 32, 58, 32, 115, 105, 122, 101, 62,
  61, 48, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121, 61, 123, 32, 48,
  61, 100, 105, 114, 105, 99, 104, 108, 101, 116, 32, 124, 32, 49, 61, 110,
  101, 117, 109, 97, 110, 110, 32, 124, 32, 50, 61, 99, 121, 99, 108, 105,
  99, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 69, 120, 112,
  97, 110, 100, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 120, 121,
  45, 97, 120, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39,
  98, 111, 114, 100, 101, 114, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 32, 51, 48, 44, 48, 10,
  101, 120, 112, 97, 110, 100, 95, 120, 121, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 36, 49, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50,
  61, 49, 125, 62, 61, 48, 32, 38, 38, 32, 36, 50, 60, 61, 50, 34,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 69, 120, 112, 97, 110, 100,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 97, 108, 111, 110, 103, 32, 116,
  104, 101, 32, 120, 121, 45, 97, 120, 101, 115, 32, 119, 105, 116, 104, 32,
  115, 105, 122, 101, 32, 36, 49, 32, 97, 110, 100, 32, 98, 111, 114, 100,
  101, 114, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 115, 32, 36, 50,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 114, 91, 36, 62, 93, 32, 64, 123, 36, 62, 44, 119,
  43, 50, 42, 36, 49, 125, 44, 64, 123, 36, 62, 44, 104, 43, 50, 42,
  36, 49, 125, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48, 44,
  36, 50, 44, 48, 46, 53, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 101, 120, 112, 97, 110, 100, 95, 120, 121, 122, 32, 58, 32, 115, 105,
  122, 101, 62, 61, 48, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121, 61,
  123, 32, 48, 61, 100, 105, 114, 105, 99, 104, 108, 101, 116, 32, 124, 32,
  49, 61, 110, 101, 117, 109, 97, 110, 110, 32, 124, 32, 50, 61, 99, 121,
  99, 108, 105, 99, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  69, 120, 112, 97, 110, 100, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101,
  32, 120, 121, 122, 45, 97, 120, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117,
  101, 58, 32, 39, 98, 111, 114, 100, 101, 114, 61, 49, 39, 46, 10, 101,
  120, 112, 97, 110, 100, 95, 120, 121, 122, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 36, 49, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50,
  61, 49, 125, 62, 61, 48, 32, 38, 38, 32, 36, 50, 60, 61, 50, 34,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 69, 120, 112, 97, 110, 100,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 97, 108, 111, 110, 103, 32, 116,
  104, 101, 32, 120, 121, 122, 45, 97, 120, 101, 115, 32, 119, 105, 116, 104,
  32, 115, 105, 122, 101, 32, 36, 49, 32, 97, 110, 100, 32, 98, 111, 114,
  100, 101, 114, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 115, 32, 36,
  50, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 114, 91, 36, 62, 93, 32, 64, 123, 36, 62, 44,
  119, 43, 50, 42, 36, 49, 125, 44, 64, 123, 36, 62, 44, 104, 43, 50,
  42, 36, 49, 125, 44, 64, 123, 36, 62, 44, 100, 43, 50, 42, 36, 49,
  125, 44, 49, 48, 48, 37, 44, 48, 44, 36, 50, 44, 48, 46, 53, 44,
  48, 46, 53, 44, 48, 46, 53, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 101, 120, 112, 97, 110, 100,
  95, 121, 32, 58, 32, 115, 105, 122, 101, 95, 121, 62, 61, 48, 44, 95,
  98, 111, 117, 110, 100, 97, 114, 121, 61, 123, 32, 48, 61, 100, 105, 114,
  105, 99, 104, 108, 101, 116, 32, 124, 32, 49, 61, 110, 101, 117, 109, 97,
  110, 110, 32, 124, 32, 50, 61, 99, 121, 99, 108, 105, 99, 32, 125, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 69, 120, 112, 97, 110, 100, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32,
  97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 121, 45, 97, 120, 105, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117,
  108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 98, 111, 114, 100, 101,
  114, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 101, 120, 112, 97,
  110, 100, 95, 121, 32, 51, 48, 44, 48, 10, 101, 120, 112, 97, 110, 100,
  95, 121, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62,
  61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 49, 125, 62, 61, 48, 32,
  38, 38, 32, 36, 50, 60, 61, 50, 34, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 69, 120, 112, 97, 110, 100, 32, 105, 109, 97, 103, 101, 36,
  63, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 121, 45, 97, 120,
  105, 115, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101, 32, 36, 49, 32,
  97, 110, 100, 32, 98, 111, 114, 100, 101, 114, 32, 99, 111, 110, 100, 105,
  116, 105, 111, 110, 115, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 114, 91, 36, 62,
  93, 32, 49, 48, 48, 37, 44, 64, 123, 36, 62, 44, 104, 43, 50, 42,
  36, 49, 125, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48, 44,
  36, 50, 44, 48, 46, 53, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 101, 120, 112, 97, 110, 100, 95, 122, 32, 58, 32, 115, 105, 122, 101,
  95, 122, 62, 61, 48, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121, 61,
  123, 32, 48, 61, 100, 105, 114, 105, 99, 104, 108, 101, 116, 32, 124, 32,
  49, 61, 110, 101, 117, 109, 97, 110, 110, 32, 124, 32, 50, 61, 99, 121,
  99, 108, 105, 99, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  69, 120, 112, 97, 110, 100, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101,
  32, 122, 45, 97, 120, 105, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58,
  32, 39, 98, 111, 114, 100, 101, 114, 61, 49, 39, 46, 10, 101, 120, 112,
  97, 110, 100, 95, 122, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  36, 49, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 49, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 50, 60, 61, 50, 34, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 69, 120, 112, 97, 110, 100, 32, 105, 109, 97,
  103, 101, 36, 63, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 122,
  45, 97, 120, 105, 115, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101, 32,
  36, 49, 32, 97, 110, 100, 32, 98, 111, 114, 100, 101, 114, 32, 99, 111,
  110, 100, 105, 116, 105, 111, 110, 115, 32, 36, 50, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 114,
  91, 36, 62, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 64,
  123, 36, 62, 44, 100, 43, 50, 42, 36, 49, 125, 44, 49, 48, 48, 37,
  44, 48, 44, 36, 50, 44, 48, 46, 53, 44, 48, 46, 53, 44, 48, 46,
  53, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 109, 105, 114, 114, 111, 114, 32, 58, 32, 123, 32, 120,
  32, 124, 32, 121, 32, 124, 32, 122, 32, 125, 46, 46, 123, 32, 120, 32,
  124, 32, 121, 32, 124, 32, 122, 32, 125, 32, 58, 32, 40, 42, 41, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 77, 105, 114, 114, 111, 114, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32,
  97, 108, 111, 110, 103, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  97, 120, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 109, 105, 114,
  114, 111, 114, 32, 121, 32, 45, 45, 109, 105, 114, 114, 111, 114, 91, 48,
  93, 32, 99, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 109, 105, 114, 114, 111,
  114, 32, 120, 32, 45, 45, 109, 105, 114, 114, 111, 114, 32, 121, 32, 45,
  97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 32, 50, 44, 50,
  10, 35, 64, 103, 109, 105, 99, 32, 112, 101, 114, 109, 117, 116, 101, 32,
  58, 32, 112, 101, 114, 109, 117, 116, 97, 116, 105, 111, 110, 95, 115, 116,
  114, 105, 110, 103, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 80, 101, 114, 109, 117, 116, 101, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 32, 97, 120, 101, 115, 32,
  98, 121, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 112, 101, 114,
  109, 117, 116, 97, 116, 105, 111, 110, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 39, 112, 101, 114, 109, 117, 116, 97, 116, 105, 111, 110, 39,
  32, 105, 115, 32, 97, 32, 99, 111, 109, 98, 105, 110, 97, 116, 105, 111,
  110, 32, 111, 102, 32, 116, 104, 101, 32, 99, 104, 97, 114, 97, 99, 116,
  101, 114, 32, 115, 101, 116, 32, 123, 120, 124, 121, 124, 122, 124, 99, 125,
  44, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 101, 46, 103, 46, 32,
  39, 120, 121, 99, 122, 39, 44, 32, 39, 99, 120, 121, 122, 39, 44, 32,
  46, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 112, 101, 114, 109, 117, 116, 101,
  32, 121, 120, 122, 99, 10, 35, 64, 103, 109, 105, 99, 32, 114, 32, 58,
  32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 114, 101, 115, 105, 122, 101,
  39, 46, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32,
  114, 101, 115, 105, 122, 101, 32, 58, 32, 91, 105, 109, 97, 103, 101, 93,
  44, 95, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 44,
  95, 98, 111, 117, 110, 100, 97, 114, 121, 44, 95, 97, 120, 44, 95, 97,
  121, 44, 95, 97, 122, 44, 95, 97, 99, 32, 58, 32, 123, 91, 105, 109,
  97, 103, 101, 95, 119, 93, 32, 124, 32, 119, 105, 100, 116, 104, 62, 48,
  91, 37, 93, 125, 44, 95, 123, 91, 105, 109, 97, 103, 101, 95, 104, 93,
  32, 124, 32, 104, 101, 105, 103, 104, 116, 62, 48, 91, 37, 93, 125, 44,
  95, 123, 91, 105, 109, 97, 103, 101, 95, 100, 93, 32, 124, 32, 100, 101,
  112, 116, 104, 62, 48, 91, 37, 93, 125, 44, 95, 123, 91, 105, 109, 97,
  103, 101, 95, 115, 93, 32, 124, 32, 115, 112, 101, 99, 116, 114, 117, 109,
  62, 48, 91, 37, 93, 125, 44, 95, 105, 110, 116, 101, 114, 112, 111, 108,
  97, 116, 105, 111, 110, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121, 44,
  95, 97, 120, 44, 95, 97, 121, 44, 95, 97, 122, 44, 95, 97, 99, 32,
  58, 32, 40, 110, 111, 97, 114, 103, 115, 41, 32, 58, 32, 40, 42, 41,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 115, 105, 122, 101,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  32, 119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  103, 101, 111, 109, 101, 116, 114, 121, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 114, 39, 41,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 105, 110, 116, 101,
  114, 112, 111, 108, 97, 116, 105, 111, 110, 39, 32, 99, 97, 110, 32, 98,
  101, 32, 123, 32, 45, 49, 61, 110, 111, 110, 101, 32, 40, 109, 101, 109,
  111, 114, 121, 32, 99, 111, 110, 116, 101, 110, 116, 41, 32, 124, 32, 48,
  61, 110, 111, 110, 101, 32, 124, 32, 49, 61, 110, 101, 97, 114, 101, 115,
  116, 32, 124, 32, 50, 61, 97, 118, 101, 114, 97, 103, 101, 32, 124, 32,
  51, 61, 108, 105, 110, 101, 97, 114, 32, 124, 32, 52, 61, 103, 114, 105,
  100, 32, 124, 32, 53, 61, 98, 105, 99, 117, 98, 105, 99, 32, 124, 32,
  54, 61, 108, 97, 110, 99, 122, 111, 115, 32, 125, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 39,
  32, 104, 97, 115, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32, 109,
  101, 97, 110, 105, 110, 103, 115, 44, 32, 97, 99, 99, 111, 114, 100, 105,
  110, 103, 32, 116, 111, 32, 116, 104, 101, 32, 99, 104, 111, 115, 101, 110,
  32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 39,
  32, 109, 111, 100, 101, 32, 58, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 46, 32, 87, 104, 101, 110, 32, 39, 105, 110, 116, 101, 114, 112, 111,
  108, 97, 116, 105, 111, 110, 61, 61, 123, 32, 45, 49, 32, 124, 32, 49,
  32, 124, 32, 50, 32, 124, 32, 52, 32, 125, 39, 44, 32, 39, 98, 111,
  117, 110, 100, 97, 114, 121, 39, 32, 105, 115, 32, 109, 101, 97, 110, 105,
  110, 103, 108, 101, 115, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 46, 32, 87, 104, 101, 110, 32, 39, 105, 110, 116, 101, 114, 112, 111,
  108, 97, 116, 105, 111, 110, 61, 61, 48, 39, 44, 32, 39, 98, 111, 117,
  110, 100, 97, 114, 121, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32,
  48, 61, 100, 105, 114, 105, 99, 104, 108, 101, 116, 32, 124, 32, 49, 61,
  110, 101, 117, 109, 97, 110, 110, 32, 124, 32, 50, 61, 99, 121, 99, 108,
  105, 99, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 46,
  32, 87, 104, 101, 110, 32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97,
  116, 105, 111, 110, 61, 61, 123, 32, 51, 32, 124, 32, 53, 32, 124, 32,
  54, 32, 125, 39, 44, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 39,
  32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 110, 111, 110, 101,
  32, 124, 32, 49, 61, 110, 101, 117, 109, 97, 110, 110, 32, 125, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 97, 120, 44, 97, 121, 44,
  97, 122, 44, 97, 99, 39, 32, 115, 101, 116, 32, 116, 104, 101, 32, 97,
  108, 105, 103, 110, 109, 101, 110, 116, 32, 109, 111, 100, 101, 32, 97, 108,
  111, 110, 103, 32, 101, 97, 99, 104, 32, 97, 120, 105, 115, 32, 119, 104,
  101, 110, 32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111,
  110, 61, 48, 32, 111, 114, 32, 52, 39, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 40, 115, 101, 116, 32, 116, 111, 32, 39, 48, 39, 32, 98,
  121, 32, 100, 101, 102, 97, 117, 108, 116, 44, 32, 109, 117, 115, 116, 32,
  98, 101, 32, 100, 101, 102, 105, 110, 101, 100, 32, 105, 110, 32, 114, 97,
  110, 103, 101, 32, 91, 48, 44, 49, 93, 41, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 40, 110, 111, 97, 114, 103, 115, 41, 32, 114, 117,
  110, 115, 32, 105, 110, 116, 101, 114, 97, 99, 116, 105, 118, 101, 32, 109,
  111, 100, 101, 32, 40, 117, 115, 101, 115, 32, 116, 104, 101, 32, 105, 110,
  115, 116, 97, 110, 116, 32, 119, 105, 110, 100, 111, 119, 32, 91, 48, 93,
  32, 105, 102, 32, 111, 112, 101, 110, 101, 100, 41, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97,
  116, 105, 111, 110, 61, 49, 39, 44, 32, 39, 98, 111, 117, 110, 100, 97,
  114, 121, 61, 48, 39, 32, 97, 110, 100, 32, 39, 97, 120, 61, 97, 121,
  61, 97, 122, 61, 97, 99, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  40, 48, 44, 49, 59, 48, 44, 49, 94, 48, 44, 48, 59, 49, 44, 49,
  94, 49, 44, 49, 59, 49, 44, 49, 41, 32, 45, 114, 101, 115, 105, 122,
  101, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 51, 32, 45, 109, 117,
  108, 91, 45, 50, 93, 32, 91, 45, 49, 93, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 50, 53, 54,
  44, 49, 50, 56, 44, 49, 44, 51, 44, 50, 32, 45, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 49, 50, 48, 37, 44, 49, 50, 48,
  37, 44, 49, 44, 51, 44, 48, 44, 49, 44, 48, 46, 53, 44, 48, 46,
  53, 32, 45, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 49,
  50, 48, 37, 44, 49, 50, 48, 37, 44, 49, 44, 51, 44, 48, 44, 48,
  44, 48, 46, 50, 44, 48, 46, 50, 32, 45, 45, 114, 101, 115, 105, 122,
  101, 91, 45, 49, 93, 32, 91, 48, 93, 44, 91, 48, 93, 44, 49, 44,
  51, 44, 52, 10, 35, 64, 103, 109, 105, 99, 32, 112, 111, 119, 50, 32,
  58, 32, 95, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110,
  44, 95, 98, 111, 117, 110, 100, 97, 114, 121, 44, 95, 97, 120, 44, 95,
  97, 121, 44, 95, 97, 122, 44, 95, 97, 99, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 82, 101, 115, 105, 122, 101, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 115, 111, 32, 116, 104,
  97, 116, 32, 101, 97, 99, 104, 32, 100, 105, 109, 101, 110, 115, 105, 111,
  110, 32, 105, 115, 32, 97, 32, 112, 111, 119, 101, 114, 32, 111, 102, 32,
  50, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 105, 110, 116,
  101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 39, 32, 99, 97, 110, 32,
  98, 101, 32, 123, 32, 45, 49, 61, 110, 111, 110, 101, 32, 40, 109, 101,
  109, 111, 114, 121, 32, 99, 111, 110, 116, 101, 110, 116, 41, 32, 124, 32,
  48, 61, 110, 111, 110, 101, 32, 124, 32, 49, 61, 110, 101, 97, 114, 101,
  115, 116, 32, 124, 32, 50, 61, 97, 118, 101, 114, 97, 103, 101, 32, 124,
  32, 51, 61, 108, 105, 110, 101, 97, 114, 32, 124, 32, 52, 61, 103, 114,
  105, 100, 32, 124, 32, 53, 61, 98, 105, 99, 117, 98, 105, 99, 32, 124,
  32, 54, 61, 108, 97, 110, 99, 122, 111, 115, 32, 125, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121,
  39, 32, 104, 97, 115, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32,
  109, 101, 97, 110, 105, 110, 103, 115, 44, 32, 97, 99, 99, 111, 114, 100,
  105, 110, 103, 32, 116, 111, 32, 116, 104, 101, 32, 99, 104, 111, 115, 101,
  110, 32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110,
  39, 32, 109, 111, 100, 101, 32, 58, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 46, 32, 87, 104, 101, 110, 32, 39, 105, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 105, 111, 110, 61, 61, 123, 32, 45, 49, 32, 124, 32,
  49, 32, 124, 32, 50, 32, 124, 32, 52, 32, 125, 39, 44, 32, 39, 98,
  111, 117, 110, 100, 97, 114, 121, 39, 32, 105, 115, 32, 109, 101, 97, 110,
  105, 110, 103, 108, 101, 115, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 46, 32, 87, 104, 101, 110, 32, 39, 105, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 105, 111, 110, 61, 61, 48, 39, 44, 32, 39, 98, 111,
  117, 110, 100, 97, 114, 121, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123,
  32, 48, 61, 100, 105, 114, 105, 99, 104, 108, 101, 116, 32, 124, 32, 49,
  61, 110, 101, 117, 109, 97, 110, 110, 32, 124, 32, 50, 61, 99, 121, 99,
  108, 105, 99, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  46, 32, 87, 104, 101, 110, 32, 39, 105, 110, 116, 101, 114, 112, 111, 108,
  97, 116, 105, 111, 110, 61, 61, 123, 32, 51, 32, 124, 32, 53, 32, 124,
  32, 54, 32, 125, 39, 44, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121,
  39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 110, 111, 110,
  101, 32, 124, 32, 49, 61, 110, 101, 117, 109, 97, 110, 110, 32, 125, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 97, 120, 44, 97, 121,
  44, 97, 122, 44, 97, 99, 39, 32, 115, 101, 116, 32, 116, 104, 101, 32,
  97, 108, 105, 103, 110, 109, 101, 110, 116, 32, 109, 111, 100, 101, 32, 97,
  108, 111, 110, 103, 32, 101, 97, 99, 104, 32, 97, 120, 105, 115, 32, 119,
  104, 101, 110, 32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105,
  111, 110, 61, 48, 39, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40,
  115, 101, 116, 32, 116, 111, 32, 39, 48, 39, 32, 98, 121, 32, 100, 101,
  102, 97, 117, 108, 116, 44, 32, 109, 117, 115, 116, 32, 98, 101, 32, 100,
  101, 102, 105, 110, 101, 100, 32, 105, 110, 32, 114, 97, 110, 103, 101, 32,
  91, 48, 44, 49, 93, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58,
  32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 61,
  48, 39, 44, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 61, 48, 39,
  32, 97, 110, 100, 32, 39, 97, 120, 61, 97, 121, 61, 97, 122, 61, 97,
  99, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 114, 101, 115,
  105, 122, 101, 95, 112, 111, 119, 50, 91, 45, 49, 93, 32, 48, 10, 114,
  101, 115, 105, 122, 101, 95, 112, 111, 119, 50, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 48,
  125, 41, 32, 38, 38, 32, 36, 49, 62, 61, 45, 49, 32, 38, 38, 32,
  36, 49, 60, 61, 54, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50,
  61, 48, 125, 44, 36, 123, 51, 61, 48, 125, 44, 36, 123, 52, 61, 48,
  125, 44, 36, 123, 53, 61, 48, 125, 44, 36, 123, 54, 61, 48, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 115, 105, 122, 101, 32,
  105, 109, 97, 103, 101, 36, 63, 32, 115, 111, 32, 116, 104, 97, 116, 32,
  101, 97, 99, 104, 32, 100, 105, 109, 101, 110, 115, 105, 111, 110, 32, 105,
  115, 32, 97, 32, 112, 111, 119, 101, 114, 32, 111, 102, 32, 50, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  10, 45, 114, 91, 36, 62, 93, 32, 64, 123, 36, 62, 44, 50, 94, 40,
  114, 111, 117, 110, 100, 40, 108, 111, 103, 50, 40, 119, 41, 44, 49, 44,
  49, 41, 41, 125, 44, 64, 123, 36, 62, 44, 50, 94, 40, 114, 111, 117,
  110, 100, 40, 108, 111, 103, 50, 40, 104, 41, 44, 49, 44, 49, 41, 41,
  125, 44, 64, 123, 36, 62, 44, 50, 94, 40, 114, 111, 117, 110, 100, 40,
  108, 111, 103, 50, 40, 100, 41, 44, 49, 44, 49, 41, 41, 125, 44, 49,
  48, 48, 37, 44, 36, 123, 49, 45, 54, 125, 10, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 114, 114, 50,
  100, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 114, 101, 115,
  105, 122, 101, 95, 114, 97, 116, 105, 111, 50, 100, 39, 46, 10, 114, 114,
  50, 100, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36,
  63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 114, 101, 115, 105, 122, 101,
  95, 114, 97, 116, 105, 111, 50, 100, 32, 36, 42, 10, 35, 64, 103, 109,
  105, 99, 32, 114, 101, 115, 105, 122, 101, 95, 114, 97, 116, 105, 111, 50,
  100, 32, 58, 32, 119, 105, 100, 116, 104, 62, 48, 44, 104, 101, 105, 103,
  104, 116, 62, 48, 44, 95, 109, 111, 100, 101, 61, 123, 32, 48, 61, 105,
  110, 115, 105, 100, 101, 32, 124, 32, 49, 61, 111, 117, 116, 115, 105, 100,
  101, 32, 124, 32, 50, 61, 112, 97, 100, 100, 101, 100, 32, 125, 44, 48,
  61, 60, 95, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110,
  60, 61, 54, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 115,
  105, 122, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 32, 119, 104, 105, 108, 101, 32, 112, 114, 101, 115, 101, 114,
  118, 105, 110, 103, 32, 116, 104, 101, 105, 114, 32, 97, 115, 112, 101, 99,
  116, 32, 114, 97, 116, 105, 111, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 114, 114, 50, 100,
  39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 109, 111,
  100, 101, 61, 48, 39, 32, 97, 110, 100, 32, 39, 105, 110, 116, 101, 114,
  112, 111, 108, 97, 116, 105, 111, 110, 61, 54, 39, 46, 10, 114, 101, 115,
  105, 122, 101, 95, 114, 97, 116, 105, 111, 50, 100, 32, 58, 10, 45, 118,
  32, 45, 32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43,
  10, 45, 95, 36, 48, 32, 36, 42, 10, 95, 114, 101, 115, 105, 122, 101,
  95, 114, 97, 116, 105, 111, 50, 100, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 34, 36, 49, 62, 48, 32, 38, 38, 32, 36, 50, 62, 48, 32,
  38, 38, 32, 36, 123, 51, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32,
  36, 51, 60, 61, 50, 32, 38, 38, 32, 36, 123, 52, 61, 54, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 52, 60, 61, 54, 34, 10, 45, 101, 91,
  48, 45, 45, 51, 93, 32, 34, 82, 101, 115, 105, 122, 101, 32, 50, 100,
  32, 105, 109, 97, 103, 101, 34, 36, 95, 95, 115, 34, 32, 116, 111, 32,
  36, 49, 120, 36, 50, 32, 119, 105, 116, 104, 32, 114, 97, 116, 105, 111,
  45, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 36, 51, 44, 105,
  110, 115, 105, 100, 101, 44, 111, 117, 116, 115, 105, 100, 101, 44, 112, 97,
  100, 100, 101, 100, 125, 92, 10, 34, 32, 109, 111, 100, 101, 32, 97, 110,
  100, 32, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 32,
  116, 121, 112, 101, 32, 36, 52, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 114, 97, 116, 105, 111, 61,
  64, 123, 36, 62, 44, 105, 102, 40, 36, 51, 61, 61, 49, 44, 109, 97,
  120, 40, 36, 49, 47, 119, 44, 36, 50, 47, 104, 41, 44, 109, 105, 110,
  40, 36, 49, 47, 119, 44, 36, 50, 47, 104, 41, 41, 125, 10, 45, 114,
  91, 36, 62, 93, 32, 64, 123, 36, 62, 44, 119, 42, 36, 114, 97, 116,
  105, 111, 125, 44, 64, 123, 36, 62, 44, 104, 42, 36, 114, 97, 116, 105,
  111, 125, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 36, 52, 10,
  45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 51, 61, 61, 50,
  125, 32, 45, 114, 32, 36, 49, 44, 36, 50, 44, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 114, 50, 100, 120, 32, 58, 32, 101, 113, 46, 32, 116,
  111, 32, 39, 45, 114, 101, 115, 105, 122, 101, 50, 100, 120, 39, 46, 10,
  114, 50, 100, 120, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61,
  34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 114, 101, 115, 105,
  122, 101, 50, 100, 120, 32, 36, 42, 10, 35, 64, 103, 109, 105, 99, 32,
  114, 101, 115, 105, 122, 101, 50, 100, 120, 32, 58, 32, 119, 105, 100, 116,
  104, 91, 37, 93, 62, 48, 44, 95, 105, 110, 116, 101, 114, 112, 111, 108,
  97, 116, 105, 111, 110, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121, 44,
  95, 97, 120, 44, 95, 97, 121, 44, 95, 97, 122, 44, 95, 97, 99, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 115, 105, 122, 101, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32,
  97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 120, 45, 97, 120, 105, 115,
  44, 32, 112, 114, 101, 115, 101, 114, 118, 105, 110, 103, 32, 50, 100, 32,
  114, 97, 116, 105, 111, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 114, 50, 100, 120, 39, 41,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 105, 110, 116, 101,
  114, 112, 111, 108, 97, 116, 105, 111, 110, 39, 32, 99, 97, 110, 32, 98,
  101, 32, 123, 32, 45, 49, 61, 110, 111, 110, 101, 32, 40, 109, 101, 109,
  111, 114, 121, 32, 99, 111, 110, 116, 101, 110, 116, 41, 32, 124, 32, 48,
  61, 110, 111, 110, 101, 32, 124, 32, 49, 61, 110, 101, 97, 114, 101, 115,
  116, 32, 124, 32, 50, 61, 97, 118, 101, 114, 97, 103, 101, 32, 124, 32,
  51, 61, 108, 105, 110, 101, 97, 114, 32, 124, 32, 52, 61, 103, 114, 105,
  100, 32, 124, 32, 53, 61, 98, 105, 99, 117, 98, 105, 99, 32, 124, 32,
  54, 61, 108, 97, 110, 99, 122, 111, 115, 32, 125, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 39,
  32, 104, 97, 115, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32, 109,
  101, 97, 110, 105, 110, 103, 115, 44, 32, 97, 99, 99, 111, 114, 100, 105,
  110, 103, 32, 116, 111, 32, 116, 104, 101, 32, 99, 104, 111, 115, 101, 110,
  32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 39,
  32, 109, 111, 100, 101, 32, 58, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 46, 32, 87, 104, 101, 110, 32, 39, 105, 110, 116, 101, 114, 112, 111,
  108, 97, 116, 105, 111, 110, 61, 61, 123, 32, 45, 49, 32, 124, 32, 49,
  32, 124, 32, 50, 32, 124, 32, 52, 32, 125, 39, 44, 32, 39, 98, 111,
  117, 110, 100, 97, 114, 121, 39, 32, 105, 115, 32, 109, 101, 97, 110, 105,
  110, 103, 108, 101, 115, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 46, 32, 87, 104, 101, 110, 32, 39, 105, 110, 116, 101, 114, 112, 111,
  108, 97, 116, 105, 111, 110, 61, 61, 48, 39, 44, 32, 39, 98, 111, 117,
  110, 100, 97, 114, 121, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32,
  48, 61, 100, 105, 114, 105, 99, 104, 108, 101, 116, 32, 124, 32, 49, 61,
  110, 101, 117, 109, 97, 110, 110, 32, 124, 32, 50, 61, 99, 121, 99, 108,
  105, 99, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 46,
  32, 87, 104, 101, 110, 32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97,
  116, 105, 111, 110, 61, 61, 123, 32, 51, 32, 124, 32, 53, 32, 124, 32,
  54, 32, 125, 39, 44, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 39,
  32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 110, 111, 110, 101,
  32, 124, 32, 49, 61, 110, 101, 117, 109, 97, 110, 110, 32, 125, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 97, 120, 44, 97, 121, 44,
  97, 122, 44, 97, 99, 39, 32, 115, 101, 116, 32, 116, 104, 101, 32, 97,
  108, 105, 103, 110, 109, 101, 110, 116, 32, 109, 111, 100, 101, 32, 97, 108,
  111, 110, 103, 32, 101, 97, 99, 104, 32, 97, 120, 105, 115, 32, 119, 104,
  101, 110, 32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111,
  110, 61, 48, 39, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 115,
  101, 116, 32, 116, 111, 32, 39, 48, 39, 32, 98, 121, 32, 100, 101, 102,
  97, 117, 108, 116, 44, 32, 109, 117, 115, 116, 32, 98, 101, 32, 100, 101,
  102, 105, 110, 101, 100, 32, 105, 110, 32, 114, 97, 110, 103, 101, 32, 91,
  48, 44, 49, 93, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 61, 51,
  39, 44, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 61, 48, 39, 32,
  97, 110, 100, 32, 39, 97, 120, 61, 97, 121, 61, 97, 122, 61, 97, 99,
  61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 114, 101, 115, 105,
  122, 101, 50, 100, 120, 32, 49, 48, 48, 44, 50, 32, 45, 97, 112, 112,
  101, 110, 100, 32, 120, 10, 114, 101, 115, 105, 122, 101, 50, 100, 120, 32,
  58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63, 34, 32,
  45, 118, 32, 43, 10, 45, 95, 36, 48, 32, 36, 42, 10, 95, 114, 101,
  115, 105, 122, 101, 50, 100, 120, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 34, 36, 49, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 51, 125,
  62, 61, 48, 32, 38, 38, 32, 36, 50, 60, 61, 54, 32, 38, 38, 32,
  36, 123, 51, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 51, 60,
  61, 50, 32, 38, 38, 32, 36, 123, 52, 61, 48, 125, 62, 61, 48, 32,
  38, 38, 32, 36, 52, 60, 61, 49, 32, 38, 38, 32, 36, 123, 53, 61,
  48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 53, 60, 61, 49, 32, 38,
  38, 32, 36, 123, 54, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36,
  54, 60, 61, 49, 32, 38, 38, 32, 36, 123, 55, 61, 48, 125, 62, 61,
  48, 32, 38, 38, 32, 36, 55, 60, 61, 49, 34, 10, 45, 101, 91, 48,
  45, 45, 51, 93, 32, 34, 82, 101, 115, 105, 122, 101, 32, 50, 100, 32,
  105, 109, 97, 103, 101, 34, 36, 95, 95, 115, 34, 32, 116, 111, 32, 36,
  49, 32, 112, 105, 120, 101, 108, 115, 32, 97, 108, 111, 110, 103, 32, 116,
  104, 101, 32, 120, 45, 97, 120, 105, 115, 44, 32, 112, 114, 101, 115, 101,
  114, 118, 105, 110, 103, 32, 50, 100, 32, 114, 97, 116, 105, 111, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 115, 105, 122, 101, 61, 123, 105, 102,
  40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32,
  36, 49, 125, 44, 36, 49, 42, 119, 44, 36, 49, 41, 125, 10, 45, 114,
  32, 123, 109, 97, 120, 40, 49, 44, 36, 115, 105, 122, 101, 41, 125, 44,
  123, 109, 97, 120, 40, 49, 44, 104, 42, 36, 115, 105, 122, 101, 47, 119,
  41, 125, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 36, 123, 50,
  45, 55, 125, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 114, 50, 100, 121,
  32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 114, 101, 115, 105,
  122, 101, 50, 100, 121, 39, 46, 10, 114, 50, 100, 121, 32, 58, 10, 45,
  118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32,
  43, 10, 45, 95, 114, 101, 115, 105, 122, 101, 50, 100, 121, 32, 36, 42,
  10, 35, 64, 103, 109, 105, 99, 32, 114, 101, 115, 105, 122, 101, 50, 100,
  121, 32, 58, 32, 104, 101, 105, 103, 104, 116, 91, 37, 93, 62, 61, 48,
  44, 95, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 44,
  95, 98, 111, 117, 110, 100, 97, 114, 121, 44, 95, 97, 120, 44, 95, 97,
  121, 44, 95, 97, 122, 44, 95, 97, 99, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 82, 101, 115, 105, 122, 101, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 97, 108, 111, 110, 103, 32,
  116, 104, 101, 32, 121, 45, 97, 120, 105, 115, 44, 32, 112, 114, 101, 115,
  101, 114, 118, 105, 110, 103, 32, 50, 100, 32, 114, 97, 116, 105, 111, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116,
  111, 32, 39, 45, 114, 50, 100, 121, 39, 41, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116,
  105, 111, 110, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 45, 49,
  61, 110, 111, 110, 101, 32, 40, 109, 101, 109, 111, 114, 121, 32, 99, 111,
  110, 116, 101, 110, 116, 41, 32, 124, 32, 48, 61, 110, 111, 110, 101, 32,
  124, 32, 49, 61, 110, 101, 97, 114, 101, 115, 116, 32, 124, 32, 50, 61,
  97, 118, 101, 114, 97, 103, 101, 32, 124, 32, 51, 61, 108, 105, 110, 101,
  97, 114, 32, 124, 32, 52, 61, 103, 114, 105, 100, 32, 124, 32, 53, 61,
  98, 105, 99, 117, 98, 105, 99, 32, 124, 32, 54, 61, 108, 97, 110, 99,
  122, 111, 115, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  39, 98, 111, 117, 110, 100, 97, 114, 121, 39, 32, 104, 97, 115, 32, 100,
  105, 102, 102, 101, 114, 101, 110, 116, 32, 109, 101, 97, 110, 105, 110, 103,
  115, 44, 32, 97, 99, 99, 111, 114, 100, 105, 110, 103, 32, 116, 111, 32,
  116, 104, 101, 32, 99, 104, 111, 115, 101, 110, 32, 39, 105, 110, 116, 101,
  114, 112, 111, 108, 97, 116, 105, 111, 110, 39, 32, 109, 111, 100, 101, 32,
  58, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 46, 32, 87, 104, 101,
  110, 32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110,
  61, 61, 123, 32, 45, 49, 32, 124, 32, 49, 32, 124, 32, 50, 32, 124,
  32, 52, 32, 125, 39, 44, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121,
  39, 32, 105, 115, 32, 109, 101, 97, 110, 105, 110, 103, 108, 101, 115, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 46, 32, 87, 104, 101,
  110, 32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110,
  61, 61, 48, 39, 44, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 39,
  32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 100, 105, 114, 105,
  99, 104, 108, 101, 116, 32, 124, 32, 49, 61, 110, 101, 117, 109, 97, 110,
  110, 32, 124, 32, 50, 61, 99, 121, 99, 108, 105, 99, 32, 125, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 46, 32, 87, 104, 101, 110, 32,
  39, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 61, 61,
  123, 32, 51, 32, 124, 32, 53, 32, 124, 32, 54, 32, 125, 39, 44, 32,
  39, 98, 111, 117, 110, 100, 97, 114, 121, 39, 32, 99, 97, 110, 32, 98,
  101, 32, 123, 32, 48, 61, 110, 111, 110, 101, 32, 124, 32, 49, 61, 110,
  101, 117, 109, 97, 110, 110, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 39, 97, 120, 44, 97, 121, 44, 97, 122, 44, 97, 99, 39,
  32, 115, 101, 116, 32, 116, 104, 101, 32, 97, 108, 105, 103, 110, 109, 101,
  110, 116, 32, 109, 111, 100, 101, 32, 97, 108, 111, 110, 103, 32, 101, 97,
  99, 104, 32, 97, 120, 105, 115, 32, 119, 104, 101, 110, 32, 39, 105, 110,
  116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 61, 48, 39, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 40, 115, 101, 116, 32, 116, 111, 32,
  39, 48, 39, 32, 98, 121, 32, 100, 101, 102, 97, 117, 108, 116, 44, 32,
  109, 117, 115, 116, 32, 98, 101, 32, 100, 101, 102, 105, 110, 101, 100, 32,
  105, 110, 32, 114, 97, 110, 103, 101, 32, 91, 48, 44, 49, 93, 41, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108,
  116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 105, 110, 116, 101, 114,
  112, 111, 108, 97, 116, 105, 111, 110, 61, 51, 39, 44, 32, 39, 98, 111,
  117, 110, 100, 97, 114, 121, 61, 48, 39, 32, 97, 110, 100, 32, 39, 97,
  120, 61, 97, 121, 61, 97, 122, 61, 97, 99, 61, 48, 39, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 45, 114, 101, 115, 105, 122, 101, 50, 100, 121, 32,
  49, 48, 48, 44, 50, 32, 45, 97, 112, 112, 101, 110, 100, 32, 120, 10,
  114, 101, 115, 105, 122, 101, 50, 100, 121, 32, 58, 10, 45, 118, 32, 45,
  32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45,
  95, 36, 48, 32, 36, 42, 10, 95, 114, 101, 115, 105, 122, 101, 50, 100,
  121, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61,
  48, 32, 38, 38, 32, 36, 123, 50, 61, 51, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 50, 60, 61, 54, 32, 38, 38, 32, 36, 123, 51, 61, 48,
  125, 62, 61, 48, 32, 38, 38, 32, 36, 51, 60, 61, 50, 32, 38, 38,
  32, 36, 123, 52, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 52,
  60, 61, 49, 32, 38, 38, 32, 36, 123, 53, 61, 48, 125, 62, 61, 48,
  32, 38, 38, 32, 36, 53, 60, 61, 49, 32, 38, 38, 32, 36, 123, 54,
  61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 54, 60, 61, 49, 32,
  38, 38, 32, 36, 123, 55, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32,
  36, 55, 60, 61, 49, 34, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32,
  34, 82, 101, 115, 105, 122, 101, 32, 50, 100, 32, 105, 109, 97, 103, 101,
  34, 36, 95, 95, 115, 34, 32, 116, 111, 32, 36, 49, 32, 112, 105, 120,
  101, 108, 115, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 121, 45,
  97, 120, 105, 115, 44, 32, 112, 114, 101, 115, 101, 114, 118, 105, 110, 103,
  32, 50, 100, 32, 114, 97, 116, 105, 111, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 115, 105, 122, 101, 61, 123, 105, 102, 40, 64, 123, 45, 105,
  115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 49, 125, 44, 36,
  49, 42, 104, 44, 36, 49, 41, 125, 10, 45, 114, 32, 123, 109, 97, 120,
  40, 49, 44, 119, 42, 36, 115, 105, 122, 101, 47, 104, 41, 125, 44, 123,
  109, 97, 120, 40, 49, 44, 36, 115, 105, 122, 101, 41, 125, 44, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 36, 123, 50, 45, 55, 125, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 114, 51, 100, 120, 32, 58, 32, 101, 113,
  46, 32, 116, 111, 32, 39, 45, 114, 101, 115, 105, 122, 101, 51, 100, 120,
  39, 46, 10, 114, 51, 100, 120, 32, 58, 10, 45, 118, 32, 45, 32, 95,
  95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 114,
  101, 115, 105, 122, 101, 51, 100, 120, 32, 36, 42, 10, 35, 64, 103, 109,
  105, 99, 32, 114, 101, 115, 105, 122, 101, 51, 100, 120, 32, 58, 32, 119,
  105, 100, 116, 104, 91, 37, 93, 62, 48, 44, 95, 105, 110, 116, 101, 114,
  112, 111, 108, 97, 116, 105, 111, 110, 44, 95, 98, 111, 117, 110, 100, 97,
  114, 121, 44, 95, 97, 120, 44, 95, 97, 121, 44, 95, 97, 122, 44, 95,
  97, 99, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 115, 105,
  122, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 120, 45, 97,
  120, 105, 115, 44, 32, 112, 114, 101, 115, 101, 114, 118, 105, 110, 103, 32,
  51, 100, 32, 114, 97, 116, 105, 111, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 114, 51, 100,
  120, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 105,
  110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 39, 32, 99, 97,
  110, 32, 98, 101, 32, 123, 32, 45, 49, 61, 110, 111, 110, 101, 32, 40,
  109, 101, 109, 111, 114, 121, 32, 99, 111, 110, 116, 101, 110, 116, 41, 32,
  124, 32, 48, 61, 110, 111, 110, 101, 32, 124, 32, 49, 61, 110, 101, 97,
  114, 101, 115, 116, 32, 124, 32, 50, 61, 97, 118, 101, 114, 97, 103, 101,
  32, 124, 32, 51, 61, 108, 105, 110, 101, 97, 114, 32, 124, 32, 52, 61,
  103, 114, 105, 100, 32, 124, 32, 53, 61, 98, 105, 99, 117, 98, 105, 99,
  32, 124, 32, 54, 61, 108, 97, 110, 99, 122, 111, 115, 32, 125, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 98, 111, 117, 110, 100, 97,
  114, 121, 39, 32, 104, 97, 115, 32, 100, 105, 102, 102, 101, 114, 101, 110,
  116, 32, 109, 101, 97, 110, 105, 110, 103, 115, 44, 32, 97, 99, 99, 111,
  114, 100, 105, 110, 103, 32, 116, 111, 32, 116, 104, 101, 32, 99, 104, 111,
  115, 101, 110, 32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105,
  111, 110, 39, 32, 109, 111, 100, 101, 32, 58, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 46, 32, 87, 104, 101, 110, 32, 39, 105, 110, 116, 101,
  114, 112, 111, 108, 97, 116, 105, 111, 110, 61, 61, 123, 32, 45, 49, 32,
  124, 32, 49, 32, 124, 32, 50, 32, 124, 32, 52, 32, 125, 39, 44, 32,
  39, 98, 111, 117, 110, 100, 97, 114, 121, 39, 32, 105, 115, 32, 109, 101,
  97, 110, 105, 110, 103, 108, 101, 115, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 46, 32, 87, 104, 101, 110, 32, 39, 105, 110, 116, 101,
  114, 112, 111, 108, 97, 116, 105, 111, 110, 61, 61, 48, 39, 44, 32, 39,
  98, 111, 117, 110, 100, 97, 114, 121, 39, 32, 99, 97, 110, 32, 98, 101,
  32, 123, 32, 48, 61, 100, 105, 114, 105, 99, 104, 108, 101, 116, 32, 124,
  32, 49, 61, 110, 101, 117, 109, 97, 110, 110, 32, 124, 32, 50, 61, 99,
  121, 99, 108, 105, 99, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 46, 32, 87, 104, 101, 110, 32, 39, 105, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 105, 111, 110, 61, 61, 123, 32, 51, 32, 124, 32, 53,
  32, 124, 32, 54, 32, 125, 39, 44, 32, 39, 98, 111, 117, 110, 100, 97,
  114, 121, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 110,
  111, 110, 101, 32, 124, 32, 49, 61, 110, 101, 117, 109, 97, 110, 110, 32,
  125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 97, 120, 44,
  97, 121, 44, 97, 122, 44, 97, 99, 39, 32, 115, 101, 116, 32, 116, 104,
  101, 32, 97, 108, 105, 103, 110, 109, 101, 110, 116, 32, 109, 111, 100, 101,
  32, 97, 108, 111, 110, 103, 32, 101, 97, 99, 104, 32, 97, 120, 105, 115,
  32, 119, 104, 101, 110, 32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97,
  116, 105, 111, 110, 61, 48, 39, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 40, 115, 101, 116, 32, 116, 111, 32, 39, 48, 39, 32, 98, 121, 32,
  100, 101, 102, 97, 117, 108, 116, 44, 32, 109, 117, 115, 116, 32, 98, 101,
  32, 100, 101, 102, 105, 110, 101, 100, 32, 105, 110, 32, 114, 97, 110, 103,
  101, 32, 91, 48, 44, 49, 93, 41, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  115, 58, 32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111,
  110, 61, 51, 39, 44, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 61,
  48, 39, 32, 97, 110, 100, 32, 39, 97, 120, 61, 97, 121, 61, 97, 122,
  61, 97, 99, 61, 48, 39, 46, 10, 114, 101, 115, 105, 122, 101, 51, 100,
  120, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63,
  34, 32, 45, 118, 32, 43, 10, 45, 95, 36, 48, 32, 36, 42, 10, 95,
  114, 101, 115, 105, 122, 101, 51, 100, 120, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 36, 49, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61,
  51, 125, 62, 61, 48, 32, 38, 38, 32, 36, 50, 60, 61, 54, 32, 38,
  38, 32, 36, 123, 51, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36,
  51, 60, 61, 50, 32, 38, 38, 32, 36, 123, 52, 61, 48, 125, 62, 61,
  48, 32, 38, 38, 32, 36, 52, 60, 61, 49, 32, 38, 38, 32, 36, 123,
  53, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 53, 60, 61, 49,
  32, 38, 38, 32, 36, 123, 54, 61, 48, 125, 62, 61, 48, 32, 38, 38,
  32, 36, 54, 60, 61, 49, 32, 38, 38, 32, 36, 123, 55, 61, 48, 125,
  62, 61, 48, 32, 38, 38, 32, 36, 55, 60, 61, 49, 34, 10, 45, 101,
  91, 48, 45, 45, 51, 93, 32, 34, 82, 101, 115, 105, 122, 101, 32, 51,
  100, 32, 105, 109, 97, 103, 101, 34, 36, 95, 95, 115, 34, 32, 116, 111,
  32, 36, 49, 32, 112, 105, 120, 101, 108, 115, 32, 97, 108, 111, 110, 103,
  32, 116, 104, 101, 32, 120, 45, 97, 120, 105, 115, 44, 32, 112, 114, 101,
  115, 101, 114, 118, 105, 110, 103, 32, 51, 100, 32, 114, 97, 116, 105, 111,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 115, 105, 122, 101, 61, 123,
  105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116,
  92, 32, 36, 49, 125, 44, 36, 49, 42, 119, 44, 36, 49, 41, 125, 10,
  45, 114, 32, 123, 109, 97, 120, 40, 49, 44, 36, 115, 105, 122, 101, 41,
  125, 44, 123, 109, 97, 120, 40, 49, 44, 104, 42, 36, 115, 105, 122, 101,
  47, 119, 41, 125, 44, 123, 109, 97, 120, 40, 49, 44, 100, 42, 36, 115,
  105, 122, 101, 47, 119, 41, 125, 44, 49, 48, 48, 37, 44, 36, 123, 50,
  45, 55, 125, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 114, 51, 100, 121,
  32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 114, 101, 115, 105,
  122, 101, 51, 100, 121, 39, 46, 10, 114, 51, 100, 121, 32, 58, 10, 45,
  118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32,
  43, 10, 45, 95, 114, 101, 115, 105, 122, 101, 51, 100, 121, 32, 36, 42,
  10, 35, 64, 103, 109, 105, 99, 32, 114, 101, 115, 105, 122, 101, 51, 100,
  121, 32, 58, 32, 104, 101, 105, 103, 104, 116, 91, 37, 93, 62, 48, 44,
  95, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 44, 95,
  98, 111, 117, 110, 100, 97, 114, 121, 44, 95, 97, 120, 44, 95, 97, 121,
  44, 95, 97, 122, 44, 95, 97, 99, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 82, 101, 115, 105, 122, 101, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 32, 97, 108, 111, 110, 103, 32, 116,
  104, 101, 32, 121, 45, 97, 120, 105, 115, 44, 32, 112, 114, 101, 115, 101,
  114, 118, 105, 110, 103, 32, 51, 100, 32, 114, 97, 116, 105, 111, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111,
  32, 39, 45, 114, 51, 100, 121, 39, 41, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105,
  111, 110, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 45, 49, 61,
  110, 111, 110, 101, 32, 40, 109, 101, 109, 111, 114, 121, 32, 99, 111, 110,
  116, 101, 110, 116, 41, 32, 124, 32, 48, 61, 110, 111, 110, 101, 32, 124,
  32, 49, 61, 110, 101, 97, 114, 101, 115, 116, 32, 124, 32, 50, 61, 97,
  118, 101, 114, 97, 103, 101, 32, 124, 32, 51, 61, 108, 105, 110, 101, 97,
  114, 32, 124, 32, 52, 61, 103, 114, 105, 100, 32, 124, 32, 53, 61, 98,
  105, 99, 117, 98, 105, 99, 32, 124, 32, 54, 61, 108, 97, 110, 99, 122,
  111, 115, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39,
  98, 111, 117, 110, 100, 97, 114, 121, 39, 32, 104, 97, 115, 32, 100, 105,
  102, 102, 101, 114, 101, 110, 116, 32, 109, 101, 97, 110, 105, 110, 103, 115,
  44, 32, 97, 99, 99, 111, 114, 100, 105, 110, 103, 32, 116, 111, 32, 116,
  104, 101, 32, 99, 104, 111, 115, 101, 110, 32, 39, 105, 110, 116, 101, 114,
  112, 111, 108, 97, 116, 105, 111, 110, 39, 32, 109, 111, 100, 101, 32, 58,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 46, 32, 87, 104, 101, 110,
  32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 61,
  61, 123, 32, 45, 49, 32, 124, 32, 49, 32, 124, 32, 50, 32, 124, 32,
  52, 32, 125, 39, 44, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 39,
  32, 105, 115, 32, 109, 101, 97, 110, 105, 110, 103, 108, 101, 115, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 46, 32, 87, 104, 101, 110,
  32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 61,
  61, 48, 39, 44, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 39, 32,
  99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 100, 105, 114, 105, 99,
  104, 108, 101, 116, 32, 124, 32, 49, 61, 110, 101, 117, 109, 97, 110, 110,
  32, 124, 32, 50, 61, 99, 121, 99, 108, 105, 99, 32, 125, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 46, 32, 87, 104, 101, 110, 32, 39,
  105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 61, 61, 123,
  32, 51, 32, 124, 32, 53, 32, 124, 32, 54, 32, 125, 39, 44, 32, 39,
  98, 111, 117, 110, 100, 97, 114, 121, 39, 32, 99, 97, 110, 32, 98, 101,
  32, 123, 32, 48, 61, 110, 111, 110, 101, 32, 124, 32, 49, 61, 110, 101,
  117, 109, 97, 110, 110, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 39, 97, 120, 44, 97, 121, 44, 97, 122, 44, 97, 99, 39, 32,
  115, 101, 116, 32, 116, 104, 101, 32, 97, 108, 105, 103, 110, 109, 101, 110,
  116, 32, 109, 111, 100, 101, 32, 97, 108, 111, 110, 103, 32, 101, 97, 99,
  104, 32, 97, 120, 105, 115, 32, 119, 104, 101, 110, 32, 39, 105, 110, 116,
  101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 61, 48, 39, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 40, 115, 101, 116, 32, 116, 111, 32, 39,
  48, 39, 32, 98, 121, 32, 100, 101, 102, 97, 117, 108, 116, 44, 32, 109,
  117, 115, 116, 32, 98, 101, 32, 100, 101, 102, 105, 110, 101, 100, 32, 105,
  110, 32, 114, 97, 110, 103, 101, 32, 91, 48, 44, 49, 93, 41, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116,
  32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 105, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 105, 111, 110, 61, 51, 39, 44, 32, 39, 98, 111, 117,
  110, 100, 97, 114, 121, 61, 48, 39, 32, 97, 110, 100, 32, 39, 97, 120,
  61, 97, 121, 61, 97, 122, 61, 97, 99, 61, 48, 39, 46, 10, 114, 101,
  115, 105, 122, 101, 51, 100, 121, 32, 58, 10, 45, 118, 32, 45, 32, 95,
  95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 36,
  48, 32, 36, 42, 10, 95, 114, 101, 115, 105, 122, 101, 51, 100, 121, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 48, 32, 38,
  38, 32, 36, 123, 50, 61, 51, 125, 62, 61, 48, 32, 38, 38, 32, 36,
  50, 60, 61, 54, 32, 38, 38, 32, 36, 123, 51, 61, 48, 125, 62, 61,
  48, 32, 38, 38, 32, 36, 51, 60, 61, 50, 32, 38, 38, 32, 36, 123,
  52, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 52, 60, 61, 49,
  32, 38, 38, 32, 36, 123, 53, 61, 48, 125, 62, 61, 48, 32, 38, 38,
  32, 36, 53, 60, 61, 49, 32, 38, 38, 32, 36, 123, 54, 61, 48, 125,
  62, 61, 48, 32, 38, 38, 32, 36, 54, 60, 61, 49, 32, 38, 38, 32,
  36, 123, 55, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 55, 60,
  61, 49, 34, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 82, 101,
  115, 105, 122, 101, 32, 51, 100, 32, 105, 109, 97, 103, 101, 34, 36, 95,
  95, 115, 34, 32, 116, 111, 32, 36, 49, 32, 112, 105, 120, 101, 108, 115,
  32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 121, 45, 97, 120, 105,
  115, 44, 32, 112, 114, 101, 115, 101, 114, 118, 105, 110, 103, 32, 51, 100,
  32, 114, 97, 116, 105, 111, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  115, 105, 122, 101, 61, 123, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112,
  101, 114, 99, 101, 110, 116, 92, 32, 36, 49, 125, 44, 36, 49, 42, 104,
  44, 36, 49, 41, 125, 10, 45, 114, 32, 123, 109, 97, 120, 40, 49, 44,
  119, 42, 36, 115, 105, 122, 101, 47, 104, 41, 125, 44, 123, 109, 97, 120,
  40, 49, 44, 36, 115, 105, 122, 101, 41, 125, 44, 123, 109, 97, 120, 40,
  49, 44, 100, 42, 36, 115, 105, 122, 101, 47, 104, 41, 125, 44, 49, 48,
  48, 37, 44, 36, 123, 50, 45, 55, 125, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 114, 51, 100, 122, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32,
  39, 45, 114, 101, 115, 105, 122, 101, 51, 100, 122, 39, 46, 10, 114, 51,
  100, 122, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36,
  63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 114, 101, 115, 105, 122, 101,
  51, 100, 122, 32, 36, 42, 10, 35, 64, 103, 109, 105, 99, 32, 114, 101,
  115, 105, 122, 101, 51, 100, 122, 32, 58, 32, 100, 101, 112, 116, 104, 91,
  37, 93, 62, 48, 44, 95, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116,
  105, 111, 110, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121, 44, 95, 97,
  120, 44, 95, 97, 121, 44, 95, 97, 122, 44, 95, 97, 99, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 82, 101, 115, 105, 122, 101, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 97, 108,
  111, 110, 103, 32, 116, 104, 101, 32, 122, 45, 97, 120, 105, 115, 44, 32,
  112, 114, 101, 115, 101, 114, 118, 105, 110, 103, 32, 51, 100, 32, 114, 97,
  116, 105, 111, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101,
  113, 46, 32, 116, 111, 32, 39, 45, 114, 51, 100, 122, 39, 41, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 105, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 105, 111, 110, 39, 32, 99, 97, 110, 32, 98, 101, 32,
  123, 32, 45, 49, 61, 110, 111, 110, 101, 32, 40, 109, 101, 109, 111, 114,
  121, 32, 99, 111, 110, 116, 101, 110, 116, 41, 32, 124, 32, 48, 61, 110,
  111, 110, 101, 32, 124, 32, 49, 61, 110, 101, 97, 114, 101, 115, 116, 32,
  124, 32, 50, 61, 97, 118, 101, 114, 97, 103, 101, 32, 124, 32, 51, 61,
  108, 105, 110, 101, 97, 114, 32, 124, 32, 52, 61, 103, 114, 105, 100, 32,
  124, 32, 53, 61, 98, 105, 99, 117, 98, 105, 99, 32, 124, 32, 54, 61,
  108, 97, 110, 99, 122, 111, 115, 32, 125, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 39, 32, 104,
  97, 115, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32, 109, 101, 97,
  110, 105, 110, 103, 115, 44, 32, 97, 99, 99, 111, 114, 100, 105, 110, 103,
  32, 116, 111, 32, 116, 104, 101, 32, 99, 104, 111, 115, 101, 110, 32, 39,
  105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 39, 32, 109,
  111, 100, 101, 32, 58, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 46,
  32, 87, 104, 101, 110, 32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97,
  116, 105, 111, 110, 61, 61, 123, 32, 45, 49, 32, 124, 32, 49, 32, 124,
  32, 50, 32, 124, 32, 52, 32, 125, 39, 44, 32, 39, 98, 111, 117, 110,
  100, 97, 114, 121, 39, 32, 105, 115, 32, 109, 101, 97, 110, 105, 110, 103,
  108, 101, 115, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 46,
  32, 87, 104, 101, 110, 32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97,
  116, 105, 111, 110, 61, 61, 48, 39, 44, 32, 39, 98, 111, 117, 110, 100,
  97, 114, 121, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61,
  100, 105, 114, 105, 99, 104, 108, 101, 116, 32, 124, 32, 49, 61, 110, 101,
  117, 109, 97, 110, 110, 32, 124, 32, 50, 61, 99, 121, 99, 108, 105, 99,
  32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 46, 32, 87,
  104, 101, 110, 32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105,
  111, 110, 61, 61, 123, 32, 51, 32, 124, 32, 53, 32, 124, 32, 54, 32,
  125, 39, 44, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 39, 32, 99,
  97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 110, 111, 110, 101, 32, 124,
  32, 49, 61, 110, 101, 117, 109, 97, 110, 110, 32, 125, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 39, 97, 120, 44, 97, 121, 44, 97, 122,
  44, 97, 99, 39, 32, 115, 101, 116, 32, 116, 104, 101, 32, 97, 108, 105,
  103, 110, 109, 101, 110, 116, 32, 109, 111, 100, 101, 32, 97, 108, 111, 110,
  103, 32, 101, 97, 99, 104, 32, 97, 120, 105, 115, 32, 119, 104, 101, 110,
  32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 61,
  48, 39, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 115, 101, 116,
  32, 116, 111, 32, 39, 48, 39, 32, 98, 121, 32, 100, 101, 102, 97, 117,
  108, 116, 44, 32, 109, 117, 115, 116, 32, 98, 101, 32, 100, 101, 102, 105,
  110, 101, 100, 32, 105, 110, 32, 114, 97, 110, 103, 101, 32, 91, 48, 44,
  49, 93, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101,
  102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 105,
  110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 61, 51, 39, 44,
  32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 61, 48, 39, 32, 97, 110,
  100, 32, 39, 97, 120, 61, 97, 121, 61, 97, 122, 61, 97, 99, 61, 48,
  39, 46, 10, 114, 101, 115, 105, 122, 101, 51, 100, 122, 32, 58, 10, 45,
  118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32,
  43, 10, 45, 95, 36, 48, 32, 36, 42, 10, 95, 114, 101, 115, 105, 122,
  101, 51, 100, 122, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36,
  49, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 51, 125, 62, 61, 48,
  32, 38, 38, 32, 36, 50, 60, 61, 54, 32, 38, 38, 32, 36, 123, 51,
  61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 51, 60, 61, 50, 32,
  38, 38, 32, 36, 123, 52, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32,
  36, 52, 60, 61, 49, 32, 38, 38, 32, 36, 123, 53, 61, 48, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 53, 60, 61, 49, 32, 38, 38, 32, 36,
  123, 54, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 54, 60, 61,
  49, 32, 38, 38, 32, 36, 123, 55, 61, 48, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 55, 60, 61, 49, 34, 10, 45, 101, 91, 48, 45, 45, 51,
  93, 32, 34, 82, 101, 115, 105, 122, 101, 32, 51, 100, 32, 105, 109, 97,
  103, 101, 34, 36, 95, 95, 115, 34, 32, 116, 111, 32, 36, 49, 32, 112,
  105, 120, 101, 108, 115, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32,
  122, 45, 97, 120, 105, 115, 44, 32, 112, 114, 101, 115, 101, 114, 118, 105,
  110, 103, 32, 51, 100, 32, 114, 97, 116, 105, 111, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 115, 105, 122, 101, 61, 123, 105, 102, 40, 64, 123,
  45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 49, 125,
  44, 36, 49, 42, 100, 44, 36, 49, 41, 125, 10, 45, 114, 91, 36, 62,
  93, 32, 123, 109, 97, 120, 40, 49, 44, 119, 42, 36, 115, 105, 122, 101,
  47, 100, 41, 125, 44, 123, 109, 97, 120, 40, 49, 44, 104, 42, 36, 115,
  105, 122, 101, 47, 100, 41, 125, 44, 123, 109, 97, 120, 40, 49, 44, 36,
  115, 105, 122, 101, 41, 125, 44, 49, 48, 48, 37, 44, 36, 123, 50, 45,
  55, 125, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 114, 111, 116, 97, 116,
  101, 32, 58, 32, 97, 110, 103, 108, 101, 44, 95, 105, 110, 116, 101, 114,
  112, 111, 108, 97, 116, 105, 111, 110, 44, 95, 98, 111, 117, 110, 100, 97,
  114, 121, 44, 95, 99, 120, 91, 37, 93, 44, 95, 99, 121, 91, 37, 93,
  44, 95, 122, 111, 111, 109, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 82, 111, 116, 97, 116, 101, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 119, 105, 116,
  104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 97, 110, 103, 108,
  101, 32, 40, 105, 110, 32, 100, 101, 103, 46, 41, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97,
  116, 105, 111, 110, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48,
  61, 110, 111, 110, 101, 32, 124, 32, 49, 61, 108, 105, 110, 101, 97, 114,
  32, 124, 32, 50, 61, 98, 105, 99, 117, 98, 105, 99, 32, 125, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 98, 111, 117, 110, 100, 97,
  114, 121, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 100,
  105, 114, 105, 99, 104, 108, 101, 116, 32, 124, 32, 49, 61, 110, 101, 117,
  109, 97, 110, 110, 32, 124, 32, 50, 61, 99, 121, 99, 108, 105, 99, 32,
  125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 87, 104, 101, 110,
  32, 114, 111, 116, 97, 116, 105, 111, 110, 32, 99, 101, 110, 116, 101, 114,
  32, 40, 39, 99, 120, 39, 44, 39, 99, 121, 39, 41, 32, 105, 115, 32,
  115, 112, 101, 99, 105, 102, 105, 101, 100, 44, 32, 116, 104, 101, 32, 115,
  105, 122, 101, 32, 111, 102, 32, 116, 104, 101, 32, 105, 109, 97, 103, 101,
  32, 105, 115, 32, 112, 114, 101, 115, 101, 114, 118, 101, 100, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32,
  118, 97, 108, 117, 101, 115, 58, 32, 39, 98, 111, 117, 110, 100, 97, 114,
  121, 61, 48, 39, 44, 32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97,
  116, 105, 111, 110, 61, 49, 39, 44, 32, 39, 99, 120, 61, 99, 121, 61,
  40, 117, 110, 100, 101, 102, 105, 110, 101, 100, 41, 39, 32, 97, 110, 100,
  32, 39, 122, 111, 111, 109, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 45, 114, 111, 116, 97, 116, 101, 32, 45, 50, 53, 44, 49, 44, 50,
  44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 46, 54, 32, 45, 114, 111,
  116, 97, 116, 101, 91, 48, 93, 32, 50, 53, 10, 35, 64, 103, 109, 105,
  99, 32, 114, 111, 116, 97, 116, 101, 95, 116, 105, 108, 101, 97, 98, 108,
  101, 32, 58, 32, 97, 110, 103, 108, 101, 44, 95, 109, 97, 120, 95, 115,
  105, 122, 101, 95, 102, 97, 99, 116, 111, 114, 62, 61, 48, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 82, 111, 116, 97, 116, 101, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 98, 121,
  32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 97, 110, 103, 108, 101,
  32, 97, 110, 100, 32, 109, 97, 107, 101, 32, 116, 104, 101, 109, 32, 116,
  105, 108, 101, 97, 98, 108, 101, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 73, 102, 32, 114, 101, 115, 117, 108, 116, 105, 110, 103, 32, 115,
  105, 122, 101, 32, 111, 102, 32, 97, 110, 32, 105, 109, 97, 103, 101, 32,
  105, 115, 32, 116, 111, 111, 32, 98, 105, 103, 44, 32, 116, 104, 101, 32,
  105, 109, 97, 103, 101, 32, 105, 115, 32, 114, 101, 112, 108, 97, 99, 101,
  100, 32, 98, 121, 32, 97, 32, 49, 120, 49, 32, 105, 109, 97, 103, 101,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117,
  108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 109, 97, 120, 95,
  115, 105, 122, 101, 95, 102, 97, 99, 116, 111, 114, 61, 56, 39, 46, 10,
  114, 111, 116, 97, 116, 101, 95, 116, 105, 108, 101, 97, 98, 108, 101, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 123, 50, 61, 56, 125, 62,
  61, 48, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 111, 116, 97,
  116, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 119, 105, 116, 104, 32,
  97, 110, 103, 108, 101, 32, 36, 49, 32, 100, 101, 103, 46, 32, 97, 110,
  100, 32, 109, 97, 107, 101, 32, 116, 104, 101, 109, 32, 116, 105, 108, 101,
  97, 98, 108, 101, 46, 34, 10, 45, 118, 32, 45, 10, 97, 110, 103, 108,
  101, 61, 123, 36, 49, 37, 51, 54, 48, 125, 10, 45, 105, 102, 32, 123,
  36, 97, 110, 103, 108, 101, 62, 61, 50, 55, 48, 125, 32, 45, 114, 111,
  116, 97, 116, 101, 32, 50, 55, 48, 32, 97, 110, 103, 108, 101, 61, 123,
  36, 97, 110, 103, 108, 101, 45, 50, 55, 48, 125, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 97, 110, 103, 108, 101, 62, 61, 49, 56, 48, 125, 32,
  45, 114, 111, 116, 97, 116, 101, 32, 49, 56, 48, 32, 97, 110, 103, 108,
  101, 61, 123, 36, 97, 110, 103, 108, 101, 45, 49, 56, 48, 125, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 97, 110, 103, 108, 101, 62, 61, 57, 48,
  125, 32, 45, 114, 111, 116, 97, 116, 101, 32, 57, 48, 32, 97, 110, 103,
  108, 101, 61, 123, 36, 97, 110, 103, 108, 101, 45, 57, 48, 125, 10, 45,
  101, 110, 100, 105, 102, 10, 40, 48, 44, 49, 59, 49, 44, 56, 59, 49,
  44, 55, 59, 49, 44, 54, 59, 49, 44, 53, 59, 49, 44, 52, 59, 49,
  44, 53, 59, 49, 44, 51, 59, 50, 44, 53, 59, 49, 44, 50, 59, 50,
  44, 53, 59, 51, 44, 53, 59, 50, 44, 51, 59, 51, 44, 52, 59, 52,
  44, 53, 59, 49, 44, 49, 59, 53, 44, 52, 59, 55, 44, 53, 59, 51,
  44, 50, 59, 56, 44, 53, 59, 57, 44, 53, 59, 50, 44, 49, 59, 51,
  44, 49, 59, 52, 44, 49, 59, 53, 44, 49, 59, 54, 44, 49, 59, 55,
  44, 49, 59, 56, 44, 49, 41, 10, 45, 115, 91, 45, 49, 93, 32, 120,
  44, 50, 32, 45, 45, 47, 91, 45, 50, 44, 45, 49, 93, 32, 45, 97,
  116, 97, 110, 91, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 123,
  49, 56, 48, 47, 112, 105, 125, 10, 40, 36, 97, 110, 103, 108, 101, 41,
  32, 45, 105, 110, 100, 101, 120, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  32, 45, 114, 109, 91, 45, 50, 93, 10, 112, 61, 64, 123, 45, 51, 44,
  64, 45, 49, 125, 32, 113, 61, 64, 123, 45, 50, 44, 64, 45, 49, 125,
  32, 45, 114, 109, 91, 45, 51, 45, 45, 49, 93, 10, 45, 105, 102, 32,
  123, 33, 36, 112, 124, 124, 33, 36, 113, 125, 32, 45, 114, 101, 116, 117,
  114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 116, 104, 101, 116,
  97, 61, 123, 97, 116, 97, 110, 50, 40, 36, 112, 44, 36, 113, 41, 125,
  10, 103, 99, 100, 61, 64, 123, 45, 103, 99, 100, 34, 32, 34, 123, 104,
  42, 36, 113, 125, 44, 123, 119, 42, 36, 112, 125, 125, 10, 112, 119, 61,
  123, 104, 42, 36, 113, 47, 36, 103, 99, 100, 125, 10, 110, 119, 61, 123,
  114, 111, 117, 110, 100, 40, 36, 112, 119, 42, 119, 47, 99, 111, 115, 40,
  36, 116, 104, 101, 116, 97, 41, 41, 125, 10, 103, 99, 100, 61, 64, 123,
  45, 103, 99, 100, 34, 32, 34, 123, 104, 42, 36, 112, 125, 44, 123, 119,
  42, 36, 113, 125, 125, 10, 113, 104, 61, 123, 119, 42, 36, 113, 47, 36,
  103, 99, 100, 125, 10, 110, 104, 61, 123, 114, 111, 117, 110, 100, 40, 36,
  113, 104, 42, 104, 47, 99, 111, 115, 40, 36, 116, 104, 101, 116, 97, 41,
  41, 125, 10, 45, 105, 102, 32, 123, 33, 36, 50, 34, 32, 124, 124, 32,
  34, 40, 36, 110, 119, 60, 36, 50, 42, 119, 34, 32, 38, 38, 32, 34,
  36, 110, 104, 60, 36, 50, 42, 104, 41, 125, 10, 45, 114, 32, 123, 49,
  46, 53, 42, 36, 110, 119, 125, 44, 123, 49, 46, 53, 42, 36, 110, 104,
  125, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44, 50, 10, 45, 114, 111,
  116, 97, 116, 101, 32, 123, 36, 116, 104, 101, 116, 97, 42, 49, 56, 48,
  47, 112, 105, 125, 44, 49, 44, 50, 44, 53, 48, 37, 44, 53, 48, 37,
  10, 45, 114, 32, 36, 110, 119, 44, 36, 110, 104, 44, 49, 44, 49, 48,
  48, 37, 44, 48, 44, 50, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45,
  101, 108, 115, 101, 32, 45, 114, 109, 32, 49, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 114, 111, 119, 115, 32, 58,
  32, 123, 32, 91, 105, 109, 97, 103, 101, 48, 93, 32, 124, 32, 121, 48,
  91, 37, 93, 32, 125, 44, 95, 123, 32, 91, 105, 109, 97, 103, 101, 49,
  93, 32, 124, 32, 121, 49, 91, 37, 93, 32, 125, 32, 58, 32, 40, 42,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 75, 101, 101, 112, 32,
  111, 110, 108, 121, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 114,
  111, 119, 115, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 105, 114, 105, 99, 104, 108, 101, 116, 32, 98, 111, 117, 110, 100,
  97, 114, 121, 32, 105, 115, 32, 117, 115, 101, 100, 32, 119, 104, 101, 110,
  32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 114, 111, 119, 115, 32,
  97, 114, 101, 32, 111, 117, 116, 32, 111, 102, 32, 114, 97, 110, 103, 101,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 114, 111, 119, 115, 32, 45, 50, 53,
  37, 44, 53, 48, 37, 10, 35, 64, 103, 109, 105, 99, 32, 115, 99, 97,
  108, 101, 50, 120, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101,
  115, 105, 122, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 32, 117, 115, 105, 110, 103, 32, 116, 104, 101, 32, 83,
  99, 97, 108, 101, 50, 120, 32, 97, 108, 103, 111, 114, 105, 116, 104, 109,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 32, 53, 48, 37, 32, 45, 114, 101, 115, 105, 122, 101, 32, 53, 48,
  37, 44, 53, 48, 37, 32, 45, 45, 115, 99, 97, 108, 101, 50, 120, 10,
  115, 99, 97, 108, 101, 50, 120, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 68, 111, 117, 98, 108, 101, 32, 120, 121, 45, 100, 105, 109,
  101, 110, 115, 105, 111, 110, 115, 32, 111, 102, 32, 105, 109, 97, 103, 101,
  36, 63, 44, 32, 117, 115, 105, 110, 103, 32, 83, 99, 97, 108, 101, 50,
  120, 32, 97, 108, 103, 111, 114, 105, 116, 104, 109, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 114, 32, 50, 48, 48, 37, 44, 50, 48, 48,
  37, 10, 45, 102, 32, 34, 100, 120, 61, 120, 38, 49, 59, 100, 121, 61,
  121, 38, 49, 59, 65, 61, 106, 40, 48, 44, 45, 50, 44, 48, 44, 48,
  44, 48, 44, 49, 41, 59, 66, 61, 106, 40, 50, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 49, 41, 59, 67, 61, 106, 40, 45, 50, 44, 48, 44,
  48, 44, 48, 44, 48, 44, 49, 41, 59, 68, 61, 106, 40, 48, 44, 50,
  44, 48, 44, 48, 44, 48, 44, 49, 41, 59, 34, 92, 10, 34, 33, 100,
  121, 42, 40, 33, 100, 120, 42, 105, 102, 40, 67, 61, 61, 65, 38, 38,
  67, 33, 61, 68, 38, 38, 65, 33, 61, 66, 44, 65, 44, 105, 41, 32,
  43, 32, 100, 120, 42, 105, 102, 40, 65, 61, 61, 66, 38, 38, 65, 33,
  61, 67, 38, 38, 66, 33, 61, 68, 44, 66, 44, 105, 41, 41, 32, 43,
  32, 100, 121, 42, 40, 100, 120, 42, 105, 102, 40, 66, 61, 61, 68, 38,
  38, 66, 33, 61, 65, 38, 38, 68, 33, 61, 67, 44, 68, 44, 105, 41,
  32, 43, 32, 33, 100, 120, 42, 105, 102, 40, 68, 61, 61, 67, 38, 38,
  68, 33, 61, 66, 38, 38, 67, 33, 61, 65, 44, 67, 44, 105, 41, 41,
  34, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 99, 97, 108, 101, 51,
  120, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 115, 105, 122,
  101, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 32, 117, 115, 105, 110, 103, 32, 116, 104, 101, 32, 83, 99, 97, 108,
  101, 51, 120, 32, 97, 108, 103, 111, 114, 105, 116, 104, 109, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 53,
  48, 37, 32, 45, 114, 101, 115, 105, 122, 101, 32, 51, 51, 37, 44, 51,
  51, 37, 32, 45, 45, 115, 99, 97, 108, 101, 51, 120, 10, 115, 99, 97,
  108, 101, 51, 120, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  84, 114, 105, 112, 108, 101, 32, 120, 121, 45, 100, 105, 109, 101, 110, 115,
  105, 111, 110, 115, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 117, 115, 105, 110, 103, 32, 83, 99, 97, 108, 101, 51, 120, 32, 97,
  108, 103, 111, 114, 105, 116, 104, 109, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 114, 32, 51, 48, 48, 37, 44, 51, 48, 48, 37, 10, 45,
  102, 32, 34, 100, 120, 61, 120, 37, 51, 59, 100, 121, 61, 121, 37, 51,
  59, 99, 48, 61, 33, 100, 120, 59, 99, 49, 61, 40, 100, 120, 61, 61,
  49, 41, 59, 99, 50, 61, 40, 100, 120, 61, 61, 50, 41, 59, 34, 92,
  10, 34, 65, 61, 106, 40, 45, 51, 44, 45, 51, 44, 48, 44, 48, 44,
  48, 44, 49, 41, 59, 66, 61, 106, 40, 48, 44, 45, 51, 44, 48, 44,
  48, 44, 48, 44, 49, 41, 59, 67, 61, 106, 40, 51, 44, 45, 51, 44,
  48, 44, 48, 44, 48, 44, 49, 41, 59, 34, 92, 10, 34, 68, 61, 106,
  40, 45, 51, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 41, 59, 70,
  61, 106, 40, 51, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 41, 59,
  34, 92, 10, 34, 71, 61, 106, 40, 45, 51, 44, 51, 44, 48, 44, 48,
  44, 48, 44, 49, 41, 59, 72, 61, 106, 40, 48, 44, 51, 44, 48, 44,
  48, 44, 48, 44, 49, 41, 59, 73, 61, 106, 40, 51, 44, 51, 44, 48,
  44, 48, 44, 48, 44, 49, 41, 59, 34, 92, 10, 34, 33, 100, 121, 42,
  40, 99, 48, 42, 105, 102, 40, 68, 61, 61, 66, 38, 38, 68, 33, 61,
  72, 38, 38, 66, 33, 61, 70, 44, 68, 44, 105, 41, 32, 43, 32, 99,
  49, 42, 105, 102, 40, 40, 68, 61, 61, 66, 38, 38, 68, 33, 61, 72,
  38, 38, 66, 33, 61, 70, 38, 38, 105, 33, 61, 67, 41, 124, 124, 40,
  66, 61, 61, 70, 38, 38, 66, 33, 61, 68, 38, 38, 70, 33, 61, 72,
  38, 38, 105, 33, 61, 65, 41, 44, 66, 44, 105, 41, 32, 43, 32, 99,
  50, 42, 105, 102, 40, 66, 61, 61, 70, 38, 38, 66, 33, 61, 68, 38,
  38, 70, 33, 61, 72, 44, 70, 44, 105, 41, 41, 32, 43, 32, 34, 92,
  10, 34, 40, 100, 121, 61, 61, 49, 41, 42, 40, 99, 48, 42, 105, 102,
  40, 40, 72, 61, 61, 68, 38, 38, 72, 33, 61, 70, 38, 38, 68, 33,
  61, 66, 38, 38, 105, 33, 61, 65, 41, 124, 124, 40, 68, 61, 61, 66,
  38, 38, 68, 33, 61, 72, 38, 38, 66, 33, 61, 70, 38, 38, 105, 33,
  61, 71, 41, 44, 68, 44, 105, 41, 32, 43, 32, 99, 49, 42, 105, 32,
  43, 32, 99, 50, 42, 105, 102, 40, 40, 66, 61, 61, 70, 38, 38, 66,
  33, 61, 68, 38, 38, 70, 33, 61, 72, 38, 38, 105, 33, 61, 73, 41,
  124, 124, 40, 70, 61, 61, 72, 38, 38, 70, 33, 61, 66, 38, 38, 72,
  33, 61, 68, 38, 38, 105, 33, 61, 67, 41, 44, 70, 44, 105, 41, 41,
  32, 43, 32, 34, 92, 10, 34, 40, 100, 121, 61, 61, 50, 41, 42, 40,
  99, 48, 42, 105, 102, 40, 72, 61, 61, 68, 38, 38, 72, 33, 61, 70,
  38, 38, 68, 33, 61, 66, 44, 68, 44, 105, 41, 32, 43, 32, 99, 49,
  42, 105, 102, 40, 40, 70, 61, 61, 72, 38, 38, 70, 33, 61, 66, 38,
  38, 72, 33, 61, 68, 38, 38, 105, 33, 61, 71, 41, 124, 124, 40, 72,
  61, 61, 68, 38, 38, 72, 33, 61, 70, 38, 38, 68, 33, 61, 66, 38,
  38, 105, 33, 61, 73, 41, 44, 72, 44, 105, 41, 32, 43, 32, 99, 50,
  42, 105, 102, 40, 70, 61, 61, 72, 38, 38, 70, 33, 61, 66, 38, 38,
  72, 33, 61, 68, 44, 70, 44, 105, 41, 41, 34, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 115, 104, 105, 102, 116, 32, 58, 32, 118, 120, 91, 37,
  93, 44, 95, 118, 121, 91, 37, 93, 44, 95, 118, 122, 91, 37, 93, 44,
  95, 118, 99, 91, 37, 93, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121,
  32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  83, 104, 105, 102, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 32, 98, 121, 32, 115, 112, 101, 99, 105, 102, 105,
  101, 100, 32, 100, 105, 115, 112, 108, 97, 99, 101, 109, 101, 110, 116, 32,
  118, 101, 99, 116, 111, 114, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 39, 32, 99, 97, 110, 32,
  98, 101, 32, 123, 32, 48, 61, 100, 105, 114, 105, 99, 104, 108, 101, 116,
  32, 124, 32, 49, 61, 110, 101, 117, 109, 97, 110, 110, 32, 124, 32, 50,
  61, 99, 121, 99, 108, 105, 99, 32, 125, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117,
  101, 58, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 61, 48, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93,
  32, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 48, 44, 48, 32, 45,
  45, 115, 104, 105, 102, 116, 91, 48, 93, 32, 53, 48, 37, 44, 53, 48,
  37, 44, 48, 44, 48, 44, 49, 32, 45, 45, 115, 104, 105, 102, 116, 91,
  48, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 48, 44, 50,
  10, 35, 64, 103, 109, 105, 99, 32, 115, 104, 114, 105, 110, 107, 95, 120,
  32, 58, 32, 115, 105, 122, 101, 95, 120, 62, 61, 48, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 83, 104, 114, 105, 110, 107, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 97, 108, 111,
  110, 103, 32, 116, 104, 101, 32, 120, 45, 97, 120, 105, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 115, 104, 114, 105, 110, 107, 95, 120, 32, 51, 48,
  10, 115, 104, 114, 105, 110, 107, 95, 120, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 36, 49, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 83, 104, 114, 105, 110, 107, 32, 105, 109, 97, 103, 101,
  36, 63, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 120, 45, 97,
  120, 105, 115, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101, 32, 36, 49,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 122, 91, 36, 62, 93, 32, 36, 49, 44, 64, 123, 36,
  62, 44, 119, 45, 36, 49, 45, 49, 125, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 104, 114, 105,
  110, 107, 95, 120, 121, 32, 58, 32, 115, 105, 122, 101, 62, 61, 48, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 104, 114, 105, 110, 107, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32,
  97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 120, 121, 45, 97, 120, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 115, 104, 114, 105, 110, 107, 95,
  120, 121, 32, 51, 48, 10, 115, 104, 114, 105, 110, 107, 95, 120, 121, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48, 34,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 83, 104, 114, 105, 110, 107,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 97, 108, 111, 110, 103, 32, 116,
  104, 101, 32, 120, 121, 45, 97, 120, 101, 115, 32, 119, 105, 116, 104, 32,
  115, 105, 122, 101, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 122, 91, 36, 62, 93,
  32, 36, 49, 44, 36, 49, 44, 64, 123, 36, 62, 44, 119, 45, 36, 49,
  45, 49, 125, 44, 64, 123, 36, 62, 44, 104, 45, 36, 49, 45, 49, 125,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109,
  105, 99, 32, 115, 104, 114, 105, 110, 107, 95, 120, 121, 122, 32, 58, 32,
  115, 105, 122, 101, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 83, 104, 114, 105, 110, 107, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 32, 97, 108, 111, 110, 103, 32, 116, 104,
  101, 32, 120, 121, 122, 45, 97, 120, 101, 115, 46, 10, 115, 104, 114, 105,
  110, 107, 95, 120, 121, 122, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 36, 49, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 83, 104, 114, 105, 110, 107, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 120, 121, 122, 45, 97, 120,
  101, 115, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101, 32, 36, 49, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 122, 91, 36, 62, 93, 32, 36, 49, 44, 36, 49, 44, 36,
  49, 44, 64, 123, 36, 62, 44, 119, 45, 36, 49, 45, 49, 125, 44, 64,
  123, 36, 62, 44, 104, 45, 36, 49, 45, 49, 125, 44, 64, 123, 36, 62,
  44, 100, 45, 36, 49, 45, 49, 125, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 104, 114, 105, 110,
  107, 95, 121, 32, 58, 32, 115, 105, 122, 101, 95, 121, 62, 61, 48, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 104, 114, 105, 110, 107, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32,
  97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 121, 45, 97, 120, 105, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 115, 104, 114, 105, 110, 107, 95, 121,
  32, 51, 48, 10, 115, 104, 114, 105, 110, 107, 95, 121, 32, 58, 32, 45,
  99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48, 34, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 83, 104, 114, 105, 110, 107, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32,
  121, 45, 97, 120, 105, 115, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101,
  32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 122, 91, 36, 62, 93, 32, 48, 44, 36,
  49, 44, 49, 48, 48, 37, 44, 64, 123, 36, 62, 44, 104, 45, 36, 49,
  45, 49, 125, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 115, 104, 114, 105, 110, 107, 95, 122, 32, 58,
  32, 115, 105, 122, 101, 95, 122, 62, 61, 48, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 83, 104, 114, 105, 110, 107, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 97, 108, 111, 110, 103,
  32, 116, 104, 101, 32, 122, 45, 97, 120, 105, 115, 46, 10, 115, 104, 114,
  105, 110, 107, 95, 122, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  36, 49, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  83, 104, 114, 105, 110, 107, 32, 105, 109, 97, 103, 101, 36, 63, 32, 97,
  108, 111, 110, 103, 32, 116, 104, 101, 32, 122, 45, 97, 120, 105, 115, 32,
  119, 105, 116, 104, 32, 115, 105, 122, 101, 32, 36, 49, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  122, 91, 36, 62, 93, 32, 48, 44, 48, 44, 36, 49, 44, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 64, 123, 36, 62, 44, 100, 45, 36, 49,
  45, 49, 125, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 115, 108, 105, 99, 101, 115, 32, 58, 32, 123,
  32, 91, 105, 109, 97, 103, 101, 48, 93, 32, 124, 32, 122, 48, 91, 37,
  93, 32, 125, 44, 95, 123, 32, 91, 105, 109, 97, 103, 101, 49, 93, 32,
  124, 32, 122, 49, 91, 37, 93, 32, 125, 32, 58, 32, 40, 42, 41, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 75, 101, 101, 112, 32, 111, 110,
  108, 121, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 115, 108, 105,
  99, 101, 115, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 105, 114, 105, 99, 104, 108, 101, 116, 32, 98, 111, 117, 110, 100,
  97, 114, 121, 32, 105, 115, 32, 117, 115, 101, 100, 32, 119, 104, 101, 110,
  32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 115, 108, 105, 99, 101,
  115, 32, 97, 114, 101, 32, 111, 117, 116, 32, 111, 102, 32, 114, 97, 110,
  103, 101, 46, 10, 35, 64, 103, 109, 105, 99, 32, 115, 111, 114, 116, 32,
  58, 32, 95, 111, 114, 100, 101, 114, 105, 110, 103, 61, 123, 32, 43, 32,
  124, 32, 45, 32, 125, 44, 95, 97, 120, 105, 115, 61, 123, 32, 120, 32,
  124, 32, 121, 32, 124, 32, 122, 32, 124, 32, 99, 32, 125, 32, 58, 32,
  40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 111, 114,
  116, 32, 112, 105, 120, 101, 108, 32, 118, 97, 108, 117, 101, 115, 32, 111,
  102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 102, 32, 39,
  97, 120, 105, 115, 39, 32, 105, 115, 32, 115, 112, 101, 99, 105, 102, 105,
  101, 100, 44, 32, 116, 104, 101, 32, 115, 111, 114, 116, 105, 110, 103, 32,
  105, 115, 32, 100, 111, 110, 101, 32, 97, 99, 99, 111, 114, 100, 105, 110,
  103, 32, 116, 111, 32, 116, 104, 101, 32, 100, 97, 116, 97, 32, 111, 102,
  32, 116, 104, 101, 32, 102, 105, 114, 115, 116, 32, 99, 111, 108, 117, 109,
  110, 47, 114, 111, 119, 47, 115, 108, 105, 99, 101, 47, 99, 104, 97, 110,
  110, 101, 108, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 111, 102, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108,
  116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 111, 114, 100, 101, 114,
  105, 110, 103, 61, 43, 39, 32, 97, 110, 100, 32, 39, 97, 120, 105, 115,
  61, 40, 117, 110, 100, 101, 102, 105, 110, 101, 100, 41, 39, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 54, 52, 32, 45, 114, 97,
  110, 100, 32, 48, 44, 49, 48, 48, 32, 45, 45, 115, 111, 114, 116, 32,
  45, 100, 105, 115, 112, 108, 97, 121, 95, 103, 114, 97, 112, 104, 32, 52,
  48, 48, 44, 51, 48, 48, 44, 51, 10, 35, 64, 103, 109, 105, 99, 32,
  115, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 115, 112, 108,
  105, 116, 39, 46, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 115, 112, 108, 105, 116, 32, 58, 32, 123, 32, 120, 32, 124, 32,
  121, 32, 124, 32, 122, 32, 124, 32, 99, 32, 125, 46, 46, 123, 32, 120,
  32, 124, 32, 121, 32, 124, 32, 122, 32, 124, 32, 99, 32, 125, 44, 95,
  110, 98, 95, 112, 97, 114, 116, 115, 32, 58, 32, 107, 101, 101, 112, 95,
  115, 112, 108, 105, 116, 116, 105, 110, 103, 95, 118, 97, 108, 117, 101, 115,
  61, 123, 32, 43, 32, 124, 32, 45, 32, 125, 44, 118, 97, 108, 117, 101,
  49, 44, 118, 97, 108, 117, 101, 50, 44, 46, 46, 46, 32, 58, 32, 40,
  110, 111, 32, 97, 114, 103, 115, 41, 32, 58, 32, 40, 42, 41, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 83, 112, 108, 105, 116, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 101, 105,
  116, 104, 101, 114, 32, 97, 108, 111, 110, 103, 32, 97, 32, 115, 112, 101,
  99, 105, 102, 105, 101, 100, 32, 97, 120, 105, 115, 44, 32, 111, 114, 32,
  114, 101, 103, 97, 114, 100, 105, 110, 103, 32, 116, 111, 32, 97, 32, 115,
  101, 113, 117, 101, 110, 99, 101, 32, 111, 102, 32, 115, 99, 97, 108, 97,
  114, 32, 118, 97, 108, 117, 101, 115, 44, 32, 111, 114, 32, 97, 115, 32,
  97, 32, 115, 101, 116, 32, 111, 102, 32, 99, 111, 110, 115, 116, 97, 110,
  116, 32, 115, 117, 98, 45, 118, 101, 99, 116, 111, 114, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32,
  39, 45, 115, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  39, 110, 98, 95, 112, 97, 114, 116, 115, 39, 32, 99, 97, 110, 32, 98,
  101, 32, 123, 32, 48, 61, 109, 97, 120, 105, 109, 117, 109, 32, 115, 112,
  108, 105, 116, 32, 124, 32, 62, 48, 61, 115, 112, 108, 105, 116, 32, 105,
  110, 32, 78, 32, 112, 97, 114, 116, 115, 32, 124, 32, 60, 48, 61, 115,
  112, 108, 105, 116, 32, 105, 110, 32, 112, 97, 114, 116, 115, 32, 111, 102,
  32, 115, 105, 122, 101, 32, 45, 78, 32, 125, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108,
  117, 101, 58, 32, 39, 110, 98, 95, 112, 97, 114, 116, 115, 61, 48, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 115, 112, 108, 105, 116, 32, 99, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 115, 112, 108, 105, 116, 32, 121, 44, 51, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 115, 112, 108, 105, 116, 32, 120, 44, 45, 49,
  50, 56, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 49, 44,
  50, 48, 44, 49, 44, 49, 44, 34, 49, 44, 50, 44, 51, 44, 52, 34,
  32, 45, 45, 115, 112, 108, 105, 116, 32, 45, 44, 50, 44, 51, 32, 45,
  97, 112, 112, 101, 110, 100, 91, 49, 45, 45, 49, 93, 32, 121, 10, 35,
  64, 103, 109, 105, 99, 32, 115, 112, 108, 105, 116, 95, 116, 105, 108, 101,
  115, 32, 58, 32, 77, 33, 61, 48, 44, 95, 78, 33, 61, 48, 44, 95,
  105, 115, 95, 104, 111, 109, 111, 103, 101, 110, 101, 111, 117, 115, 61, 123,
  32, 48, 32, 124, 32, 49, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 83, 112, 108, 105, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 32, 97, 115, 32, 97, 32, 77, 120, 78,
  32, 97, 114, 114, 97, 121, 32, 111, 102, 32, 116, 105, 108, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 102, 32, 77, 32, 111,
  114, 32, 78, 32, 105, 115, 32, 110, 101, 103, 97, 116, 105, 118, 101, 44,
  32, 105, 116, 32, 115, 116, 97, 110, 100, 115, 32, 102, 111, 114, 32, 116,
  104, 101, 32, 116, 105, 108, 101, 32, 115, 105, 122, 101, 32, 105, 110, 115,
  116, 101, 97, 100, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39,
  78, 61, 77, 39, 32, 97, 110, 100, 32, 39, 105, 115, 95, 104, 111, 109,
  111, 103, 101, 110, 101, 111, 117, 115, 61, 48, 39, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 45, 108, 111, 99, 97, 108, 32, 45, 115, 112, 108, 105, 116,
  95, 116, 105, 108, 101, 115, 32, 53, 44, 52, 32, 45, 98, 108, 117, 114,
  32, 51, 44, 48, 32, 45, 115, 104, 97, 114, 112, 101, 110, 32, 55, 48,
  48, 32, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 32,
  52, 44, 53, 32, 45, 101, 110, 100, 108, 111, 99, 97, 108, 10, 115, 112,
  108, 105, 116, 95, 116, 105, 108, 101, 115, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 50, 61, 36, 49, 125, 44, 36, 123, 51, 61, 48, 125,
  10, 45, 105, 102, 32, 36, 51, 32, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 83, 112, 108, 105, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 97,
  115, 32, 97, 32, 36, 49, 120, 36, 50, 32, 97, 114, 114, 97, 121, 32,
  111, 102, 32, 104, 111, 109, 111, 103, 101, 110, 101, 111, 117, 115, 32, 116,
  105, 108, 101, 115, 46, 34, 10, 45, 101, 108, 115, 101, 32, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 83, 112, 108, 105, 116, 32, 105, 109, 97, 103,
  101, 36, 63, 32, 97, 115, 32, 97, 32, 36, 49, 120, 36, 50, 32, 97,
  114, 114, 97, 121, 32, 111, 102, 32, 116, 105, 108, 101, 115, 46, 34, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 60, 93, 32, 45, 115,
  32, 121, 44, 36, 50, 32, 45, 115, 32, 120, 44, 36, 49, 32, 45, 105,
  102, 32, 36, 51, 32, 45, 114, 32, 91, 48, 93, 44, 91, 48, 93, 44,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48, 32, 45, 101, 110, 100,
  105, 102, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 121, 32, 58, 32, 101,
  113, 46, 32, 116, 111, 32, 39, 45, 117, 110, 114, 111, 108, 108, 39, 46,
  32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 117, 110,
  114, 111, 108, 108, 32, 58, 32, 95, 97, 120, 105, 115, 61, 123, 32, 120,
  32, 124, 32, 121, 32, 124, 32, 122, 32, 124, 32, 99, 32, 125, 32, 58,
  32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 85, 110,
  114, 111, 108, 108, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 32, 97, 108, 111, 110, 103, 32, 115, 112, 101, 99, 105,
  102, 105, 101, 100, 32, 97, 120, 105, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 121, 39,
  41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 97, 120, 105, 115,
  61, 121, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  40, 49, 44, 50, 44, 51, 59, 52, 44, 53, 44, 54, 59, 55, 44, 56,
  44, 57, 41, 32, 45, 45, 117, 110, 114, 111, 108, 108, 32, 121, 10, 35,
  64, 103, 109, 105, 99, 32, 117, 112, 115, 99, 97, 108, 101, 95, 115, 109,
  97, 114, 116, 32, 58, 32, 119, 105, 100, 116, 104, 44, 95, 104, 101, 105,
  103, 104, 116, 44, 95, 100, 101, 112, 116, 104, 44, 95, 115, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 62, 61, 48, 44, 95, 97, 110, 105, 115, 111,
  116, 114, 111, 112, 121, 61, 91, 48, 44, 49, 93, 44, 115, 104, 97, 114,
  112, 101, 110, 105, 110, 103, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 85, 112, 115, 99, 97, 108, 101, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 119, 105, 116, 104, 32,
  97, 110, 32, 101, 100, 103, 101, 45, 112, 114, 101, 115, 101, 114, 118, 105,
  110, 103, 32, 97, 108, 103, 111, 114, 105, 116, 104, 109, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 104, 101, 105, 103, 104, 116, 61, 49,
  48, 48, 37, 39, 44, 32, 39, 100, 101, 112, 116, 104, 61, 49, 48, 48,
  37, 39, 44, 32, 39, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61,
  50, 39, 44, 32, 39, 97, 110, 105, 115, 111, 116, 114, 111, 112, 121, 61,
  48, 46, 52, 39, 32, 97, 110, 100, 32, 39, 115, 104, 97, 114, 112, 101,
  110, 105, 110, 103, 61, 49, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  114, 101, 115, 105, 122, 101, 50, 100, 121, 32, 49, 48, 48, 32, 45, 45,
  117, 112, 115, 99, 97, 108, 101, 95, 115, 109, 97, 114, 116, 32, 53, 48,
  48, 37, 44, 53, 48, 48, 37, 32, 45, 97, 112, 112, 101, 110, 100, 32,
  120, 10, 117, 112, 115, 99, 97, 108, 101, 95, 115, 109, 97, 114, 116, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 49, 48, 48, 37,
  125, 44, 36, 123, 51, 61, 49, 48, 48, 37, 125, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 36, 123, 52, 61, 50, 125, 62, 61, 48, 32, 38, 38,
  32, 36, 123, 53, 61, 48, 46, 52, 125, 62, 61, 48, 32, 38, 38, 32,
  36, 53, 60, 61, 49, 32, 38, 38, 32, 36, 123, 54, 61, 49, 48, 125,
  62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 85, 112,
  115, 99, 97, 108, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 111,
  32, 36, 49, 120, 36, 50, 120, 36, 51, 44, 32, 119, 105, 116, 104, 32,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 52, 44, 32, 97,
  110, 105, 115, 111, 116, 114, 111, 112, 121, 32, 36, 53, 32, 97, 110, 100,
  32, 115, 104, 97, 114, 112, 101, 110, 105, 110, 103, 32, 36, 54, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 119, 61, 123, 119, 125, 32, 104, 61,
  123, 104, 125, 10, 45, 45, 114, 91, 45, 49, 93, 32, 36, 49, 44, 36,
  50, 44, 36, 51, 44, 49, 44, 48, 10, 45, 105, 102, 32, 123, 119, 60,
  36, 119, 34, 32, 38, 38, 32, 34, 104, 60, 36, 104, 125, 10, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 114, 91, 45, 49, 93, 32, 36, 49, 44,
  36, 50, 44, 36, 51, 44, 49, 48, 48, 37, 44, 50, 10, 45, 101, 108,
  115, 101, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 45, 100, 105, 102,
  102, 117, 115, 105, 111, 110, 116, 101, 110, 115, 111, 114, 115, 32, 48, 44,
  36, 53, 44, 49, 46, 50, 44, 49, 46, 50, 10, 45, 114, 91, 45, 50,
  44, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 49, 48,
  48, 37, 44, 53, 10, 45, 115, 109, 111, 111, 116, 104, 91, 45, 50, 93,
  32, 91, 45, 49, 93, 44, 36, 52, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 34, 45, 115, 104, 97, 114, 112, 101, 110, 91, 45, 49, 93, 32, 36,
  54, 44, 49, 48, 34, 44, 51, 44, 48, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 119, 97, 114, 112, 32, 58, 32,
  91, 119, 97, 114, 112, 105, 110, 103, 95, 102, 105, 101, 108, 100, 93, 44,
  95, 105, 115, 95, 114, 101, 108, 97, 116, 105, 118, 101, 61, 123, 32, 48,
  32, 124, 32, 49, 32, 125, 44, 95, 105, 110, 116, 101, 114, 112, 111, 108,
  97, 116, 105, 111, 110, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121, 44,
  95, 110, 98, 95, 102, 114, 97, 109, 101, 115, 62, 48, 32, 58, 32, 40,
  43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 87, 97, 114, 112,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 32,
  119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 100,
  105, 115, 112, 108, 97, 99, 101, 109, 101, 110, 116, 32, 102, 105, 101, 108,
  100, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 105, 110, 116,
  101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 39, 32, 99, 97, 110, 32,
  98, 101, 32, 123, 32, 48, 61, 110, 101, 97, 114, 101, 115, 116, 45, 110,
  101, 105, 103, 104, 98, 111, 114, 32, 124, 32, 49, 61, 108, 105, 110, 101,
  97, 114, 32, 124, 32, 50, 61, 99, 117, 98, 105, 99, 32, 125, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 98, 111, 117, 110, 100, 97,
  114, 121, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 100,
  105, 114, 105, 99, 104, 108, 101, 116, 32, 124, 32, 49, 61, 110, 101, 117,
  109, 97, 110, 110, 32, 124, 32, 50, 61, 99, 121, 99, 108, 105, 99, 32,
  125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 105, 115, 95,
  114, 101, 108, 97, 116, 105, 118, 101, 61, 48, 39, 44, 32, 39, 105, 110,
  116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 61, 49, 39, 44, 32,
  39, 98, 111, 117, 110, 100, 97, 114, 121, 61, 49, 39, 32, 97, 110, 100,
  32, 39, 110, 98, 95, 102, 114, 97, 109, 101, 115, 61, 49, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 50, 44, 39, 88, 61, 120, 47, 119, 45, 48, 46, 53, 59, 89, 61,
  121, 47, 104, 45, 48, 46, 53, 59, 82, 61, 40, 88, 42, 88, 43, 89,
  42, 89, 41, 94, 48, 46, 53, 59, 65, 61, 97, 116, 97, 110, 50, 40,
  89, 44, 88, 41, 59, 49, 51, 48, 42, 82, 42, 105, 102, 40, 99, 61,
  61, 48, 44, 99, 111, 115, 40, 52, 42, 65, 41, 44, 115, 105, 110, 40,
  56, 42, 65, 41, 41, 39, 32, 45, 119, 97, 114, 112, 91, 45, 50, 93,
  32, 91, 45, 49, 93, 44, 49, 44, 49, 44, 48, 32, 45, 113, 117, 105,
  118, 101, 114, 91, 45, 49, 93, 32, 91, 45, 49, 93, 44, 49, 48, 44,
  48, 46, 50, 44, 49, 44, 49, 44, 49, 48, 48, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 58, 32, 70, 105, 108, 116, 101, 114, 105, 110, 103, 10,
  35, 64, 103, 109, 105, 99, 32, 98, 97, 110, 100, 112, 97, 115, 115, 32,
  58, 32, 95, 109, 105, 110, 95, 102, 114, 101, 113, 91, 37, 93, 44, 95,
  109, 97, 120, 95, 102, 114, 101, 113, 91, 37, 93, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 98, 97, 110, 100, 112,
  97, 115, 115, 32, 102, 105, 108, 116, 101, 114, 32, 116, 111, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32,
  118, 97, 108, 117, 101, 115, 58, 32, 39, 109, 105, 110, 95, 102, 114, 101,
  113, 61, 48, 39, 32, 97, 110, 100, 32, 39, 109, 97, 120, 95, 102, 114,
  101, 113, 61, 50, 48, 37, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 98,
  97, 110, 100, 112, 97, 115, 115, 32, 49, 37, 44, 51, 37, 10, 98, 97,
  110, 100, 112, 97, 115, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 49, 61, 48, 125, 44, 36, 123, 50, 61, 50, 48, 37, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 98, 97,
  110, 100, 112, 97, 115, 115, 32, 102, 105, 108, 116, 101, 114, 32, 91, 36,
  49, 44, 36, 50, 93, 32, 116, 111, 32, 105, 109, 97, 103, 101, 36, 63,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 102, 91, 45, 49, 93, 32,
  34, 115, 113, 114, 116, 40, 40, 120, 47, 119, 45, 48, 46, 53, 41, 94,
  50, 32, 43, 32, 40, 121, 47, 104, 45, 48, 46, 53, 41, 94, 50, 32,
  43, 32, 40, 122, 47, 100, 45, 48, 46, 53, 41, 94, 50, 41, 34, 10,
  45, 110, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 116, 50, 91, 45,
  49, 93, 32, 36, 49, 44, 36, 50, 32, 45, 115, 104, 105, 102, 116, 91,
  45, 49, 93, 32, 123, 105, 110, 116, 40, 119, 47, 50, 41, 125, 44, 123,
  105, 110, 116, 40, 104, 47, 50, 41, 125, 44, 53, 48, 37, 44, 48, 44,
  50, 10, 45, 102, 102, 116, 91, 45, 50, 93, 32, 45, 42, 91, 45, 51,
  93, 32, 91, 45, 49, 93, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 105, 102, 102, 116, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 98, 105, 108, 97, 116, 101, 114, 97, 108,
  32, 58, 32, 91, 103, 117, 105, 100, 101, 93, 44, 115, 116, 100, 95, 118,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 115, 62, 48, 91, 37, 93, 44,
  115, 116, 100, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 114, 91,
  37, 93, 62, 48, 32, 58, 32, 115, 116, 100, 95, 118, 97, 114, 105, 97,
  116, 105, 111, 110, 95, 115, 62, 48, 91, 37, 93, 44, 115, 116, 100, 95,
  118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 114, 91, 37, 93, 62, 48,
  32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  66, 108, 117, 114, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 32, 98, 121, 32, 97, 110, 105, 115, 111, 116, 114, 111,
  112, 105, 99, 32, 40, 101, 118, 101, 110, 116, 117, 97, 108, 108, 121, 32,
  106, 111, 105, 110, 116, 47, 99, 114, 111, 115, 115, 41, 32, 98, 105, 108,
  97, 116, 101, 114, 97, 108, 32, 102, 105, 108, 116, 101, 114, 105, 110, 103,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 102, 32, 97, 32,
  103, 117, 105, 100, 101, 32, 105, 109, 97, 103, 101, 32, 105, 115, 32, 112,
  114, 111, 118, 105, 100, 101, 100, 44, 32, 105, 116, 32, 105, 115, 32, 117,
  115, 101, 100, 32, 102, 111, 114, 32, 99, 111, 109, 112, 117, 116, 105, 110,
  103, 32, 116, 104, 101, 32, 115, 109, 111, 111, 116, 104, 105, 110, 103, 32,
  103, 101, 111, 109, 101, 116, 114, 121, 32, 105, 110, 32, 116, 104, 101, 32,
  99, 114, 111, 115, 115, 32, 98, 105, 108, 97, 116, 101, 114, 97, 108, 32,
  102, 105, 108, 116, 101, 114, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 65, 32, 103, 117, 105, 100, 101, 32, 105, 109, 97, 103, 101, 32, 109,
  117, 115, 116, 32, 98, 101, 32, 111, 102, 32, 116, 104, 101, 32, 115, 97,
  109, 101, 32, 120, 121, 122, 45, 115, 105, 122, 101, 32, 97, 115, 32, 116,
  104, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 91, 48, 93, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 53, 32, 45, 98, 105, 108, 97, 116, 101, 114, 97,
  108, 91, 45, 49, 93, 32, 49, 48, 44, 49, 48, 32, 45, 100, 111, 110,
  101, 10, 35, 64, 103, 109, 105, 99, 32, 98, 32, 58, 32, 101, 113, 46,
  32, 116, 111, 32, 39, 45, 98, 108, 117, 114, 39, 46, 32, 58, 32, 40,
  43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 98, 108, 117, 114, 32, 58,
  32, 115, 116, 100, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 62, 61,
  48, 91, 37, 93, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121, 61, 123,
  32, 48, 61, 100, 105, 114, 105, 99, 104, 108, 101, 116, 32, 124, 32, 49,
  61, 110, 101, 117, 109, 97, 110, 110, 32, 125, 44, 95, 107, 101, 114, 110,
  101, 108, 61, 123, 32, 48, 61, 113, 117, 97, 115, 105, 45, 103, 97, 117,
  115, 115, 105, 97, 110, 32, 40, 102, 97, 115, 116, 101, 114, 41, 32, 124,
  32, 49, 61, 103, 97, 117, 115, 115, 105, 97, 110, 32, 125, 32, 58, 32,
  40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 66, 108, 117,
  114, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 32, 98, 121, 32, 97, 32, 113, 117, 97, 115, 105, 45, 103, 97, 117,
  115, 115, 105, 97, 110, 32, 111, 114, 32, 103, 97, 117, 115, 115, 105, 97,
  110, 32, 102, 105, 108, 116, 101, 114, 32, 40, 114, 101, 99, 117, 114, 115,
  105, 118, 101, 32, 105, 109, 112, 108, 101, 109, 101, 110, 116, 97, 116, 105,
  111, 110, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101,
  113, 46, 32, 116, 111, 32, 39, 45, 98, 39, 41, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 58, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 61, 49,
  39, 32, 97, 110, 100, 32, 39, 107, 101, 114, 110, 101, 108, 61, 48, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 45, 98, 108, 117, 114, 32, 53, 44,
  48, 32, 45, 45, 98, 108, 117, 114, 91, 48, 93, 32, 53, 44, 49, 10,
  35, 64, 103, 109, 105, 99, 32, 98, 108, 117, 114, 95, 97, 110, 103, 117,
  108, 97, 114, 32, 58, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 91,
  37, 93, 44, 95, 99, 120, 44, 95, 99, 121, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 97, 110, 103, 117, 108, 97,
  114, 32, 98, 108, 117, 114, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117,
  101, 115, 58, 32, 39, 99, 120, 61, 99, 121, 61, 48, 46, 53, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 98, 108, 117, 114, 95, 97, 110, 103,
  117, 108, 97, 114, 32, 50, 37, 10, 98, 108, 117, 114, 95, 97, 110, 103,
  117, 108, 97, 114, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50,
  61, 48, 46, 53, 125, 44, 36, 123, 51, 61, 48, 46, 53, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 97, 110,
  103, 117, 108, 97, 114, 32, 98, 108, 117, 114, 32, 111, 110, 32, 105, 109,
  97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 97, 109, 112, 108,
  105, 116, 117, 100, 101, 32, 36, 49, 32, 97, 110, 100, 32, 99, 101, 110,
  116, 101, 114, 32, 40, 36, 50, 44, 36, 51, 41, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 101, 117, 99, 108, 105, 100, 101, 97, 110, 50, 112, 111,
  108, 97, 114, 32, 36, 50, 44, 36, 51, 44, 49, 46, 51, 44, 49, 32,
  45, 101, 120, 112, 97, 110, 100, 95, 121, 32, 49, 54, 44, 50, 32, 45,
  98, 108, 117, 114, 95, 121, 32, 36, 49, 32, 45, 115, 104, 114, 105, 110,
  107, 95, 121, 32, 49, 54, 32, 45, 112, 111, 108, 97, 114, 50, 101, 117,
  99, 108, 105, 100, 101, 97, 110, 32, 36, 50, 44, 36, 51, 44, 49, 46,
  51, 44, 49, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  98, 108, 117, 114, 95, 108, 105, 110, 101, 97, 114, 32, 58, 32, 97, 109,
  112, 108, 105, 116, 117, 100, 101, 49, 91, 37, 93, 44, 95, 97, 109, 112,
  108, 105, 116, 117, 100, 101, 50, 91, 37, 93, 44, 95, 97, 110, 103, 108,
  101, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121, 61, 123, 32, 48, 61,
  100, 105, 114, 105, 99, 104, 108, 101, 116, 32, 124, 32, 49, 61, 110, 101,
  117, 109, 97, 110, 110, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 65, 112, 112, 108, 121, 32, 108, 105, 110, 101, 97, 114, 32, 98, 108,
  117, 114, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 44, 32, 119, 105, 116, 104, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 97, 110, 103, 108, 101, 32, 97, 110, 100, 32,
  97, 109, 112, 108, 105, 116, 117, 100, 101, 115, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108,
  117, 101, 115, 58, 32, 39, 97, 109, 112, 108, 105, 116, 117, 100, 101, 50,
  61, 48, 39, 44, 32, 39, 97, 110, 103, 108, 101, 61, 48, 39, 32, 97,
  110, 100, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 61, 49, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 98, 108, 117, 114, 95, 108, 105, 110,
  101, 97, 114, 32, 49, 48, 44, 48, 44, 52, 53, 10, 98, 108, 117, 114,
  95, 108, 105, 110, 101, 97, 114, 32, 58, 32, 45, 115, 107, 105, 112, 32,
  36, 123, 50, 61, 48, 125, 44, 36, 123, 51, 61, 48, 125, 44, 36, 123,
  52, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112,
  112, 108, 121, 32, 108, 105, 110, 101, 97, 114, 32, 98, 108, 117, 114, 32,
  111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104,
  32, 97, 110, 103, 108, 101, 32, 36, 51, 32, 100, 101, 103, 46, 32, 97,
  110, 100, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 115, 32, 40, 36,
  49, 44, 36, 50, 41, 46, 34, 10, 45, 118, 32, 45, 10, 115, 116, 100,
  49, 61, 123, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99,
  101, 110, 116, 92, 32, 36, 49, 125, 44, 36, 49, 42, 109, 97, 120, 40,
  119, 44, 104, 41, 44, 36, 49, 41, 125, 10, 115, 116, 100, 50, 61, 123,
  105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116,
  92, 32, 36, 50, 125, 44, 36, 50, 42, 109, 97, 120, 40, 119, 44, 104,
  41, 44, 36, 50, 41, 125, 10, 115, 116, 100, 77, 61, 123, 114, 111, 117,
  110, 100, 40, 49, 46, 50, 53, 42, 109, 97, 120, 40, 36, 115, 116, 100,
  49, 44, 36, 115, 116, 100, 50, 41, 41, 125, 10, 45, 105, 102, 32, 123,
  36, 115, 116, 100, 77, 60, 61, 48, 125, 32, 45, 114, 101, 116, 117, 114,
  110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 101, 120, 112, 97,
  110, 100, 95, 120, 121, 32, 36, 115, 116, 100, 77, 44, 123, 36, 52, 33,
  61, 48, 125, 10, 123, 50, 42, 36, 115, 116, 100, 77, 125, 44, 123, 50,
  42, 36, 115, 116, 100, 77, 125, 32, 45, 103, 97, 117, 115, 115, 105, 97,
  110, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 32, 45,
  110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 115, 117, 109, 91, 45, 49,
  93, 10, 45, 99, 111, 110, 118, 111, 108, 118, 101, 95, 102, 102, 116, 32,
  45, 115, 104, 114, 105, 110, 107, 95, 120, 121, 32, 36, 115, 116, 100, 77,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 98, 108, 117, 114, 95, 114, 97,
  100, 105, 97, 108, 32, 58, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101,
  91, 37, 93, 44, 95, 99, 120, 44, 95, 99, 121, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 114, 97, 100, 105, 97,
  108, 32, 98, 108, 117, 114, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117,
  101, 115, 58, 32, 39, 99, 120, 61, 99, 121, 61, 48, 46, 53, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 98, 108, 117, 114, 95, 114, 97, 100,
  105, 97, 108, 32, 50, 37, 10, 98, 108, 117, 114, 95, 114, 97, 100, 105,
  97, 108, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 48,
  46, 53, 125, 44, 36, 123, 51, 61, 48, 46, 53, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 114, 97, 100, 105,
  97, 108, 32, 98, 108, 117, 114, 32, 111, 110, 32, 105, 109, 97, 103, 101,
  36, 63, 44, 32, 119, 105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117,
  100, 101, 32, 36, 49, 32, 97, 110, 100, 32, 99, 101, 110, 116, 101, 114,
  32, 40, 36, 50, 44, 36, 51, 41, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 101, 117, 99, 108, 105, 100, 101, 97, 110, 50, 112, 111, 108, 97, 114,
  32, 36, 50, 44, 36, 51, 44, 53, 44, 49, 32, 45, 98, 108, 117, 114,
  95, 120, 32, 36, 49, 32, 45, 112, 111, 108, 97, 114, 50, 101, 117, 99,
  108, 105, 100, 101, 97, 110, 32, 36, 50, 44, 36, 51, 44, 53, 44, 49,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 98, 108, 117,
  114, 95, 115, 101, 108, 101, 99, 116, 105, 118, 101, 32, 58, 32, 115, 105,
  103, 109, 97, 62, 61, 48, 44, 95, 101, 100, 103, 101, 115, 62, 48, 44,
  95, 110, 98, 95, 115, 99, 97, 108, 101, 115, 62, 48, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 66, 108, 117, 114, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 117, 115, 105, 110, 103,
  32, 115, 101, 108, 101, 99, 116, 105, 118, 101, 32, 103, 97, 117, 115, 115,
  105, 97, 110, 32, 115, 99, 97, 108, 101, 115, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108,
  117, 101, 115, 58, 32, 39, 115, 105, 103, 109, 97, 61, 53, 39, 44, 32,
  39, 101, 100, 103, 101, 115, 61, 48, 46, 53, 39, 32, 97, 110, 100, 32,
  39, 110, 98, 95, 115, 99, 97, 108, 101, 115, 61, 53, 39, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 110, 111, 105, 115, 101, 32, 50, 48, 32, 45, 99,
  117, 116, 32, 48, 44, 50, 53, 53, 32, 45, 45, 108, 111, 99, 97, 108,
  91, 45, 49, 93, 32, 45, 114, 101, 112, 101, 97, 116, 32, 52, 32, 45,
  98, 108, 117, 114, 95, 115, 101, 108, 101, 99, 116, 105, 118, 101, 32, 44,
  32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 108, 111, 99, 97, 108,
  10, 98, 108, 117, 114, 95, 115, 101, 108, 101, 99, 116, 105, 118, 101, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 53, 125,
  62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 48, 46, 53, 125, 62,
  61, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 51, 61,
  53, 125, 41, 32, 38, 38, 32, 36, 51, 62, 48, 34, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 66, 108, 117, 114, 32, 105, 109, 97, 103, 101,
  36, 63, 32, 117, 115, 105, 110, 103, 32, 36, 51, 32, 115, 101, 108, 101,
  99, 116, 105, 118, 101, 32, 103, 97, 117, 115, 115, 105, 97, 110, 32, 115,
  99, 97, 108, 101, 115, 44, 32, 119, 105, 116, 104, 32, 115, 105, 103, 109,
  97, 32, 36, 49, 32, 97, 110, 100, 32, 101, 100, 103, 101, 115, 32, 36,
  50, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123,
  48, 44, 110, 125, 10, 45, 45, 103, 114, 97, 100, 105, 101, 110, 116, 95,
  110, 111, 114, 109, 32, 45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 94,
  91, 45, 49, 93, 32, 123, 45, 109, 97, 120, 40, 48, 46, 48, 49, 44,
  36, 50, 41, 125, 32, 45, 113, 117, 97, 110, 116, 105, 122, 101, 91, 45,
  49, 93, 32, 123, 36, 51, 43, 49, 125, 44, 48, 44, 49, 32, 45, 109,
  105, 110, 91, 45, 49, 93, 32, 123, 36, 51, 45, 49, 125, 32, 45, 114,
  91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 47, 91, 45, 49, 93,
  32, 49, 48, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 51, 32,
  45, 45, 61, 61, 91, 45, 49, 93, 32, 123, 36, 62, 47, 49, 48, 48,
  125, 32, 45, 42, 91, 45, 49, 93, 32, 91, 45, 51, 93, 32, 45, 43,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 98, 91, 45, 50, 93, 32, 123,
  36, 49, 47, 40, 36, 51, 43, 49, 41, 125, 32, 45, 100, 111, 110, 101,
  10, 45, 114, 109, 91, 45, 50, 93, 32, 45, 110, 109, 32, 36, 110, 109,
  44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 98, 108, 117, 114, 95,
  120, 32, 58, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 91, 37, 93,
  62, 61, 48, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121, 61, 123, 32,
  48, 61, 100, 105, 114, 105, 99, 104, 108, 101, 116, 32, 124, 32, 49, 61,
  110, 101, 117, 109, 97, 110, 110, 32, 125, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 66, 108, 117, 114, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 32, 97, 108, 111, 110, 103, 32, 116, 104,
  101, 32, 120, 45, 97, 120, 105, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  58, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 61, 49, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 45, 98, 108, 117, 114, 95, 120, 32, 54, 10,
  98, 108, 117, 114, 95, 120, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 50, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 66,
  108, 117, 114, 32, 105, 109, 97, 103, 101, 36, 63, 32, 97, 108, 111, 110,
  103, 32, 116, 104, 101, 32, 120, 45, 97, 120, 105, 115, 44, 32, 119, 105,
  116, 104, 32, 115, 105, 103, 109, 97, 32, 36, 49, 32, 97, 110, 100, 32,
  34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 33, 36, 50, 44, 110,
  101, 117, 109, 97, 110, 110, 44, 100, 105, 114, 105, 99, 104, 108, 101, 116,
  125, 34, 32, 98, 111, 117, 110, 100, 97, 114, 121, 32, 99, 111, 110, 100,
  105, 116, 105, 111, 110, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 100,
  101, 114, 105, 99, 104, 101, 32, 36, 49, 44, 48, 44, 120, 44, 36, 50,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 98, 108, 117,
  114, 95, 120, 121, 32, 58, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101,
  95, 120, 91, 37, 93, 44, 97, 109, 112, 108, 105, 116, 117, 100, 101, 95,
  121, 91, 37, 93, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121, 61, 123,
  32, 48, 61, 100, 105, 114, 105, 99, 104, 108, 101, 116, 32, 124, 32, 49,
  61, 110, 101, 117, 109, 97, 110, 110, 32, 125, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 66, 108, 117, 114, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 32, 97, 108, 111, 110, 103, 32, 116,
  104, 101, 32, 88, 32, 97, 110, 100, 32, 89, 32, 97, 120, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108,
  116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 98, 111, 117, 110, 100, 97,
  114, 121, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 98, 108,
  117, 114, 95, 120, 121, 32, 54, 10, 98, 108, 117, 114, 95, 120, 121, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 36, 49, 125, 44,
  36, 123, 51, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  66, 108, 117, 114, 32, 105, 109, 97, 103, 101, 36, 63, 32, 97, 108, 111,
  110, 103, 32, 116, 104, 101, 32, 120, 121, 45, 97, 120, 101, 115, 44, 32,
  119, 105, 116, 104, 32, 115, 105, 103, 109, 97, 32, 36, 49, 32, 97, 110,
  100, 32, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 33, 36, 50,
  44, 110, 101, 117, 109, 97, 110, 110, 44, 100, 105, 114, 105, 99, 104, 108,
  101, 116, 125, 34, 32, 98, 111, 117, 110, 100, 97, 114, 121, 32, 99, 111,
  110, 100, 105, 116, 105, 111, 110, 115, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 100, 101, 114, 105, 99, 104, 101, 32, 36, 49, 44, 48, 44, 120, 44,
  36, 51, 32, 45, 100, 101, 114, 105, 99, 104, 101, 32, 36, 50, 44, 48,
  44, 121, 44, 36, 51, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 98, 108, 117, 114, 95, 120, 121, 122, 32, 58, 32, 97, 109, 112,
  108, 105, 116, 117, 100, 101, 95, 120, 91, 37, 93, 44, 97, 109, 112, 108,
  105, 116, 117, 100, 101, 95, 121, 91, 37, 93, 44, 97, 109, 112, 108, 105,
  116, 117, 100, 101, 95, 122, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121,
  61, 123, 32, 48, 61, 100, 105, 114, 105, 99, 104, 108, 101, 116, 32, 124,
  32, 49, 61, 110, 101, 117, 109, 97, 110, 110, 32, 125, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 66, 108, 117, 114, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 97, 108, 111, 110, 103,
  32, 116, 104, 101, 32, 88, 44, 32, 89, 32, 97, 110, 100, 32, 90, 32,
  97, 120, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 98,
  111, 117, 110, 100, 97, 114, 121, 61, 49, 39, 46, 10, 98, 108, 117, 114,
  95, 120, 121, 122, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 52,
  61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 66, 108, 117,
  114, 32, 105, 109, 97, 103, 101, 36, 63, 32, 97, 108, 111, 110, 103, 32,
  116, 104, 101, 32, 120, 121, 122, 45, 97, 120, 101, 115, 44, 32, 119, 105,
  116, 104, 32, 115, 105, 103, 109, 97, 32, 36, 49, 32, 97, 110, 100, 32,
  34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 33, 36, 50, 44, 110,
  101, 117, 109, 97, 110, 110, 44, 100, 105, 114, 105, 99, 104, 108, 101, 116,
  125, 34, 32, 98, 111, 117, 110, 100, 97, 114, 121, 32, 99, 111, 110, 100,
  105, 116, 105, 111, 110, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 100,
  101, 114, 105, 99, 104, 101, 32, 36, 49, 44, 48, 44, 120, 44, 36, 52,
  32, 45, 100, 101, 114, 105, 99, 104, 101, 32, 36, 50, 44, 48, 44, 121,
  44, 36, 52, 32, 45, 100, 101, 114, 105, 99, 104, 101, 32, 36, 51, 44,
  48, 44, 122, 44, 36, 52, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109,
  105, 99, 32, 98, 108, 117, 114, 95, 121, 32, 58, 32, 97, 109, 112, 108,
  105, 116, 117, 100, 101, 91, 37, 93, 62, 61, 48, 44, 95, 98, 111, 117,
  110, 100, 97, 114, 121, 61, 123, 32, 48, 61, 100, 105, 114, 105, 99, 104,
  108, 101, 116, 32, 124, 32, 49, 61, 110, 101, 117, 109, 97, 110, 110, 32,
  125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 66, 108, 117, 114, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32,
  97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 121, 45, 97, 120, 105, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117,
  108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 98, 111, 117, 110, 100,
  97, 114, 121, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 98,
  108, 117, 114, 95, 121, 32, 54, 10, 98, 108, 117, 114, 95, 121, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 49, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 66, 108, 117, 114, 32, 105, 109, 97, 103,
  101, 36, 63, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 121, 45,
  97, 120, 105, 115, 44, 32, 119, 105, 116, 104, 32, 115, 105, 103, 109, 97,
  32, 36, 49, 32, 97, 110, 100, 32, 34, 64, 123, 45, 97, 114, 103, 92,
  32, 49, 43, 33, 36, 50, 44, 110, 101, 117, 109, 97, 110, 110, 44, 100,
  105, 114, 105, 99, 104, 108, 101, 116, 125, 34, 32, 98, 111, 117, 110, 100,
  97, 114, 121, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 115, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 100, 101, 114, 105, 99, 104, 101, 32, 36,
  49, 44, 48, 44, 121, 44, 36, 50, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 98, 108, 117, 114, 95, 122, 32, 58, 32, 97, 109,
  112, 108, 105, 116, 117, 100, 101, 91, 37, 93, 62, 61, 48, 44, 95, 98,
  111, 117, 110, 100, 97, 114, 121, 61, 123, 32, 48, 61, 100, 105, 114, 105,
  99, 104, 108, 101, 116, 32, 124, 32, 49, 61, 110, 101, 117, 109, 97, 110,
  110, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 66, 108, 117,
  114, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 122, 45, 97, 120,
  105, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 98, 111, 117,
  110, 100, 97, 114, 121, 61, 49, 39, 46, 10, 98, 108, 117, 114, 95, 122,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 49, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 66, 108, 117, 114, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32,
  122, 45, 97, 120, 105, 115, 44, 32, 119, 105, 116, 104, 32, 115, 105, 103,
  109, 97, 32, 36, 49, 32, 97, 110, 100, 32, 34, 64, 123, 45, 97, 114,
  103, 92, 32, 49, 43, 33, 36, 50, 44, 110, 101, 117, 109, 97, 110, 110,
  44, 100, 105, 114, 105, 99, 104, 108, 101, 116, 125, 34, 32, 98, 111, 117,
  110, 100, 97, 114, 121, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 115,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 100, 101, 114, 105, 99, 104, 101,
  32, 36, 49, 44, 48, 44, 122, 44, 36, 50, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 98, 111, 107, 101, 104, 32, 58, 32, 95,
  97, 109, 112, 108, 105, 116, 117, 100, 101, 62, 61, 48, 44, 95, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 62, 61, 48, 44, 48, 60, 61, 95,
  100, 101, 110, 115, 105, 116, 121, 60, 61, 49, 48, 48, 44, 95, 98, 111,
  107, 101, 104, 95, 115, 105, 122, 101, 62, 48, 44, 48, 60, 61, 95, 98,
  111, 107, 101, 104, 95, 111, 117, 116, 108, 105, 110, 101, 95, 115, 105, 122,
  101, 60, 61, 49, 48, 48, 44, 95, 98, 111, 107, 101, 104, 95, 111, 117,
  116, 108, 105, 110, 101, 95, 97, 109, 112, 108, 105, 116, 117, 100, 101, 62,
  61, 48, 44, 95, 98, 111, 107, 101, 104, 95, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 67, 114, 101, 97, 116, 101, 32, 97, 32, 66, 111, 107, 101, 104, 32,
  101, 102, 102, 101, 99, 116, 32, 102, 114, 111, 109, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 97, 109, 112, 108, 105, 116, 117, 100, 101,
  61, 50, 48, 48, 39, 44, 32, 39, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 61, 50, 39, 44, 32, 39, 100, 101, 110, 115, 105, 116, 121, 61,
  48, 46, 50, 39, 44, 32, 39, 98, 111, 107, 101, 104, 95, 115, 105, 122,
  101, 61, 50, 52, 39, 44, 32, 39, 98, 111, 107, 101, 104, 95, 111, 117,
  116, 108, 105, 110, 101, 95, 115, 105, 122, 101, 61, 49, 48, 39, 44, 32,
  39, 98, 111, 107, 101, 104, 95, 111, 117, 116, 108, 105, 110, 101, 95, 97,
  109, 112, 108, 105, 116, 117, 100, 101, 61, 49, 39, 32, 97, 110, 100, 32,
  39, 98, 111, 107, 101, 104, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 61, 48, 46, 49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 98,
  111, 107, 101, 104, 32, 44, 10, 98, 111, 107, 101, 104, 32, 58, 32, 45,
  99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 50, 48, 48, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 50, 125, 62, 61, 48, 32,
  38, 38, 32, 36, 123, 51, 61, 48, 46, 50, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 51, 60, 61, 49, 48, 48, 32, 38, 38, 32, 36, 123, 52,
  61, 50, 52, 125, 62, 48, 32, 38, 38, 32, 36, 123, 53, 61, 49, 48,
  125, 62, 61, 48, 32, 38, 38, 32, 36, 53, 60, 61, 49, 48, 48, 32,
  38, 38, 32, 36, 123, 54, 61, 50, 125, 62, 61, 48, 32, 38, 38, 32,
  36, 123, 55, 61, 49, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 56,
  61, 48, 46, 49, 125, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 65, 112, 112, 108, 121, 32, 98, 111, 107, 101, 104, 32, 101,
  102, 102, 101, 99, 116, 32, 116, 111, 32, 105, 109, 97, 103, 101, 36, 63,
  44, 32, 119, 105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101,
  32, 36, 49, 44, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  36, 50, 44, 32, 100, 101, 110, 115, 105, 116, 121, 32, 36, 51, 37, 44,
  32, 98, 111, 107, 101, 104, 32, 115, 105, 122, 101, 32, 36, 52, 44, 32,
  98, 111, 107, 101, 104, 32, 111, 117, 116, 108, 105, 110, 101, 32, 115, 105,
  122, 101, 32, 36, 53, 32, 34, 92, 10, 34, 98, 111, 107, 101, 104, 32,
  111, 117, 116, 108, 105, 110, 101, 32, 97, 109, 112, 108, 105, 116, 117, 100,
  101, 32, 36, 54, 32, 97, 110, 100, 32, 98, 111, 107, 101, 104, 32, 115,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 55, 46, 34, 10, 45,
  118, 32, 45, 10, 50, 53, 54, 44, 50, 53, 54, 32, 45, 61, 91, 45,
  49, 93, 32, 49, 44, 53, 48, 37, 44, 53, 48, 37, 32, 45, 100, 105,
  115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 10, 45, 45, 108,
  116, 91, 45, 49, 93, 32, 55, 48, 37, 32, 45, 116, 50, 91, 45, 50,
  93, 32, 55, 48, 37, 44, 123, 55, 48, 45, 36, 53, 42, 55, 48, 47,
  49, 48, 48, 125, 37, 32, 45, 42, 91, 45, 50, 93, 32, 36, 54, 32,
  45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 114, 91, 45, 49, 93,
  32, 36, 52, 44, 36, 52, 44, 49, 44, 49, 44, 50, 10, 45, 101, 120,
  112, 97, 110, 100, 95, 120, 121, 91, 45, 49, 93, 32, 123, 51, 42, 36,
  55, 125, 44, 48, 32, 45, 98, 91, 45, 49, 93, 32, 36, 55, 44, 48,
  32, 45, 45, 103, 116, 91, 45, 49, 93, 32, 48, 46, 49, 32, 45, 42,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 97, 117, 116, 111, 99, 114, 111,
  112, 91, 45, 49, 93, 10, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101,
  95, 115, 117, 109, 91, 45, 49, 93, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 123, 64, 35, 45, 49, 125, 32, 45, 108, 91, 36, 62, 44, 45, 49,
  93, 10, 45, 45, 114, 101, 109, 111, 118, 101, 95, 112, 105, 120, 101, 108,
  115, 91, 48, 93, 32, 123, 49, 48, 48, 45, 36, 51, 125, 32, 45, 99,
  111, 110, 118, 111, 108, 118, 101, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  44, 48, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 36, 49, 10, 45,
  98, 91, 48, 93, 32, 36, 50, 32, 45, 43, 91, 48, 44, 45, 49, 93,
  32, 45, 99, 91, 48, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 99, 111, 109,
  112, 111, 115, 101, 95, 102, 114, 101, 113, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 67, 111, 109, 112, 111, 115, 101, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 108, 111, 119, 32, 97, 110, 100, 32, 104, 105, 103, 104,
  32, 102, 114, 101, 113, 117, 101, 110, 99, 121, 32, 112, 97, 114, 116, 115,
  32, 105, 110, 116, 111, 32, 110, 101, 119, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 115, 112, 108, 105, 116, 95, 102, 114,
  101, 113, 32, 50, 37, 32, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49,
  93, 32, 120, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 102, 114, 101,
  113, 10, 99, 111, 109, 112, 111, 115, 101, 95, 102, 114, 101, 113, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 111, 115,
  101, 32, 108, 111, 119, 32, 97, 110, 100, 32, 104, 105, 103, 104, 32, 102,
  114, 101, 113, 117, 101, 110, 99, 121, 32, 112, 97, 114, 116, 36, 63, 32,
  105, 110, 116, 111, 32, 110, 101, 119, 32, 105, 109, 97, 103, 101, 115, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 43, 91, 36, 62,
  44, 123, 36, 62, 43, 49, 125, 93, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 99, 111, 110, 118, 111,
  108, 118, 101, 32, 58, 32, 91, 109, 97, 115, 107, 93, 44, 95, 98, 111,
  117, 110, 100, 97, 114, 121, 44, 95, 105, 115, 95, 110, 111, 114, 109, 97,
  108, 105, 122, 101, 100, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 32,
  58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67,
  111, 110, 118, 111, 108, 118, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 32, 98, 121, 32, 115, 112, 101, 99, 105,
  102, 105, 101, 100, 32, 109, 97, 115, 107, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 39, 32, 99,
  97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 100, 105, 114, 105, 99, 104,
  108, 101, 116, 32, 124, 32, 49, 61, 110, 101, 117, 109, 97, 110, 110, 32,
  125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 98, 111, 117,
  110, 100, 97, 114, 121, 61, 49, 39, 32, 97, 110, 100, 32, 39, 105, 115,
  95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 100, 61, 48, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 40, 48, 44, 49, 44, 48, 59, 49, 44, 45, 52,
  44, 49, 59, 48, 44, 49, 44, 48, 41, 32, 45, 99, 111, 110, 118, 111,
  108, 118, 101, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 107, 101,
  101, 112, 91, 45, 50, 93, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 40, 48, 44, 49,
  44, 48, 41, 32, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32,
  49, 51, 48, 44, 49, 44, 49, 44, 49, 44, 51, 32, 45, 45, 99, 111,
  110, 118, 111, 108, 118, 101, 91, 48, 93, 32, 91, 49, 93, 10, 35, 64,
  103, 109, 105, 99, 32, 99, 111, 110, 118, 111, 108, 118, 101, 95, 102, 102,
  116, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 111,
  108, 118, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111, 32, 116,
  104, 114, 111, 117, 103, 104, 32, 102, 111, 117, 114, 105, 101, 114, 32, 116,
  114, 97, 110, 115, 102, 111, 114, 109, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 103, 97, 117, 115, 115,
  105, 97, 110, 91, 45, 49, 93, 32, 50, 48, 44, 49, 44, 52, 53, 32,
  45, 45, 99, 111, 110, 118, 111, 108, 118, 101, 95, 102, 102, 116, 10, 99,
  111, 110, 118, 111, 108, 118, 101, 95, 102, 102, 116, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 111, 108, 118, 101, 32,
  105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116,
  119, 111, 32, 116, 104, 114, 111, 117, 103, 104, 32, 102, 111, 117, 114, 105,
  101, 114, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 115, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110,
  116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123,
  36, 62, 43, 49, 125, 93, 10, 119, 50, 61, 123, 105, 110, 116, 40, 64,
  123, 48, 44, 119, 125, 47, 50, 41, 125, 32, 104, 50, 61, 123, 105, 110,
  116, 40, 64, 123, 48, 44, 104, 125, 47, 50, 41, 125, 32, 100, 50, 61,
  123, 105, 110, 116, 40, 64, 123, 48, 44, 100, 125, 47, 50, 41, 125, 10,
  45, 114, 91, 49, 93, 32, 91, 48, 93, 44, 91, 48, 93, 44, 91, 48,
  93, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 44,
  48, 46, 53, 44, 48, 46, 53, 32, 45, 115, 104, 105, 102, 116, 91, 49,
  93, 32, 45, 36, 119, 50, 44, 45, 36, 104, 50, 44, 45, 36, 100, 50,
  44, 48, 44, 50, 10, 45, 102, 102, 116, 91, 48, 93, 32, 45, 102, 102,
  116, 91, 50, 93, 10, 45, 45, 42, 91, 45, 52, 93, 32, 91, 45, 49,
  93, 32, 45, 45, 42, 91, 45, 52, 93, 32, 91, 45, 51, 93, 32, 45,
  43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 42, 91, 45, 53, 44, 45,
  51, 93, 32, 45, 42, 91, 45, 51, 44, 45, 50, 93, 32, 45, 45, 91,
  45, 51, 44, 45, 50, 93, 10, 45, 105, 102, 102, 116, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 99, 111, 114,
  114, 101, 108, 97, 116, 101, 32, 58, 32, 91, 109, 97, 115, 107, 93, 44,
  95, 98, 111, 117, 110, 100, 97, 114, 121, 44, 95, 105, 115, 95, 110, 111,
  114, 109, 97, 108, 105, 122, 101, 100, 61, 123, 32, 48, 32, 124, 32, 49,
  32, 125, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 67, 111, 114, 114, 101, 108, 97, 116, 101, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 98, 121, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 109, 97, 115, 107, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 39, 98, 111, 117, 110, 100, 97, 114,
  121, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 100, 105,
  114, 105, 99, 104, 108, 101, 116, 32, 124, 32, 49, 61, 110, 101, 117, 109,
  97, 110, 110, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 98, 111, 117, 110, 100, 97, 114, 121, 61, 49, 39, 32, 97, 110, 100,
  32, 39, 105, 115, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 100, 61,
  48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 40, 48, 44, 49, 44, 48, 59,
  49, 44, 45, 52, 44, 49, 59, 48, 44, 49, 44, 48, 41, 32, 45, 99,
  111, 114, 114, 101, 108, 97, 116, 101, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 32, 45, 107, 101, 101, 112, 91, 45, 50, 93, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 45, 99, 114, 111, 112, 32, 52, 48, 37, 44, 52, 48, 37, 44,
  54, 48, 37, 44, 54, 48, 37, 32, 45, 45, 99, 111, 114, 114, 101, 108,
  97, 116, 101, 91, 48, 93, 32, 91, 45, 49, 93, 44, 48, 44, 49, 10,
  35, 64, 103, 109, 105, 99, 32, 99, 114, 111, 115, 115, 95, 99, 111, 114,
  114, 101, 108, 97, 116, 105, 111, 110, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 99, 114, 111, 115, 115, 45,
  99, 111, 114, 114, 101, 108, 97, 116, 105, 111, 110, 32, 117, 115, 105, 110,
  103, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 45, 115, 104, 105, 102, 116, 32, 45, 51, 48, 44, 45,
  50, 48, 32, 45, 99, 114, 111, 115, 115, 95, 99, 111, 114, 114, 101, 108,
  97, 116, 105, 111, 110, 10, 99, 114, 111, 115, 115, 95, 99, 111, 114, 114,
  101, 108, 97, 116, 105, 111, 110, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 99, 114, 111, 115, 115,
  45, 99, 111, 114, 114, 101, 108, 97, 116, 105, 111, 110, 32, 117, 115, 105,
  110, 103, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111, 32, 105, 109,
  97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125,
  32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 45,
  110, 111, 114, 109, 32, 45, 102, 102, 116, 91, 45, 50, 93, 32, 45, 102,
  102, 116, 91, 45, 49, 93, 32, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  42, 91, 45, 50, 93, 32, 91, 45, 53, 93, 32, 45, 42, 91, 45, 49,
  93, 32, 91, 45, 54, 93, 10, 45, 45, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 42, 91, 45, 53, 44, 45, 51, 93, 32, 45, 42, 91, 45, 51,
  44, 45, 50, 93, 32, 45, 43, 91, 45, 51, 44, 45, 50, 93, 32, 45,
  105, 102, 102, 116, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 99, 117, 114, 118, 97, 116, 117, 114, 101, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32,
  105, 115, 111, 112, 104, 111, 116, 101, 32, 99, 117, 114, 118, 97, 116, 117,
  114, 101, 115, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 98, 108,
  117, 114, 32, 49, 48, 32, 45, 99, 117, 114, 118, 97, 116, 117, 114, 101,
  10, 99, 117, 114, 118, 97, 116, 117, 114, 101, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 105, 115,
  111, 112, 104, 111, 116, 101, 32, 99, 117, 114, 118, 97, 116, 117, 114, 101,
  115, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 100, 61, 61, 49, 125,
  10, 45, 45, 103, 32, 120, 121, 44, 48, 32, 45, 104, 101, 115, 115, 105,
  97, 110, 91, 45, 51, 93, 32, 120, 120, 120, 121, 121, 121, 10, 45, 42,
  91, 45, 51, 93, 32, 91, 45, 50, 93, 32, 45, 42, 91, 45, 52, 93,
  32, 91, 45, 49, 93, 32, 45, 42, 91, 45, 52, 93, 32, 45, 50, 10,
  45, 43, 91, 45, 52, 44, 45, 51, 93, 32, 45, 42, 91, 45, 51, 93,
  32, 91, 45, 50, 93, 10, 45, 115, 113, 114, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 42, 91, 45, 52, 93, 32, 91, 45, 49, 93, 32, 45, 43,
  91, 45, 52, 44, 45, 51, 93, 10, 45, 43, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 43, 91, 45, 49, 93, 32, 48, 46, 49, 32, 45, 94, 91,
  45, 49, 93, 32, 49, 46, 53, 32, 45, 47, 10, 45, 101, 108, 115, 101,
  10, 45, 45, 105, 110, 110, 32, 45, 45, 103, 114, 97, 100, 105, 101, 110,
  116, 95, 110, 111, 114, 109, 91, 45, 50, 93, 32, 45, 108, 97, 112, 108,
  97, 99, 105, 97, 110, 91, 45, 51, 93, 10, 45, 45, 91, 45, 51, 44,
  45, 50, 93, 32, 45, 43, 91, 45, 49, 93, 32, 48, 46, 49, 32, 45,
  47, 91, 45, 50, 44, 45, 49, 93, 10, 45, 45, 105, 110, 110, 91, 45,
  49, 93, 32, 45, 108, 97, 112, 108, 97, 99, 105, 97, 110, 91, 45, 50,
  93, 32, 45, 45, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 100, 101, 98, 108, 117, 114, 32, 58, 32, 97, 109, 112,
  108, 105, 116, 117, 100, 101, 91, 37, 93, 62, 61, 48, 44, 95, 110, 98,
  95, 105, 116, 101, 114, 62, 61, 48, 44, 95, 100, 116, 62, 61, 48, 44,
  95, 114, 101, 103, 117, 108, 62, 61, 48, 44, 95, 114, 101, 103, 117, 108,
  95, 116, 121, 112, 101, 61, 123, 32, 48, 61, 84, 105, 107, 104, 111, 110,
  111, 118, 32, 124, 32, 49, 61, 109, 101, 97, 110, 99, 117, 114, 118, 46,
  32, 124, 32, 50, 61, 84, 86, 32, 125, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 98, 108, 117, 114, 32, 105, 109, 97, 103, 101, 32,
  117, 115, 105, 110, 103, 32, 97, 32, 114, 101, 103, 117, 108, 97, 114, 105,
  122, 101, 100, 32, 74, 97, 110, 115, 115, 111, 110, 45, 86, 97, 110, 32,
  67, 105, 116, 116, 101, 114, 116, 32, 97, 108, 103, 111, 114, 105, 116, 104,
  109, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 110, 98, 95,
  105, 116, 101, 114, 61, 49, 48, 39, 44, 32, 39, 100, 116, 61, 50, 48,
  39, 44, 32, 39, 114, 101, 103, 117, 108, 61, 48, 46, 55, 39, 32, 97,
  110, 100, 32, 39, 114, 101, 103, 117, 108, 95, 116, 121, 112, 101, 61, 49,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 98, 108, 117, 114, 32, 51, 32,
  45, 45, 100, 101, 98, 108, 117, 114, 32, 51, 44, 52, 48, 44, 50, 48,
  44, 48, 46, 48, 49, 10, 100, 101, 98, 108, 117, 114, 32, 58, 32, 45,
  99, 104, 101, 99, 107, 32, 34, 36, 123, 50, 61, 49, 48, 125, 62, 61,
  48, 32, 38, 38, 32, 36, 123, 51, 61, 50, 48, 125, 62, 61, 48, 32,
  38, 38, 32, 36, 123, 52, 61, 48, 46, 55, 125, 62, 61, 48, 34, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 53, 61, 49, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 68, 101, 98, 108, 117, 114, 32, 105, 109, 97,
  103, 101, 36, 63, 32, 119, 105, 116, 104, 32, 97, 32, 114, 101, 103, 117,
  108, 97, 114, 105, 122, 101, 100, 32, 74, 97, 110, 115, 115, 111, 110, 45,
  86, 97, 110, 32, 67, 105, 116, 116, 101, 114, 116, 32, 97, 108, 103, 111,
  114, 105, 116, 104, 109, 44, 32, 119, 105, 116, 104, 32, 115, 105, 103, 109,
  97, 32, 36, 49, 44, 32, 36, 50, 32, 105, 116, 101, 114, 97, 116, 105,
  111, 110, 115, 44, 32, 116, 105, 109, 101, 32, 115, 116, 101, 112, 32, 36,
  51, 32, 97, 110, 100, 32, 114, 101, 103, 117, 108, 97, 114, 105, 122, 97,
  116, 105, 111, 110, 32, 36, 52, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 91, 48, 93, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 36, 50, 10, 45, 105, 102, 32, 123, 36,
  53, 62, 61, 50, 125, 32, 45, 45, 99, 117, 114, 118, 97, 116, 117, 114,
  101, 91, 45, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 53, 62,
  61, 49, 125, 32, 45, 45, 105, 101, 101, 91, 45, 49, 93, 10, 45, 101,
  108, 115, 101, 32, 45, 45, 108, 97, 112, 108, 97, 99, 105, 97, 110, 91,
  45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 42, 91, 45, 49,
  93, 32, 36, 52, 10, 45, 45, 98, 91, 45, 50, 93, 32, 36, 49, 32,
  45, 45, 91, 45, 49, 93, 32, 91, 45, 52, 93, 10, 45, 45, 91, 45,
  50, 44, 45, 49, 93, 10, 45, 42, 91, 45, 49, 93, 32, 123, 36, 51,
  47, 40, 48, 46, 48, 48, 48, 49, 43, 109, 97, 120, 40, 97, 98, 115,
  40, 64, 123, 45, 49, 44, 109, 125, 41, 44, 97, 98, 115, 40, 64, 123,
  45, 49, 44, 77, 125, 41, 41, 41, 125, 10, 45, 43, 91, 45, 50, 44,
  45, 49, 93, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 45, 50,
  93, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 100, 101, 98, 108, 117, 114, 95, 103, 111, 108, 100, 109,
  101, 105, 110, 101, 108, 32, 58, 32, 115, 105, 103, 109, 97, 62, 61, 48,
  44, 32, 95, 110, 98, 95, 105, 116, 101, 114, 62, 61, 48, 44, 32, 95,
  97, 99, 99, 101, 108, 101, 114, 97, 116, 105, 111, 110, 62, 61, 48, 44,
  32, 95, 107, 101, 114, 110, 101, 108, 95, 116, 121, 112, 101, 61, 123, 32,
  48, 61, 113, 117, 97, 115, 105, 45, 103, 97, 117, 115, 115, 105, 97, 110,
  32, 40, 102, 97, 115, 116, 101, 114, 41, 32, 124, 32, 49, 61, 103, 97,
  117, 115, 115, 105, 97, 110, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 98, 108, 117, 114, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 117, 115, 105, 110, 103, 32,
  71, 111, 108, 100, 45, 77, 101, 105, 110, 101, 108, 32, 97, 108, 103, 111,
  114, 105, 116, 104, 109, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39,
  110, 98, 95, 105, 116, 101, 114, 61, 56, 39, 44, 32, 39, 97, 99, 99,
  101, 108, 101, 114, 97, 116, 105, 111, 110, 61, 49, 39, 32, 97, 110, 100,
  32, 39, 107, 101, 114, 110, 101, 108, 95, 116, 121, 112, 101, 61, 49, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 45, 98, 108, 117, 114, 32, 49, 32,
  45, 45, 100, 101, 98, 108, 117, 114, 95, 103, 111, 108, 100, 109, 101, 105,
  110, 101, 108, 91, 45, 49, 93, 32, 49, 10, 100, 101, 98, 108, 117, 114,
  95, 103, 111, 108, 100, 109, 101, 105, 110, 101, 108, 32, 58, 32, 45, 99,
  104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48, 32, 38, 38, 32, 36,
  123, 50, 61, 56, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 51, 61,
  49, 125, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 52,
  61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 101, 98,
  108, 117, 114, 32, 105, 109, 97, 103, 101, 36, 63, 32, 117, 115, 105, 110,
  103, 32, 71, 111, 108, 100, 45, 77, 101, 105, 110, 101, 108, 32, 97, 108,
  103, 111, 114, 105, 116, 104, 109, 44, 32, 119, 105, 116, 104, 32, 115, 105,
  103, 109, 97, 32, 36, 49, 44, 32, 36, 50, 32, 105, 116, 101, 114, 97,
  116, 105, 111, 110, 115, 44, 32, 97, 99, 99, 101, 108, 101, 114, 97, 116,
  105, 111, 110, 32, 36, 51, 32, 97, 110, 100, 32, 34, 64, 123, 45, 97,
  114, 103, 92, 32, 49, 43, 33, 36, 52, 44, 34, 34, 44, 113, 117, 97,
  115, 105, 45, 125, 34, 103, 97, 117, 115, 115, 105, 97, 110, 32, 107, 101,
  114, 110, 101, 108, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 91, 48,
  93, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 50, 10, 45, 45, 98,
  91, 45, 49, 93, 32, 36, 49, 44, 49, 44, 36, 52, 32, 45, 45, 47,
  91, 48, 44, 45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45,
  94, 91, 45, 49, 93, 32, 36, 51, 32, 45, 42, 91, 45, 49, 44, 45,
  50, 93, 10, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 93, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 100, 101, 98, 108, 117, 114, 95, 114,
  105, 99, 104, 97, 114, 100, 115, 111, 110, 108, 117, 99, 121, 32, 58, 32,
  115, 105, 103, 109, 97, 62, 61, 48, 44, 32, 110, 98, 95, 105, 116, 101,
  114, 62, 61, 48, 44, 32, 95, 107, 101, 114, 110, 101, 108, 95, 116, 121,
  112, 101, 61, 123, 32, 48, 61, 113, 117, 97, 115, 105, 45, 103, 97, 117,
  115, 115, 105, 97, 110, 32, 40, 102, 97, 115, 116, 101, 114, 41, 32, 124,
  32, 49, 61, 103, 97, 117, 115, 115, 105, 97, 110, 32, 125, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 98, 108, 117, 114, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 117,
  115, 105, 110, 103, 32, 82, 105, 99, 104, 97, 114, 100, 115, 111, 110, 45,
  76, 117, 99, 121, 32, 97, 108, 103, 111, 114, 105, 116, 104, 109, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116,
  32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 110, 98, 95, 105, 116, 101,
  114, 61, 53, 48, 39, 32, 97, 110, 100, 32, 39, 107, 101, 114, 110, 101,
  108, 95, 116, 121, 112, 101, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 45, 98, 108, 117, 114, 32, 49, 32, 45, 45, 100, 101, 98, 108, 117,
  114, 95, 114, 105, 99, 104, 97, 114, 100, 115, 111, 110, 108, 117, 99, 121,
  91, 45, 49, 93, 32, 49, 10, 100, 101, 98, 108, 117, 114, 95, 114, 105,
  99, 104, 97, 114, 100, 115, 111, 110, 108, 117, 99, 121, 32, 58, 32, 45,
  99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48, 32, 38, 38, 32,
  36, 123, 50, 61, 53, 48, 125, 62, 61, 48, 34, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 51, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 68, 101, 98, 108, 117, 114, 32, 105, 109, 97, 103, 101, 36, 63,
  32, 117, 115, 105, 110, 103, 32, 82, 105, 99, 104, 97, 114, 100, 115, 111,
  110, 45, 76, 117, 99, 121, 32, 97, 108, 103, 111, 114, 105, 116, 104, 109,
  44, 32, 119, 105, 116, 104, 32, 115, 105, 103, 109, 97, 32, 36, 49, 44,
  32, 36, 50, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 97,
  110, 100, 32, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 33, 36,
  51, 44, 34, 34, 44, 113, 117, 97, 115, 105, 45, 125, 34, 103, 97, 117,
  115, 115, 105, 97, 110, 32, 107, 101, 114, 110, 101, 108, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 91, 48, 93, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 36, 50, 10, 45, 45, 98, 91, 45, 49, 93, 32, 36, 49, 44,
  49, 44, 123, 36, 51, 33, 61, 48, 125, 32, 45, 45, 47, 91, 48, 44,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45, 98, 91, 45,
  49, 93, 32, 36, 49, 44, 49, 44, 123, 36, 51, 33, 61, 48, 125, 32,
  45, 42, 91, 45, 49, 44, 45, 50, 93, 10, 45, 100, 111, 110, 101, 32,
  45, 114, 109, 91, 48, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 100,
  101, 99, 111, 110, 118, 111, 108, 118, 101, 95, 102, 102, 116, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 99, 111, 110, 118, 111, 108, 118,
  101, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111, 32, 116, 104, 114,
  111, 117, 103, 104, 32, 102, 111, 117, 114, 105, 101, 114, 32, 116, 114, 97,
  110, 115, 102, 111, 114, 109, 115, 46, 10, 100, 101, 99, 111, 110, 118, 111,
  108, 118, 101, 95, 102, 102, 116, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 68, 101, 99, 111, 110, 118, 111, 108, 118, 101, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111,
  32, 116, 104, 114, 111, 117, 103, 104, 32, 102, 111, 117, 114, 105, 101, 114,
  32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 115, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40,
  64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62,
  43, 49, 125, 93, 10, 119, 50, 61, 123, 105, 110, 116, 40, 64, 123, 48,
  44, 119, 125, 47, 50, 41, 125, 32, 104, 50, 61, 123, 105, 110, 116, 40,
  64, 123, 48, 44, 104, 125, 47, 50, 41, 125, 32, 100, 50, 61, 123, 105,
  110, 116, 40, 64, 123, 48, 44, 100, 125, 47, 50, 41, 125, 10, 45, 114,
  91, 49, 93, 32, 91, 48, 93, 44, 91, 48, 93, 44, 91, 48, 93, 44,
  49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 44, 48, 46,
  53, 44, 48, 46, 53, 32, 45, 115, 104, 105, 102, 116, 91, 49, 93, 32,
  45, 36, 119, 50, 44, 45, 36, 104, 50, 44, 45, 36, 100, 50, 44, 48,
  44, 50, 10, 45, 102, 102, 116, 91, 48, 93, 32, 45, 102, 102, 116, 91,
  49, 93, 10, 45, 45, 115, 113, 114, 91, 45, 50, 93, 32, 45, 45, 115,
  113, 114, 91, 45, 50, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 43, 91, 45, 49, 93, 32, 49, 101, 45, 53, 10, 45, 45, 42,
  91, 45, 52, 93, 32, 91, 45, 51, 93, 10, 45, 45, 42, 91, 45, 54,
  93, 32, 91, 45, 51, 93, 10, 45, 45, 91, 45, 50, 44, 45, 49, 93,
  10, 45, 42, 91, 45, 54, 44, 45, 52, 93, 10, 45, 42, 91, 45, 52,
  44, 45, 51, 93, 10, 45, 43, 91, 45, 52, 44, 45, 51, 93, 10, 45,
  47, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 47, 91, 45, 51,
  44, 45, 50, 93, 10, 45, 105, 102, 102, 116, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 100, 101, 105, 110, 116,
  101, 114, 108, 97, 99, 101, 32, 58, 32, 95, 109, 101, 116, 104, 111, 100,
  61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 101, 105, 110, 116, 101, 114, 108, 97, 99, 101, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32,
  40, 39, 109, 101, 116, 104, 111, 100, 39, 32, 99, 97, 110, 32, 98, 101,
  32, 123, 32, 48, 61, 115, 116, 97, 110, 100, 97, 114, 100, 32, 111, 114,
  32, 49, 61, 109, 111, 116, 105, 111, 110, 45, 99, 111, 109, 112, 101, 110,
  115, 97, 116, 101, 100, 32, 125, 41, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  58, 32, 39, 109, 101, 116, 104, 111, 100, 61, 48, 39, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 45, 114, 111, 116, 97, 116, 101, 32, 51, 44, 49, 44,
  49, 44, 53, 48, 37, 44, 53, 48, 37, 32, 45, 114, 101, 115, 105, 122,
  101, 32, 49, 48, 48, 37, 44, 53, 48, 37, 32, 45, 114, 101, 115, 105,
  122, 101, 32, 49, 48, 48, 37, 44, 50, 48, 48, 37, 44, 49, 44, 51,
  44, 52, 32, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 48, 44,
  49, 32, 45, 97, 100, 100, 32, 45, 45, 100, 101, 105, 110, 116, 101, 114,
  108, 97, 99, 101, 32, 49, 10, 100, 101, 105, 110, 116, 101, 114, 108, 97,
  99, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 101, 105, 110, 116,
  101, 114, 108, 97, 99, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 119,
  105, 116, 104, 32, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 33,
  36, 49, 44, 109, 111, 116, 105, 111, 110, 45, 99, 111, 109, 112, 101, 110,
  115, 97, 116, 101, 100, 44, 115, 116, 97, 110, 100, 97, 114, 100, 125, 34,
  32, 109, 101, 116, 104, 111, 100, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 119, 104, 61, 123, 119, 125, 44, 123, 104, 125, 10, 45, 115, 32, 121,
  32, 45, 97, 91, 48, 45, 45, 49, 58, 50, 93, 32, 121, 32, 45, 97,
  91, 94, 48, 93, 32, 121, 32, 45, 114, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 44, 48, 32, 45, 114, 32, 49, 48, 48, 37, 44, 50, 48, 48,
  37, 44, 49, 44, 49, 48, 48, 37, 44, 53, 10, 45, 105, 102, 32, 123,
  36, 49, 33, 61, 48, 125, 32, 45, 45, 100, 105, 115, 112, 108, 97, 99,
  101, 109, 101, 110, 116, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48,
  46, 48, 53, 32, 45, 119, 97, 114, 112, 91, 45, 51, 93, 32, 91, 45,
  49, 93, 44, 49, 44, 49, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 43, 32, 45, 47, 32, 50, 32,
  45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 114, 32, 36, 119, 104, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 100, 101, 110, 111, 105, 115, 101, 32,
  58, 32, 115, 116, 100, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  115, 62, 61, 48, 44, 95, 115, 116, 100, 95, 118, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 112, 62, 61, 48, 44, 95, 112, 97, 116, 99, 104, 95,
  115, 105, 122, 101, 62, 61, 48, 44, 95, 108, 111, 111, 107, 117, 112, 95,
  115, 105, 122, 101, 62, 61, 48, 44, 95, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 44, 95, 102, 97, 115, 116, 95, 97, 112, 112, 114, 111, 120,
  61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 32, 58, 32, 40, 43, 41,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 110, 111, 105, 115,
  101, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 32, 98, 121, 32, 110, 111, 110, 45, 108, 111, 99, 97, 108, 32, 112,
  97, 116, 99, 104, 32, 97, 118, 101, 114, 97, 103, 105, 110, 103, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116,
  32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 115, 116, 100, 95, 118, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 112, 61, 49, 48, 39, 44, 32, 39,
  112, 97, 116, 99, 104, 95, 115, 105, 122, 101, 61, 53, 39, 44, 32, 39,
  108, 111, 111, 107, 117, 112, 95, 115, 105, 122, 101, 61, 54, 39, 32, 97,
  110, 100, 32, 39, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 49,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 100, 101, 110, 111, 105, 115,
  101, 32, 53, 44, 53, 44, 56, 10, 35, 64, 103, 109, 105, 99, 32, 100,
  101, 110, 111, 105, 115, 101, 95, 104, 97, 97, 114, 32, 58, 32, 95, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 62, 61, 48, 44, 95, 110, 98, 95,
  115, 99, 97, 108, 101, 115, 62, 61, 48, 44, 95, 99, 121, 99, 108, 101,
  95, 115, 112, 105, 110, 110, 105, 110, 103, 62, 48, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 68, 101, 110, 111, 105, 115, 101, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 32, 117, 115, 105, 110,
  103, 32, 104, 97, 97, 114, 45, 119, 97, 118, 101, 108, 101, 116, 32, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 105, 110, 103, 32, 119, 105, 116, 104,
  32, 99, 121, 99, 108, 101, 32, 115, 112, 105, 110, 110, 105, 110, 103, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 101, 116, 32, 39, 110,
  98, 95, 115, 99, 97, 108, 101, 115, 61, 61, 48, 39, 32, 116, 111, 32,
  97, 117, 116, 111, 109, 97, 116, 105, 99, 97, 108, 108, 121, 32, 100, 101,
  116, 101, 114, 109, 105, 110, 101, 32, 116, 104, 101, 32, 111, 112, 116, 105,
  109, 97, 108, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 115, 99,
  97, 108, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 61, 49, 46, 52, 39, 44, 32,
  39, 110, 98, 95, 115, 99, 97, 108, 101, 61, 48, 39, 32, 97, 110, 100,
  32, 39, 99, 121, 99, 108, 101, 95, 115, 112, 105, 110, 110, 105, 110, 103,
  61, 49, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 110, 111, 105, 115,
  101, 32, 50, 48, 32, 45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 45,
  100, 101, 110, 111, 105, 115, 101, 95, 104, 97, 97, 114, 91, 45, 49, 93,
  32, 48, 46, 56, 10, 100, 101, 110, 111, 105, 115, 101, 95, 104, 97, 97,
  114, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61,
  49, 46, 52, 125, 62, 61, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116,
  40, 36, 123, 50, 61, 48, 125, 41, 32, 38, 38, 32, 36, 50, 62, 61,
  48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 51, 61, 49,
  48, 125, 41, 32, 38, 38, 32, 36, 51, 62, 48, 34, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 68, 101, 110, 111, 105, 115, 101, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 117, 115, 105, 110, 103, 32, 104, 97, 97, 114,
  45, 119, 97, 118, 101, 108, 101, 116, 32, 116, 104, 114, 101, 115, 104, 111,
  108, 100, 105, 110, 103, 44, 32, 119, 105, 116, 104, 32, 116, 104, 114, 101,
  115, 104, 111, 108, 100, 32, 36, 49, 44, 32, 34, 92, 10, 64, 123, 45,
  97, 114, 103, 92, 32, 49, 43, 40, 36, 50, 62, 48, 41, 44, 97, 117,
  116, 111, 44, 36, 50, 125, 34, 32, 115, 99, 97, 108, 101, 115, 32, 97,
  110, 100, 32, 36, 51, 32, 115, 112, 105, 110, 110, 105, 110, 103, 32, 99,
  121, 99, 108, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110,
  109, 61, 64, 123, 48, 44, 110, 125, 10, 110, 98, 95, 115, 99, 97, 108,
  101, 115, 61, 123, 109, 105, 110, 40, 105, 102, 40, 36, 50, 44, 36, 50,
  44, 51, 50, 41, 44, 105, 110, 116, 40, 108, 111, 103, 50, 40, 109, 105,
  110, 40, 119, 44, 104, 41, 41, 45, 49, 41, 41, 125, 10, 119, 61, 123,
  119, 125, 32, 104, 61, 123, 104, 125, 32, 100, 61, 123, 100, 125, 32, 115,
  105, 103, 109, 97, 61, 64, 123, 45, 118, 97, 114, 105, 97, 110, 99, 101,
  95, 110, 111, 105, 115, 101, 125, 10, 45, 114, 32, 123, 114, 111, 117, 110,
  100, 40, 119, 44, 50, 94, 40, 36, 110, 98, 95, 115, 99, 97, 108, 101,
  115, 43, 49, 41, 44, 49, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40,
  104, 44, 50, 94, 40, 36, 110, 98, 95, 115, 99, 97, 108, 101, 115, 43,
  49, 41, 44, 49, 41, 125, 44, 123, 105, 102, 40, 100, 61, 61, 49, 44,
  49, 44, 114, 111, 117, 110, 100, 40, 100, 44, 50, 94, 40, 36, 110, 98,
  95, 115, 99, 97, 108, 101, 115, 43, 49, 41, 44, 49, 41, 41, 125, 44,
  49, 48, 48, 37, 44, 48, 44, 48, 10, 45, 45, 102, 32, 48, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 36, 51, 10, 100, 120, 61, 123, 114, 111,
  117, 110, 100, 40, 63, 40, 48, 44, 123, 52, 42, 36, 110, 98, 95, 115,
  99, 97, 108, 101, 115, 125, 41, 41, 125, 10, 100, 121, 61, 123, 114, 111,
  117, 110, 100, 40, 63, 40, 48, 44, 123, 52, 42, 36, 110, 98, 95, 115,
  99, 97, 108, 101, 115, 125, 41, 41, 125, 10, 100, 122, 61, 123, 105, 102,
  40, 36, 100, 61, 61, 49, 44, 48, 44, 114, 111, 117, 110, 100, 40, 63,
  40, 48, 44, 123, 52, 42, 36, 110, 98, 95, 115, 99, 97, 108, 101, 115,
  125, 41, 41, 41, 125, 10, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93,
  32, 36, 100, 120, 44, 36, 100, 121, 44, 36, 100, 122, 44, 48, 44, 50,
  10, 45, 104, 97, 97, 114, 91, 45, 49, 93, 32, 36, 110, 98, 95, 115,
  99, 97, 108, 101, 115, 10, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100,
  91, 45, 49, 93, 32, 123, 36, 49, 42, 36, 115, 105, 103, 109, 97, 125,
  44, 49, 10, 45, 105, 104, 97, 97, 114, 91, 45, 49, 93, 32, 36, 110,
  98, 95, 115, 99, 97, 108, 101, 115, 10, 45, 115, 104, 105, 102, 116, 91,
  45, 49, 93, 32, 123, 45, 36, 100, 120, 125, 44, 123, 45, 36, 100, 121,
  125, 44, 123, 45, 36, 100, 122, 125, 44, 48, 44, 50, 10, 45, 43, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109,
  91, 48, 93, 32, 45, 47, 32, 36, 51, 32, 45, 114, 32, 36, 119, 44,
  36, 104, 44, 36, 100, 44, 49, 48, 48, 37, 44, 48, 10, 45, 110, 109,
  32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 100,
  101, 114, 105, 99, 104, 101, 32, 58, 32, 115, 116, 100, 95, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 62, 61, 48, 91, 37, 93, 44, 111, 114, 100,
  101, 114, 61, 123, 32, 48, 32, 124, 32, 49, 32, 124, 32, 50, 32, 125,
  44, 97, 120, 105, 115, 61, 123, 32, 120, 32, 124, 32, 121, 32, 124, 32,
  122, 32, 124, 32, 99, 32, 125, 44, 95, 98, 111, 117, 110, 100, 97, 114,
  121, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 65, 112, 112, 108, 121, 32, 68, 101, 114, 105, 99, 104, 101, 32, 114,
  101, 99, 117, 114, 115, 105, 118, 101, 32, 102, 105, 108, 116, 101, 114, 32,
  119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 115,
  116, 97, 110, 100, 97, 114, 100, 32, 100, 101, 118, 105, 97, 116, 105, 111,
  110, 44, 32, 111, 114, 100, 101, 114, 44, 32, 97, 120, 105, 115, 32, 97,
  110, 100, 32, 98, 111, 114, 100, 101, 114, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 115, 32, 111, 110,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 98, 111, 117, 110,
  100, 97, 114, 121, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48,
  61, 100, 105, 114, 105, 99, 104, 108, 101, 116, 32, 124, 32, 49, 61, 110,
  101, 117, 109, 97, 110, 110, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  58, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 61, 49, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 45, 100, 101, 114, 105, 99, 104, 101, 32, 51,
  44, 49, 44, 120, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 100, 101, 114, 105,
  99, 104, 101, 32, 51, 48, 44, 48, 44, 120, 32, 45, 100, 101, 114, 105,
  99, 104, 101, 91, 45, 50, 93, 32, 51, 48, 44, 48, 44, 121, 32, 45,
  97, 100, 100, 10, 35, 64, 103, 109, 105, 99, 32, 100, 105, 108, 97, 116,
  101, 32, 58, 32, 115, 105, 122, 101, 62, 61, 48, 32, 58, 32, 115, 105,
  122, 101, 95, 120, 62, 61, 48, 44, 115, 105, 122, 101, 95, 121, 62, 61,
  48, 44, 115, 105, 122, 101, 95, 122, 62, 61, 48, 32, 58, 32, 91, 109,
  97, 115, 107, 93, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121, 44, 95,
  105, 115, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 100, 61, 123, 32,
  48, 32, 124, 32, 49, 32, 125, 32, 58, 32, 40, 43, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 105, 108, 97, 116, 101, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 98, 121,
  32, 97, 32, 114, 101, 99, 116, 97, 110, 103, 117, 108, 97, 114, 32, 111,
  114, 32, 116, 104, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  115, 116, 114, 117, 99, 116, 117, 114, 105, 110, 103, 32, 101, 108, 101, 109,
  101, 110, 116, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 98,
  111, 117, 110, 100, 97, 114, 121, 39, 32, 99, 97, 110, 32, 98, 101, 32,
  123, 32, 48, 61, 100, 105, 114, 105, 99, 104, 108, 101, 116, 32, 124, 32,
  49, 61, 110, 101, 117, 109, 97, 110, 110, 32, 125, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 115, 105, 122, 101, 95, 122, 61, 49, 39,
  44, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 61, 49, 39, 32, 97,
  110, 100, 32, 39, 105, 115, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101,
  100, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 100, 105, 108,
  97, 116, 101, 32, 49, 48, 10, 35, 64, 103, 109, 105, 99, 32, 100, 105,
  108, 97, 116, 101, 95, 99, 105, 114, 99, 32, 58, 32, 95, 115, 105, 122,
  101, 62, 61, 48, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121, 44, 95,
  105, 115, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 100, 61, 123, 32,
  48, 32, 124, 32, 49, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 65, 112, 112, 108, 121, 32, 99, 105, 114, 99, 117, 108, 97, 114, 32,
  100, 105, 108, 97, 116, 105, 111, 110, 32, 111, 102, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 32, 98, 121, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 115, 105, 122, 101, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121,
  61, 49, 39, 32, 97, 110, 100, 32, 39, 105, 115, 95, 110, 111, 114, 109,
  97, 108, 105, 122, 101, 100, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 45, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 32, 55, 10,
  100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 32, 58, 32, 45, 99,
  104, 101, 99, 107, 32, 36, 49, 62, 61, 48, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 50, 61, 49, 125, 44, 36, 123, 51, 61, 48, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 105,
  114, 99, 117, 108, 97, 114, 32, 100, 105, 108, 97, 116, 105, 111, 110, 32,
  111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 32, 98, 121, 32, 115, 105,
  122, 101, 32, 36, 49, 44, 32, 98, 111, 117, 110, 100, 97, 114, 121, 32,
  36, 50, 32, 97, 110, 100, 32, 105, 115, 95, 110, 111, 114, 109, 97, 108,
  105, 122, 101, 100, 32, 36, 51, 46, 34, 10, 45, 105, 102, 32, 123, 36,
  49, 60, 50, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 118, 32, 45, 32, 45, 95, 100, 116, 95, 99, 105,
  114, 99, 108, 101, 91, 93, 32, 36, 49, 32, 45, 100, 105, 108, 97, 116,
  101, 91, 94, 45, 49, 93, 32, 91, 45, 49, 93, 44, 36, 50, 44, 36,
  51, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 100, 105, 108, 97, 116, 101, 95, 111, 99, 116,
  32, 58, 32, 95, 115, 105, 122, 101, 62, 61, 48, 44, 95, 98, 111, 117,
  110, 100, 97, 114, 121, 44, 95, 105, 115, 95, 110, 111, 114, 109, 97, 108,
  105, 122, 101, 100, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 111, 99,
  116, 97, 103, 111, 110, 97, 108, 32, 100, 105, 108, 97, 116, 105, 111, 110,
  32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 32, 98, 121, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  115, 105, 122, 101, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39,
  98, 111, 117, 110, 100, 97, 114, 121, 61, 49, 39, 32, 97, 110, 100, 32,
  39, 105, 115, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 100, 61, 48,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 100, 105, 108, 97, 116, 101,
  95, 111, 99, 116, 32, 55, 10, 100, 105, 108, 97, 116, 101, 95, 111, 99,
  116, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 49, 62, 61, 48,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 49, 125, 44, 36, 123,
  51, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112,
  112, 108, 121, 32, 111, 99, 116, 97, 103, 111, 110, 97, 108, 32, 100, 105,
  108, 97, 116, 105, 111, 110, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36,
  63, 32, 98, 121, 32, 115, 105, 122, 101, 32, 36, 49, 44, 32, 98, 111,
  117, 110, 100, 97, 114, 121, 32, 36, 50, 32, 97, 110, 100, 32, 105, 115,
  95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 100, 32, 36, 51, 46, 34,
  10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 123, 36, 49, 60, 50, 125,
  32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 49, 38, 49, 125, 32, 115, 115, 61, 123, 36,
  49, 125, 32, 45, 101, 108, 115, 101, 32, 115, 115, 61, 123, 36, 49, 43,
  49, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 91, 48, 93, 32,
  40, 48, 44, 49, 44, 48, 59, 49, 44, 49, 44, 49, 59, 48, 44, 49,
  44, 48, 41, 32, 45, 105, 91, 49, 93, 32, 40, 49, 44, 49, 44, 49,
  59, 49, 44, 49, 44, 49, 59, 49, 44, 49, 44, 49, 41, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 50, 125, 10, 114, 61, 123,
  114, 111, 117, 110, 100, 40, 40, 36, 115, 115, 45, 49, 41, 42, 115, 113,
  114, 116, 40, 50, 41, 47, 40, 49, 43, 115, 113, 114, 116, 40, 50, 41,
  41, 47, 50, 41, 125, 10, 113, 61, 123, 114, 111, 117, 110, 100, 40, 40,
  36, 115, 115, 45, 49, 41, 47, 40, 49, 43, 115, 113, 114, 116, 40, 50,
  41, 41, 47, 50, 41, 125, 10, 45, 105, 102, 32, 123, 36, 114, 62, 48,
  125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 114, 32, 45, 100, 105,
  108, 97, 116, 101, 91, 45, 49, 93, 32, 91, 48, 93, 44, 36, 50, 44,
  36, 51, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 113, 62, 48, 125, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 36, 113, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49,
  93, 32, 91, 49, 93, 44, 36, 50, 44, 36, 51, 32, 45, 100, 111, 110,
  101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 109, 118, 91, 45, 49, 93,
  32, 50, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 44, 49,
  93, 32, 45, 118, 32, 43, 10, 95, 107, 114, 95, 99, 105, 114, 99, 108,
  101, 32, 58, 10, 45, 105, 102, 32, 123, 36, 49, 37, 50, 61, 61, 48,
  125, 32, 45, 105, 32, 50, 44, 50, 44, 49, 44, 49, 44, 49, 32, 45,
  101, 108, 115, 101, 32, 45, 105, 32, 49, 44, 49, 44, 49, 44, 49, 44,
  49, 32, 45, 101, 110, 100, 105, 102, 32, 45, 114, 91, 45, 49, 93, 32,
  36, 49, 44, 36, 49, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 10, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91,
  45, 49, 93, 32, 49, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93,
  32, 48, 46, 53, 32, 45, 116, 50, 91, 45, 49, 93, 32, 48, 44, 123,
  36, 49, 47, 50, 125, 10, 95, 106, 102, 95, 99, 105, 114, 99, 108, 101,
  32, 58, 10, 123, 114, 111, 117, 110, 100, 40, 36, 49, 41, 125, 44, 123,
  114, 111, 117, 110, 100, 40, 36, 49, 41, 125, 10, 99, 101, 110, 116, 101,
  114, 61, 123, 48, 46, 53, 42, 40, 119, 45, 49, 41, 125, 10, 45, 102,
  91, 45, 49, 93, 32, 39, 115, 113, 114, 116, 40, 40, 120, 45, 36, 99,
  101, 110, 116, 101, 114, 41, 94, 50, 43, 40, 121, 45, 36, 99, 101, 110,
  116, 101, 114, 41, 94, 50, 41, 39, 10, 45, 105, 102, 32, 123, 33, 40,
  119, 37, 50, 41, 125, 10, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93,
  32, 48, 46, 48, 48, 48, 49, 44, 45, 49, 10, 116, 49, 61, 123, 115,
  113, 114, 116, 40, 40, 40, 114, 111, 117, 110, 100, 40, 36, 49, 41, 45,
  49, 41, 47, 50, 41, 94, 50, 43, 48, 46, 50, 53, 41, 125, 10, 116,
  50, 61, 123, 115, 113, 114, 116, 40, 40, 40, 114, 111, 117, 110, 100, 40,
  36, 49, 41, 43, 49, 41, 47, 50, 41, 94, 50, 43, 48, 46, 50, 53,
  41, 125, 10, 107, 61, 123, 36, 49, 45, 114, 111, 117, 110, 100, 40, 36,
  49, 41, 43, 48, 46, 53, 125, 10, 116, 61, 123, 36, 116, 49, 43, 40,
  36, 116, 50, 45, 36, 116, 49, 41, 42, 36, 107, 125, 10, 45, 116, 50,
  91, 45, 49, 93, 32, 48, 44, 36, 116, 10, 45, 101, 108, 115, 101, 32,
  45, 116, 50, 91, 45, 49, 93, 32, 48, 44, 123, 36, 49, 47, 50, 45,
  48, 46, 50, 53, 125, 10, 45, 101, 110, 100, 105, 102, 10, 95, 100, 116,
  95, 99, 105, 114, 99, 108, 101, 32, 58, 10, 105, 114, 61, 123, 114, 111,
  117, 110, 100, 40, 36, 49, 41, 125, 10, 45, 105, 102, 32, 123, 33, 36,
  105, 114, 125, 32, 49, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  105, 114, 60, 50, 125, 32, 36, 105, 114, 44, 36, 105, 114, 44, 49, 44,
  49, 44, 49, 10, 45, 101, 108, 115, 101, 10, 123, 105, 110, 116, 40, 36,
  105, 114, 47, 50, 41, 43, 40, 36, 105, 114, 37, 50, 41, 125, 44, 123,
  105, 110, 116, 40, 36, 105, 114, 47, 50, 41, 43, 40, 36, 105, 114, 37,
  50, 41, 125, 32, 45, 61, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 10, 45, 100, 105, 115, 116, 97, 110, 99, 101,
  91, 45, 49, 93, 32, 49, 32, 45, 108, 101, 91, 45, 49, 93, 32, 123,
  40, 105, 43, 48, 46, 52, 41, 47, 115, 113, 114, 116, 40, 50, 41, 125,
  10, 45, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 120, 10,
  45, 105, 102, 32, 123, 36, 105, 114, 62, 49, 38, 38, 40, 36, 105, 114,
  37, 50, 41, 125, 32, 45, 114, 91, 45, 49, 93, 32, 123, 119, 45, 49,
  125, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 48, 44, 48, 44, 49,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 91, 45, 50, 44, 45, 49,
  93, 32, 120, 32, 45, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93,
  32, 121, 10, 45, 105, 102, 32, 123, 36, 105, 114, 62, 49, 38, 38, 40,
  36, 105, 114, 37, 50, 41, 125, 32, 45, 114, 91, 45, 49, 93, 32, 49,
  48, 48, 37, 44, 123, 104, 45, 49, 125, 44, 49, 44, 49, 44, 48, 44,
  48, 44, 48, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 91,
  45, 50, 44, 45, 49, 93, 32, 121, 10, 45, 101, 110, 100, 105, 102, 10,
  95, 100, 116, 95, 100, 105, 97, 109, 111, 110, 100, 32, 58, 10, 105, 114,
  61, 123, 114, 111, 117, 110, 100, 40, 36, 49, 41, 125, 10, 45, 105, 102,
  32, 123, 36, 105, 114, 60, 50, 125, 32, 36, 105, 114, 44, 36, 105, 114,
  44, 49, 44, 49, 44, 49, 10, 45, 101, 108, 115, 101, 10, 123, 105, 110,
  116, 40, 36, 105, 114, 47, 50, 41, 43, 40, 36, 105, 114, 37, 50, 41,
  125, 44, 123, 105, 110, 116, 40, 36, 105, 114, 47, 50, 41, 43, 40, 36,
  105, 114, 37, 50, 41, 125, 32, 45, 61, 91, 45, 49, 93, 32, 49, 44,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 10, 45, 100, 105, 115, 116, 97,
  110, 99, 101, 91, 45, 49, 93, 32, 49, 44, 49, 32, 45, 108, 101, 91,
  45, 49, 93, 32, 123, 105, 47, 50, 125, 10, 45, 45, 109, 105, 114, 114,
  111, 114, 91, 45, 49, 93, 32, 120, 10, 45, 105, 102, 32, 123, 36, 105,
  114, 62, 49, 38, 38, 40, 36, 105, 114, 37, 50, 41, 125, 32, 45, 114,
  91, 45, 49, 93, 32, 123, 119, 45, 49, 125, 44, 49, 48, 48, 37, 44,
  49, 44, 49, 44, 48, 44, 48, 44, 49, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 45, 109,
  105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 121, 10, 45, 105, 102, 32,
  123, 36, 105, 114, 62, 49, 38, 38, 40, 36, 105, 114, 37, 50, 41, 125,
  32, 45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 123, 104, 45,
  49, 125, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 44, 49, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32,
  121, 10, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103, 109, 105, 99, 32,
  100, 105, 118, 101, 114, 103, 101, 110, 99, 101, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 100, 105, 118, 101,
  114, 103, 101, 110, 99, 101, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 118, 101, 99, 116, 111, 114, 32, 102, 105, 101, 108, 100, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 108, 117, 109, 105, 110, 97, 110, 99,
  101, 32, 45, 45, 103, 114, 97, 100, 105, 101, 110, 116, 32, 45, 97, 112,
  112, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 100,
  105, 118, 101, 114, 103, 101, 110, 99, 101, 91, 45, 49, 93, 10, 100, 105,
  118, 101, 114, 103, 101, 110, 99, 101, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 100, 105, 118, 101,
  114, 103, 101, 110, 99, 101, 32, 111, 102, 32, 118, 101, 99, 116, 111, 114,
  32, 102, 105, 101, 108, 100, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 105, 102, 32, 123, 115, 61, 61, 49, 125, 32, 45, 103, 32,
  120, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 115, 61, 61, 50, 125,
  32, 45, 115, 32, 99, 32, 45, 103, 91, 45, 50, 93, 32, 120, 44, 48,
  32, 45, 103, 91, 45, 49, 93, 32, 121, 44, 48, 32, 45, 43, 10, 45,
  101, 108, 105, 102, 32, 123, 115, 61, 61, 51, 125, 32, 45, 115, 32, 99,
  32, 45, 103, 91, 45, 51, 93, 32, 120, 44, 48, 32, 45, 103, 91, 45,
  50, 93, 32, 121, 44, 48, 32, 45, 103, 91, 45, 49, 93, 32, 122, 44,
  48, 32, 45, 43, 10, 45, 101, 108, 115, 101, 32, 45, 101, 114, 114, 111,
  114, 91, 93, 32, 34, 67, 97, 110, 110, 111, 116, 32, 99, 111, 109, 112,
  117, 116, 101, 32, 100, 105, 118, 101, 114, 103, 101, 110, 99, 101, 32, 111,
  102, 32, 105, 109, 97, 103, 101, 32, 91, 34, 36, 62, 34, 93, 32, 40,
  104, 97, 115, 32, 34, 123, 115, 125, 34, 62, 51, 32, 99, 104, 97, 110,
  110, 101, 108, 115, 41, 46, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 100, 111, 103, 32, 58, 32, 95, 115, 105,
  103, 109, 97, 49, 62, 61, 48, 91, 37, 93, 44, 95, 115, 105, 103, 109,
  97, 50, 62, 61, 48, 91, 37, 93, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 100, 105, 102, 102, 101, 114,
  101, 110, 99, 101, 32, 111, 102, 32, 103, 97, 117, 115, 115, 105, 97, 110,
  32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101,
  102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 115,
  105, 103, 109, 97, 49, 61, 50, 37, 39, 32, 97, 110, 100, 32, 39, 115,
  105, 103, 109, 97, 50, 61, 51, 37, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 45, 100, 111, 103, 32, 50, 44, 51, 10, 100, 111, 103, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 50, 37, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 51, 37, 125, 62, 61, 48,
  34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117,
  116, 101, 32, 100, 105, 102, 102, 101, 114, 101, 110, 99, 101, 32, 111, 102,
  32, 103, 97, 117, 115, 115, 105, 97, 110, 32, 111, 110, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 115, 116, 97, 110, 100,
  97, 114, 100, 32, 100, 101, 118, 105, 97, 116, 105, 111, 110, 115, 32, 36,
  49, 32, 97, 110, 100, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 91, 48, 93, 32, 45, 112, 97, 114, 97, 108, 108, 101, 108, 32,
  34, 45, 98, 91, 48, 93, 32, 36, 49, 34, 44, 34, 45, 98, 91, 49,
  93, 32, 36, 50, 34, 32, 45, 45, 32, 45, 110, 111, 114, 109, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 100, 105, 102, 102, 117, 115, 105, 111, 110,
  116, 101, 110, 115, 111, 114, 115, 32, 58, 32, 95, 115, 104, 97, 114, 112,
  110, 101, 115, 115, 62, 61, 48, 44, 48, 60, 61, 95, 97, 110, 105, 115,
  111, 116, 114, 111, 112, 121, 60, 61, 49, 44, 95, 97, 108, 112, 104, 97,
  91, 37, 93, 44, 95, 115, 105, 103, 109, 97, 91, 37, 93, 44, 105, 115,
  95, 115, 113, 114, 116, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101,
  32, 116, 104, 101, 32, 100, 105, 102, 102, 117, 115, 105, 111, 110, 32, 116,
  101, 110, 115, 111, 114, 115, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 102, 111, 114, 32, 101, 100,
  103, 101, 45, 112, 114, 101, 115, 101, 114, 118, 105, 110, 103, 32, 115, 109,
  111, 111, 116, 104, 105, 110, 103, 32, 97, 108, 103, 111, 114, 105, 116, 104,
  109, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 115, 104,
  97, 114, 112, 110, 101, 115, 115, 61, 48, 46, 55, 39, 44, 32, 39, 97,
  110, 105, 115, 111, 116, 114, 111, 112, 121, 61, 48, 46, 51, 39, 44, 32,
  39, 97, 108, 112, 104, 97, 61, 48, 46, 54, 39, 44, 32, 39, 115, 105,
  103, 109, 97, 61, 49, 46, 49, 39, 32, 97, 110, 100, 32, 39, 105, 115,
  95, 115, 113, 114, 116, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  100, 105, 102, 102, 117, 115, 105, 111, 110, 116, 101, 110, 115, 111, 114, 115,
  32, 48, 46, 56, 32, 45, 97, 98, 115, 32, 45, 112, 111, 119, 32, 48,
  46, 50, 10, 100, 105, 102, 102, 117, 115, 105, 111, 110, 116, 101, 110, 115,
  111, 114, 115, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123,
  49, 61, 48, 46, 55, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50,
  61, 48, 46, 51, 125, 62, 61, 48, 32, 38, 38, 32, 36, 50, 60, 61,
  49, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 48, 46, 54,
  125, 44, 36, 123, 52, 61, 49, 46, 49, 125, 44, 36, 123, 53, 61, 48,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117,
  116, 101, 32, 100, 105, 102, 102, 117, 115, 105, 111, 110, 32, 116, 101, 110,
  115, 111, 114, 115, 32, 102, 111, 114, 32, 105, 109, 97, 103, 101, 36, 63,
  44, 32, 119, 105, 116, 104, 32, 115, 104, 97, 114, 112, 110, 101, 115, 115,
  32, 36, 49, 44, 32, 97, 110, 105, 115, 111, 116, 114, 111, 112, 121, 32,
  36, 50, 44, 32, 97, 108, 112, 104, 97, 32, 36, 51, 32, 97, 110, 100,
  32, 115, 105, 103, 109, 97, 32, 36, 52, 46, 34, 10, 45, 118, 32, 45,
  10, 112, 49, 61, 123, 105, 102, 40, 36, 53, 44, 48, 46, 53, 44, 49,
  41, 42, 109, 97, 120, 40, 36, 49, 44, 49, 101, 45, 53, 41, 125, 10,
  112, 50, 61, 123, 36, 112, 49, 47, 40, 49, 101, 45, 55, 43, 49, 45,
  36, 50, 41, 125, 10, 45, 98, 32, 36, 51, 32, 45, 110, 32, 48, 44,
  50, 53, 53, 32, 45, 115, 116, 114, 117, 99, 116, 117, 114, 101, 116, 101,
  110, 115, 111, 114, 115, 32, 50, 32, 45, 98, 32, 36, 52, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  45, 101, 105, 103, 101, 110, 32, 45, 109, 97, 120, 91, 45, 50, 93, 32,
  48, 10, 45, 105, 102, 32, 123, 115, 61, 61, 50, 125, 32, 45, 115, 91,
  45, 50, 93, 32, 99, 32, 45, 43, 91, 45, 51, 44, 45, 50, 93, 32,
  45, 43, 91, 45, 50, 93, 32, 49, 32, 45, 45, 94, 91, 45, 50, 93,
  32, 45, 36, 112, 49, 32, 45, 94, 91, 45, 51, 93, 32, 45, 36, 112,
  50, 32, 45, 97, 91, 45, 51, 44, 45, 49, 93, 32, 99, 10, 45, 101,
  108, 115, 101, 32, 45, 115, 91, 45, 50, 93, 32, 99, 32, 45, 43, 91,
  45, 52, 45, 45, 50, 93, 32, 45, 43, 91, 45, 50, 93, 32, 49, 32,
  45, 45, 94, 91, 45, 50, 93, 32, 45, 36, 112, 49, 32, 45, 114, 91,
  45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 50, 32, 45, 94, 91, 45, 51, 93, 32, 45, 36, 112, 50,
  32, 45, 97, 91, 45, 51, 44, 45, 49, 93, 32, 99, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 105, 103, 101, 110, 50, 116, 101, 110, 115, 111,
  114, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 101, 100, 103, 101, 115, 32,
  58, 32, 95, 116, 104, 114, 101, 115, 104, 111, 108, 100, 91, 37, 93, 62,
  61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 69, 115, 116, 105,
  109, 97, 116, 101, 32, 99, 111, 110, 116, 111, 117, 114, 115, 32, 111, 102,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117,
  108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 101, 100, 103, 101, 115,
  61, 49, 53, 37, 39, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 101, 100, 103,
  101, 115, 32, 49, 53, 37, 10, 101, 100, 103, 101, 115, 32, 58, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 53, 37, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 69, 115, 116, 105, 109, 97, 116, 101, 32,
  105, 109, 97, 103, 101, 32, 99, 111, 110, 116, 111, 117, 114, 115, 32, 111,
  102, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 36, 49, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111,
  114, 109, 32, 45, 98, 32, 48, 46, 53, 32, 45, 103, 101, 32, 36, 49,
  32, 45, 100, 105, 115, 116, 97, 110, 99, 101, 32, 48, 32, 45, 101, 113,
  117, 97, 108, 105, 122, 101, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101,
  32, 45, 99, 32, 51, 48, 37, 44, 55, 48, 37, 32, 45, 110, 32, 48,
  44, 49, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 101,
  114, 111, 100, 101, 32, 58, 32, 115, 105, 122, 101, 62, 61, 48, 32, 58,
  32, 115, 105, 122, 101, 95, 120, 62, 61, 48, 44, 115, 105, 122, 101, 95,
  121, 62, 61, 48, 44, 95, 115, 105, 122, 101, 95, 122, 62, 61, 48, 32,
  58, 32, 91, 109, 97, 115, 107, 93, 44, 95, 98, 111, 117, 110, 100, 97,
  114, 121, 44, 95, 105, 115, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101,
  100, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 32, 58, 32, 40, 43,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 69, 114, 111, 100, 101,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  32, 98, 121, 32, 97, 32, 114, 101, 99, 116, 97, 110, 103, 117, 108, 97,
  114, 32, 111, 114, 32, 116, 104, 101, 32, 115, 112, 101, 99, 105, 102, 105,
  101, 100, 32, 115, 116, 114, 117, 99, 116, 117, 114, 105, 110, 103, 32, 101,
  108, 101, 109, 101, 110, 116, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 98, 111, 117, 110, 100, 97, 114, 121, 39, 32, 99, 97, 110, 32, 98,
  101, 32, 123, 32, 48, 61, 100, 105, 114, 105, 99, 104, 108, 101, 116, 32,
  124, 32, 49, 61, 110, 101, 117, 109, 97, 110, 110, 32, 125, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32,
  118, 97, 108, 117, 101, 115, 58, 32, 39, 115, 105, 122, 101, 95, 122, 61,
  49, 39, 44, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 61, 49, 39,
  32, 97, 110, 100, 32, 39, 105, 115, 95, 110, 111, 114, 109, 97, 108, 105,
  122, 101, 100, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 101,
  114, 111, 100, 101, 32, 49, 48, 10, 35, 64, 103, 109, 105, 99, 32, 101,
  114, 111, 100, 101, 95, 99, 105, 114, 99, 32, 58, 32, 95, 115, 105, 122,
  101, 62, 61, 48, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121, 44, 95,
  105, 115, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 100, 61, 123, 32,
  48, 32, 124, 32, 49, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 65, 112, 112, 108, 121, 32, 99, 105, 114, 99, 117, 108, 97, 114, 32,
  101, 114, 111, 115, 105, 111, 110, 32, 111, 102, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 98, 121, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 115, 105, 122, 101, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121,
  61, 49, 39, 32, 97, 110, 100, 32, 39, 105, 115, 95, 110, 111, 114, 109,
  97, 108, 105, 122, 101, 100, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 45, 101, 114, 111, 100, 101, 95, 99, 105, 114, 99, 32, 55, 10, 101,
  114, 111, 100, 101, 95, 99, 105, 114, 99, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 36, 49, 62, 61, 48, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 50, 61, 49, 125, 44, 36, 123, 51, 61, 48, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 105, 114, 99,
  117, 108, 97, 114, 32, 101, 114, 111, 115, 105, 111, 110, 32, 111, 102, 32,
  105, 109, 97, 103, 101, 36, 63, 32, 98, 121, 32, 115, 105, 122, 101, 32,
  36, 49, 44, 32, 98, 111, 117, 110, 100, 97, 114, 121, 32, 36, 50, 32,
  97, 110, 100, 32, 105, 115, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101,
  100, 32, 36, 51, 46, 34, 10, 45, 105, 102, 32, 123, 36, 49, 60, 50,
  125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 118, 32, 45, 32, 45, 95, 100, 116, 95, 99, 105, 114, 99, 108,
  101, 91, 93, 32, 36, 49, 32, 45, 101, 114, 111, 100, 101, 91, 94, 45,
  49, 93, 32, 91, 45, 49, 93, 44, 36, 50, 44, 36, 51, 32, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 101, 114, 111, 100, 101, 95, 111, 99, 116, 32, 58, 32, 95, 115,
  105, 122, 101, 62, 61, 48, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121,
  44, 95, 105, 115, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 100, 61,
  123, 32, 48, 32, 124, 32, 49, 32, 125, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 65, 112, 112, 108, 121, 32, 111, 99, 116, 97, 103, 111, 110,
  97, 108, 32, 101, 114, 111, 115, 105, 111, 110, 32, 111, 102, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 98, 121,
  32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 115, 105, 122, 101, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108,
  116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 98, 111, 117, 110, 100,
  97, 114, 121, 61, 49, 39, 32, 97, 110, 100, 32, 39, 105, 115, 95, 110,
  111, 114, 109, 97, 108, 105, 122, 101, 100, 61, 48, 39, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 45, 101, 114, 111, 100, 101, 95, 111, 99, 116, 32, 55,
  10, 101, 114, 111, 100, 101, 95, 111, 99, 116, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 36, 49, 62, 61, 48, 32, 45, 115, 107, 105, 112, 32,
  36, 123, 50, 61, 49, 125, 44, 36, 123, 51, 61, 48, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 111, 99, 116,
  97, 103, 111, 110, 97, 108, 32, 101, 114, 111, 115, 105, 111, 110, 32, 111,
  102, 32, 105, 109, 97, 103, 101, 36, 63, 32, 98, 121, 32, 115, 105, 122,
  101, 32, 36, 49, 44, 32, 98, 111, 117, 110, 100, 97, 114, 121, 32, 36,
  50, 32, 97, 110, 100, 32, 105, 115, 95, 110, 111, 114, 109, 97, 108, 105,
  122, 101, 100, 32, 36, 51, 46, 34, 10, 45, 118, 32, 45, 10, 45, 105,
  102, 32, 123, 36, 49, 60, 50, 125, 32, 45, 114, 101, 116, 117, 114, 110,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 38,
  49, 125, 32, 115, 115, 61, 123, 36, 49, 125, 32, 45, 101, 108, 115, 101,
  32, 115, 115, 61, 123, 36, 49, 43, 49, 125, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 91, 48, 93, 32, 40, 48, 44, 49, 44, 48, 59, 49,
  44, 49, 44, 49, 59, 48, 44, 49, 44, 48, 41, 32, 45, 105, 91, 49,
  93, 32, 40, 49, 44, 49, 44, 49, 59, 49, 44, 49, 44, 49, 59, 49,
  44, 49, 44, 49, 41, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64,
  35, 45, 50, 125, 10, 114, 61, 123, 114, 111, 117, 110, 100, 40, 40, 36,
  115, 115, 45, 49, 41, 42, 115, 113, 114, 116, 40, 50, 41, 47, 40, 49,
  43, 115, 113, 114, 116, 40, 50, 41, 41, 47, 50, 41, 125, 10, 113, 61,
  123, 114, 111, 117, 110, 100, 40, 40, 36, 115, 115, 45, 49, 41, 47, 40,
  49, 43, 115, 113, 114, 116, 40, 50, 41, 41, 47, 50, 41, 125, 10, 45,
  105, 102, 32, 123, 36, 114, 62, 48, 125, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 36, 114, 32, 45, 101, 114, 111, 100, 101, 91, 45, 49, 93, 32,
  91, 48, 93, 44, 36, 50, 44, 36, 51, 32, 45, 100, 111, 110, 101, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 113, 62, 48,
  125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 113, 32, 45, 101, 114,
  111, 100, 101, 91, 45, 49, 93, 32, 91, 49, 93, 44, 36, 50, 44, 36,
  51, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  109, 118, 91, 45, 49, 93, 32, 50, 32, 45, 100, 111, 110, 101, 32, 45,
  114, 109, 91, 48, 44, 49, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 102, 102, 116, 32, 58, 32, 40, 43, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116,
  104, 101, 32, 100, 105, 114, 101, 99, 116, 32, 102, 111, 117, 114, 105, 101,
  114, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32, 40, 114, 101, 97,
  108, 32, 97, 110, 100, 32, 105, 109, 97, 103, 105, 110, 97, 114, 121, 32,
  112, 97, 114, 116, 115, 41, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 45, 102, 102, 116,
  32, 45, 97, 112, 112, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32,
  99, 32, 45, 110, 111, 114, 109, 91, 45, 49, 93, 32, 45, 108, 111, 103,
  91, 45, 49, 93, 32, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32,
  53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 48, 44, 50, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 102, 102, 116, 32, 45, 115, 104, 105, 102, 116, 32, 53,
  48, 37, 44, 53, 48, 37, 44, 48, 44, 48, 44, 50, 32, 45, 101, 108,
  108, 105, 112, 115, 101, 32, 53, 48, 37, 44, 53, 48, 37, 44, 51, 48,
  44, 51, 48, 44, 48, 44, 49, 44, 48, 32, 45, 115, 104, 105, 102, 116,
  32, 45, 53, 48, 37, 44, 45, 53, 48, 37, 44, 48, 44, 48, 44, 50,
  32, 45, 105, 102, 102, 116, 32, 45, 114, 101, 109, 111, 118, 101, 91, 45,
  49, 93, 10, 35, 64, 103, 109, 105, 99, 32, 103, 32, 58, 32, 101, 113,
  46, 32, 116, 111, 32, 39, 45, 103, 114, 97, 100, 105, 101, 110, 116, 39,
  46, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 103,
  114, 97, 100, 105, 101, 110, 116, 32, 58, 32, 123, 32, 120, 32, 124, 32,
  121, 32, 124, 32, 122, 32, 125, 46, 46, 123, 32, 120, 32, 124, 32, 121,
  32, 124, 32, 122, 32, 125, 44, 95, 115, 99, 104, 101, 109, 101, 32, 58,
  32, 40, 110, 111, 32, 97, 114, 103, 115, 41, 32, 58, 32, 40, 43, 41,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116,
  101, 32, 116, 104, 101, 32, 103, 114, 97, 100, 105, 101, 110, 116, 32, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 115, 32, 40, 102, 105, 114, 115, 116,
  32, 100, 101, 114, 105, 118, 97, 116, 105, 118, 101, 115, 41, 32, 111, 102,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32,
  116, 111, 32, 39, 45, 103, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 39, 115, 99, 104, 101, 109, 101, 39, 32, 99, 97, 110, 32,
  98, 101, 32, 123, 32, 45, 49, 61, 98, 97, 99, 107, 119, 97, 114, 100,
  32, 124, 32, 48, 61, 99, 101, 110, 116, 101, 114, 101, 100, 32, 124, 32,
  49, 61, 102, 111, 114, 119, 97, 114, 100, 32, 124, 32, 50, 61, 115, 111,
  98, 101, 108, 32, 124, 32, 51, 61, 114, 111, 116, 97, 116, 105, 111, 110,
  45, 105, 110, 118, 97, 114, 105, 97, 110, 116, 32, 40, 100, 101, 102, 97,
  117, 108, 116, 41, 32, 124, 32, 52, 61, 100, 101, 114, 105, 99, 104, 101,
  32, 124, 32, 53, 61, 118, 97, 110, 118, 108, 105, 101, 116, 32, 125, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 110, 111, 32, 97, 114,
  103, 115, 41, 32, 99, 111, 109, 112, 117, 116, 101, 32, 97, 108, 108, 32,
  115, 105, 103, 110, 105, 102, 105, 99, 97, 110, 116, 32, 50, 100, 47, 51,
  100, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 58, 32, 39, 115, 99, 104, 101, 109, 101, 61, 51, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 103, 114, 97, 100, 105, 101, 110, 116,
  10, 35, 64, 103, 109, 105, 99, 32, 103, 114, 97, 100, 105, 101, 110, 116,
  95, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 32, 58, 32, 95,
  100, 105, 109, 101, 110, 115, 105, 111, 110, 61, 123, 49, 44, 50, 44, 51,
  125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117,
  116, 101, 32, 78, 45, 100, 32, 103, 114, 97, 100, 105, 101, 110, 116, 32,
  111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 32, 111, 102, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116,
  32, 118, 97, 108, 117, 101, 58, 32, 39, 100, 105, 109, 101, 110, 115, 105,
  111, 110, 61, 51, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 103, 114,
  97, 100, 105, 101, 110, 116, 95, 111, 114, 105, 101, 110, 116, 97, 116, 105,
  111, 110, 32, 50, 10, 103, 114, 97, 100, 105, 101, 110, 116, 95, 111, 114,
  105, 101, 110, 116, 97, 116, 105, 111, 110, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 36, 123, 49, 61, 51, 125, 61, 61, 49, 32, 124, 124,
  32, 36, 49, 61, 61, 50, 32, 124, 124, 32, 36, 49, 61, 61, 51, 34,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116,
  101, 32, 36, 49, 45, 100, 32, 103, 114, 97, 100, 105, 101, 110, 116, 32,
  111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 32, 111, 102, 32, 105,
  109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 60, 93, 10,
  45, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 32, 45, 103, 32, 120,
  32, 45, 45, 97, 98, 115, 91, 45, 49, 93, 32, 45, 43, 91, 45, 49,
  93, 32, 49, 101, 45, 56, 32, 45, 47, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 49, 61, 61, 50, 125, 32, 45, 103, 32, 120, 121, 32, 45, 45,
  115, 113, 114, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 43,
  91, 45, 49, 93, 32, 49, 101, 45, 56, 32, 45, 115, 113, 114, 116, 91,
  45, 49, 93, 32, 45, 47, 91, 45, 51, 93, 32, 91, 45, 49, 93, 32,
  45, 47, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 108, 115, 101, 32,
  45, 103, 32, 120, 121, 122, 32, 45, 45, 115, 113, 114, 32, 45, 43, 91,
  45, 51, 45, 45, 49, 93, 32, 45, 43, 91, 45, 49, 93, 32, 49, 101,
  45, 56, 32, 45, 115, 113, 114, 116, 91, 45, 49, 93, 32, 45, 47, 91,
  45, 52, 44, 45, 51, 93, 32, 91, 45, 49, 93, 32, 45, 47, 91, 45,
  50, 44, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111,
  114, 109, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112,
  117, 116, 101, 32, 103, 114, 97, 100, 105, 101, 110, 116, 32, 110, 111, 114,
  109, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 103, 114, 97,
  100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 32, 45, 101, 113, 117, 97,
  108, 105, 122, 101, 91, 45, 49, 93, 10, 103, 114, 97, 100, 105, 101, 110,
  116, 95, 110, 111, 114, 109, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 103, 114, 97, 100, 105, 101,
  110, 116, 32, 110, 111, 114, 109, 32, 111, 102, 32, 105, 109, 97, 103, 101,
  36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 103, 32,
  120, 32, 45, 115, 113, 114, 91, 45, 49, 93, 10, 45, 45, 103, 91, 45,
  50, 93, 32, 121, 32, 45, 115, 113, 114, 91, 45, 49, 93, 32, 45, 43,
  91, 45, 50, 44, 45, 49, 93, 10, 45, 103, 91, 45, 50, 93, 32, 122,
  32, 45, 115, 113, 114, 91, 45, 50, 93, 32, 45, 43, 91, 45, 50, 44,
  45, 49, 93, 10, 115, 61, 123, 115, 125, 32, 45, 115, 91, 45, 49, 93,
  32, 99, 32, 45, 43, 91, 45, 36, 115, 45, 45, 49, 93, 32, 45, 115,
  113, 114, 116, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  104, 97, 97, 114, 32, 58, 32, 115, 99, 97, 108, 101, 62, 48, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32,
  116, 104, 101, 32, 100, 105, 114, 101, 99, 116, 32, 104, 97, 97, 114, 32,
  109, 117, 108, 116, 105, 115, 99, 97, 108, 101, 32, 119, 97, 118, 101, 108,
  101, 116, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32, 111, 102, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 104, 97, 97, 114, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 49, 125, 41, 32, 38, 38,
  32, 36, 49, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 67, 111, 109, 112, 117, 116, 101, 32, 104, 97, 97, 114, 32, 116, 114,
  97, 110, 115, 102, 111, 114, 109, 32, 111, 102, 32, 105, 109, 97, 103, 101,
  36, 63, 32, 119, 105, 116, 104, 32, 36, 49, 32, 115, 99, 97, 108, 101,
  115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 95, 104, 97, 97,
  114, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 49, 45, 49, 125,
  10, 119, 61, 123, 109, 97, 120, 40, 48, 44, 114, 111, 117, 110, 100, 40,
  119, 47, 50, 94, 40, 49, 43, 36, 62, 41, 41, 45, 49, 41, 125, 10,
  104, 61, 123, 109, 97, 120, 40, 48, 44, 114, 111, 117, 110, 100, 40, 104,
  47, 50, 94, 40, 49, 43, 36, 62, 41, 41, 45, 49, 41, 125, 10, 100,
  61, 123, 109, 97, 120, 40, 48, 44, 114, 111, 117, 110, 100, 40, 100, 47,
  50, 94, 40, 49, 43, 36, 62, 41, 41, 45, 49, 41, 125, 10, 45, 45,
  122, 32, 48, 44, 48, 44, 48, 44, 36, 119, 44, 36, 104, 44, 36, 100,
  32, 45, 95, 104, 97, 97, 114, 91, 45, 49, 93, 32, 45, 106, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 95, 104, 97, 97, 114, 32, 58, 10, 45,
  95, 104, 97, 97, 114, 95, 120, 32, 45, 95, 104, 97, 97, 114, 95, 121,
  32, 45, 95, 104, 97, 97, 114, 95, 122, 10, 95, 104, 97, 97, 114, 95,
  120, 32, 58, 10, 45, 105, 102, 32, 123, 119, 60, 61, 49, 125, 32, 45,
  114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 119, 37, 50, 125, 32, 45, 101, 114, 114, 111, 114, 91, 48,
  45, 45, 54, 93, 32, 34, 73, 110, 118, 97, 108, 105, 100, 32, 105, 109,
  97, 103, 101, 32, 119, 105, 100, 116, 104, 61, 34, 123, 119, 125, 34, 32,
  40, 105, 115, 32, 110, 111, 116, 32, 101, 118, 101, 110, 41, 46, 34, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 45, 115, 104, 105, 102, 116, 32, 45,
  49, 32, 45, 114, 32, 53, 48, 37, 32, 45, 45, 45, 91, 49, 93, 32,
  91, 48, 93, 32, 45, 43, 91, 48, 44, 49, 93, 32, 45, 47, 32, 123,
  115, 113, 114, 116, 40, 50, 41, 125, 32, 45, 97, 32, 120, 10, 95, 104,
  97, 97, 114, 95, 121, 32, 58, 10, 45, 105, 102, 32, 123, 104, 60, 61,
  49, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 104, 37, 50, 125, 32, 45, 101, 114, 114,
  111, 114, 91, 48, 45, 45, 54, 93, 32, 34, 73, 110, 118, 97, 108, 105,
  100, 32, 105, 109, 97, 103, 101, 32, 104, 101, 105, 103, 104, 116, 61, 34,
  123, 104, 125, 34, 32, 40, 105, 115, 32, 110, 111, 116, 32, 101, 118, 101,
  110, 41, 46, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 115, 104,
  105, 102, 116, 32, 48, 44, 45, 49, 32, 45, 114, 32, 49, 48, 48, 37,
  44, 53, 48, 37, 32, 45, 45, 45, 91, 49, 93, 32, 91, 48, 93, 32,
  45, 43, 91, 48, 44, 49, 93, 32, 45, 47, 32, 123, 115, 113, 114, 116,
  40, 50, 41, 125, 32, 45, 97, 32, 121, 10, 95, 104, 97, 97, 114, 95,
  122, 32, 58, 10, 45, 105, 102, 32, 123, 100, 60, 61, 49, 125, 32, 45,
  114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 100, 37, 50, 125, 32, 45, 101, 114, 114, 111, 114, 91, 48,
  45, 45, 54, 93, 32, 34, 73, 110, 118, 97, 108, 105, 100, 32, 105, 109,
  97, 103, 101, 32, 100, 101, 112, 116, 104, 61, 34, 123, 104, 125, 34, 32,
  40, 105, 115, 32, 110, 111, 116, 32, 101, 118, 101, 110, 41, 46, 34, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 45, 115, 104, 105, 102, 116, 32, 48,
  44, 48, 44, 45, 49, 32, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 53, 48, 37, 32, 45, 45, 45, 91, 49, 93, 32, 91, 48,
  93, 32, 45, 43, 91, 48, 44, 49, 93, 32, 45, 47, 32, 123, 115, 113,
  114, 116, 40, 50, 41, 125, 32, 45, 97, 32, 122, 10, 35, 64, 103, 109,
  105, 99, 32, 104, 101, 97, 116, 95, 102, 108, 111, 119, 32, 58, 32, 95,
  110, 98, 95, 105, 116, 101, 114, 62, 61, 48, 44, 95, 100, 116, 44, 95,
  107, 101, 101, 112, 95, 115, 101, 113, 117, 101, 110, 99, 101, 61, 123, 32,
  48, 32, 124, 32, 49, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 65, 112, 112, 108, 121, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110,
  115, 32, 111, 102, 32, 116, 104, 101, 32, 104, 101, 97, 116, 32, 102, 108,
  111, 119, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 110, 98, 95, 105, 116, 101, 114, 61, 49, 48, 39, 44, 32, 39, 100,
  116, 61, 51, 48, 39, 32, 97, 110, 100, 32, 39, 107, 101, 101, 112, 95,
  115, 101, 113, 117, 101, 110, 99, 101, 61, 48, 39, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 45, 104, 101, 97, 116, 95, 102, 108, 111, 119, 32, 50, 48,
  10, 104, 101, 97, 116, 95, 102, 108, 111, 119, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 49, 61, 49, 48, 125, 44, 36, 123, 50, 61, 51,
  48, 125, 44, 36, 123, 51, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 65, 112, 112, 108, 121, 32, 36, 49, 32, 105, 116, 101, 114,
  97, 116, 105, 111, 110, 115, 32, 111, 102, 32, 116, 104, 101, 32, 104, 101,
  97, 116, 32, 102, 108, 111, 119, 32, 111, 110, 32, 105, 109, 97, 103, 101,
  36, 63, 44, 32, 119, 105, 116, 104, 32, 116, 105, 109, 101, 32, 115, 116,
  101, 112, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 45, 112, 100,
  101, 95, 102, 108, 111, 119, 32, 36, 49, 44, 36, 50, 44, 108, 97, 112,
  108, 97, 99, 105, 97, 110, 44, 36, 51, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 104, 101, 115, 115, 105, 97, 110, 32, 58, 32,
  123, 32, 120, 120, 32, 124, 32, 120, 121, 32, 124, 32, 120, 122, 32, 124,
  32, 121, 121, 32, 124, 32, 121, 122, 32, 124, 32, 122, 122, 32, 125, 46,
  46, 123, 32, 120, 120, 32, 124, 32, 120, 121, 32, 124, 32, 120, 122, 32,
  124, 32, 121, 121, 32, 124, 32, 121, 122, 32, 124, 32, 122, 122, 32, 125,
  32, 58, 32, 40, 110, 111, 32, 97, 114, 103, 115, 41, 32, 58, 32, 40,
  43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112,
  117, 116, 101, 32, 116, 104, 101, 32, 104, 101, 115, 115, 105, 97, 110, 32,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 32, 40, 115, 101, 99, 111,
  110, 100, 32, 100, 101, 114, 105, 118, 97, 116, 105, 118, 101, 115, 41, 32,
  111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 110, 111,
  32, 97, 114, 103, 115, 41, 32, 99, 111, 109, 112, 117, 116, 101, 32, 97,
  108, 108, 32, 115, 105, 103, 110, 105, 102, 105, 99, 97, 110, 116, 32, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 104, 101, 115, 115, 105, 97, 110, 10, 35, 64, 103, 109, 105, 99, 32,
  105, 101, 101, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109,
  112, 117, 116, 101, 32, 103, 114, 97, 100, 105, 101, 110, 116, 45, 111, 114,
  116, 104, 111, 103, 111, 110, 97, 108, 45, 100, 105, 114, 101, 99, 116, 101,
  100, 32, 50, 110, 100, 32, 100, 101, 114, 105, 118, 97, 116, 105, 118, 101,
  32, 111, 102, 32, 105, 109, 97, 103, 101, 40, 115, 41, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 105, 101, 101, 10, 105, 101, 101, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 103,
  114, 97, 100, 105, 101, 110, 116, 45, 111, 114, 116, 104, 111, 103, 111, 110,
  97, 108, 45, 100, 105, 114, 101, 99, 116, 101, 100, 32, 50, 110, 100, 32,
  100, 101, 114, 105, 118, 97, 116, 105, 118, 101, 32, 111, 102, 32, 105, 109,
  97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45,
  105, 102, 32, 123, 100, 61, 61, 49, 125, 10, 45, 45, 103, 32, 120, 121,
  44, 48, 32, 45, 104, 101, 115, 115, 105, 97, 110, 91, 45, 51, 93, 32,
  120, 120, 120, 121, 121, 121, 10, 45, 42, 91, 45, 51, 93, 32, 91, 45,
  50, 93, 32, 45, 42, 91, 45, 52, 93, 32, 91, 45, 49, 93, 32, 45,
  42, 91, 45, 52, 93, 32, 45, 50, 10, 45, 43, 91, 45, 52, 44, 45,
  51, 93, 32, 45, 42, 91, 45, 51, 93, 32, 91, 45, 50, 93, 10, 45,
  115, 113, 114, 91, 45, 50, 44, 45, 49, 93, 32, 45, 42, 91, 45, 52,
  93, 32, 91, 45, 49, 93, 32, 45, 43, 91, 45, 52, 44, 45, 51, 93,
  10, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 43, 91, 45, 49,
  93, 32, 49, 101, 45, 56, 32, 45, 47, 10, 45, 101, 108, 115, 101, 10,
  45, 45, 105, 110, 110, 32, 45, 108, 97, 112, 108, 97, 99, 105, 97, 110,
  91, 45, 50, 93, 32, 45, 45, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 105, 102, 102, 116, 32, 58, 32, 40, 43,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117,
  116, 101, 32, 116, 104, 101, 32, 105, 110, 118, 101, 114, 115, 101, 32, 102,
  111, 117, 114, 105, 101, 114, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109,
  32, 40, 114, 101, 97, 108, 32, 97, 110, 100, 32, 105, 109, 97, 103, 105,
  110, 97, 114, 121, 32, 112, 97, 114, 116, 115, 41, 32, 111, 102, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 105, 104, 97, 97, 114, 32, 58, 32, 115,
  99, 97, 108, 101, 62, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 105, 110, 118, 101,
  114, 115, 101, 32, 104, 97, 97, 114, 32, 109, 117, 108, 116, 105, 115, 99,
  97, 108, 101, 32, 119, 97, 118, 101, 108, 101, 116, 32, 116, 114, 97, 110,
  115, 102, 111, 114, 109, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 105, 104, 97, 97, 114, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110, 116, 40,
  36, 123, 49, 61, 49, 125, 41, 32, 38, 38, 32, 36, 49, 62, 61, 48,
  34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117,
  116, 101, 32, 105, 110, 118, 101, 114, 115, 101, 32, 104, 97, 97, 114, 32,
  116, 114, 97, 110, 115, 102, 111, 114, 109, 32, 111, 102, 32, 105, 109, 97,
  103, 101, 36, 63, 32, 119, 105, 116, 104, 32, 36, 49, 32, 115, 99, 97,
  108, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 36, 49, 45, 49, 125, 10, 119, 61, 123, 109,
  97, 120, 40, 48, 44, 114, 111, 117, 110, 100, 40, 119, 47, 50, 94, 40,
  49, 43, 36, 60, 41, 41, 45, 49, 41, 125, 10, 104, 61, 123, 109, 97,
  120, 40, 48, 44, 114, 111, 117, 110, 100, 40, 104, 47, 50, 94, 40, 49,
  43, 36, 60, 41, 41, 45, 49, 41, 125, 10, 100, 61, 123, 109, 97, 120,
  40, 48, 44, 114, 111, 117, 110, 100, 40, 100, 47, 50, 94, 40, 49, 43,
  36, 60, 41, 41, 45, 49, 41, 125, 10, 45, 45, 122, 32, 48, 44, 48,
  44, 48, 44, 36, 119, 44, 36, 104, 44, 36, 100, 32, 45, 95, 105, 104,
  97, 97, 114, 91, 45, 49, 93, 32, 45, 106, 91, 45, 50, 93, 32, 91,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 100, 111, 110,
  101, 10, 45, 95, 105, 104, 97, 97, 114, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 95, 105, 104, 97, 97,
  114, 32, 58, 10, 45, 95, 105, 104, 97, 97, 114, 95, 120, 32, 45, 95,
  105, 104, 97, 97, 114, 95, 121, 32, 45, 95, 105, 104, 97, 97, 114, 95,
  122, 10, 95, 105, 104, 97, 97, 114, 95, 120, 32, 58, 10, 45, 105, 102,
  32, 123, 119, 60, 61, 49, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 119, 37, 50, 125,
  32, 45, 101, 114, 114, 111, 114, 91, 48, 45, 45, 54, 93, 32, 34, 73,
  110, 118, 97, 108, 105, 100, 32, 105, 109, 97, 103, 101, 32, 119, 105, 100,
  116, 104, 61, 34, 123, 119, 125, 34, 32, 40, 105, 115, 32, 110, 111, 116,
  32, 101, 118, 101, 110, 41, 46, 34, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 115, 32, 120, 44, 50, 32, 45, 114, 32, 50, 48, 48, 37, 32, 40,
  45, 49, 44, 49, 41, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 43, 32, 45, 47, 32, 123, 115, 113, 114, 116, 40, 50, 41, 125, 10,
  95, 105, 104, 97, 97, 114, 95, 121, 32, 58, 10, 45, 105, 102, 32, 123,
  104, 60, 61, 49, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 104, 37, 50, 125, 32, 45,
  101, 114, 114, 111, 114, 32, 34, 73, 110, 118, 97, 108, 105, 100, 32, 105,
  109, 97, 103, 101, 32, 104, 101, 105, 103, 104, 116, 61, 34, 123, 104, 125,
  34, 32, 40, 105, 115, 32, 110, 111, 116, 32, 101, 118, 101, 110, 41, 46,
  34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 115, 32, 121, 44, 50, 32,
  45, 114, 32, 49, 48, 48, 37, 44, 50, 48, 48, 37, 32, 40, 45, 49,
  59, 49, 41, 32, 45, 114, 91, 45, 49, 93, 32, 64, 123, 45, 50, 44,
  119, 125, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 43, 32,
  45, 47, 32, 123, 115, 113, 114, 116, 40, 50, 41, 125, 10, 95, 105, 104,
  97, 97, 114, 95, 122, 32, 58, 10, 45, 105, 102, 32, 123, 100, 60, 61,
  49, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 100, 37, 50, 125, 32, 45, 101, 114, 114,
  111, 114, 32, 34, 73, 110, 118, 97, 108, 105, 100, 32, 105, 109, 97, 103,
  101, 32, 100, 101, 112, 116, 104, 61, 34, 123, 104, 125, 34, 32, 40, 105,
  115, 32, 110, 111, 116, 32, 101, 118, 101, 110, 41, 46, 34, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 115, 32, 122, 44, 50, 32, 45, 114, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 50, 48, 48, 37, 32, 40, 45,
  49, 47, 49, 41, 32, 45, 114, 91, 45, 49, 93, 32, 64, 123, 45, 50,
  44, 119, 125, 44, 64, 123, 45, 50, 44, 104, 125, 32, 45, 42, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 43, 32, 45, 47, 32, 123, 115, 113, 114,
  116, 40, 50, 41, 125, 10, 35, 64, 103, 109, 105, 99, 32, 105, 110, 110,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116,
  101, 32, 103, 114, 97, 100, 105, 101, 110, 116, 45, 100, 105, 114, 101, 99,
  116, 101, 100, 32, 50, 110, 100, 32, 100, 101, 114, 105, 118, 97, 116, 105,
  118, 101, 32, 111, 102, 32, 105, 109, 97, 103, 101, 40, 115, 41, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 105, 110, 110, 10, 105, 110, 110, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101,
  32, 103, 114, 97, 100, 105, 101, 110, 116, 45, 100, 105, 114, 101, 99, 116,
  101, 100, 32, 50, 110, 100, 32, 100, 101, 114, 105, 118, 97, 116, 105, 118,
  101, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 100, 61, 61, 49, 125,
  10, 45, 45, 103, 32, 120, 121, 44, 48, 32, 45, 104, 101, 115, 115, 105,
  97, 110, 91, 45, 51, 93, 32, 120, 120, 120, 121, 121, 121, 10, 45, 42,
  91, 45, 53, 93, 32, 91, 45, 50, 93, 32, 45, 42, 91, 45, 52, 93,
  32, 91, 45, 49, 93, 32, 45, 42, 91, 45, 52, 93, 32, 50, 10, 45,
  43, 91, 45, 53, 44, 45, 52, 93, 32, 45, 42, 91, 45, 52, 93, 32,
  91, 45, 50, 93, 10, 45, 115, 113, 114, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 42, 91, 45, 51, 93, 32, 91, 45, 49, 93, 32, 45, 43, 91,
  45, 52, 44, 45, 51, 93, 10, 45, 43, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 43, 91, 45, 49, 93, 32, 49, 101, 45, 56, 32, 45, 47, 10,
  45, 101, 108, 115, 101, 10, 45, 45, 103, 32, 120, 121, 122, 44, 48, 32,
  45, 104, 101, 115, 115, 105, 97, 110, 91, 45, 52, 93, 32, 120, 120, 120,
  121, 120, 122, 121, 121, 121, 122, 122, 122, 10, 45, 42, 91, 45, 57, 93,
  32, 91, 45, 51, 93, 32, 45, 42, 91, 45, 56, 93, 32, 91, 45, 50,
  93, 32, 45, 42, 91, 45, 56, 93, 32, 50, 32, 45, 42, 91, 45, 55,
  93, 32, 91, 45, 49, 93, 32, 45, 42, 91, 45, 55, 93, 32, 50, 10,
  45, 43, 91, 45, 57, 45, 45, 55, 93, 32, 45, 42, 91, 45, 55, 93,
  32, 91, 45, 51, 93, 10, 45, 42, 91, 45, 54, 93, 32, 91, 45, 50,
  93, 32, 45, 42, 91, 45, 53, 93, 32, 91, 45, 49, 93, 32, 45, 42,
  91, 45, 53, 93, 32, 50, 10, 45, 43, 91, 45, 54, 44, 45, 53, 93,
  32, 45, 42, 91, 45, 53, 93, 32, 91, 45, 50, 93, 32, 45, 43, 91,
  45, 54, 44, 45, 53, 93, 10, 45, 115, 113, 114, 91, 45, 51, 45, 45,
  49, 93, 32, 45, 42, 91, 45, 52, 93, 32, 91, 45, 49, 93, 32, 45,
  43, 91, 45, 53, 44, 45, 52, 93, 10, 45, 43, 91, 45, 51, 45, 45,
  49, 93, 32, 45, 43, 91, 45, 49, 93, 32, 49, 101, 45, 56, 32, 45,
  47, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 105, 110, 112, 97, 105, 110, 116, 32, 58, 32, 91, 109, 97, 115, 107,
  93, 32, 58, 32, 91, 109, 97, 115, 107, 93, 44, 48, 44, 95, 102, 97,
  115, 116, 95, 109, 101, 116, 104, 111, 100, 32, 58, 32, 91, 109, 97, 115,
  107, 93, 44, 95, 112, 97, 116, 99, 104, 95, 115, 105, 122, 101, 62, 61,
  49, 44, 95, 108, 111, 111, 107, 117, 112, 95, 115, 105, 122, 101, 62, 61,
  49, 44, 95, 108, 111, 111, 107, 117, 112, 95, 102, 97, 99, 116, 111, 114,
  62, 61, 48, 44, 95, 98, 108, 101, 110, 100, 95, 115, 105, 122, 101, 62,
  61, 48, 44, 48, 60, 61, 95, 98, 108, 101, 110, 100, 95, 116, 104, 114,
  101, 115, 104, 111, 108, 100, 60, 61, 49, 44, 95, 98, 108, 101, 110, 100,
  95, 100, 101, 99, 97, 121, 62, 61, 48, 44, 95, 98, 108, 101, 110, 100,
  95, 115, 99, 97, 108, 101, 115, 62, 61, 49, 44, 95, 105, 115, 95, 98,
  108, 101, 110, 100, 95, 111, 117, 116, 101, 114, 61, 123, 32, 48, 32, 124,
  32, 49, 32, 125, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 73, 110, 112, 97, 105, 110, 116, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 98, 121, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 109, 97, 115, 107, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 73, 102, 32, 110, 111, 32, 112, 97,
  116, 99, 104, 32, 115, 105, 122, 101, 32, 40, 111, 114, 32, 48, 41, 32,
  105, 115, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 44, 32, 105, 110,
  112, 97, 105, 110, 116, 105, 110, 103, 32, 105, 115, 32, 100, 111, 110, 101,
  32, 117, 115, 105, 110, 103, 32, 97, 32, 102, 97, 115, 116, 32, 97, 118,
  101, 114, 97, 103, 101, 32, 111, 114, 32, 109, 101, 100, 105, 97, 110, 32,
  97, 108, 103, 111, 114, 105, 116, 104, 109, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 79, 116, 104, 101, 114, 119, 105, 115, 101, 44, 32, 105,
  116, 32, 117, 115, 101, 100, 32, 97, 32, 112, 97, 116, 99, 104, 45, 98,
  97, 115, 101, 100, 32, 114, 101, 99, 111, 110, 115, 116, 114, 117, 99, 116,
  105, 111, 110, 32, 109, 101, 116, 104, 111, 100, 44, 32, 116, 104, 97, 116,
  32, 99, 97, 110, 32, 98, 101, 32, 118, 101, 114, 121, 32, 116, 105, 109,
  101, 32, 99, 111, 110, 115, 117, 109, 105, 110, 103, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 39, 102, 97, 115, 116, 95, 109, 101, 116, 104,
  111, 100, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 108,
  111, 119, 45, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 32,
  97, 118, 101, 114, 97, 103, 101, 32, 124, 32, 49, 61, 104, 105, 103, 104,
  45, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 32, 97, 118,
  101, 114, 97, 103, 101, 32, 124, 32, 50, 61, 108, 111, 119, 45, 99, 111,
  110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 32, 109, 101, 100, 105, 97,
  110, 32, 124, 32, 51, 61, 104, 105, 103, 104, 45, 99, 111, 110, 110, 101,
  99, 116, 105, 118, 105, 116, 121, 32, 109, 101, 100, 105, 97, 110, 32, 125,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117,
  108, 116, 32, 118, 97, 108, 117, 101, 115, 32, 58, 32, 39, 112, 97, 116,
  99, 104, 95, 115, 105, 122, 101, 61, 48, 39, 44, 32, 39, 102, 97, 115,
  116, 95, 109, 101, 116, 104, 111, 100, 61, 49, 39, 44, 32, 39, 108, 111,
  111, 107, 117, 112, 95, 115, 105, 122, 101, 61, 50, 50, 39, 44, 32, 39,
  108, 111, 111, 107, 117, 112, 95, 102, 97, 99, 116, 111, 114, 61, 48, 46,
  53, 39, 44, 32, 39, 98, 108, 101, 110, 100, 95, 115, 105, 122, 101, 61,
  48, 39, 44, 32, 39, 98, 108, 101, 110, 100, 95, 116, 104, 114, 101, 115,
  104, 111, 108, 100, 61, 48, 39, 44, 32, 39, 98, 108, 101, 110, 100, 95,
  100, 101, 99, 97, 121, 61, 48, 46, 48, 53, 39, 44, 32, 39, 98, 108,
  101, 110, 100, 95, 115, 99, 97, 108, 101, 115, 61, 49, 48, 39, 32, 97,
  110, 100, 32, 39, 105, 115, 95, 98, 108, 101, 110, 100, 95, 111, 117, 116,
  101, 114, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 32, 45, 101, 108, 108, 105, 112, 115, 101, 32, 53,
  48, 37, 44, 53, 48, 37, 44, 51, 48, 44, 51, 48, 44, 48, 44, 49,
  44, 50, 53, 53, 32, 45, 101, 108, 108, 105, 112, 115, 101, 32, 50, 48,
  37, 44, 50, 48, 37, 44, 51, 48, 44, 49, 48, 44, 48, 44, 49, 44,
  50, 53, 53, 32, 45, 45, 105, 110, 112, 97, 105, 110, 116, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 32, 45, 114, 101, 109, 111, 118, 101, 91, 45,
  50, 93, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 32, 45, 99, 105, 114, 99, 108, 101, 32, 51, 48, 37, 44, 51, 48,
  37, 44, 51, 48, 44, 49, 44, 50, 53, 53, 44, 48, 44, 50, 53, 53,
  32, 45, 99, 105, 114, 99, 108, 101, 32, 55, 48, 37, 44, 55, 48, 37,
  44, 53, 48, 44, 49, 44, 50, 53, 53, 44, 48, 44, 50, 53, 53, 32,
  45, 45, 105, 110, 112, 97, 105, 110, 116, 91, 48, 93, 32, 91, 49, 93,
  44, 53, 44, 49, 53, 44, 48, 46, 53, 44, 49, 44, 57, 44, 48, 32,
  45, 114, 101, 109, 111, 118, 101, 91, 49, 93, 10, 35, 64, 103, 109, 105,
  99, 32, 105, 110, 112, 97, 105, 110, 116, 95, 102, 108, 111, 119, 32, 58,
  32, 95, 110, 98, 95, 105, 116, 101, 114, 49, 62, 61, 48, 44, 95, 110,
  98, 95, 105, 116, 101, 114, 50, 62, 61, 48, 44, 95, 100, 116, 62, 61,
  48, 44, 95, 97, 108, 112, 104, 97, 44, 95, 115, 105, 103, 109, 97, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 105,
  116, 101, 114, 97, 116, 105, 111, 110, 32, 111, 102, 32, 116, 104, 101, 32,
  105, 110, 112, 97, 105, 110, 116, 105, 110, 103, 32, 102, 108, 111, 119, 32,
  111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 110, 98,
  95, 105, 116, 101, 114, 49, 61, 52, 39, 44, 32, 39, 110, 98, 95, 105,
  116, 101, 114, 50, 61, 49, 53, 39, 44, 32, 39, 100, 116, 61, 49, 53,
  39, 44, 32, 39, 97, 108, 112, 104, 97, 61, 49, 39, 32, 97, 110, 100,
  32, 39, 115, 105, 103, 109, 97, 61, 51, 39, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 101, 108, 108, 105,
  112, 115, 101, 91, 45, 49, 93, 32, 51, 48, 37, 44, 51, 48, 37, 44,
  52, 48, 44, 51, 48, 44, 48, 44, 49, 44, 50, 53, 53, 32, 45, 114,
  101, 118, 101, 114, 115, 101, 32, 45, 105, 110, 112, 97, 105, 110, 116, 95,
  102, 108, 111, 119, 32, 44, 10, 105, 110, 112, 97, 105, 110, 116, 95, 102,
  108, 111, 119, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  52, 125, 44, 36, 123, 50, 61, 49, 53, 125, 44, 36, 123, 51, 61, 49,
  53, 125, 44, 36, 123, 52, 61, 49, 125, 44, 36, 123, 53, 61, 51, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32,
  36, 49, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110, 32, 111, 102, 32,
  116, 104, 101, 32, 105, 110, 112, 97, 105, 110, 116, 105, 110, 103, 32, 102,
  108, 111, 119, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 110, 111, 114, 109, 91, 48, 93, 32, 45,
  113, 117, 97, 110, 116, 105, 122, 101, 91, 48, 93, 32, 50, 44, 49, 44,
  49, 32, 45, 110, 91, 48, 93, 32, 48, 44, 49, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 105, 102, 32, 36, 62, 32, 45, 108,
  91, 48, 44, 36, 62, 93, 10, 45, 114, 91, 48, 93, 32, 91, 49, 93,
  32, 45, 105, 110, 112, 97, 105, 110, 116, 91, 49, 93, 32, 91, 48, 93,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 32, 45, 45, 100, 105,
  102, 102, 117, 115, 105, 111, 110, 116, 101, 110, 115, 111, 114, 115, 91, 49,
  93, 32, 48, 44, 49, 44, 36, 52, 44, 36, 53, 44, 48, 32, 45, 42,
  91, 50, 93, 32, 91, 48, 93, 32, 45, 115, 109, 111, 111, 116, 104, 91,
  49, 93, 32, 91, 50, 93, 44, 36, 50, 44, 36, 51, 44, 48, 32, 45,
  114, 109, 91, 50, 93, 32, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100,
  108, 32, 45, 101, 110, 100, 105, 102, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 107, 117, 119, 97, 104,
  97, 114, 97, 32, 58, 32, 115, 105, 122, 101, 62, 48, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 75, 117, 119, 97,
  104, 97, 114, 97, 32, 102, 105, 108, 116, 101, 114, 32, 111, 102, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 115, 105, 122, 101, 32, 111, 110,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 45, 107, 117, 119, 97, 104, 97, 114,
  97, 32, 53, 10, 107, 117, 119, 97, 104, 97, 114, 97, 32, 58, 32, 45,
  99, 104, 101, 99, 107, 32, 36, 49, 62, 48, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 75, 117, 119, 97, 104, 97,
  114, 97, 32, 102, 105, 108, 116, 101, 114, 32, 111, 102, 32, 115, 105, 122,
  101, 32, 36, 49, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 115, 61, 123, 115, 125, 10, 45,
  45, 100, 105, 108, 97, 116, 101, 32, 36, 49, 32, 45, 99, 111, 109, 112,
  111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93,
  32, 109, 105, 110, 10, 45, 45, 101, 114, 111, 100, 101, 91, 48, 93, 32,
  36, 49, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 91, 45, 49, 93, 32, 109, 97, 120, 10, 45, 45, 91,
  45, 50, 44, 45, 49, 93, 10, 36, 49, 44, 49, 44, 49, 44, 49, 44,
  123, 49, 47, 36, 49, 125, 32, 45, 99, 111, 110, 118, 111, 108, 118, 101,
  91, 48, 93, 32, 91, 45, 49, 93, 32, 45, 116, 114, 97, 110, 115, 112,
  111, 115, 101, 91, 45, 49, 93, 32, 45, 99, 111, 110, 118, 111, 108, 118,
  101, 91, 48, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 112, 61, 123, 105, 110, 116, 40, 36, 49, 47, 50, 41, 125, 10,
  45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 102, 32, 34,
  118, 49, 61, 105, 40, 120, 45, 34, 36, 112, 34, 44, 121, 45, 34, 36,
  112, 34, 44, 48, 44, 34, 36, 115, 34, 44, 48, 44, 49, 41, 59, 32,
  92, 10, 118, 50, 61, 105, 40, 120, 43, 34, 36, 112, 34, 44, 121, 45,
  34, 36, 112, 34, 44, 48, 44, 34, 36, 115, 34, 44, 48, 44, 49, 41,
  59, 32, 92, 10, 118, 51, 61, 105, 40, 120, 45, 34, 36, 112, 34, 44,
  121, 43, 34, 36, 112, 34, 44, 48, 44, 34, 36, 115, 34, 44, 48, 44,
  49, 41, 59, 32, 92, 10, 118, 52, 61, 105, 40, 120, 43, 34, 36, 112,
  34, 44, 121, 43, 34, 36, 112, 34, 44, 48, 44, 34, 36, 115, 34, 44,
  48, 44, 49, 41, 59, 32, 92, 10, 118, 109, 61, 109, 105, 110, 40, 118,
  49, 44, 118, 50, 44, 118, 51, 44, 118, 52, 41, 59, 32, 92, 10, 105,
  102, 40, 99, 62, 61, 34, 36, 115, 34, 44, 105, 44, 32, 92, 10, 105,
  102, 40, 118, 109, 61, 61, 118, 49, 44, 105, 40, 120, 45, 34, 36, 112,
  34, 44, 121, 45, 34, 36, 112, 34, 44, 48, 44, 99, 44, 48, 44, 49,
  41, 44, 10, 105, 102, 40, 118, 109, 61, 61, 118, 50, 44, 105, 40, 120,
  43, 34, 36, 112, 34, 44, 121, 45, 34, 36, 112, 34, 44, 48, 44, 99,
  44, 48, 44, 49, 41, 44, 10, 105, 102, 40, 118, 109, 61, 61, 118, 51,
  44, 105, 40, 120, 45, 34, 36, 112, 34, 44, 121, 43, 34, 36, 112, 34,
  44, 48, 44, 99, 44, 48, 44, 49, 41, 44, 10, 105, 40, 120, 43, 34,
  36, 112, 34, 44, 121, 43, 34, 36, 112, 34, 44, 48, 44, 99, 44, 48,
  44, 49, 41, 41, 41, 41, 41, 34, 10, 45, 99, 104, 97, 110, 110, 101,
  108, 115, 32, 48, 44, 123, 115, 45, 50, 125, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109,
  105, 99, 32, 108, 97, 112, 108, 97, 99, 105, 97, 110, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 76, 97,
  112, 108, 97, 99, 105, 97, 110, 32, 111, 102, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 108, 97, 112, 108, 97, 99, 105, 97, 110, 10, 108, 97, 112, 108,
  97, 99, 105, 97, 110, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 67, 111, 109, 112, 117, 116, 101, 32, 76, 97, 112, 108, 97, 99, 105,
  97, 110, 32, 111, 102, 32, 105, 109, 97, 103, 101, 32, 36, 63, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 45, 104, 101, 115, 115, 105, 97, 110,
  32, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 40, 100, 61, 61, 49,
  41, 44, 120, 120, 121, 121, 122, 122, 44, 120, 120, 121, 121, 125, 32, 45,
  43, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 108, 105, 99, 32, 58, 32,
  95, 97, 109, 112, 108, 105, 116, 117, 100, 101, 62, 48, 44, 95, 99, 104,
  97, 110, 110, 101, 108, 115, 62, 48, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 82, 101, 110, 100, 101, 114, 32, 76, 73, 67, 32, 114, 101, 112,
  114, 101, 115, 101, 110, 116, 97, 116, 105, 111, 110, 32, 111, 102, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 118, 101, 99, 116, 111, 114, 32, 102,
  105, 101, 108, 100, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 97, 109, 112, 108, 105, 116, 117, 100, 101, 61, 51, 48, 39, 32, 97,
  110, 100, 32, 39, 99, 104, 97, 110, 110, 101, 108, 115, 61, 49, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 52, 48, 48, 44,
  52, 48, 48, 44, 49, 44, 50, 44, 39, 105, 102, 40, 99, 61, 61, 48,
  44, 120, 45, 119, 47, 50, 44, 121, 45, 104, 47, 50, 41, 39, 32, 45,
  45, 108, 105, 99, 32, 50, 48, 48, 44, 51, 32, 45, 113, 117, 105, 118,
  101, 114, 91, 45, 50, 93, 32, 91, 45, 50, 93, 44, 49, 48, 44, 45,
  49, 51, 44, 49, 44, 49, 44, 50, 53, 53, 10, 108, 105, 99, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 51, 48, 125, 44, 36,
  123, 50, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82,
  101, 110, 100, 101, 114, 32, 76, 73, 67, 32, 114, 101, 112, 114, 101, 115,
  101, 110, 116, 97, 116, 105, 111, 110, 32, 111, 102, 32, 50, 100, 32, 118,
  101, 99, 116, 111, 114, 32, 102, 105, 101, 108, 100, 36, 63, 44, 32, 119,
  105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 36, 49,
  32, 97, 110, 100, 32, 36, 50, 32, 99, 104, 97, 110, 110, 101, 108, 40,
  115, 41, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64,
  123, 48, 44, 110, 125, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  48, 44, 49, 32, 45, 47, 32, 123, 109, 97, 120, 40, 97, 98, 115, 40,
  64, 123, 45, 49, 44, 109, 125, 41, 44, 97, 98, 115, 40, 64, 123, 45,
  49, 44, 77, 125, 41, 41, 125, 32, 45, 118, 101, 99, 116, 111, 114, 50,
  116, 101, 110, 115, 111, 114, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 36, 50, 32, 45, 114, 97, 110, 100, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 115, 109, 111, 111, 116, 104,
  91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 36, 49, 32, 45, 114, 109,
  91, 45, 50, 93, 10, 45, 101, 113, 117, 97, 108, 105, 122, 101, 10, 45,
  110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 109, 97, 112, 95, 116, 111, 110, 101, 115, 32, 58, 32, 95, 116, 104,
  114, 101, 115, 104, 111, 108, 100, 62, 61, 48, 44, 95, 103, 97, 109, 109,
  97, 62, 61, 48, 44, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  62, 61, 48, 44, 110, 98, 95, 105, 116, 101, 114, 62, 61, 48, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 116, 111,
  110, 101, 32, 109, 97, 112, 112, 105, 110, 103, 32, 111, 112, 101, 114, 97,
  116, 111, 114, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 44, 32, 98, 97, 115, 101, 100, 32, 111, 110,
  32, 80, 111, 105, 115, 115, 111, 110, 32, 101, 113, 117, 97, 116, 105, 111,
  110, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 116, 104, 114,
  101, 115, 104, 111, 108, 100, 61, 48, 46, 49, 39, 44, 32, 39, 103, 97,
  109, 109, 97, 61, 48, 46, 56, 39, 44, 32, 39, 115, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 61, 48, 46, 53, 39, 32, 97, 110, 100, 32, 39,
  110, 98, 95, 105, 116, 101, 114, 61, 51, 48, 39, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 45, 109, 97, 112, 95, 116, 111, 110, 101, 115, 32, 44, 10,
  109, 97, 112, 95, 116, 111, 110, 101, 115, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 49, 61, 48, 46, 49, 125, 44, 36, 123, 50, 61, 48,
  46, 56, 125, 44, 36, 123, 51, 61, 48, 46, 53, 125, 44, 36, 123, 52,
  61, 51, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112,
  112, 108, 121, 32, 116, 111, 110, 101, 32, 109, 97, 112, 112, 105, 110, 103,
  32, 111, 112, 101, 114, 97, 116, 111, 114, 32, 111, 110, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 116, 104, 114, 101, 115,
  104, 111, 108, 100, 32, 36, 49, 44, 32, 103, 97, 109, 109, 97, 32, 36,
  50, 44, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 51,
  32, 97, 110, 100, 32, 36, 52, 32, 105, 116, 101, 114, 97, 116, 105, 111,
  110, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 108, 32,
  45, 115, 32, 99, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 103, 32, 120, 121, 44, 49, 32, 45,
  97, 32, 99, 32, 45, 45, 110, 111, 114, 109, 32, 45, 111, 114, 105, 101,
  110, 116, 97, 116, 105, 111, 110, 91, 45, 50, 93, 10, 109, 61, 123, 105,
  109, 125, 32, 77, 61, 123, 105, 77, 125, 32, 45, 98, 91, 45, 49, 93,
  32, 36, 51, 32, 45, 110, 91, 45, 49, 93, 32, 36, 109, 44, 36, 77,
  10, 45, 42, 91, 45, 49, 93, 32, 39, 97, 108, 112, 104, 97, 61, 36,
  49, 42, 105, 77, 59, 40, 97, 108, 112, 104, 97, 47, 40, 49, 101, 45,
  49, 48, 43, 105, 41, 41, 42, 40, 105, 47, 40, 49, 101, 45, 49, 48,
  43, 97, 108, 112, 104, 97, 41, 41, 94, 36, 50, 39, 10, 45, 42, 32,
  45, 115, 32, 99, 32, 45, 103, 91, 45, 50, 93, 32, 120, 44, 45, 49,
  32, 45, 103, 91, 45, 49, 93, 32, 121, 44, 45, 49, 32, 45, 43, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 97, 32, 99,
  32, 45, 42, 32, 48, 46, 50, 53, 32, 45, 101, 110, 100, 108, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 36, 52, 32, 45, 45, 108, 97, 112, 108,
  97, 99, 105, 97, 110, 91, 45, 50, 93, 32, 45, 42, 91, 45, 49, 93,
  32, 48, 46, 50, 53, 32, 45, 43, 91, 45, 49, 93, 32, 91, 45, 51,
  93, 32, 45, 45, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 42,
  91, 45, 49, 93, 32, 56, 48, 48, 32, 45, 43, 91, 45, 51, 44, 45,
  49, 93, 32, 45, 47, 91, 45, 50, 93, 32, 56, 48, 49, 32, 45, 99,
  91, 45, 50, 93, 32, 48, 44, 50, 53, 53, 32, 45, 100, 111, 110, 101,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 109, 97, 112, 95, 116, 111, 110, 101, 115, 95, 102, 97, 115, 116,
  32, 58, 32, 95, 114, 97, 100, 105, 117, 115, 91, 37, 93, 62, 61, 48,
  44, 95, 112, 111, 119, 101, 114, 62, 61, 48, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 102, 97, 115, 116, 32, 116,
  111, 110, 101, 32, 109, 97, 112, 112, 105, 110, 103, 32, 111, 112, 101, 114,
  97, 116, 111, 114, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115,
  58, 32, 39, 114, 97, 100, 105, 117, 115, 61, 51, 37, 39, 32, 97, 110,
  100, 32, 39, 112, 111, 119, 101, 114, 61, 48, 46, 51, 39, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 45, 109, 97, 112, 95, 116, 111, 110, 101, 115, 95,
  102, 97, 115, 116, 32, 44, 10, 109, 97, 112, 95, 116, 111, 110, 101, 115,
  95, 102, 97, 115, 116, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  36, 123, 49, 61, 51, 37, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123,
  50, 61, 48, 46, 51, 125, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 102, 97, 115, 116, 32, 116,
  111, 110, 101, 32, 109, 97, 112, 112, 105, 110, 103, 32, 111, 112, 101, 114,
  97, 116, 111, 114, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 119, 105, 116, 104, 32, 114, 97, 100, 105, 117, 115, 32, 36, 49, 32,
  97, 110, 100, 32, 112, 111, 119, 101, 114, 32, 36, 50, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 45, 108, 117, 109, 105, 110, 97, 110, 99,
  101, 32, 45, 98, 91, 45, 49, 93, 32, 36, 49, 32, 45, 110, 32, 48,
  44, 49, 10, 45, 45, 42, 91, 45, 49, 93, 32, 50, 32, 45, 45, 91,
  45, 49, 93, 32, 49, 32, 45, 97, 98, 115, 91, 45, 49, 93, 32, 45,
  42, 91, 45, 49, 93, 32, 123, 36, 50, 42, 108, 111, 103, 40, 49, 48,
  41, 125, 32, 45, 101, 120, 112, 91, 45, 49, 93, 10, 45, 108, 101, 91,
  45, 50, 93, 32, 48, 46, 53, 32, 45, 114, 91, 45, 49, 93, 32, 91,
  45, 51, 93, 10, 45, 45, 42, 91, 45, 51, 93, 32, 45, 49, 32, 45,
  43, 91, 45, 49, 93, 32, 49, 32, 45, 94, 91, 45, 49, 93, 32, 91,
  45, 50, 93, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 43,
  91, 45, 49, 93, 32, 49, 32, 45, 42, 91, 45, 49, 93, 32, 91, 45,
  51, 93, 10, 45, 94, 91, 45, 52, 44, 45, 50, 93, 32, 45, 101, 113,
  91, 45, 50, 93, 32, 48, 32, 45, 42, 91, 45, 51, 44, 45, 50, 93,
  32, 45, 43, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 109, 101, 97, 110, 99, 117, 114, 118, 97, 116, 117,
  114, 101, 95, 102, 108, 111, 119, 32, 58, 32, 95, 110, 98, 95, 105, 116,
  101, 114, 62, 61, 48, 44, 95, 100, 116, 44, 95, 115, 101, 113, 117, 101,
  110, 99, 101, 95, 102, 108, 97, 103, 61, 123, 32, 48, 32, 124, 32, 49,
  32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108,
  121, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 111, 102, 32,
  116, 104, 101, 32, 109, 101, 97, 110, 32, 99, 117, 114, 118, 97, 116, 117,
  114, 101, 32, 102, 108, 111, 119, 32, 111, 110, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108,
  117, 101, 115, 58, 32, 39, 110, 98, 95, 105, 116, 101, 114, 61, 49, 48,
  39, 44, 32, 39, 100, 116, 61, 51, 48, 39, 32, 97, 110, 100, 32, 39,
  107, 101, 101, 112, 95, 115, 101, 113, 117, 101, 110, 99, 101, 61, 48, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 45, 109, 101, 97, 110, 99, 117, 114,
  118, 97, 116, 117, 114, 101, 95, 102, 108, 111, 119, 32, 50, 48, 10, 109,
  101, 97, 110, 99, 117, 114, 118, 97, 116, 117, 114, 101, 95, 102, 108, 111,
  119, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 48,
  125, 44, 36, 123, 50, 61, 51, 48, 125, 44, 36, 123, 51, 61, 48, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32,
  36, 49, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 111, 102,
  32, 116, 104, 101, 32, 109, 101, 97, 110, 32, 99, 117, 114, 118, 97, 116,
  117, 114, 101, 32, 102, 108, 111, 119, 32, 111, 110, 32, 105, 109, 97, 103,
  101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 116, 105, 109, 101, 32, 115,
  116, 101, 112, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 45, 112,
  100, 101, 95, 102, 108, 111, 119, 32, 36, 49, 44, 36, 50, 44, 105, 101,
  101, 44, 36, 51, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 109, 101, 100, 105, 97, 110, 32, 58, 32, 115, 105, 122, 101, 62, 61,
  48, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 65, 112, 112, 108, 121, 32, 109, 101, 100, 105, 97, 110, 32, 102, 105,
  108, 116, 101, 114, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 32, 119, 105, 116, 104, 32, 115, 116, 114,
  117, 99, 116, 117, 114, 105, 110, 103, 32, 101, 108, 101, 109, 101, 110, 116,
  32, 115, 105, 122, 101, 32, 120, 32, 115, 105, 122, 101, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 45, 109, 101, 100, 105, 97, 110, 32, 53, 10, 35, 64,
  103, 109, 105, 99, 32, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 108,
  111, 99, 97, 108, 32, 58, 32, 95, 97, 109, 112, 108, 105, 116, 117, 100,
  101, 62, 61, 48, 44, 95, 114, 97, 100, 105, 117, 115, 62, 48, 44, 95,
  110, 95, 115, 109, 111, 111, 116, 104, 62, 61, 48, 91, 37, 93, 44, 95,
  97, 95, 115, 109, 111, 111, 116, 104, 62, 61, 48, 91, 37, 93, 44, 95,
  105, 115, 95, 99, 117, 116, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125,
  44, 95, 109, 105, 110, 61, 48, 44, 95, 109, 97, 120, 61, 50, 53, 53,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 78, 111, 114, 109, 97, 108,
  105, 122, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 32, 108, 111, 99, 97, 108, 108, 121, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 97, 109, 112, 108, 105, 116, 117, 100, 101,
  61, 51, 39, 44, 32, 39, 114, 97, 100, 105, 117, 115, 61, 49, 54, 39,
  44, 32, 39, 110, 95, 115, 109, 111, 111, 116, 104, 61, 52, 37, 39, 44,
  32, 39, 97, 95, 115, 109, 111, 111, 116, 104, 61, 50, 37, 39, 44, 32,
  39, 105, 115, 95, 99, 117, 116, 61, 49, 39, 44, 32, 39, 109, 105, 110,
  61, 48, 39, 32, 97, 110, 100, 32, 39, 109, 97, 120, 61, 50, 53, 53,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 110, 111, 114, 109, 97, 108,
  105, 122, 101, 95, 108, 111, 99, 97, 108, 32, 56, 44, 49, 48, 10, 110,
  111, 114, 109, 97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 32, 58,
  10, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 51, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 49, 54, 125, 62, 48, 32,
  38, 38, 32, 105, 115, 98, 111, 111, 108, 40, 36, 123, 53, 61, 49, 125,
  41, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 52, 37, 125,
  44, 36, 123, 52, 61, 50, 37, 125, 44, 36, 123, 54, 61, 48, 125, 44,
  36, 123, 55, 61, 50, 53, 53, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 78, 111, 114, 109, 97, 108, 105, 122, 101, 32, 105, 109, 97, 103,
  101, 36, 63, 32, 108, 111, 99, 97, 108, 108, 121, 44, 32, 119, 105, 116,
  104, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 36, 49, 44, 32,
  114, 97, 100, 105, 117, 115, 32, 36, 50, 44, 32, 110, 101, 105, 103, 104,
  98, 111, 114, 104, 111, 111, 100, 32, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 36, 51, 32, 97, 110, 100, 32, 97, 118, 101, 114, 97, 103,
  101, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 52, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 108, 32, 45, 101, 114,
  111, 100, 101, 32, 123, 50, 42, 36, 50, 43, 49, 125, 32, 45, 115, 32,
  99, 32, 45, 109, 105, 110, 32, 45, 101, 110, 100, 108, 10, 45, 45, 108,
  91, 45, 50, 93, 32, 45, 100, 105, 108, 97, 116, 101, 32, 123, 50, 42,
  36, 50, 43, 49, 125, 32, 45, 115, 32, 99, 32, 45, 109, 97, 120, 32,
  45, 101, 110, 100, 108, 10, 45, 45, 98, 91, 45, 51, 93, 32, 36, 52,
  32, 45, 98, 91, 45, 51, 44, 45, 50, 93, 32, 36, 51, 10, 45, 45,
  45, 91, 45, 50, 93, 32, 91, 45, 51, 93, 32, 45, 43, 91, 45, 49,
  93, 32, 48, 46, 48, 49, 32, 45, 45, 91, 45, 53, 93, 32, 91, 45,
  52, 93, 32, 45, 47, 91, 45, 53, 44, 45, 49, 93, 10, 45, 42, 91,
  45, 51, 44, 45, 50, 93, 32, 123, 36, 49, 43, 49, 125, 32, 45, 42,
  91, 45, 49, 93, 32, 45, 36, 49, 32, 45, 43, 91, 45, 51, 93, 32,
  91, 45, 49, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45,
  105, 102, 32, 36, 53, 32, 45, 109, 97, 120, 91, 45, 50, 93, 32, 36,
  54, 32, 45, 109, 105, 110, 91, 45, 49, 93, 32, 36, 55, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 45, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  32, 45, 42, 91, 45, 51, 44, 45, 49, 93, 32, 45, 43, 10, 45, 105,
  102, 32, 36, 53, 32, 45, 99, 32, 36, 54, 44, 36, 55, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 110, 111, 114,
  109, 97, 108, 105, 122, 101, 100, 95, 99, 114, 111, 115, 115, 95, 99, 111,
  114, 114, 101, 108, 97, 116, 105, 111, 110, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 110, 111, 114, 109, 97,
  108, 105, 122, 101, 100, 32, 99, 114, 111, 115, 115, 45, 99, 111, 114, 114,
  101, 108, 97, 116, 105, 111, 110, 32, 117, 115, 105, 110, 103, 32, 116, 119,
  111, 45, 98, 121, 45, 116, 119, 111, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  45, 115, 104, 105, 102, 116, 32, 45, 51, 48, 44, 45, 50, 48, 32, 45,
  110, 111, 114, 109, 97, 108, 105, 122, 101, 100, 95, 99, 114, 111, 115, 115,
  95, 99, 111, 114, 114, 101, 108, 97, 116, 105, 111, 110, 10, 110, 111, 114,
  109, 97, 108, 105, 122, 101, 100, 95, 99, 114, 111, 115, 115, 95, 99, 111,
  114, 114, 101, 108, 97, 116, 105, 111, 110, 32, 58, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 110, 111, 114,
  109, 97, 108, 105, 122, 101, 100, 32, 99, 114, 111, 115, 115, 45, 99, 111,
  114, 114, 101, 108, 97, 116, 105, 111, 110, 32, 117, 115, 105, 110, 103, 32,
  116, 119, 111, 45, 98, 121, 45, 116, 119, 111, 32, 105, 109, 97, 103, 101,
  36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 110, 111, 114, 109, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47,
  50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125,
  93, 10, 45, 102, 102, 116, 91, 45, 50, 93, 32, 45, 102, 102, 116, 91,
  45, 49, 93, 32, 91, 45, 50, 44, 45, 49, 93, 32, 45, 109, 117, 108,
  91, 45, 50, 93, 32, 91, 45, 53, 93, 32, 45, 109, 117, 108, 91, 45,
  49, 93, 32, 91, 45, 54, 93, 10, 45, 45, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 42, 91, 45, 53, 44, 45, 51, 93, 32, 45, 42, 91, 45,
  51, 44, 45, 50, 93, 32, 45, 43, 91, 45, 51, 44, 45, 50, 93, 32,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 97, 91, 45, 50, 44, 45, 49,
  93, 32, 99, 32, 45, 110, 111, 114, 109, 91, 45, 49, 93, 10, 45, 47,
  91, 45, 51, 93, 32, 91, 45, 49, 93, 32, 45, 47, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 105, 102, 102, 116, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 112, 104, 97, 115, 101, 95,
  99, 111, 114, 114, 101, 108, 97, 116, 105, 111, 110, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 69, 115, 116, 105, 109, 97, 116, 101, 32, 116, 114,
  97, 110, 115, 108, 97, 116, 105, 111, 110, 32, 118, 101, 99, 116, 111, 114,
  32, 117, 115, 105, 110, 103, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119,
  111, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 115, 104, 105, 102, 116, 32,
  45, 51, 48, 44, 45, 50, 48, 32, 45, 45, 112, 104, 97, 115, 101, 95,
  99, 111, 114, 114, 101, 108, 97, 116, 105, 111, 110, 32, 45, 117, 110, 114,
  111, 108, 108, 91, 45, 49, 93, 32, 121, 10, 112, 104, 97, 115, 101, 95,
  99, 111, 114, 114, 101, 108, 97, 116, 105, 111, 110, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 69, 115, 116, 105, 109, 97, 116, 101, 32,
  116, 114, 97, 110, 115, 108, 97, 116, 105, 111, 110, 32, 118, 101, 99, 116,
  111, 114, 32, 117, 115, 105, 110, 103, 32, 116, 119, 111, 45, 98, 121, 45,
  116, 119, 111, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40,
  64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62,
  43, 49, 125, 93, 10, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 100,
  95, 99, 114, 111, 115, 115, 95, 99, 111, 114, 114, 101, 108, 97, 116, 105,
  111, 110, 10, 40, 64, 123, 45, 49, 44, 67, 125, 41, 32, 45, 42, 91,
  45, 49, 93, 32, 50, 32, 45, 115, 91, 45, 49, 93, 32, 120, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 64, 45, 51, 62,
  64, 123, 45, 52, 44, 119, 125, 125, 32, 45, 45, 91, 45, 51, 93, 32,
  64, 123, 45, 52, 44, 119, 125, 32, 45, 45, 91, 45, 51, 93, 32, 64,
  123, 45, 52, 44, 119, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 64, 45, 50, 62, 64, 123, 45, 52, 44, 104, 125, 125, 32,
  45, 45, 91, 45, 50, 93, 32, 64, 123, 45, 52, 44, 104, 125, 32, 45,
  45, 91, 45, 50, 93, 32, 64, 123, 45, 52, 44, 104, 125, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64, 45, 49, 62, 64, 123,
  45, 52, 44, 100, 125, 125, 32, 45, 45, 91, 45, 49, 93, 32, 64, 123,
  45, 52, 44, 100, 125, 32, 45, 45, 91, 45, 49, 93, 32, 64, 123, 45,
  52, 44, 100, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 91, 45,
  51, 45, 45, 49, 93, 32, 99, 32, 45, 114, 109, 91, 45, 50, 93, 32,
  45, 47, 32, 50, 32, 45, 42, 32, 45, 49, 10, 45, 110, 109, 32, 91,
  112, 104, 97, 115, 101, 92, 32, 99, 111, 114, 114, 101, 108, 97, 116, 105,
  111, 110, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 112, 100, 101, 95,
  102, 108, 111, 119, 32, 58, 32, 95, 110, 98, 95, 105, 116, 101, 114, 62,
  61, 48, 44, 95, 100, 116, 44, 95, 118, 101, 108, 111, 99, 105, 116, 121,
  95, 99, 111, 109, 109, 97, 110, 100, 44, 95, 107, 101, 101, 112, 95, 115,
  101, 113, 117, 101, 110, 99, 101, 61, 123, 32, 48, 32, 124, 32, 49, 32,
  125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121,
  32, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 111, 102, 32, 97,
  32, 103, 101, 110, 101, 114, 105, 99, 32, 80, 68, 69, 32, 102, 108, 111,
  119, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39,
  110, 98, 95, 105, 116, 101, 114, 61, 49, 48, 39, 44, 32, 39, 100, 116,
  61, 51, 48, 39, 44, 32, 39, 118, 101, 108, 111, 99, 105, 116, 121, 95,
  99, 111, 109, 109, 97, 110, 100, 61, 108, 97, 112, 108, 97, 99, 105, 97,
  110, 39, 32, 97, 110, 100, 32, 39, 107, 101, 101, 112, 95, 115, 101, 113,
  117, 101, 110, 99, 101, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  45, 112, 100, 101, 95, 102, 108, 111, 119, 32, 50, 48, 10, 112, 100, 101,
  95, 102, 108, 111, 119, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  49, 61, 49, 48, 125, 44, 36, 123, 50, 61, 51, 48, 125, 44, 36, 123,
  51, 61, 108, 97, 112, 108, 97, 99, 105, 97, 110, 125, 44, 36, 123, 52,
  61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112,
  108, 121, 32, 36, 49, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115,
  32, 111, 102, 32, 116, 104, 101, 32, 118, 101, 108, 111, 99, 105, 116, 121,
  32, 102, 108, 111, 119, 32, 39, 36, 51, 39, 32, 111, 110, 32, 105, 109,
  97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 116, 105, 109, 101,
  32, 115, 116, 101, 112, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 60,
  93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 10, 45, 45, 36,
  51, 91, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 123, 36, 50,
  47, 40, 48, 46, 48, 49, 43, 109, 97, 120, 40, 97, 98, 115, 40, 105,
  109, 41, 44, 97, 98, 115, 40, 105, 77, 41, 41, 41, 125, 10, 45, 105,
  102, 32, 36, 52, 32, 45, 43, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  32, 45, 101, 108, 115, 101, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 105,
  102, 32, 36, 52, 32, 45, 114, 109, 91, 48, 93, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 97, 32, 120, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 45, 105, 102, 32, 36, 52, 32, 45, 115, 32, 120, 44,
  36, 49, 32, 45, 101, 110, 100, 105, 102, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 114, 101, 100, 95, 101, 121, 101, 32, 58, 32,
  48, 60, 61, 95, 116, 104, 114, 101, 115, 104, 111, 108, 100, 60, 61, 49,
  48, 48, 44, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 62, 61,
  48, 44, 48, 60, 61, 97, 116, 116, 101, 110, 117, 97, 116, 105, 111, 110,
  60, 61, 49, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 116, 116,
  101, 110, 117, 97, 116, 101, 32, 114, 101, 100, 45, 101, 121, 101, 32, 101,
  102, 102, 101, 99, 116, 32, 105, 110, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  115, 58, 32, 39, 116, 104, 114, 101, 115, 104, 111, 108, 100, 61, 55, 53,
  39, 44, 32, 39, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 51,
  46, 53, 39, 32, 97, 110, 100, 32, 39, 97, 116, 116, 101, 110, 117, 97,
  116, 105, 111, 110, 61, 48, 46, 49, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 45, 114, 101, 100, 95, 101, 121, 101, 32, 44, 10, 114, 101, 100, 95,
  101, 121, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  55, 53, 125, 44, 36, 123, 50, 61, 51, 46, 53, 125, 44, 36, 123, 51,
  61, 48, 46, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65,
  116, 116, 101, 110, 117, 97, 116, 101, 32, 114, 101, 100, 45, 101, 121, 101,
  32, 101, 102, 102, 101, 99, 116, 32, 105, 110, 32, 105, 109, 97, 103, 101,
  36, 63, 44, 32, 119, 105, 116, 104, 32, 116, 104, 114, 101, 115, 104, 111,
  108, 100, 32, 36, 49, 44, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 36, 50, 32, 97, 110, 100, 32, 97, 116, 116, 101, 110, 117, 97,
  116, 105, 111, 110, 32, 36, 51, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  116, 111, 95, 114, 103, 98, 32, 45, 114, 103, 98, 50, 121, 99, 98, 99,
  114, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 115, 32, 99, 32, 45, 45, 91, 45, 49, 93, 32,
  49, 50, 56, 32, 45, 45, 103, 101, 91, 45, 49, 93, 32, 36, 49, 37,
  32, 45, 98, 91, 45, 49, 93, 32, 36, 50, 32, 45, 115, 113, 114, 116,
  91, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45,
  43, 91, 45, 49, 93, 32, 49, 10, 45, 110, 91, 45, 49, 93, 32, 36,
  51, 44, 49, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 43,
  91, 45, 49, 93, 32, 49, 50, 56, 32, 45, 97, 32, 99, 32, 45, 121,
  99, 98, 99, 114, 50, 114, 103, 98, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 114, 101, 109, 111, 118, 101, 95, 104, 111, 116, 112, 105, 120, 101, 108,
  115, 32, 58, 32, 95, 109, 97, 115, 107, 95, 115, 105, 122, 101, 62, 48,
  44, 32, 95, 116, 104, 114, 101, 115, 104, 111, 108, 100, 91, 37, 93, 62,
  48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 109, 111, 118,
  101, 32, 104, 111, 116, 32, 112, 105, 120, 101, 108, 115, 32, 105, 110, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108,
  116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 109, 97, 115, 107, 95,
  115, 105, 122, 101, 61, 51, 39, 32, 97, 110, 100, 32, 39, 116, 104, 114,
  101, 115, 104, 111, 108, 100, 61, 49, 48, 37, 39, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 110, 111, 105, 115, 101, 32, 49, 48, 44, 50, 32, 45, 45,
  114, 101, 109, 111, 118, 101, 95, 104, 111, 116, 112, 105, 120, 101, 108, 115,
  32, 44, 10, 114, 101, 109, 111, 118, 101, 95, 104, 111, 116, 112, 105, 120,
  101, 108, 115, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 123, 49,
  61, 51, 125, 62, 48, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61,
  49, 48, 37, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101,
  109, 111, 118, 101, 32, 104, 111, 116, 32, 112, 105, 120, 101, 108, 115, 32,
  105, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104,
  32, 109, 97, 115, 107, 32, 115, 105, 122, 101, 32, 36, 49, 32, 97, 110,
  100, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 36, 50, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 109, 101, 100, 105, 97, 110,
  32, 36, 49, 32, 45, 45, 45, 32, 45, 97, 98, 115, 91, 45, 49, 93,
  32, 45, 103, 101, 91, 45, 49, 93, 32, 36, 50, 10, 45, 42, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 32, 45, 61, 61, 91, 45, 49, 93, 32,
  48, 32, 45, 42, 91, 45, 51, 44, 45, 49, 93, 32, 45, 43, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 114, 101, 109, 111, 118, 101, 95, 112, 105,
  120, 101, 108, 115, 32, 58, 32, 100, 101, 110, 115, 105, 116, 121, 62, 61,
  48, 44, 95, 112, 105, 120, 101, 108, 95, 115, 117, 109, 62, 61, 48, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 109, 111, 118, 101, 32,
  40, 105, 46, 101, 46, 32, 115, 101, 116, 32, 116, 111, 32, 48, 41, 32,
  115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 100, 101, 110, 115, 105, 116,
  121, 32, 40, 105, 110, 32, 112, 101, 114, 99, 101, 110, 116, 41, 32, 111,
  102, 32, 110, 111, 110, 45, 122, 101, 114, 111, 32, 112, 105, 120, 101, 108,
  115, 32, 116, 111, 32, 48, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 83, 112, 101, 99, 105, 102, 105, 101, 100, 32, 100, 101, 110, 115, 105,
  116, 121, 32, 105, 115, 32, 114, 101, 103, 97, 114, 100, 101, 100, 32, 97,
  103, 97, 105, 110, 115, 116, 32, 39, 112, 105, 120, 101, 108, 95, 115, 117,
  109, 39, 32, 101, 120, 99, 101, 112, 116, 32, 105, 102, 32, 105, 116, 32,
  105, 115, 32, 115, 101, 116, 32, 116, 111, 32, 39, 48, 39, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 40, 105, 110, 32, 116, 104, 105, 115, 32,
  99, 97, 115, 101, 44, 32, 39, 112, 105, 120, 101, 108, 95, 115, 117, 109,
  39, 32, 104, 97, 115, 32, 100, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 32, 39, 119, 105, 100, 116, 104, 42, 104, 101, 105, 103, 104,
  116, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101,
  102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 100, 101,
  110, 115, 105, 116, 121, 61, 49, 48, 39, 44, 32, 39, 112, 105, 120, 101,
  108, 95, 115, 117, 109, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  45, 114, 101, 109, 111, 118, 101, 95, 112, 105, 120, 101, 108, 115, 32, 53,
  48, 10, 114, 101, 109, 111, 118, 101, 95, 112, 105, 120, 101, 108, 115, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 49, 48,
  125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 48, 125, 62, 61,
  48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 109, 111,
  118, 101, 32, 36, 49, 37, 32, 111, 102, 32, 110, 111, 110, 45, 122, 101,
  114, 111, 32, 112, 105, 120, 101, 108, 115, 32, 111, 102, 32, 105, 109, 97,
  103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45,
  110, 111, 114, 109, 32, 45, 103, 116, 91, 45, 49, 93, 32, 48, 10, 45,
  105, 102, 32, 36, 50, 32, 114, 97, 116, 101, 61, 123, 36, 49, 42, 36,
  50, 47, 109, 97, 120, 40, 49, 101, 45, 56, 44, 64, 123, 45, 49, 44,
  43, 125, 41, 125, 10, 45, 101, 108, 115, 101, 32, 114, 97, 116, 101, 61,
  123, 36, 49, 42, 119, 42, 104, 47, 109, 97, 120, 40, 49, 101, 45, 56,
  44, 64, 123, 45, 49, 44, 43, 125, 41, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 114, 109, 91, 45, 49, 93, 10, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44,
  49, 32, 45, 103, 101, 91, 45, 49, 93, 32, 36, 114, 97, 116, 101, 37,
  32, 45, 42, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 104, 97, 114,
  112, 101, 110, 32, 58, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 62,
  61, 48, 32, 58, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 62, 61,
  48, 44, 101, 100, 103, 101, 62, 61, 48, 44, 95, 97, 108, 112, 104, 97,
  44, 95, 115, 105, 103, 109, 97, 32, 58, 32, 40, 43, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 83, 104, 97, 114, 112, 101, 110, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 98,
  121, 32, 105, 110, 118, 101, 114, 115, 101, 32, 100, 105, 102, 102, 117, 115,
  105, 111, 110, 32, 111, 114, 32, 115, 104, 111, 99, 107, 32, 102, 105, 108,
  116, 101, 114, 115, 32, 109, 101, 116, 104, 111, 100, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 39, 101, 100, 103, 101, 39, 32, 109, 117,
  115, 116, 32, 98, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  116, 111, 32, 101, 110, 97, 98, 108, 101, 32, 115, 104, 111, 99, 107, 45,
  102, 105, 108, 116, 101, 114, 32, 109, 101, 116, 104, 111, 100, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32,
  118, 97, 108, 117, 101, 115, 58, 32, 39, 97, 108, 112, 104, 97, 61, 48,
  39, 32, 97, 110, 100, 32, 39, 115, 105, 103, 109, 97, 61, 48, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 115, 104, 97, 114, 112, 101, 110, 32,
  51, 48, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 98, 108, 117, 114, 32, 53,
  32, 45, 45, 115, 104, 97, 114, 112, 101, 110, 91, 45, 49, 93, 32, 51,
  48, 48, 44, 49, 10, 35, 64, 103, 109, 105, 99, 32, 115, 109, 111, 111,
  116, 104, 32, 58, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 62, 61,
  48, 44, 95, 115, 104, 97, 114, 112, 110, 101, 115, 115, 62, 61, 48, 44,
  95, 97, 110, 105, 115, 111, 116, 114, 111, 112, 121, 44, 95, 97, 108, 112,
  104, 97, 44, 95, 115, 105, 103, 109, 97, 44, 95, 100, 108, 62, 48, 44,
  95, 100, 97, 62, 48, 44, 95, 112, 114, 101, 99, 105, 115, 105, 111, 110,
  62, 48, 44, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110,
  44, 95, 102, 97, 115, 116, 95, 97, 112, 112, 114, 111, 120, 61, 123, 32,
  48, 32, 124, 32, 49, 32, 125, 32, 58, 32, 110, 98, 95, 105, 116, 101,
  114, 97, 116, 105, 111, 110, 115, 62, 61, 48, 44, 95, 115, 104, 97, 114,
  112, 110, 101, 115, 115, 62, 61, 48, 44, 95, 97, 110, 105, 115, 111, 116,
  114, 111, 112, 121, 44, 95, 97, 108, 112, 104, 97, 44, 95, 115, 105, 103,
  109, 97, 44, 95, 100, 116, 62, 48, 44, 48, 32, 58, 32, 91, 116, 101,
  110, 115, 111, 114, 95, 102, 105, 101, 108, 100, 93, 44, 95, 97, 109, 112,
  108, 105, 116, 117, 100, 101, 62, 61, 48, 44, 95, 100, 108, 62, 48, 44,
  95, 100, 97, 62, 48, 44, 95, 112, 114, 101, 99, 105, 115, 105, 111, 110,
  62, 48, 44, 95, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111,
  110, 44, 95, 102, 97, 115, 116, 95, 97, 112, 112, 114, 111, 120, 61, 123,
  32, 48, 32, 124, 32, 49, 32, 125, 32, 58, 32, 91, 116, 101, 110, 115,
  111, 114, 95, 102, 105, 101, 108, 100, 93, 44, 95, 110, 98, 95, 105, 116,
  101, 114, 115, 62, 61, 48, 44, 95, 100, 116, 62, 48, 44, 48, 32, 58,
  32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 109,
  111, 111, 116, 104, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 32, 97, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99,
  97, 108, 108, 121, 32, 117, 115, 105, 110, 103, 32, 100, 105, 102, 102, 117,
  115, 105, 111, 110, 32, 80, 68, 69, 39, 115, 44, 32, 119, 105, 116, 104,
  32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 102, 105, 101, 108, 100,
  32, 111, 102, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 100, 105, 102,
  102, 117, 115, 105, 111, 110, 32, 116, 101, 110, 115, 111, 114, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 97, 110, 105, 115, 111, 116,
  114, 111, 112, 121, 39, 32, 109, 117, 115, 116, 32, 98, 101, 32, 105, 110,
  32, 91, 48, 44, 49, 93, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 39,
  32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 110, 101, 97, 114,
  101, 115, 116, 32, 124, 32, 49, 61, 108, 105, 110, 101, 97, 114, 32, 124,
  32, 50, 61, 114, 117, 110, 103, 101, 45, 107, 117, 116, 116, 97, 32, 125,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117,
  108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 115, 104, 97, 114,
  112, 110, 101, 115, 115, 61, 48, 46, 55, 39, 44, 32, 39, 97, 110, 105,
  115, 111, 116, 114, 111, 112, 121, 61, 48, 46, 51, 39, 44, 32, 39, 97,
  108, 112, 104, 97, 61, 48, 46, 54, 39, 44, 32, 39, 115, 105, 103, 109,
  97, 61, 49, 46, 49, 39, 44, 32, 39, 100, 108, 61, 48, 46, 56, 39,
  44, 32, 39, 100, 97, 61, 51, 48, 39, 44, 32, 39, 112, 114, 101, 99,
  105, 115, 105, 111, 110, 61, 50, 39, 44, 32, 39, 105, 110, 116, 101, 114,
  112, 111, 108, 97, 116, 105, 111, 110, 61, 48, 39, 32, 97, 110, 100, 32,
  39, 102, 97, 115, 116, 95, 97, 112, 112, 114, 111, 120, 61, 49, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 91, 48, 93, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 51, 32, 45, 115, 109, 111, 111, 116, 104, 91, 45, 49, 93, 32,
  50, 48, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 50, 32, 45, 114, 97, 110,
  100, 91, 45, 49, 93, 32, 45, 49, 48, 48, 44, 49, 48, 48, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 50, 32, 45, 115, 109, 111, 111, 116, 104,
  91, 45, 49, 93, 32, 49, 48, 48, 44, 48, 46, 50, 44, 49, 44, 52,
  44, 52, 32, 45, 100, 111, 110, 101, 32, 45, 45, 119, 97, 114, 112, 91,
  48, 93, 32, 91, 45, 49, 93, 44, 49, 44, 49, 10, 35, 64, 103, 109,
  105, 99, 32, 115, 112, 108, 105, 116, 95, 102, 114, 101, 113, 32, 58, 32,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 62, 48, 91, 37, 93, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 112, 108, 105, 116, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 105,
  110, 116, 111, 32, 108, 111, 119, 32, 97, 110, 100, 32, 104, 105, 103, 104,
  32, 102, 114, 101, 113, 117, 101, 110, 99, 121, 32, 112, 97, 114, 116, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 115, 112, 108, 105, 116, 95, 102, 114,
  101, 113, 32, 50, 37, 10, 115, 112, 108, 105, 116, 95, 102, 114, 101, 113,
  32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 83, 112, 108, 105,
  116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 105, 110, 116, 111, 32, 108,
  111, 119, 32, 97, 110, 100, 32, 104, 105, 103, 104, 32, 102, 114, 101, 113,
  117, 101, 110, 99, 121, 32, 112, 97, 114, 116, 115, 44, 32, 119, 105, 116,
  104, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 49, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 45, 98, 32, 36, 49, 32,
  45, 45, 91, 48, 93, 32, 91, 49, 93, 32, 45, 114, 118, 32, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 115, 111, 108, 105, 100, 105, 102, 121, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 112, 108, 97, 99, 101, 32,
  116, 114, 97, 110, 115, 112, 97, 114, 101, 110, 116, 32, 114, 101, 103, 105,
  111, 110, 115, 32, 111, 102, 32, 97, 32, 82, 71, 66, 65, 32, 105, 109,
  97, 103, 101, 32, 98, 121, 32, 109, 111, 114, 112, 104, 111, 108, 111, 103,
  105, 99, 97, 108, 108, 121, 32, 105, 110, 116, 101, 114, 112, 111, 108, 97,
  116, 101, 100, 32, 99, 111, 108, 111, 114, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 103, 101, 91,
  45, 49, 93, 32, 49, 50, 48, 32, 45, 42, 91, 45, 49, 93, 32, 50,
  53, 53, 32, 45, 97, 112, 112, 101, 110, 100, 32, 99, 32, 45, 45, 115,
  111, 108, 105, 100, 105, 102, 121, 32, 45, 100, 105, 115, 112, 108, 97, 121,
  95, 114, 103, 98, 97, 10, 115, 111, 108, 105, 100, 105, 102, 121, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 112, 108, 97, 99,
  101, 32, 116, 114, 97, 110, 115, 112, 97, 114, 101, 110, 116, 32, 114, 101,
  103, 105, 111, 110, 115, 32, 111, 102, 32, 82, 71, 66, 65, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 98, 121, 32, 109, 111, 114, 112, 104, 111, 108,
  111, 103, 105, 99, 97, 108, 108, 121, 32, 105, 110, 116, 101, 114, 112, 111,
  108, 97, 116, 101, 100, 32, 99, 111, 108, 111, 114, 115, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 32,
  45, 116, 111, 95, 97, 10, 91, 45, 49, 93, 32, 45, 115, 112, 108, 105,
  116, 95, 111, 112, 97, 99, 105, 116, 121, 91, 45, 50, 93, 32, 45, 103,
  101, 91, 45, 50, 93, 32, 53, 48, 37, 32, 45, 42, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99,
  111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 45, 49, 44, 45, 49, 44, 45, 49, 44, 45, 49,
  32, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10, 45, 100, 111,
  10, 45, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51, 10,
  45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 45,
  50, 93, 32, 48, 44, 48, 44, 45, 49, 44, 45, 49, 44, 45, 49, 44,
  49, 48, 48, 48, 44, 49, 48, 48, 48, 44, 49, 48, 48, 48, 10, 45,
  101, 114, 111, 100, 101, 91, 45, 50, 93, 32, 51, 10, 45, 114, 101, 112,
  108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 45, 50, 93, 32, 48,
  44, 48, 44, 49, 48, 48, 48, 44, 49, 48, 48, 48, 44, 49, 48, 48,
  48, 44, 45, 49, 44, 45, 49, 44, 45, 49, 10, 45, 43, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 47, 91, 45, 49, 93, 32, 50, 10, 45, 106,
  91, 45, 49, 93, 32, 91, 45, 51, 93, 44, 48, 44, 48, 44, 48, 44,
  48, 44, 49, 44, 91, 45, 50, 93, 10, 45, 119, 104, 105, 108, 101, 32,
  123, 105, 109, 60, 48, 125, 10, 45, 107, 91, 45, 49, 93, 10, 45, 110,
  109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  115, 111, 108, 105, 100, 105, 102, 121, 95, 108, 105, 110, 101, 97, 114, 32,
  58, 32, 95, 115, 105, 103, 109, 97, 62, 61, 49, 44, 95, 100, 115, 105,
  103, 109, 97, 62, 61, 49, 44, 48, 60, 61, 95, 112, 114, 101, 99, 105,
  115, 105, 111, 110, 60, 61, 49, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 82, 101, 112, 108, 97, 99, 101, 32, 116, 114, 97, 110, 115, 112, 97,
  114, 101, 110, 116, 32, 114, 101, 103, 105, 111, 110, 115, 32, 111, 102, 32,
  97, 32, 82, 71, 66, 65, 32, 105, 109, 97, 103, 101, 32, 98, 121, 32,
  108, 105, 110, 101, 97, 114, 108, 121, 32, 105, 110, 116, 101, 114, 112, 111,
  108, 97, 116, 101, 100, 32, 99, 111, 108, 111, 114, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 115, 105, 103, 109, 97, 61, 49, 46, 53,
  39, 44, 32, 39, 100, 115, 105, 103, 109, 97, 61, 49, 39, 32, 97, 110,
  100, 32, 39, 112, 114, 101, 99, 105, 115, 105, 111, 110, 61, 48, 46, 53,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 108, 117, 109, 105, 110, 97,
  110, 99, 101, 32, 45, 103, 101, 91, 45, 49, 93, 32, 49, 50, 48, 32,
  45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 97, 112, 112, 101,
  110, 100, 32, 99, 32, 45, 45, 115, 111, 108, 105, 100, 105, 102, 121, 95,
  108, 105, 110, 101, 97, 114, 32, 44, 32, 45, 100, 105, 115, 112, 108, 97,
  121, 95, 114, 103, 98, 97, 10, 115, 111, 108, 105, 100, 105, 102, 121, 95,
  108, 105, 110, 101, 97, 114, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 36, 123, 49, 61, 49, 46, 53, 125, 62, 61, 49, 32, 38, 38, 32,
  36, 123, 50, 61, 49, 125, 62, 61, 49, 32, 38, 38, 32, 36, 123, 51,
  61, 48, 46, 53, 125, 62, 61, 48, 32, 38, 38, 32, 36, 51, 60, 61,
  49, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 112, 108,
  97, 99, 101, 32, 116, 114, 97, 110, 115, 112, 97, 114, 101, 110, 116, 32,
  114, 101, 103, 105, 111, 110, 115, 32, 111, 102, 32, 82, 71, 66, 65, 32,
  105, 109, 97, 103, 101, 36, 63, 32, 98, 121, 32, 108, 105, 110, 101, 97,
  114, 108, 121, 32, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 101, 100,
  32, 99, 111, 108, 111, 114, 115, 44, 32, 119, 105, 116, 104, 32, 115, 105,
  103, 109, 97, 32, 36, 49, 44, 32, 100, 115, 105, 103, 109, 97, 32, 36,
  50, 32, 97, 110, 100, 32, 112, 114, 101, 99, 105, 115, 105, 111, 110, 32,
  36, 51, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 112, 108,
  105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 10, 45, 105, 102, 32, 123,
  64, 35, 62, 49, 125, 10, 45, 103, 101, 91, 45, 49, 93, 32, 53, 48,
  37, 32, 45, 42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 10, 115, 105,
  103, 109, 97, 61, 36, 49, 32, 45, 100, 111, 10, 78, 61, 123, 118, 61,
  114, 111, 117, 110, 100, 40, 51, 42, 36, 115, 105, 103, 109, 97, 41, 59,
  109, 105, 110, 40, 51, 51, 44, 109, 97, 120, 40, 51, 44, 118, 43, 49,
  45, 40, 118, 37, 50, 41, 41, 41, 125, 10, 36, 78, 44, 36, 78, 32,
  45, 61, 91, 45, 49, 93, 32, 49, 44, 53, 48, 37, 44, 53, 48, 37,
  32, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49,
  32, 45, 42, 91, 45, 49, 93, 32, 123, 45, 49, 47, 36, 115, 105, 103,
  109, 97, 94, 50, 125, 32, 45, 101, 120, 112, 91, 45, 49, 93, 32, 45,
  110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 115, 117, 109, 91, 45, 49,
  93, 10, 45, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 45, 51, 44,
  45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 51, 93,
  10, 45, 109, 97, 120, 91, 45, 49, 93, 32, 49, 101, 45, 53, 32, 45,
  47, 91, 45, 50, 44, 45, 49, 93, 10, 45, 45, 100, 105, 108, 97, 116,
  101, 91, 45, 50, 93, 32, 123, 118, 61, 114, 111, 117, 110, 100, 40, 40,
  49, 47, 51, 45, 36, 78, 47, 54, 41, 42, 36, 51, 43, 36, 78, 47,
  50, 41, 59, 109, 97, 120, 40, 51, 44, 118, 43, 49, 45, 40, 118, 37,
  50, 41, 41, 125, 10, 45, 45, 91, 45, 51, 93, 32, 91, 45, 49, 93,
  32, 45, 42, 91, 45, 50, 93, 32, 91, 45, 51, 93, 32, 45, 114, 109,
  91, 45, 51, 93, 10, 45, 45, 91, 45, 51, 44, 45, 50, 93, 10, 115,
  105, 103, 109, 97, 61, 123, 36, 115, 105, 103, 109, 97, 42, 36, 50, 125,
  10, 45, 119, 104, 105, 108, 101, 32, 123, 33, 105, 109, 125, 10, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 115, 111, 108, 105, 100, 105, 102, 121, 95, 119, 97,
  116, 101, 114, 115, 104, 101, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 82, 101, 112, 108, 97, 99, 101, 32, 116, 114, 97, 110, 115, 112, 97,
  114, 101, 110, 116, 32, 114, 101, 103, 105, 111, 110, 115, 32, 111, 102, 32,
  82, 71, 66, 65, 32, 105, 109, 97, 103, 101, 32, 98, 121, 32, 99, 111,
  108, 111, 114, 32, 112, 114, 111, 112, 97, 103, 97, 116, 105, 111, 110, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 108, 117, 109, 105, 110, 97, 110, 99,
  101, 32, 45, 103, 101, 91, 45, 49, 93, 32, 49, 50, 48, 32, 45, 42,
  91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 97, 112, 112, 101, 110, 100,
  32, 99, 32, 45, 45, 115, 111, 108, 105, 100, 105, 102, 121, 95, 119, 97,
  116, 101, 114, 115, 104, 101, 100, 32, 45, 100, 105, 115, 112, 108, 97, 121,
  95, 114, 103, 98, 97, 10, 115, 111, 108, 105, 100, 105, 102, 121, 95, 119,
  97, 116, 101, 114, 115, 104, 101, 100, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 82, 101, 112, 108, 97, 99, 101, 32, 116, 114, 97, 110,
  115, 112, 97, 114, 101, 110, 116, 32, 114, 101, 103, 105, 111, 110, 115, 32,
  111, 102, 32, 82, 71, 66, 65, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  98, 121, 32, 99, 111, 108, 111, 114, 32, 112, 114, 111, 112, 97, 103, 97,
  116, 105, 111, 110, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115,
  112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 10, 45, 105, 102,
  32, 123, 64, 35, 62, 49, 125, 10, 45, 43, 91, 48, 93, 32, 49, 32,
  45, 103, 101, 91, 49, 93, 32, 53, 48, 37, 32, 45, 42, 91, 48, 93,
  32, 91, 49, 93, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 49,
  93, 32, 49, 32, 45, 42, 91, 49, 93, 32, 45, 49, 10, 45, 119, 97,
  116, 101, 114, 115, 104, 101, 100, 91, 48, 93, 32, 91, 49, 93, 32, 45,
  114, 109, 91, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 115, 111, 108, 118, 101, 95, 112, 111, 105, 115, 115,
  111, 110, 32, 58, 32, 34, 108, 97, 112, 108, 97, 99, 105, 97, 110, 95,
  99, 111, 109, 109, 97, 110, 100, 34, 44, 95, 110, 98, 95, 105, 116, 101,
  114, 97, 116, 105, 111, 110, 115, 62, 61, 48, 44, 95, 116, 105, 109, 101,
  95, 115, 116, 101, 112, 62, 48, 44, 95, 110, 98, 95, 115, 99, 97, 108,
  101, 115, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83,
  111, 108, 118, 101, 32, 80, 111, 105, 115, 115, 111, 110, 32, 101, 113, 117,
  97, 116, 105, 111, 110, 32, 115, 111, 32, 116, 104, 97, 116, 32, 97, 112,
  112, 108, 121, 105, 110, 103, 32, 39, 45, 108, 97, 112, 108, 97, 99, 105,
  97, 110, 91, 110, 93, 39, 32, 105, 115, 32, 99, 108, 111, 115, 101, 32,
  116, 111, 32, 116, 104, 101, 32, 114, 101, 115, 117, 108, 116, 32, 111, 102,
  32, 39, 45, 108, 97, 112, 108, 97, 99, 105, 97, 110, 95, 99, 111, 109,
  109, 97, 110, 100, 91, 110, 93, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 83, 111, 108, 118, 105, 110, 103, 32, 105, 115, 32, 112, 101,
  114, 102, 111, 114, 109, 101, 100, 32, 117, 115, 105, 110, 103, 32, 97, 32,
  109, 117, 108, 116, 105, 45, 115, 99, 97, 108, 101, 32, 103, 114, 97, 100,
  105, 101, 110, 116, 32, 100, 101, 115, 99, 101, 110, 116, 32, 97, 108, 103,
  111, 114, 105, 116, 104, 109, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 73, 102, 32, 39, 110, 98, 95, 115, 99, 97, 108, 101, 115, 61, 48,
  39, 44, 32, 116, 104, 101, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102,
  32, 115, 99, 97, 108, 101, 115, 32, 105, 115, 32, 97, 117, 116, 111, 109,
  97, 116, 105, 99, 97, 108, 108, 121, 32, 100, 101, 116, 101, 114, 109, 105,
  110, 101, 100, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101,
  102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 110,
  98, 95, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 61, 54, 48, 39,
  44, 32, 39, 100, 116, 61, 53, 39, 32, 97, 110, 100, 32, 39, 110, 98,
  95, 115, 99, 97, 108, 101, 115, 61, 48, 39, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 109, 32, 34, 102, 111, 111, 32, 58, 32, 45, 103, 114, 97, 100,
  105, 101, 110, 116, 32, 120, 34, 32, 45, 45, 115, 111, 108, 118, 101, 95,
  112, 111, 105, 115, 115, 111, 110, 32, 102, 111, 111, 32, 45, 45, 102, 111,
  111, 91, 48, 93, 32, 45, 45, 108, 97, 112, 108, 97, 99, 105, 97, 110,
  91, 49, 93, 10, 115, 111, 108, 118, 101, 95, 112, 111, 105, 115, 115, 111,
  110, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 50, 61,
  54, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 51, 61, 53, 125,
  62, 48, 32, 38, 38, 32, 36, 123, 52, 61, 48, 125, 62, 61, 48, 34,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 83, 111, 108, 118, 101, 32,
  80, 111, 105, 115, 115, 111, 110, 32, 101, 113, 117, 97, 116, 105, 111, 110,
  32, 102, 111, 114, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 102, 111,
  114, 32, 108, 97, 112, 108, 97, 99, 105, 97, 110, 32, 99, 111, 109, 109,
  97, 110, 100, 32, 39, 36, 49, 39, 44, 32, 119, 105, 116, 104, 32, 36,
  50, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 44, 32, 116, 105,
  109, 101, 32, 115, 116, 101, 112, 32, 36, 51, 32, 97, 110, 100, 32, 34,
  64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 40, 36, 52, 61, 61, 48,
  41, 44, 36, 52, 44, 97, 117, 116, 111, 125, 34, 32, 115, 99, 97, 108,
  101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 91, 48, 93, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 102, 40, 36, 52, 44, 36,
  52, 44, 105, 110, 116, 40, 109, 97, 120, 40, 108, 111, 103, 50, 40, 109,
  97, 120, 40, 119, 44, 104, 41, 41, 45, 49, 44, 49, 41, 41, 41, 125,
  10, 102, 61, 123, 50, 94, 36, 60, 125, 10, 45, 114, 91, 49, 93, 32,
  64, 123, 48, 44, 109, 97, 120, 40, 49, 44, 119, 47, 36, 102, 41, 125,
  44, 64, 123, 48, 44, 109, 97, 120, 40, 49, 44, 104, 47, 36, 102, 41,
  125, 44, 49, 44, 49, 48, 48, 37, 44, 51, 10, 45, 45, 114, 91, 48,
  93, 32, 91, 49, 93, 44, 50, 32, 45, 108, 91, 45, 49, 93, 32, 45,
  36, 49, 32, 45, 107, 91, 48, 93, 32, 45, 101, 110, 100, 108, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 36, 50, 32, 45, 45, 108, 97, 112, 108,
  97, 99, 105, 97, 110, 91, 45, 50, 93, 32, 45, 45, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 32, 45, 42, 91, 45, 49, 93, 32, 123, 36, 51,
  47, 109, 97, 120, 40, 49, 101, 45, 56, 44, 97, 98, 115, 40, 105, 109,
  41, 44, 97, 98, 115, 40, 105, 77, 41, 41, 125, 32, 45, 43, 91, 45,
  51, 44, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 48, 93,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 112, 108, 105, 116, 95, 100,
  101, 116, 97, 105, 108, 115, 32, 58, 32, 95, 110, 98, 95, 115, 99, 97,
  108, 101, 115, 62, 48, 44, 95, 98, 97, 115, 101, 95, 115, 99, 97, 108,
  101, 91, 37, 93, 62, 61, 48, 44, 95, 100, 101, 116, 97, 105, 108, 95,
  115, 99, 97, 108, 101, 91, 37, 93, 62, 61, 48, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 83, 112, 108, 105, 116, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 105, 110, 116, 111, 32,
  39, 110, 98, 95, 115, 99, 97, 108, 101, 115, 39, 32, 115, 112, 97, 116,
  105, 97, 108, 32, 115, 99, 97, 108, 101, 115, 32, 40, 103, 97, 117, 115,
  115, 105, 97, 110, 32, 112, 121, 114, 97, 109, 105, 100, 115, 41, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116,
  32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 110, 98, 95, 115, 99, 97,
  108, 101, 115, 61, 52, 39, 44, 32, 39, 98, 97, 115, 101, 95, 115, 99,
  97, 108, 101, 61, 50, 37, 39, 32, 97, 110, 100, 32, 39, 100, 101, 116,
  97, 105, 108, 95, 115, 99, 97, 108, 101, 61, 48, 46, 53, 37, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 115, 112, 108, 105, 116, 95, 100, 101, 116,
  97, 105, 108, 115, 32, 44, 10, 115, 112, 108, 105, 116, 95, 100, 101, 116,
  97, 105, 108, 115, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105,
  115, 105, 110, 116, 40, 36, 123, 49, 61, 52, 125, 41, 32, 38, 38, 32,
  36, 49, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 50, 37, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 123, 51, 61, 48, 46, 53, 37, 125, 62,
  61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 83, 112, 108,
  105, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 117, 115, 105, 110, 103,
  32, 36, 49, 32, 115, 112, 97, 116, 105, 97, 108, 32, 115, 99, 97, 108,
  101, 115, 32, 119, 105, 116, 104, 32, 98, 97, 115, 101, 32, 115, 99, 97,
  108, 101, 32, 36, 50, 32, 97, 110, 100, 32, 100, 101, 116, 97, 105, 108,
  32, 115, 99, 97, 108, 101, 32, 36, 51, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  60, 93, 10, 115, 115, 61, 123, 109, 97, 120, 40, 48, 46, 51, 44, 105,
  102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92,
  32, 36, 50, 125, 44, 36, 50, 42, 109, 97, 120, 40, 119, 44, 104, 41,
  44, 36, 50, 41, 41, 125, 10, 115, 101, 61, 123, 109, 97, 120, 40, 48,
  46, 51, 44, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99,
  101, 110, 116, 92, 32, 36, 51, 125, 44, 36, 51, 42, 109, 97, 120, 40,
  119, 44, 104, 41, 44, 36, 51, 41, 41, 125, 10, 100, 115, 61, 123, 36,
  115, 101, 45, 36, 115, 115, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 36, 49, 45, 49, 125, 32, 45, 45, 98, 91, 45, 49, 93, 32, 123,
  36, 115, 115, 43, 36, 62, 42, 36, 100, 115, 47, 40, 36, 49, 45, 50,
  41, 125, 32, 45, 45, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45,
  114, 118, 91, 45, 50, 44, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 115, 116, 114, 117, 99, 116, 117, 114,
  101, 116, 101, 110, 115, 111, 114, 115, 32, 58, 32, 95, 115, 99, 104, 101,
  109, 101, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 115, 116,
  114, 117, 99, 116, 117, 114, 101, 32, 116, 101, 110, 115, 111, 114, 32, 102,
  105, 101, 108, 100, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 39, 115, 99, 104, 101, 109, 101, 39, 32, 99, 97, 110, 32, 98,
  101, 32, 123, 32, 48, 61, 99, 101, 110, 116, 101, 114, 101, 100, 32, 124,
  32, 49, 61, 102, 111, 114, 119, 97, 114, 100, 45, 98, 97, 99, 107, 119,
  97, 114, 100, 49, 32, 124, 32, 50, 61, 102, 111, 114, 119, 97, 114, 100,
  45, 98, 97, 99, 107, 119, 97, 114, 100, 50, 32, 125, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 58, 32, 39, 115, 99, 104, 101, 109, 101, 61, 50, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 115, 116, 114, 117, 99, 116, 117, 114,
  101, 116, 101, 110, 115, 111, 114, 115, 32, 45, 97, 98, 115, 32, 45, 112,
  111, 119, 32, 48, 46, 50, 10, 35, 64, 103, 109, 105, 99, 32, 116, 118,
  95, 102, 108, 111, 119, 32, 58, 32, 95, 110, 98, 95, 105, 116, 101, 114,
  62, 61, 48, 44, 95, 100, 116, 44, 95, 115, 101, 113, 117, 101, 110, 99,
  101, 95, 102, 108, 97, 103, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32,
  105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 111, 102, 32, 116, 104,
  101, 32, 116, 111, 116, 97, 108, 32, 118, 97, 114, 105, 97, 116, 105, 111,
  110, 32, 102, 108, 111, 119, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117,
  101, 115, 58, 32, 39, 110, 98, 95, 105, 116, 101, 114, 61, 49, 48, 39,
  44, 32, 39, 100, 116, 61, 51, 48, 39, 32, 97, 110, 100, 32, 39, 107,
  101, 101, 112, 95, 115, 101, 113, 117, 101, 110, 99, 101, 61, 48, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 116, 118, 95, 102, 108, 111, 119, 32,
  52, 48, 10, 116, 118, 95, 102, 108, 111, 119, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 49, 61, 49, 48, 125, 44, 36, 123, 50, 61, 51,
  48, 125, 44, 36, 123, 51, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 65, 112, 112, 108, 121, 32, 36, 49, 32, 105, 116, 101, 114,
  97, 116, 105, 111, 110, 115, 32, 111, 102, 32, 116, 104, 101, 32, 116, 111,
  116, 97, 108, 32, 118, 97, 114, 105, 97, 116, 105, 111, 110, 32, 102, 108,
  111, 119, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119,
  105, 116, 104, 32, 116, 105, 109, 101, 32, 115, 116, 101, 112, 32, 36, 50,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 112, 100, 101, 95, 102, 108, 111,
  119, 32, 36, 49, 44, 36, 50, 44, 99, 117, 114, 118, 97, 116, 117, 114,
  101, 44, 36, 51, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 117, 110, 115, 104, 97, 114, 112, 32, 58, 32, 114, 97, 100, 105, 117,
  115, 91, 37, 93, 62, 61, 48, 44, 95, 97, 109, 111, 117, 110, 116, 62,
  61, 48, 44, 95, 116, 104, 114, 101, 115, 104, 111, 108, 100, 91, 37, 93,
  62, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112,
  108, 121, 32, 117, 110, 115, 104, 97, 114, 112, 32, 109, 97, 115, 107, 32,
  111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 97, 109,
  111, 117, 110, 116, 61, 50, 39, 32, 97, 110, 100, 32, 39, 116, 104, 114,
  101, 115, 104, 111, 108, 100, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 98, 108, 117, 114, 32, 51, 32, 45, 45, 117, 110, 115, 104, 97, 114,
  112, 32, 49, 46, 53, 44, 49, 53, 32, 45, 99, 117, 116, 32, 48, 44,
  50, 53, 53, 10, 117, 110, 115, 104, 97, 114, 112, 32, 58, 32, 45, 99,
  104, 101, 99, 107, 32, 34, 36, 123, 50, 61, 50, 125, 62, 61, 48, 34,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 48, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 117, 110, 115,
  104, 97, 114, 112, 32, 109, 97, 115, 107, 32, 111, 110, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 114, 97, 100, 105, 117,
  115, 32, 36, 49, 44, 32, 97, 109, 111, 117, 110, 116, 32, 36, 50, 32,
  97, 110, 100, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 36, 51,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 10, 45, 45, 98, 91, 36, 62, 93, 32, 36, 49, 32, 45, 45,
  91, 45, 49, 93, 32, 91, 36, 62, 93, 10, 45, 105, 102, 32, 36, 51,
  32, 45, 45, 110, 111, 114, 109, 91, 45, 49, 93, 32, 45, 103, 101, 91,
  45, 49, 93, 32, 36, 51, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 42, 91, 45, 49, 93, 32, 36,
  50, 32, 45, 45, 91, 36, 62, 44, 45, 49, 93, 10, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 117, 110,
  115, 104, 97, 114, 112, 95, 111, 99, 116, 97, 118, 101, 32, 58, 32, 95,
  110, 98, 95, 115, 99, 97, 108, 101, 115, 62, 48, 44, 95, 114, 97, 100,
  105, 117, 115, 91, 37, 93, 62, 61, 48, 44, 95, 97, 109, 111, 117, 110,
  116, 62, 61, 48, 44, 116, 104, 114, 101, 115, 104, 111, 108, 100, 91, 37,
  93, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112,
  112, 108, 121, 32, 111, 99, 116, 97, 118, 101, 32, 115, 104, 97, 114, 112,
  101, 110, 105, 110, 103, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  115, 58, 32, 39, 110, 98, 95, 115, 99, 97, 108, 101, 115, 61, 52, 39,
  44, 32, 39, 114, 97, 100, 105, 117, 115, 61, 49, 39, 44, 32, 39, 97,
  109, 111, 117, 110, 116, 61, 50, 39, 32, 97, 110, 100, 32, 39, 116, 104,
  114, 101, 115, 104, 111, 108, 100, 61, 48, 39, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 98, 108, 117, 114, 32, 51, 32, 45, 45, 117, 110, 115, 104, 97,
  114, 112, 95, 111, 99, 116, 97, 118, 101, 32, 52, 44, 53, 44, 49, 53,
  32, 45, 99, 117, 116, 32, 48, 44, 50, 53, 53, 10, 117, 110, 115, 104,
  97, 114, 112, 95, 111, 99, 116, 97, 118, 101, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 36, 123, 49, 61, 52, 125, 62, 48, 32, 38, 38,
  32, 36, 123, 51, 61, 50, 125, 62, 61, 48, 34, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 50, 61, 49, 125, 44, 36, 123, 52, 61, 48, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 111,
  99, 116, 97, 118, 101, 32, 115, 104, 97, 114, 112, 101, 110, 105, 110, 103,
  32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116,
  104, 32, 36, 49, 32, 115, 99, 97, 108, 101, 115, 44, 32, 114, 97, 100,
  105, 117, 115, 32, 36, 50, 44, 32, 97, 109, 111, 117, 110, 116, 32, 36,
  51, 32, 97, 110, 100, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32,
  36, 52, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64,
  123, 48, 44, 110, 125, 10, 45, 45, 102, 32, 48, 32, 119, 101, 105, 103,
  104, 116, 61, 48, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 10,
  45, 45, 117, 110, 115, 104, 97, 114, 112, 91, 48, 93, 32, 123, 36, 50,
  42, 50, 94, 45, 64, 123, 60, 44, 45, 49, 125, 125, 44, 36, 51, 44,
  36, 52, 32, 45, 42, 91, 45, 49, 93, 32, 123, 50, 94, 45, 36, 62,
  125, 32, 119, 101, 105, 103, 104, 116, 61, 123, 36, 119, 101, 105, 103, 104,
  116, 43, 50, 94, 45, 36, 62, 125, 32, 45, 43, 91, 49, 44, 45, 49,
  93, 10, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 93, 32, 45,
  47, 32, 36, 119, 101, 105, 103, 104, 116, 10, 45, 110, 109, 32, 36, 110,
  109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 118, 97, 110, 118,
  108, 105, 101, 116, 32, 58, 32, 115, 116, 100, 95, 118, 97, 114, 105, 97,
  116, 105, 111, 110, 62, 61, 48, 91, 37, 93, 44, 111, 114, 100, 101, 114,
  61, 123, 32, 48, 32, 124, 32, 49, 32, 124, 32, 50, 32, 124, 32, 51,
  32, 125, 44, 97, 120, 105, 115, 61, 123, 32, 120, 32, 124, 32, 121, 32,
  124, 32, 122, 32, 124, 32, 99, 32, 125, 44, 95, 98, 111, 117, 110, 100,
  97, 114, 121, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 65, 112, 112, 108, 121, 32, 86, 97, 110, 118, 108, 105, 101,
  116, 32, 114, 101, 99, 117, 114, 115, 105, 118, 101, 32, 102, 105, 108, 116,
  101, 114, 32, 119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101,
  100, 32, 115, 116, 97, 110, 100, 97, 114, 100, 32, 100, 101, 118, 105, 97,
  116, 105, 111, 110, 44, 32, 111, 114, 100, 101, 114, 44, 32, 97, 120, 105,
  115, 32, 97, 110, 100, 32, 98, 111, 114, 100, 101, 114, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 115,
  32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 98,
  111, 117, 110, 100, 97, 114, 121, 39, 32, 99, 97, 110, 32, 98, 101, 32,
  123, 32, 48, 61, 100, 105, 114, 105, 99, 104, 108, 101, 116, 32, 124, 32,
  49, 61, 110, 101, 117, 109, 97, 110, 110, 32, 125, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 58, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 61, 49,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 118, 97, 110, 118, 108, 105,
  101, 116, 32, 51, 44, 49, 44, 120, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45,
  118, 97, 110, 118, 108, 105, 101, 116, 32, 51, 48, 44, 48, 44, 120, 32,
  45, 118, 97, 110, 118, 108, 105, 101, 116, 91, 45, 50, 93, 32, 51, 48,
  44, 48, 44, 121, 32, 45, 97, 100, 100, 10, 35, 64, 103, 109, 105, 99,
  32, 119, 97, 116, 101, 114, 109, 97, 114, 107, 95, 102, 111, 117, 114, 105,
  101, 114, 32, 58, 32, 116, 101, 120, 116, 44, 95, 115, 105, 122, 101, 62,
  48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 100, 100, 32, 97,
  32, 116, 101, 120, 116, 117, 97, 108, 32, 119, 97, 116, 101, 114, 109, 97,
  114, 107, 32, 105, 110, 32, 116, 104, 101, 32, 102, 114, 101, 113, 117, 101,
  110, 99, 121, 32, 100, 111, 109, 97, 105, 110, 32, 111, 102, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32,
  118, 97, 108, 117, 101, 58, 32, 39, 115, 105, 122, 101, 61, 51, 50, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 45, 119, 97, 116, 101, 114, 109, 97,
  114, 107, 95, 102, 111, 117, 114, 105, 101, 114, 32, 34, 87, 97, 116, 101,
  114, 109, 97, 114, 107, 101, 100, 33, 34, 32, 45, 45, 100, 105, 115, 112,
  108, 97, 121, 95, 102, 102, 116, 32, 45, 114, 101, 109, 111, 118, 101, 91,
  45, 51, 44, 45, 49, 93, 32, 45, 110, 111, 114, 109, 97, 108, 105, 122,
  101, 32, 48, 44, 50, 53, 53, 32, 45, 97, 112, 112, 101, 110, 100, 91,
  45, 52, 44, 45, 50, 93, 32, 121, 32, 45, 97, 112, 112, 101, 110, 100,
  91, 45, 50, 44, 45, 49, 93, 32, 121, 10, 119, 97, 116, 101, 114, 109,
  97, 114, 107, 95, 102, 111, 117, 114, 105, 101, 114, 32, 58, 32, 45, 99,
  104, 101, 99, 107, 32, 36, 123, 50, 61, 51, 50, 125, 62, 48, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 65, 100, 100, 32, 116, 101, 120, 116,
  117, 97, 108, 32, 119, 97, 116, 101, 114, 109, 97, 114, 107, 32, 39, 36,
  49, 39, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101, 32, 36, 50, 32,
  105, 110, 32, 116, 104, 101, 32, 102, 114, 101, 113, 117, 101, 110, 99, 121,
  32, 100, 111, 109, 97, 105, 110, 32, 111, 102, 32, 105, 109, 97, 103, 101,
  36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 105, 91, 48, 93, 32,
  48, 32, 45, 116, 91, 48, 93, 32, 34, 36, 49, 34, 44, 48, 44, 48,
  44, 36, 50, 44, 49, 44, 49, 32, 45, 103, 101, 91, 48, 93, 32, 48,
  46, 53, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 48, 93, 32,
  48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125,
  32, 119, 50, 61, 123, 105, 110, 116, 40, 119, 47, 50, 41, 125, 32, 104,
  50, 61, 123, 105, 110, 116, 40, 104, 47, 50, 41, 125, 10, 45, 102, 102,
  116, 91, 45, 49, 93, 10, 45, 115, 104, 105, 102, 116, 91, 45, 50, 44,
  45, 49, 93, 32, 36, 119, 50, 44, 36, 104, 50, 44, 48, 44, 48, 44,
  50, 10, 91, 48, 93, 44, 91, 48, 93, 44, 49, 44, 123, 115, 125, 10,
  45, 106, 91, 45, 51, 44, 45, 50, 93, 32, 91, 45, 49, 93, 44, 51,
  44, 51, 44, 48, 44, 48, 44, 49, 44, 91, 48, 93, 10, 45, 109, 105,
  114, 114, 111, 114, 91, 48, 93, 32, 120, 10, 45, 106, 91, 45, 51, 44,
  45, 50, 93, 32, 91, 45, 49, 93, 44, 123, 64, 123, 45, 50, 44, 119,
  125, 45, 50, 45, 64, 123, 48, 44, 119, 125, 125, 44, 51, 44, 48, 44,
  48, 44, 49, 44, 91, 48, 93, 10, 45, 109, 105, 114, 114, 111, 114, 91,
  48, 93, 32, 121, 10, 45, 106, 91, 45, 51, 44, 45, 50, 93, 32, 91,
  45, 49, 93, 44, 123, 64, 123, 45, 50, 44, 119, 125, 45, 50, 45, 64,
  123, 48, 44, 119, 125, 125, 44, 123, 64, 123, 45, 50, 44, 104, 125, 45,
  50, 45, 64, 123, 48, 44, 104, 125, 125, 44, 48, 44, 48, 44, 49, 44,
  91, 48, 93, 10, 45, 109, 105, 114, 114, 111, 114, 91, 48, 93, 32, 120,
  10, 45, 106, 91, 45, 51, 44, 45, 50, 93, 32, 91, 45, 49, 93, 44,
  51, 44, 123, 64, 123, 45, 50, 44, 104, 125, 45, 50, 45, 64, 123, 48,
  44, 104, 125, 125, 44, 48, 44, 48, 44, 49, 44, 91, 48, 93, 10, 45,
  109, 105, 114, 114, 111, 114, 91, 48, 93, 32, 121, 10, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 115, 104, 105, 102, 116, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 36, 119, 50, 44, 45, 36, 104, 50, 44, 48, 44, 48, 44,
  50, 10, 45, 105, 102, 102, 116, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 109, 118, 91, 45, 49, 93, 32, 49,
  32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 48, 93, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 119, 97, 116, 101, 114, 115,
  104, 101, 100, 32, 58, 32, 91, 112, 114, 105, 111, 114, 105, 116, 121, 95,
  105, 109, 97, 103, 101, 93, 44, 95, 102, 105, 108, 108, 95, 108, 105, 110,
  101, 115, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 32, 58, 32, 40,
  43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112,
  117, 116, 101, 32, 116, 104, 101, 32, 119, 97, 116, 101, 114, 115, 104, 101,
  100, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32, 111, 102, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116,
  32, 118, 97, 108, 117, 101, 58, 32, 39, 102, 105, 108, 108, 95, 108, 105,
  110, 101, 115, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 52, 48, 48, 44, 52, 48, 48, 32, 45, 110, 111, 105, 115,
  101, 32, 48, 46, 50, 44, 50, 32, 45, 45, 100, 105, 115, 116, 97, 110,
  99, 101, 32, 49, 32, 45, 109, 117, 108, 91, 45, 49, 93, 32, 45, 49,
  32, 45, 108, 97, 98, 101, 108, 91, 45, 50, 93, 32, 45, 119, 97, 116,
  101, 114, 115, 104, 101, 100, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32,
  45, 109, 111, 100, 91, 45, 50, 93, 32, 50, 53, 54, 32, 45, 109, 97,
  112, 91, 45, 50, 93, 32, 48, 32, 45, 114, 101, 118, 101, 114, 115, 101,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 58, 32, 70, 101, 97, 116, 117,
  114, 101, 115, 32, 101, 120, 116, 114, 97, 99, 116, 105, 111, 110, 10, 35,
  64, 103, 109, 105, 99, 32, 97, 114, 101, 97, 32, 58, 32, 116, 111, 108,
  101, 114, 97, 110, 99, 101, 62, 61, 48, 44, 105, 115, 95, 104, 105, 103,
  104, 95, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 61, 123,
  32, 48, 32, 124, 32, 49, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 97, 114, 101, 97, 32, 111,
  102, 32, 99, 111, 110, 110, 101, 99, 116, 101, 100, 32, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 115, 32, 105, 110, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117,
  101, 115, 58, 32, 39, 105, 115, 95, 104, 105, 103, 104, 95, 99, 111, 110,
  110, 101, 99, 116, 105, 118, 105, 116, 121, 61, 48, 39, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 115,
  116, 101, 110, 99, 105, 108, 91, 45, 49, 93, 32, 49, 32, 45, 45, 97,
  114, 101, 97, 32, 48, 10, 97, 114, 101, 97, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 36, 49, 62, 61, 48, 34, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 50, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 97, 114, 101, 97, 32, 111,
  102, 32, 99, 111, 110, 110, 101, 99, 116, 101, 100, 32, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 115, 32, 105, 110, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 119, 105, 116, 104, 32, 116, 111, 108, 101, 114, 97, 110, 99,
  101, 32, 36, 49, 32, 97, 110, 100, 32, 34, 64, 123, 45, 97, 114, 103,
  92, 32, 49, 43, 33, 36, 50, 44, 104, 105, 103, 104, 44, 108, 111, 119,
  125, 34, 32, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 32, 99, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 97, 98, 101, 108, 91,
  36, 62, 93, 32, 36, 49, 44, 36, 50, 32, 110, 98, 61, 64, 123, 36,
  62, 44, 49, 43, 105, 77, 125, 32, 45, 45, 104, 105, 115, 116, 111, 103,
  114, 97, 109, 91, 36, 62, 93, 32, 36, 110, 98, 44, 48, 44, 123, 36,
  110, 98, 45, 49, 125, 32, 45, 109, 97, 112, 91, 36, 62, 93, 32, 91,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 100, 111, 110,
  101, 10, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 97,
  114, 101, 97, 95, 102, 103, 32, 58, 32, 116, 111, 108, 101, 114, 97, 110,
  99, 101, 62, 61, 48, 44, 105, 115, 95, 104, 105, 103, 104, 95, 99, 111,
  110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 61, 123, 32, 48, 32, 124,
  32, 49, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111,
  109, 112, 117, 116, 101, 32, 97, 114, 101, 97, 32, 111, 102, 32, 99, 111,
  110, 110, 101, 99, 116, 101, 100, 32, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 115, 32, 102, 111, 114, 32, 110, 111, 110, 45, 122, 101, 114, 111, 32,
  118, 97, 108, 117, 101, 115, 32, 105, 110, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 83, 105, 109, 105, 108, 97, 114, 32, 116, 111, 32, 39,
  45, 97, 114, 101, 97, 39, 32, 101, 120, 99, 101, 112, 116, 32, 116, 104,
  97, 116, 32, 48, 45, 118, 97, 108, 117, 101, 100, 32, 112, 105, 120, 101,
  108, 115, 32, 97, 114, 101, 32, 110, 111, 116, 32, 99, 111, 110, 115, 105,
  100, 101, 114, 101, 100, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 105, 115, 95, 104, 105, 103, 104, 95, 99, 111, 110, 110, 101, 99, 116,
  105, 118, 105, 116, 121, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 115, 116, 101, 110, 99,
  105, 108, 91, 45, 49, 93, 32, 49, 32, 45, 45, 97, 114, 101, 97, 95,
  102, 103, 32, 48, 10, 97, 114, 101, 97, 95, 102, 103, 32, 58, 32, 45,
  99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48, 34, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 50, 61, 48, 125, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 97, 114, 101, 97,
  32, 111, 102, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 32, 99,
  111, 110, 110, 101, 99, 116, 101, 100, 32, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 115, 32, 105, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32,
  119, 105, 116, 104, 32, 116, 111, 108, 101, 114, 97, 110, 99, 101, 32, 36,
  49, 32, 97, 110, 100, 32, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49,
  43, 33, 36, 50, 44, 104, 105, 103, 104, 44, 108, 111, 119, 125, 34, 32,
  99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 32, 45, 115, 32, 99, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 97, 98, 101, 108, 95, 102, 103, 91,
  36, 62, 93, 32, 36, 49, 44, 36, 50, 32, 110, 98, 61, 64, 123, 36,
  62, 44, 49, 43, 105, 77, 125, 32, 45, 45, 104, 105, 115, 116, 111, 103,
  114, 97, 109, 91, 36, 62, 93, 32, 36, 110, 98, 44, 48, 44, 123, 36,
  110, 98, 45, 49, 125, 32, 45, 61, 91, 45, 49, 93, 32, 48, 32, 45,
  109, 97, 112, 91, 36, 62, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 97, 32, 99, 32,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 97, 116, 95, 108, 105, 110, 101, 32,
  58, 32, 120, 48, 91, 37, 93, 44, 121, 48, 91, 37, 93, 44, 122, 48,
  91, 37, 93, 44, 120, 49, 91, 37, 93, 44, 121, 49, 91, 37, 93, 44,
  122, 49, 91, 37, 93, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82,
  101, 116, 114, 105, 101, 118, 101, 32, 112, 105, 120, 101, 108, 115, 32, 111,
  102, 32, 116, 104, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 32, 98, 101, 108, 111, 110, 103, 105, 110, 103, 32,
  116, 111, 32, 116, 104, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100,
  32, 108, 105, 110, 101, 32, 40, 120, 48, 44, 121, 48, 44, 122, 48, 41,
  45, 40, 120, 49, 44, 121, 49, 44, 122, 49, 41, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 45, 97, 116, 95, 108, 105, 110, 101, 32, 48, 44, 48, 44,
  48, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48, 10, 97, 116,
  95, 108, 105, 110, 101, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36,
  123, 55, 61, 49, 48, 48, 37, 125, 62, 61, 48, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 82, 101, 116, 114, 105, 101, 118, 101, 32, 112, 105,
  120, 101, 108, 115, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 98, 101, 108, 111, 110, 103, 105, 110, 103, 32, 116, 111, 32, 108, 105,
  110, 101, 32, 40, 36, 49, 44, 36, 50, 44, 36, 51, 41, 45, 40, 36,
  52, 44, 36, 53, 44, 36, 54, 41, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 120, 48, 61, 123, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112,
  101, 114, 99, 101, 110, 116, 92, 32, 36, 49, 125, 44, 40, 119, 45, 49,
  41, 42, 36, 49, 44, 36, 49, 41, 125, 10, 121, 48, 61, 123, 105, 102,
  40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32,
  36, 50, 125, 44, 40, 104, 45, 49, 41, 42, 36, 50, 44, 36, 50, 41,
  125, 10, 122, 48, 61, 123, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112,
  101, 114, 99, 101, 110, 116, 92, 32, 36, 51, 125, 44, 40, 100, 45, 49,
  41, 42, 36, 51, 44, 36, 51, 41, 125, 10, 120, 49, 61, 123, 105, 102,
  40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32,
  36, 52, 125, 44, 40, 119, 45, 49, 41, 42, 36, 52, 44, 36, 52, 41,
  125, 10, 121, 49, 61, 123, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112,
  101, 114, 99, 101, 110, 116, 92, 32, 36, 53, 125, 44, 40, 104, 45, 49,
  41, 42, 36, 53, 44, 36, 53, 41, 125, 10, 122, 49, 61, 123, 105, 102,
  40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32,
  36, 54, 125, 44, 40, 100, 45, 49, 41, 42, 36, 54, 44, 36, 54, 41,
  125, 10, 40, 36, 120, 48, 44, 36, 120, 49, 94, 36, 121, 48, 44, 36,
  121, 49, 94, 36, 122, 48, 44, 36, 122, 49, 41, 10, 45, 114, 91, 45,
  49, 93, 32, 123, 49, 43, 109, 97, 120, 40, 97, 98, 115, 40, 36, 120,
  49, 45, 36, 120, 48, 41, 44, 97, 98, 115, 40, 36, 121, 49, 45, 36,
  121, 48, 41, 44, 97, 98, 115, 40, 36, 122, 49, 45, 36, 122, 48, 41,
  41, 125, 44, 49, 44, 49, 44, 51, 44, 51, 10, 45, 114, 111, 117, 110,
  100, 91, 45, 49, 93, 32, 49, 32, 45, 119, 97, 114, 112, 91, 48, 93,
  32, 91, 45, 49, 93, 44, 48, 44, 48, 44, 48, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 98, 97, 114, 121,
  99, 101, 110, 116, 101, 114, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 98, 97, 114, 121,
  99, 101, 110, 116, 101, 114, 32, 118, 101, 99, 116, 111, 114, 32, 111, 102,
  32, 112, 105, 120, 101, 108, 32, 118, 97, 108, 117, 101, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 50, 53, 54, 44, 50, 53,
  54, 32, 45, 101, 108, 108, 105, 112, 115, 101, 32, 53, 48, 37, 44, 53,
  48, 37, 44, 50, 48, 37, 44, 50, 48, 37, 44, 48, 44, 49, 44, 49,
  32, 45, 100, 101, 102, 111, 114, 109, 32, 50, 48, 32, 45, 45, 98, 97,
  114, 121, 99, 101, 110, 116, 101, 114, 32, 45, 45, 101, 108, 108, 105, 112,
  115, 101, 91, 45, 50, 93, 32, 64, 123, 45, 49, 44, 48, 44, 49, 125,
  44, 53, 44, 53, 44, 48, 44, 49, 48, 10, 98, 97, 114, 121, 99, 101,
  110, 116, 101, 114, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 98, 97, 114, 121,
  99, 101, 110, 116, 101, 114, 32, 118, 101, 99, 116, 111, 114, 32, 111, 102,
  32, 112, 105, 120, 101, 108, 32, 118, 97, 108, 117, 101, 115, 32, 111, 102,
  32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 110, 111, 114, 109, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 98,
  125, 10, 115, 117, 109, 61, 64, 123, 45, 49, 44, 43, 125, 10, 45, 105,
  102, 32, 123, 36, 115, 117, 109, 62, 48, 125, 10, 45, 105, 102, 32, 123,
  100, 62, 49, 125, 32, 45, 45, 42, 32, 39, 122, 39, 32, 122, 61, 64,
  123, 45, 49, 44, 43, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  101, 108, 115, 101, 32, 122, 61, 48, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 104, 62, 49, 125, 32, 45, 45, 42, 32, 39, 121,
  39, 32, 121, 61, 64, 123, 45, 49, 44, 43, 125, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 101, 108, 115, 101, 32, 121, 61, 48, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 42, 32, 39, 120, 39, 32, 120, 61, 64, 123,
  45, 49, 44, 43, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 40, 123,
  36, 120, 47, 36, 115, 117, 109, 125, 59, 123, 36, 121, 47, 36, 115, 117,
  109, 125, 59, 123, 36, 122, 47, 36, 115, 117, 109, 125, 41, 10, 45, 101,
  108, 115, 101, 32, 40, 123, 119, 47, 50, 125, 44, 123, 104, 47, 50, 125,
  44, 123, 100, 47, 50, 125, 41, 32, 45, 114, 109, 91, 45, 50, 93, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 110, 109, 32, 34, 91, 98, 97, 114,
  121, 99, 101, 110, 116, 101, 114, 32, 111, 102, 32, 39, 34, 36, 110, 109,
  34, 39, 93, 34, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 100, 101, 116,
  101, 99, 116, 95, 115, 107, 105, 110, 32, 58, 32, 48, 60, 61, 116, 111,
  108, 101, 114, 97, 110, 99, 101, 60, 61, 49, 44, 95, 115, 107, 105, 110,
  95, 120, 44, 95, 115, 107, 105, 110, 95, 121, 44, 95, 115, 107, 105, 110,
  95, 114, 97, 100, 105, 117, 115, 62, 61, 48, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 101, 116, 101, 99, 116, 32, 115, 107, 105, 110, 32,
  105, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 99, 111, 108, 111,
  114, 32, 105, 109, 97, 103, 101, 115, 32, 97, 110, 100, 32, 111, 117, 116,
  112, 117, 116, 32, 97, 110, 32, 97, 112, 112, 97, 114, 116, 101, 110, 97,
  110, 99, 101, 32, 112, 114, 111, 98, 97, 98, 105, 108, 105, 116, 121, 32,
  109, 97, 112, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101,
  116, 101, 99, 116, 105, 111, 110, 32, 105, 115, 32, 112, 101, 114, 102, 111,
  114, 109, 101, 100, 32, 117, 115, 105, 110, 103, 32, 67, 98, 67, 114, 32,
  99, 104, 114, 111, 109, 97, 116, 105, 99, 105, 116, 121, 32, 100, 97, 116,
  97, 32, 111, 102, 32, 115, 107, 105, 110, 32, 112, 105, 120, 101, 108, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 102, 32, 97, 114,
  103, 117, 109, 101, 110, 116, 115, 32, 39, 115, 107, 105, 110, 95, 120, 39,
  44, 32, 39, 115, 107, 105, 110, 95, 121, 39, 32, 97, 110, 100, 32, 39,
  115, 107, 105, 110, 95, 114, 97, 100, 105, 117, 115, 39, 32, 97, 114, 101,
  32, 112, 114, 111, 118, 105, 100, 101, 100, 44, 32, 115, 107, 105, 110, 32,
  112, 105, 120, 101, 108, 115, 32, 97, 114, 101, 32, 108, 101, 97, 114, 110,
  116, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 102, 114, 111, 109, 32,
  116, 104, 101, 32, 115, 97, 109, 112, 108, 101, 32, 112, 105, 120, 101, 108,
  115, 32, 105, 110, 115, 105, 100, 101, 32, 116, 104, 101, 32, 99, 105, 114,
  99, 108, 101, 32, 108, 111, 99, 97, 116, 101, 100, 32, 97, 116, 32, 40,
  39, 115, 107, 105, 110, 95, 120, 39, 44, 39, 115, 107, 105, 110, 95, 121,
  39, 41, 32, 119, 105, 116, 104, 32, 114, 97, 100, 105, 117, 115, 32, 39,
  115, 107, 105, 110, 95, 114, 97, 100, 105, 117, 115, 39, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 58, 32, 39, 116, 111, 108, 101, 114, 97, 110, 99, 101,
  61, 48, 46, 53, 39, 32, 97, 110, 100, 32, 39, 115, 107, 105, 110, 95,
  120, 61, 115, 107, 105, 110, 121, 61, 114, 97, 100, 105, 117, 115, 61, 45,
  49, 39, 46, 10, 100, 101, 116, 101, 99, 116, 95, 115, 107, 105, 110, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 48, 46,
  53, 125, 62, 61, 48, 32, 38, 38, 32, 36, 49, 60, 61, 49, 34, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 45, 49, 125, 44, 36, 123,
  51, 61, 45, 49, 125, 44, 36, 123, 52, 61, 45, 49, 125, 10, 45, 105,
  102, 32, 123, 36, 50, 60, 48, 124, 124, 36, 51, 60, 61, 48, 124, 124,
  36, 52, 60, 61, 48, 125, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32,
  34, 68, 101, 116, 101, 99, 116, 32, 115, 107, 105, 110, 32, 105, 110, 32,
  105, 109, 97, 103, 101, 36, 63, 44, 32, 117, 115, 105, 110, 103, 32, 116,
  111, 108, 101, 114, 97, 110, 99, 101, 32, 36, 49, 46, 34, 10, 45, 118,
  32, 45, 10, 109, 48, 61, 49, 50, 48, 46, 57, 50, 57, 50, 49, 48,
  56, 56, 48, 48, 48, 54, 57, 10, 109, 49, 61, 49, 52, 50, 46, 53,
  55, 52, 53, 50, 55, 50, 57, 49, 56, 48, 56, 52, 10, 65, 61, 48,
  46, 48, 57, 55, 52, 57, 57, 56, 53, 52, 56, 54, 50, 54, 56, 57,
  57, 55, 10, 66, 61, 48, 46, 48, 54, 51, 56, 56, 56, 55, 49, 51,
  55, 49, 55, 52, 54, 48, 54, 51, 10, 67, 61, 48, 46, 48, 53, 50,
  53, 48, 48, 53, 51, 49, 48, 55, 55, 51, 56, 52, 57, 53, 10, 45,
  116, 111, 95, 114, 103, 98, 32, 45, 115, 114, 103, 98, 50, 114, 103, 98,
  32, 45, 114, 103, 98, 50, 121, 99, 98, 99, 114, 32, 45, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 49, 44, 50, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 104, 100, 61,
  123, 119, 125, 44, 123, 104, 125, 44, 123, 100, 125, 32, 45, 114, 32, 123,
  119, 42, 104, 42, 100, 125, 44, 50, 44, 49, 44, 49, 44, 45, 49, 10,
  45, 115, 32, 121, 32, 45, 45, 91, 48, 93, 32, 36, 109, 48, 32, 45,
  45, 91, 49, 93, 32, 36, 109, 49, 32, 45, 97, 32, 121, 10, 45, 105,
  91, 48, 93, 32, 40, 36, 65, 44, 36, 66, 59, 36, 66, 44, 36, 67,
  41, 32, 45, 45, 42, 42, 32, 45, 114, 109, 91, 48, 93, 10, 45, 42,
  32, 45, 115, 32, 121, 32, 45, 43, 32, 45, 42, 91, 45, 49, 93, 32,
  123, 36, 49, 45, 49, 125, 32, 45, 101, 120, 112, 91, 45, 49, 93, 10,
  45, 114, 32, 36, 119, 104, 100, 44, 49, 44, 45, 49, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 115, 101, 10, 45,
  101, 91, 48, 45, 45, 51, 93, 32, 34, 68, 101, 116, 101, 99, 116, 32,
  115, 107, 105, 110, 32, 105, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 117, 115, 105, 110, 103, 32, 116, 111, 108, 101, 114, 97, 110, 99, 101,
  32, 36, 49, 32, 97, 110, 100, 32, 116, 97, 114, 103, 101, 116, 32, 99,
  105, 114, 99, 108, 101, 32, 97, 116, 32, 40, 36, 50, 44, 36, 51, 41,
  32, 119, 105, 116, 104, 32, 114, 97, 100, 105, 117, 115, 32, 36, 52, 46,
  34, 10, 45, 118, 32, 45, 10, 45, 116, 111, 95, 114, 103, 98, 32, 45,
  115, 114, 103, 98, 50, 114, 103, 98, 32, 45, 114, 103, 98, 50, 121, 99,
  98, 99, 114, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 49, 44,
  50, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 99,
  105, 114, 99, 108, 101, 91, 49, 93, 32, 36, 50, 44, 36, 51, 44, 36,
  52, 44, 49, 44, 49, 32, 45, 45, 102, 91, 49, 93, 32, 39, 105, 102,
  40, 105, 44, 121, 44, 45, 49, 41, 39, 32, 45, 102, 91, 49, 93, 32,
  39, 105, 102, 40, 105, 44, 120, 44, 45, 49, 41, 39, 32, 45, 100, 105,
  115, 99, 97, 114, 100, 91, 49, 44, 50, 93, 32, 45, 49, 32, 45, 97,
  91, 49, 44, 50, 93, 32, 99, 10, 45, 45, 119, 97, 114, 112, 91, 48,
  93, 32, 91, 49, 93, 44, 48, 44, 48, 32, 45, 114, 109, 91, 49, 93,
  10, 45, 115, 91, 49, 93, 32, 99, 10, 109, 48, 61, 64, 123, 49, 44,
  105, 97, 125, 32, 45, 45, 91, 49, 93, 32, 36, 109, 48, 10, 109, 49,
  61, 64, 123, 50, 44, 105, 97, 125, 32, 45, 45, 91, 50, 93, 32, 36,
  109, 49, 10, 77, 61, 123, 104, 125, 32, 45, 97, 91, 49, 44, 50, 93,
  32, 120, 32, 45, 45, 116, 114, 97, 110, 115, 112, 111, 115, 101, 91, 49,
  93, 32, 45, 114, 118, 91, 49, 44, 50, 93, 32, 45, 42, 42, 91, 49,
  44, 50, 93, 32, 45, 47, 91, 49, 93, 32, 36, 77, 32, 45, 105, 110,
  118, 101, 114, 116, 91, 49, 93, 10, 45, 114, 118, 32, 119, 104, 100, 61,
  123, 119, 125, 44, 123, 104, 125, 44, 123, 100, 125, 32, 45, 114, 91, 49,
  93, 32, 123, 119, 42, 104, 42, 100, 125, 44, 50, 44, 49, 44, 49, 44,
  45, 49, 10, 45, 115, 91, 49, 93, 32, 121, 32, 45, 45, 91, 49, 93,
  32, 36, 109, 48, 32, 45, 45, 91, 50, 93, 32, 36, 109, 49, 32, 45,
  97, 91, 49, 44, 50, 93, 32, 121, 32, 45, 45, 42, 42, 32, 45, 114,
  109, 91, 48, 93, 10, 45, 42, 32, 45, 115, 32, 121, 32, 45, 43, 32,
  45, 42, 91, 45, 49, 93, 32, 123, 36, 49, 45, 49, 125, 32, 45, 101,
  120, 112, 91, 45, 49, 93, 10, 45, 114, 32, 36, 119, 104, 100, 44, 49,
  44, 45, 49, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 35, 64, 103, 109,
  105, 99, 32, 100, 105, 115, 112, 108, 97, 99, 101, 109, 101, 110, 116, 32,
  58, 32, 91, 115, 111, 117, 114, 99, 101, 95, 105, 109, 97, 103, 101, 93,
  44, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 44, 95, 112, 114,
  101, 99, 105, 115, 105, 111, 110, 62, 61, 48, 44, 95, 110, 98, 95, 115,
  99, 97, 108, 101, 115, 62, 61, 48, 44, 105, 116, 101, 114, 97, 116, 105,
  111, 110, 95, 109, 97, 120, 62, 61, 48, 44, 105, 115, 95, 98, 97, 99,
  107, 119, 97, 114, 100, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 32,
  58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 69,
  115, 116, 105, 109, 97, 116, 101, 32, 100, 105, 115, 112, 108, 97, 99, 101,
  109, 101, 110, 116, 32, 102, 105, 101, 108, 100, 32, 98, 101, 116, 119, 101,
  101, 110, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 115, 111, 117,
  114, 99, 101, 32, 97, 110, 100, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 73, 102, 32, 39, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  62, 61, 48, 39, 44, 32, 114, 101, 103, 117, 108, 97, 114, 105, 122, 97,
  116, 105, 111, 110, 32, 116, 121, 112, 101, 32, 105, 115, 32, 115, 101, 116,
  32, 116, 111, 32, 105, 115, 111, 116, 114, 111, 112, 105, 99, 44, 32, 101,
  108, 115, 101, 32, 116, 111, 32, 97, 110, 105, 115, 111, 116, 114, 111, 112,
  105, 99, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 102, 32,
  39, 110, 98, 115, 99, 97, 108, 101, 115, 61, 61, 48, 39, 44, 32, 116,
  104, 101, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 110, 101, 101,
  100, 101, 100, 32, 115, 99, 97, 108, 101, 115, 32, 105, 115, 32, 101, 115,
  116, 105, 109, 97, 116, 101, 100, 32, 102, 114, 111, 109, 32, 116, 104, 101,
  32, 105, 109, 97, 103, 101, 32, 115, 105, 122, 101, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 61, 48, 46, 49, 39, 44, 32, 39, 112, 114, 101, 99, 105, 115, 105,
  111, 110, 61, 53, 39, 44, 32, 39, 110, 98, 95, 115, 99, 97, 108, 101,
  115, 61, 48, 39, 44, 32, 39, 105, 116, 101, 114, 97, 116, 105, 111, 110,
  95, 109, 97, 120, 61, 49, 48, 48, 48, 48, 39, 32, 97, 110, 100, 32,
  39, 105, 115, 95, 98, 97, 99, 107, 119, 97, 114, 100, 61, 49, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 114, 111, 116, 97, 116, 101, 32, 51,
  44, 49, 44, 48, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 46, 57,
  32, 45, 45, 100, 105, 115, 112, 108, 97, 99, 101, 109, 101, 110, 116, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 113, 117, 105, 118, 101, 114,
  91, 45, 49, 93, 32, 91, 45, 49, 93, 44, 49, 53, 44, 45, 50, 48,
  44, 49, 44, 49, 44, 123, 49, 46, 53, 42, 105, 77, 125, 10, 35, 64,
  103, 109, 105, 99, 32, 100, 105, 115, 116, 97, 110, 99, 101, 32, 58, 32,
  105, 115, 111, 118, 97, 108, 117, 101, 91, 37, 93, 44, 95, 109, 101, 116,
  114, 105, 99, 32, 58, 32, 105, 115, 111, 118, 97, 108, 117, 101, 91, 37,
  93, 44, 91, 109, 101, 116, 114, 105, 99, 93, 44, 95, 109, 101, 116, 104,
  111, 100, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 117, 110,
  115, 105, 103, 110, 101, 100, 32, 100, 105, 115, 116, 97, 110, 99, 101, 32,
  102, 117, 110, 99, 116, 105, 111, 110, 32, 116, 111, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 105, 115, 111, 118, 97, 108, 117, 101, 44, 32,
  111, 112, 116, 46, 32, 97, 99, 99, 111, 114, 100, 105, 110, 103, 32, 116,
  111, 32, 97, 32, 99, 117, 115, 116, 111, 109, 32, 109, 101, 116, 114, 105,
  99, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 109, 101, 116,
  114, 105, 99, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61,
  99, 104, 101, 98, 121, 115, 104, 101, 118, 32, 124, 32, 49, 61, 109, 97,
  110, 104, 97, 116, 116, 97, 110, 32, 124, 32, 50, 61, 101, 117, 99, 108,
  105, 100, 101, 97, 110, 32, 124, 32, 51, 61, 115, 113, 117, 97, 114, 101,
  100, 45, 101, 117, 99, 108, 105, 100, 101, 97, 110, 32, 125, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 39, 109, 101, 116, 104, 111, 100, 39,
  32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 102, 97, 115, 116,
  45, 109, 97, 114, 99, 104, 105, 110, 103, 32, 124, 32, 49, 61, 108, 111,
  119, 45, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 32, 100,
  105, 106, 107, 115, 116, 114, 97, 32, 124, 32, 50, 61, 104, 105, 103, 104,
  45, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 32, 100, 105,
  106, 107, 115, 116, 114, 97, 32, 124, 32, 51, 61, 49, 43, 114, 101, 116,
  117, 114, 110, 32, 112, 97, 116, 104, 32, 124, 32, 52, 61, 50, 43, 114,
  101, 116, 117, 114, 110, 32, 112, 97, 116, 104, 32, 125, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 58, 32, 39, 109, 101, 116, 114, 105, 99, 61, 50, 39,
  32, 97, 110, 100, 32, 39, 109, 101, 116, 104, 111, 100, 61, 48, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100,
  32, 50, 48, 37, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101, 32, 48,
  32, 45, 112, 111, 119, 32, 48, 46, 51, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 52, 48, 48, 44, 52, 48, 48, 32, 45, 115, 101,
  116, 32, 49, 44, 53, 48, 37, 44, 53, 48, 37, 32, 45, 45, 100, 105,
  115, 116, 97, 110, 99, 101, 91, 48, 93, 32, 49, 44, 50, 32, 45, 45,
  100, 105, 115, 116, 97, 110, 99, 101, 91, 48, 93, 32, 49, 44, 49, 32,
  45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 48, 93, 32, 49, 44, 48,
  32, 45, 109, 111, 100, 32, 51, 50, 32, 45, 116, 104, 114, 101, 115, 104,
  111, 108, 100, 32, 49, 54, 32, 45, 97, 112, 112, 101, 110, 100, 32, 99,
  10, 35, 64, 103, 109, 105, 99, 32, 102, 108, 111, 97, 116, 50, 102, 102,
  116, 56, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118,
  101, 114, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 102, 108, 111,
  97, 116, 45, 118, 97, 108, 117, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  32, 116, 111, 32, 56, 98, 105, 116, 115, 32, 102, 111, 117, 114, 105, 101,
  114, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 97, 116, 105, 111, 110,
  115, 46, 10, 102, 108, 111, 97, 116, 50, 102, 102, 116, 56, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116,
  32, 102, 108, 111, 97, 116, 45, 118, 97, 108, 117, 101, 100, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 116, 111, 32, 56, 98, 105, 116, 115, 32, 102,
  111, 117, 114, 105, 101, 114, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116,
  97, 116, 105, 111, 110, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  45, 102, 102, 116, 112, 111, 108, 97, 114, 32, 45, 43, 91, 45, 50, 93,
  32, 49, 32, 45, 108, 111, 103, 91, 45, 50, 93, 32, 45, 102, 108, 111,
  97, 116, 50, 105, 110, 116, 56, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  97, 32, 121, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 102, 102, 116, 56,
  50, 102, 108, 111, 97, 116, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  67, 111, 110, 118, 101, 114, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 56, 98, 105, 116, 115, 32, 102, 111, 117, 114, 105, 101, 114, 32, 114,
  101, 112, 114, 101, 115, 101, 110, 116, 97, 116, 105, 111, 110, 115, 32, 116,
  111, 32, 102, 108, 111, 97, 116, 45, 118, 97, 108, 117, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 46, 10, 102, 102, 116, 56, 50, 102, 108, 111, 97,
  116, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110,
  118, 101, 114, 116, 32, 102, 108, 111, 97, 116, 45, 118, 97, 108, 117, 101,
  100, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 111, 32, 56, 98, 105,
  116, 115, 32, 102, 111, 117, 114, 105, 101, 114, 32, 114, 101, 112, 114, 101,
  115, 101, 110, 116, 97, 116, 105, 111, 110, 115, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 115, 32, 121, 44, 50, 32, 45, 105, 110, 116, 56,
  50, 102, 108, 111, 97, 116, 32, 45, 101, 120, 112, 91, 45, 50, 93, 32,
  45, 45, 91, 45, 50, 93, 32, 49, 32, 45, 105, 102, 102, 116, 112, 111,
  108, 97, 114, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 102, 102, 116, 112,
  111, 108, 97, 114, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111,
  109, 112, 117, 116, 101, 32, 102, 111, 117, 114, 105, 101, 114, 32, 116, 114,
  97, 110, 115, 102, 111, 114, 109, 32, 111, 102, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 44, 32, 97, 115, 32, 99,
  101, 110, 116, 101, 114, 101, 100, 32, 109, 97, 103, 110, 105, 116, 117, 100,
  101, 47, 112, 104, 97, 115, 101, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 102, 102, 116, 112, 111, 108, 97, 114, 32, 45,
  101, 108, 108, 105, 112, 115, 101, 32, 53, 48, 37, 44, 53, 48, 37, 44,
  49, 48, 44, 49, 48, 44, 48, 44, 49, 44, 48, 32, 45, 105, 102, 102,
  116, 112, 111, 108, 97, 114, 10, 102, 102, 116, 112, 111, 108, 97, 114, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117,
  116, 101, 32, 102, 111, 117, 114, 105, 101, 114, 32, 116, 114, 97, 110, 115,
  102, 111, 114, 109, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 97, 115, 32, 99, 101, 110, 116, 101, 114, 101, 100, 32, 109, 97, 103,
  110, 105, 116, 117, 100, 101, 47, 112, 104, 97, 115, 101, 32, 105, 109, 97,
  103, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 60, 93, 10, 45, 102, 102,
  116, 32, 45, 99, 111, 109, 112, 108, 101, 120, 50, 112, 111, 108, 97, 114,
  32, 45, 115, 104, 105, 102, 116, 32, 123, 45, 105, 110, 116, 40, 119, 47,
  50, 41, 125, 44, 123, 45, 105, 110, 116, 40, 104, 47, 50, 41, 125, 44,
  123, 45, 105, 110, 116, 40, 100, 47, 50, 41, 125, 44, 48, 44, 50, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 104, 105, 115, 116, 111, 103, 114, 97,
  109, 32, 58, 32, 95, 110, 98, 95, 108, 101, 118, 101, 108, 115, 62, 48,
  91, 37, 93, 44, 95, 118, 97, 108, 117, 101, 48, 91, 37, 93, 44, 95,
  118, 97, 108, 117, 101, 49, 91, 37, 93, 32, 58, 32, 40, 43, 41, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101,
  32, 116, 104, 101, 32, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 111,
  102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 102, 32, 118,
  97, 108, 117, 101, 32, 114, 97, 110, 103, 101, 32, 105, 115, 32, 115, 101,
  116, 44, 32, 116, 104, 101, 32, 104, 105, 115, 116, 111, 103, 114, 97, 109,
  32, 105, 115, 32, 101, 115, 116, 105, 109, 97, 116, 101, 100, 32, 111, 110,
  108, 121, 32, 102, 111, 114, 32, 112, 105, 120, 101, 108, 115, 32, 105, 110,
  32, 116, 104, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 118, 97, 108, 117, 101, 32, 114, 97,
  110, 103, 101, 46, 32, 65, 114, 103, 117, 109, 101, 110, 116, 32, 39, 118,
  97, 108, 117, 101, 49, 39, 32, 109, 117, 115, 116, 32, 98, 101, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 105, 102, 32, 39, 118, 97, 108,
  117, 101, 48, 39, 32, 105, 115, 32, 115, 101, 116, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 110, 98, 95, 108, 101, 118, 101, 108, 115,
  61, 50, 53, 54, 39, 44, 32, 39, 118, 97, 108, 117, 101, 48, 61, 48,
  37, 39, 32, 97, 110, 100, 32, 39, 118, 97, 108, 117, 101, 49, 61, 49,
  48, 48, 37, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 104, 105, 115,
  116, 111, 103, 114, 97, 109, 32, 54, 52, 32, 45, 100, 105, 115, 112, 108,
  97, 121, 95, 103, 114, 97, 112, 104, 91, 45, 49, 93, 32, 52, 48, 48,
  44, 51, 48, 48, 44, 51, 10, 35, 64, 103, 109, 105, 99, 32, 104, 105,
  115, 116, 111, 103, 114, 97, 109, 51, 32, 58, 32, 110, 98, 95, 108, 101,
  118, 101, 108, 115, 62, 48, 91, 37, 93, 44, 95, 118, 97, 108, 117, 101,
  48, 91, 37, 93, 44, 95, 118, 97, 108, 117, 101, 49, 91, 37, 93, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101,
  32, 116, 104, 101, 32, 49, 100, 44, 50, 100, 32, 111, 114, 32, 51, 100,
  32, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 111, 102, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 109, 117, 108, 116, 105, 45, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 105, 109, 97, 103, 101, 115, 32, 40, 104, 97,
  118, 105, 110, 103, 32, 49, 44, 50, 32, 111, 114, 32, 51, 32, 99, 104,
  97, 110, 110, 101, 108, 115, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 73, 102, 32, 118, 97, 108, 117, 101, 32, 114, 97, 110, 103, 101,
  32, 105, 115, 32, 115, 101, 116, 44, 32, 116, 104, 101, 32, 104, 105, 115,
  116, 111, 103, 114, 97, 109, 32, 105, 115, 32, 101, 115, 116, 105, 109, 97,
  116, 101, 100, 32, 111, 110, 108, 121, 32, 102, 111, 114, 32, 112, 105, 120,
  101, 108, 115, 32, 105, 110, 32, 116, 104, 101, 32, 115, 112, 101, 99, 105,
  102, 105, 101, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 118, 97,
  108, 117, 101, 32, 114, 97, 110, 103, 101, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117,
  101, 115, 58, 32, 39, 118, 97, 108, 117, 101, 48, 61, 48, 37, 39, 32,
  97, 110, 100, 32, 39, 118, 97, 108, 117, 101, 49, 61, 49, 48, 48, 37,
  39, 46, 10, 104, 105, 115, 116, 111, 103, 114, 97, 109, 51, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 36, 49, 62, 48, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 50, 61, 48, 37, 125, 44, 36, 123, 51, 61, 49, 48,
  48, 37, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109,
  112, 117, 116, 101, 32, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 111,
  102, 32, 109, 117, 108, 116, 105, 45, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 117, 115, 105, 110, 103, 32,
  36, 49, 32, 108, 101, 118, 101, 108, 115, 32, 105, 110, 32, 114, 97, 110,
  103, 101, 32, 91, 36, 49, 44, 36, 50, 93, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 114, 32, 123, 119, 42, 104, 42, 100, 125, 44, 123,
  109, 105, 110, 40, 51, 44, 115, 41, 125, 44, 49, 44, 49, 44, 45, 49,
  32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 49, 10, 118, 109,
  105, 110, 61, 123, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114,
  99, 101, 110, 116, 92, 32, 36, 50, 125, 44, 36, 50, 42, 105, 109, 44,
  36, 50, 41, 125, 32, 118, 109, 97, 120, 61, 123, 105, 102, 40, 64, 123,
  45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 51, 125,
  44, 36, 51, 42, 105, 77, 44, 36, 51, 41, 125, 10, 45, 45, 32, 36,
  118, 109, 105, 110, 32, 45, 42, 32, 123, 40, 36, 49, 45, 49, 41, 47,
  40, 36, 118, 109, 97, 120, 45, 36, 118, 109, 105, 110, 41, 125, 10, 110,
  98, 95, 108, 101, 118, 101, 108, 115, 61, 123, 105, 102, 40, 64, 123, 45,
  105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 49, 125, 44,
  36, 49, 42, 40, 36, 118, 109, 97, 120, 45, 36, 118, 109, 105, 110, 41,
  43, 49, 44, 36, 49, 41, 125, 10, 45, 112, 111, 105, 110, 116, 99, 108,
  111, 117, 100, 32, 49, 44, 36, 110, 98, 95, 108, 101, 118, 101, 108, 115,
  44, 36, 110, 98, 95, 108, 101, 118, 101, 108, 115, 44, 36, 110, 98, 95,
  108, 101, 118, 101, 108, 115, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 104,
  105, 115, 116, 111, 103, 114, 97, 109, 95, 99, 117, 109, 117, 108, 32, 58,
  32, 95, 110, 98, 95, 108, 101, 118, 101, 108, 115, 62, 48, 44, 95, 105,
  115, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 100, 61, 123, 32, 48,
  32, 124, 32, 49, 32, 125, 44, 95, 118, 97, 108, 48, 91, 37, 93, 44,
  95, 118, 97, 108, 49, 91, 37, 93, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 99, 117, 109, 117, 108, 97,
  116, 105, 118, 101, 32, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 111,
  102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 110, 98, 95,
  108, 101, 118, 101, 108, 115, 61, 50, 53, 54, 39, 44, 32, 39, 105, 115,
  95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 100, 61, 48, 39, 32, 97,
  110, 100, 32, 39, 118, 97, 108, 48, 61, 118, 97, 108, 49, 61, 48, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 45, 104, 105, 115, 116, 111, 103, 114,
  97, 109, 95, 99, 117, 109, 117, 108, 32, 50, 53, 54, 32, 45, 104, 105,
  115, 116, 111, 103, 114, 97, 109, 91, 48, 93, 32, 50, 53, 54, 32, 45,
  100, 105, 115, 112, 108, 97, 121, 95, 103, 114, 97, 112, 104, 32, 52, 48,
  48, 44, 51, 48, 48, 44, 51, 10, 104, 105, 115, 116, 111, 103, 114, 97,
  109, 95, 99, 117, 109, 117, 108, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 36, 123, 49, 61, 50, 53, 54, 125, 62, 48, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 50, 61, 48, 125, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 51, 61, 48, 125, 44, 36, 123, 52, 61, 48, 125, 10, 45, 97, 114,
  103, 32, 49, 43, 33, 36, 50, 44, 34, 110, 111, 114, 109, 97, 108, 105,
  122, 101, 100, 32, 34, 44, 34, 34, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 34, 64, 123, 125, 34, 99,
  117, 109, 117, 108, 97, 116, 105, 118, 101, 32, 104, 105, 115, 116, 111, 103,
  114, 97, 109, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32,
  117, 115, 105, 110, 103, 32, 36, 49, 32, 108, 101, 118, 101, 108, 115, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 104, 105, 115, 116, 111, 103, 114, 97,
  109, 32, 36, 49, 44, 36, 51, 44, 36, 52, 32, 45, 99, 117, 109, 117,
  108, 32, 45, 105, 102, 32, 36, 50, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 47, 91, 36, 62, 93, 32, 64, 123, 36, 62, 44,
  77, 125, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 104, 105, 115, 116,
  111, 103, 114, 97, 109, 95, 112, 111, 105, 110, 116, 119, 105, 115, 101, 32,
  58, 32, 110, 98, 95, 108, 101, 118, 101, 108, 115, 62, 48, 91, 37, 93,
  44, 95, 118, 97, 108, 117, 101, 48, 91, 37, 93, 44, 95, 118, 97, 108,
  117, 101, 49, 91, 37, 93, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 104, 105, 115, 116,
  111, 103, 114, 97, 109, 32, 111, 102, 32, 101, 97, 99, 104, 32, 118, 101,
  99, 116, 111, 114, 45, 118, 97, 108, 117, 101, 100, 32, 112, 111, 105, 110,
  116, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73,
  102, 32, 118, 97, 108, 117, 101, 32, 114, 97, 110, 103, 101, 32, 105, 115,
  32, 115, 101, 116, 44, 32, 116, 104, 101, 32, 104, 105, 115, 116, 111, 103,
  114, 97, 109, 32, 105, 115, 32, 101, 115, 116, 105, 109, 97, 116, 101, 100,
  32, 111, 110, 108, 121, 32, 102, 111, 114, 32, 118, 97, 108, 117, 101, 115,
  32, 105, 110, 32, 116, 104, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101,
  100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 118, 97, 108, 117, 101,
  32, 114, 97, 110, 103, 101, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58,
  32, 39, 118, 97, 108, 117, 101, 48, 61, 48, 37, 39, 32, 97, 110, 100,
  32, 39, 118, 97, 108, 117, 101, 49, 61, 49, 48, 48, 37, 39, 46, 10,
  104, 105, 115, 116, 111, 103, 114, 97, 109, 95, 112, 111, 105, 110, 116, 119,
  105, 115, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61,
  48, 37, 125, 44, 36, 123, 51, 61, 49, 48, 48, 37, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 116,
  104, 101, 32, 112, 111, 105, 110, 116, 119, 105, 115, 101, 32, 104, 105, 115,
  116, 111, 103, 114, 97, 109, 32, 111, 102, 32, 118, 101, 99, 116, 111, 114,
  45, 118, 97, 108, 117, 101, 100, 32, 112, 111, 105, 110, 116, 115, 32, 105,
  110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32,
  36, 49, 32, 108, 101, 118, 101, 108, 115, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 110, 98, 95,
  108, 101, 118, 101, 108, 115, 61, 123, 114, 111, 117, 110, 100, 40, 105, 102,
  40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32,
  36, 49, 125, 44, 40, 105, 77, 45, 105, 109, 41, 42, 36, 49, 44, 36,
  49, 41, 41, 125, 10, 118, 97, 108, 117, 101, 48, 61, 123, 105, 102, 40,
  64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36,
  50, 125, 44, 105, 109, 43, 40, 105, 77, 45, 105, 109, 41, 42, 36, 50,
  44, 36, 50, 41, 125, 10, 118, 97, 108, 117, 101, 49, 61, 123, 105, 102,
  40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32,
  36, 51, 125, 44, 105, 109, 43, 40, 105, 77, 45, 105, 109, 41, 42, 36,
  51, 44, 36, 51, 41, 125, 10, 45, 45, 32, 36, 118, 97, 108, 117, 101,
  48, 32, 45, 42, 32, 123, 36, 110, 98, 95, 108, 101, 118, 101, 108, 115,
  47, 109, 97, 120, 40, 49, 44, 97, 98, 115, 40, 36, 118, 97, 108, 117,
  101, 49, 45, 36, 118, 97, 108, 117, 101, 48, 41, 41, 125, 32, 45, 99,
  32, 48, 44, 123, 36, 110, 98, 95, 108, 101, 118, 101, 108, 115, 45, 49,
  125, 32, 45, 114, 111, 117, 110, 100, 10, 119, 61, 123, 119, 125, 32, 104,
  61, 123, 104, 125, 32, 100, 61, 123, 100, 125, 32, 45, 114, 32, 123, 119,
  42, 104, 42, 100, 125, 44, 123, 115, 125, 44, 49, 44, 49, 44, 45, 49,
  10, 45, 105, 91, 45, 50, 93, 32, 40, 48, 44, 123, 119, 45, 49, 125,
  41, 32, 45, 114, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 91, 45,
  49, 93, 44, 49, 44, 49, 44, 51, 32, 45, 114, 111, 117, 110, 100, 91,
  45, 50, 93, 10, 45, 114, 91, 45, 50, 44, 45, 49, 93, 32, 51, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 52, 32, 45, 115,
  104, 105, 102, 116, 91, 45, 49, 93, 32, 49, 32, 45, 43, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 121, 91, 45, 49, 93, 10, 45, 105, 91, 45,
  50, 93, 32, 40, 123, 39, 67, 73, 109, 103, 51, 100, 39, 125, 44, 123,
  104, 47, 51, 125, 44, 123, 104, 47, 51, 125, 41, 10, 40, 49, 44, 48,
  59, 49, 44, 123, 104, 47, 51, 45, 49, 125, 41, 32, 45, 114, 91, 45,
  49, 93, 32, 50, 44, 64, 123, 45, 50, 44, 104, 47, 51, 125, 44, 49,
  44, 49, 44, 51, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 10,
  51, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 49, 32, 49, 44, 49,
  48, 48, 37, 44, 49, 44, 49, 44, 45, 49, 32, 45, 121, 91, 45, 53,
  44, 45, 51, 44, 45, 50, 93, 32, 45, 97, 91, 45, 53, 45, 45, 49,
  93, 32, 121, 10, 123, 36, 119, 42, 36, 104, 42, 36, 100, 125, 44, 36,
  110, 98, 95, 108, 101, 118, 101, 108, 115, 32, 45, 111, 98, 106, 101, 99,
  116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48,
  44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45,
  50, 93, 10, 45, 114, 32, 36, 119, 44, 36, 104, 44, 36, 100, 44, 36,
  110, 98, 95, 108, 101, 118, 101, 108, 115, 44, 45, 49, 10, 45, 110, 109,
  32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 104,
  111, 117, 103, 104, 32, 58, 32, 95, 119, 105, 100, 116, 104, 62, 48, 44,
  95, 104, 101, 105, 103, 104, 116, 62, 48, 44, 103, 114, 97, 100, 105, 101,
  110, 116, 95, 110, 111, 114, 109, 95, 118, 111, 116, 105, 110, 103, 61, 123,
  32, 48, 32, 124, 32, 49, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 104, 111, 117, 103, 104, 32,
  116, 114, 97, 110, 115, 102, 111, 114, 109, 32, 40, 116, 104, 101, 116, 97,
  44, 114, 104, 111, 41, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  115, 58, 32, 39, 119, 105, 100, 116, 104, 61, 53, 49, 50, 39, 44, 32,
  39, 104, 101, 105, 103, 104, 116, 61, 119, 105, 100, 116, 104, 39, 32, 97,
  110, 100, 32, 39, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114,
  109, 95, 118, 111, 116, 105, 110, 103, 61, 49, 39, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 49, 46, 53,
  32, 45, 104, 111, 117, 103, 104, 91, 45, 49, 93, 32, 52, 48, 48, 44,
  52, 48, 48, 32, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 48, 46,
  53, 32, 45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 108, 111, 103, 91,
  45, 49, 93, 10, 104, 111, 117, 103, 104, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 36, 123, 49, 61, 53, 49, 50, 125, 62, 48, 32, 38,
  38, 32, 36, 123, 50, 61, 36, 49, 125, 62, 48, 34, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 51, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 36, 49, 120, 36, 50,
  32, 104, 111, 117, 103, 104, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109,
  32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 34, 64, 123,
  45, 97, 114, 103, 92, 32, 49, 43, 33, 36, 51, 44, 119, 105, 116, 104,
  44, 119, 105, 116, 104, 111, 117, 116, 125, 34, 32, 103, 114, 97, 100, 105,
  101, 110, 116, 32, 110, 111, 114, 109, 32, 118, 111, 116, 105, 110, 103, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 115, 108, 105, 99, 101, 115, 32, 53,
  48, 37, 32, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32,
  110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 114, 104, 111, 109, 97, 120,
  61, 123, 115, 113, 114, 116, 40, 119, 94, 50, 43, 104, 94, 50, 41, 47,
  50, 125, 10, 45, 103, 32, 40, 48, 44, 123, 119, 45, 49, 125, 41, 32,
  40, 48, 59, 123, 64, 123, 45, 50, 44, 104, 125, 45, 49, 125, 41, 32,
  45, 114, 91, 45, 50, 44, 45, 49, 93, 32, 64, 123, 45, 51, 44, 119,
  125, 44, 64, 123, 45, 51, 44, 104, 125, 44, 49, 44, 49, 44, 51, 32,
  45, 45, 91, 45, 50, 93, 32, 123, 119, 47, 50, 125, 32, 45, 45, 91,
  45, 49, 93, 32, 123, 104, 47, 50, 125, 10, 45, 99, 111, 109, 112, 108,
  101, 120, 50, 112, 111, 108, 97, 114, 91, 45, 52, 45, 45, 49, 93, 32,
  45, 45, 91, 45, 49, 93, 32, 91, 45, 51, 93, 32, 45, 112, 111, 108,
  97, 114, 50, 99, 111, 109, 112, 108, 101, 120, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 45, 108, 116, 91, 45,
  49, 93, 32, 48, 32, 45, 42, 91, 45, 49, 93, 32, 123, 112, 105, 125,
  32, 45, 43, 91, 45, 51, 44, 45, 49, 93, 32, 45, 97, 98, 115, 91,
  45, 49, 93, 32, 45, 37, 91, 45, 50, 93, 32, 123, 50, 42, 112, 105,
  125, 10, 45, 42, 91, 45, 49, 93, 32, 123, 36, 50, 47, 36, 114, 104,
  111, 109, 97, 120, 125, 32, 45, 42, 91, 45, 50, 93, 32, 123, 48, 46,
  53, 42, 36, 49, 47, 112, 105, 125, 10, 45, 121, 91, 45, 51, 45, 45,
  49, 93, 32, 120, 32, 123, 119, 125, 32, 45, 109, 118, 91, 45, 52, 93,
  32, 64, 35, 32, 45, 105, 102, 32, 123, 33, 36, 51, 125, 32, 45, 102,
  91, 45, 49, 93, 32, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97,
  32, 121, 32, 45, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 32, 49,
  32, 45, 114, 32, 36, 49, 44, 36, 50, 44, 49, 44, 49, 44, 48, 10,
  45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 105, 102, 102, 116, 112, 111, 108, 97, 114, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 105, 110, 118,
  101, 114, 115, 101, 32, 102, 111, 117, 114, 105, 101, 114, 32, 116, 114, 97,
  110, 115, 102, 111, 114, 109, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 44, 32, 102, 114, 111, 109, 32,
  99, 101, 110, 116, 101, 114, 101, 100, 32, 109, 97, 103, 110, 105, 116, 117,
  100, 101, 47, 112, 104, 97, 115, 101, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 105, 102, 102, 116, 112, 111, 108, 97, 114, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 105, 110,
  118, 101, 114, 115, 101, 32, 102, 111, 117, 114, 105, 101, 114, 32, 116, 114,
  97, 110, 115, 102, 111, 114, 109, 32, 111, 102, 32, 105, 109, 97, 103, 101,
  36, 63, 44, 32, 102, 114, 111, 109, 32, 99, 101, 110, 116, 101, 114, 101,
  100, 32, 109, 97, 103, 110, 105, 116, 117, 100, 101, 47, 112, 104, 97, 115,
  101, 32, 105, 109, 97, 103, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47,
  50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125,
  93, 10, 45, 115, 104, 105, 102, 116, 32, 123, 105, 110, 116, 40, 119, 47,
  50, 41, 125, 44, 123, 105, 110, 116, 40, 104, 47, 50, 41, 125, 44, 123,
  105, 110, 116, 40, 100, 47, 50, 41, 125, 44, 48, 44, 50, 32, 45, 112,
  111, 108, 97, 114, 50, 99, 111, 109, 112, 108, 101, 120, 32, 45, 105, 102,
  102, 116, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109,
  105, 99, 32, 105, 115, 111, 112, 104, 111, 116, 101, 115, 32, 58, 32, 95,
  110, 98, 95, 108, 101, 118, 101, 108, 115, 62, 48, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 82, 101, 110, 100, 101, 114, 32, 105, 115, 111, 112,
  104, 111, 116, 101, 115, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 32, 111, 110, 32, 97, 32, 116, 114,
  97, 110, 115, 112, 97, 114, 101, 110, 116, 32, 98, 97, 99, 107, 103, 114,
  111, 117, 110, 100, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 110,
  98, 95, 108, 101, 118, 101, 108, 115, 61, 54, 52, 39, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 98, 108, 117, 114, 32, 50, 32, 45, 105, 115, 111, 112, 104,
  111, 116, 101, 115, 32, 54, 32, 45, 100, 105, 108, 97, 116, 101, 95, 99,
  105, 114, 99, 32, 53, 32, 45, 100, 105, 115, 112, 108, 97, 121, 95, 114,
  103, 98, 97, 10, 105, 115, 111, 112, 104, 111, 116, 101, 115, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 54, 52, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 82, 101, 110, 100, 101, 114, 32, 105, 115,
  111, 112, 104, 111, 116, 101, 32, 109, 97, 112, 115, 32, 102, 114, 111, 109,
  32, 105, 109, 97, 103, 101, 115, 36, 63, 44, 32, 119, 105, 116, 104, 32,
  36, 49, 32, 108, 101, 118, 101, 108, 115, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 108, 117,
  109, 105, 110, 97, 110, 99, 101, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  36, 49, 32, 45, 45, 105, 115, 111, 108, 105, 110, 101, 51, 100, 91, 49,
  93, 32, 123, 36, 62, 42, 50, 53, 53, 47, 40, 36, 49, 45, 49, 41,
  125, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 49, 93, 32, 45,
  43, 51, 100, 91, 94, 48, 93, 32, 45, 99, 111, 108, 51, 100, 91, 45,
  49, 93, 32, 49, 10, 91, 48, 93, 44, 91, 48, 93, 32, 45, 111, 98,
  106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44,
  48, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 32, 45, 114,
  109, 91, 45, 50, 93, 32, 45, 42, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 108, 97, 98, 101, 108, 32, 58, 32, 116, 111, 108, 101, 114, 97, 110,
  99, 101, 62, 61, 48, 44, 105, 115, 95, 104, 105, 103, 104, 95, 99, 111,
  110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 61, 123, 32, 48, 32, 124,
  32, 49, 32, 125, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 76, 97, 98, 101, 108, 32, 99, 111, 110, 110, 101, 99,
  116, 101, 100, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 32, 105,
  110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 116, 111, 108,
  101, 114, 97, 110, 99, 101, 61, 48, 39, 32, 97, 110, 100, 32, 39, 105,
  115, 95, 104, 105, 103, 104, 95, 99, 111, 110, 110, 101, 99, 116, 105, 118,
  105, 116, 121, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 108, 117,
  109, 105, 110, 97, 110, 99, 101, 32, 45, 116, 104, 114, 101, 115, 104, 111,
  108, 100, 32, 54, 48, 37, 32, 45, 108, 97, 98, 101, 108, 32, 45, 110,
  111, 114, 109, 97, 108, 105, 122, 101, 32, 48, 44, 50, 53, 53, 32, 45,
  109, 97, 112, 32, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 52, 48, 48, 44, 52, 48, 48, 32, 45, 115, 101, 116, 32, 49, 44,
  53, 48, 37, 44, 53, 48, 37, 32, 45, 100, 105, 115, 116, 97, 110, 99,
  101, 32, 49, 32, 45, 109, 111, 100, 32, 49, 54, 32, 45, 116, 104, 114,
  101, 115, 104, 111, 108, 100, 32, 56, 32, 45, 108, 97, 98, 101, 108, 32,
  45, 109, 111, 100, 32, 50, 53, 53, 32, 45, 109, 97, 112, 32, 50, 10,
  35, 64, 103, 109, 105, 99, 32, 108, 97, 98, 101, 108, 95, 102, 103, 32,
  58, 32, 116, 111, 108, 101, 114, 97, 110, 99, 101, 62, 61, 48, 44, 105,
  115, 95, 104, 105, 103, 104, 95, 99, 111, 110, 110, 101, 99, 116, 105, 118,
  105, 116, 121, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 76, 97, 98, 101, 108, 32, 99, 111, 110,
  110, 101, 99, 116, 101, 100, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  115, 32, 102, 111, 114, 32, 110, 111, 110, 45, 122, 101, 114, 111, 32, 118,
  97, 108, 117, 101, 115, 32, 40, 102, 111, 114, 101, 103, 114, 111, 117, 110,
  100, 41, 32, 105, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  83, 105, 109, 105, 108, 97, 114, 32, 116, 111, 32, 39, 45, 108, 97, 98,
  101, 108, 39, 32, 101, 120, 99, 101, 112, 116, 32, 116, 104, 97, 116, 32,
  48, 45, 118, 97, 108, 117, 101, 100, 32, 112, 105, 120, 101, 108, 115, 32,
  97, 114, 101, 32, 110, 111, 116, 32, 108, 97, 98, 101, 108, 101, 100, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108,
  116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 105, 115, 95, 104, 105, 103,
  104, 95, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 61, 48,
  39, 46, 10, 108, 97, 98, 101, 108, 95, 102, 103, 32, 58, 32, 45, 99,
  104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48, 34, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 50, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 76, 97, 98, 101, 108, 32, 102, 111, 114, 101, 103, 114, 111,
  117, 110, 100, 32, 99, 111, 110, 110, 101, 99, 116, 101, 100, 32, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 115, 32, 111, 110, 32, 105, 109, 97, 103,
  101, 32, 91, 49, 93, 44, 32, 119, 105, 116, 104, 32, 116, 111, 108, 101,
  114, 97, 110, 99, 101, 32, 36, 49, 32, 97, 110, 100, 32, 34, 64, 123,
  45, 97, 114, 103, 92, 32, 49, 43, 33, 36, 50, 44, 104, 105, 103, 104,
  44, 108, 111, 119, 125, 34, 32, 99, 111, 110, 110, 101, 99, 116, 105, 118,
  105, 116, 121, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102,
  32, 123, 100, 62, 49, 125, 32, 45, 45, 122, 32, 45, 49, 44, 45, 49,
  44, 45, 49, 44, 123, 119, 45, 49, 125, 44, 123, 104, 45, 49, 125, 44,
  123, 100, 45, 49, 125, 32, 45, 108, 97, 98, 101, 108, 91, 45, 49, 93,
  32, 36, 49, 44, 36, 50, 32, 45, 122, 91, 45, 49, 93, 32, 49, 44,
  49, 44, 49, 44, 123, 119, 45, 49, 125, 44, 123, 104, 45, 49, 125, 44,
  123, 100, 45, 49, 125, 10, 45, 101, 108, 115, 101, 32, 45, 45, 122, 32,
  45, 49, 44, 45, 49, 44, 123, 119, 45, 49, 125, 44, 123, 104, 45, 49,
  125, 32, 45, 108, 97, 98, 101, 108, 91, 45, 49, 93, 32, 36, 49, 44,
  36, 50, 32, 45, 122, 91, 45, 49, 93, 32, 49, 44, 49, 44, 123, 119,
  45, 49, 125, 44, 123, 104, 45, 49, 125, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 110, 101, 113, 91, 45, 50, 93, 32, 48, 32, 45, 42, 10, 45,
  45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 123, 49, 43, 105, 77,
  125, 32, 45, 110, 101, 113, 91, 45, 49, 93, 32, 48, 32, 45, 42, 91,
  45, 49, 93, 32, 39, 120, 39, 32, 45, 114, 111, 119, 115, 91, 45, 49,
  93, 32, 45, 49, 44, 48, 32, 45, 108, 97, 98, 101, 108, 91, 45, 49,
  93, 32, 45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 49, 44, 49, 10,
  45, 109, 97, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 109, 97,
  120, 95, 112, 97, 116, 99, 104, 32, 58, 32, 95, 112, 97, 116, 99, 104,
  95, 115, 105, 122, 101, 62, 61, 49, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 82, 101, 116, 117, 114, 110, 32, 108, 111, 99, 97, 116, 105, 111,
  110, 115, 32, 111, 102, 32, 109, 97, 120, 105, 109, 97, 108, 32, 118, 97,
  108, 117, 101, 115, 32, 105, 110, 32, 108, 111, 99, 97, 108, 32, 112, 97,
  116, 99, 104, 45, 98, 97, 115, 101, 100, 32, 110, 101, 105, 103, 104, 98,
  111, 114, 104, 111, 111, 100, 32, 111, 102, 32, 103, 105, 118, 101, 110, 32,
  115, 105, 122, 101, 32, 102, 111, 114, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  58, 32, 39, 112, 97, 116, 99, 104, 95, 115, 105, 122, 101, 61, 49, 54,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 110, 111, 114, 109, 32, 45, 45,
  109, 97, 120, 95, 112, 97, 116, 99, 104, 32, 49, 54, 10, 109, 97, 120,
  95, 112, 97, 116, 99, 104, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 49, 54, 125, 41, 32,
  38, 38, 32, 36, 49, 62, 61, 49, 34, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 82, 101, 116, 117, 114, 110, 32, 108, 111, 99, 97, 116, 105,
  111, 110, 115, 32, 111, 102, 32, 109, 97, 120, 105, 109, 97, 108, 32, 118,
  97, 108, 117, 101, 115, 32, 105, 110, 32, 108, 111, 99, 97, 108, 32, 112,
  97, 116, 99, 104, 32, 110, 101, 105, 103, 104, 98, 111, 114, 104, 111, 111,
  100, 32, 111, 102, 32, 115, 105, 122, 101, 32, 36, 49, 44, 32, 105, 110,
  32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 45, 100, 105, 108,
  97, 116, 101, 91, 36, 62, 93, 32, 36, 49, 32, 45, 61, 61, 91, 36,
  62, 44, 45, 49, 93, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 109, 105, 110, 95, 112, 97, 116, 99,
  104, 32, 58, 32, 95, 112, 97, 116, 99, 104, 95, 115, 105, 122, 101, 62,
  61, 49, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116, 117,
  114, 110, 32, 108, 111, 99, 97, 116, 105, 111, 110, 115, 32, 111, 102, 32,
  109, 105, 110, 105, 109, 97, 108, 32, 118, 97, 108, 117, 101, 115, 32, 105,
  110, 32, 108, 111, 99, 97, 108, 32, 112, 97, 116, 99, 104, 45, 98, 97,
  115, 101, 100, 32, 110, 101, 105, 103, 104, 98, 111, 114, 104, 111, 111, 100,
  32, 111, 102, 32, 103, 105, 118, 101, 110, 32, 115, 105, 122, 101, 32, 102,
  111, 114, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 112, 97, 116,
  99, 104, 95, 115, 105, 122, 101, 61, 49, 54, 39, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 110, 111, 114, 109, 32, 45, 45, 109, 105, 110, 95, 112, 97,
  116, 99, 104, 32, 49, 54, 10, 109, 105, 110, 95, 112, 97, 116, 99, 104,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110, 116,
  40, 36, 123, 49, 61, 49, 54, 125, 41, 32, 38, 38, 32, 36, 49, 62,
  61, 49, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 116,
  117, 114, 110, 32, 108, 111, 99, 97, 116, 105, 111, 110, 115, 32, 111, 102,
  32, 109, 105, 110, 105, 109, 97, 108, 32, 118, 97, 108, 117, 101, 115, 32,
  105, 110, 32, 108, 111, 99, 97, 108, 32, 112, 97, 116, 99, 104, 32, 110,
  101, 105, 103, 104, 98, 111, 114, 104, 111, 111, 100, 32, 111, 102, 32, 115,
  105, 122, 101, 32, 36, 49, 44, 32, 105, 110, 32, 105, 109, 97, 103, 101,
  36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 45, 101, 114, 111, 100, 101, 91, 36, 62, 93,
  32, 36, 49, 32, 45, 61, 61, 91, 36, 62, 44, 45, 49, 93, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 109, 105, 110, 105, 109, 97, 108, 95, 112, 97, 116, 104, 32, 58, 32,
  120, 48, 91, 37, 93, 62, 61, 48, 44, 121, 48, 91, 37, 93, 62, 61,
  48, 44, 122, 48, 91, 37, 93, 62, 61, 48, 44, 120, 49, 91, 37, 93,
  62, 61, 48, 44, 121, 49, 91, 37, 93, 62, 61, 48, 44, 122, 49, 91,
  37, 93, 62, 61, 48, 44, 95, 105, 115, 95, 104, 105, 103, 104, 95, 99,
  111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 61, 123, 32, 48, 32,
  124, 32, 49, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67,
  111, 109, 112, 117, 116, 101, 32, 109, 105, 110, 105, 109, 97, 108, 32, 112,
  97, 116, 104, 32, 98, 101, 116, 119, 101, 101, 110, 32, 116, 119, 111, 32,
  112, 111, 105, 110, 116, 115, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 112, 111, 116, 101, 110, 116, 105, 97, 108, 32, 109, 97, 112,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 105, 115, 95, 104,
  105, 103, 104, 95, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121,
  61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 103, 114, 97, 100,
  105, 101, 110, 116, 95, 110, 111, 114, 109, 32, 45, 102, 105, 108, 108, 91,
  45, 49, 93, 32, 49, 47, 40, 49, 43, 105, 41, 32, 45, 109, 105, 110,
  105, 109, 97, 108, 95, 112, 97, 116, 104, 91, 45, 49, 93, 32, 48, 44,
  48, 44, 48, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48, 32,
  45, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 91, 45, 49, 93, 32,
  48, 32, 45, 42, 91, 45, 49, 93, 32, 50, 56, 48, 32, 45, 116, 111,
  95, 114, 103, 98, 91, 45, 49, 93, 32, 45, 114, 101, 115, 105, 122, 101,
  91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 32, 45, 111, 114, 10,
  109, 105, 110, 105, 109, 97, 108, 95, 112, 97, 116, 104, 32, 58, 32, 45,
  99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48, 32, 38, 38, 32,
  36, 50, 62, 61, 48, 32, 38, 38, 32, 36, 51, 62, 61, 48, 34, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 55, 61, 48, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 109, 105,
  110, 105, 109, 97, 108, 32, 112, 97, 116, 104, 32, 98, 101, 116, 119, 101,
  101, 110, 32, 112, 111, 105, 110, 116, 115, 32, 40, 36, 49, 44, 36, 50,
  44, 36, 51, 41, 32, 97, 110, 100, 32, 40, 36, 52, 44, 36, 53, 44,
  36, 54, 41, 32, 102, 111, 114, 32, 112, 111, 116, 101, 110, 116, 105, 97,
  108, 32, 109, 97, 112, 36, 63, 44, 32, 119, 105, 116, 104, 32, 34, 64,
  123, 45, 97, 114, 103, 92, 32, 49, 43, 36, 55, 44, 108, 111, 119, 44,
  104, 105, 103, 104, 125, 34, 32, 99, 111, 110, 110, 101, 99, 116, 105, 118,
  105, 116, 121, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61,
  64, 123, 48, 44, 110, 125, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  32, 45, 61, 32, 49, 44, 36, 123, 52, 45, 54, 125, 32, 45, 100, 105,
  115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 44, 91, 48, 93,
  44, 123, 105, 102, 40, 36, 55, 44, 52, 44, 51, 41, 125, 32, 45, 107,
  91, 45, 49, 93, 10, 120, 61, 123, 114, 111, 117, 110, 100, 40, 105, 102,
  40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32,
  36, 49, 125, 44, 36, 49, 42, 40, 119, 45, 49, 41, 44, 36, 49, 41,
  41, 125, 10, 121, 61, 123, 114, 111, 117, 110, 100, 40, 105, 102, 40, 64,
  123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 50,
  125, 44, 36, 50, 42, 40, 104, 45, 49, 41, 44, 36, 50, 41, 41, 125,
  10, 122, 61, 123, 114, 111, 117, 110, 100, 40, 105, 102, 40, 64, 123, 45,
  105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 51, 125, 44,
  36, 51, 42, 40, 100, 45, 49, 41, 44, 36, 51, 41, 41, 125, 10, 40,
  36, 120, 59, 36, 121, 59, 36, 122, 41, 10, 45, 100, 111, 10, 112, 61,
  64, 123, 48, 44, 40, 36, 120, 44, 36, 121, 44, 36, 122, 41, 125, 10,
  45, 105, 102, 32, 123, 36, 112, 38, 49, 125, 32, 120, 61, 123, 36, 120,
  45, 49, 125, 10, 45, 101, 108, 105, 102, 32, 123, 36, 112, 38, 50, 125,
  32, 120, 61, 123, 36, 120, 43, 49, 125, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 112, 38, 52, 125, 32, 121, 61, 123, 36,
  121, 45, 49, 125, 10, 45, 101, 108, 105, 102, 32, 123, 36, 112, 38, 56,
  125, 32, 121, 61, 123, 36, 121, 43, 49, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 112, 38, 49, 54, 125, 32, 122, 61,
  123, 36, 122, 45, 49, 125, 10, 45, 101, 108, 105, 102, 32, 123, 36, 112,
  38, 51, 50, 125, 32, 122, 61, 123, 36, 122, 43, 49, 125, 10, 45, 101,
  110, 100, 105, 102, 10, 40, 36, 120, 59, 36, 121, 59, 36, 122, 41, 10,
  45, 119, 104, 105, 108, 101, 32, 36, 112, 10, 45, 114, 109, 91, 48, 44,
  45, 49, 93, 32, 45, 97, 32, 120, 10, 45, 110, 109, 32, 36, 110, 109,
  44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 109, 115, 101, 32, 58,
  32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  67, 111, 109, 112, 117, 116, 101, 32, 77, 83, 69, 32, 40, 77, 101, 97,
  110, 45, 83, 113, 117, 97, 114, 101, 100, 32, 69, 114, 114, 111, 114, 41,
  32, 109, 97, 116, 114, 105, 120, 32, 98, 101, 116, 119, 101, 101, 110, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 110, 111, 105, 115, 101, 32, 51, 48,
  32, 45, 45, 110, 111, 105, 115, 101, 91, 48, 93, 32, 51, 53, 32, 45,
  45, 110, 111, 105, 115, 101, 91, 48, 93, 32, 51, 56, 32, 45, 99, 117,
  116, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 109, 115, 101,
  10, 35, 64, 103, 109, 105, 99, 32, 112, 97, 116, 99, 104, 101, 115, 32,
  58, 32, 112, 97, 116, 99, 104, 95, 119, 105, 100, 116, 104, 62, 48, 44,
  112, 97, 116, 99, 104, 95, 104, 101, 105, 103, 104, 116, 62, 48, 44, 112,
  97, 116, 99, 104, 95, 100, 101, 112, 116, 104, 62, 48, 44, 120, 48, 44,
  121, 48, 44, 122, 48, 44, 95, 120, 49, 44, 95, 121, 49, 44, 95, 122,
  49, 44, 46, 46, 46, 44, 95, 120, 78, 44, 95, 121, 78, 44, 95, 122,
  78, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 69, 120, 116, 114, 97,
  99, 116, 32, 78, 43, 49, 32, 112, 97, 116, 99, 104, 101, 115, 32, 102,
  114, 111, 109, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 44, 32, 99, 101, 110, 116, 101, 114, 101, 100, 32, 97, 116,
  32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 108, 111, 99, 97, 116,
  105, 111, 110, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 112, 97, 116,
  99, 104, 101, 115, 32, 54, 52, 44, 54, 52, 44, 49, 44, 49, 53, 51,
  44, 49, 50, 52, 44, 48, 44, 49, 56, 52, 44, 50, 52, 48, 44, 48,
  44, 50, 49, 55, 44, 49, 50, 54, 44, 48, 44, 50, 55, 53, 44, 51,
  56, 44, 48, 10, 112, 97, 116, 99, 104, 101, 115, 32, 58, 32, 45, 99,
  104, 101, 99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 49, 41, 32,
  38, 38, 32, 36, 49, 62, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116,
  40, 36, 50, 41, 32, 38, 38, 32, 36, 50, 62, 48, 32, 38, 38, 32,
  105, 115, 105, 110, 116, 40, 36, 51, 41, 32, 38, 38, 32, 36, 51, 62,
  48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 69, 120, 116, 114,
  97, 99, 116, 32, 36, 49, 120, 36, 50, 120, 36, 51, 32, 112, 97, 116,
  99, 104, 101, 115, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 97, 116, 32, 108, 111, 99, 97, 116, 105, 111, 110, 115, 32,
  40, 36, 123, 52, 45, 45, 49, 125, 41, 46, 34, 10, 45, 118, 32, 45,
  10, 40, 36, 123, 52, 45, 45, 49, 125, 41, 32, 45, 114, 91, 45, 49,
  93, 32, 51, 44, 123, 119, 47, 51, 125, 44, 49, 44, 49, 44, 45, 49,
  32, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 49, 93, 32, 121, 122,
  99, 120, 32, 78, 61, 123, 119, 125, 10, 72, 61, 123, 105, 110, 116, 40,
  115, 113, 114, 116, 40, 119, 41, 41, 125, 32, 87, 61, 123, 114, 111, 117,
  110, 100, 40, 119, 47, 36, 72, 44, 49, 44, 49, 41, 125, 32, 45, 114,
  91, 45, 49, 93, 32, 123, 36, 87, 42, 36, 72, 125, 44, 49, 44, 49,
  44, 51, 44, 48, 32, 45, 114, 91, 45, 49, 93, 32, 36, 87, 44, 36,
  72, 44, 49, 44, 51, 44, 45, 49, 10, 45, 114, 91, 45, 49, 93, 32,
  123, 119, 42, 36, 49, 125, 44, 123, 104, 42, 36, 50, 125, 44, 123, 100,
  42, 36, 51, 125, 10, 36, 49, 44, 36, 50, 44, 36, 51, 44, 49, 44,
  120, 45, 123, 105, 110, 116, 40, 36, 49, 47, 50, 41, 125, 32, 45, 45,
  102, 91, 45, 49, 93, 32, 121, 45, 123, 105, 110, 116, 40, 36, 50, 47,
  50, 41, 125, 32, 45, 45, 102, 91, 45, 49, 93, 32, 122, 45, 123, 105,
  110, 116, 40, 36, 51, 47, 50, 41, 125, 32, 45, 97, 91, 45, 51, 45,
  45, 49, 93, 32, 99, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50,
  93, 44, 48, 44, 50, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 45,
  119, 97, 114, 112, 91, 36, 62, 93, 32, 91, 45, 49, 93, 44, 48, 44,
  48, 44, 48, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 60, 93, 32, 45, 115, 32, 121, 44, 36, 72, 32, 45, 115, 32, 120,
  44, 36, 87, 32, 45, 107, 91, 48, 45, 123, 36, 78, 45, 49, 125, 93,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 112, 108, 111, 116, 50, 118, 97,
  108, 117, 101, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116,
  114, 105, 101, 118, 101, 32, 118, 97, 108, 117, 101, 115, 32, 102, 114, 111,
  109, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 50, 100, 32, 103, 114,
  97, 112, 104, 32, 112, 108, 111, 116, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 52, 48, 48, 44, 51, 48, 48, 44, 49, 44,
  49, 44, 39, 105, 102, 40, 121, 62, 51, 48, 48, 42, 97, 98, 115, 40,
  99, 111, 115, 40, 120, 47, 49, 48, 43, 50, 42, 63, 41, 41, 44, 49,
  44, 48, 41, 39, 32, 45, 45, 112, 108, 111, 116, 50, 118, 97, 108, 117,
  101, 32, 45, 45, 100, 105, 115, 112, 108, 97, 121, 95, 103, 114, 97, 112,
  104, 91, 45, 49, 93, 32, 52, 48, 48, 44, 51, 48, 48, 10, 112, 108,
  111, 116, 50, 118, 97, 108, 117, 101, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 82, 101, 116, 114, 105, 101, 118, 101, 32, 118, 97, 108,
  117, 101, 115, 32, 102, 114, 111, 109, 32, 50, 100, 32, 103, 114, 97, 112,
  104, 32, 112, 108, 111, 116, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 115, 32, 99, 32, 45, 103, 101, 32, 53, 48, 37, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 40, 49, 44, 123, 119, 125, 41, 32, 45, 114, 91, 49, 93, 32, 91,
  48, 93, 44, 51, 32, 45, 42, 32, 45, 104, 105, 115, 116, 111, 103, 114,
  97, 109, 32, 123, 119, 125, 44, 49, 44, 123, 119, 125, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 97, 32, 99, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100,
  32, 58, 32, 95, 116, 121, 112, 101, 32, 61, 32, 123, 32, 45, 88, 61,
  45, 88, 45, 111, 112, 97, 99, 105, 116, 121, 32, 124, 32, 48, 61, 98,
  105, 110, 97, 114, 121, 32, 124, 32, 49, 61, 99, 117, 109, 117, 108, 97,
  116, 105, 118, 101, 32, 124, 32, 50, 61, 108, 97, 98, 101, 108, 32, 125,
  44, 95, 119, 105, 100, 116, 104, 44, 95, 104, 101, 105, 103, 104, 116, 62,
  48, 44, 95, 100, 101, 112, 116, 104, 62, 48, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 97, 32, 78, 120,
  49, 44, 32, 78, 120, 50, 44, 32, 78, 120, 51, 32, 111, 114, 32, 78,
  120, 77, 32, 105, 109, 97, 103, 101, 32, 97, 115, 32, 97, 32, 112, 111,
  105, 110, 116, 32, 99, 108, 111, 117, 100, 32, 105, 110, 32, 97, 32, 49,
  100, 47, 50, 100, 32, 111, 114, 32, 51, 100, 32, 98, 105, 110, 97, 114,
  121, 32, 105, 109, 97, 103, 101, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 73, 102, 32, 39, 77, 39, 62, 51, 44, 32, 116, 104, 101, 32,
  51, 45, 116, 111, 45, 77, 32, 108, 105, 110, 101, 115, 32, 115, 101, 116,
  115, 32, 116, 104, 101, 32, 40, 77, 45, 51, 41, 45, 100, 105, 109, 101,
  110, 115, 105, 111, 110, 97, 108, 32, 99, 111, 108, 111, 114, 32, 97, 116,
  32, 101, 97, 99, 104, 32, 112, 111, 105, 110, 116, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 80, 97, 114, 97, 109, 101, 116, 101, 114, 115,
  32, 39, 119, 105, 100, 116, 104, 39, 44, 39, 104, 101, 105, 103, 104, 116,
  39, 32, 97, 110, 100, 32, 39, 100, 101, 112, 116, 104, 39, 32, 97, 114,
  101, 32, 114, 101, 108, 97, 116, 101, 100, 32, 116, 111, 32, 116, 104, 101,
  32, 115, 105, 122, 101, 32, 111, 102, 32, 116, 104, 101, 32, 102, 105, 110,
  97, 108, 32, 105, 109, 97, 103, 101, 32, 58, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 32, 32, 45, 32, 73, 102, 32, 115, 101, 116, 32, 116,
  111, 32, 48, 44, 32, 116, 104, 101, 32, 115, 105, 122, 101, 32, 105, 115,
  32, 97, 117, 116, 111, 109, 97, 116, 105, 99, 97, 108, 108, 121, 32, 115,
  101, 116, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 115, 112, 101,
  99, 105, 102, 105, 101, 100, 32, 97, 120, 105, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 32, 32, 45, 32, 73, 102, 32, 115, 101, 116,
  32, 116, 111, 32, 78, 62, 48, 44, 32, 116, 104, 101, 32, 115, 105, 122,
  101, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 97, 120, 105, 115, 32, 105, 115, 32, 78, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 32, 32, 45, 32, 73, 102,
  32, 115, 101, 116, 32, 116, 111, 32, 78, 60, 48, 44, 32, 116, 104, 101,
  32, 115, 105, 122, 101, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32,
  115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 97, 120, 105, 115, 32, 105,
  115, 32, 97, 116, 32, 109, 111, 115, 116, 32, 78, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 80, 111, 105, 110, 116, 115, 32, 119, 105, 116,
  104, 32, 99, 111, 111, 114, 100, 105, 110, 97, 116, 101, 115, 32, 116, 104,
  97, 116, 32, 97, 114, 101, 32, 110, 101, 103, 97, 116, 105, 118, 101, 32,
  111, 114, 32, 104, 105, 103, 104, 101, 114, 32, 116, 104, 97, 110, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 40, 39, 119, 105, 100, 116, 104,
  39, 44, 39, 104, 101, 105, 103, 104, 116, 39, 44, 39, 100, 101, 112, 116,
  104, 39, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 97, 114, 101,
  32, 110, 111, 116, 32, 112, 108, 111, 116, 116, 101, 100, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 116, 121, 112, 101, 61, 48, 39, 32,
  97, 110, 100, 32, 39, 109, 97, 120, 95, 119, 105, 100, 116, 104, 61, 109,
  97, 120, 95, 104, 101, 105, 103, 104, 116, 61, 109, 97, 120, 95, 100, 101,
  112, 116, 104, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 51, 48, 48, 48, 44, 50, 32, 45, 114, 97, 110, 100, 32,
  48, 44, 52, 48, 48, 32, 45, 45, 112, 111, 105, 110, 116, 99, 108, 111,
  117, 100, 32, 48, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93,
  32, 51, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 51, 48,
  48, 48, 44, 50, 32, 45, 114, 97, 110, 100, 32, 48, 44, 52, 48, 48,
  32, 123, 119, 125, 32, 123, 119, 125, 44, 51, 32, 45, 114, 97, 110, 100,
  91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 97, 112, 112, 101,
  110, 100, 32, 121, 32, 45, 45, 112, 111, 105, 110, 116, 99, 108, 111, 117,
  100, 32, 48, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32,
  51, 10, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 32, 58, 32, 45,
  99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 48, 125, 60, 51, 34,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 48, 125, 44, 36, 123,
  51, 61, 48, 125, 44, 36, 123, 52, 61, 48, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97,
  103, 101, 36, 63, 32, 116, 111, 32, 112, 111, 105, 110, 116, 32, 99, 108,
  111, 117, 100, 115, 44, 32, 105, 110, 32, 34, 64, 123, 45, 97, 114, 103,
  92, 32, 50, 43, 40, 36, 49, 62, 61, 48, 41, 42, 36, 49, 45, 40,
  36, 49, 60, 48, 41, 44, 123, 45, 36, 49, 125, 45, 111, 112, 97, 99,
  105, 116, 121, 44, 98, 105, 110, 97, 114, 121, 44, 99, 117, 109, 117, 108,
  97, 116, 105, 118, 101, 44, 108, 97, 98, 101, 108, 105, 110, 103, 125, 34,
  32, 109, 111, 100, 101, 44, 34, 92, 10, 34, 119, 105, 116, 104, 32, 40,
  36, 50, 44, 36, 51, 44, 36, 52, 41, 32, 97, 115, 32, 109, 97, 120,
  105, 109, 97, 108, 32, 100, 105, 109, 101, 110, 115, 105, 111, 110, 115, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44,
  110, 125, 10, 45, 105, 102, 32, 123, 34, 100, 62, 49, 32, 124, 124, 32,
  115, 62, 49, 34, 125, 32, 45, 101, 114, 114, 111, 114, 32, 34, 73, 110,
  118, 97, 108, 105, 100, 32, 105, 110, 112, 117, 116, 32, 105, 109, 97, 103,
  101, 32, 34, 123, 119, 125, 120, 123, 104, 125, 120, 123, 100, 125, 120, 123,
  115, 125, 34, 46, 32, 83, 104, 111, 117, 108, 100, 32, 98, 101, 32, 78,
  120, 77, 120, 49, 120, 49, 46, 34, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 114, 111, 119, 115, 32, 48, 44, 123, 109, 97, 120, 40, 50, 44, 104,
  45, 49, 41, 125, 10, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 48,
  44, 48, 44, 48, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32,
  100, 120, 61, 123, 114, 111, 117, 110, 100, 40, 105, 102, 40, 36, 50, 61,
  61, 48, 44, 105, 77, 43, 49, 44, 105, 102, 40, 36, 50, 60, 48, 44,
  109, 105, 110, 40, 105, 77, 43, 49, 44, 45, 36, 50, 41, 44, 36, 50,
  41, 41, 41, 125, 10, 45, 115, 104, 91, 45, 50, 93, 32, 49, 44, 49,
  44, 48, 44, 48, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32,
  100, 121, 61, 123, 114, 111, 117, 110, 100, 40, 105, 102, 40, 36, 51, 61,
  61, 48, 44, 105, 77, 43, 49, 44, 105, 102, 40, 36, 51, 60, 48, 44,
  109, 105, 110, 40, 105, 77, 43, 49, 44, 45, 36, 51, 41, 44, 36, 51,
  41, 41, 41, 125, 10, 45, 115, 104, 91, 45, 51, 93, 32, 50, 44, 50,
  44, 48, 44, 48, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32,
  100, 122, 61, 123, 114, 111, 117, 110, 100, 40, 105, 102, 40, 36, 52, 61,
  61, 48, 44, 105, 77, 43, 49, 44, 105, 102, 40, 36, 52, 60, 48, 44,
  109, 105, 110, 40, 105, 77, 43, 49, 44, 45, 36, 52, 41, 44, 36, 52,
  41, 41, 41, 125, 10, 45, 42, 91, 45, 49, 93, 32, 36, 100, 121, 32,
  45, 43, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 102, 91, 45,
  49, 93, 32, 48, 32, 45, 114, 109, 91, 45, 51, 45, 45, 49, 93, 10,
  45, 115, 32, 120, 44, 45, 49, 48, 48, 48, 48, 48, 48, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  110, 98, 112, 61, 123, 119, 125, 10, 45, 105, 102, 32, 123, 104, 62, 51,
  125, 32, 45, 45, 114, 111, 119, 115, 32, 51, 44, 49, 48, 48, 37, 32,
  45, 114, 111, 119, 115, 91, 45, 50, 93, 32, 48, 44, 50, 32, 45, 101,
  108, 115, 101, 32, 49, 48, 48, 37, 44, 49, 44, 49, 44, 49, 44, 49,
  32, 45, 105, 102, 32, 123, 36, 49, 61, 61, 50, 125, 32, 45, 102, 91,
  45, 49, 93, 32, 49, 43, 120, 32, 45, 101, 110, 100, 105, 102, 32, 45,
  101, 110, 100, 105, 102, 10, 115, 112, 101, 99, 116, 114, 117, 109, 61, 123,
  104, 125, 32, 45, 105, 91, 45, 50, 93, 32, 40, 45, 49, 50, 56, 59,
  49, 59, 49, 59, 123, 104, 125, 41, 32, 45, 114, 91, 45, 50, 93, 32,
  123, 119, 125, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 10,
  45, 105, 91, 45, 51, 93, 32, 40, 123, 39, 67, 73, 109, 103, 51, 100,
  39, 125, 41, 32, 45, 116, 114, 97, 110, 115, 112, 111, 115, 101, 91, 45,
  51, 45, 45, 49, 93, 32, 45, 105, 91, 45, 51, 93, 32, 40, 36, 110,
  98, 112, 59, 36, 110, 98, 112, 41, 10, 45, 105, 91, 45, 50, 93, 32,
  49, 44, 36, 110, 98, 112, 44, 49, 44, 49, 44, 49, 32, 45, 105, 91,
  45, 50, 93, 32, 49, 44, 36, 110, 98, 112, 44, 49, 44, 49, 44, 121,
  32, 45, 97, 91, 45, 51, 44, 45, 50, 93, 32, 120, 10, 49, 44, 36,
  110, 98, 112, 44, 49, 44, 49, 44, 123, 105, 102, 40, 36, 49, 60, 48,
  44, 45, 36, 49, 44, 105, 102, 40, 36, 49, 61, 61, 49, 44, 45, 49,
  44, 49, 41, 41, 125, 10, 45, 121, 91, 45, 52, 45, 45, 50, 93, 32,
  45, 97, 32, 121, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 45, 43, 51, 100, 10, 36, 100, 120, 44, 123, 36, 100, 121, 42, 36,
  100, 122, 125, 44, 49, 44, 36, 115, 112, 101, 99, 116, 114, 117, 109, 32,
  45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 44, 48, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48,
  32, 45, 114, 109, 91, 45, 50, 93, 32, 45, 114, 91, 45, 49, 93, 32,
  36, 100, 120, 44, 36, 100, 121, 44, 36, 100, 122, 44, 49, 48, 48, 37,
  44, 45, 49, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 112, 115, 110, 114, 32, 58, 32, 95, 109, 97,
  120, 95, 118, 97, 108, 117, 101, 32, 58, 32, 40, 43, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 80,
  83, 78, 82, 32, 40, 80, 101, 97, 107, 32, 83, 105, 103, 110, 97, 108,
  45, 116, 111, 45, 78, 111, 105, 115, 101, 32, 82, 97, 116, 105, 111, 41,
  32, 109, 97, 116, 114, 105, 120, 32, 98, 101, 116, 119, 101, 101, 110, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108,
  116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 109, 97, 120, 95, 118, 97,
  108, 117, 101, 61, 50, 53, 53, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  45, 110, 111, 105, 115, 101, 32, 51, 48, 32, 45, 45, 110, 111, 105, 115,
  101, 91, 48, 93, 32, 51, 53, 32, 45, 45, 110, 111, 105, 115, 101, 91,
  48, 93, 32, 51, 56, 32, 45, 99, 117, 116, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 32, 45, 112, 115, 110, 114, 32, 50, 53, 53, 32, 45,
  114, 101, 112, 108, 97, 99, 101, 95, 105, 110, 102, 32, 48, 10, 112, 115,
  110, 114, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 50,
  53, 53, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109,
  112, 117, 116, 101, 32, 116, 104, 101, 32, 34, 64, 35, 120, 64, 35, 34,
  32, 109, 97, 116, 114, 105, 120, 32, 111, 102, 32, 80, 83, 78, 82, 32,
  118, 97, 108, 117, 101, 115, 44, 32, 102, 114, 111, 109, 32, 105, 109, 97,
  103, 101, 36, 63, 32, 119, 105, 116, 104, 32, 109, 97, 120, 105, 109, 117,
  109, 32, 118, 97, 108, 117, 101, 32, 36, 49, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 109, 115, 101, 32, 45, 108, 111, 103, 49, 48, 32, 45, 45,
  32, 123, 108, 111, 103, 49, 48, 40, 36, 49, 42, 36, 49, 41, 125, 32,
  45, 42, 32, 45, 49, 48, 32, 45, 110, 109, 91, 45, 49, 93, 32, 91,
  80, 83, 78, 82, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 115, 101, 103, 109, 101, 110, 116, 95, 119, 97, 116, 101, 114, 115,
  104, 101, 100, 32, 58, 32, 95, 116, 104, 114, 101, 115, 104, 111, 108, 100,
  62, 61, 48, 44, 95, 102, 105, 108, 108, 95, 108, 105, 110, 101, 115, 61,
  123, 32, 48, 32, 124, 32, 49, 32, 125, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 65, 112, 112, 108, 121, 32, 119, 97, 116, 101, 114, 115, 104,
  101, 100, 32, 115, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111, 110, 32,
  111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 116, 104,
  114, 101, 115, 104, 111, 108, 100, 61, 50, 39, 32, 97, 110, 100, 32, 39,
  102, 105, 108, 108, 95, 108, 105, 110, 101, 115, 61, 49, 39, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 45, 115, 101, 103, 109, 101, 110, 116, 95, 119, 97,
  116, 101, 114, 115, 104, 101, 100, 32, 50, 44, 48, 10, 115, 101, 103, 109,
  101, 110, 116, 95, 119, 97, 116, 101, 114, 115, 104, 101, 100, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 50, 125, 62, 61,
  48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 49, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 119,
  97, 116, 101, 114, 115, 104, 101, 100, 32, 115, 101, 103, 109, 101, 110, 116,
  97, 116, 105, 111, 110, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63,
  44, 32, 119, 105, 116, 104, 32, 101, 100, 103, 101, 32, 116, 104, 114, 101,
  115, 104, 111, 108, 100, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 43, 32, 123, 49, 43, 64, 123, 45, 49, 44, 109, 125, 125,
  32, 45, 45, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109,
  10, 45, 105, 102, 32, 123, 100, 62, 49, 125, 32, 45, 45, 102, 91, 45,
  49, 93, 32, 34, 105, 102, 40, 105, 60, 36, 49, 32, 38, 38, 32, 105,
  60, 106, 40, 49, 41, 32, 38, 38, 32, 105, 60, 106, 40, 45, 49, 41,
  32, 38, 38, 32, 105, 60, 106, 40, 48, 44, 49, 41, 32, 38, 38, 32,
  105, 60, 106, 40, 48, 44, 45, 49, 41, 32, 38, 38, 32, 105, 60, 106,
  40, 48, 44, 48, 44, 49, 41, 32, 38, 38, 32, 105, 60, 106, 40, 48,
  44, 48, 44, 45, 49, 41, 44, 49, 44, 48, 41, 34, 10, 45, 101, 108,
  115, 101, 32, 45, 45, 102, 91, 45, 49, 93, 32, 34, 105, 102, 40, 105,
  60, 36, 49, 32, 38, 38, 32, 105, 60, 106, 40, 49, 41, 32, 38, 38,
  32, 105, 60, 106, 40, 45, 49, 41, 32, 38, 38, 32, 105, 60, 106, 40,
  48, 44, 49, 41, 32, 38, 38, 32, 105, 60, 106, 40, 48, 44, 45, 49,
  41, 44, 49, 44, 48, 41, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  42, 91, 45, 51, 44, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32,
  45, 49, 32, 45, 119, 97, 116, 101, 114, 115, 104, 101, 100, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 44, 36, 50, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 107, 101, 108, 101, 116,
  111, 110, 32, 58, 32, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  91, 37, 93, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  67, 111, 109, 112, 117, 116, 101, 32, 115, 107, 101, 108, 101, 116, 111, 110,
  32, 111, 102, 32, 98, 105, 110, 97, 114, 121, 32, 115, 104, 97, 112, 101,
  115, 32, 117, 115, 105, 110, 103, 32, 100, 105, 115, 116, 97, 110, 99, 101,
  32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108,
  117, 101, 58, 32, 39, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61,
  48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 116, 104, 114, 101, 115, 104,
  111, 108, 100, 32, 53, 48, 37, 32, 45, 45, 115, 107, 101, 108, 101, 116,
  111, 110, 32, 48, 10, 115, 107, 101, 108, 101, 116, 111, 110, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 36, 123, 49, 61, 48, 125, 62, 61, 48,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116,
  101, 32, 115, 107, 101, 108, 101, 116, 111, 110, 32, 111, 102, 32, 98, 105,
  110, 97, 114, 121, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 103, 101, 32, 53, 48, 37, 32, 45, 100, 105, 115,
  116, 97, 110, 99, 101, 32, 48, 32, 45, 98, 32, 36, 49, 32, 45, 115,
  104, 97, 114, 112, 101, 110, 32, 49, 101, 49, 48, 32, 45, 103, 101, 32,
  49, 48, 48, 37, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 45, 101, 114, 111, 100, 101, 91, 36, 62, 93, 32, 50, 32, 45, 45,
  91, 36, 62, 44, 45, 49, 93, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 115, 100, 95, 112, 97,
  116, 99, 104, 32, 58, 32, 95, 117, 115, 101, 95, 102, 111, 117, 114, 105,
  101, 114, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 44, 95, 98, 111,
  117, 110, 100, 97, 114, 121, 95, 99, 111, 110, 100, 105, 116, 105, 111, 110,
  115, 61, 123, 32, 48, 61, 100, 105, 114, 105, 99, 104, 108, 101, 116, 32,
  124, 32, 49, 61, 110, 101, 117, 109, 97, 110, 110, 32, 125, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 102,
  105, 101, 108, 100, 32, 111, 102, 32, 83, 83, 68, 32, 98, 101, 116, 119,
  101, 101, 110, 32, 97, 110, 32, 105, 109, 97, 103, 101, 32, 97, 110, 100,
  32, 97, 32, 112, 97, 116, 99, 104, 44, 32, 116, 97, 107, 101, 110, 32,
  97, 115, 32, 99, 111, 110, 115, 101, 99, 117, 116, 105, 118, 101, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 114, 103, 117, 109, 101, 110,
  116, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 95, 99, 111, 110, 100,
  105, 116, 105, 111, 110, 115, 39, 32, 105, 115, 32, 118, 97, 108, 105, 100,
  32, 111, 110, 108, 121, 32, 119, 104, 101, 110, 32, 39, 117, 115, 101, 95,
  102, 111, 117, 114, 105, 101, 114, 61, 48, 39, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108,
  117, 101, 58, 32, 39, 117, 115, 101, 95, 102, 111, 117, 114, 105, 101, 114,
  61, 48, 39, 32, 97, 110, 100, 32, 39, 98, 111, 117, 110, 100, 97, 114,
  121, 95, 99, 111, 110, 100, 105, 116, 105, 111, 110, 115, 61, 48, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 99, 114, 111, 112, 32, 50, 48, 37,
  44, 50, 48, 37, 44, 51, 53, 37, 44, 51, 53, 37, 32, 45, 45, 115,
  115, 100, 95, 112, 97, 116, 99, 104, 32, 48, 44, 48, 10, 115, 115, 100,
  95, 112, 97, 116, 99, 104, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 49, 61, 48, 125, 44, 36, 123, 50, 61, 48, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 102, 105,
  101, 108, 100, 32, 111, 102, 32, 83, 83, 68, 32, 98, 101, 116, 119, 101,
  101, 110, 32, 105, 109, 97, 103, 101, 115, 32, 97, 110, 100, 32, 112, 97,
  116, 99, 104, 115, 32, 117, 115, 105, 110, 103, 32, 34, 64, 123, 45, 97,
  114, 103, 92, 32, 49, 43, 33, 36, 49, 44, 102, 111, 117, 114, 105, 101,
  114, 44, 115, 112, 97, 116, 105, 97, 108, 125, 34, 32, 109, 111, 100, 101,
  44, 32, 105, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116,
  40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36,
  62, 43, 49, 125, 93, 10, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 64, 123, 45, 109, 97, 120, 95, 115,
  125, 32, 45, 115, 32, 99, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  64, 35, 47, 50, 125, 32, 45, 108, 91, 36, 62, 44, 123, 45, 49, 45,
  36, 60, 125, 93, 10, 45, 45, 115, 113, 114, 91, 49, 93, 32, 118, 97,
  108, 61, 64, 123, 45, 49, 44, 43, 125, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 45, 115, 113, 114, 91, 48, 93, 32, 45, 45, 102, 91, 49,
  93, 32, 49, 10, 45, 105, 102, 32, 36, 49, 10, 45, 99, 111, 110, 118,
  111, 108, 118, 101, 95, 102, 102, 116, 91, 45, 50, 44, 45, 49, 93, 10,
  45, 109, 105, 114, 114, 111, 114, 91, 49, 93, 32, 120, 121, 122, 32, 45,
  99, 111, 110, 118, 111, 108, 118, 101, 95, 102, 102, 116, 91, 48, 44, 49,
  93, 10, 45, 101, 108, 115, 101, 10, 45, 99, 111, 114, 114, 101, 108, 97,
  116, 101, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 50, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 99, 111, 114, 114, 101, 108, 97, 116,
  101, 91, 48, 93, 32, 91, 49, 93, 44, 36, 50, 32, 45, 114, 109, 91,
  49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 42, 91, 48, 93, 32,
  45, 50, 32, 45, 43, 91, 48, 44, 49, 93, 32, 45, 43, 32, 36, 118,
  97, 108, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  43, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 116, 104, 105, 110, 110, 105,
  110, 103, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112,
  117, 116, 101, 32, 115, 107, 101, 108, 101, 116, 111, 110, 32, 111, 102, 32,
  98, 105, 110, 97, 114, 121, 32, 115, 104, 97, 112, 101, 115, 32, 117, 115,
  105, 110, 103, 32, 109, 111, 114, 112, 104, 111, 108, 111, 103, 105, 99, 97,
  108, 32, 116, 104, 105, 110, 110, 105, 110, 103, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 40, 84, 104, 105, 115, 32, 105, 115, 32, 97, 32, 113,
  117, 105, 116, 101, 32, 115, 108, 111, 119, 32, 105, 116, 101, 114, 97, 116,
  105, 118, 101, 32, 112, 114, 111, 99, 101, 115, 41, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 53, 48, 37, 32,
  45, 45, 116, 104, 105, 110, 110, 105, 110, 103, 10, 116, 104, 105, 110, 110,
  105, 110, 103, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67,
  111, 109, 112, 117, 116, 101, 32, 115, 107, 101, 108, 101, 116, 111, 110, 32,
  111, 102, 32, 98, 105, 110, 97, 114, 121, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 117, 115, 105, 110, 103, 32, 109, 111, 114, 112, 104, 111, 108,
  111, 103, 105, 99, 97, 108, 32, 116, 104, 105, 110, 110, 105, 110, 103, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 103, 101, 32, 53, 48, 37, 32, 45,
  42, 32, 50, 32, 45, 45, 32, 49, 10, 40, 45, 49, 44, 45, 49, 44,
  45, 49, 59, 48, 44, 49, 44, 48, 59, 49, 44, 49, 44, 49, 41, 32,
  40, 48, 44, 45, 49, 44, 45, 49, 59, 49, 44, 49, 44, 45, 49, 59,
  48, 44, 49, 44, 48, 41, 32, 45, 45, 114, 111, 116, 97, 116, 101, 91,
  45, 50, 44, 45, 49, 93, 32, 57, 48, 32, 45, 45, 114, 111, 116, 97,
  116, 101, 91, 45, 50, 44, 45, 49, 93, 32, 57, 48, 32, 45, 45, 114,
  111, 116, 97, 116, 101, 91, 45, 50, 44, 45, 49, 93, 32, 57, 48, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 56, 125, 10, 98,
  97, 118, 103, 61, 64, 123, 45, 57, 44, 43, 125, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 57, 57, 57, 57, 57, 10, 45, 45, 99, 111, 114, 114,
  101, 108, 97, 116, 101, 91, 45, 57, 93, 32, 91, 45, 56, 93, 32, 45,
  103, 101, 91, 45, 49, 93, 32, 55, 32, 45, 42, 91, 45, 49, 93, 32,
  50, 32, 45, 45, 91, 45, 49, 48, 44, 45, 49, 93, 10, 45, 45, 99,
  111, 114, 114, 101, 108, 97, 116, 101, 91, 45, 57, 93, 32, 91, 45, 55,
  93, 32, 45, 103, 101, 91, 45, 49, 93, 32, 54, 32, 45, 42, 91, 45,
  49, 93, 32, 50, 32, 45, 45, 91, 45, 49, 48, 44, 45, 49, 93, 10,
  45, 45, 99, 111, 114, 114, 101, 108, 97, 116, 101, 91, 45, 57, 93, 32,
  91, 45, 54, 93, 32, 45, 103, 101, 91, 45, 49, 93, 32, 55, 32, 45,
  42, 91, 45, 49, 93, 32, 50, 32, 45, 45, 91, 45, 49, 48, 44, 45,
  49, 93, 10, 45, 45, 99, 111, 114, 114, 101, 108, 97, 116, 101, 91, 45,
  57, 93, 32, 91, 45, 53, 93, 32, 45, 103, 101, 91, 45, 49, 93, 32,
  54, 32, 45, 42, 91, 45, 49, 93, 32, 50, 32, 45, 45, 91, 45, 49,
  48, 44, 45, 49, 93, 10, 45, 45, 99, 111, 114, 114, 101, 108, 97, 116,
  101, 91, 45, 57, 93, 32, 91, 45, 52, 93, 32, 45, 103, 101, 91, 45,
  49, 93, 32, 55, 32, 45, 42, 91, 45, 49, 93, 32, 50, 32, 45, 45,
  91, 45, 49, 48, 44, 45, 49, 93, 10, 45, 45, 99, 111, 114, 114, 101,
  108, 97, 116, 101, 91, 45, 57, 93, 32, 91, 45, 51, 93, 32, 45, 103,
  101, 91, 45, 49, 93, 32, 54, 32, 45, 42, 91, 45, 49, 93, 32, 50,
  32, 45, 45, 91, 45, 49, 48, 44, 45, 49, 93, 10, 45, 45, 99, 111,
  114, 114, 101, 108, 97, 116, 101, 91, 45, 57, 93, 32, 91, 45, 50, 93,
  32, 45, 103, 101, 91, 45, 49, 93, 32, 55, 32, 45, 42, 91, 45, 49,
  93, 32, 50, 32, 45, 45, 91, 45, 49, 48, 44, 45, 49, 93, 10, 45,
  45, 99, 111, 114, 114, 101, 108, 97, 116, 101, 91, 45, 57, 93, 32, 91,
  45, 49, 93, 32, 45, 103, 101, 91, 45, 49, 93, 32, 54, 32, 45, 42,
  91, 45, 49, 93, 32, 50, 32, 45, 45, 91, 45, 49, 48, 44, 45, 49,
  93, 10, 97, 97, 118, 103, 61, 64, 123, 45, 57, 44, 43, 125, 32, 45,
  105, 102, 32, 123, 36, 97, 97, 118, 103, 61, 61, 36, 98, 97, 118, 103,
  125, 32, 45, 98, 114, 101, 97, 107, 32, 45, 101, 110, 100, 105, 102, 32,
  98, 97, 118, 103, 61, 36, 97, 97, 118, 103, 10, 45, 100, 111, 110, 101,
  10, 45, 109, 118, 91, 45, 57, 93, 32, 48, 32, 45, 100, 111, 110, 101,
  32, 45, 114, 109, 91, 45, 56, 45, 45, 49, 93, 32, 45, 43, 32, 49,
  32, 45, 47, 32, 50, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 116, 111, 110, 101, 115, 32, 58, 32, 78, 62, 48, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 71, 101, 116, 32, 78, 32, 116, 111, 110,
  101, 115, 32, 109, 97, 115, 107, 115, 32, 102, 114, 111, 109, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 45, 116, 111, 110, 101, 115, 32, 51, 10, 116, 111,
  110, 101, 115, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 49, 62,
  48, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 71, 101, 116, 32, 36,
  49, 32, 116, 111, 110, 101, 115, 32, 109, 97, 115, 107, 115, 32, 102, 114,
  111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 110, 111, 114, 109, 32, 45, 110, 32, 48, 44, 123, 36, 49,
  45, 49, 125, 32, 45, 114, 111, 117, 110, 100, 32, 49, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 60, 93, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 36, 49, 45, 49, 125, 32, 45, 45,
  61, 61, 91, 48, 93, 32, 123, 49, 43, 36, 62, 125, 32, 45, 100, 111,
  110, 101, 32, 45, 61, 61, 91, 48, 93, 32, 48, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 116, 111, 112, 111, 103, 114, 97, 112, 104, 105, 99, 95,
  109, 97, 112, 32, 58, 32, 95, 110, 98, 95, 108, 101, 118, 101, 108, 115,
  62, 48, 44, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 110, 100, 101, 114, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 97,
  115, 32, 116, 111, 112, 111, 103, 114, 97, 112, 104, 105, 99, 32, 109, 97,
  112, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 110, 98,
  95, 108, 101, 118, 101, 108, 115, 61, 49, 54, 39, 32, 97, 110, 100, 32,
  39, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 50, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 45, 116, 111, 112, 111, 103, 114, 97, 112, 104,
  105, 99, 95, 109, 97, 112, 32, 49, 48, 10, 116, 111, 112, 111, 103, 114,
  97, 112, 104, 105, 99, 95, 109, 97, 112, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 49, 54,
  125, 41, 32, 38, 38, 32, 36, 49, 62, 48, 34, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 50, 61, 50, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 82, 101, 110, 100, 101, 114, 32, 116, 111, 112, 111, 103, 114, 97,
  112, 104, 105, 99, 32, 109, 97, 112, 115, 32, 102, 114, 111, 109, 32, 105,
  109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 36, 49, 32,
  108, 101, 118, 101, 108, 115, 32, 97, 110, 100, 32, 115, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 45, 98, 32, 36, 50, 32, 45, 105, 115, 111, 112, 104, 111,
  116, 101, 115, 91, 45, 49, 93, 32, 36, 49, 32, 45, 99, 111, 109, 112,
  111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93,
  32, 43, 32, 45, 61, 61, 91, 45, 49, 93, 32, 48, 32, 45, 98, 108,
  101, 110, 100, 32, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97, 103, 101,
  48, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 58, 58, 32, 73, 109, 97,
  103, 101, 32, 100, 114, 97, 119, 105, 110, 103, 10, 35, 64, 103, 109, 105,
  99, 32, 97, 120, 101, 115, 32, 58, 32, 120, 48, 44, 120, 49, 44, 121,
  48, 44, 121, 49, 44, 95, 102, 111, 110, 116, 95, 104, 101, 105, 103, 104,
  116, 62, 61, 48, 44, 95, 111, 112, 97, 99, 105, 116, 121, 44, 95, 112,
  97, 116, 116, 101, 114, 110, 44, 95, 99, 111, 108, 111, 114, 49, 44, 46,
  46, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 114, 97, 119, 32, 120, 121, 45, 97, 120, 101, 115, 32, 111, 110,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 112, 97, 116, 116,
  101, 114, 110, 39, 32, 105, 115, 32, 97, 110, 32, 104, 101, 120, 97, 100,
  101, 99, 105, 109, 97, 108, 32, 110, 117, 109, 98, 101, 114, 32, 115, 116,
  97, 114, 116, 105, 110, 103, 32, 119, 105, 116, 104, 32, 39, 48, 120, 39,
  32, 119, 104, 105, 99, 104, 32, 99, 97, 110, 32, 98, 101, 32, 111, 109,
  105, 116, 116, 101, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 101,
  118, 101, 110, 32, 105, 102, 32, 97, 32, 99, 111, 108, 111, 114, 32, 105,
  115, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 84, 111, 32, 100, 114, 97, 119, 32, 111, 110,
  108, 121, 32, 111, 110, 101, 32, 120, 45, 97, 120, 105, 115, 32, 97, 116,
  32, 114, 111, 119, 32, 89, 44, 32, 115, 101, 116, 32, 98, 111, 116, 104,
  32, 39, 121, 48, 39, 32, 97, 110, 100, 32, 39, 121, 49, 39, 32, 116,
  111, 32, 89, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 84, 111,
  32, 100, 114, 97, 119, 32, 111, 110, 108, 121, 32, 111, 110, 101, 32, 121,
  45, 97, 120, 105, 115, 32, 97, 116, 32, 99, 111, 108, 117, 109, 110, 32,
  88, 44, 32, 115, 101, 116, 32, 98, 111, 116, 104, 32, 39, 120, 48, 39,
  32, 97, 110, 100, 32, 39, 120, 49, 39, 32, 116, 111, 32, 88, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116,
  32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 102, 111, 110, 116, 95, 104,
  101, 105, 103, 104, 116, 61, 49, 51, 39, 44, 32, 39, 111, 112, 97, 99,
  105, 116, 121, 61, 49, 39, 44, 32, 39, 112, 97, 116, 116, 101, 114, 110,
  61, 40, 117, 110, 100, 101, 102, 105, 110, 101, 100, 41, 39, 32, 97, 110,
  100, 32, 39, 99, 111, 108, 111, 114, 49, 61, 48, 39, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 52, 48, 48, 44, 52, 48, 48,
  44, 49, 44, 51, 44, 50, 53, 53, 32, 45, 97, 120, 101, 115, 32, 45,
  49, 44, 49, 44, 49, 44, 45, 49, 10, 35, 64, 103, 109, 105, 99, 32,
  98, 97, 108, 108, 32, 58, 32, 95, 115, 105, 122, 101, 62, 48, 44, 32,
  95, 82, 44, 95, 71, 44, 95, 66, 44, 48, 60, 61, 95, 115, 112, 101,
  99, 117, 108, 97, 114, 95, 108, 105, 103, 104, 116, 60, 61, 56, 44, 48,
  60, 61, 95, 115, 112, 101, 99, 117, 108, 97, 114, 95, 115, 105, 122, 101,
  60, 61, 56, 44, 95, 115, 104, 97, 100, 111, 119, 62, 61, 48, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 73, 110, 112, 117, 116, 32, 97, 32,
  50, 100, 32, 82, 71, 66, 65, 32, 99, 111, 108, 111, 114, 101, 100, 32,
  98, 97, 108, 108, 32, 115, 112, 114, 105, 116, 101, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 115, 105, 122, 101, 61, 54, 52, 39, 44,
  32, 39, 82, 61, 50, 53, 53, 39, 44, 32, 39, 71, 61, 82, 39, 44,
  32, 39, 66, 61, 82, 39, 44, 32, 39, 115, 112, 101, 99, 117, 108, 97,
  114, 95, 108, 105, 103, 104, 116, 61, 48, 46, 56, 39, 44, 32, 39, 115,
  112, 101, 99, 117, 108, 97, 114, 95, 115, 105, 122, 101, 61, 49, 39, 32,
  97, 110, 100, 32, 39, 115, 104, 97, 100, 105, 110, 103, 61, 49, 46, 53,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 57, 32, 45, 98, 97, 108, 108, 32, 123, 49,
  46, 53, 94, 40, 36, 62, 43, 50, 41, 125, 44, 64, 123, 45, 82, 71,
  66, 125, 32, 45, 100, 111, 110, 101, 32, 45, 97, 112, 112, 101, 110, 100,
  32, 120, 10, 98, 97, 108, 108, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 34, 36, 123, 49, 61, 54, 52, 125, 62, 48, 32, 38, 38, 32, 36,
  123, 53, 61, 48, 46, 56, 125, 62, 61, 48, 32, 38, 38, 32, 36, 53,
  60, 61, 56, 32, 38, 38, 32, 36, 123, 54, 61, 49, 125, 62, 61, 48,
  32, 36, 54, 60, 61, 56, 32, 38, 38, 32, 36, 123, 55, 61, 49, 46,
  53, 125, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50,
  61, 50, 53, 53, 125, 44, 36, 123, 51, 61, 36, 50, 125, 44, 36, 123,
  52, 61, 36, 51, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73,
  110, 112, 117, 116, 32, 36, 49, 120, 36, 49, 32, 98, 97, 108, 108, 32,
  119, 105, 116, 104, 32, 99, 111, 108, 111, 114, 32, 40, 36, 123, 50, 45,
  52, 125, 41, 44, 32, 115, 112, 101, 99, 117, 108, 97, 114, 32, 108, 105,
  103, 104, 116, 32, 36, 53, 44, 32, 115, 112, 101, 99, 117, 108, 97, 114,
  32, 115, 105, 122, 101, 32, 36, 54, 32, 97, 110, 100, 32, 115, 104, 97,
  100, 111, 119, 32, 102, 97, 99, 116, 111, 114, 32, 36, 55, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 108, 91, 93, 10, 123, 50, 42, 36, 49, 125,
  44, 123, 50, 42, 36, 49, 125, 32, 45, 61, 32, 49, 44, 54, 53, 37,
  44, 51, 48, 37, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101, 32, 49,
  32, 45, 42, 32, 45, 49, 10, 45, 45, 110, 32, 48, 44, 49, 32, 45,
  112, 111, 119, 91, 49, 93, 32, 36, 55, 32, 45, 42, 91, 49, 93, 32,
  49, 46, 52, 32, 45, 45, 42, 91, 49, 93, 32, 36, 51, 32, 45, 45,
  42, 91, 49, 93, 32, 36, 52, 32, 45, 42, 91, 49, 93, 32, 36, 50,
  32, 45, 97, 91, 94, 48, 93, 32, 99, 10, 45, 103, 101, 91, 48, 93,
  32, 123, 49, 48, 48, 45, 49, 48, 42, 36, 54, 125, 37, 32, 45, 98,
  91, 48, 93, 32, 123, 51, 42, 36, 54, 125, 37, 32, 45, 110, 91, 48,
  93, 32, 48, 44, 123, 36, 53, 42, 50, 53, 53, 125, 32, 45, 114, 118,
  32, 45, 43, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 32, 45, 99, 105, 114, 99, 108, 101, 91, 49,
  93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 51, 52, 37, 44, 49, 44,
  49, 32, 45, 42, 91, 48, 93, 32, 91, 49, 93, 32, 45, 42, 91, 45,
  49, 93, 32, 50, 53, 53, 32, 45, 97, 32, 99, 10, 45, 114, 32, 36,
  49, 44, 36, 49, 44, 49, 44, 52, 44, 50, 10, 45, 101, 110, 100, 108,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 99, 104, 101,
  115, 115, 98, 111, 97, 114, 100, 32, 58, 32, 115, 105, 122, 101, 49, 62,
  48, 44, 95, 115, 105, 122, 101, 50, 62, 48, 44, 95, 111, 102, 102, 115,
  101, 116, 49, 44, 95, 111, 102, 102, 115, 101, 116, 50, 44, 95, 97, 110,
  103, 108, 101, 44, 95, 111, 112, 97, 99, 105, 116, 121, 44, 95, 99, 111,
  108, 111, 114, 49, 44, 46, 46, 44, 95, 99, 111, 108, 111, 114, 50, 44,
  46, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 114, 97, 119,
  32, 99, 104, 101, 115, 115, 98, 111, 97, 114, 100, 32, 111, 110, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116,
  32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 115, 105, 122, 101, 50, 61,
  115, 105, 122, 101, 49, 39, 44, 32, 39, 111, 102, 102, 115, 101, 116, 49,
  61, 111, 102, 102, 115, 101, 116, 50, 61, 48, 39, 44, 32, 39, 97, 110,
  103, 108, 101, 61, 48, 39, 44, 32, 39, 111, 112, 97, 99, 105, 116, 121,
  61, 49, 39, 44, 32, 39, 99, 111, 108, 111, 114, 49, 61, 48, 39, 32,
  97, 110, 100, 32, 39, 99, 111, 108, 111, 114, 50, 61, 50, 53, 53, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 99, 104, 101, 115, 115, 98, 111, 97,
  114, 100, 32, 51, 50, 44, 51, 50, 44, 48, 44, 48, 44, 50, 53, 44,
  48, 46, 51, 44, 50, 53, 53, 44, 49, 50, 56, 44, 48, 44, 48, 44,
  49, 50, 56, 44, 50, 53, 53, 10, 99, 104, 101, 115, 115, 98, 111, 97,
  114, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62,
  48, 32, 38, 38, 32, 36, 123, 50, 61, 36, 49, 125, 62, 48, 34, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 48, 125, 44, 36, 123, 52,
  61, 48, 125, 44, 36, 123, 53, 61, 48, 125, 44, 36, 123, 54, 61, 49,
  125, 44, 36, 123, 55, 61, 48, 125, 44, 36, 123, 56, 61, 50, 53, 53,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 114, 97, 119, 32,
  99, 104, 101, 115, 115, 98, 111, 97, 114, 100, 32, 111, 110, 32, 105, 109,
  97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101,
  115, 32, 40, 36, 49, 44, 36, 50, 41, 44, 32, 111, 102, 102, 115, 101,
  116, 115, 32, 40, 36, 51, 44, 36, 52, 41, 44, 32, 97, 110, 103, 108,
  101, 32, 36, 53, 32, 100, 101, 103, 46, 44, 32, 111, 112, 97, 99, 105,
  116, 121, 32, 36, 54, 32, 97, 110, 100, 32, 99, 111, 108, 111, 114, 115,
  32, 40, 36, 123, 55, 45, 45, 49, 125, 41, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 105, 91, 48, 93, 32, 40, 36, 123, 55, 45, 45, 49, 125,
  41, 32, 45, 114, 91, 48, 93, 32, 123, 64, 123, 48, 44, 119, 125, 47,
  50, 125, 44, 49, 44, 49, 44, 50, 44, 45, 49, 32, 45, 112, 101, 114,
  109, 117, 116, 101, 91, 48, 93, 32, 99, 121, 122, 120, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 10, 119, 61, 123, 119,
  125, 32, 104, 61, 123, 104, 125, 32, 116, 104, 101, 116, 97, 61, 123, 36,
  53, 42, 112, 105, 47, 49, 56, 48, 125, 10, 40, 36, 51, 44, 123, 36,
  51, 43, 36, 119, 45, 49, 125, 59, 36, 51, 44, 123, 36, 51, 43, 36,
  119, 45, 49, 125, 94, 36, 52, 44, 36, 52, 59, 123, 36, 52, 43, 36,
  104, 45, 49, 125, 44, 123, 36, 52, 43, 36, 104, 45, 49, 125, 41, 32,
  45, 114, 91, 45, 49, 93, 32, 36, 119, 44, 36, 104, 44, 49, 44, 50,
  44, 51, 10, 45, 114, 91, 45, 49, 93, 32, 123, 36, 119, 42, 36, 104,
  125, 44, 50, 44, 49, 44, 49, 44, 45, 49, 10, 45, 105, 91, 45, 50,
  93, 32, 40, 123, 99, 111, 115, 40, 36, 116, 104, 101, 116, 97, 41, 125,
  44, 123, 45, 115, 105, 110, 40, 36, 116, 104, 101, 116, 97, 41, 125, 59,
  123, 115, 105, 110, 40, 36, 116, 104, 101, 116, 97, 41, 125, 44, 123, 99,
  111, 115, 40, 36, 116, 104, 101, 116, 97, 41, 125, 41, 32, 45, 42, 42,
  91, 45, 50, 44, 45, 49, 93, 10, 45, 114, 91, 45, 49, 93, 32, 36,
  119, 44, 36, 104, 44, 49, 44, 50, 44, 45, 49, 10, 45, 37, 91, 45,
  49, 93, 32, 123, 36, 49, 43, 36, 50, 125, 32, 45, 62, 61, 91, 45,
  49, 93, 32, 36, 49, 32, 45, 115, 91, 45, 49, 93, 32, 99, 32, 45,
  120, 111, 114, 91, 45, 50, 44, 45, 49, 93, 32, 45, 109, 97, 112, 91,
  45, 49, 93, 32, 91, 48, 93, 32, 45, 114, 91, 45, 49, 93, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 91, 45, 50, 93, 10,
  45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 36, 54, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  109, 118, 91, 45, 49, 93, 32, 49, 32, 45, 100, 111, 110, 101, 32, 45,
  114, 109, 91, 48, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 99, 105, 101, 49, 57, 51, 49, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 114, 97, 119, 32, 67, 73, 69, 45, 49, 57, 51, 49,
  32, 99, 104, 114, 111, 109, 97, 116, 105, 99, 105, 116, 121, 32, 100, 105,
  97, 103, 114, 97, 109, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 53, 48, 48, 44, 52, 48, 48, 44, 49, 44, 51,
  32, 45, 99, 105, 101, 49, 57, 51, 49, 10, 99, 105, 101, 49, 57, 51,
  49, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 114, 97,
  119, 32, 67, 73, 69, 45, 49, 57, 51, 49, 32, 99, 104, 114, 111, 109,
  97, 116, 105, 99, 105, 116, 121, 32, 100, 105, 97, 103, 114, 97, 109, 32,
  111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32,
  45, 10, 40, 54, 55, 46, 53, 59, 55, 51, 46, 53, 59, 49, 48, 57,
  46, 53, 59, 49, 48, 51, 46, 53, 59, 53, 49, 46, 53, 59, 49, 48,
  48, 46, 53, 59, 51, 55, 59, 51, 54, 41, 10, 40, 50, 56, 48, 44,
  52, 50, 48, 44, 48, 59, 49, 55, 49, 44, 56, 50, 57, 44, 48, 59,
  49, 53, 56, 44, 56, 50, 48, 44, 48, 59, 49, 53, 51, 44, 56, 49,
  54, 44, 48, 59, 49, 52, 55, 44, 56, 49, 49, 44, 48, 59, 49, 52,
  48, 44, 56, 48, 52, 44, 48, 59, 49, 51, 50, 44, 55, 57, 52, 44,
  48, 59, 49, 50, 49, 44, 55, 55, 54, 44, 48, 59, 49, 48, 54, 44,
  55, 52, 55, 44, 48, 59, 56, 56, 44, 55, 48, 49, 44, 48, 59, 92,
  10, 54, 53, 44, 54, 51, 51, 44, 48, 59, 52, 50, 44, 53, 51, 57,
  44, 48, 59, 50, 48, 44, 52, 50, 49, 44, 48, 59, 53, 44, 50, 57,
  53, 44, 48, 59, 48, 44, 49, 55, 57, 44, 48, 59, 52, 44, 49, 49,
  53, 44, 48, 59, 49, 48, 44, 56, 51, 44, 48, 59, 49, 54, 44, 54,
  49, 44, 48, 59, 50, 53, 44, 51, 56, 44, 48, 59, 51, 53, 44, 50,
  49, 44, 48, 59, 52, 55, 44, 49, 48, 44, 48, 59, 53, 56, 44, 51,
  44, 48, 59, 92, 10, 55, 49, 44, 48, 44, 48, 59, 57, 50, 44, 49,
  44, 48, 59, 49, 49, 49, 44, 55, 44, 48, 59, 49, 53, 49, 44, 50,
  56, 44, 48, 59, 49, 56, 57, 44, 53, 50, 44, 48, 59, 50, 50, 54,
  44, 55, 57, 44, 48, 59, 50, 54, 50, 44, 49, 48, 57, 44, 48, 59,
  50, 57, 56, 44, 49, 52, 49, 44, 48, 59, 51, 51, 52, 44, 49, 55,
  53, 44, 48, 59, 51, 55, 48, 44, 50, 48, 57, 44, 48, 59, 52, 48,
  53, 44, 50, 52, 52, 44, 48, 59, 92, 10, 52, 52, 49, 44, 50, 55,
  57, 44, 48, 59, 52, 55, 53, 44, 51, 49, 51, 44, 48, 59, 53, 48,
  57, 44, 51, 52, 55, 44, 48, 59, 55, 51, 49, 44, 53, 54, 56, 44,
  48, 41, 10, 120, 77, 61, 55, 51, 49, 32, 121, 77, 61, 56, 50, 57,
  10, 50, 44, 123, 104, 45, 49, 125, 44, 49, 44, 49, 44, 51, 44, 48,
  32, 49, 44, 123, 104, 125, 44, 49, 44, 49, 44, 39, 121, 39, 32, 45,
  45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 37, 91, 45, 49, 93, 32,
  123, 104, 125, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 49, 32,
  45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 120, 10, 51, 44, 123, 104,
  125, 44, 49, 44, 49, 44, 49, 54, 48, 32, 49, 44, 123, 104, 125, 44,
  49, 44, 49, 44, 49, 10, 45, 121, 91, 45, 52, 45, 45, 50, 93, 32,
  45, 97, 91, 45, 53, 45, 45, 49, 93, 32, 121, 32, 45, 109, 118, 91,
  45, 49, 93, 32, 48, 10, 120, 82, 61, 54, 51, 54, 32, 121, 82, 61,
  53, 48, 52, 32, 120, 71, 61, 50, 57, 55, 32, 121, 71, 61, 50, 51,
  52, 32, 120, 66, 61, 49, 52, 55, 32, 121, 66, 61, 55, 55, 52, 10,
  53, 49, 50, 44, 53, 49, 50, 44, 49, 44, 51, 32, 45, 116, 114, 105,
  97, 110, 103, 108, 101, 95, 115, 104, 97, 100, 101, 91, 45, 49, 93, 32,
  48, 44, 48, 44, 123, 119, 45, 49, 125, 44, 48, 44, 48, 44, 123, 104,
  45, 49, 125, 44, 34, 34, 50, 53, 53, 44, 48, 44, 48, 44, 34, 34,
  48, 44, 50, 53, 53, 44, 48, 44, 34, 34, 48, 44, 48, 44, 50, 53,
  53, 32, 45, 114, 103, 98, 50, 115, 114, 103, 98, 91, 45, 49, 93, 10,
  45, 45, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101,
  108, 115, 91, 45, 49, 93, 32, 109, 97, 120, 32, 45, 43, 91, 45, 49,
  93, 32, 49, 101, 45, 56, 32, 45, 47, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 10, 45, 105, 91, 45,
  50, 93, 32, 40, 54, 55, 46, 53, 59, 55, 51, 46, 53, 59, 49, 48,
  57, 46, 53, 59, 49, 48, 51, 46, 53, 59, 53, 49, 46, 53, 59, 49,
  48, 48, 46, 53, 59, 51, 59, 49, 59, 36, 120, 82, 59, 36, 121, 82,
  59, 45, 48, 46, 48, 49, 59, 36, 120, 71, 59, 36, 121, 71, 59, 45,
  48, 46, 48, 49, 59, 36, 120, 66, 59, 36, 121, 66, 59, 45, 48, 46,
  48, 49, 59, 57, 59, 48, 59, 49, 59, 50, 59, 48, 59, 48, 59, 53,
  49, 49, 59, 48, 59, 48, 59, 53, 49, 49, 59, 45, 49, 50, 56, 59,
  53, 49, 50, 59, 53, 49, 50, 59, 51, 41, 10, 45, 121, 91, 45, 49,
  93, 32, 40, 49, 41, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32,
  121, 32, 45, 109, 118, 91, 45, 49, 93, 32, 49, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 64, 35, 45, 50, 125, 10, 45, 116, 111, 95, 114,
  103, 98, 91, 45, 49, 93, 32, 45, 102, 99, 91, 45, 49, 93, 32, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 103, 114, 105, 100,
  91, 45, 49, 93, 32, 49, 48, 37, 44, 49, 48, 37, 44, 48, 44, 48,
  44, 48, 46, 51, 44, 48, 120, 67, 67, 67, 67, 67, 67, 67, 67, 44,
  49, 44, 48, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44,
  51, 10, 45, 45, 42, 51, 100, 91, 48, 44, 49, 93, 32, 123, 40, 119,
  45, 56, 41, 47, 36, 120, 77, 125, 44, 123, 40, 104, 45, 51, 50, 41,
  47, 36, 121, 77, 125, 10, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91,
  45, 51, 93, 32, 91, 45, 49, 93, 44, 50, 44, 51, 48, 44, 48, 44,
  49, 44, 50, 10, 45, 45, 110, 101, 113, 91, 45, 51, 93, 32, 48, 32,
  45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32,
  45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 119, 97, 116, 101, 114,
  115, 104, 101, 100, 91, 45, 52, 93, 32, 91, 45, 49, 93, 32, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 47, 91, 45, 51, 93, 32, 49, 46, 53,
  10, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 51, 93, 32, 91,
  45, 49, 93, 44, 50, 44, 51, 48, 44, 48, 44, 49, 44, 50, 10, 45,
  112, 51, 100, 91, 45, 49, 93, 32, 49, 32, 45, 112, 51, 100, 91, 45,
  49, 93, 32, 50, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32,
  49, 50, 56, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 51,
  93, 32, 91, 45, 49, 93, 44, 50, 44, 51, 48, 44, 48, 44, 49, 44,
  49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 64, 123, 45, 50, 44, 119,
  125, 44, 64, 123, 45, 50, 44, 104, 125, 32, 45, 111, 98, 106, 101, 99,
  116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 50, 44, 51,
  48, 44, 48, 44, 49, 44, 50, 32, 45, 114, 109, 91, 45, 50, 93, 10,
  45, 45, 101, 114, 111, 100, 101, 91, 45, 49, 93, 32, 52, 32, 45, 45,
  91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 101, 113, 91, 45, 49,
  93, 32, 48, 32, 45, 42, 91, 45, 51, 44, 45, 49, 93, 10, 45, 97,
  91, 45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 98, 108, 101, 110, 100,
  91, 45, 50, 44, 45, 49, 93, 32, 97, 108, 112, 104, 97, 10, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 50, 53, 53, 32,
  45, 97, 120, 101, 115, 91, 45, 49, 93, 32, 48, 44, 48, 46, 55, 53,
  44, 48, 46, 56, 53, 44, 48, 44, 49, 51, 44, 49, 32, 45, 45, 101,
  114, 111, 100, 101, 91, 45, 49, 93, 32, 51, 32, 45, 110, 101, 103, 97,
  116, 105, 118, 101, 91, 45, 49, 93, 32, 45, 116, 111, 95, 114, 103, 98,
  91, 45, 50, 93, 10, 45, 106, 91, 45, 51, 93, 32, 91, 45, 50, 93,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 44,
  52, 48, 48, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45,
  109, 118, 91, 45, 49, 93, 32, 50, 32, 45, 100, 111, 110, 101, 32, 45,
  114, 109, 91, 48, 44, 49, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 99, 105, 114, 99, 108, 101, 32, 58, 32, 120, 91, 37,
  93, 44, 121, 91, 37, 93, 44, 82, 91, 37, 93, 44, 95, 111, 112, 97,
  99, 105, 116, 121, 44, 95, 112, 97, 116, 116, 101, 114, 110, 44, 95, 99,
  111, 108, 111, 114, 49, 44, 46, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 68, 114, 97, 119, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100,
  32, 99, 111, 108, 111, 114, 101, 100, 32, 99, 105, 114, 99, 108, 101, 32,
  111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 32, 114,
  97, 100, 105, 117, 115, 32, 111, 102, 32, 39, 49, 48, 48, 37, 39, 32,
  115, 116, 97, 110, 100, 115, 32, 102, 111, 114, 32, 39, 115, 113, 114, 116,
  40, 119, 105, 100, 116, 104, 94, 50, 43, 104, 101, 105, 103, 104, 116, 94,
  50, 41, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 112,
  97, 116, 116, 101, 114, 110, 39, 32, 105, 115, 32, 97, 110, 32, 104, 101,
  120, 97, 100, 101, 99, 105, 109, 97, 108, 32, 110, 117, 109, 98, 101, 114,
  32, 115, 116, 97, 114, 116, 105, 110, 103, 32, 119, 105, 116, 104, 32, 39,
  48, 120, 39, 32, 119, 104, 105, 99, 104, 32, 99, 97, 110, 32, 98, 101,
  32, 111, 109, 105, 116, 116, 101, 100, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 101, 118, 101, 110, 32, 105, 102, 32, 97, 32, 99, 111, 108, 111,
  114, 32, 105, 115, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 46, 32,
  73, 102, 32, 97, 32, 112, 97, 116, 116, 101, 114, 110, 32, 105, 115, 32,
  115, 112, 101, 99, 105, 102, 105, 101, 100, 44, 32, 116, 104, 101, 32, 99,
  105, 114, 99, 108, 101, 32, 105, 115, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 100, 114, 97, 119, 110, 32, 111, 117, 116, 108, 105, 110, 101, 100,
  32, 105, 110, 115, 116, 101, 97, 100, 32, 111, 102, 32, 102, 105, 108, 108,
  101, 100, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 111, 112,
  97, 99, 105, 116, 121, 61, 49, 39, 44, 32, 39, 112, 97, 116, 116, 101,
  114, 110, 61, 40, 117, 110, 100, 101, 102, 105, 110, 101, 100, 41, 39, 32,
  97, 110, 100, 32, 39, 99, 111, 108, 111, 114, 49, 61, 48, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 114, 101, 112, 101, 97, 116, 32, 51, 48, 48,
  32, 45, 99, 105, 114, 99, 108, 101, 32, 123, 63, 40, 49, 48, 48, 41,
  125, 37, 44, 123, 63, 40, 49, 48, 48, 41, 125, 37, 44, 123, 63, 40,
  51, 48, 41, 125, 44, 48, 46, 51, 44, 64, 123, 45, 82, 71, 66, 125,
  32, 45, 100, 111, 110, 101, 32, 45, 99, 105, 114, 99, 108, 101, 32, 53,
  48, 37, 44, 53, 48, 37, 44, 49, 48, 48, 44, 48, 46, 55, 44, 50,
  53, 53, 10, 99, 105, 114, 99, 108, 101, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 52, 61, 49, 125, 44, 36, 123, 53, 61, 48, 125, 10,
  45, 118, 32, 45, 32, 40, 123, 39, 34, 36, 53, 34, 39, 125, 41, 32,
  105, 115, 95, 112, 97, 116, 116, 101, 114, 110, 61, 123, 64, 123, 45, 49,
  44, 48, 45, 49, 125, 39, 61, 61, 39, 123, 39, 48, 120, 39, 125, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 118, 32, 43, 10, 45, 105,
  102, 32, 36, 105, 115, 95, 112, 97, 116, 116, 101, 114, 110, 10, 45, 101,
  91, 48, 45, 45, 51, 93, 32, 34, 68, 114, 97, 119, 32, 111, 117, 116,
  108, 105, 110, 101, 100, 32, 99, 105, 114, 99, 108, 101, 32, 97, 116, 32,
  40, 36, 49, 44, 36, 50, 41, 32, 119, 105, 116, 104, 32, 114, 97, 100,
  105, 117, 115, 32, 36, 51, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 119, 105, 116, 104, 32, 111, 112, 97, 99, 105, 116, 121, 32,
  36, 52, 32, 97, 110, 100, 32, 99, 111, 108, 111, 114, 32, 40, 36, 123,
  54, 45, 45, 49, 125, 41, 46, 34, 10, 45, 101, 108, 115, 101, 10, 45,
  101, 91, 48, 45, 45, 51, 93, 32, 34, 68, 114, 97, 119, 32, 102, 105,
  108, 108, 101, 100, 32, 99, 105, 114, 99, 108, 101, 32, 97, 116, 32, 40,
  36, 49, 44, 36, 50, 41, 32, 119, 105, 116, 104, 32, 114, 97, 100, 105,
  117, 115, 32, 36, 51, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63,
  44, 32, 119, 105, 116, 104, 32, 111, 112, 97, 99, 105, 116, 121, 32, 36,
  52, 32, 97, 110, 100, 32, 99, 111, 108, 111, 114, 32, 40, 36, 123, 53,
  45, 45, 49, 125, 41, 46, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  118, 32, 45, 32, 45, 101, 108, 108, 105, 112, 115, 101, 32, 36, 49, 44,
  36, 50, 44, 36, 51, 44, 36, 51, 44, 48, 44, 36, 123, 52, 45, 45,
  49, 125, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 101,
  108, 108, 105, 112, 115, 101, 32, 58, 32, 120, 91, 37, 93, 44, 121, 91,
  37, 93, 44, 82, 91, 37, 93, 44, 114, 91, 37, 93, 44, 95, 97, 110,
  103, 108, 101, 44, 95, 111, 112, 97, 99, 105, 116, 121, 44, 95, 112, 97,
  116, 116, 101, 114, 110, 44, 95, 99, 111, 108, 111, 114, 49, 44, 46, 46,
  32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 114, 97, 119, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 99,
  111, 108, 111, 114, 101, 100, 32, 101, 108, 108, 105, 112, 115, 101, 32, 111,
  110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 32, 114, 97,
  100, 105, 117, 115, 32, 111, 102, 32, 39, 49, 48, 48, 37, 39, 32, 115,
  116, 97, 110, 100, 115, 32, 102, 111, 114, 32, 39, 115, 113, 114, 116, 40,
  119, 105, 100, 116, 104, 94, 50, 43, 104, 101, 105, 103, 104, 116, 94, 50,
  41, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 112, 97,
  116, 116, 101, 114, 110, 39, 32, 105, 115, 32, 97, 110, 32, 104, 101, 120,
  97, 100, 101, 99, 105, 109, 97, 108, 32, 110, 117, 109, 98, 101, 114, 32,
  115, 116, 97, 114, 116, 105, 110, 103, 32, 119, 105, 116, 104, 32, 39, 48,
  120, 39, 32, 119, 104, 105, 99, 104, 32, 99, 97, 110, 32, 98, 101, 32,
  111, 109, 105, 116, 116, 101, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 101, 118, 101, 110, 32, 105, 102, 32, 97, 32, 99, 111, 108, 111, 114,
  32, 105, 115, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 46, 32, 73,
  102, 32, 97, 32, 112, 97, 116, 116, 101, 114, 110, 32, 105, 115, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 44, 32, 116, 104, 101, 32, 101, 108,
  108, 105, 112, 115, 101, 32, 105, 115, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 100, 114, 97, 119, 110, 32, 111, 117, 116, 108, 105, 110, 101, 100,
  32, 105, 110, 115, 116, 101, 97, 100, 32, 111, 102, 32, 102, 105, 108, 108,
  101, 100, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 111, 112,
  97, 99, 105, 116, 121, 61, 49, 39, 44, 32, 39, 112, 97, 116, 116, 101,
  114, 110, 61, 40, 117, 110, 100, 101, 102, 105, 110, 101, 100, 41, 39, 32,
  97, 110, 100, 32, 39, 99, 111, 108, 111, 114, 49, 61, 48, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 114, 101, 112, 101, 97, 116, 32, 51, 48, 48,
  32, 45, 101, 108, 108, 105, 112, 115, 101, 32, 123, 63, 40, 49, 48, 48,
  41, 125, 37, 44, 123, 63, 40, 49, 48, 48, 41, 125, 37, 44, 123, 63,
  40, 51, 48, 41, 125, 44, 123, 63, 40, 51, 48, 41, 125, 44, 123, 63,
  40, 49, 56, 48, 41, 125, 44, 48, 46, 51, 44, 64, 123, 45, 82, 71,
  66, 125, 32, 45, 100, 111, 110, 101, 32, 45, 101, 108, 108, 105, 112, 115,
  101, 32, 53, 48, 37, 44, 53, 48, 37, 44, 49, 48, 48, 44, 49, 48,
  48, 44, 48, 44, 48, 46, 55, 44, 50, 53, 53, 10, 35, 64, 103, 109,
  105, 99, 32, 102, 108, 111, 111, 100, 32, 58, 32, 120, 91, 37, 93, 44,
  95, 121, 91, 37, 93, 44, 95, 122, 91, 37, 93, 44, 95, 116, 111, 108,
  101, 114, 97, 110, 99, 101, 62, 61, 48, 44, 95, 105, 115, 95, 104, 105,
  103, 104, 95, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 61,
  123, 32, 48, 32, 124, 32, 49, 32, 125, 44, 95, 111, 112, 97, 99, 105,
  116, 121, 44, 95, 99, 111, 108, 111, 114, 49, 44, 46, 46, 32, 58, 32,
  40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 70, 108, 111,
  111, 100, 45, 102, 105, 108, 108, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 32, 117, 115, 105, 110, 103, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 118, 97, 108, 117, 101, 32, 97, 110,
  100, 32, 116, 111, 108, 101, 114, 97, 110, 99, 101, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 121, 61, 122, 61, 48, 39, 44, 32, 39,
  116, 111, 108, 101, 114, 97, 110, 99, 101, 61, 48, 39, 44, 32, 39, 105,
  115, 95, 104, 105, 103, 104, 95, 99, 111, 110, 110, 101, 99, 116, 105, 118,
  105, 116, 121, 61, 48, 39, 44, 32, 39, 111, 112, 97, 99, 105, 116, 121,
  61, 49, 39, 32, 97, 110, 100, 32, 39, 99, 111, 108, 111, 114, 49, 61,
  48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 49, 48, 48, 48, 32, 45, 102, 108, 111, 111, 100, 32, 123, 63, 40,
  49, 48, 48, 41, 125, 37, 44, 123, 63, 40, 49, 48, 48, 41, 125, 37,
  44, 48, 44, 50, 48, 44, 48, 44, 49, 44, 64, 123, 45, 82, 71, 66,
  125, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 109, 105, 99, 32, 103,
  97, 117, 115, 115, 105, 97, 110, 32, 58, 32, 95, 115, 105, 103, 109, 97,
  49, 91, 37, 93, 44, 95, 115, 105, 103, 109, 97, 50, 91, 37, 93, 44,
  95, 97, 110, 103, 108, 101, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 114, 97, 119, 32, 97, 32, 99, 101, 110, 116, 101, 114, 101, 100, 32,
  103, 97, 117, 115, 115, 105, 97, 110, 32, 111, 110, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 44, 32, 119, 105, 116,
  104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 115, 116, 97, 110,
  100, 97, 114, 100, 32, 100, 101, 118, 105, 97, 116, 105, 111, 110, 115, 32,
  97, 110, 100, 32, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108,
  116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 115, 105, 103, 109, 97,
  49, 61, 51, 39, 44, 32, 39, 115, 105, 103, 109, 97, 50, 61, 115, 105,
  103, 109, 97, 49, 39, 32, 97, 110, 100, 32, 39, 97, 110, 103, 108, 101,
  61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  52, 48, 48, 44, 52, 48, 48, 32, 45, 103, 97, 117, 115, 115, 105, 97,
  110, 32, 49, 48, 48, 44, 51, 48, 44, 52, 53, 10, 103, 97, 117, 115,
  115, 105, 97, 110, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49,
  61, 51, 125, 44, 36, 123, 50, 61, 36, 49, 125, 44, 36, 123, 51, 61,
  48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 114, 97, 119,
  32, 99, 101, 110, 116, 101, 114, 101, 100, 32, 103, 97, 117, 115, 115, 105,
  97, 110, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 32, 119, 105,
  116, 104, 32, 115, 116, 97, 110, 100, 97, 114, 100, 32, 100, 101, 118, 105,
  97, 116, 105, 111, 110, 115, 32, 40, 36, 49, 44, 36, 50, 41, 32, 97,
  110, 100, 32, 97, 110, 103, 108, 101, 32, 36, 51, 32, 100, 101, 103, 46,
  34, 10, 45, 118, 32, 45, 10, 117, 61, 123, 99, 111, 115, 40, 36, 51,
  42, 112, 105, 47, 49, 56, 48, 41, 125, 10, 118, 61, 123, 115, 105, 110,
  40, 36, 51, 42, 112, 105, 47, 49, 56, 48, 41, 125, 10, 100, 109, 97,
  120, 61, 123, 109, 97, 120, 40, 119, 44, 104, 41, 125, 10, 45, 105, 102,
  32, 123, 105, 115, 118, 97, 108, 40, 36, 49, 41, 125, 32, 108, 49, 61,
  36, 49, 32, 45, 101, 108, 115, 101, 32, 108, 49, 61, 123, 36, 123, 49,
  125, 49, 48, 48, 48, 48, 42, 36, 100, 109, 97, 120, 47, 49, 48, 48,
  125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 105, 115,
  118, 97, 108, 40, 36, 50, 41, 125, 32, 108, 50, 61, 36, 50, 32, 45,
  101, 108, 115, 101, 32, 108, 50, 61, 123, 36, 123, 50, 125, 49, 48, 48,
  48, 48, 42, 36, 100, 109, 97, 120, 47, 49, 48, 48, 125, 32, 45, 101,
  110, 100, 105, 102, 10, 108, 49, 61, 123, 49, 47, 40, 50, 42, 109, 97,
  120, 40, 49, 47, 51, 44, 36, 108, 49, 41, 94, 50, 41, 125, 10, 108,
  50, 61, 123, 49, 47, 40, 50, 42, 109, 97, 120, 40, 49, 47, 51, 44,
  36, 108, 50, 41, 94, 50, 41, 125, 10, 65, 61, 123, 36, 108, 49, 42,
  36, 117, 42, 36, 117, 43, 36, 108, 50, 42, 36, 118, 42, 36, 118, 125,
  10, 66, 61, 123, 40, 36, 108, 49, 45, 36, 108, 50, 41, 42, 36, 117,
  42, 36, 118, 125, 10, 67, 61, 123, 36, 108, 49, 42, 36, 118, 42, 36,
  118, 43, 36, 108, 50, 42, 36, 117, 42, 36, 117, 125, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110,
  109, 61, 64, 123, 48, 44, 110, 125, 10, 119, 61, 123, 119, 125, 32, 104,
  61, 123, 104, 125, 32, 100, 115, 61, 123, 100, 125, 44, 123, 115, 125, 32,
  45, 114, 109, 10, 40, 123, 45, 36, 119, 47, 50, 125, 44, 123, 36, 119,
  47, 50, 125, 41, 32, 45, 114, 32, 36, 119, 44, 36, 104, 44, 49, 44,
  49, 44, 51, 10, 45, 102, 91, 45, 49, 93, 32, 34, 89, 61, 121, 45,
  34, 123, 36, 104, 47, 50, 125, 59, 36, 65, 34, 42, 105, 42, 105, 43,
  50, 42, 34, 36, 66, 34, 42, 105, 42, 89, 43, 34, 36, 67, 42, 34,
  89, 42, 89, 34, 10, 45, 42, 32, 45, 49, 32, 45, 101, 120, 112, 32,
  45, 114, 32, 36, 119, 44, 36, 104, 44, 36, 100, 115, 10, 45, 110, 109,
  32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 103,
  114, 97, 112, 104, 32, 58, 32, 91, 102, 117, 110, 99, 116, 105, 111, 110,
  95, 105, 109, 97, 103, 101, 93, 44, 95, 112, 108, 111, 116, 95, 116, 121,
  112, 101, 44, 95, 118, 101, 114, 116, 101, 120, 95, 116, 121, 112, 101, 44,
  95, 121, 109, 105, 110, 44, 95, 121, 109, 97, 120, 44, 95, 111, 112, 97,
  99, 105, 116, 121, 44, 95, 112, 97, 116, 116, 101, 114, 110, 44, 95, 99,
  111, 108, 111, 114, 49, 44, 46, 46, 32, 58, 32, 39, 102, 111, 114, 109,
  117, 108, 97, 39, 44, 95, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110,
  62, 61, 48, 44, 95, 112, 108, 111, 116, 95, 116, 121, 112, 101, 44, 95,
  118, 101, 114, 116, 101, 120, 95, 116, 121, 112, 101, 44, 95, 120, 109, 105,
  110, 44, 120, 109, 97, 120, 44, 95, 121, 109, 105, 110, 44, 95, 121, 109,
  97, 120, 44, 95, 111, 112, 97, 99, 105, 116, 121, 44, 95, 112, 97, 116,
  116, 101, 114, 110, 44, 95, 99, 111, 108, 111, 114, 49, 44, 46, 46, 32,
  58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  114, 97, 119, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 102, 117,
  110, 99, 116, 105, 111, 110, 32, 103, 114, 97, 112, 104, 32, 111, 110, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 112, 108, 111, 116, 95,
  116, 121, 112, 101, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48,
  61, 110, 111, 110, 101, 32, 124, 32, 49, 61, 108, 105, 110, 101, 115, 32,
  124, 32, 50, 61, 115, 112, 108, 105, 110, 101, 115, 32, 124, 32, 51, 61,
  98, 97, 114, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  39, 118, 101, 114, 116, 101, 120, 95, 116, 121, 112, 101, 39, 32, 99, 97,
  110, 32, 98, 101, 32, 123, 32, 48, 61, 110, 111, 110, 101, 32, 124, 32,
  49, 61, 112, 111, 105, 110, 116, 115, 32, 124, 32, 50, 44, 51, 61, 99,
  114, 111, 115, 115, 101, 115, 32, 124, 32, 52, 44, 53, 61, 99, 105, 114,
  99, 108, 101, 115, 32, 124, 32, 54, 44, 55, 61, 115, 113, 117, 97, 114,
  101, 115, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39,
  112, 97, 116, 116, 101, 114, 110, 39, 32, 105, 115, 32, 97, 110, 32, 104,
  101, 120, 97, 100, 101, 99, 105, 109, 97, 108, 32, 110, 117, 109, 98, 101,
  114, 32, 115, 116, 97, 114, 116, 105, 110, 103, 32, 119, 105, 116, 104, 32,
  39, 48, 120, 39, 32, 119, 104, 105, 99, 104, 32, 99, 97, 110, 32, 98,
  101, 32, 111, 109, 105, 116, 116, 101, 100, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 101, 118, 101, 110, 32, 105, 102, 32, 97, 32, 99, 111, 108,
  111, 114, 32, 105, 115, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108,
  116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 112, 108, 111, 116, 95,
  116, 121, 112, 101, 61, 49, 39, 44, 32, 39, 118, 101, 114, 116, 101, 120,
  95, 116, 121, 112, 101, 61, 49, 39, 44, 32, 39, 121, 109, 105, 110, 61,
  121, 109, 97, 120, 61, 48, 32, 40, 97, 117, 116, 111, 41, 39, 44, 32,
  39, 111, 112, 97, 99, 105, 116, 121, 61, 49, 39, 44, 32, 39, 112, 97,
  116, 116, 101, 114, 110, 61, 40, 117, 110, 100, 101, 102, 105, 110, 101, 100,
  41, 39, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 97, 110, 100, 32,
  39, 99, 111, 108, 111, 114, 49, 61, 48, 39, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 45, 114, 111, 119, 115, 32, 53, 48, 37, 32, 45, 98, 108, 117,
  114, 91, 45, 49, 93, 32, 51, 32, 45, 115, 112, 108, 105, 116, 91, 45,
  49, 93, 32, 99, 32, 45, 100, 105, 118, 91, 48, 93, 32, 49, 46, 53,
  32, 45, 103, 114, 97, 112, 104, 91, 48, 93, 32, 91, 49, 93, 44, 50,
  44, 48, 44, 48, 44, 48, 44, 49, 44, 50, 53, 53, 44, 48, 44, 48,
  32, 45, 103, 114, 97, 112, 104, 91, 48, 93, 32, 91, 50, 93, 44, 50,
  44, 48, 44, 48, 44, 48, 44, 49, 44, 48, 44, 50, 53, 53, 44, 48,
  32, 45, 103, 114, 97, 112, 104, 91, 48, 93, 32, 91, 51, 93, 44, 50,
  44, 48, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 50, 53, 53,
  32, 45, 107, 101, 101, 112, 91, 48, 93, 10, 35, 64, 103, 109, 105, 99,
  32, 103, 114, 105, 100, 32, 58, 32, 115, 105, 122, 101, 95, 120, 91, 37,
  93, 62, 61, 48, 44, 115, 105, 122, 101, 95, 121, 91, 37, 93, 62, 61,
  48, 44, 95, 111, 102, 102, 115, 101, 116, 95, 120, 91, 37, 93, 44, 95,
  111, 102, 102, 115, 101, 116, 95, 121, 91, 37, 93, 44, 95, 111, 112, 97,
  99, 105, 116, 121, 44, 95, 112, 97, 116, 116, 101, 114, 110, 44, 95, 99,
  111, 108, 111, 114, 49, 44, 46, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 68, 114, 97, 119, 32, 120, 121, 45, 103, 114, 105, 100, 32, 111,
  110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 112, 97, 116,
  116, 101, 114, 110, 39, 32, 105, 115, 32, 97, 110, 32, 104, 101, 120, 97,
  100, 101, 99, 105, 109, 97, 108, 32, 110, 117, 109, 98, 101, 114, 32, 115,
  116, 97, 114, 116, 105, 110, 103, 32, 119, 105, 116, 104, 32, 39, 48, 120,
  39, 32, 119, 104, 105, 99, 104, 32, 99, 97, 110, 32, 98, 101, 32, 111,
  109, 105, 116, 116, 101, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  101, 118, 101, 110, 32, 105, 102, 32, 97, 32, 99, 111, 108, 111, 114, 32,
  105, 115, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 111, 102, 102, 115, 101, 116, 95, 120,
  61, 111, 102, 102, 115, 101, 116, 95, 121, 61, 48, 39, 44, 32, 39, 111,
  112, 97, 99, 105, 116, 121, 61, 49, 39, 44, 32, 39, 112, 97, 116, 116,
  101, 114, 110, 61, 40, 117, 110, 100, 101, 102, 105, 110, 101, 100, 41, 39,
  32, 97, 110, 100, 32, 39, 99, 111, 108, 111, 114, 49, 61, 48, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 103, 114, 105, 100, 32, 49, 48, 37, 44,
  49, 48, 37, 44, 48, 44, 48, 44, 48, 46, 53, 44, 50, 53, 53, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 52, 48, 48, 44, 52,
  48, 48, 44, 49, 44, 51, 44, 50, 53, 53, 32, 45, 103, 114, 105, 100,
  32, 49, 48, 37, 44, 49, 48, 37, 44, 48, 44, 48, 44, 48, 46, 51,
  44, 48, 120, 67, 67, 67, 67, 67, 67, 67, 67, 44, 49, 50, 56, 44,
  51, 50, 44, 49, 54, 10, 103, 114, 105, 100, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 36, 49, 62, 61, 48, 32, 38, 38, 32, 36, 50,
  62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 48,
  125, 44, 36, 123, 52, 61, 48, 125, 44, 36, 123, 53, 61, 49, 125, 44,
  36, 123, 54, 61, 48, 125, 10, 45, 118, 32, 45, 32, 40, 123, 39, 34,
  36, 54, 34, 39, 125, 41, 32, 105, 115, 95, 112, 97, 116, 116, 101, 114,
  110, 61, 123, 64, 123, 45, 49, 44, 48, 45, 49, 125, 39, 61, 61, 39,
  123, 39, 48, 120, 39, 125, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 118, 32, 43, 10, 45, 105, 102, 32, 36, 105, 115, 95, 112, 97, 116,
  116, 101, 114, 110, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 68,
  114, 97, 119, 32, 120, 121, 45, 103, 114, 105, 100, 32, 111, 110, 32, 105,
  109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 115, 105, 122,
  101, 115, 32, 40, 36, 49, 44, 36, 50, 41, 44, 32, 111, 102, 102, 115,
  101, 116, 115, 32, 40, 36, 51, 44, 36, 52, 41, 44, 32, 111, 112, 97,
  99, 105, 116, 121, 32, 36, 53, 44, 32, 112, 97, 116, 116, 101, 114, 110,
  32, 36, 54, 32, 97, 110, 100, 32, 99, 111, 108, 111, 114, 32, 40, 36,
  123, 55, 45, 45, 49, 125, 41, 46, 34, 10, 45, 118, 32, 45, 32, 112,
  97, 116, 116, 101, 114, 110, 61, 36, 54, 32, 99, 111, 108, 111, 114, 61,
  36, 123, 55, 45, 45, 49, 125, 10, 45, 101, 108, 115, 101, 10, 45, 101,
  91, 48, 45, 45, 51, 93, 32, 34, 68, 114, 97, 119, 32, 120, 121, 45,
  103, 114, 105, 100, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 119, 105, 116, 104, 32, 115, 105, 122, 101, 115, 32, 40, 36, 49, 44,
  36, 50, 41, 44, 32, 111, 102, 102, 115, 101, 116, 115, 32, 40, 36, 51,
  44, 36, 52, 41, 44, 32, 111, 112, 97, 99, 105, 116, 121, 32, 36, 53,
  44, 32, 97, 110, 100, 32, 99, 111, 108, 111, 114, 32, 40, 36, 123, 54,
  45, 45, 49, 125, 41, 46, 34, 10, 45, 118, 32, 45, 32, 112, 97, 116,
  116, 101, 114, 110, 61, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 32,
  99, 111, 108, 111, 114, 61, 36, 123, 54, 45, 45, 49, 125, 10, 45, 101,
  110, 100, 105, 102, 10, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 115,
  120, 61, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92,
  32, 36, 49, 125, 32, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 115,
  121, 61, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92,
  32, 36, 50, 125, 10, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 111,
  120, 61, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92,
  32, 36, 51, 125, 32, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 111,
  121, 61, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92,
  32, 36, 52, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123,
  104, 125, 32, 115, 61, 123, 115, 125, 10, 115, 105, 122, 101, 61, 123, 105,
  102, 40, 36, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 115, 120, 44,
  109, 97, 120, 40, 49, 44, 119, 42, 36, 49, 41, 44, 36, 49, 41, 125,
  10, 45, 105, 102, 32, 123, 36, 115, 105, 122, 101, 62, 61, 49, 125, 10,
  111, 102, 102, 115, 101, 116, 61, 123, 105, 102, 40, 36, 105, 115, 95, 112,
  101, 114, 99, 101, 110, 116, 111, 120, 44, 36, 115, 105, 122, 101, 42, 36,
  51, 44, 36, 51, 41, 125, 10, 40, 123, 39, 67, 73, 109, 103, 51, 100,
  39, 125, 41, 32, 45, 43, 91, 45, 49, 93, 32, 48, 46, 53, 10, 49,
  44, 123, 49, 43, 105, 110, 116, 40, 36, 119, 47, 36, 115, 105, 122, 101,
  41, 125, 44, 49, 44, 49, 44, 39, 121, 39, 32, 45, 42, 91, 45, 49,
  93, 32, 36, 115, 105, 122, 101, 32, 45, 43, 91, 45, 49, 93, 32, 123,
  36, 111, 102, 102, 115, 101, 116, 37, 36, 115, 105, 122, 101, 125, 10, 49,
  44, 123, 104, 125, 44, 49, 44, 49, 44, 123, 36, 104, 47, 50, 125, 32,
  45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 122, 91, 45,
  49, 93, 32, 48, 44, 50, 32, 110, 61, 123, 104, 125, 32, 45, 105, 91,
  45, 50, 93, 32, 40, 36, 110, 59, 36, 110, 41, 10, 40, 49, 44, 48,
  59, 49, 44, 123, 36, 110, 45, 49, 125, 41, 32, 45, 114, 91, 45, 49,
  93, 32, 50, 44, 36, 110, 44, 49, 44, 49, 44, 51, 32, 45, 114, 111,
  117, 110, 100, 91, 45, 49, 93, 10, 40, 45, 49, 50, 56, 59, 49, 59,
  36, 104, 59, 36, 115, 41, 32, 49, 44, 36, 104, 44, 49, 44, 36, 115,
  32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48,
  44, 49, 48, 48, 37, 44, 49, 44, 36, 112, 97, 116, 116, 101, 114, 110,
  44, 36, 99, 111, 108, 111, 114, 10, 45, 105, 102, 32, 123, 36, 110, 62,
  49, 125, 32, 49, 44, 123, 52, 42, 40, 36, 110, 45, 49, 41, 125, 44,
  49, 44, 49, 44, 45, 49, 50, 56, 44, 48, 44, 48, 44, 48, 32, 45,
  101, 110, 100, 105, 102, 10, 40, 45, 49, 50, 56, 59, 49, 59, 36, 104,
  59, 49, 41, 32, 49, 44, 36, 104, 44, 49, 44, 49, 32, 45, 108, 105,
  110, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 49, 48, 48,
  37, 44, 49, 44, 36, 112, 97, 116, 116, 101, 114, 110, 44, 49, 10, 45,
  105, 102, 32, 123, 36, 110, 62, 49, 125, 32, 49, 44, 123, 52, 42, 40,
  36, 110, 45, 49, 41, 125, 44, 49, 44, 49, 44, 45, 49, 50, 56, 44,
  48, 44, 48, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 121, 91,
  94, 48, 93, 32, 45, 97, 91, 94, 48, 93, 32, 121, 32, 45, 111, 98,
  106, 101, 99, 116, 51, 100, 91, 48, 93, 32, 91, 49, 93, 44, 48, 44,
  48, 44, 48, 44, 36, 53, 44, 48, 44, 48, 44, 48, 32, 45, 114, 109,
  91, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 115, 105, 122, 101, 61,
  123, 105, 102, 40, 36, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 115,
  121, 44, 109, 97, 120, 40, 49, 44, 104, 42, 36, 50, 41, 44, 36, 50,
  41, 125, 10, 45, 105, 102, 32, 123, 36, 115, 105, 122, 101, 62, 61, 49,
  125, 10, 111, 102, 102, 115, 101, 116, 61, 123, 105, 102, 40, 36, 105, 115,
  95, 112, 101, 114, 99, 101, 110, 116, 111, 121, 44, 36, 115, 105, 122, 101,
  42, 36, 52, 44, 36, 52, 41, 125, 10, 40, 123, 39, 67, 73, 109, 103,
  51, 100, 39, 125, 41, 32, 45, 43, 91, 45, 49, 93, 32, 48, 46, 53,
  10, 49, 44, 123, 49, 43, 105, 110, 116, 40, 36, 104, 47, 36, 115, 105,
  122, 101, 41, 125, 44, 49, 44, 49, 44, 39, 121, 39, 32, 45, 42, 91,
  45, 49, 93, 32, 36, 115, 105, 122, 101, 32, 45, 43, 91, 45, 49, 93,
  32, 123, 36, 111, 102, 102, 115, 101, 116, 37, 36, 115, 105, 122, 101, 125,
  10, 45, 105, 91, 45, 50, 93, 32, 49, 44, 123, 104, 125, 44, 49, 44,
  49, 44, 123, 36, 119, 47, 50, 125, 32, 45, 97, 91, 45, 50, 44, 45,
  49, 93, 32, 120, 32, 45, 122, 91, 45, 49, 93, 32, 48, 44, 50, 32,
  110, 61, 123, 104, 125, 32, 45, 105, 91, 45, 50, 93, 32, 40, 36, 110,
  59, 36, 110, 41, 10, 40, 49, 44, 48, 59, 49, 44, 123, 36, 110, 45,
  49, 125, 41, 32, 45, 114, 91, 45, 49, 93, 32, 50, 44, 36, 110, 44,
  49, 44, 49, 44, 51, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93,
  10, 40, 45, 49, 50, 56, 59, 36, 119, 59, 49, 59, 36, 115, 41, 32,
  36, 119, 44, 49, 44, 49, 44, 36, 115, 32, 45, 108, 105, 110, 101, 91,
  45, 49, 93, 32, 48, 44, 48, 44, 49, 48, 48, 37, 44, 48, 44, 49,
  44, 36, 112, 97, 116, 116, 101, 114, 110, 44, 36, 99, 111, 108, 111, 114,
  10, 45, 105, 102, 32, 123, 36, 110, 62, 49, 125, 32, 49, 44, 123, 52,
  42, 40, 36, 110, 45, 49, 41, 125, 44, 49, 44, 49, 44, 45, 49, 50,
  56, 44, 48, 44, 48, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 40,
  45, 49, 50, 56, 59, 36, 119, 59, 49, 59, 49, 41, 32, 36, 119, 44,
  49, 44, 49, 44, 49, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32,
  48, 44, 48, 44, 49, 48, 48, 37, 44, 48, 44, 49, 44, 36, 112, 97,
  116, 116, 101, 114, 110, 44, 49, 10, 45, 105, 102, 32, 123, 36, 110, 62,
  49, 125, 32, 49, 44, 123, 52, 42, 40, 36, 110, 45, 49, 41, 125, 44,
  49, 44, 49, 44, 45, 49, 50, 56, 44, 48, 44, 48, 44, 48, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 121, 91, 94, 48, 93, 32, 45, 97, 91,
  94, 48, 93, 32, 121, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 44, 48, 44, 36,
  53, 44, 48, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 106,
  32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 105, 109, 97, 103,
  101, 39, 46, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99,
  32, 105, 109, 97, 103, 101, 32, 58, 32, 91, 115, 112, 114, 105, 116, 101,
  93, 44, 95, 120, 91, 37, 93, 44, 95, 121, 91, 37, 93, 44, 95, 122,
  91, 37, 93, 44, 95, 99, 91, 37, 93, 44, 95, 111, 112, 97, 99, 105,
  116, 121, 44, 95, 91, 115, 112, 114, 105, 116, 101, 95, 109, 97, 115, 107,
  93, 44, 95, 109, 97, 120, 95, 111, 112, 97, 99, 105, 116, 121, 95, 109,
  97, 115, 107, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 114, 97, 119, 32, 115, 112, 101, 99, 105, 102, 105, 101,
  100, 32, 115, 112, 114, 105, 116, 101, 32, 105, 109, 97, 103, 101, 32, 111,
  110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46,
  32, 116, 111, 32, 39, 45, 106, 39, 41, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117,
  101, 115, 58, 32, 39, 120, 61, 121, 61, 122, 61, 99, 61, 48, 39, 44,
  32, 39, 111, 112, 97, 99, 105, 116, 121, 61, 49, 39, 44, 32, 39, 115,
  112, 114, 105, 116, 101, 95, 109, 97, 115, 107, 61, 40, 117, 110, 100, 101,
  102, 105, 110, 101, 100, 41, 39, 32, 97, 110, 100, 32, 39, 109, 97, 120,
  95, 111, 112, 97, 99, 105, 116, 121, 95, 109, 97, 115, 107, 61, 49, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 45, 99, 114, 111, 112, 32, 52, 48,
  37, 44, 52, 48, 37, 44, 54, 48, 37, 44, 54, 48, 37, 32, 45, 114,
  101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 50, 48, 48, 37, 44, 50,
  48, 48, 37, 44, 49, 44, 51, 44, 53, 32, 45, 102, 114, 97, 109, 101,
  91, 45, 49, 93, 32, 50, 44, 50, 44, 48, 32, 45, 105, 109, 97, 103,
  101, 91, 48, 93, 32, 91, 45, 49, 93, 44, 51, 48, 37, 44, 51, 48,
  37, 32, 45, 107, 101, 101, 112, 91, 48, 93, 10, 35, 64, 103, 109, 105,
  99, 32, 108, 105, 110, 101, 32, 58, 32, 120, 48, 91, 37, 93, 44, 121,
  48, 91, 37, 93, 44, 120, 49, 91, 37, 93, 44, 121, 49, 91, 37, 93,
  44, 95, 111, 112, 97, 99, 105, 116, 121, 44, 95, 112, 97, 116, 116, 101,
  114, 110, 44, 95, 99, 111, 108, 111, 114, 49, 44, 46, 46, 32, 58, 32,
  40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 114, 97,
  119, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 99, 111, 108, 111,
  114, 101, 100, 32, 108, 105, 110, 101, 32, 111, 110, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 39, 112, 97, 116, 116, 101, 114, 110, 39, 32,
  105, 115, 32, 97, 110, 32, 104, 101, 120, 97, 100, 101, 99, 105, 109, 97,
  108, 32, 110, 117, 109, 98, 101, 114, 32, 115, 116, 97, 114, 116, 105, 110,
  103, 32, 119, 105, 116, 104, 32, 39, 48, 120, 39, 32, 119, 104, 105, 99,
  104, 32, 99, 97, 110, 32, 98, 101, 32, 111, 109, 105, 116, 116, 101, 100,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 101, 118, 101, 110, 32, 105,
  102, 32, 97, 32, 99, 111, 108, 111, 114, 32, 105, 115, 32, 115, 112, 101,
  99, 105, 102, 105, 101, 100, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58,
  32, 39, 111, 112, 97, 99, 105, 116, 121, 61, 49, 39, 44, 32, 39, 112,
  97, 116, 116, 101, 114, 110, 61, 40, 117, 110, 100, 101, 102, 105, 110, 101,
  100, 41, 39, 32, 97, 110, 100, 32, 39, 99, 111, 108, 111, 114, 49, 61,
  48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 53, 48, 48, 32, 45, 108, 105, 110, 101, 32, 53, 48, 37, 44, 53,
  48, 37, 44, 123, 63, 40, 119, 41, 125, 44, 123, 63, 40, 104, 41, 125,
  44, 48, 46, 53, 44, 64, 123, 45, 82, 71, 66, 125, 32, 45, 100, 111,
  110, 101, 32, 45, 108, 105, 110, 101, 32, 48, 44, 48, 44, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 49, 44, 48, 120, 67, 67, 67, 67, 67,
  67, 67, 67, 44, 50, 53, 53, 32, 45, 108, 105, 110, 101, 32, 49, 48,
  48, 37, 44, 48, 44, 48, 44, 49, 48, 48, 37, 44, 49, 44, 48, 120,
  67, 67, 67, 67, 67, 67, 67, 67, 44, 50, 53, 53, 10, 35, 64, 103,
  109, 105, 99, 32, 109, 97, 110, 100, 101, 108, 98, 114, 111, 116, 32, 58,
  32, 122, 48, 114, 44, 122, 48, 105, 44, 122, 49, 114, 44, 122, 49, 105,
  44, 95, 105, 116, 101, 114, 97, 116, 105, 111, 110, 95, 109, 97, 120, 62,
  61, 48, 44, 95, 105, 115, 95, 106, 117, 108, 105, 97, 61, 123, 32, 48,
  32, 124, 32, 49, 32, 125, 44, 95, 99, 48, 114, 44, 95, 99, 48, 105,
  44, 95, 111, 112, 97, 99, 105, 116, 121, 32, 58, 32, 40, 43, 41, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 114, 97, 119, 32, 109, 97,
  110, 100, 101, 108, 98, 114, 111, 116, 47, 106, 117, 108, 105, 97, 32, 102,
  114, 97, 99, 116, 97, 108, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117,
  101, 115, 58, 32, 39, 105, 116, 101, 114, 97, 116, 105, 111, 110, 95, 109,
  97, 120, 61, 49, 48, 48, 39, 44, 32, 39, 105, 115, 95, 106, 117, 108,
  105, 97, 61, 48, 39, 44, 32, 39, 99, 48, 114, 61, 99, 48, 105, 61,
  48, 39, 32, 97, 110, 100, 32, 39, 111, 112, 97, 99, 105, 116, 121, 61,
  49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 52,
  48, 48, 44, 52, 48, 48, 32, 45, 109, 97, 110, 100, 101, 108, 98, 114,
  111, 116, 32, 45, 50, 46, 53, 44, 45, 50, 44, 50, 44, 50, 44, 49,
  48, 50, 52, 32, 45, 109, 97, 112, 32, 48, 32, 45, 45, 98, 108, 117,
  114, 32, 50, 32, 45, 101, 108, 101, 118, 97, 116, 105, 111, 110, 51, 100,
  91, 45, 49, 93, 32, 45, 48, 46, 50, 10, 35, 64, 103, 109, 105, 99,
  32, 109, 97, 114, 98, 108, 101, 32, 58, 32, 95, 105, 109, 97, 103, 101,
  95, 119, 101, 105, 103, 104, 116, 44, 95, 112, 97, 116, 116, 101, 114, 110,
  95, 119, 101, 105, 103, 104, 116, 44, 95, 97, 110, 103, 108, 101, 44, 95,
  97, 109, 112, 108, 105, 116, 117, 100, 101, 44, 95, 115, 104, 97, 114, 112,
  110, 101, 115, 115, 62, 61, 48, 44, 95, 97, 110, 105, 115, 111, 116, 114,
  111, 112, 121, 62, 61, 48, 44, 95, 97, 108, 112, 104, 97, 44, 95, 115,
  105, 103, 109, 97, 44, 95, 99, 117, 116, 95, 108, 111, 119, 62, 61, 48,
  44, 95, 99, 117, 116, 95, 104, 105, 103, 104, 62, 61, 48, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 82, 101, 110, 100, 101, 114, 32, 109, 97,
  114, 98, 108, 101, 32, 108, 105, 107, 101, 32, 112, 97, 116, 116, 101, 114,
  110, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39,
  105, 109, 97, 103, 101, 95, 119, 101, 105, 103, 104, 116, 61, 48, 46, 50,
  39, 44, 32, 39, 112, 97, 116, 116, 101, 114, 110, 95, 119, 101, 105, 103,
  104, 116, 61, 48, 46, 49, 39, 44, 32, 39, 97, 110, 103, 108, 101, 61,
  52, 53, 39, 44, 32, 39, 97, 109, 112, 108, 105, 116, 117, 100, 101, 61,
  48, 39, 44, 32, 39, 115, 104, 97, 114, 112, 110, 101, 115, 115, 61, 48,
  46, 52, 39, 44, 32, 39, 97, 110, 105, 115, 111, 116, 114, 111, 112, 121,
  61, 48, 46, 56, 39, 44, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  39, 97, 108, 112, 104, 97, 61, 48, 46, 54, 39, 44, 32, 39, 115, 105,
  103, 109, 97, 61, 49, 46, 49, 39, 32, 97, 110, 100, 32, 39, 99, 117,
  116, 95, 108, 111, 119, 61, 99, 117, 116, 95, 104, 105, 103, 104, 61, 48,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 109, 97, 114, 98, 108, 101,
  32, 44, 10, 109, 97, 114, 98, 108, 101, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 49, 61, 48, 46, 50, 125, 44, 36, 123, 50, 61, 48,
  46, 49, 125, 44, 36, 123, 51, 61, 52, 53, 125, 44, 36, 123, 52, 61,
  48, 125, 44, 36, 123, 53, 61, 48, 46, 52, 125, 44, 36, 123, 54, 61,
  48, 46, 56, 125, 44, 36, 123, 55, 61, 48, 46, 54, 125, 44, 36, 123,
  56, 61, 49, 46, 49, 125, 44, 36, 123, 57, 61, 48, 37, 125, 44, 36,
  123, 49, 48, 61, 49, 48, 48, 37, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 82, 101, 110, 100, 101, 114, 32, 109, 97, 114, 98, 108, 101,
  32, 108, 105, 107, 101, 32, 112, 97, 116, 116, 101, 114, 110, 32, 111, 110,
  32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 105,
  109, 97, 103, 101, 32, 119, 101, 105, 103, 104, 116, 32, 36, 49, 44, 32,
  112, 97, 116, 116, 101, 114, 110, 32, 119, 101, 105, 103, 104, 116, 32, 36,
  50, 44, 32, 97, 110, 103, 108, 101, 32, 36, 51, 32, 100, 101, 103, 46,
  44, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 36, 52, 44, 32,
  34, 92, 10, 34, 115, 104, 97, 114, 112, 110, 101, 115, 115, 32, 36, 53,
  44, 32, 97, 110, 105, 115, 111, 116, 114, 111, 112, 121, 32, 36, 54, 44,
  32, 97, 108, 112, 104, 97, 32, 36, 55, 44, 32, 115, 105, 103, 109, 97,
  32, 36, 56, 44, 32, 97, 110, 100, 32, 99, 117, 116, 32, 40, 36, 57,
  44, 36, 49, 48, 41, 46, 34, 10, 45, 118, 32, 45, 32, 115, 120, 61,
  123, 36, 50, 42, 115, 105, 110, 40, 36, 51, 42, 112, 105, 47, 49, 56,
  48, 41, 125, 32, 115, 121, 61, 123, 36, 50, 42, 99, 111, 115, 40, 36,
  51, 42, 112, 105, 47, 49, 56, 48, 41, 125, 32, 45, 102, 32, 115, 105,
  110, 40, 120, 42, 36, 115, 120, 43, 121, 42, 36, 115, 121, 43, 105, 42,
  36, 49, 41, 10, 45, 105, 102, 32, 123, 36, 52, 125, 32, 45, 115, 109,
  111, 111, 116, 104, 32, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55,
  44, 36, 56, 32, 45, 101, 110, 100, 105, 102, 10, 45, 99, 32, 36, 57,
  44, 36, 49, 48, 32, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 109, 97, 122, 101, 32, 58,
  32, 95, 119, 105, 100, 116, 104, 62, 48, 44, 95, 104, 101, 105, 103, 104,
  116, 62, 48, 44, 95, 99, 101, 108, 108, 95, 115, 105, 122, 101, 62, 48,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 110, 112, 117, 116, 32,
  109, 97, 122, 101, 32, 119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102,
  105, 101, 100, 32, 115, 105, 122, 101, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 45, 109, 97, 122, 101, 32, 51, 48, 44, 50, 48,
  32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 32, 45, 110, 111, 114, 109,
  97, 108, 105, 122, 101, 32, 48, 44, 50, 53, 53, 10, 109, 97, 122, 101,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110, 116,
  40, 36, 123, 49, 61, 49, 53, 125, 41, 32, 38, 38, 32, 36, 49, 62,
  48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 50, 61, 36,
  49, 125, 41, 32, 38, 38, 32, 36, 50, 62, 48, 32, 38, 38, 32, 105,
  115, 105, 110, 116, 40, 36, 123, 51, 61, 50, 52, 125, 41, 32, 38, 38,
  32, 36, 51, 62, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  73, 110, 112, 117, 116, 32, 36, 49, 120, 36, 50, 32, 109, 97, 122, 101,
  46, 34, 10, 45, 118, 32, 45, 10, 40, 123, 114, 111, 117, 110, 100, 40,
  63, 40, 36, 49, 45, 49, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 36, 50, 45, 49, 41, 41, 125, 41, 10, 36, 49, 44, 36,
  50, 44, 49, 44, 49, 44, 49, 53, 32, 45, 45, 102, 91, 45, 49, 93,
  32, 48, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45,
  95, 103, 101, 110, 101, 114, 97, 116, 101, 95, 109, 97, 122, 101, 32, 36,
  49, 44, 36, 50, 10, 45, 95, 114, 101, 110, 100, 101, 114, 95, 109, 97,
  122, 101, 91, 45, 49, 93, 32, 36, 51, 32, 45, 110, 109, 91, 45, 49,
  93, 32, 91, 109, 97, 122, 101, 93, 10, 45, 118, 32, 43, 10, 95, 103,
  101, 110, 101, 114, 97, 116, 101, 95, 109, 97, 122, 101, 32, 58, 10, 45,
  100, 111, 10, 120, 61, 64, 123, 45, 50, 44, 45, 50, 125, 32, 121, 61,
  64, 123, 45, 50, 44, 45, 49, 125, 10, 45, 61, 91, 45, 49, 93, 32,
  49, 44, 36, 120, 44, 36, 121, 44, 48, 44, 49, 10, 105, 115, 95, 99,
  97, 110, 100, 105, 100, 97, 116, 101, 61, 48, 10, 117, 112, 61, 45, 49,
  32, 45, 105, 102, 32, 123, 105, 40, 36, 120, 44, 36, 121, 41, 38, 56,
  34, 32, 38, 38, 32, 34, 36, 121, 62, 48, 34, 32, 38, 38, 32, 34,
  33, 105, 40, 36, 120, 44, 36, 121, 45, 49, 44, 48, 44, 49, 41, 125,
  32, 117, 112, 61, 36, 120, 44, 123, 36, 121, 45, 49, 125, 44, 56, 32,
  105, 115, 95, 99, 97, 110, 100, 105, 100, 97, 116, 101, 61, 49, 32, 45,
  101, 110, 100, 105, 102, 10, 100, 111, 119, 110, 61, 45, 49, 32, 45, 105,
  102, 32, 123, 105, 40, 36, 120, 44, 36, 121, 41, 38, 52, 34, 32, 38,
  38, 32, 34, 36, 121, 60, 36, 50, 45, 49, 34, 32, 38, 38, 32, 34,
  33, 105, 40, 36, 120, 44, 36, 121, 43, 49, 44, 48, 44, 49, 41, 125,
  32, 100, 111, 119, 110, 61, 36, 120, 44, 123, 36, 121, 43, 49, 125, 44,
  52, 32, 105, 115, 95, 99, 97, 110, 100, 105, 100, 97, 116, 101, 61, 49,
  32, 45, 101, 110, 100, 105, 102, 10, 108, 101, 102, 116, 61, 45, 49, 32,
  45, 105, 102, 32, 123, 105, 40, 36, 120, 44, 36, 121, 41, 38, 50, 34,
  32, 38, 38, 32, 34, 36, 120, 62, 48, 34, 32, 38, 38, 32, 34, 33,
  105, 40, 36, 120, 45, 49, 44, 36, 121, 44, 48, 44, 49, 41, 125, 32,
  108, 101, 102, 116, 61, 123, 36, 120, 45, 49, 125, 44, 36, 121, 44, 50,
  32, 105, 115, 95, 99, 97, 110, 100, 105, 100, 97, 116, 101, 61, 49, 32,
  45, 101, 110, 100, 105, 102, 10, 114, 105, 103, 104, 116, 61, 45, 49, 32,
  45, 105, 102, 32, 123, 105, 40, 36, 120, 44, 36, 121, 41, 38, 49, 34,
  32, 38, 38, 32, 34, 36, 120, 60, 36, 49, 45, 49, 34, 32, 38, 38,
  32, 34, 33, 105, 40, 36, 120, 43, 49, 44, 36, 121, 44, 48, 44, 49,
  41, 125, 32, 114, 105, 103, 104, 116, 61, 123, 36, 120, 43, 49, 125, 44,
  36, 121, 44, 49, 32, 105, 115, 95, 99, 97, 110, 100, 105, 100, 97, 116,
  101, 61, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36,
  105, 115, 95, 99, 97, 110, 100, 105, 100, 97, 116, 101, 10, 40, 36, 117,
  112, 44, 36, 100, 111, 119, 110, 44, 36, 108, 101, 102, 116, 44, 36, 114,
  105, 103, 104, 116, 41, 32, 45, 100, 105, 115, 99, 97, 114, 100, 91, 45,
  49, 93, 32, 45, 49, 32, 45, 114, 91, 45, 49, 93, 32, 51, 44, 123,
  104, 47, 51, 125, 44, 49, 44, 49, 44, 45, 49, 32, 45, 115, 104, 105,
  102, 116, 91, 45, 49, 93, 32, 48, 44, 123, 63, 40, 52, 41, 125, 44,
  48, 44, 48, 44, 50, 32, 45, 114, 111, 119, 115, 91, 45, 49, 93, 32,
  48, 44, 48, 32, 45, 109, 118, 91, 45, 49, 93, 32, 45, 50, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 105, 115, 95, 99, 97,
  110, 100, 105, 100, 97, 116, 101, 10, 45, 105, 102, 32, 123, 64, 123, 45,
  50, 44, 45, 49, 125, 61, 61, 56, 125, 32, 32, 32, 45, 61, 91, 45,
  49, 93, 32, 123, 105, 40, 36, 120, 44, 36, 121, 41, 38, 55, 125, 44,
  36, 120, 44, 36, 121, 32, 45, 61, 91, 45, 49, 93, 32, 123, 105, 40,
  36, 120, 44, 36, 121, 45, 49, 41, 38, 49, 49, 125, 44, 36, 120, 44,
  123, 36, 121, 45, 49, 125, 10, 45, 101, 108, 105, 102, 32, 123, 64, 123,
  45, 50, 44, 45, 49, 125, 61, 61, 52, 125, 32, 45, 61, 91, 45, 49,
  93, 32, 123, 105, 40, 36, 120, 44, 36, 121, 41, 38, 49, 49, 125, 44,
  36, 120, 44, 36, 121, 32, 45, 61, 91, 45, 49, 93, 32, 123, 105, 40,
  36, 120, 44, 36, 121, 43, 49, 41, 38, 55, 125, 44, 36, 120, 44, 123,
  36, 121, 43, 49, 125, 10, 45, 101, 108, 105, 102, 32, 123, 64, 123, 45,
  50, 44, 45, 49, 125, 61, 61, 50, 125, 32, 45, 61, 91, 45, 49, 93,
  32, 123, 105, 40, 36, 120, 44, 36, 121, 41, 38, 49, 51, 125, 44, 36,
  120, 44, 36, 121, 32, 45, 61, 91, 45, 49, 93, 32, 123, 105, 40, 36,
  120, 45, 49, 44, 36, 121, 41, 38, 49, 52, 125, 44, 123, 36, 120, 45,
  49, 125, 44, 36, 121, 10, 45, 101, 108, 115, 101, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 45, 61, 91, 45, 49, 93,
  32, 123, 105, 40, 36, 120, 44, 36, 121, 41, 38, 49, 52, 125, 44, 36,
  120, 44, 36, 121, 32, 45, 61, 91, 45, 49, 93, 32, 123, 105, 40, 36,
  120, 43, 49, 44, 36, 121, 41, 38, 49, 51, 125, 44, 123, 36, 120, 43,
  49, 125, 44, 36, 121, 10, 45, 101, 110, 100, 105, 102, 10, 45, 122, 91,
  45, 50, 93, 32, 48, 44, 49, 32, 45, 97, 91, 45, 51, 44, 45, 50,
  93, 32, 121, 10, 45, 101, 108, 115, 101, 10, 45, 105, 102, 32, 123, 64,
  123, 45, 50, 44, 104, 125, 61, 61, 49, 125, 32, 45, 98, 114, 101, 97,
  107, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 111, 119, 115, 91, 45,
  50, 93, 32, 48, 44, 123, 64, 123, 45, 50, 44, 104, 125, 45, 50, 125,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 49,
  10, 45, 114, 109, 91, 45, 50, 93, 32, 45, 99, 104, 97, 110, 110, 101,
  108, 115, 91, 45, 49, 93, 32, 48, 10, 95, 114, 101, 110, 100, 101, 114,
  95, 109, 97, 122, 101, 32, 58, 10, 45, 105, 91, 48, 93, 32, 36, 49,
  44, 36, 49, 32, 45, 105, 91, 49, 93, 32, 91, 48, 93, 120, 49, 53,
  10, 45, 108, 105, 110, 101, 91, 56, 45, 49, 53, 93, 32, 48, 44, 48,
  44, 49, 48, 48, 37, 44, 48, 44, 49, 44, 49, 10, 45, 108, 105, 110,
  101, 91, 52, 45, 55, 44, 49, 50, 45, 49, 53, 93, 32, 48, 44, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44,
  49, 10, 45, 108, 105, 110, 101, 91, 50, 45, 51, 44, 54, 45, 55, 44,
  49, 48, 45, 49, 49, 44, 49, 52, 45, 49, 53, 93, 32, 48, 44, 48,
  44, 48, 44, 49, 48, 48, 37, 44, 49, 44, 49, 10, 45, 108, 105, 110,
  101, 91, 49, 45, 49, 53, 58, 50, 93, 32, 49, 48, 48, 37, 44, 48,
  44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 10, 45,
  97, 91, 48, 45, 49, 53, 93, 32, 120, 32, 45, 114, 91, 45, 49, 93,
  32, 123, 119, 42, 36, 49, 125, 44, 123, 104, 42, 36, 49, 125, 32, 45,
  42, 91, 45, 49, 93, 32, 36, 49, 32, 45, 99, 104, 97, 110, 110, 101,
  108, 115, 91, 45, 49, 93, 32, 48, 44, 49, 10, 36, 49, 44, 36, 49,
  44, 49, 44, 49, 44, 120, 32, 36, 49, 44, 36, 49, 44, 49, 44, 49,
  44, 121, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32, 45,
  114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44,
  49, 44, 50, 44, 48, 44, 50, 32, 45, 43, 91, 45, 50, 44, 45, 49,
  93, 10, 45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  44, 48, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 35,
  64, 103, 109, 105, 99, 32, 109, 97, 122, 101, 95, 109, 97, 115, 107, 32,
  58, 32, 95, 99, 101, 108, 108, 115, 105, 122, 101, 62, 48, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 73, 110, 112, 117, 116, 32, 109, 97, 122,
  101, 32, 97, 99, 99, 111, 114, 100, 105, 110, 103, 32, 116, 111, 32, 115,
  105, 122, 101, 32, 97, 110, 100, 32, 115, 104, 97, 112, 101, 32, 111, 102,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 109, 97, 115, 107, 32, 105,
  109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  77, 97, 115, 107, 32, 109, 97, 121, 32, 99, 111, 110, 116, 97, 105, 110,
  32, 100, 105, 115, 99, 111, 110, 110, 101, 99, 116, 101, 100, 32, 115, 104,
  97, 112, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 48, 32, 45, 116, 101, 120, 116, 32, 34, 71, 39, 77, 73, 67, 34,
  44, 48, 44, 48, 44, 53, 55, 44, 49, 44, 49, 32, 45, 100, 105, 108,
  97, 116, 101, 32, 51, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32,
  48, 32, 45, 102, 114, 97, 109, 101, 32, 49, 44, 49, 44, 48, 32, 45,
  109, 97, 122, 101, 95, 109, 97, 115, 107, 32, 56, 32, 45, 100, 105, 108,
  97, 116, 101, 32, 51, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 32,
  45, 42, 32, 50, 53, 53, 10, 109, 97, 122, 101, 95, 109, 97, 115, 107,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110, 116,
  40, 36, 123, 49, 61, 50, 52, 125, 41, 32, 38, 38, 32, 36, 49, 62,
  48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117,
  116, 32, 109, 97, 115, 107, 101, 100, 32, 109, 97, 122, 101, 32, 102, 114,
  111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 32, 119, 105, 116, 104, 32,
  99, 101, 108, 108, 32, 115, 105, 122, 101, 32, 36, 49, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 110, 111, 114, 109, 32, 45, 103, 101, 32, 53, 48,
  37, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 100, 111, 10, 45, 45, 114, 97, 110, 100, 91, 48,
  93, 32, 48, 44, 49, 32, 45, 42, 91, 45, 49, 93, 32, 91, 48, 93,
  32, 40, 123, 120, 77, 125, 44, 123, 121, 77, 125, 41, 32, 45, 114, 109,
  91, 45, 50, 93, 10, 45, 45, 102, 108, 111, 111, 100, 91, 48, 93, 32,
  64, 45, 49, 44, 48, 44, 48, 44, 48, 44, 49, 44, 50, 32, 45, 103,
  101, 91, 45, 49, 93, 32, 50, 32, 45, 45, 110, 101, 103, 97, 116, 105,
  118, 101, 91, 45, 49, 93, 32, 45, 42, 91, 45, 50, 93, 32, 49, 53,
  32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 102, 108,
  111, 111, 100, 91, 48, 93, 32, 64, 45, 50, 44, 48, 44, 48, 44, 48,
  44, 49, 44, 48, 10, 45, 95, 103, 101, 110, 101, 114, 97, 116, 101, 95,
  109, 97, 122, 101, 32, 123, 119, 125, 44, 123, 104, 125, 10, 45, 119, 104,
  105, 108, 101, 32, 64, 123, 48, 44, 77, 125, 10, 45, 114, 109, 91, 48,
  93, 32, 45, 43, 32, 45, 95, 114, 101, 110, 100, 101, 114, 95, 109, 97,
  122, 101, 91, 45, 49, 93, 32, 36, 49, 32, 45, 110, 109, 91, 45, 49,
  93, 32, 91, 109, 97, 122, 101, 93, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 111, 98, 106, 101, 99, 116, 51, 100, 32, 58, 32, 91, 111, 98, 106,
  101, 99, 116, 51, 100, 93, 44, 95, 120, 91, 37, 93, 44, 95, 121, 91,
  37, 93, 44, 95, 122, 44, 95, 111, 112, 97, 99, 105, 116, 121, 44, 95,
  114, 101, 110, 100, 101, 114, 105, 110, 103, 95, 109, 111, 100, 101, 44, 95,
  105, 115, 95, 100, 111, 117, 98, 108, 101, 95, 115, 105, 100, 101, 100, 61,
  123, 32, 48, 32, 124, 32, 49, 32, 125, 44, 95, 105, 115, 95, 122, 98,
  117, 102, 102, 101, 114, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 44,
  95, 102, 111, 99, 97, 108, 101, 44, 95, 108, 105, 103, 104, 116, 95, 120,
  44, 95, 108, 105, 103, 104, 116, 95, 121, 44, 95, 108, 105, 103, 104, 116,
  95, 122, 44, 95, 115, 112, 101, 99, 117, 108, 97, 114, 95, 108, 105, 103,
  104, 116, 110, 101, 115, 115, 44, 95, 115, 112, 101, 99, 117, 108, 97, 114,
  95, 115, 104, 105, 110, 105, 110, 101, 115, 115, 32, 58, 32, 40, 43, 41,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 114, 97, 119, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 51, 100, 32, 111, 98, 106, 101,
  99, 116, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  39, 114, 101, 110, 100, 101, 114, 105, 110, 103, 95, 109, 111, 100, 101, 39,
  32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 100, 111, 116, 115,
  32, 124, 32, 49, 61, 119, 105, 114, 101, 102, 114, 97, 109, 101, 32, 124,
  32, 50, 61, 102, 108, 97, 116, 32, 124, 32, 51, 61, 102, 108, 97, 116,
  45, 115, 104, 97, 100, 101, 100, 32, 124, 32, 52, 61, 103, 111, 117, 114,
  97, 117, 100, 45, 115, 104, 97, 100, 101, 100, 32, 124, 32, 53, 61, 112,
  104, 111, 110, 103, 45, 115, 104, 97, 100, 101, 100, 32, 125, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32,
  118, 97, 108, 117, 101, 115, 58, 32, 39, 120, 61, 121, 61, 122, 61, 48,
  39, 44, 32, 39, 111, 112, 97, 99, 105, 116, 121, 61, 49, 39, 32, 97,
  110, 100, 32, 39, 105, 115, 95, 122, 98, 117, 102, 102, 101, 114, 61, 49,
  39, 46, 32, 65, 108, 108, 32, 111, 116, 104, 101, 114, 32, 97, 114, 103,
  117, 109, 101, 110, 116, 115, 32, 116, 97, 107, 101, 32, 116, 104, 101, 105,
  114, 32, 100, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115,
  32, 102, 114, 111, 109, 32, 116, 104, 101, 32, 51, 100, 32, 101, 110, 118,
  105, 114, 111, 110, 109, 101, 110, 116, 32, 118, 97, 114, 105, 97, 98, 108,
  101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 116, 111, 114, 117, 115, 51,
  100, 32, 49, 48, 48, 44, 49, 48, 32, 45, 99, 111, 110, 101, 51, 100,
  32, 51, 48, 44, 45, 49, 50, 48, 32, 45, 97, 100, 100, 51, 100, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 114, 111, 116, 97, 116, 101, 51, 100,
  91, 45, 49, 93, 32, 49, 44, 49, 44, 48, 44, 54, 48, 32, 45, 111,
  98, 106, 101, 99, 116, 51, 100, 91, 48, 93, 32, 91, 45, 49, 93, 44,
  53, 48, 37, 44, 53, 48, 37, 32, 45, 107, 101, 101, 112, 91, 48, 93,
  10, 35, 64, 103, 109, 105, 99, 32, 112, 97, 99, 107, 95, 115, 112, 114,
  105, 116, 101, 115, 32, 58, 32, 95, 110, 98, 95, 115, 99, 97, 108, 101,
  115, 62, 61, 48, 44, 48, 60, 61, 95, 109, 105, 110, 95, 115, 99, 97,
  108, 101, 60, 61, 49, 48, 48, 44, 95, 97, 108, 108, 111, 119, 95, 114,
  111, 116, 97, 116, 105, 111, 110, 61, 123, 32, 48, 61, 48, 32, 100, 101,
  103, 46, 32, 124, 32, 49, 61, 49, 56, 48, 32, 100, 101, 103, 46, 32,
  124, 32, 50, 61, 57, 48, 32, 100, 101, 103, 46, 32, 124, 32, 51, 61,
  97, 110, 121, 32, 125, 44, 95, 115, 112, 97, 99, 105, 110, 103, 44, 95,
  112, 114, 101, 99, 105, 115, 105, 111, 110, 62, 61, 48, 44, 44, 109, 97,
  120, 95, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 62, 61, 48, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 84, 114, 121, 32, 116, 111, 32,
  114, 97, 110, 100, 111, 109, 108, 121, 32, 112, 97, 99, 107, 32, 97, 115,
  32, 109, 97, 110, 121, 32, 115, 112, 114, 105, 116, 101, 115, 32, 97, 115,
  32, 112, 111, 115, 115, 105, 98, 108, 101, 32, 111, 110, 116, 111, 32, 116,
  104, 101, 32, 39, 101, 109, 112, 116, 121, 39, 32, 97, 114, 101, 97, 115,
  32, 111, 102, 32, 97, 110, 32, 105, 109, 97, 103, 101, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 83, 112, 114, 105, 116, 101, 115, 32, 99,
  97, 110, 32, 98, 101, 32, 101, 118, 101, 110, 116, 117, 97, 108, 108, 121,
  32, 114, 111, 116, 97, 116, 101, 100, 32, 97, 110, 100, 32, 115, 99, 97,
  108, 101, 100, 32, 100, 117, 114, 105, 110, 103, 32, 116, 104, 101, 32, 112,
  97, 99, 107, 105, 110, 103, 32, 112, 114, 111, 99, 101, 115, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 70, 105, 114, 115, 116, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 32, 105, 115,
  32, 116, 104, 101, 32, 99, 97, 110, 118, 97, 115, 32, 116, 104, 97, 116,
  32, 119, 105, 108, 108, 32, 98, 101, 32, 102, 105, 108, 108, 101, 100, 32,
  119, 105, 116, 104, 32, 116, 104, 101, 32, 115, 112, 114, 105, 116, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 116, 115, 32, 108,
  97, 115, 116, 32, 99, 104, 97, 110, 110, 101, 108, 32, 109, 117, 115, 116,
  32, 98, 101, 32, 97, 32, 98, 105, 110, 97, 114, 121, 32, 109, 97, 115,
  107, 32, 119, 104, 111, 115, 101, 32, 122, 101, 114, 111, 32, 118, 97, 108,
  117, 101, 115, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 32, 112, 111,
  116, 101, 110, 116, 105, 97, 108, 32, 108, 111, 99, 97, 116, 105, 111, 110,
  115, 32, 102, 111, 114, 32, 100, 114, 97, 119, 105, 110, 103, 32, 116, 104,
  101, 32, 115, 112, 114, 105, 116, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 65, 108, 108, 32, 111, 116, 104, 101, 114, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 114, 101,
  112, 114, 101, 115, 101, 110, 116, 32, 116, 104, 101, 32, 115, 112, 114, 105,
  116, 101, 115, 32, 99, 111, 110, 115, 105, 100, 101, 114, 101, 100, 32, 102,
  111, 114, 32, 112, 97, 99, 107, 105, 110, 103, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 84, 104, 101, 105, 114, 32, 108, 97, 115, 116, 32,
  99, 104, 97, 110, 110, 101, 108, 32, 109, 117, 115, 116, 32, 98, 101, 32,
  97, 32, 98, 105, 110, 97, 114, 121, 32, 109, 97, 115, 107, 32, 116, 104,
  97, 116, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 115, 32, 116, 104,
  101, 32, 115, 112, 114, 105, 116, 101, 32, 115, 104, 97, 112, 101, 32, 40,
  105, 46, 101, 46, 32, 97, 32, 56, 45, 99, 111, 110, 110, 101, 99, 116,
  101, 100, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 41, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 84, 104, 101, 32, 111, 114, 100, 101,
  114, 32, 111, 102, 32, 115, 112, 114, 105, 116, 101, 32, 112, 97, 99, 107,
  105, 110, 103, 32, 102, 111, 108, 108, 111, 119, 115, 32, 116, 104, 101, 32,
  111, 114, 100, 101, 114, 32, 111, 102, 32, 115, 112, 101, 99, 105, 102, 105,
  101, 100, 32, 115, 112, 114, 105, 116, 101, 115, 32, 105, 110, 32, 116, 104,
  101, 32, 105, 109, 97, 103, 101, 32, 108, 105, 115, 116, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 83, 112, 114, 105, 116, 101, 32, 112, 97,
  99, 107, 105, 110, 103, 32, 105, 115, 32, 100, 111, 110, 101, 32, 111, 110,
  32, 114, 97, 110, 100, 111, 109, 32, 108, 111, 99, 97, 116, 105, 111, 110,
  115, 32, 97, 110, 100, 32, 105, 116, 101, 114, 97, 116, 105, 118, 101, 108,
  121, 32, 119, 105, 116, 104, 32, 100, 101, 99, 114, 101, 97, 115, 105, 110,
  103, 32, 115, 99, 97, 108, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 39, 110, 98, 95, 115, 99, 97, 108, 101, 115, 39, 32, 115,
  101, 116, 115, 32, 116, 104, 101, 32, 110, 117, 109, 98, 101, 114, 32, 111,
  102, 32, 100, 101, 99, 114, 101, 97, 115, 105, 110, 103, 32, 115, 99, 97,
  108, 101, 115, 32, 99, 111, 110, 115, 105, 100, 101, 114, 101, 100, 32, 102,
  111, 114, 32, 97, 108, 108, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100,
  32, 115, 112, 114, 105, 116, 101, 115, 32, 116, 111, 32, 98, 101, 32, 112,
  97, 99, 107, 101, 100, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  39, 109, 105, 110, 95, 115, 99, 97, 108, 101, 39, 32, 40, 105, 110, 32,
  37, 41, 32, 115, 101, 116, 115, 32, 116, 104, 101, 32, 109, 105, 110, 105,
  109, 97, 108, 32, 115, 105, 122, 101, 32, 99, 111, 110, 115, 105, 100, 101,
  114, 101, 100, 32, 102, 111, 114, 32, 112, 97, 99, 107, 105, 110, 103, 32,
  40, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 97, 115, 32, 97, 32,
  112, 101, 114, 99, 101, 110, 116, 97, 103, 101, 32, 111, 102, 32, 116, 104,
  101, 32, 111, 114, 105, 103, 105, 110, 97, 108, 32, 115, 112, 114, 105, 116,
  101, 32, 115, 105, 122, 101, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 39, 115, 112, 97, 99, 105, 110, 103, 39, 32, 99, 97, 110, 32,
  98, 101, 32, 112, 111, 115, 105, 116, 105, 118, 101, 32, 111, 114, 32, 110,
  101, 103, 97, 116, 105, 118, 101, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 39, 112, 114, 101, 99, 105, 115, 105, 111, 110, 39, 32, 116, 101,
  108, 108, 115, 32, 97, 98, 111, 117, 116, 32, 116, 104, 101, 32, 100, 101,
  115, 105, 114, 101, 100, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32,
  102, 97, 105, 108, 101, 100, 32, 116, 114, 105, 97, 108, 115, 32, 98, 101,
  102, 111, 114, 101, 32, 101, 110, 100, 105, 110, 103, 32, 116, 104, 101, 32,
  102, 105, 108, 108, 105, 110, 103, 32, 112, 114, 111, 99, 101, 115, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108,
  116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 110, 98, 95, 115, 99,
  97, 108, 101, 115, 61, 53, 39, 44, 32, 39, 109, 105, 110, 95, 115, 99,
  97, 108, 101, 61, 50, 53, 39, 44, 32, 39, 97, 108, 108, 111, 119, 95,
  114, 111, 116, 97, 116, 105, 111, 110, 61, 51, 39, 44, 32, 39, 115, 112,
  97, 99, 105, 110, 103, 61, 49, 39, 44, 32, 39, 112, 114, 101, 99, 105,
  115, 105, 111, 110, 61, 55, 39, 32, 97, 110, 100, 32, 39, 109, 97, 120,
  95, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 61, 50, 53, 54, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 53, 49, 50,
  44, 53, 49, 50, 44, 49, 44, 51, 44, 34, 109, 105, 110, 40, 50, 53,
  53, 44, 121, 42, 99, 47, 50, 41, 34, 32, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 32, 45, 99, 105, 114, 99, 108, 101, 32, 53, 48, 37, 44,
  53, 48, 37, 44, 49, 48, 48, 44, 49, 44, 50, 53, 53, 32, 45, 97,
  112, 112, 101, 110, 100, 32, 99, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 114, 101, 115, 105, 122, 101, 50, 100, 121, 91, 45, 49, 93,
  32, 50, 52, 32, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 112, 97,
  99, 107, 95, 115, 112, 114, 105, 116, 101, 115, 32, 51, 44, 50, 53, 10,
  112, 97, 99, 107, 95, 115, 112, 114, 105, 116, 101, 115, 32, 58, 32, 45,
  99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 123, 49,
  61, 53, 125, 41, 32, 38, 38, 32, 36, 49, 62, 61, 48, 32, 38, 38,
  32, 36, 123, 50, 61, 50, 53, 125, 62, 61, 48, 32, 38, 38, 32, 36,
  50, 60, 61, 49, 48, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40,
  36, 123, 51, 61, 51, 125, 41, 32, 38, 38, 32, 36, 51, 62, 61, 48,
  32, 38, 38, 32, 36, 51, 60, 61, 51, 32, 38, 38, 32, 105, 115, 105,
  110, 116, 40, 36, 123, 52, 61, 49, 125, 41, 32, 38, 38, 32, 105, 115,
  105, 110, 116, 40, 36, 123, 53, 61, 55, 125, 41, 32, 38, 38, 32, 36,
  53, 62, 61, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123,
  54, 61, 50, 53, 54, 125, 41, 32, 38, 38, 32, 36, 54, 62, 61, 48,
  34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 97, 110, 100, 111,
  109, 108, 121, 32, 112, 97, 99, 107, 32, 105, 109, 97, 103, 101, 36, 63,
  32, 119, 105, 116, 104, 32, 36, 49, 32, 115, 99, 97, 108, 101, 115, 44,
  32, 109, 105, 110, 105, 109, 117, 109, 32, 115, 99, 97, 108, 101, 32, 36,
  50, 37, 44, 32, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 36,
  51, 44, 110, 111, 44, 49, 56, 48, 92, 34, 92, 32, 92, 34, 100, 101,
  103, 46, 44, 57, 48, 92, 34, 92, 32, 92, 34, 100, 101, 103, 46, 44,
  97, 110, 121, 125, 34, 32, 114, 111, 116, 97, 116, 105, 111, 110, 44, 32,
  115, 112, 97, 99, 105, 110, 103, 32, 36, 52, 44, 32, 112, 114, 101, 99,
  105, 115, 105, 111, 110, 32, 36, 53, 32, 97, 110, 100, 32, 36, 54, 32,
  109, 97, 120, 105, 109, 117, 109, 32, 105, 116, 101, 114, 97, 116, 105, 111,
  110, 115, 46, 34, 10, 45, 118, 32, 45, 32, 78, 61, 123, 64, 35, 45,
  49, 125, 32, 105, 115, 95, 102, 105, 114, 115, 116, 95, 116, 105, 109, 101,
  61, 49, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 114,
  91, 36, 62, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 123, 109, 97, 120, 40, 50, 44, 64, 123, 36, 62, 44, 115, 125, 41,
  125, 32, 45, 100, 111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  36, 49, 10, 45, 114, 112, 114, 111, 103, 114, 101, 115, 115, 32, 123, 36,
  62, 42, 49, 48, 48, 47, 36, 49, 125, 10, 110, 98, 95, 97, 116, 116,
  101, 109, 112, 116, 115, 61, 48, 10, 114, 97, 116, 105, 111, 61, 123, 105,
  102, 40, 36, 49, 62, 49, 44, 36, 50, 43, 40, 49, 48, 48, 45, 36,
  50, 41, 42, 36, 60, 47, 40, 36, 49, 45, 49, 41, 44, 49, 48, 48,
  41, 125, 37, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 78, 32, 45,
  45, 108, 91, 123, 49, 43, 36, 62, 125, 93, 10, 119, 61, 123, 119, 42,
  36, 114, 97, 116, 105, 111, 125, 32, 104, 61, 123, 104, 42, 36, 114, 97,
  116, 105, 111, 125, 10, 45, 105, 102, 32, 123, 36, 119, 60, 49, 124, 124,
  36, 104, 60, 49, 125, 32, 45, 114, 109, 10, 45, 101, 108, 115, 101, 32,
  45, 114, 32, 36, 119, 44, 36, 104, 44, 49, 44, 49, 48, 48, 37, 44,
  50, 32, 45, 115, 104, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 32, 45, 110, 101, 113, 91, 45, 49, 93, 32, 48, 32, 97,
  114, 101, 97, 123, 49, 43, 36, 62, 125, 61, 64, 123, 45, 49, 44, 43,
  125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 108, 91,
  48, 44, 123, 36, 78, 43, 49, 125, 45, 45, 49, 93, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 36, 54, 10, 105, 110, 100, 61, 123, 49, 43, 40,
  36, 62, 37, 36, 78, 41, 125, 32, 97, 114, 101, 97, 61, 36, 123, 97,
  114, 101, 97, 36, 105, 110, 100, 125, 10, 45, 105, 102, 32, 123, 36, 51,
  61, 61, 48, 125, 32, 91, 36, 105, 110, 100, 93, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 51, 61, 61, 49, 125, 32, 45, 45, 114, 111, 116, 97,
  116, 101, 91, 36, 105, 110, 100, 93, 32, 123, 114, 111, 117, 110, 100, 40,
  63, 41, 42, 49, 56, 48, 125, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  51, 61, 61, 50, 125, 32, 45, 45, 114, 111, 116, 97, 116, 101, 91, 36,
  105, 110, 100, 93, 32, 123, 114, 111, 117, 110, 100, 40, 63, 40, 51, 41,
  41, 42, 57, 48, 125, 10, 45, 101, 108, 115, 101, 32, 45, 45, 114, 111,
  116, 97, 116, 101, 91, 36, 105, 110, 100, 93, 32, 123, 63, 42, 51, 54,
  48, 125, 32, 45, 115, 104, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 32, 45, 110, 101, 113, 91, 45, 49, 93, 32, 48, 32,
  97, 114, 101, 97, 61, 64, 123, 45, 49, 44, 43, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 48, 93, 32, 49, 48, 48, 37, 32, 45,
  101, 113, 91, 45, 49, 93, 32, 48, 10, 45, 105, 102, 32, 123, 36, 52,
  62, 49, 125, 32, 45, 101, 114, 111, 100, 101, 91, 45, 49, 93, 32, 123,
  50, 42, 36, 52, 45, 49, 125, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  52, 60, 49, 125, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93,
  32, 123, 45, 50, 42, 36, 52, 43, 51, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49,
  93, 32, 48, 44, 48, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 10, 45,
  105, 102, 32, 36, 105, 115, 95, 102, 105, 114, 115, 116, 95, 116, 105, 109,
  101, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 48, 46, 49,
  44, 50, 32, 45, 101, 110, 100, 105, 102, 10, 45, 100, 105, 115, 116, 97,
  110, 99, 101, 91, 45, 49, 93, 32, 48, 32, 45, 110, 111, 105, 115, 101,
  91, 45, 49, 93, 32, 49, 44, 49, 10, 45, 109, 97, 120, 95, 112, 97,
  116, 99, 104, 91, 45, 49, 93, 32, 123, 114, 111, 117, 110, 100, 40, 49,
  46, 53, 42, 64, 123, 36, 105, 110, 100, 44, 109, 97, 120, 40, 119, 44,
  104, 41, 125, 41, 125, 10, 45, 42, 91, 45, 49, 93, 32, 91, 45, 50,
  93, 32, 45, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 51, 100, 91,
  45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 78, 62, 49, 125, 32, 45,
  108, 91, 45, 49, 93, 10, 45, 115, 51, 100, 32, 45, 47, 91, 49, 93,
  32, 36, 78, 32, 45, 114, 111, 117, 110, 100, 91, 49, 93, 32, 45, 109,
  97, 120, 91, 49, 93, 32, 49, 32, 110, 61, 64, 123, 49, 44, 48, 125,
  10, 45, 114, 91, 50, 93, 32, 51, 44, 123, 64, 123, 50, 44, 104, 125,
  47, 51, 125, 44, 49, 44, 49, 44, 45, 49, 10, 45, 105, 91, 50, 93,
  32, 49, 44, 64, 123, 50, 44, 104, 125, 32, 45, 114, 97, 110, 100, 91,
  50, 93, 32, 48, 44, 49, 32, 45, 97, 91, 50, 44, 51, 93, 32, 120,
  32, 45, 115, 111, 114, 116, 91, 50, 93, 32, 43, 44, 121, 32, 45, 122,
  91, 50, 93, 32, 49, 44, 51, 32, 45, 114, 91, 50, 93, 32, 51, 44,
  36, 110, 44, 49, 44, 49, 32, 45, 121, 91, 50, 93, 10, 45, 114, 91,
  51, 93, 32, 49, 44, 123, 50, 42, 36, 110, 125, 44, 49, 44, 49, 44,
  48, 32, 45, 114, 91, 52, 93, 32, 49, 44, 123, 51, 42, 36, 110, 125,
  44, 49, 44, 49, 44, 48, 32, 45, 114, 91, 53, 93, 32, 49, 44, 36,
  110, 44, 49, 44, 49, 44, 48, 32, 45, 97, 32, 121, 10, 45, 101, 110,
  100, 108, 32, 45, 101, 110, 100, 105, 102, 10, 110, 61, 64, 123, 45, 49,
  44, 55, 125, 10, 45, 105, 102, 32, 36, 110, 10, 45, 115, 51, 100, 91,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45,
  105, 102, 32, 123, 36, 51, 61, 61, 48, 125, 10, 91, 45, 54, 93, 32,
  45, 105, 91, 45, 50, 93, 32, 40, 45, 49, 50, 56, 59, 123, 119, 125,
  59, 123, 104, 125, 59, 123, 115, 125, 41, 10, 45, 105, 102, 32, 123, 36,
  110, 62, 49, 125, 32, 52, 44, 123, 36, 110, 45, 49, 125, 44, 49, 44,
  49, 44, 45, 49, 50, 56, 44, 48, 44, 48, 44, 48, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45,
  50, 93, 32, 49, 48, 48, 37, 32, 45, 105, 91, 45, 50, 93, 32, 40,
  45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 123, 115, 125,
  41, 10, 45, 105, 102, 32, 123, 36, 110, 62, 49, 125, 32, 91, 45, 51,
  93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 51, 61, 61, 49, 125, 10, 45, 45, 114, 111, 116, 97, 116, 101, 91,
  45, 54, 93, 32, 123, 114, 111, 117, 110, 100, 40, 63, 40, 49, 41, 41,
  42, 49, 56, 48, 125, 32, 45, 105, 91, 45, 50, 93, 32, 40, 45, 49,
  50, 56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 123, 115, 125, 41, 10,
  45, 105, 102, 32, 123, 36, 110, 62, 49, 125, 32, 45, 45, 114, 111, 116,
  97, 116, 101, 91, 45, 49, 93, 32, 49, 56, 48, 32, 45, 105, 91, 45,
  50, 93, 32, 40, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104, 125,
  59, 123, 115, 125, 41, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 110, 62, 50, 125, 32, 52, 44, 123, 36, 110, 45, 50, 125,
  44, 49, 44, 49, 44, 45, 49, 50, 56, 44, 48, 44, 48, 44, 48, 32,
  49, 44, 49, 48, 48, 37, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93,
  32, 48, 44, 49, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32,
  49, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 32,
  45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 52, 93, 32, 49, 48,
  48, 37, 32, 45, 105, 91, 45, 50, 93, 32, 40, 45, 49, 50, 56, 59,
  123, 119, 125, 59, 123, 104, 125, 59, 123, 115, 125, 41, 10, 45, 105, 102,
  32, 123, 36, 110, 62, 49, 125, 32, 45, 45, 99, 104, 97, 110, 110, 101,
  108, 115, 91, 45, 52, 93, 32, 49, 48, 48, 37, 32, 45, 105, 91, 45,
  50, 93, 32, 40, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104, 125,
  59, 123, 115, 125, 41, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 110, 62, 50, 125, 32, 91, 45, 53, 93, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 108, 115, 101, 10, 45, 45, 114, 111, 116, 97,
  116, 101, 91, 45, 54, 93, 32, 123, 114, 111, 117, 110, 100, 40, 63, 40,
  51, 41, 41, 42, 57, 48, 125, 32, 45, 105, 91, 45, 50, 93, 32, 40,
  45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 123, 115, 125,
  41, 10, 45, 105, 102, 32, 123, 36, 110, 62, 49, 125, 32, 45, 45, 114,
  111, 116, 97, 116, 101, 91, 45, 49, 93, 32, 57, 48, 32, 45, 105, 91,
  45, 50, 93, 32, 40, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104,
  125, 59, 123, 115, 125, 41, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 110, 62, 50, 125, 32, 45, 45, 114, 111, 116, 97, 116,
  101, 91, 45, 49, 93, 32, 57, 48, 32, 45, 105, 91, 45, 50, 93, 32,
  40, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 123, 115,
  125, 41, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  110, 62, 51, 125, 32, 45, 45, 114, 111, 116, 97, 116, 101, 91, 45, 49,
  93, 32, 57, 48, 32, 45, 105, 91, 45, 50, 93, 32, 40, 45, 49, 50,
  56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 123, 115, 125, 41, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 110, 62, 52, 125,
  32, 52, 44, 123, 36, 110, 45, 52, 125, 44, 49, 44, 49, 44, 45, 49,
  50, 56, 44, 48, 44, 48, 44, 48, 32, 49, 44, 49, 48, 48, 37, 32,
  45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44, 51, 32, 45, 114,
  111, 117, 110, 100, 91, 45, 49, 93, 32, 49, 32, 45, 106, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 99, 104, 97, 110, 110, 101,
  108, 115, 91, 45, 56, 93, 32, 49, 48, 48, 37, 32, 45, 105, 91, 45,
  50, 93, 32, 40, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104, 125,
  59, 123, 115, 125, 41, 10, 45, 105, 102, 32, 123, 36, 110, 62, 49, 125,
  32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 56, 93, 32,
  49, 48, 48, 37, 32, 45, 105, 91, 45, 50, 93, 32, 40, 45, 49, 50,
  56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 123, 115, 125, 41, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 110, 62, 50, 125,
  32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 56, 93, 32,
  49, 48, 48, 37, 32, 45, 105, 91, 45, 50, 93, 32, 40, 45, 49, 50,
  56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 123, 115, 125, 41, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 110, 62, 51, 125,
  32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 56, 93, 32,
  49, 48, 48, 37, 32, 45, 105, 91, 45, 50, 93, 32, 40, 45, 49, 50,
  56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 123, 115, 125, 41, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 110, 62, 52, 125,
  32, 91, 45, 57, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 121, 91, 123, 36, 78, 43, 51, 125, 45, 45, 49,
  93, 32, 45, 97, 91, 123, 36, 78, 43, 51, 125, 45, 45, 49, 93, 32,
  121, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 51, 93,
  10, 91, 48, 93, 32, 45, 115, 104, 91, 45, 49, 93, 32, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 32, 45, 102, 91, 45, 49, 93, 32, 49, 32,
  45, 45, 91, 45, 49, 93, 32, 91, 45, 52, 93, 10, 45, 111, 98, 106,
  101, 99, 116, 51, 100, 91, 45, 50, 93, 32, 91, 45, 51, 93, 44, 48,
  44, 48, 44, 48, 44, 49, 44, 50, 44, 48, 44, 48, 32, 45, 114, 109,
  91, 45, 51, 44, 45, 49, 93, 10, 45, 115, 104, 91, 45, 49, 93, 32,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 97, 114, 101, 97, 95,
  102, 103, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 101, 113, 91, 45,
  49, 93, 32, 36, 97, 114, 101, 97, 10, 45, 42, 91, 45, 49, 93, 32,
  91, 45, 51, 93, 32, 45, 114, 109, 91, 45, 51, 93, 32, 45, 115, 104,
  91, 45, 50, 93, 32, 48, 44, 64, 123, 45, 50, 44, 115, 45, 50, 125,
  32, 45, 42, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 105, 77, 125, 32, 45, 106,
  91, 48, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 49, 44, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 44, 45,
  49, 93, 10, 45, 101, 108, 115, 101, 10, 45, 114, 109, 91, 45, 50, 44,
  45, 49, 93, 10, 110, 98, 95, 97, 116, 116, 101, 109, 112, 116, 115, 61,
  123, 36, 110, 98, 95, 97, 116, 116, 101, 109, 112, 116, 115, 43, 49, 125,
  10, 45, 105, 102, 32, 123, 36, 110, 98, 95, 97, 116, 116, 101, 109, 112,
  116, 115, 62, 36, 53, 125, 32, 45, 98, 114, 101, 97, 107, 32, 45, 101,
  108, 115, 101, 32, 45, 99, 111, 110, 116, 105, 110, 117, 101, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110,
  101, 32, 45, 107, 91, 48, 93, 32, 45, 101, 110, 100, 108, 10, 45, 100,
  111, 110, 101, 32, 45, 107, 91, 48, 93, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 112, 105, 101, 99, 104, 97, 114, 116, 32, 58,
  32, 108, 97, 98, 101, 108, 95, 104, 101, 105, 103, 104, 116, 62, 61, 48,
  44, 108, 97, 98, 101, 108, 95, 82, 44, 108, 97, 98, 101, 108, 95, 71,
  44, 108, 97, 98, 101, 108, 95, 66, 44, 34, 108, 97, 98, 101, 108, 49,
  34, 44, 118, 97, 108, 117, 101, 49, 44, 82, 49, 44, 71, 49, 44, 66,
  49, 44, 46, 46, 46, 44, 34, 108, 97, 98, 101, 108, 78, 34, 44, 118,
  97, 108, 117, 101, 78, 44, 82, 78, 44, 71, 78, 44, 66, 78, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 114, 97, 119, 32, 112, 105, 101,
  32, 99, 104, 97, 114, 116, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 40, 82, 71, 66, 41, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 112, 105, 101, 99, 104, 97, 114, 116, 32,
  50, 53, 44, 48, 44, 48, 44, 48, 44, 34, 82, 101, 100, 34, 44, 53,
  53, 44, 50, 53, 53, 44, 48, 44, 48, 44, 34, 71, 114, 101, 101, 110,
  34, 44, 52, 48, 44, 48, 44, 50, 53, 53, 44, 48, 44, 34, 66, 108,
  117, 101, 34, 44, 51, 48, 44, 49, 50, 56, 44, 49, 50, 56, 44, 50,
  53, 53, 44, 34, 79, 116, 104, 101, 114, 34, 44, 53, 44, 49, 50, 56,
  44, 49, 50, 56, 44, 49, 50, 56, 10, 112, 105, 101, 99, 104, 97, 114,
  116, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 49, 62, 61, 48,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 114, 97, 119, 32, 112,
  105, 101, 32, 99, 104, 97, 114, 116, 32, 111, 110, 32, 105, 109, 97, 103,
  101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 108, 97, 98, 101, 108, 32,
  104, 101, 105, 103, 104, 116, 32, 36, 49, 32, 97, 110, 100, 32, 99, 111,
  108, 111, 114, 32, 40, 36, 50, 44, 36, 51, 44, 36, 52, 41, 46, 34,
  10, 45, 118, 32, 45, 32, 36, 61, 97, 114, 103, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 101,
  108, 108, 105, 112, 115, 101, 32, 53, 48, 37, 44, 53, 48, 37, 44, 123,
  119, 47, 50, 45, 49, 125, 44, 123, 104, 47, 50, 45, 49, 125, 44, 48,
  44, 49, 44, 49, 10, 45, 101, 108, 108, 105, 112, 115, 101, 32, 53, 48,
  37, 44, 53, 48, 37, 44, 123, 119, 47, 50, 45, 49, 125, 44, 123, 104,
  47, 50, 45, 49, 125, 44, 48, 44, 49, 44, 48, 120, 70, 70, 70, 70,
  70, 70, 70, 70, 10, 40, 36, 123, 54, 45, 45, 49, 58, 53, 125, 41,
  32, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 115, 117, 109, 91,
  45, 49, 93, 10, 116, 104, 101, 116, 97, 61, 48, 10, 45, 105, 102, 32,
  123, 119, 62, 49, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 119,
  125, 10, 120, 101, 61, 123, 48, 46, 53, 42, 64, 123, 45, 50, 44, 119,
  125, 42, 40, 49, 43, 99, 111, 115, 40, 36, 116, 104, 101, 116, 97, 41,
  41, 125, 10, 121, 101, 61, 123, 48, 46, 53, 42, 64, 123, 45, 50, 44,
  104, 125, 42, 40, 49, 43, 115, 105, 110, 40, 36, 116, 104, 101, 116, 97,
  41, 41, 125, 10, 45, 108, 105, 110, 101, 91, 45, 50, 93, 32, 53, 48,
  37, 44, 53, 48, 37, 44, 36, 120, 101, 44, 36, 121, 101, 10, 116, 104,
  101, 116, 97, 61, 123, 36, 116, 104, 101, 116, 97, 45, 50, 42, 112, 105,
  42, 105, 40, 36, 62, 41, 125, 10, 45, 100, 111, 110, 101, 32, 45, 101,
  110, 100, 105, 102, 10, 116, 104, 101, 116, 97, 61, 48, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 119, 125, 32, 45, 105, 102, 32, 123, 105, 40,
  36, 62, 41, 125, 10, 110, 116, 104, 101, 116, 97, 61, 123, 36, 116, 104,
  101, 116, 97, 45, 50, 42, 112, 105, 42, 105, 40, 36, 62, 41, 125, 10,
  120, 99, 61, 123, 48, 46, 53, 42, 64, 123, 45, 50, 44, 119, 125, 42,
  40, 49, 43, 48, 46, 53, 42, 99, 111, 115, 40, 48, 46, 53, 42, 40,
  36, 110, 116, 104, 101, 116, 97, 43, 36, 116, 104, 101, 116, 97, 41, 41,
  41, 125, 10, 121, 99, 61, 123, 48, 46, 53, 42, 64, 123, 45, 50, 44,
  104, 125, 42, 40, 49, 43, 48, 46, 53, 42, 115, 105, 110, 40, 48, 46,
  53, 42, 40, 36, 110, 116, 104, 101, 116, 97, 43, 36, 116, 104, 101, 116,
  97, 41, 41, 41, 125, 10, 120, 102, 61, 123, 48, 46, 53, 42, 64, 123,
  45, 50, 44, 119, 125, 42, 40, 49, 43, 48, 46, 56, 42, 99, 111, 115,
  40, 48, 46, 53, 42, 40, 36, 110, 116, 104, 101, 116, 97, 43, 36, 116,
  104, 101, 116, 97, 41, 41, 41, 125, 10, 121, 102, 61, 123, 48, 46, 53,
  42, 64, 123, 45, 50, 44, 104, 125, 42, 40, 49, 43, 48, 46, 56, 42,
  115, 105, 110, 40, 48, 46, 53, 42, 40, 36, 110, 116, 104, 101, 116, 97,
  43, 36, 116, 104, 101, 116, 97, 41, 41, 41, 125, 10, 45, 102, 108, 111,
  111, 100, 91, 45, 50, 93, 32, 36, 120, 102, 44, 36, 121, 102, 44, 48,
  44, 48, 44, 48, 44, 49, 44, 36, 123, 97, 114, 103, 123, 55, 43, 53,
  42, 36, 62, 125, 125, 44, 36, 123, 97, 114, 103, 123, 56, 43, 53, 42,
  36, 62, 125, 125, 44, 36, 123, 97, 114, 103, 123, 57, 43, 53, 42, 36,
  62, 125, 125, 10, 45, 105, 102, 32, 123, 97, 98, 115, 40, 36, 110, 116,
  104, 101, 116, 97, 45, 36, 116, 104, 101, 116, 97, 41, 62, 48, 46, 49,
  125, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 36, 123, 97, 114, 103,
  123, 53, 43, 53, 42, 36, 62, 125, 125, 44, 48, 44, 48, 44, 36, 49,
  44, 49, 44, 49, 10, 40, 36, 50, 94, 36, 51, 94, 36, 52, 41, 32,
  45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93,
  44, 49, 44, 51, 32, 45, 42, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  10, 45, 106, 91, 45, 52, 93, 32, 91, 45, 49, 93, 44, 123, 36, 120,
  99, 45, 119, 47, 50, 125, 44, 123, 36, 121, 99, 45, 104, 47, 50, 125,
  44, 48, 44, 48, 44, 49, 44, 91, 45, 50, 93, 10, 45, 114, 109, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 116, 104,
  101, 116, 97, 61, 36, 110, 116, 104, 101, 116, 97, 10, 45, 101, 110, 100,
  105, 102, 32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 112, 108, 97, 115, 109, 97, 32,
  58, 32, 95, 97, 108, 112, 104, 97, 44, 95, 95, 98, 101, 116, 97, 44,
  95, 115, 99, 97, 108, 101, 62, 61, 48, 32, 58, 32, 40, 43, 41, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 114, 97, 119, 32, 97, 32,
  114, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111, 114, 101, 100, 32, 112,
  108, 97, 115, 109, 97, 32, 102, 114, 97, 99, 116, 97, 108, 32, 111, 110,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 84, 104, 105, 115, 32,
  99, 111, 109, 109, 97, 110, 100, 32, 105, 109, 112, 108, 101, 109, 101, 110,
  116, 115, 32, 116, 104, 101, 32, 115, 111, 45, 99, 97, 108, 108, 101, 100,
  32, 39, 68, 105, 97, 109, 111, 110, 100, 45, 83, 113, 117, 97, 114, 101,
  39, 32, 97, 108, 103, 111, 114, 105, 116, 104, 109, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 97, 108, 112, 104, 97, 61, 49, 39, 44,
  32, 39, 98, 101, 116, 97, 61, 49, 39, 32, 97, 110, 100, 32, 39, 115,
  99, 97, 108, 101, 61, 56, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 52, 48, 48, 44, 52, 48, 48, 44, 49, 44, 51, 32,
  45, 112, 108, 97, 115, 109, 97, 10, 35, 64, 103, 109, 105, 99, 32, 112,
  111, 105, 110, 116, 32, 58, 32, 120, 91, 37, 93, 44, 121, 91, 37, 93,
  44, 95, 122, 91, 37, 93, 44, 95, 111, 112, 97, 99, 105, 116, 121, 44,
  95, 99, 111, 108, 111, 114, 49, 44, 46, 46, 32, 58, 32, 40, 43, 41,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 101, 116, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 99, 111, 108, 111, 114, 101, 100, 32,
  112, 105, 120, 101, 108, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  115, 58, 32, 39, 122, 61, 48, 39, 44, 32, 39, 111, 112, 97, 99, 105,
  116, 121, 61, 49, 39, 32, 97, 110, 100, 32, 39, 99, 111, 108, 111, 114,
  49, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 49, 48, 48, 48, 48, 32, 45, 112, 111, 105, 110, 116, 32,
  123, 63, 40, 49, 48, 48, 41, 125, 37, 44, 123, 63, 40, 49, 48, 48,
  41, 125, 37, 44, 48, 44, 49, 44, 64, 123, 45, 82, 71, 66, 125, 32,
  45, 100, 111, 110, 101, 10, 35, 64, 103, 109, 105, 99, 32, 112, 111, 108,
  107, 97, 95, 100, 111, 116, 115, 32, 58, 32, 100, 105, 97, 109, 101, 116,
  101, 114, 62, 61, 48, 44, 95, 100, 101, 110, 115, 105, 116, 121, 44, 95,
  111, 102, 102, 115, 101, 116, 49, 44, 95, 111, 102, 102, 115, 101, 116, 50,
  44, 95, 97, 110, 103, 108, 101, 44, 95, 97, 108, 105, 97, 115, 105, 110,
  103, 44, 95, 115, 104, 97, 100, 105, 110, 103, 44, 95, 111, 112, 97, 99,
  105, 116, 121, 44, 95, 99, 111, 108, 111, 114, 44, 46, 46, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 114, 97, 119, 32, 100, 111, 116,
  115, 32, 112, 97, 116, 116, 101, 114, 110, 32, 111, 110, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 100, 101, 110, 115, 105, 116, 121, 61,
  50, 48, 39, 44, 32, 39, 111, 102, 102, 115, 101, 116, 49, 61, 111, 102,
  102, 115, 101, 116, 50, 61, 53, 48, 39, 44, 32, 39, 97, 110, 103, 108,
  101, 61, 48, 39, 44, 32, 39, 97, 108, 105, 97, 115, 105, 110, 103, 61,
  49, 48, 39, 44, 32, 39, 115, 104, 97, 100, 105, 110, 103, 61, 49, 39,
  44, 32, 39, 111, 112, 97, 99, 105, 116, 121, 61, 49, 39, 32, 97, 110,
  100, 32, 39, 99, 111, 108, 111, 114, 61, 50, 53, 53, 39, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 112, 111, 108, 107, 97, 95, 100, 111, 116, 115, 32,
  49, 48, 44, 49, 53, 44, 48, 44, 48, 44, 50, 48, 44, 49, 48, 44,
  49, 44, 48, 46, 53, 44, 48, 44, 49, 50, 56, 44, 50, 53, 53, 10,
  112, 111, 108, 107, 97, 95, 100, 111, 116, 115, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 36, 49, 62, 61, 48, 32, 45, 115, 107, 105, 112, 32,
  36, 123, 50, 61, 50, 48, 125, 44, 36, 123, 51, 61, 53, 48, 125, 44,
  36, 123, 52, 61, 53, 48, 125, 44, 36, 123, 53, 61, 48, 125, 44, 36,
  123, 54, 61, 49, 48, 125, 44, 36, 123, 55, 61, 49, 125, 44, 36, 123,
  56, 61, 49, 125, 44, 36, 123, 57, 61, 50, 53, 53, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 68, 114, 97, 119, 32, 112, 111, 108, 107,
  97, 32, 100, 111, 116, 115, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 119, 105, 116, 104, 32, 100, 105, 97, 109, 101, 116, 101, 114,
  32, 36, 49, 44, 32, 100, 101, 110, 115, 105, 116, 121, 32, 36, 50, 44,
  32, 97, 110, 103, 108, 101, 32, 36, 51, 32, 100, 101, 103, 46, 44, 32,
  115, 104, 105, 102, 116, 32, 40, 36, 52, 44, 36, 53, 41, 44, 32, 97,
  108, 105, 97, 115, 105, 110, 103, 32, 36, 54, 32, 97, 110, 100, 32, 115,
  104, 97, 100, 105, 110, 103, 32, 36, 55, 46, 34, 10, 45, 118, 32, 45,
  32, 116, 104, 101, 116, 97, 61, 123, 36, 53, 42, 112, 105, 47, 49, 56,
  48, 125, 32, 99, 116, 61, 123, 99, 111, 115, 40, 36, 116, 104, 101, 116,
  97, 41, 125, 32, 115, 116, 61, 123, 115, 105, 110, 40, 36, 116, 104, 101,
  116, 97, 41, 125, 32, 109, 105, 100, 49, 61, 123, 36, 49, 47, 50, 125,
  32, 109, 105, 100, 50, 61, 123, 36, 50, 47, 50, 125, 10, 45, 105, 91,
  48, 93, 32, 40, 36, 123, 57, 45, 45, 49, 125, 41, 32, 45, 121, 91,
  48, 93, 32, 99, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35,
  45, 49, 125, 10, 87, 72, 61, 123, 109, 97, 120, 40, 119, 44, 104, 41,
  125, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 49, 44, 34, 120, 110, 32, 61, 32, 49, 48, 48, 42, 120, 47, 34,
  36, 87, 72, 34, 45, 36, 51, 59, 32, 121, 110, 32, 61, 32, 49, 48,
  48, 42, 121, 47, 34, 36, 87, 72, 34, 45, 36, 52, 59, 32, 92, 10,
  120, 114, 32, 61, 32, 120, 110, 42, 34, 36, 99, 116, 34, 45, 121, 110,
  42, 34, 36, 115, 116, 34, 59, 32, 121, 114, 32, 61, 32, 120, 110, 42,
  34, 36, 115, 116, 34, 43, 121, 110, 42, 34, 36, 99, 116, 34, 59, 32,
  92, 10, 120, 99, 32, 61, 32, 120, 114, 37, 36, 50, 45, 34, 36, 109,
  105, 100, 50, 34, 59, 32, 121, 99, 32, 61, 32, 121, 114, 37, 36, 50,
  45, 34, 36, 109, 105, 100, 50, 34, 59, 32, 92, 10, 34, 36, 109, 105,
  100, 49, 34, 45, 115, 113, 114, 116, 40, 120, 99, 42, 120, 99, 43, 121,
  99, 42, 121, 99, 41, 34, 10, 45, 42, 91, 45, 49, 93, 32, 36, 54,
  32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 36, 55, 32, 45, 110, 91,
  45, 49, 93, 32, 48, 44, 36, 56, 32, 40, 36, 123, 57, 45, 45, 49,
  125, 41, 32, 45, 121, 91, 45, 49, 93, 32, 99, 32, 45, 114, 91, 45,
  49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 91, 45, 50,
  93, 10, 45, 106, 91, 45, 51, 93, 32, 91, 45, 49, 93, 44, 48, 44,
  48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 50, 93, 32, 45, 114, 109,
  91, 45, 50, 44, 45, 49, 93, 10, 45, 109, 118, 91, 45, 49, 93, 32,
  49, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 93, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 112, 111, 108, 121, 103,
  111, 110, 32, 58, 32, 78, 62, 61, 49, 44, 120, 49, 91, 37, 93, 44,
  121, 49, 91, 37, 93, 44, 46, 46, 44, 120, 78, 91, 37, 93, 44, 121,
  78, 91, 37, 93, 44, 95, 111, 112, 97, 99, 105, 116, 121, 44, 95, 112,
  97, 116, 116, 101, 114, 110, 44, 95, 99, 111, 108, 111, 114, 49, 44, 46,
  46, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 114, 97, 119, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  99, 111, 108, 111, 114, 101, 100, 32, 78, 45, 118, 101, 114, 116, 105, 99,
  101, 115, 32, 112, 111, 108, 121, 103, 111, 110, 32, 111, 110, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 39, 112, 97, 116, 116, 101, 114, 110,
  39, 32, 105, 115, 32, 97, 110, 32, 104, 101, 120, 97, 100, 101, 99, 105,
  109, 97, 108, 32, 110, 117, 109, 98, 101, 114, 32, 115, 116, 97, 114, 116,
  105, 110, 103, 32, 119, 105, 116, 104, 32, 39, 48, 120, 39, 32, 119, 104,
  105, 99, 104, 32, 99, 97, 110, 32, 98, 101, 32, 111, 109, 105, 116, 116,
  101, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 101, 118, 101, 110,
  32, 105, 102, 32, 97, 32, 99, 111, 108, 111, 114, 32, 105, 115, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 46, 32, 73, 102, 32, 97, 32, 112,
  97, 116, 116, 101, 114, 110, 32, 105, 115, 32, 115, 112, 101, 99, 105, 102,
  105, 101, 100, 44, 32, 116, 104, 101, 32, 112, 111, 108, 121, 103, 111, 110,
  32, 105, 115, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 100, 114, 97,
  119, 110, 32, 111, 117, 116, 108, 105, 110, 101, 100, 32, 105, 110, 115, 116,
  101, 97, 100, 32, 111, 102, 32, 102, 105, 108, 108, 101, 100, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32,
  118, 97, 108, 117, 101, 115, 58, 32, 39, 111, 112, 97, 99, 105, 116, 121,
  61, 49, 39, 44, 32, 39, 112, 97, 116, 116, 101, 114, 110, 61, 40, 117,
  110, 100, 101, 102, 105, 110, 101, 100, 41, 39, 32, 97, 110, 100, 32, 39,
  99, 111, 108, 111, 114, 49, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 112, 111, 108, 121, 103, 111, 110, 32, 52, 44, 50, 48, 37, 44, 50,
  48, 37, 44, 56, 48, 37, 44, 51, 48, 37, 44, 56, 48, 37, 44, 55,
  48, 37, 44, 50, 48, 37, 44, 56, 48, 37, 44, 48, 46, 51, 44, 48,
  44, 50, 53, 53, 44, 48, 32, 45, 112, 111, 108, 121, 103, 111, 110, 32,
  52, 44, 50, 48, 37, 44, 50, 48, 37, 44, 56, 48, 37, 44, 51, 48,
  37, 44, 56, 48, 37, 44, 55, 48, 37, 44, 50, 48, 37, 44, 56, 48,
  37, 44, 49, 44, 48, 120, 67, 67, 67, 67, 67, 67, 67, 67, 44, 50,
  53, 53, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 50, 44, 49, 54, 44, 49, 44, 49,
  44, 39, 63, 40, 105, 102, 40, 120, 44, 64, 123, 45, 49, 44, 104, 125,
  44, 64, 123, 45, 49, 44, 119, 125, 41, 41, 39, 32, 45, 112, 111, 108,
  121, 103, 111, 110, 91, 45, 50, 93, 32, 123, 104, 125, 44, 64, 45, 49,
  44, 48, 46, 54, 44, 50, 53, 53, 44, 48, 44, 50, 53, 53, 32, 45,
  114, 101, 109, 111, 118, 101, 91, 45, 49, 93, 10, 35, 64, 103, 109, 105,
  99, 32, 113, 117, 105, 118, 101, 114, 32, 58, 32, 91, 102, 117, 110, 99,
  116, 105, 111, 110, 95, 105, 109, 97, 103, 101, 93, 44, 95, 115, 97, 109,
  112, 108, 105, 110, 103, 62, 48, 44, 95, 102, 97, 99, 116, 111, 114, 44,
  95, 105, 115, 95, 97, 114, 114, 111, 119, 61, 123, 32, 48, 32, 124, 32,
  49, 32, 125, 44, 95, 111, 112, 97, 99, 105, 116, 121, 44, 95, 112, 97,
  116, 116, 101, 114, 110, 44, 95, 99, 111, 108, 111, 114, 49, 44, 46, 46,
  32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 114, 97, 119, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 50,
  100, 32, 118, 101, 99, 116, 111, 114, 47, 111, 114, 105, 101, 110, 116, 97,
  116, 105, 111, 110, 32, 102, 105, 101, 108, 100, 32, 111, 110, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 39, 112, 97, 116, 116, 101, 114, 110,
  39, 32, 105, 115, 32, 97, 110, 32, 104, 101, 120, 97, 100, 101, 99, 105,
  109, 97, 108, 32, 110, 117, 109, 98, 101, 114, 32, 115, 116, 97, 114, 116,
  105, 110, 103, 32, 119, 105, 116, 104, 32, 39, 48, 120, 39, 32, 119, 104,
  105, 99, 104, 32, 99, 97, 110, 32, 98, 101, 32, 111, 109, 105, 116, 116,
  101, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 101, 118, 101, 110,
  32, 105, 102, 32, 97, 32, 99, 111, 108, 111, 114, 32, 105, 115, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  115, 58, 32, 39, 115, 97, 109, 112, 108, 105, 110, 103, 61, 50, 53, 39,
  44, 32, 39, 102, 97, 99, 116, 111, 114, 61, 45, 50, 48, 39, 44, 32,
  39, 105, 115, 95, 97, 114, 114, 111, 119, 61, 49, 39, 44, 32, 39, 111,
  112, 97, 99, 105, 116, 121, 61, 49, 39, 44, 32, 39, 112, 97, 116, 116,
  101, 114, 110, 61, 40, 117, 110, 100, 101, 102, 105, 110, 101, 100, 41, 39,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 97, 110, 100, 32, 39, 99,
  111, 108, 111, 114, 49, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 49, 48, 48, 44, 49, 48, 48, 44, 49, 44, 50,
  44, 39, 105, 102, 40, 99, 61, 61, 48, 44, 120, 45, 119, 47, 50, 44,
  121, 45, 104, 47, 50, 41, 39, 32, 53, 48, 48, 44, 53, 48, 48, 44,
  49, 44, 51, 44, 50, 53, 53, 32, 45, 113, 117, 105, 118, 101, 114, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 44, 49, 48, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 45, 114, 101, 115, 105, 122, 101, 50, 100, 121, 32, 54, 48, 48,
  32, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 48, 93, 32, 45,
  103, 114, 97, 100, 105, 101, 110, 116, 91, 48, 93, 32, 45, 109, 117, 108,
  91, 49, 93, 32, 45, 49, 32, 45, 114, 101, 118, 101, 114, 115, 101, 91,
  48, 44, 49, 93, 32, 45, 97, 112, 112, 101, 110, 100, 91, 48, 44, 49,
  93, 32, 99, 32, 45, 98, 108, 117, 114, 91, 48, 93, 32, 56, 32, 45,
  111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 91, 48, 93, 32, 45,
  113, 117, 105, 118, 101, 114, 91, 49, 93, 32, 91, 48, 93, 44, 49, 48,
  44, 49, 48, 44, 49, 44, 48, 46, 56, 44, 50, 53, 53, 10, 35, 64,
  103, 109, 105, 99, 32, 114, 101, 99, 116, 97, 110, 103, 108, 101, 32, 58,
  32, 120, 48, 91, 37, 93, 44, 121, 48, 91, 37, 93, 44, 120, 49, 91,
  37, 93, 44, 121, 49, 91, 37, 93, 44, 95, 111, 112, 97, 99, 105, 116,
  121, 44, 95, 112, 97, 116, 116, 101, 114, 110, 44, 95, 99, 111, 108, 111,
  114, 49, 44, 46, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  114, 97, 119, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 99, 111,
  108, 111, 114, 101, 100, 32, 114, 101, 99, 116, 97, 110, 103, 108, 101, 32,
  111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 112, 97,
  116, 116, 101, 114, 110, 39, 32, 105, 115, 32, 97, 110, 32, 104, 101, 120,
  97, 100, 101, 99, 105, 109, 97, 108, 32, 110, 117, 109, 98, 101, 114, 32,
  115, 116, 97, 114, 116, 105, 110, 103, 32, 119, 105, 116, 104, 32, 39, 48,
  120, 39, 32, 119, 104, 105, 99, 104, 32, 99, 97, 110, 32, 98, 101, 32,
  111, 109, 105, 116, 116, 101, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 101, 118, 101, 110, 32, 105, 102, 32, 97, 32, 99, 111, 108, 111, 114,
  32, 105, 115, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 46, 32, 73,
  102, 32, 97, 32, 112, 97, 116, 116, 101, 114, 110, 32, 105, 115, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 44, 32, 116, 104, 101, 32, 114, 101,
  99, 116, 97, 110, 103, 108, 101, 32, 105, 115, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 100, 114, 97, 119, 110, 32, 111, 117, 116, 108, 105, 110,
  101, 100, 32, 105, 110, 115, 116, 101, 97, 100, 32, 111, 102, 32, 102, 105,
  108, 108, 101, 100, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39,
  111, 112, 97, 99, 105, 116, 121, 61, 49, 39, 44, 32, 39, 112, 97, 116,
  116, 101, 114, 110, 61, 40, 117, 110, 100, 101, 102, 105, 110, 101, 100, 41,
  39, 32, 97, 110, 100, 32, 39, 99, 111, 108, 111, 114, 49, 61, 48, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 114, 101, 112, 101, 97, 116, 32, 51,
  48, 32, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 32, 123, 63, 40,
  49, 48, 48, 41, 125, 37, 44, 123, 63, 40, 49, 48, 48, 41, 125, 37,
  44, 123, 63, 40, 49, 48, 48, 41, 125, 37, 44, 123, 63, 40, 49, 48,
  48, 41, 125, 37, 44, 48, 46, 51, 44, 64, 123, 45, 82, 71, 66, 125,
  32, 45, 100, 111, 110, 101, 10, 114, 101, 99, 116, 97, 110, 103, 108, 101,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 53, 61, 49, 125, 44,
  36, 123, 54, 61, 48, 125, 10, 45, 118, 32, 45, 32, 40, 123, 39, 34,
  36, 53, 34, 39, 125, 41, 32, 105, 115, 95, 112, 97, 116, 116, 101, 114,
  110, 61, 123, 64, 123, 45, 49, 44, 48, 45, 49, 125, 39, 61, 61, 39,
  123, 39, 48, 120, 39, 125, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 118, 32, 43, 10, 45, 105, 102, 32, 36, 105, 115, 95, 112, 97, 116,
  116, 101, 114, 110, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 68,
  114, 97, 119, 32, 111, 117, 116, 108, 105, 110, 101, 100, 32, 114, 101, 99,
  116, 97, 110, 103, 108, 101, 32, 102, 114, 111, 109, 32, 40, 36, 49, 44,
  36, 50, 41, 32, 116, 111, 32, 40, 36, 51, 44, 36, 52, 41, 32, 111,
  110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32,
  111, 112, 97, 99, 105, 116, 121, 32, 36, 53, 32, 97, 110, 100, 32, 99,
  111, 108, 111, 114, 32, 40, 36, 123, 55, 45, 45, 49, 125, 41, 46, 34,
  10, 45, 101, 108, 115, 101, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32,
  34, 68, 114, 97, 119, 32, 102, 105, 108, 108, 101, 100, 32, 114, 101, 99,
  116, 97, 110, 103, 108, 101, 32, 102, 114, 111, 109, 32, 40, 36, 49, 44,
  36, 50, 41, 32, 116, 111, 32, 40, 36, 51, 44, 36, 52, 41, 32, 111,
  110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32,
  111, 112, 97, 99, 105, 116, 121, 32, 36, 53, 32, 97, 110, 100, 32, 99,
  111, 108, 111, 114, 32, 40, 36, 123, 54, 45, 45, 49, 125, 41, 46, 34,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 32, 45, 112, 111,
  108, 121, 103, 111, 110, 32, 52, 44, 36, 49, 44, 36, 50, 44, 36, 51,
  44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 49, 44, 36, 52, 44,
  36, 123, 53, 45, 45, 49, 125, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 114, 111, 114, 115, 99, 104, 97, 99, 104, 32, 58, 32,
  39, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 91, 37, 93, 62, 61,
  48, 39, 44, 39, 109, 105, 114, 114, 111, 114, 105, 110, 103, 61, 123, 32,
  48, 61, 110, 111, 110, 101, 32, 124, 32, 49, 61, 120, 32, 124, 32, 50,
  61, 121, 32, 124, 32, 51, 61, 120, 121, 32, 125, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 82, 101, 110, 100, 101, 114, 32, 114, 111, 114, 115,
  99, 104, 97, 99, 104, 45, 108, 105, 107, 101, 32, 105, 110, 107, 98, 108,
  111, 116, 115, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58,
  32, 39, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 53, 37, 39,
  32, 97, 110, 100, 32, 39, 109, 105, 114, 114, 111, 114, 105, 110, 103, 61,
  49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 52,
  48, 48, 44, 52, 48, 48, 32, 45, 114, 111, 114, 115, 99, 104, 97, 99,
  104, 32, 51, 37, 10, 114, 111, 114, 115, 99, 104, 97, 99, 104, 32, 58,
  32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 53, 37, 125,
  62, 61, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 50,
  61, 49, 125, 41, 32, 38, 38, 32, 36, 50, 62, 61, 48, 32, 38, 38,
  32, 36, 50, 60, 61, 51, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 82, 101, 110, 100, 101, 114, 32, 114, 111, 114, 115, 99, 104, 97, 99,
  104, 45, 108, 105, 107, 101, 32, 105, 110, 107, 98, 108, 111, 116, 115, 32,
  111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104,
  32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 49, 32, 97,
  110, 100, 32, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 36, 50,
  44, 110, 111, 44, 120, 44, 121, 44, 120, 121, 125, 34, 45, 109, 105, 114,
  114, 111, 114, 105, 110, 103, 46, 34, 10, 45, 118, 32, 45, 10, 45, 105,
  102, 32, 123, 36, 50, 61, 61, 48, 125, 10, 45, 114, 97, 110, 100, 32,
  45, 49, 44, 49, 32, 45, 98, 32, 36, 49, 32, 45, 103, 101, 32, 48,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 61, 61, 49, 125, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 119, 61, 123, 119, 125, 10, 45, 99, 111, 108, 117, 109, 110, 115, 32,
  48, 44, 123, 119, 47, 50, 45, 49, 125, 32, 45, 114, 97, 110, 100, 32,
  45, 49, 44, 49, 32, 45, 98, 32, 36, 49, 32, 45, 103, 101, 32, 48,
  10, 45, 45, 109, 105, 114, 114, 111, 114, 32, 120, 32, 45, 105, 102, 32,
  123, 36, 119, 37, 50, 125, 32, 45, 99, 111, 108, 117, 109, 110, 115, 91,
  45, 49, 93, 32, 49, 44, 49, 48, 48, 37, 32, 45, 101, 110, 100, 105,
  102, 32, 45, 97, 32, 120, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 61, 61, 50, 125,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 104, 61, 123, 104, 125, 10, 45, 114, 111, 119, 115, 32, 48,
  44, 123, 104, 47, 50, 45, 49, 125, 32, 45, 114, 97, 110, 100, 32, 45,
  49, 44, 49, 32, 45, 98, 32, 36, 49, 32, 45, 103, 101, 32, 48, 10,
  45, 45, 109, 105, 114, 114, 111, 114, 32, 121, 32, 45, 105, 102, 32, 123,
  36, 104, 37, 50, 125, 32, 45, 114, 111, 119, 115, 91, 45, 49, 93, 32,
  49, 44, 49, 48, 48, 37, 32, 45, 101, 110, 100, 105, 102, 32, 45, 97,
  32, 121, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 50, 61, 61, 51, 125, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119,
  61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 10, 45, 122, 32, 48, 44,
  48, 44, 123, 119, 47, 50, 45, 49, 125, 44, 123, 104, 47, 50, 45, 49,
  125, 32, 45, 114, 97, 110, 100, 32, 45, 49, 44, 49, 32, 45, 98, 32,
  36, 49, 32, 45, 103, 101, 32, 48, 10, 45, 45, 109, 105, 114, 114, 111,
  114, 32, 120, 32, 45, 105, 102, 32, 123, 36, 119, 37, 50, 125, 32, 45,
  99, 111, 108, 117, 109, 110, 115, 91, 45, 49, 93, 32, 49, 44, 49, 48,
  48, 37, 32, 45, 101, 110, 100, 105, 102, 32, 45, 97, 32, 120, 10, 45,
  45, 109, 105, 114, 114, 111, 114, 32, 121, 32, 45, 105, 102, 32, 123, 36,
  104, 37, 50, 125, 32, 45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 49,
  44, 49, 48, 48, 37, 32, 45, 101, 110, 100, 105, 102, 32, 45, 97, 32,
  121, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 115, 105, 101, 114, 112, 105, 110, 115, 107, 105, 32, 58, 32, 114, 101,
  99, 117, 114, 115, 105, 111, 110, 95, 108, 101, 118, 101, 108, 62, 61, 48,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 114, 97, 119, 32, 83,
  105, 101, 114, 112, 105, 110, 115, 107, 105, 32, 116, 114, 105, 97, 110, 103,
  108, 101, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39,
  114, 101, 99, 117, 114, 115, 105, 111, 110, 95, 108, 101, 118, 101, 108, 61,
  55, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 115, 105, 101, 114, 112, 105,
  110, 115, 107, 105, 32, 55, 10, 115, 105, 101, 114, 112, 105, 110, 115, 107,
  105, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 123, 49, 61, 55,
  125, 62, 61, 48, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 53,
  48, 125, 44, 36, 123, 51, 61, 48, 125, 44, 36, 123, 52, 61, 48, 125,
  44, 36, 123, 53, 61, 49, 48, 48, 125, 44, 36, 123, 54, 61, 49, 48,
  48, 125, 44, 36, 123, 55, 61, 49, 48, 48, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 68, 114, 97, 119, 32, 83, 105, 101, 114, 112, 105,
  110, 115, 107, 105, 32, 116, 114, 105, 97, 110, 103, 108, 101, 32, 111, 102,
  32, 100, 101, 103, 114, 101, 101, 32, 36, 49, 32, 111, 110, 32, 105, 109,
  97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 95, 115,
  105, 101, 114, 112, 105, 110, 115, 107, 105, 32, 36, 123, 50, 45, 55, 125,
  44, 36, 49, 32, 32, 45, 118, 32, 43, 10, 95, 115, 105, 101, 114, 112,
  105, 110, 115, 107, 105, 32, 58, 10, 45, 105, 102, 32, 123, 36, 55, 60,
  61, 48, 125, 32, 45, 112, 111, 108, 121, 103, 111, 110, 32, 51, 44, 36,
  49, 37, 44, 36, 50, 37, 44, 36, 51, 37, 44, 36, 52, 37, 44, 36,
  53, 37, 44, 36, 54, 37, 44, 49, 44, 50, 53, 53, 32, 45, 114, 101,
  116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 115, 105,
  101, 114, 112, 105, 110, 115, 107, 105, 32, 36, 49, 44, 36, 50, 44, 123,
  40, 36, 49, 43, 36, 51, 41, 47, 50, 125, 44, 123, 40, 36, 50, 43,
  36, 52, 41, 47, 50, 125, 44, 123, 40, 36, 49, 43, 36, 53, 41, 47,
  50, 125, 44, 123, 40, 36, 50, 43, 36, 54, 41, 47, 50, 125, 44, 123,
  36, 55, 45, 49, 125, 10, 45, 95, 115, 105, 101, 114, 112, 105, 110, 115,
  107, 105, 32, 123, 40, 36, 49, 43, 36, 51, 41, 47, 50, 125, 44, 123,
  40, 36, 50, 43, 36, 52, 41, 47, 50, 125, 44, 36, 51, 44, 36, 52,
  44, 123, 40, 36, 51, 43, 36, 53, 41, 47, 50, 125, 44, 123, 40, 36,
  52, 43, 36, 54, 41, 47, 50, 125, 44, 123, 36, 55, 45, 49, 125, 10,
  45, 95, 115, 105, 101, 114, 112, 105, 110, 115, 107, 105, 32, 123, 40, 36,
  49, 43, 36, 53, 41, 47, 50, 125, 44, 123, 40, 36, 50, 43, 36, 54,
  41, 47, 50, 125, 44, 36, 53, 44, 36, 54, 44, 123, 40, 36, 51, 43,
  36, 53, 41, 47, 50, 125, 44, 123, 40, 36, 52, 43, 36, 54, 41, 47,
  50, 125, 44, 123, 36, 55, 45, 49, 125, 10, 35, 64, 103, 109, 105, 99,
  32, 115, 110, 111, 119, 102, 108, 97, 107, 101, 32, 58, 32, 95, 114, 101,
  99, 117, 114, 115, 105, 111, 110, 62, 61, 48, 44, 95, 120, 48, 44, 95,
  121, 48, 44, 95, 120, 49, 44, 95, 121, 49, 44, 95, 120, 50, 44, 95,
  121, 50, 44, 95, 111, 112, 97, 99, 105, 116, 121, 44, 95, 99, 111, 108,
  49, 44, 46, 46, 46, 95, 99, 111, 108, 78, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 114, 97, 119, 32, 97, 32, 75, 111, 99, 104, 32,
  115, 110, 111, 119, 102, 108, 97, 107, 101, 32, 111, 110, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 114, 101, 99, 117, 114, 115, 105, 111,
  110, 61, 52, 39, 44, 32, 39, 120, 48, 61, 50, 48, 39, 44, 32, 39,
  121, 48, 61, 55, 48, 39, 44, 32, 39, 120, 49, 61, 56, 48, 39, 44,
  32, 39, 121, 49, 61, 55, 48, 39, 44, 32, 39, 120, 50, 61, 53, 48,
  39, 44, 32, 39, 121, 50, 61, 49, 48, 39, 44, 32, 39, 111, 112, 97,
  99, 105, 116, 121, 61, 49, 39, 32, 97, 110, 100, 32, 39, 99, 111, 108,
  49, 61, 50, 53, 53, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 115, 110,
  111, 119, 102, 108, 97, 107, 101, 32, 52, 10, 115, 110, 111, 119, 102, 108,
  97, 107, 101, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 123, 49,
  61, 52, 125, 62, 61, 48, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50,
  61, 50, 48, 125, 44, 36, 123, 51, 61, 55, 48, 125, 44, 36, 123, 52,
  61, 56, 48, 125, 44, 36, 123, 53, 61, 55, 48, 125, 44, 36, 123, 54,
  61, 53, 48, 125, 44, 36, 123, 55, 61, 49, 48, 125, 44, 36, 123, 56,
  61, 49, 125, 44, 36, 123, 57, 61, 50, 53, 53, 125, 10, 45, 118, 32,
  45, 10, 45, 112, 111, 108, 121, 103, 111, 110, 32, 51, 44, 36, 50, 37,
  44, 36, 51, 37, 44, 36, 52, 37, 44, 36, 53, 37, 44, 36, 54, 37,
  44, 36, 55, 37, 44, 36, 123, 56, 45, 45, 49, 125, 10, 45, 95, 115,
  110, 111, 119, 102, 108, 97, 107, 101, 32, 36, 49, 44, 36, 50, 44, 36,
  51, 44, 36, 54, 44, 36, 55, 44, 36, 123, 56, 45, 45, 49, 125, 10,
  45, 95, 115, 110, 111, 119, 102, 108, 97, 107, 101, 32, 36, 49, 44, 36,
  54, 44, 36, 55, 44, 36, 52, 44, 36, 53, 44, 36, 123, 56, 45, 45,
  49, 125, 10, 45, 95, 115, 110, 111, 119, 102, 108, 97, 107, 101, 32, 36,
  49, 44, 36, 52, 44, 36, 53, 44, 36, 50, 44, 36, 51, 44, 36, 123,
  56, 45, 45, 49, 125, 10, 45, 118, 32, 43, 10, 95, 115, 110, 111, 119,
  102, 108, 97, 107, 101, 32, 58, 10, 120, 48, 61, 123, 36, 50, 43, 40,
  36, 52, 45, 36, 50, 41, 47, 51, 125, 32, 121, 48, 61, 123, 36, 51,
  43, 40, 36, 53, 45, 36, 51, 41, 47, 51, 125, 10, 120, 49, 61, 123,
  36, 50, 43, 50, 42, 40, 36, 52, 45, 36, 50, 41, 47, 51, 125, 32,
  121, 49, 61, 123, 36, 51, 43, 50, 42, 40, 36, 53, 45, 36, 51, 41,
  47, 51, 125, 10, 99, 61, 123, 99, 111, 115, 40, 45, 112, 105, 47, 51,
  41, 125, 32, 115, 61, 123, 115, 105, 110, 40, 45, 112, 105, 47, 51, 41,
  125, 10, 120, 50, 61, 123, 36, 120, 48, 43, 40, 36, 120, 49, 45, 36,
  120, 48, 41, 42, 36, 99, 45, 40, 36, 121, 49, 45, 36, 121, 48, 41,
  42, 36, 115, 125, 32, 121, 50, 61, 123, 36, 121, 48, 43, 40, 36, 120,
  49, 45, 36, 120, 48, 41, 42, 36, 115, 43, 40, 36, 121, 49, 45, 36,
  121, 48, 41, 42, 36, 99, 125, 10, 45, 112, 111, 108, 121, 103, 111, 110,
  32, 51, 44, 36, 120, 48, 37, 44, 36, 121, 48, 37, 44, 36, 120, 49,
  37, 44, 36, 121, 49, 37, 44, 36, 120, 50, 37, 44, 36, 121, 50, 37,
  44, 36, 123, 54, 45, 45, 49, 125, 10, 45, 105, 102, 32, 36, 49, 10,
  45, 95, 115, 110, 111, 119, 102, 108, 97, 107, 101, 32, 123, 36, 49, 45,
  49, 125, 44, 36, 50, 44, 36, 51, 44, 36, 120, 48, 44, 36, 121, 48,
  44, 36, 123, 54, 45, 45, 49, 125, 10, 45, 95, 115, 110, 111, 119, 102,
  108, 97, 107, 101, 32, 123, 36, 49, 45, 49, 125, 44, 36, 120, 48, 44,
  36, 121, 48, 44, 36, 120, 50, 44, 36, 121, 50, 44, 36, 123, 54, 45,
  45, 49, 125, 10, 45, 95, 115, 110, 111, 119, 102, 108, 97, 107, 101, 32,
  123, 36, 49, 45, 49, 125, 44, 36, 120, 50, 44, 36, 121, 50, 44, 36,
  120, 49, 44, 36, 121, 49, 44, 36, 123, 54, 45, 45, 49, 125, 10, 45,
  95, 115, 110, 111, 119, 102, 108, 97, 107, 101, 32, 123, 36, 49, 45, 49,
  125, 44, 36, 120, 49, 44, 36, 121, 49, 44, 36, 52, 44, 36, 53, 44,
  36, 123, 54, 45, 45, 49, 125, 10, 45, 101, 110, 100, 105, 102, 10, 35,
  64, 103, 109, 105, 99, 32, 115, 112, 105, 114, 97, 108, 98, 119, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 114, 97, 119, 32, 40, 115, 113,
  117, 97, 114, 101, 100, 41, 32, 115, 112, 105, 114, 97, 108, 32, 111, 110,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 49, 54, 44,
  49, 54, 32, 45, 115, 112, 105, 114, 97, 108, 98, 119, 10, 115, 112, 105,
  114, 97, 108, 98, 119, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 68, 114, 97, 119, 32, 40, 115, 113, 117, 97, 114, 101, 100, 41, 32,
  98, 108, 97, 99, 107, 32, 97, 110, 100, 32, 119, 104, 105, 116, 101, 32,
  115, 112, 105, 114, 97, 108, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36,
  63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 99, 104, 97, 110, 110, 101,
  108, 115, 32, 48, 10, 45, 102, 32, 34, 114, 61, 109, 105, 110, 40, 120,
  44, 121, 44, 119, 45, 49, 45, 120, 44, 104, 45, 49, 45, 121, 41, 59,
  32, 50, 42, 114, 42, 40, 119, 43, 104, 45, 50, 42, 114, 45, 49, 41,
  32, 43, 32, 105, 102, 40, 109, 105, 110, 40, 120, 44, 104, 45, 49, 45,
  121, 41, 62, 61, 109, 105, 110, 40, 119, 45, 49, 45, 120, 44, 121, 41,
  44, 120, 43, 121, 44, 50, 42, 40, 119, 43, 104, 45, 50, 45, 50, 42,
  114, 41, 45, 120, 45, 121, 41, 34, 10, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 115, 112, 108, 105, 110, 101, 32, 58, 32, 120, 48,
  91, 37, 93, 44, 121, 48, 91, 37, 93, 44, 117, 48, 91, 37, 93, 44,
  118, 48, 91, 37, 93, 44, 120, 49, 91, 37, 93, 44, 121, 49, 91, 37,
  93, 44, 117, 49, 91, 37, 93, 44, 118, 49, 91, 37, 93, 44, 95, 110,
  98, 95, 118, 101, 114, 116, 105, 99, 101, 115, 62, 61, 50, 44, 95, 111,
  112, 97, 99, 105, 116, 121, 44, 95, 99, 111, 108, 111, 114, 49, 44, 46,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 114, 97, 119, 32,
  115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 99, 111, 108, 111, 114, 101,
  100, 32, 115, 112, 108, 105, 110, 101, 32, 99, 117, 114, 118, 101, 32, 111,
  110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 32, 40, 99, 117, 98, 105, 99, 32, 104, 101, 114, 109, 105, 116, 101,
  32, 115, 112, 108, 105, 110, 101, 41, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  115, 58, 32, 39, 110, 98, 95, 118, 101, 114, 116, 105, 99, 101, 115, 61,
  50, 53, 54, 39, 44, 32, 39, 111, 112, 97, 99, 105, 116, 121, 61, 49,
  39, 32, 97, 110, 100, 32, 39, 99, 111, 108, 111, 114, 49, 61, 48, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 114, 101, 112, 101, 97, 116, 32, 51,
  48, 32, 45, 115, 112, 108, 105, 110, 101, 32, 123, 63, 40, 49, 48, 48,
  41, 125, 37, 44, 123, 63, 40, 49, 48, 48, 41, 125, 37, 44, 123, 63,
  40, 45, 54, 48, 48, 44, 54, 48, 48, 41, 125, 44, 123, 63, 40, 45,
  54, 48, 48, 44, 54, 48, 48, 41, 125, 44, 123, 63, 40, 49, 48, 48,
  41, 125, 37, 44, 123, 63, 40, 49, 48, 48, 41, 125, 37, 44, 123, 63,
  40, 45, 54, 48, 48, 44, 54, 48, 48, 41, 125, 44, 123, 63, 40, 45,
  54, 48, 48, 44, 54, 48, 48, 41, 125, 44, 50, 53, 54, 44, 48, 46,
  51, 44, 50, 53, 53, 32, 45, 100, 111, 110, 101, 10, 115, 112, 108, 105,
  110, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 57, 61, 50,
  53, 54, 125, 44, 36, 123, 49, 48, 61, 49, 125, 44, 36, 123, 49, 49,
  61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 114, 97,
  119, 32, 115, 112, 108, 105, 110, 101, 32, 102, 114, 111, 109, 32, 40, 36,
  49, 44, 36, 50, 41, 32, 91, 36, 51, 44, 36, 52, 93, 32, 116, 111,
  32, 40, 36, 53, 44, 36, 54, 41, 32, 91, 36, 55, 44, 36, 56, 93,
  32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116,
  104, 32, 36, 57, 32, 118, 101, 114, 116, 105, 99, 101, 115, 44, 32, 111,
  112, 97, 99, 105, 116, 121, 32, 36, 49, 48, 32, 97, 110, 100, 32, 99,
  111, 108, 111, 114, 32, 40, 36, 123, 49, 49, 45, 45, 49, 125, 41, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 120, 48, 61, 123, 105, 102, 40,
  64, 123, 34, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 32, 36,
  49, 34, 125, 44, 36, 49, 42, 40, 119, 45, 49, 41, 44, 36, 49, 41,
  125, 10, 121, 48, 61, 123, 105, 102, 40, 64, 123, 34, 45, 105, 115, 95,
  112, 101, 114, 99, 101, 110, 116, 32, 36, 50, 34, 125, 44, 36, 50, 42,
  40, 104, 45, 49, 41, 44, 36, 50, 41, 125, 10, 117, 48, 61, 123, 105,
  102, 40, 64, 123, 34, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116,
  32, 36, 51, 34, 125, 44, 36, 51, 42, 40, 119, 45, 49, 41, 44, 36,
  51, 41, 125, 10, 118, 48, 61, 123, 105, 102, 40, 64, 123, 34, 45, 105,
  115, 95, 112, 101, 114, 99, 101, 110, 116, 32, 36, 52, 34, 125, 44, 36,
  52, 42, 40, 104, 45, 49, 41, 44, 36, 52, 41, 125, 10, 120, 49, 61,
  123, 105, 102, 40, 64, 123, 34, 45, 105, 115, 95, 112, 101, 114, 99, 101,
  110, 116, 32, 36, 53, 34, 125, 44, 36, 53, 42, 40, 119, 45, 49, 41,
  44, 36, 53, 41, 125, 10, 121, 49, 61, 123, 105, 102, 40, 64, 123, 34,
  45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 32, 36, 54, 34, 125,
  44, 36, 54, 42, 40, 104, 45, 49, 41, 44, 36, 54, 41, 125, 10, 117,
  49, 61, 123, 105, 102, 40, 64, 123, 34, 45, 105, 115, 95, 112, 101, 114,
  99, 101, 110, 116, 32, 36, 55, 34, 125, 44, 36, 55, 42, 40, 119, 45,
  49, 41, 44, 36, 55, 41, 125, 10, 118, 49, 61, 123, 105, 102, 40, 64,
  123, 34, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 32, 36, 56,
  34, 125, 44, 36, 56, 42, 40, 104, 45, 49, 41, 44, 36, 56, 41, 125,
  10, 45, 115, 112, 108, 105, 110, 101, 51, 100, 32, 36, 120, 48, 44, 36,
  121, 48, 44, 48, 44, 36, 117, 48, 44, 36, 118, 48, 44, 48, 44, 36,
  120, 49, 44, 36, 121, 49, 44, 48, 44, 36, 117, 49, 44, 36, 118, 49,
  44, 48, 44, 36, 57, 10, 45, 115, 104, 91, 45, 49, 93, 32, 56, 44,
  123, 56, 43, 51, 42, 36, 57, 45, 49, 125, 44, 48, 44, 48, 32, 45,
  114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 99, 111, 108, 51, 100, 91, 49, 93, 32, 36, 123, 49, 49,
  45, 45, 49, 125, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 48,
  93, 32, 91, 49, 93, 44, 48, 44, 48, 44, 48, 44, 36, 49, 48, 44,
  49, 44, 48, 44, 48, 32, 45, 114, 109, 91, 49, 93, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 116, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32,
  39, 45, 116, 101, 120, 116, 39, 46, 32, 58, 32, 40, 43, 41, 10, 35,
  64, 103, 109, 105, 99, 32, 116, 101, 120, 116, 32, 58, 32, 116, 101, 120,
  116, 44, 95, 120, 91, 37, 93, 44, 95, 121, 91, 37, 93, 44, 95, 102,
  111, 110, 116, 95, 104, 101, 105, 103, 104, 116, 62, 61, 48, 44, 95, 111,
  112, 97, 99, 105, 116, 121, 44, 95, 99, 111, 108, 111, 114, 49, 44, 46,
  46, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 114, 97, 119, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  99, 111, 108, 111, 114, 101, 100, 32, 116, 101, 120, 116, 32, 115, 116, 114,
  105, 110, 103, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 116, 39, 41, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 69, 120, 97, 99, 116, 32, 112,
  114, 101, 45, 100, 101, 102, 105, 110, 101, 100, 32, 115, 105, 122, 101, 115,
  32, 97, 114, 101, 32, 39, 49, 51, 39, 44, 39, 50, 52, 39, 44, 39,
  51, 50, 39, 32, 97, 110, 100, 32, 39, 53, 55, 39, 46, 32, 65, 110,
  121, 32, 111, 116, 104, 101, 114, 32, 115, 105, 122, 101, 32, 105, 115, 32,
  105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 101, 100, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 83, 112, 101, 99, 105, 102, 121, 105, 110,
  103, 32, 97, 110, 32, 101, 109, 112, 116, 121, 32, 116, 97, 114, 103, 101,
  116, 32, 105, 109, 97, 103, 101, 32, 114, 101, 115, 105, 122, 101, 115, 32,
  105, 116, 32, 116, 111, 32, 110, 101, 119, 32, 100, 105, 109, 101, 110, 115,
  105, 111, 110, 115, 32, 115, 117, 99, 104, 32, 116, 104, 97, 116, 32, 116,
  104, 101, 32, 105, 109, 97, 103, 101, 32, 99, 111, 110, 116, 97, 105, 110,
  115, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 116, 104, 101, 32, 101,
  110, 116, 105, 114, 101, 32, 116, 101, 120, 116, 32, 115, 116, 114, 105, 110,
  103, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 111, 112, 97,
  99, 105, 116, 121, 61, 49, 39, 32, 97, 110, 100, 32, 39, 99, 111, 108,
  111, 114, 49, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114, 101,
  115, 105, 122, 101, 50, 100, 121, 32, 54, 48, 48, 32, 121, 61, 48, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 51, 48, 32, 45, 116, 101, 120, 116,
  32, 123, 50, 42, 36, 62, 125, 34, 32, 58, 32, 84, 104, 105, 115, 32,
  105, 115, 32, 97, 32, 110, 105, 99, 101, 32, 116, 101, 120, 116, 44, 32,
  105, 115, 110, 39, 116, 32, 105, 116, 32, 63, 34, 44, 49, 48, 44, 36,
  121, 44, 123, 50, 42, 36, 62, 125, 44, 48, 46, 57, 44, 50, 53, 53,
  32, 121, 61, 123, 36, 121, 43, 50, 42, 36, 62, 125, 32, 45, 100, 111,
  110, 101, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 48, 32,
  45, 116, 101, 120, 116, 32, 34, 71, 39, 77, 73, 67, 34, 44, 48, 44,
  48, 44, 50, 52, 44, 49, 44, 50, 53, 53, 10, 35, 64, 103, 109, 105,
  99, 32, 116, 101, 120, 116, 95, 111, 117, 116, 108, 105, 110, 101, 32, 58,
  32, 116, 101, 120, 116, 44, 95, 120, 91, 37, 93, 44, 95, 121, 91, 37,
  93, 44, 95, 102, 111, 110, 116, 95, 104, 101, 105, 103, 104, 116, 62, 48,
  44, 95, 111, 117, 116, 108, 105, 110, 101, 62, 61, 48, 44, 95, 111, 112,
  97, 99, 105, 116, 121, 44, 95, 99, 111, 108, 111, 114, 49, 44, 46, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 114, 97, 119, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 99, 111, 108, 111, 114, 101, 100,
  32, 97, 110, 100, 32, 111, 117, 116, 108, 105, 110, 101, 100, 32, 116, 101,
  120, 116, 32, 115, 116, 114, 105, 110, 103, 32, 111, 110, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 120, 61, 121, 61, 50, 39, 44, 32,
  39, 102, 111, 110, 116, 95, 104, 101, 105, 103, 104, 116, 61, 49, 51, 39,
  44, 32, 39, 111, 117, 116, 108, 105, 110, 101, 61, 50, 39, 44, 32, 39,
  111, 112, 97, 99, 105, 116, 121, 61, 49, 39, 32, 97, 110, 100, 32, 39,
  99, 111, 108, 111, 114, 49, 61, 50, 53, 53, 39, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 116, 101, 120, 116, 95, 111, 117, 116, 108, 105, 110, 101, 32,
  34, 72, 105, 32, 116, 104, 101, 114, 101, 33, 34, 44, 49, 48, 44, 49,
  48, 44, 53, 50, 44, 51, 10, 116, 101, 120, 116, 95, 111, 117, 116, 108,
  105, 110, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61,
  50, 125, 44, 36, 123, 51, 61, 50, 125, 44, 36, 123, 52, 61, 49, 51,
  125, 44, 36, 123, 53, 61, 50, 125, 44, 36, 123, 54, 61, 49, 125, 44,
  36, 123, 55, 61, 50, 53, 53, 125, 44, 36, 123, 56, 61, 36, 45, 49,
  125, 44, 36, 123, 57, 61, 36, 45, 49, 125, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 68, 114, 97, 119, 32, 111, 117, 116, 108, 105, 110, 101,
  100, 32, 116, 101, 120, 116, 32, 39, 36, 49, 39, 32, 97, 116, 32, 112,
  111, 115, 105, 116, 105, 111, 110, 32, 40, 36, 50, 44, 36, 51, 41, 32,
  111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104,
  32, 102, 111, 110, 116, 32, 104, 101, 105, 103, 104, 116, 32, 36, 52, 44,
  32, 111, 117, 116, 108, 105, 110, 101, 32, 36, 53, 44, 32, 111, 112, 97,
  99, 105, 116, 121, 32, 36, 54, 32, 97, 110, 100, 32, 99, 111, 108, 111,
  114, 32, 36, 123, 55, 45, 45, 49, 125, 46, 34, 10, 45, 118, 32, 45,
  10, 45, 105, 102, 32, 36, 53, 10, 48, 32, 45, 116, 91, 45, 49, 93,
  32, 34, 36, 49, 34, 44, 48, 44, 48, 44, 36, 52, 44, 49, 44, 49,
  32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 91, 45, 49, 93, 32,
  123, 49, 43, 36, 53, 125, 44, 48, 32, 45, 45, 100, 105, 108, 97, 116,
  101, 91, 45, 49, 93, 32, 123, 50, 42, 36, 53, 43, 49, 125, 10, 40,
  36, 123, 55, 45, 45, 49, 125, 41, 32, 45, 121, 91, 45, 49, 93, 32,
  99, 32, 45, 114, 91, 45, 49, 93, 32, 50, 44, 49, 44, 49, 44, 49,
  48, 48, 37, 44, 48, 44, 48, 44, 49, 32, 45, 109, 97, 112, 91, 45,
  51, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 50, 125, 32, 45,
  105, 102, 32, 64, 123, 36, 62, 44, 119, 125, 32, 45, 106, 91, 36, 62,
  93, 32, 91, 45, 50, 93, 44, 36, 50, 44, 36, 51, 44, 48, 44, 48,
  44, 36, 54, 44, 91, 45, 49, 93, 32, 45, 101, 108, 115, 101, 32, 45,
  114, 109, 91, 36, 62, 93, 32, 45, 105, 91, 36, 62, 93, 32, 91, 45,
  50, 93, 32, 45, 101, 110, 100, 105, 102, 32, 45, 100, 111, 110, 101, 32,
  45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 108, 115, 101,
  10, 45, 116, 32, 34, 36, 49, 34, 44, 36, 123, 50, 45, 52, 125, 44,
  36, 123, 54, 45, 45, 49, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 116, 114, 105, 97, 110,
  103, 108, 101, 95, 115, 104, 97, 100, 101, 32, 58, 32, 120, 48, 44, 121,
  48, 44, 120, 49, 44, 121, 48, 44, 120, 50, 44, 121, 50, 44, 82, 48,
  44, 71, 48, 44, 66, 48, 44, 46, 46, 46, 44, 82, 49, 44, 71, 49,
  44, 66, 49, 44, 46, 46, 46, 44, 82, 50, 44, 71, 50, 44, 66, 50,
  44, 46, 46, 46, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  114, 97, 119, 32, 116, 114, 105, 97, 110, 103, 108, 101, 32, 119, 105, 116,
  104, 32, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 101, 100, 32, 99,
  111, 108, 111, 114, 115, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  116, 114, 105, 97, 110, 103, 108, 101, 95, 115, 104, 97, 100, 101, 32, 50,
  48, 44, 50, 48, 44, 52, 48, 48, 44, 49, 48, 48, 44, 49, 50, 48,
  44, 50, 48, 48, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 50,
  53, 53, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 10, 116, 114, 105,
  97, 110, 103, 108, 101, 95, 115, 104, 97, 100, 101, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 68, 114, 97, 119, 32, 116, 114, 105, 97,
  110, 103, 108, 101, 32, 40, 36, 49, 44, 36, 50, 41, 45, 40, 36, 51,
  44, 36, 52, 41, 45, 40, 36, 53, 44, 36, 54, 41, 32, 119, 105, 116,
  104, 32, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 101, 100, 32, 99,
  111, 108, 111, 114, 115, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63,
  46, 34, 10, 45, 118, 32, 45, 10, 45, 108, 91, 93, 32, 40, 36, 49,
  44, 36, 50, 44, 49, 59, 36, 51, 44, 36, 52, 44, 49, 59, 36, 53,
  44, 36, 54, 44, 49, 41, 32, 40, 36, 123, 55, 45, 45, 49, 125, 41,
  32, 45, 114, 91, 45, 49, 93, 32, 123, 119, 47, 51, 125, 44, 51, 44,
  49, 44, 49, 44, 45, 49, 32, 45, 115, 91, 45, 49, 93, 32, 120, 32,
  45, 115, 111, 108, 118, 101, 91, 94, 48, 93, 32, 91, 48, 93, 32, 45,
  114, 109, 91, 48, 93, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108,
  10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 94, 45, 49, 93, 32, 51,
  44, 36, 123, 49, 45, 54, 125, 44, 49, 44, 45, 54, 53, 53, 51, 53,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 32,
  45, 108, 91, 36, 62, 44, 45, 49, 93, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 123, 48, 44, 115, 125, 10, 97, 61, 123, 105, 40, 48, 44,
  48, 44, 48, 44, 36, 62, 41, 125, 32, 98, 61, 123, 105, 40, 48, 44,
  49, 44, 48, 44, 36, 62, 41, 125, 32, 99, 61, 123, 105, 40, 48, 44,
  50, 44, 48, 44, 36, 62, 41, 125, 10, 45, 115, 104, 91, 48, 93, 32,
  36, 62, 44, 36, 62, 32, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102,
  40, 105, 61, 61, 45, 54, 53, 53, 51, 53, 44, 36, 97, 42, 120, 43,
  36, 98, 42, 121, 43, 36, 99, 44, 105, 41, 39, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 116, 114, 117, 99, 104, 101,
  116, 32, 58, 32, 95, 115, 99, 97, 108, 101, 62, 48, 44, 95, 114, 97,
  100, 105, 117, 115, 62, 61, 48, 44, 95, 112, 97, 116, 116, 101, 114, 110,
  95, 116, 121, 112, 101, 61, 123, 32, 48, 61, 115, 116, 114, 97, 105, 103,
  104, 116, 32, 124, 32, 49, 61, 99, 117, 114, 118, 101, 100, 32, 125, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 70, 105, 108, 108, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 119, 105,
  116, 104, 32, 114, 97, 110, 100, 111, 109, 32, 116, 114, 117, 99, 104, 101,
  116, 32, 112, 97, 116, 116, 101, 114, 110, 115, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108,
  117, 101, 115, 58, 32, 39, 115, 99, 97, 108, 101, 61, 51, 50, 39, 44,
  32, 39, 114, 97, 100, 105, 117, 115, 61, 53, 39, 32, 97, 110, 100, 32,
  39, 112, 97, 116, 116, 101, 114, 110, 95, 116, 121, 112, 101, 61, 49, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 52, 48, 48,
  44, 51, 48, 48, 32, 45, 116, 114, 117, 99, 104, 101, 116, 32, 44, 10,
  116, 114, 117, 99, 104, 101, 116, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 34, 105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 51, 50, 125, 41,
  32, 38, 38, 32, 36, 49, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61,
  51, 125, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51,
  61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 110,
  100, 101, 114, 32, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 33,
  36, 51, 44, 99, 117, 114, 118, 101, 100, 44, 115, 116, 114, 97, 105, 103,
  104, 116, 125, 34, 32, 116, 114, 117, 99, 104, 101, 116, 32, 112, 97, 116,
  116, 101, 114, 110, 115, 32, 105, 110, 32, 105, 109, 97, 103, 101, 36, 63,
  44, 32, 119, 105, 116, 104, 32, 115, 99, 97, 108, 101, 32, 36, 49, 32,
  97, 110, 100, 32, 114, 97, 100, 105, 117, 115, 32, 36, 50, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125,
  10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 32, 115, 61, 123,
  115, 125, 32, 45, 114, 109, 10, 36, 49, 44, 36, 49, 32, 45, 61, 32,
  49, 44, 48, 44, 48, 32, 45, 61, 32, 49, 44, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101, 32, 49,
  44, 123, 49, 43, 36, 51, 125, 32, 77, 61, 123, 105, 110, 116, 40, 105,
  77, 47, 50, 41, 125, 10, 45, 116, 50, 32, 123, 36, 77, 45, 36, 50,
  47, 50, 45, 40, 36, 49, 37, 50, 41, 125, 44, 123, 36, 77, 43, 36,
  50, 47, 50, 125, 32, 45, 45, 109, 105, 114, 114, 111, 114, 32, 121, 32,
  45, 97, 32, 120, 10, 123, 114, 111, 117, 110, 100, 40, 36, 119, 47, 36,
  49, 44, 49, 44, 49, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 36,
  104, 47, 36, 49, 44, 49, 44, 49, 41, 125, 32, 45, 114, 97, 110, 100,
  91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 103, 101, 91, 45, 49, 93,
  32, 53, 48, 37, 32, 45, 114, 91, 45, 49, 93, 32, 123, 119, 42, 36,
  49, 125, 44, 123, 104, 42, 36, 49, 125, 32, 45, 42, 91, 45, 49, 93,
  32, 36, 49, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49,
  93, 32, 48, 44, 49, 32, 40, 48, 44, 123, 36, 49, 45, 49, 125, 41,
  32, 45, 114, 91, 45, 49, 93, 32, 36, 49, 44, 36, 49, 44, 49, 44,
  49, 44, 51, 32, 45, 45, 116, 114, 97, 110, 115, 112, 111, 115, 101, 91,
  45, 49, 93, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32,
  45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 50, 32,
  45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 119, 97, 114, 112, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 103, 101, 32, 53, 48, 37, 32, 45, 114, 32, 36, 119, 44, 36,
  104, 44, 49, 44, 49, 44, 48, 32, 45, 114, 32, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 44, 49, 44, 36, 115, 10, 45, 110, 109, 32, 36, 110,
  109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 116, 117, 114, 98,
  117, 108, 101, 110, 99, 101, 32, 58, 32, 95, 114, 97, 100, 105, 117, 115,
  62, 48, 44, 95, 111, 99, 116, 97, 118, 101, 115, 61, 123, 49, 44, 50,
  44, 51, 46, 46, 46, 44, 49, 50, 125, 44, 95, 97, 108, 112, 104, 97,
  62, 48, 44, 95, 100, 105, 102, 102, 101, 114, 101, 110, 99, 101, 61, 123,
  45, 49, 48, 44, 49, 48, 125, 44, 95, 109, 111, 100, 101, 61, 123, 48,
  44, 49, 44, 50, 44, 51, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 82, 101, 110, 100, 101, 114, 32, 102, 114, 97, 99, 116, 97, 108, 32,
  110, 111, 105, 115, 101, 32, 111, 114, 32, 116, 117, 114, 98, 117, 108, 101,
  110, 99, 101, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58,
  32, 39, 114, 97, 100, 105, 117, 115, 61, 51, 50, 39, 44, 32, 39, 111,
  99, 116, 97, 118, 101, 115, 61, 54, 39, 44, 32, 39, 97, 108, 112, 104,
  97, 61, 51, 39, 44, 32, 39, 100, 105, 102, 102, 101, 114, 101, 110, 99,
  101, 61, 48, 39, 32, 97, 110, 100, 32, 39, 109, 111, 100, 101, 61, 48,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 52, 48,
  48, 44, 52, 48, 48, 44, 49, 44, 51, 32, 45, 116, 117, 114, 98, 117,
  108, 101, 110, 99, 101, 32, 49, 54, 10, 116, 117, 114, 98, 117, 108, 101,
  110, 99, 101, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123,
  49, 61, 51, 50, 125, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 54,
  125, 62, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 51,
  125, 44, 36, 123, 52, 61, 48, 125, 44, 36, 123, 53, 61, 48, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 110, 100, 101, 114, 32,
  102, 114, 97, 99, 116, 97, 108, 32, 110, 111, 105, 115, 101, 32, 111, 114,
  32, 116, 117, 114, 98, 117, 108, 101, 110, 99, 101, 32, 111, 110, 32, 105,
  109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 114, 97, 100,
  105, 117, 115, 32, 36, 49, 44, 32, 111, 99, 116, 97, 118, 101, 115, 32,
  36, 50, 44, 32, 100, 97, 109, 112, 105, 110, 103, 32, 112, 101, 114, 32,
  111, 99, 116, 97, 118, 101, 32, 36, 51, 44, 32, 100, 105, 102, 102, 101,
  114, 101, 110, 99, 101, 32, 36, 52, 32, 97, 110, 100, 32, 109, 111, 100,
  101, 32, 36, 53, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109,
  61, 64, 123, 48, 44, 110, 125, 10, 45, 105, 102, 32, 123, 36, 52, 125,
  32, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 102, 91,
  45, 49, 93, 32, 48, 32, 45, 45, 110, 111, 105, 115, 101, 91, 45, 49,
  93, 32, 49, 48, 44, 48, 32, 45, 98, 91, 45, 49, 93, 32, 36, 49,
  44, 48, 10, 45, 105, 102, 32, 123, 36, 53, 61, 61, 48, 124, 124, 36,
  53, 61, 61, 49, 125, 32, 45, 45, 91, 45, 49, 93, 32, 64, 123, 45,
  49, 44, 97, 125, 32, 45, 97, 98, 115, 91, 45, 49, 93, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 53, 61, 61, 51, 124, 124, 36, 53, 61, 61,
  52, 125, 32, 45, 94, 91, 45, 49, 93, 32, 50, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 53, 61, 61, 53, 125, 32, 45, 94, 91, 45, 49, 93,
  32, 51, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 36, 50, 45, 49, 125, 10, 45, 45, 110, 111, 105, 115, 101,
  91, 45, 50, 93, 32, 49, 48, 44, 48, 32, 45, 98, 91, 45, 49, 93,
  32, 123, 36, 49, 47, 50, 94, 36, 62, 125, 44, 48, 10, 45, 105, 102,
  32, 123, 36, 53, 61, 61, 48, 125, 32, 45, 45, 91, 45, 49, 93, 32,
  64, 123, 45, 49, 44, 97, 125, 32, 45, 97, 98, 115, 91, 45, 49, 93,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 53, 61, 61, 52, 125, 32, 45,
  94, 91, 45, 49, 93, 32, 50, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  53, 61, 61, 53, 125, 32, 45, 94, 91, 45, 49, 93, 32, 51, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 42, 91, 45, 50, 93, 32, 36, 51, 32,
  45, 43, 91, 45, 50, 45, 45, 49, 93, 10, 45, 100, 111, 110, 101, 10,
  45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 114, 109,
  91, 45, 50, 93, 10, 45, 105, 102, 32, 123, 36, 52, 125, 32, 45, 42,
  91, 45, 49, 93, 32, 36, 52, 32, 45, 109, 118, 91, 45, 50, 93, 32,
  50, 32, 45, 45, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 110, 109, 32, 36, 110, 109,
  44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 121, 105, 110, 121, 97,
  110, 103, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 114, 97, 119,
  32, 97, 32, 121, 105, 110, 45, 121, 97, 110, 103, 32, 115, 121, 109, 98,
  111, 108, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 52, 48, 48, 44, 52, 48, 48, 32, 45, 121, 105, 110, 121, 97,
  110, 103, 10, 121, 105, 110, 121, 97, 110, 103, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 68, 114, 97, 119, 32, 121, 105, 110, 45, 121,
  97, 110, 103, 32, 115, 121, 109, 98, 111, 108, 32, 111, 110, 32, 105, 109,
  97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 102, 32,
  48, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 115, 61, 123, 115, 125, 32, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 48, 10, 114, 61, 123, 114, 111, 117, 110, 100, 40, 48,
  46, 57, 53, 42, 109, 105, 110, 40, 119, 44, 104, 41, 47, 52, 41, 125,
  10, 45, 45, 108, 105, 110, 101, 32, 53, 48, 37, 44, 48, 44, 53, 48,
  37, 44, 53, 48, 37, 44, 49, 44, 50, 32, 45, 101, 108, 108, 105, 112,
  115, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 123, 104, 47, 50, 45,
  36, 114, 125, 44, 36, 114, 44, 36, 114, 44, 48, 44, 49, 44, 50, 10,
  45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48,
  37, 44, 53, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 32, 45,
  101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44,
  123, 104, 47, 50, 43, 36, 114, 125, 44, 36, 114, 44, 36, 114, 44, 48,
  44, 49, 44, 49, 10, 45, 102, 108, 111, 111, 100, 91, 45, 49, 93, 32,
  123, 119, 47, 50, 45, 36, 114, 125, 44, 53, 48, 37, 44, 48, 44, 48,
  44, 48, 44, 49, 44, 50, 10, 45, 102, 108, 111, 111, 100, 91, 45, 49,
  93, 32, 123, 119, 47, 50, 43, 36, 114, 125, 44, 53, 48, 37, 44, 48,
  44, 48, 44, 48, 44, 49, 44, 49, 10, 45, 101, 108, 108, 105, 112, 115,
  101, 91, 45, 50, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 123, 50,
  42, 36, 114, 125, 44, 123, 50, 42, 36, 114, 125, 44, 48, 44, 49, 44,
  49, 10, 45, 42, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49,
  93, 32, 53, 48, 37, 44, 123, 104, 47, 50, 45, 36, 114, 125, 44, 123,
  36, 114, 47, 51, 125, 44, 123, 36, 114, 47, 51, 125, 44, 48, 44, 49,
  44, 49, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32,
  53, 48, 37, 44, 123, 104, 47, 50, 43, 36, 114, 125, 44, 123, 36, 114,
  47, 51, 125, 44, 123, 36, 114, 47, 51, 125, 44, 48, 44, 49, 44, 50,
  10, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44,
  36, 115, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 58, 58, 32, 77, 97,
  116, 114, 105, 120, 32, 99, 111, 109, 112, 117, 116, 97, 116, 105, 111, 110,
  10, 35, 64, 103, 109, 105, 99, 32, 100, 105, 106, 107, 115, 116, 114, 97,
  32, 58, 32, 115, 116, 97, 114, 116, 105, 110, 103, 95, 110, 111, 100, 101,
  62, 61, 48, 44, 101, 110, 100, 105, 110, 103, 95, 110, 111, 100, 101, 62,
  61, 48, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 109, 105, 110, 105, 109, 97,
  108, 32, 100, 105, 115, 116, 97, 110, 99, 101, 115, 32, 97, 110, 100, 32,
  112, 97, 116, 104, 101, 115, 32, 102, 114, 111, 109, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 97, 100, 106, 97, 99, 101, 110, 99, 121, 32,
  109, 97, 116, 114, 105, 99, 101, 115, 32, 98, 121, 32, 116, 104, 101, 32,
  68, 105, 106, 107, 115, 116, 114, 97, 32, 97, 108, 103, 111, 114, 105, 116,
  104, 109, 46, 10, 35, 64, 103, 109, 105, 99, 32, 101, 105, 103, 101, 110,
  32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 101, 105, 103, 101,
  110, 118, 97, 108, 117, 101, 115, 32, 97, 110, 100, 32, 101, 105, 103, 101,
  110, 118, 101, 99, 116, 111, 114, 115, 32, 111, 102, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 115, 121, 109, 109, 101, 116, 114, 105, 99, 32, 109,
  97, 116, 114, 105, 99, 101, 115, 32, 111, 114, 32, 109, 97, 116, 114, 105,
  120, 32, 102, 105, 101, 108, 100, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 73, 102, 32, 111, 110, 101, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 32, 104, 97, 115, 32, 51, 32, 111,
  114, 32, 54, 32, 99, 104, 97, 110, 110, 101, 108, 115, 44, 32, 105, 116,
  32, 105, 115, 32, 114, 101, 103, 97, 114, 100, 101, 100, 32, 97, 115, 32,
  97, 32, 102, 105, 101, 108, 100, 32, 111, 102, 32, 50, 120, 50, 32, 111,
  114, 32, 51, 120, 51, 32, 115, 121, 109, 109, 101, 116, 114, 105, 99, 32,
  109, 97, 116, 114, 105, 99, 101, 115, 44, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 119, 104, 111, 115, 101, 32, 101, 105, 103, 101, 110, 32, 101,
  108, 101, 109, 101, 110, 116, 115, 32, 97, 114, 101, 32, 99, 111, 109, 112,
  117, 116, 101, 100, 32, 97, 116, 32, 101, 97, 99, 104, 32, 112, 111, 105,
  110, 116, 32, 111, 102, 32, 116, 104, 101, 32, 102, 105, 101, 108, 100, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 40, 49, 44, 48,
  44, 48, 59, 48, 44, 50, 44, 48, 59, 48, 44, 48, 44, 51, 41, 32,
  45, 45, 101, 105, 103, 101, 110, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 115, 116,
  114, 117, 99, 116, 117, 114, 101, 116, 101, 110, 115, 111, 114, 115, 32, 45,
  98, 108, 117, 114, 32, 50, 32, 45, 101, 105, 103, 101, 110, 32, 45, 115,
  112, 108, 105, 116, 91, 48, 93, 32, 99, 10, 35, 64, 103, 109, 105, 99,
  32, 105, 110, 118, 101, 114, 116, 32, 58, 32, 40, 43, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 116,
  104, 101, 32, 105, 110, 118, 101, 114, 115, 101, 32, 111, 102, 32, 116, 104,
  101, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 109, 97, 116, 114, 105,
  99, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  40, 48, 44, 49, 44, 48, 59, 48, 44, 48, 44, 49, 59, 49, 44, 48,
  44, 48, 41, 32, 45, 45, 105, 110, 118, 101, 114, 116, 10, 35, 64, 103,
  109, 105, 99, 32, 115, 111, 108, 118, 101, 32, 58, 32, 91, 105, 109, 97,
  103, 101, 93, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 83, 111, 108, 118, 101, 32, 108, 105, 110, 101, 97, 114, 32,
  115, 121, 115, 116, 101, 109, 32, 65, 88, 32, 61, 32, 66, 32, 102, 111,
  114, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 66, 45, 118, 101, 99,
  116, 111, 114, 115, 32, 97, 110, 100, 32, 115, 112, 101, 99, 105, 102, 105,
  101, 100, 32, 65, 45, 109, 97, 116, 114, 105, 120, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 73, 102, 32, 116, 104, 101, 32, 115, 121, 115,
  116, 101, 109, 32, 105, 115, 32, 117, 110, 100, 101, 114, 45, 32, 111, 114,
  32, 111, 118, 101, 114, 45, 100, 101, 116, 101, 114, 109, 105, 110, 101, 100,
  44, 32, 108, 101, 97, 115, 116, 32, 115, 113, 117, 97, 114, 101, 32, 115,
  111, 108, 117, 116, 105, 111, 110, 32, 105, 115, 32, 114, 101, 116, 117, 114,
  110, 101, 100, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  40, 48, 44, 49, 44, 48, 59, 49, 44, 48, 44, 48, 59, 48, 44, 48,
  44, 49, 41, 32, 40, 49, 59, 50, 59, 51, 41, 32, 45, 45, 115, 111,
  108, 118, 101, 91, 45, 49, 93, 32, 91, 45, 50, 93, 10, 35, 64, 103,
  109, 105, 99, 32, 115, 118, 100, 32, 58, 32, 40, 43, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 112, 117, 116, 101, 32, 83,
  86, 68, 32, 100, 101, 99, 111, 109, 112, 111, 115, 105, 116, 105, 111, 110,
  32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 109, 97, 116,
  114, 105, 99, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 49, 48, 44, 49, 48, 44, 49, 44, 49, 44, 39, 105, 102, 40,
  120, 61, 61, 121, 44, 120, 43, 63, 40, 45, 48, 46, 50, 44, 48, 46,
  50, 41, 44, 48, 41, 39, 32, 45, 45, 115, 118, 100, 10, 35, 64, 103,
  109, 105, 99, 32, 116, 114, 97, 110, 115, 112, 111, 115, 101, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 84, 114, 97, 110, 115, 112, 111, 115, 101,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 109, 97, 116, 114, 105, 99,
  101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 116, 114, 97, 110, 115,
  112, 111, 115, 101, 10, 116, 114, 97, 110, 115, 112, 111, 115, 101, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 84, 114, 97, 110, 115, 112,
  111, 115, 101, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 112, 101, 114, 109, 117, 116, 101, 32, 121, 120, 122, 99,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 116, 114, 105,
  115, 111, 108, 118, 101, 32, 58, 32, 91, 105, 109, 97, 103, 101, 93, 32,
  58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83,
  111, 108, 118, 101, 32, 116, 114, 105, 100, 105, 97, 103, 111, 110, 97, 108,
  32, 115, 121, 115, 116, 101, 109, 32, 65, 88, 32, 61, 32, 66, 32, 102,
  111, 114, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 66, 45, 118, 101,
  99, 116, 111, 114, 115, 32, 97, 110, 100, 32, 115, 112, 101, 99, 105, 102,
  105, 101, 100, 32, 116, 114, 105, 100, 105, 97, 103, 111, 110, 97, 108, 32,
  65, 45, 109, 97, 116, 114, 105, 120, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 84, 114, 105, 100, 105, 97, 103, 111, 110, 97, 108, 32, 109,
  97, 116, 114, 105, 120, 32, 109, 117, 115, 116, 32, 98, 101, 32, 115, 116,
  111, 114, 101, 100, 32, 97, 115, 32, 97, 32, 51, 32, 99, 111, 108, 117,
  109, 110, 32, 118, 101, 99, 116, 111, 114, 44, 32, 119, 104, 101, 114, 101,
  32, 50, 110, 100, 32, 99, 111, 108, 117, 109, 110, 32, 99, 111, 110, 116,
  97, 105, 110, 115, 32, 116, 104, 101, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 100, 105, 97, 103, 111, 110, 97, 108, 32, 99, 111, 101, 102, 102,
  105, 99, 105, 101, 110, 116, 115, 44, 32, 119, 104, 105, 108, 101, 32, 49,
  115, 116, 32, 97, 110, 100, 32, 51, 114, 100, 32, 99, 111, 108, 117, 109,
  110, 115, 32, 99, 111, 110, 116, 97, 105, 110, 32, 116, 104, 101, 32, 108,
  101, 102, 116, 32, 97, 110, 100, 32, 114, 105, 103, 104, 116, 32, 99, 111,
  101, 102, 102, 105, 99, 105, 101, 110, 116, 115, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 40, 48, 44, 48, 44, 49, 59, 49, 44,
  48, 44, 48, 59, 48, 44, 49, 44, 48, 41, 32, 40, 49, 59, 50, 59,
  51, 41, 32, 45, 45, 116, 114, 105, 115, 111, 108, 118, 101, 91, 45, 49,
  93, 32, 91, 45, 50, 93, 10, 35, 64, 103, 109, 105, 99, 32, 58, 58,
  32, 51, 100, 32, 114, 101, 110, 100, 101, 114, 105, 110, 103, 10, 35, 64,
  103, 109, 105, 99, 32, 43, 51, 100, 32, 58, 32, 101, 113, 46, 32, 116,
  111, 32, 39, 45, 97, 100, 100, 51, 100, 39, 46, 32, 58, 32, 40, 43,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 97, 100, 100, 51, 100, 32, 58,
  32, 116, 120, 44, 95, 116, 121, 44, 95, 116, 122, 32, 58, 32, 91, 111,
  98, 106, 101, 99, 116, 51, 100, 93, 32, 58, 32, 40, 110, 111, 97, 114,
  103, 115, 41, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 83, 104, 105, 102, 116, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 115, 32, 119, 105, 116,
  104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 100, 105, 115, 112,
  108, 97, 99, 101, 109, 101, 110, 116, 32, 118, 101, 99, 116, 111, 114, 44,
  32, 111, 114, 32, 109, 101, 114, 103, 101, 32, 116, 104, 101, 109, 32, 119,
  105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116,
  44, 32, 111, 114, 32, 109, 101, 114, 103, 101, 32, 97, 108, 108, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 51, 100, 32, 111, 98, 106, 101, 99,
  116, 115, 32, 116, 111, 103, 101, 116, 104, 101, 114, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45,
  43, 51, 100, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 116, 121, 61, 116, 122, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 45, 115, 112, 104, 101, 114, 101, 51, 100, 32,
  49, 48, 32, 45, 114, 101, 112, 101, 97, 116, 32, 53, 32, 45, 45, 97,
  100, 100, 51, 100, 91, 45, 49, 93, 32, 49, 48, 44, 123, 63, 40, 45,
  49, 48, 44, 49, 48, 41, 125, 44, 48, 32, 45, 99, 111, 108, 111, 114,
  51, 100, 91, 45, 49, 93, 32, 64, 123, 45, 82, 71, 66, 125, 32, 45,
  100, 111, 110, 101, 32, 45, 97, 100, 100, 51, 100, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 45, 114, 101, 112, 101, 97, 116, 32, 50,
  48, 32, 45, 116, 111, 114, 117, 115, 51, 100, 32, 49, 53, 44, 50, 32,
  45, 99, 111, 108, 111, 114, 51, 100, 91, 45, 49, 93, 32, 64, 123, 45,
  82, 71, 66, 125, 32, 45, 109, 117, 108, 51, 100, 91, 45, 49, 93, 32,
  48, 46, 53, 44, 49, 32, 45, 105, 102, 32, 123, 36, 62, 37, 50, 125,
  32, 45, 114, 111, 116, 97, 116, 101, 51, 100, 91, 45, 49, 93, 32, 48,
  44, 49, 44, 48, 44, 57, 48, 32, 45, 101, 110, 100, 105, 102, 32, 45,
  97, 100, 100, 51, 100, 91, 45, 49, 93, 32, 55, 48, 32, 45, 97, 100,
  100, 51, 100, 32, 45, 114, 111, 116, 97, 116, 101, 51, 100, 91, 45, 49,
  93, 32, 48, 44, 48, 44, 49, 44, 49, 56, 32, 45, 100, 111, 110, 101,
  32, 45, 100, 111, 117, 98, 108, 101, 51, 100, 32, 48, 10, 35, 64, 103,
  109, 105, 99, 32, 97, 110, 105, 109, 97, 116, 101, 51, 100, 32, 58, 32,
  95, 119, 105, 100, 116, 104, 62, 48, 44, 95, 104, 101, 105, 103, 104, 116,
  62, 48, 44, 95, 100, 120, 44, 95, 100, 121, 44, 95, 100, 122, 44, 95,
  122, 111, 111, 109, 62, 61, 48, 44, 95, 102, 105, 108, 101, 110, 97, 109,
  101, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 110, 105, 109, 97,
  116, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 51, 100, 32, 111,
  98, 106, 101, 99, 116, 115, 32, 105, 110, 32, 97, 32, 119, 105, 110, 100,
  111, 119, 46, 10, 97, 110, 105, 109, 97, 116, 101, 51, 100, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 54, 52, 48, 125, 44, 36,
  123, 50, 61, 52, 56, 48, 125, 44, 36, 123, 51, 61, 48, 125, 44, 36,
  123, 52, 61, 49, 48, 125, 44, 36, 123, 53, 61, 48, 125, 44, 34, 36,
  123, 55, 61, 34, 34, 125, 34, 32, 45, 99, 104, 101, 99, 107, 32, 36,
  123, 54, 61, 49, 125, 62, 61, 48, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 65, 110, 105, 109, 97, 116, 101, 32, 51, 100, 32, 111, 98, 106,
  101, 99, 116, 36, 63, 44, 32, 105, 110, 32, 97, 32, 36, 49, 120, 36,
  50, 32, 119, 105, 110, 100, 111, 119, 32, 119, 105, 116, 104, 32, 97, 110,
  103, 108, 101, 32, 118, 101, 108, 111, 99, 105, 116, 105, 101, 115, 32, 40,
  36, 51, 44, 36, 52, 44, 36, 53, 41, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 45, 108, 91,
  36, 62, 93, 10, 45, 110, 51, 100, 32, 45, 42, 51, 100, 32, 123, 36,
  54, 42, 109, 105, 110, 40, 36, 49, 44, 36, 50, 41, 47, 49, 46, 53,
  125, 32, 45, 99, 51, 100, 10, 97, 120, 61, 48, 32, 97, 121, 61, 48,
  32, 97, 122, 61, 48, 32, 102, 114, 97, 109, 101, 61, 48, 10, 45, 100,
  111, 10, 45, 45, 114, 51, 100, 32, 49, 44, 48, 44, 48, 44, 36, 97,
  120, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 49, 44, 48,
  44, 36, 97, 121, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44,
  48, 44, 49, 44, 36, 97, 122, 10, 97, 120, 61, 123, 36, 97, 120, 43,
  36, 51, 125, 32, 97, 121, 61, 123, 36, 97, 121, 43, 36, 52, 125, 32,
  97, 122, 61, 123, 36, 97, 122, 43, 36, 53, 125, 10, 36, 49, 44, 36,
  50, 44, 49, 44, 51, 44, 45, 49, 32, 45, 111, 98, 106, 101, 99, 116,
  51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 53, 48, 37, 44,
  53, 48, 37, 44, 48, 44, 49, 10, 45, 105, 102, 32, 123, 110, 97, 114,
  103, 40, 34, 36, 55, 34, 41, 125, 10, 45, 116, 111, 95, 114, 103, 98,
  97, 91, 45, 49, 93, 32, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99,
  111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 45, 49, 44,
  45, 49, 44, 45, 49, 44, 50, 53, 53, 44, 54, 52, 44, 54, 52, 44,
  54, 52, 44, 48, 10, 45, 111, 91, 45, 49, 93, 32, 64, 123, 45, 102,
  105, 108, 101, 110, 97, 109, 101, 92, 32, 34, 36, 55, 34, 44, 36, 62,
  44, 36, 102, 114, 97, 109, 101, 125, 32, 102, 114, 97, 109, 101, 61, 123,
  36, 102, 114, 97, 109, 101, 43, 49, 125, 10, 45, 101, 108, 115, 101, 10,
  45, 114, 101, 112, 108, 97, 99, 101, 91, 45, 49, 93, 32, 45, 49, 44,
  54, 52, 10, 45, 101, 110, 100, 105, 102, 10, 45, 119, 91, 45, 49, 93,
  32, 123, 119, 125, 44, 123, 104, 125, 44, 48, 44, 48, 44, 45, 49, 44,
  45, 49, 44, 64, 123, 48, 44, 110, 125, 32, 45, 119, 97, 105, 116, 32,
  50, 48, 32, 45, 107, 91, 48, 93, 10, 45, 119, 104, 105, 108, 101, 32,
  123, 64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83,
  67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125,
  32, 45, 114, 109, 32, 45, 119, 32, 48, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 97, 112, 112, 108, 121, 95, 99, 97, 109, 101, 114, 97, 51, 100,
  32, 58, 32, 112, 111, 115, 95, 120, 44, 112, 111, 115, 95, 121, 44, 112,
  111, 115, 95, 122, 44, 116, 97, 114, 103, 101, 116, 95, 120, 44, 116, 97,
  114, 103, 101, 116, 95, 121, 44, 116, 97, 114, 103, 101, 116, 95, 122, 44,
  117, 112, 95, 120, 44, 117, 112, 95, 121, 44, 117, 112, 95, 122, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 51, 100,
  32, 99, 97, 109, 101, 114, 97, 32, 109, 97, 116, 114, 105, 120, 32, 116,
  111, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 51, 100, 32, 111, 98,
  106, 101, 99, 116, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 116, 97, 114, 103, 101, 116, 95, 120, 61, 48, 39, 44, 32, 39, 116,
  97, 114, 103, 101, 116, 95, 121, 61, 48, 39, 44, 32, 39, 116, 97, 114,
  103, 101, 116, 95, 122, 61, 48, 39, 44, 32, 39, 117, 112, 95, 120, 61,
  48, 39, 44, 32, 39, 117, 112, 95, 121, 61, 45, 49, 39, 32, 97, 110,
  100, 32, 39, 117, 112, 95, 122, 61, 48, 39, 46, 10, 97, 112, 112, 108,
  121, 95, 99, 97, 109, 101, 114, 97, 51, 100, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 52, 61, 48, 125, 44, 36, 123, 53, 61, 48, 125,
  44, 36, 123, 54, 61, 48, 125, 44, 36, 123, 55, 61, 48, 125, 44, 36,
  123, 56, 61, 45, 49, 125, 44, 36, 123, 57, 61, 48, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 51, 100, 32,
  99, 97, 109, 101, 114, 97, 32, 109, 97, 116, 114, 105, 120, 32, 116, 111,
  32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 36, 63, 44, 32, 119, 105,
  116, 104, 32, 99, 97, 109, 101, 114, 97, 32, 112, 111, 115, 105, 116, 105,
  111, 110, 32, 40, 36, 49, 44, 36, 50, 44, 36, 51, 41, 44, 32, 116,
  97, 114, 103, 101, 116, 32, 112, 111, 115, 105, 116, 105, 111, 110, 32, 40,
  36, 52, 44, 36, 53, 44, 36, 54, 41, 32, 97, 110, 100, 32, 117, 112,
  45, 118, 101, 99, 116, 111, 114, 32, 40, 36, 55, 44, 36, 56, 44, 36,
  57, 41, 46, 34, 10, 45, 118, 32, 45, 10, 40, 123, 36, 52, 45, 36,
  49, 125, 94, 123, 36, 53, 45, 36, 50, 125, 94, 123, 36, 54, 45, 36,
  51, 125, 41, 10, 40, 36, 55, 94, 36, 56, 94, 36, 57, 41, 10, 45,
  111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 91, 45, 50, 44, 45,
  49, 93, 10, 45, 95, 99, 114, 111, 115, 115, 51, 100, 32, 64, 45, 50,
  44, 64, 45, 49, 10, 45, 95, 99, 114, 111, 115, 115, 51, 100, 32, 64,
  45, 49, 44, 64, 45, 51, 10, 45, 114, 109, 91, 45, 51, 93, 32, 45,
  121, 91, 45, 51, 45, 45, 49, 93, 32, 120, 32, 45, 109, 118, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 51, 10, 45, 97, 91, 45, 51, 45, 45,
  49, 93, 32, 121, 32, 45, 122, 91, 45, 49, 93, 32, 48, 44, 51, 10,
  45, 45, 51, 100, 91, 94, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44,
  36, 51, 32, 45, 97, 112, 112, 108, 121, 95, 112, 111, 115, 101, 51, 100,
  91, 94, 45, 49, 93, 32, 64, 45, 49, 32, 45, 114, 109, 91, 45, 49,
  93, 32, 45, 45, 51, 100, 32, 48, 44, 48, 44, 56, 48, 48, 10, 45,
  118, 32, 43, 10, 95, 99, 114, 111, 115, 115, 51, 100, 32, 58, 10, 40,
  123, 36, 50, 42, 36, 54, 45, 36, 51, 42, 36, 53, 125, 94, 123, 36,
  51, 42, 36, 52, 45, 36, 49, 42, 36, 54, 125, 94, 123, 36, 49, 42,
  36, 53, 45, 36, 50, 42, 36, 52, 125, 41, 32, 45, 111, 114, 105, 101,
  110, 116, 97, 116, 105, 111, 110, 91, 45, 49, 93, 32, 45, 121, 91, 45,
  49, 93, 10, 35, 64, 103, 109, 105, 99, 32, 97, 112, 112, 108, 121, 95,
  112, 111, 115, 101, 51, 100, 32, 58, 32, 112, 49, 44, 46, 46, 44, 112,
  49, 50, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108,
  121, 32, 51, 100, 32, 112, 111, 115, 101, 32, 109, 97, 116, 114, 105, 120,
  32, 116, 111, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 51, 100, 32,
  111, 98, 106, 101, 99, 116, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 45, 116, 111, 114, 117, 115, 51, 100, 32, 49, 48, 48,
  44, 50, 48, 32, 45, 97, 112, 112, 108, 121, 95, 112, 111, 115, 101, 51,
  100, 32, 48, 46, 49, 53, 50, 52, 51, 55, 44, 49, 46, 50, 48, 54,
  54, 54, 44, 45, 48, 46, 53, 52, 54, 51, 54, 54, 44, 48, 44, 45,
  48, 46, 53, 51, 53, 57, 54, 50, 44, 48, 46, 53, 53, 57, 49, 50,
  57, 44, 49, 46, 48, 56, 53, 51, 49, 44, 48, 44, 49, 46, 50, 49,
  49, 51, 50, 44, 48, 46, 48, 57, 53, 53, 52, 51, 49, 44, 48, 46,
  53, 52, 56, 57, 54, 54, 44, 48, 44, 48, 44, 48, 44, 45, 50, 48,
  54, 44, 49, 32, 45, 115, 110, 97, 112, 115, 104, 111, 116, 51, 100, 32,
  52, 48, 48, 10, 97, 112, 112, 108, 121, 95, 112, 111, 115, 101, 51, 100,
  32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108,
  121, 32, 51, 100, 32, 112, 111, 115, 101, 32, 109, 97, 116, 114, 105, 120,
  32, 91, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 59, 32,
  36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 59, 32, 36, 57, 44,
  36, 49, 48, 44, 36, 49, 49, 44, 36, 49, 50, 32, 93, 32, 116, 111,
  32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 36, 63, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 32, 45, 105, 102, 32, 64, 123, 45, 105, 115, 95,
  51, 100, 125, 10, 45, 115, 51, 100, 32, 45, 114, 91, 50, 93, 32, 51,
  44, 64, 123, 50, 44, 104, 47, 51, 125, 44, 49, 44, 49, 44, 45, 49,
  32, 45, 105, 91, 51, 93, 32, 49, 44, 64, 123, 50, 44, 104, 125, 44,
  49, 44, 49, 44, 49, 32, 45, 97, 91, 50, 44, 51, 93, 32, 120, 10,
  45, 105, 91, 51, 93, 32, 40, 36, 49, 44, 36, 53, 44, 36, 57, 59,
  36, 50, 44, 36, 54, 44, 36, 49, 48, 59, 36, 51, 44, 36, 55, 44,
  36, 49, 49, 59, 36, 52, 44, 36, 56, 44, 36, 49, 50, 41, 32, 45,
  42, 42, 91, 50, 44, 51, 93, 10, 45, 114, 91, 50, 93, 32, 49, 44,
  64, 123, 50, 44, 51, 42, 104, 125, 44, 49, 44, 49, 44, 45, 49, 32,
  45, 97, 32, 121, 10, 45, 101, 108, 115, 101, 32, 45, 101, 114, 114, 111,
  114, 32, 34, 73, 109, 97, 103, 101, 32, 91, 34, 123, 64, 35, 45, 36,
  62, 45, 49, 125, 34, 93, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32,
  114, 101, 112, 114, 101, 115, 101, 110, 116, 32, 97, 32, 51, 100, 32, 111,
  98, 106, 101, 99, 116, 46, 34, 10, 45, 101, 110, 100, 105, 102, 32, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 97, 114, 114, 111, 119, 51, 100, 32, 58,
  32, 120, 48, 44, 121, 48, 44, 122, 48, 44, 120, 49, 44, 121, 49, 44,
  122, 49, 44, 95, 114, 97, 100, 105, 117, 115, 91, 37, 93, 62, 61, 48,
  44, 95, 104, 101, 97, 100, 95, 108, 101, 110, 103, 116, 104, 91, 37, 93,
  62, 61, 48, 44, 95, 104, 101, 97, 100, 95, 114, 97, 100, 105, 117, 115,
  91, 37, 93, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  73, 110, 112, 117, 116, 32, 51, 100, 32, 97, 114, 114, 111, 119, 32, 119,
  105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 115, 116,
  97, 114, 116, 105, 110, 103, 32, 97, 110, 100, 32, 101, 110, 100, 105, 110,
  103, 32, 51, 100, 32, 112, 111, 105, 110, 116, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 114, 97, 100, 105, 117, 115, 61, 53, 37,
  39, 44, 32, 39, 104, 101, 97, 100, 95, 108, 101, 110, 103, 116, 104, 61,
  50, 53, 37, 39, 32, 97, 110, 100, 32, 39, 104, 101, 97, 100, 95, 114,
  97, 100, 105, 117, 115, 61, 49, 53, 37, 39, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 45, 114, 101, 112, 101, 97, 116, 32, 49,
  48, 32, 97, 61, 123, 36, 62, 42, 50, 42, 112, 105, 47, 49, 48, 125,
  32, 45, 97, 114, 114, 111, 119, 51, 100, 32, 48, 44, 48, 44, 48, 44,
  123, 99, 111, 115, 40, 36, 97, 41, 125, 44, 123, 115, 105, 110, 40, 36,
  97, 41, 125, 44, 45, 48, 46, 53, 32, 45, 100, 111, 110, 101, 32, 45,
  43, 51, 100, 10, 97, 114, 114, 111, 119, 51, 100, 32, 58, 32, 45, 99,
  104, 101, 99, 107, 32, 34, 36, 123, 55, 61, 53, 37, 125, 62, 61, 48,
  32, 38, 38, 32, 36, 123, 56, 61, 50, 53, 37, 125, 62, 61, 48, 32,
  38, 38, 32, 36, 123, 57, 61, 49, 53, 37, 125, 62, 61, 48, 34, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 51,
  100, 32, 97, 114, 114, 111, 119, 44, 32, 102, 114, 111, 109, 32, 40, 36,
  123, 49, 45, 51, 125, 41, 32, 116, 111, 32, 40, 36, 123, 52, 45, 54,
  125, 41, 44, 32, 119, 105, 116, 104, 32, 114, 97, 100, 105, 117, 115, 32,
  36, 55, 44, 32, 104, 101, 97, 100, 32, 108, 101, 110, 103, 116, 104, 32,
  36, 56, 32, 97, 110, 100, 32, 104, 101, 97, 100, 32, 114, 97, 100, 105,
  117, 115, 32, 36, 57, 46, 34, 10, 45, 118, 32, 45, 10, 76, 61, 123,
  115, 113, 114, 116, 40, 40, 36, 52, 45, 36, 49, 41, 94, 50, 43, 40,
  36, 53, 45, 36, 50, 41, 94, 50, 43, 40, 36, 54, 45, 36, 51, 41,
  94, 50, 41, 125, 10, 82, 61, 123, 105, 102, 40, 64, 123, 45, 105, 115,
  95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 55, 125, 44, 36, 55,
  42, 36, 76, 44, 36, 55, 41, 125, 10, 108, 61, 123, 105, 102, 40, 64,
  123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 56,
  125, 44, 36, 56, 42, 36, 76, 44, 36, 56, 41, 125, 10, 114, 61, 123,
  105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116,
  92, 32, 36, 57, 125, 44, 36, 57, 42, 36, 76, 44, 36, 57, 41, 125,
  10, 76, 61, 123, 36, 76, 45, 36, 108, 125, 32, 45, 99, 121, 108, 105,
  110, 100, 101, 114, 51, 100, 32, 36, 82, 44, 36, 76, 32, 45, 99, 111,
  110, 101, 51, 100, 32, 36, 114, 44, 36, 108, 32, 45, 43, 51, 100, 91,
  45, 49, 93, 32, 48, 44, 48, 44, 36, 76, 32, 45, 43, 51, 100, 91,
  45, 50, 44, 45, 49, 93, 10, 40, 123, 36, 52, 45, 36, 49, 125, 94,
  123, 36, 53, 45, 36, 50, 125, 94, 123, 36, 54, 45, 36, 51, 125, 41,
  32, 40, 48, 46, 48, 49, 94, 45, 48, 46, 48, 50, 94, 48, 46, 48,
  51, 41, 32, 45, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 95, 99, 114, 111, 115, 115, 51, 100,
  32, 64, 45, 50, 44, 64, 45, 49, 32, 45, 95, 99, 114, 111, 115, 115,
  51, 100, 32, 64, 45, 49, 44, 64, 45, 51, 32, 45, 114, 109, 91, 45,
  51, 93, 32, 45, 121, 91, 45, 51, 45, 45, 49, 93, 32, 120, 32, 45,
  109, 118, 91, 45, 50, 44, 45, 49, 93, 32, 45, 51, 10, 45, 97, 91,
  45, 51, 45, 45, 49, 93, 32, 121, 10, 45, 115, 51, 100, 91, 45, 50,
  93, 32, 45, 114, 91, 45, 53, 93, 32, 51, 44, 64, 123, 45, 53, 44,
  104, 47, 51, 125, 44, 49, 44, 49, 44, 45, 49, 32, 45, 42, 42, 91,
  45, 53, 44, 45, 49, 93, 10, 45, 121, 91, 45, 52, 93, 32, 45, 97,
  91, 45, 54, 45, 45, 49, 93, 32, 121, 32, 45, 43, 51, 100, 91, 45,
  49, 93, 32, 36, 123, 49, 45, 51, 125, 32, 45, 114, 118, 51, 100, 91,
  45, 49, 93, 10, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  97, 120, 101, 115, 51, 100, 32, 58, 32, 95, 115, 105, 122, 101, 95, 120,
  44, 95, 115, 105, 122, 101, 95, 121, 44, 95, 115, 105, 122, 101, 95, 122,
  44, 95, 102, 111, 110, 116, 95, 115, 105, 122, 101, 62, 48, 44, 95, 108,
  97, 98, 101, 108, 95, 120, 44, 95, 108, 97, 98, 101, 108, 95, 121, 44,
  95, 108, 97, 98, 101, 108, 95, 122, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 73, 110, 112, 117, 116, 32, 51, 100, 32, 97, 120, 101, 115, 32,
  119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 115,
  105, 122, 101, 115, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 120,
  44, 121, 32, 97, 110, 100, 32, 122, 32, 111, 114, 105, 101, 110, 116, 97,
  116, 105, 111, 110, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 115, 105, 122, 101, 95, 120, 61, 115, 105, 122, 101, 95, 121, 61, 115,
  105, 122, 101, 95, 122, 61, 49, 39, 44, 32, 39, 102, 111, 110, 116, 95,
  115, 105, 122, 101, 61, 50, 52, 39, 44, 32, 39, 108, 97, 98, 101, 108,
  95, 120, 61, 88, 39, 44, 32, 39, 108, 97, 98, 101, 108, 95, 121, 61,
  89, 39, 32, 97, 110, 100, 32, 39, 108, 97, 98, 101, 108, 95, 122, 61,
  90, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45,
  97, 120, 101, 115, 51, 100, 32, 44, 10, 97, 120, 101, 115, 51, 100, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 123, 52, 61, 50, 52, 125,
  62, 48, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 125, 44,
  36, 123, 50, 61, 36, 49, 125, 44, 36, 123, 51, 61, 36, 50, 125, 44,
  34, 36, 123, 53, 61, 88, 125, 44, 36, 123, 54, 61, 89, 125, 44, 36,
  123, 55, 61, 90, 125, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  73, 110, 112, 117, 116, 32, 51, 100, 32, 97, 120, 101, 115, 32, 119, 105,
  116, 104, 32, 115, 105, 122, 101, 115, 32, 40, 36, 49, 44, 36, 50, 44,
  36, 51, 41, 46, 34, 10, 45, 118, 32, 45, 32, 45, 108, 91, 93, 10,
  109, 61, 123, 109, 97, 120, 40, 97, 98, 115, 40, 36, 49, 41, 44, 97,
  98, 115, 40, 36, 50, 41, 44, 97, 98, 115, 40, 36, 51, 41, 41, 47,
  52, 48, 125, 32, 109, 50, 61, 123, 50, 42, 36, 109, 125, 32, 109, 51,
  61, 123, 49, 46, 50, 42, 36, 109, 50, 125, 10, 45, 95, 97, 120, 101,
  115, 51, 100, 32, 34, 79, 34, 44, 36, 52, 32, 45, 45, 51, 100, 91,
  45, 49, 93, 32, 36, 109, 51, 44, 36, 109, 51, 44, 36, 109, 51, 10,
  45, 105, 102, 32, 36, 49, 10, 45, 108, 105, 110, 101, 51, 100, 32, 48,
  44, 48, 44, 48, 44, 36, 49, 44, 48, 44, 48, 10, 45, 99, 111, 110,
  101, 51, 100, 32, 36, 109, 44, 123, 50, 42, 36, 109, 125, 44, 49, 54,
  32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 49, 44, 48, 44,
  45, 57, 48, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 123, 36, 49,
  45, 36, 109, 50, 125, 44, 48, 44, 48, 10, 45, 95, 97, 120, 101, 115,
  51, 100, 32, 34, 36, 53, 34, 44, 36, 52, 32, 45, 43, 51, 100, 91,
  45, 49, 93, 32, 123, 36, 49, 43, 36, 109, 51, 125, 44, 48, 44, 48,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 50, 10, 45,
  108, 105, 110, 101, 51, 100, 32, 48, 44, 48, 44, 48, 44, 48, 44, 36,
  50, 44, 48, 10, 45, 99, 111, 110, 101, 51, 100, 32, 36, 109, 44, 123,
  50, 42, 36, 109, 125, 44, 49, 54, 32, 45, 114, 51, 100, 91, 45, 49,
  93, 32, 49, 44, 48, 44, 48, 44, 57, 48, 32, 45, 43, 51, 100, 91,
  45, 49, 93, 32, 48, 44, 123, 36, 50, 45, 36, 109, 50, 125, 44, 48,
  10, 45, 95, 97, 120, 101, 115, 51, 100, 32, 34, 36, 54, 34, 44, 36,
  52, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 48, 44, 123, 36, 50,
  43, 36, 109, 51, 125, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 36, 51, 10, 45, 108, 105, 110, 101, 51, 100, 32, 48, 44,
  48, 44, 48, 44, 48, 44, 48, 44, 36, 51, 10, 45, 99, 111, 110, 101,
  51, 100, 32, 36, 109, 44, 123, 50, 42, 36, 109, 125, 44, 49, 54, 32,
  45, 43, 51, 100, 91, 45, 49, 93, 32, 48, 44, 48, 44, 123, 36, 51,
  45, 36, 109, 50, 125, 10, 45, 95, 97, 120, 101, 115, 51, 100, 32, 34,
  36, 55, 34, 44, 36, 52, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32,
  48, 44, 48, 44, 123, 36, 51, 43, 36, 109, 51, 125, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 43, 51, 100, 32, 45, 110, 109, 32, 91, 51, 100,
  92, 32, 97, 120, 101, 115, 93, 10, 45, 101, 110, 100, 108, 32, 45, 118,
  32, 43, 10, 95, 97, 120, 101, 115, 51, 100, 32, 58, 10, 48, 32, 45,
  116, 91, 45, 49, 93, 32, 34, 36, 49, 34, 44, 50, 44, 48, 44, 36,
  50, 44, 49, 44, 49, 32, 45, 45, 100, 105, 108, 97, 116, 101, 91, 45,
  49, 93, 32, 51, 32, 45, 42, 91, 45, 50, 93, 32, 50, 53, 53, 32,
  45, 114, 91, 45, 50, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 49, 44, 51, 10, 45, 105, 91, 45, 51, 93, 32, 40, 54, 55, 46,
  53, 59, 55, 51, 46, 53, 59, 49, 48, 57, 46, 53, 59, 49, 48, 51,
  46, 53, 59, 53, 49, 46, 53, 59, 49, 48, 48, 46, 53, 59, 49, 59,
  49, 59, 48, 59, 48, 59, 48, 59, 49, 59, 48, 59, 45, 49, 50, 56,
  59, 123, 119, 125, 59, 123, 104, 125, 59, 51, 41, 10, 45, 105, 91, 45,
  50, 93, 32, 40, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104, 125,
  59, 49, 41, 32, 45, 121, 91, 45, 51, 44, 45, 49, 93, 32, 45, 97,
  91, 45, 52, 45, 45, 49, 93, 32, 121, 10, 35, 64, 103, 109, 105, 99,
  32, 98, 51, 100, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45,
  98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 51, 100, 39, 46, 32, 58,
  32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 98, 97, 99, 107,
  103, 114, 111, 117, 110, 100, 51, 100, 32, 58, 32, 82, 44, 95, 71, 44,
  95, 66, 32, 58, 32, 91, 105, 109, 97, 103, 101, 93, 32, 58, 32, 40,
  110, 111, 32, 97, 114, 103, 115, 41, 32, 58, 32, 40, 43, 41, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 105, 110, 101, 32, 98,
  97, 99, 107, 103, 114, 111, 117, 110, 100, 32, 102, 114, 111, 109, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 99, 111, 108, 111, 114, 32, 111,
  114, 32, 101, 120, 105, 115, 116, 105, 110, 103, 32, 105, 109, 97, 103, 101,
  32, 102, 111, 114, 32, 105, 110, 116, 101, 114, 97, 99, 116, 105, 118, 101,
  32, 51, 100, 32, 118, 105, 101, 119, 101, 114, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 98,
  51, 100, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40,
  110, 111, 32, 97, 114, 103, 115, 41, 32, 114, 101, 115, 101, 116, 115, 32,
  116, 104, 101, 32, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 32, 116,
  111, 32, 100, 101, 102, 97, 117, 108, 116, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 98, 111, 120, 51, 100, 32, 58, 32, 95, 115, 105, 122, 101, 95,
  120, 44, 95, 115, 105, 122, 101, 95, 121, 44, 95, 115, 105, 122, 101, 95,
  122, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 110, 112, 117, 116,
  32, 51, 100, 32, 98, 111, 120, 32, 97, 116, 32, 40, 48, 44, 48, 44,
  48, 41, 44, 32, 119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105,
  101, 100, 32, 103, 101, 111, 109, 101, 116, 114, 121, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 115, 105, 122, 101, 95, 120, 61, 49, 39,
  32, 97, 110, 100, 32, 39, 115, 105, 122, 101, 95, 122, 61, 115, 105, 122,
  101, 95, 121, 61, 115, 105, 122, 101, 95, 120, 39, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 45, 98, 111, 120, 51, 100, 32, 49,
  48, 48, 44, 52, 48, 44, 51, 48, 32, 45, 45, 112, 114, 105, 109, 105,
  116, 105, 118, 101, 115, 51, 100, 32, 49, 32, 45, 99, 111, 108, 111, 114,
  51, 100, 91, 45, 50, 93, 32, 64, 123, 45, 82, 71, 66, 125, 10, 98,
  111, 120, 51, 100, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49,
  61, 49, 125, 44, 36, 123, 50, 61, 36, 49, 125, 44, 36, 123, 51, 61,
  36, 50, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112,
  117, 116, 32, 51, 100, 32, 98, 111, 120, 44, 32, 119, 105, 116, 104, 32,
  115, 105, 122, 101, 32, 40, 36, 49, 44, 36, 50, 44, 36, 51, 41, 46,
  34, 10, 45, 118, 32, 45, 10, 49, 44, 56, 54, 44, 49, 44, 49, 44,
  92, 10, 54, 55, 46, 53, 44, 55, 51, 46, 53, 44, 49, 48, 57, 46,
  53, 44, 49, 48, 51, 46, 53, 44, 53, 49, 46, 53, 44, 49, 48, 48,
  46, 53, 44, 56, 44, 54, 44, 92, 10, 48, 44, 48, 44, 48, 44, 36,
  49, 44, 48, 44, 48, 44, 36, 49, 44, 36, 50, 44, 48, 44, 48, 44,
  36, 50, 44, 48, 44, 92, 10, 48, 44, 48, 44, 36, 51, 44, 36, 49,
  44, 48, 44, 36, 51, 44, 36, 49, 44, 36, 50, 44, 36, 51, 44, 48,
  44, 36, 50, 44, 36, 51, 44, 92, 10, 52, 44, 48, 44, 51, 44, 50,
  44, 49, 44, 52, 44, 52, 44, 53, 44, 54, 44, 55, 44, 52, 44, 48,
  44, 49, 44, 53, 44, 52, 44, 52, 44, 51, 44, 55, 44, 54, 44, 50,
  44, 52, 44, 48, 44, 52, 44, 55, 44, 51, 44, 52, 44, 49, 44, 50,
  44, 54, 44, 53, 44, 92, 10, 50, 48, 48, 44, 50, 48, 48, 44, 50,
  48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44, 50,
  48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44, 50,
  48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44, 50,
  48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44, 92,
  10, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 10, 45, 110, 109,
  91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 98, 111, 120, 93, 10, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 99, 51, 100, 32, 58,
  32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 99, 101, 110, 116, 101, 114,
  51, 100, 39, 46, 10, 99, 51, 100, 32, 58, 10, 45, 95, 99, 101, 110,
  116, 101, 114, 51, 100, 10, 35, 64, 103, 109, 105, 99, 32, 99, 101, 110,
  116, 101, 114, 51, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67,
  101, 110, 116, 101, 114, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 51,
  100, 32, 111, 98, 106, 101, 99, 116, 115, 32, 97, 116, 32, 40, 48, 44,
  48, 44, 48, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40,
  101, 113, 46, 32, 116, 111, 32, 39, 45, 99, 51, 100, 39, 41, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 49, 48, 48, 32, 45, 99, 105, 114, 99, 108, 101, 51, 100,
  32, 123, 63, 40, 49, 48, 48, 41, 125, 44, 123, 63, 40, 49, 48, 48,
  41, 125, 44, 123, 63, 40, 49, 48, 48, 41, 125, 44, 50, 32, 45, 100,
  111, 110, 101, 32, 45, 97, 100, 100, 51, 100, 32, 45, 99, 111, 108, 111,
  114, 51, 100, 91, 45, 49, 93, 32, 50, 53, 53, 44, 48, 44, 48, 32,
  45, 45, 99, 101, 110, 116, 101, 114, 51, 100, 32, 45, 99, 111, 108, 111,
  114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 44, 48, 32,
  45, 97, 100, 100, 51, 100, 10, 99, 101, 110, 116, 101, 114, 51, 100, 32,
  58, 10, 45, 95, 36, 48, 10, 95, 99, 101, 110, 116, 101, 114, 51, 100,
  32, 58, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 67, 101, 110,
  116, 101, 114, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 36, 63, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 99, 104, 101, 99, 107, 51, 100, 32,
  48, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 110, 61, 123, 105, 91, 54, 93, 125, 10, 45, 105, 102,
  32, 123, 36, 110, 62, 48, 125, 10, 45, 115, 104, 32, 56, 44, 123, 55,
  43, 51, 42, 36, 110, 125, 44, 48, 44, 48, 32, 45, 114, 91, 45, 49,
  93, 32, 51, 44, 123, 104, 47, 51, 125, 44, 49, 44, 49, 44, 45, 49,
  32, 45, 115, 91, 45, 49, 93, 32, 120, 10, 45, 45, 91, 45, 51, 93,
  32, 64, 123, 45, 51, 44, 40, 105, 77, 43, 105, 109, 41, 47, 50, 125,
  32, 45, 45, 91, 45, 50, 93, 32, 64, 123, 45, 50, 44, 40, 105, 77,
  43, 105, 109, 41, 47, 50, 125, 32, 45, 45, 91, 45, 49, 93, 32, 123,
  40, 105, 77, 43, 105, 109, 41, 47, 50, 125, 10, 45, 97, 91, 45, 51,
  45, 45, 49, 93, 32, 120, 32, 45, 121, 91, 45, 49, 93, 32, 45, 106,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 56, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 99, 105, 114, 99, 108, 101, 51, 100, 32, 58, 32,
  95, 120, 48, 44, 95, 121, 48, 44, 95, 122, 48, 44, 95, 114, 97, 100,
  105, 117, 115, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  73, 110, 112, 117, 116, 32, 51, 100, 32, 99, 105, 114, 99, 108, 101, 32,
  97, 116, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 99, 111, 111,
  114, 100, 105, 110, 97, 116, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  115, 58, 32, 39, 120, 48, 61, 121, 48, 61, 122, 48, 61, 48, 39, 32,
  97, 110, 100, 32, 39, 114, 97, 100, 105, 117, 115, 61, 49, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 53, 48, 48, 32, 97, 61, 123, 36, 62, 42, 112, 105, 47,
  50, 53, 48, 125, 32, 45, 99, 105, 114, 99, 108, 101, 51, 100, 32, 123,
  99, 111, 115, 40, 51, 42, 36, 97, 41, 125, 44, 123, 115, 105, 110, 40,
  50, 42, 36, 97, 41, 125, 44, 48, 44, 123, 36, 97, 47, 53, 48, 125,
  32, 45, 99, 111, 108, 111, 114, 51, 100, 91, 45, 49, 93, 32, 64, 123,
  45, 82, 71, 66, 125, 44, 48, 46, 52, 32, 45, 100, 111, 110, 101, 32,
  45, 97, 100, 100, 51, 100, 10, 99, 105, 114, 99, 108, 101, 51, 100, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 125, 44, 36,
  123, 50, 61, 48, 125, 44, 36, 123, 51, 61, 48, 125, 44, 36, 123, 52,
  61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112,
  117, 116, 32, 51, 100, 32, 99, 105, 114, 99, 108, 101, 32, 97, 116, 32,
  112, 111, 115, 105, 116, 105, 111, 110, 32, 40, 36, 49, 44, 36, 50, 44,
  36, 51, 41, 32, 119, 105, 116, 104, 32, 114, 97, 100, 105, 117, 115, 32,
  36, 52, 46, 34, 10, 45, 118, 32, 45, 10, 114, 61, 123, 36, 52, 47,
  115, 113, 114, 116, 40, 51, 41, 125, 10, 49, 44, 50, 52, 44, 49, 44,
  49, 44, 92, 10, 54, 55, 46, 53, 44, 55, 51, 46, 53, 44, 49, 48,
  57, 46, 53, 44, 49, 48, 51, 46, 53, 44, 53, 49, 46, 53, 44, 49,
  48, 48, 46, 53, 44, 50, 44, 49, 44, 92, 10, 123, 36, 49, 45, 36,
  114, 125, 44, 123, 36, 50, 45, 36, 114, 125, 44, 123, 36, 51, 45, 36,
  114, 125, 44, 92, 10, 123, 36, 49, 43, 36, 114, 125, 44, 123, 36, 50,
  43, 36, 114, 125, 44, 123, 36, 51, 43, 36, 114, 125, 44, 92, 10, 53,
  44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 48, 48, 44, 50,
  48, 48, 44, 50, 48, 48, 44, 49, 10, 45, 110, 109, 91, 45, 49, 93,
  32, 91, 51, 100, 92, 32, 99, 105, 114, 99, 108, 101, 93, 10, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 99, 105, 114, 99, 108, 101,
  115, 51, 100, 32, 58, 32, 95, 114, 97, 100, 105, 117, 115, 62, 61, 48,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114,
  116, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 51, 100, 32, 111,
  98, 106, 101, 99, 116, 115, 32, 116, 111, 32, 115, 101, 116, 115, 32, 111,
  102, 32, 51, 100, 32, 99, 105, 114, 99, 108, 101, 115, 32, 119, 105, 116,
  104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 114, 97, 100, 105,
  117, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 114, 97, 100,
  105, 117, 115, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 108, 117,
  109, 105, 110, 97, 110, 99, 101, 32, 45, 114, 101, 115, 105, 122, 101, 50,
  100, 121, 32, 52, 48, 32, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100,
  32, 53, 48, 37, 32, 45, 42, 32, 50, 53, 53, 32, 45, 112, 111, 105,
  110, 116, 99, 108, 111, 117, 100, 51, 100, 32, 45, 99, 111, 108, 111, 114,
  51, 100, 91, 45, 49, 93, 32, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 32, 45, 99, 105, 114, 99, 108, 101, 115, 51, 100, 32, 48, 46,
  55, 10, 99, 105, 114, 99, 108, 101, 115, 51, 100, 32, 58, 32, 45, 99,
  104, 101, 99, 107, 32, 36, 123, 49, 61, 49, 125, 62, 61, 48, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32,
  51, 100, 32, 111, 98, 106, 101, 99, 116, 36, 63, 32, 116, 111, 32, 115,
  101, 116, 115, 32, 111, 102, 32, 51, 100, 32, 99, 105, 114, 99, 108, 101,
  115, 32, 119, 105, 116, 104, 32, 114, 97, 100, 105, 117, 115, 32, 36, 49,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 112, 51, 100, 32, 48, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 110, 98, 118, 61, 64, 123, 45, 49, 44, 54, 125, 32, 110, 98, 112,
  61, 64, 123, 45, 49, 44, 55, 125, 10, 45, 105, 102, 32, 123, 36, 110,
  98, 118, 38, 38, 36, 110, 98, 112, 125, 10, 45, 45, 51, 100, 32, 123,
  36, 49, 47, 50, 125, 44, 48, 44, 48, 32, 45, 45, 43, 51, 100, 32,
  36, 49, 44, 48, 44, 48, 32, 45, 43, 51, 100, 32, 110, 98, 112, 50,
  61, 64, 123, 45, 49, 44, 55, 125, 10, 45, 115, 51, 100, 32, 45, 61,
  91, 49, 93, 32, 36, 110, 98, 112, 44, 48, 44, 49, 10, 45, 114, 91,
  51, 93, 32, 50, 44, 36, 110, 98, 112, 50, 44, 49, 44, 49, 44, 45,
  49, 32, 45, 99, 111, 108, 117, 109, 110, 115, 91, 51, 93, 32, 49, 44,
  49, 32, 45, 115, 91, 51, 93, 32, 121, 44, 50, 32, 45, 105, 91, 51,
  93, 32, 49, 44, 36, 110, 98, 112, 44, 49, 44, 49, 44, 53, 32, 45,
  97, 91, 51, 45, 53, 93, 32, 120, 32, 45, 99, 111, 108, 117, 109, 110,
  115, 91, 51, 93, 32, 48, 44, 53, 32, 45, 121, 91, 51, 93, 10, 45,
  114, 111, 119, 115, 91, 52, 93, 32, 48, 44, 123, 51, 42, 36, 110, 98,
  112, 45, 49, 125, 32, 45, 114, 111, 119, 115, 91, 53, 93, 32, 48, 44,
  123, 36, 110, 98, 112, 45, 49, 125, 32, 45, 97, 32, 121, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 99, 111, 108,
  51, 100, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 99, 111,
  108, 111, 114, 51, 100, 39, 46, 32, 58, 32, 40, 43, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 99, 111, 108, 111, 114, 51, 100, 32, 58, 32, 82,
  44, 95, 71, 44, 95, 66, 44, 95, 111, 112, 97, 99, 105, 116, 121, 32,
  58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83,
  101, 116, 32, 99, 111, 108, 111, 114, 32, 97, 110, 100, 32, 111, 112, 97,
  99, 105, 116, 121, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45,
  99, 111, 108, 51, 100, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58,
  32, 39, 66, 61, 71, 61, 82, 39, 32, 97, 110, 100, 32, 39, 111, 112,
  97, 99, 105, 116, 121, 61, 40, 117, 110, 100, 101, 102, 105, 110, 101, 100,
  41, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45,
  116, 111, 114, 117, 115, 51, 100, 32, 49, 48, 48, 44, 49, 48, 32, 45,
  100, 111, 117, 98, 108, 101, 51, 100, 32, 48, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 55, 32, 45, 45, 114, 111, 116, 97, 116, 101, 51, 100, 91,
  45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 50, 48, 32, 45, 99, 111,
  108, 111, 114, 51, 100, 91, 45, 49, 93, 32, 64, 123, 45, 82, 71, 66,
  125, 32, 45, 100, 111, 110, 101, 32, 45, 97, 100, 100, 51, 100, 10, 35,
  64, 103, 109, 105, 99, 32, 99, 111, 108, 111, 114, 99, 117, 98, 101, 51,
  100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 110, 112, 117, 116,
  32, 51, 100, 32, 99, 111, 108, 111, 114, 32, 99, 117, 98, 101, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 99, 111, 108, 111,
  114, 99, 117, 98, 101, 51, 100, 32, 45, 109, 111, 100, 101, 51, 100, 32,
  50, 32, 45, 45, 112, 114, 105, 109, 105, 116, 105, 118, 101, 115, 51, 100,
  32, 49, 10, 99, 111, 108, 111, 114, 99, 117, 98, 101, 51, 100, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32,
  51, 100, 32, 82, 71, 66, 45, 99, 111, 108, 111, 114, 32, 99, 117, 98,
  101, 46, 34, 10, 45, 118, 32, 45, 10, 40, 54, 55, 46, 53, 59, 55,
  51, 46, 53, 59, 49, 48, 57, 46, 53, 59, 49, 48, 51, 46, 53, 59,
  53, 49, 46, 53, 59, 49, 48, 48, 46, 53, 59, 56, 59, 54, 41, 10,
  40, 48, 59, 48, 59, 48, 59, 92, 10, 50, 53, 53, 59, 48, 59, 48,
  59, 92, 10, 50, 53, 53, 59, 50, 53, 53, 59, 48, 59, 92, 10, 48,
  59, 50, 53, 53, 59, 48, 59, 92, 10, 48, 59, 48, 59, 50, 53, 53,
  59, 92, 10, 50, 53, 53, 59, 48, 59, 50, 53, 53, 59, 92, 10, 50,
  53, 53, 59, 50, 53, 53, 59, 50, 53, 53, 59, 92, 10, 48, 59, 50,
  53, 53, 59, 50, 53, 53, 41, 10, 40, 49, 50, 59, 48, 59, 51, 59,
  50, 59, 49, 59, 48, 59, 48, 59, 48, 59, 54, 51, 59, 54, 51, 59,
  54, 51, 59, 54, 51, 59, 48, 59, 92, 10, 49, 50, 59, 49, 59, 50,
  59, 54, 59, 53, 59, 48, 59, 48, 59, 48, 59, 54, 51, 59, 54, 51,
  59, 54, 51, 59, 54, 51, 59, 48, 59, 92, 10, 49, 50, 59, 48, 59,
  52, 59, 55, 59, 51, 59, 48, 59, 48, 59, 54, 51, 59, 48, 59, 54,
  51, 59, 54, 51, 59, 48, 59, 54, 51, 59, 92, 10, 49, 50, 59, 52,
  59, 53, 59, 54, 59, 55, 59, 48, 59, 48, 59, 54, 51, 59, 48, 59,
  54, 51, 59, 54, 51, 59, 48, 59, 54, 51, 59, 92, 10, 49, 50, 59,
  48, 59, 49, 59, 53, 59, 52, 59, 48, 59, 48, 59, 54, 51, 59, 48,
  59, 54, 51, 59, 54, 51, 59, 48, 59, 54, 51, 59, 92, 10, 49, 50,
  59, 51, 59, 55, 59, 54, 59, 50, 59, 48, 59, 48, 59, 48, 59, 54,
  51, 59, 54, 51, 59, 54, 51, 59, 54, 51, 59, 48, 41, 10, 40, 48,
  44, 50, 53, 53, 59, 48, 44, 50, 53, 53, 94, 48, 44, 48, 59, 50,
  53, 53, 44, 50, 53, 53, 94, 48, 44, 48, 59, 48, 44, 48, 41, 10,
  40, 50, 53, 53, 44, 50, 53, 53, 59, 50, 53, 53, 44, 50, 53, 53,
  94, 48, 44, 48, 59, 50, 53, 53, 44, 50, 53, 53, 94, 48, 44, 50,
  53, 53, 59, 48, 44, 50, 53, 53, 41, 10, 40, 48, 44, 48, 59, 48,
  44, 48, 94, 48, 44, 48, 59, 50, 53, 53, 44, 50, 53, 53, 94, 48,
  44, 50, 53, 53, 59, 48, 44, 50, 53, 53, 41, 10, 40, 48, 44, 50,
  53, 53, 59, 48, 44, 50, 53, 53, 94, 48, 44, 48, 59, 50, 53, 53,
  44, 50, 53, 53, 94, 50, 53, 53, 44, 50, 53, 53, 59, 50, 53, 53,
  44, 50, 53, 53, 41, 10, 40, 48, 44, 50, 53, 53, 59, 48, 44, 50,
  53, 53, 94, 48, 44, 48, 59, 48, 44, 48, 94, 48, 44, 48, 59, 50,
  53, 53, 44, 50, 53, 53, 41, 10, 40, 48, 44, 50, 53, 53, 59, 48,
  44, 50, 53, 53, 94, 50, 53, 53, 44, 50, 53, 53, 59, 50, 53, 53,
  44, 50, 53, 53, 94, 48, 44, 48, 59, 50, 53, 53, 44, 50, 53, 53,
  41, 10, 45, 114, 91, 45, 54, 45, 45, 49, 93, 32, 54, 52, 44, 54,
  52, 44, 49, 44, 51, 44, 51, 32, 45, 121, 91, 45, 54, 45, 45, 49,
  93, 32, 45, 105, 91, 45, 55, 45, 45, 50, 93, 32, 40, 45, 49, 50,
  56, 59, 54, 52, 59, 54, 52, 59, 51, 41, 10, 40, 49, 59, 49, 59,
  49, 59, 49, 59, 49, 59, 49, 41, 10, 45, 97, 91, 45, 49, 54, 45,
  45, 49, 93, 32, 121, 32, 45, 110, 109, 91, 45, 49, 93, 32, 91, 51,
  100, 92, 32, 99, 111, 108, 111, 114, 99, 117, 98, 101, 93, 10, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 99, 111, 110, 101, 51, 100,
  32, 58, 32, 95, 114, 97, 100, 105, 117, 115, 44, 95, 104, 101, 105, 103,
  104, 116, 44, 95, 110, 98, 95, 115, 117, 98, 100, 105, 118, 105, 115, 105,
  111, 110, 115, 62, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73,
  110, 112, 117, 116, 32, 51, 100, 32, 99, 111, 110, 101, 32, 97, 116, 32,
  40, 48, 44, 48, 44, 48, 41, 44, 32, 119, 105, 116, 104, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 103, 101, 111, 109, 101, 116, 114, 121,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117,
  108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 114, 97, 100, 105, 117,
  115, 61, 49, 39, 44, 39, 104, 101, 105, 103, 104, 116, 61, 49, 39, 32,
  97, 110, 100, 32, 39, 110, 98, 95, 115, 117, 98, 100, 105, 118, 105, 115,
  105, 111, 110, 115, 61, 50, 52, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 45, 99, 111, 110, 101, 51, 100, 32, 49, 48, 44,
  52, 48, 32, 45, 45, 112, 114, 105, 109, 105, 116, 105, 118, 101, 115, 51,
  100, 32, 49, 32, 45, 99, 111, 108, 111, 114, 51, 100, 91, 45, 50, 93,
  32, 64, 123, 45, 82, 71, 66, 125, 10, 99, 111, 110, 101, 51, 100, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 123, 51, 61, 50, 52, 125,
  62, 48, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 125, 44,
  36, 123, 50, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  73, 110, 112, 117, 116, 32, 51, 100, 32, 99, 111, 110, 101, 44, 32, 119,
  105, 116, 104, 32, 114, 97, 100, 105, 117, 115, 32, 36, 49, 44, 32, 104,
  101, 105, 103, 104, 116, 32, 36, 50, 32, 97, 110, 100, 32, 36, 51, 32,
  115, 117, 98, 100, 105, 118, 105, 115, 105, 111, 110, 115, 46, 34, 10, 45,
  118, 32, 45, 10, 40, 54, 55, 46, 53, 59, 55, 51, 46, 53, 59, 49,
  48, 57, 46, 53, 59, 49, 48, 51, 46, 53, 59, 53, 49, 46, 53, 59,
  49, 48, 48, 46, 53, 41, 10, 40, 123, 36, 51, 43, 50, 125, 59, 123,
  50, 42, 36, 51, 125, 41, 10, 40, 48, 44, 48, 44, 48, 59, 48, 44,
  48, 44, 36, 50, 41, 10, 40, 48, 59, 123, 50, 42, 112, 105, 125, 41,
  32, 45, 114, 91, 45, 49, 93, 32, 49, 44, 123, 36, 51, 43, 49, 125,
  44, 49, 44, 49, 44, 51, 32, 45, 114, 111, 119, 115, 91, 45, 49, 93,
  32, 48, 44, 123, 36, 51, 45, 49, 125, 32, 45, 45, 115, 105, 110, 91,
  45, 49, 93, 32, 45, 99, 111, 115, 91, 45, 50, 93, 32, 45, 42, 91,
  45, 50, 44, 45, 49, 93, 32, 36, 49, 32, 45, 97, 91, 45, 50, 44,
  45, 49, 93, 32, 120, 32, 45, 122, 91, 45, 49, 93, 32, 48, 44, 50,
  32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 10, 49, 44, 36,
  51, 44, 49, 44, 49, 44, 39, 121, 39, 32, 45, 45, 115, 104, 105, 102,
  116, 91, 45, 49, 93, 32, 48, 44, 45, 49, 32, 45, 43, 91, 45, 50,
  44, 45, 49, 93, 32, 50, 10, 50, 44, 36, 51, 44, 49, 44, 49, 44,
  51, 44, 48, 32, 91, 45, 50, 93, 32, 91, 45, 52, 93, 32, 45, 97,
  91, 45, 51, 45, 45, 49, 93, 32, 120, 10, 45, 105, 91, 45, 52, 93,
  32, 50, 44, 36, 51, 44, 49, 44, 49, 44, 51, 44, 49, 32, 45, 97,
  91, 45, 52, 45, 45, 50, 93, 32, 120, 10, 45, 97, 91, 45, 50, 44,
  45, 49, 93, 32, 121, 10, 51, 44, 123, 104, 125, 44, 49, 44, 49, 44,
  50, 48, 48, 10, 49, 44, 123, 104, 125, 44, 49, 44, 49, 44, 49, 10,
  45, 121, 91, 45, 52, 45, 45, 50, 93, 32, 45, 97, 91, 45, 54, 45,
  45, 49, 93, 32, 121, 32, 45, 110, 109, 91, 45, 49, 93, 32, 91, 51,
  100, 92, 32, 99, 111, 110, 101, 93, 10, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 99, 117, 98, 101, 115, 51, 100, 32, 58, 32, 95,
  115, 105, 122, 101, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 112, 101, 99, 105, 102, 105,
  101, 100, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 115, 32, 116, 111,
  32, 115, 101, 116, 115, 32, 111, 102, 32, 51, 100, 32, 99, 117, 98, 101,
  115, 32, 119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100,
  32, 115, 105, 122, 101, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39,
  115, 105, 122, 101, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 108,
  117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 114, 101, 115, 105, 122, 101,
  50, 100, 121, 32, 52, 48, 32, 45, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 32, 53, 48, 37, 32, 45, 42, 32, 50, 53, 53, 32, 45, 112, 111,
  105, 110, 116, 99, 108, 111, 117, 100, 51, 100, 32, 45, 99, 111, 108, 111,
  114, 51, 100, 91, 45, 49, 93, 32, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 32, 45, 99, 117, 98, 101, 115, 51, 100, 32, 49, 10, 99,
  117, 98, 101, 115, 51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  36, 123, 49, 61, 49, 125, 62, 61, 48, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 51, 100, 32, 111, 98,
  106, 101, 99, 116, 36, 63, 32, 116, 111, 32, 115, 101, 116, 115, 32, 111,
  102, 32, 51, 100, 32, 99, 117, 98, 101, 115, 32, 119, 105, 116, 104, 32,
  115, 105, 122, 101, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  112, 51, 100, 32, 48, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 110, 98, 118, 61, 64, 123, 45, 49,
  44, 54, 125, 32, 110, 98, 112, 61, 64, 123, 45, 49, 44, 55, 125, 10,
  45, 105, 102, 32, 123, 36, 110, 98, 118, 38, 38, 36, 110, 98, 112, 125,
  10, 45, 115, 51, 100, 10, 45, 108, 91, 49, 93, 32, 45, 61, 32, 123,
  56, 42, 105, 91, 48, 93, 125, 32, 45, 61, 32, 123, 54, 42, 105, 91,
  49, 93, 125, 44, 48, 44, 49, 32, 45, 101, 110, 100, 108, 10, 45, 108,
  91, 50, 93, 32, 45, 114, 32, 51, 44, 123, 104, 47, 51, 125, 44, 49,
  44, 49, 44, 45, 49, 10, 104, 97, 108, 102, 61, 123, 36, 49, 47, 50,
  125, 10, 45, 45, 32, 39, 36, 104, 97, 108, 102, 44, 48, 44, 48, 39,
  32, 45, 45, 43, 32, 39, 36, 49, 44, 48, 44, 48, 39, 32, 45, 97,
  32, 120, 10, 45, 45, 32, 39, 48, 44, 36, 104, 97, 108, 102, 44, 48,
  39, 32, 45, 45, 43, 32, 39, 48, 44, 36, 49, 44, 48, 39, 32, 45,
  97, 32, 120, 10, 45, 45, 32, 39, 48, 44, 48, 44, 36, 104, 97, 108,
  102, 39, 32, 45, 45, 43, 32, 39, 48, 44, 48, 44, 36, 49, 39, 32,
  45, 97, 32, 120, 10, 45, 101, 110, 100, 108, 10, 45, 108, 91, 51, 93,
  32, 45, 114, 32, 50, 44, 123, 104, 47, 50, 125, 44, 49, 44, 49, 44,
  45, 49, 10, 45, 122, 32, 49, 44, 49, 32, 45, 42, 32, 56, 32, 45,
  114, 32, 52, 44, 49, 48, 48, 37, 32, 45, 105, 91, 48, 93, 32, 49,
  44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 52, 32, 45, 97, 32, 120,
  32, 91, 45, 49, 93, 120, 53, 32, 45, 97, 32, 120, 10, 45, 43, 32,
  39, 34, 48, 44, 48, 44, 50, 44, 51, 44, 49, 44, 32, 48, 44, 52,
  44, 53, 44, 55, 44, 54, 44, 32, 48, 44, 48, 44, 49, 44, 53, 44,
  52, 44, 32, 48, 44, 50, 44, 54, 44, 55, 44, 51, 44, 32, 48, 44,
  48, 44, 52, 44, 54, 44, 50, 44, 32, 48, 44, 49, 44, 51, 44, 55,
  44, 53, 34, 39, 10, 45, 101, 110, 100, 108, 10, 45, 108, 91, 52, 93,
  32, 45, 114, 32, 51, 44, 123, 104, 47, 51, 125, 44, 49, 44, 49, 44,
  45, 49, 32, 45, 114, 32, 49, 56, 44, 49, 48, 48, 37, 44, 49, 44,
  49, 44, 48, 44, 50, 32, 45, 101, 110, 100, 108, 32, 45, 114, 91, 53,
  93, 32, 54, 44, 49, 48, 48, 37, 10, 45, 121, 32, 45, 97, 32, 121,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  99, 117, 112, 51, 100, 32, 58, 32, 95, 114, 101, 115, 111, 108, 117, 116,
  105, 111, 110, 62, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73,
  110, 112, 117, 116, 32, 51, 100, 32, 99, 117, 112, 32, 111, 98, 106, 101,
  99, 116, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45,
  99, 117, 112, 51, 100, 32, 44, 10, 99, 117, 112, 51, 100, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 36, 123, 49, 61, 49, 50, 56, 125, 62,
  48, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116,
  32, 51, 100, 32, 99, 117, 112, 44, 32, 119, 105, 116, 104, 32, 114, 101,
  115, 111, 108, 117, 116, 105, 111, 110, 32, 36, 49, 46, 34, 10, 45, 118,
  32, 45, 10, 49, 48, 48, 44, 50, 48, 48, 10, 45, 101, 108, 108, 105,
  112, 115, 101, 91, 45, 49, 93, 32, 48, 37, 44, 48, 37, 44, 52, 48,
  37, 44, 52, 48, 37, 44, 48, 44, 49, 44, 49, 10, 45, 101, 108, 108,
  105, 112, 115, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 51, 53, 37,
  44, 51, 53, 37, 44, 48, 44, 49, 44, 48, 10, 45, 112, 111, 108, 121,
  103, 111, 110, 91, 45, 49, 93, 32, 52, 44, 48, 44, 52, 53, 37, 44,
  56, 37, 44, 52, 53, 37, 44, 50, 48, 37, 44, 57, 48, 37, 44, 48,
  44, 57, 48, 37, 44, 49, 44, 49, 10, 45, 101, 108, 108, 105, 112, 115,
  101, 91, 45, 49, 93, 32, 48, 37, 44, 49, 48, 48, 37, 44, 51, 48,
  37, 44, 49, 48, 37, 44, 48, 44, 49, 44, 49, 32, 45, 98, 91, 45,
  49, 93, 32, 48, 46, 49, 37, 10, 45, 108, 97, 116, 104, 101, 51, 100,
  91, 45, 49, 93, 32, 36, 49, 44, 50, 32, 45, 110, 109, 91, 45, 49,
  93, 32, 91, 51, 100, 92, 32, 99, 117, 112, 93, 10, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 99, 121, 108, 105, 110, 100, 101, 114,
  51, 100, 32, 58, 32, 95, 114, 97, 100, 105, 117, 115, 44, 95, 104, 101,
  105, 103, 104, 116, 44, 95, 110, 98, 95, 115, 117, 98, 100, 105, 118, 105,
  115, 105, 111, 110, 115, 62, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 73, 110, 112, 117, 116, 32, 51, 100, 32, 99, 121, 108, 105, 110, 100,
  101, 114, 32, 97, 116, 32, 40, 48, 44, 48, 44, 48, 41, 44, 32, 119,
  105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 103, 101,
  111, 109, 101, 116, 114, 121, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32,
  39, 114, 97, 100, 105, 117, 115, 61, 49, 39, 44, 39, 104, 101, 105, 103,
  104, 116, 61, 49, 39, 32, 97, 110, 100, 32, 39, 110, 98, 95, 115, 117,
  98, 100, 105, 118, 105, 115, 105, 111, 110, 115, 61, 50, 52, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 99, 121, 108, 105,
  110, 100, 101, 114, 51, 100, 32, 49, 48, 44, 52, 48, 32, 45, 45, 112,
  114, 105, 109, 105, 116, 105, 118, 101, 115, 51, 100, 32, 49, 32, 45, 99,
  111, 108, 111, 114, 51, 100, 91, 45, 50, 93, 32, 64, 123, 45, 82, 71,
  66, 125, 10, 99, 121, 108, 105, 110, 100, 101, 114, 51, 100, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 36, 123, 51, 61, 50, 52, 125, 62, 48,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 125, 44, 36, 123,
  50, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110,
  112, 117, 116, 32, 51, 100, 32, 99, 121, 108, 105, 110, 100, 101, 114, 44,
  32, 119, 105, 116, 104, 32, 114, 97, 100, 105, 117, 115, 32, 36, 49, 44,
  32, 104, 101, 105, 103, 104, 116, 32, 36, 50, 32, 97, 110, 100, 32, 36,
  51, 32, 115, 117, 98, 100, 105, 118, 105, 115, 105, 111, 110, 115, 46, 34,
  10, 45, 118, 32, 45, 10, 40, 54, 55, 46, 53, 59, 55, 51, 46, 53,
  59, 49, 48, 57, 46, 53, 59, 49, 48, 51, 46, 53, 59, 53, 49, 46,
  53, 59, 49, 48, 48, 46, 53, 41, 10, 40, 123, 50, 42, 36, 51, 43,
  50, 125, 59, 123, 51, 42, 36, 51, 125, 41, 10, 40, 48, 44, 48, 44,
  48, 59, 48, 44, 48, 44, 36, 50, 41, 10, 40, 48, 59, 123, 50, 42,
  112, 105, 125, 41, 32, 45, 114, 91, 45, 49, 93, 32, 49, 44, 123, 36,
  51, 43, 49, 125, 44, 49, 44, 49, 44, 51, 32, 45, 114, 111, 119, 115,
  91, 45, 49, 93, 32, 48, 44, 123, 36, 51, 45, 49, 125, 32, 45, 45,
  115, 105, 110, 91, 45, 49, 93, 32, 45, 99, 111, 115, 91, 45, 50, 93,
  32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 36, 49, 32, 45, 97,
  91, 45, 50, 44, 45, 49, 93, 32, 120, 10, 45, 45, 122, 91, 45, 49,
  93, 32, 48, 44, 50, 32, 49, 44, 36, 51, 44, 49, 44, 49, 44, 36,
  50, 32, 45, 97, 91, 45, 51, 44, 45, 49, 93, 32, 120, 10, 45, 97,
  91, 45, 51, 45, 45, 49, 93, 32, 121, 10, 49, 44, 36, 51, 44, 49,
  44, 49, 44, 39, 121, 39, 32, 45, 45, 115, 104, 105, 102, 116, 91, 45,
  49, 93, 32, 48, 44, 45, 49, 32, 45, 43, 91, 45, 50, 44, 45, 49,
  93, 32, 50, 10, 50, 44, 36, 51, 44, 49, 44, 49, 44, 51, 44, 49,
  32, 91, 45, 51, 93, 32, 91, 45, 51, 93, 32, 45, 97, 91, 45, 51,
  45, 45, 49, 93, 32, 120, 10, 50, 44, 36, 51, 44, 49, 44, 49, 44,
  51, 44, 48, 32, 91, 45, 51, 93, 32, 91, 45, 53, 93, 32, 45, 43,
  91, 45, 50, 44, 45, 49, 93, 32, 36, 51, 32, 45, 97, 91, 45, 51,
  45, 45, 49, 93, 32, 120, 10, 45, 45, 43, 91, 45, 52, 44, 45, 51,
  93, 32, 36, 51, 32, 45, 105, 91, 45, 55, 93, 32, 49, 44, 36, 51,
  44, 49, 44, 49, 44, 52, 32, 45, 114, 118, 91, 45, 54, 44, 45, 53,
  93, 32, 45, 97, 91, 45, 55, 45, 45, 53, 44, 45, 50, 44, 45, 49,
  93, 32, 120, 10, 51, 44, 123, 51, 42, 36, 51, 125, 44, 49, 44, 49,
  44, 50, 48, 48, 10, 49, 44, 123, 104, 125, 44, 49, 44, 49, 44, 49,
  10, 45, 121, 91, 45, 54, 45, 45, 50, 93, 32, 45, 97, 91, 45, 56,
  45, 45, 49, 93, 32, 121, 32, 45, 110, 109, 91, 45, 49, 93, 32, 91,
  51, 100, 92, 32, 99, 121, 108, 105, 110, 100, 101, 114, 93, 10, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 100, 105, 115, 116, 114, 105,
  98, 117, 116, 105, 111, 110, 51, 100, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 71, 101, 116, 32, 51, 100, 32, 99, 111, 108, 111, 114, 32, 100,
  105, 115, 116, 114, 105, 98, 117, 116, 105, 111, 110, 32, 111, 102, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 100, 105, 115, 116, 114, 105, 98, 117, 116, 105,
  111, 110, 51, 100, 32, 45, 99, 111, 108, 111, 114, 99, 117, 98, 101, 51,
  100, 32, 45, 112, 114, 105, 109, 105, 116, 105, 118, 101, 115, 51, 100, 91,
  45, 49, 93, 32, 49, 32, 45, 97, 100, 100, 51, 100, 10, 100, 105, 115,
  116, 114, 105, 98, 117, 116, 105, 111, 110, 51, 100, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 71, 101, 116, 32, 51, 100, 32, 99, 111,
  108, 111, 114, 32, 100, 105, 115, 116, 114, 105, 98, 117, 116, 105, 111, 110,
  32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 112, 101, 114, 109,
  117, 116, 101, 32, 34, 99, 120, 121, 122, 34, 32, 45, 121, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  110, 98, 112, 61, 123, 104, 47, 51, 125, 10, 45, 105, 91, 45, 50, 93,
  32, 40, 54, 55, 46, 53, 59, 55, 51, 46, 53, 59, 49, 48, 57, 46,
  53, 59, 49, 48, 51, 46, 53, 59, 53, 49, 46, 53, 59, 49, 48, 48,
  46, 53, 59, 92, 10, 36, 110, 98, 112, 59, 36, 110, 98, 112, 41, 10,
  40, 49, 44, 48, 59, 49, 44, 123, 36, 110, 98, 112, 45, 49, 125, 41,
  32, 45, 114, 91, 45, 49, 93, 32, 50, 44, 36, 110, 98, 112, 44, 49,
  44, 49, 44, 51, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32,
  49, 32, 45, 121, 91, 45, 49, 93, 10, 91, 45, 50, 93, 10, 49, 44,
  36, 110, 98, 112, 44, 49, 44, 49, 44, 49, 10, 45, 97, 32, 121, 32,
  45, 110, 109, 91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 100, 105, 115,
  116, 114, 105, 98, 117, 116, 105, 111, 110, 93, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109,
  105, 99, 32, 47, 51, 100, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32,
  39, 45, 100, 105, 118, 51, 100, 39, 46, 32, 58, 32, 40, 43, 41, 10,
  35, 64, 103, 109, 105, 99, 32, 100, 105, 118, 51, 100, 32, 58, 32, 102,
  97, 99, 116, 111, 114, 32, 58, 32, 102, 97, 99, 116, 111, 114, 95, 120,
  44, 102, 97, 99, 116, 111, 114, 95, 121, 44, 95, 102, 97, 99, 116, 111,
  114, 95, 122, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 83, 99, 97, 108, 101, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 115, 32, 105, 115, 111,
  116, 114, 111, 112, 105, 99, 97, 108, 108, 121, 32, 111, 114, 32, 97, 110,
  105, 115, 111, 116, 114, 111, 112, 105, 99, 97, 108, 108, 121, 44, 32, 119,
  105, 116, 104, 32, 116, 104, 101, 32, 105, 110, 118, 101, 114, 115, 101, 32,
  111, 102, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 102, 97, 99, 116, 111, 114, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32,
  39, 45, 47, 51, 100, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58,
  32, 39, 102, 97, 99, 116, 111, 114, 95, 122, 61, 48, 39, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 116, 111, 114, 117, 115,
  51, 100, 32, 53, 44, 50, 32, 45, 114, 101, 112, 101, 97, 116, 32, 53,
  32, 45, 45, 97, 100, 100, 51, 100, 91, 45, 49, 93, 32, 49, 50, 44,
  48, 44, 48, 32, 45, 100, 105, 118, 51, 100, 91, 45, 49, 93, 32, 49,
  46, 50, 32, 45, 99, 111, 108, 111, 114, 51, 100, 91, 45, 49, 93, 32,
  64, 123, 45, 82, 71, 66, 125, 32, 45, 100, 111, 110, 101, 32, 45, 97,
  100, 100, 51, 100, 10, 35, 64, 103, 109, 105, 99, 32, 100, 98, 51, 100,
  32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 100, 111, 117, 98,
  108, 101, 51, 100, 39, 46, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103,
  109, 105, 99, 32, 100, 111, 117, 98, 108, 101, 51, 100, 32, 58, 32, 95,
  105, 115, 95, 100, 111, 117, 98, 108, 101, 95, 115, 105, 100, 101, 100, 61,
  123, 32, 48, 32, 124, 32, 49, 32, 125, 32, 58, 32, 40, 43, 41, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 69, 110, 97, 98, 108, 101, 47,
  100, 105, 115, 97, 98, 108, 101, 32, 100, 111, 117, 98, 108, 101, 45, 115,
  105, 100, 101, 100, 32, 109, 111, 100, 101, 32, 102, 111, 114, 32, 51, 100,
  32, 114, 101, 110, 100, 101, 114, 105, 110, 103, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 100,
  98, 51, 100, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39,
  105, 115, 95, 100, 111, 117, 98, 108, 101, 95, 115, 105, 100, 101, 100, 61,
  49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45,
  109, 111, 100, 101, 51, 100, 32, 49, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 50, 32, 45, 116, 111, 114, 117, 115, 51, 100, 32, 49, 48, 48, 44,
  51, 48, 32, 45, 114, 111, 116, 97, 116, 101, 51, 100, 91, 45, 49, 93,
  32, 49, 44, 49, 44, 48, 44, 54, 48, 32, 45, 100, 111, 117, 98, 108,
  101, 51, 100, 32, 36, 62, 32, 45, 115, 110, 97, 112, 115, 104, 111, 116,
  51, 100, 91, 45, 49, 93, 32, 52, 48, 48, 32, 45, 100, 111, 110, 101,
  10, 35, 64, 103, 109, 105, 99, 32, 101, 108, 101, 118, 97, 116, 105, 111,
  110, 51, 100, 32, 58, 32, 122, 45, 102, 97, 99, 116, 111, 114, 32, 58,
  32, 91, 101, 108, 101, 118, 97, 116, 105, 111, 110, 95, 109, 97, 112, 93,
  32, 58, 32, 39, 102, 111, 114, 109, 117, 108, 97, 39, 32, 58, 32, 40,
  110, 111, 32, 97, 114, 103, 115, 41, 32, 58, 32, 40, 43, 41, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 66, 117, 105, 108, 100, 32, 51, 100,
  32, 101, 108, 101, 118, 97, 116, 105, 111, 110, 32, 111, 102, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 44, 32, 119,
  105, 116, 104, 32, 97, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  101, 108, 101, 118, 97, 116, 105, 111, 110, 32, 109, 97, 112, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 87, 104, 101, 110, 32, 105, 110, 118,
  111, 107, 101, 100, 32, 119, 105, 116, 104, 32, 40, 110, 111, 32, 97, 114,
  103, 115, 41, 32, 111, 114, 32, 39, 122, 45, 102, 97, 99, 116, 111, 114,
  39, 44, 32, 116, 104, 101, 32, 101, 108, 101, 118, 97, 116, 105, 111, 110,
  32, 109, 97, 112, 32, 105, 115, 32, 99, 111, 109, 112, 117, 116, 101, 100,
  32, 97, 115, 32, 116, 104, 101, 32, 112, 111, 105, 110, 116, 119, 105, 115,
  101, 32, 76, 50, 32, 110, 111, 114, 109, 32, 111, 102, 32, 116, 104, 101,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 112, 105, 120, 101, 108, 32,
  118, 97, 108, 117, 101, 115, 46, 32, 79, 116, 104, 101, 114, 119, 105, 115,
  101, 44, 32, 116, 104, 101, 32, 101, 108, 101, 118, 97, 116, 105, 111, 110,
  32, 109, 97, 112, 32, 105, 115, 32, 116, 97, 107, 101, 110, 32, 102, 114,
  111, 109, 32, 116, 104, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100,
  32, 105, 109, 97, 103, 101, 32, 111, 114, 32, 102, 111, 114, 109, 117, 108,
  97, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 98, 108, 117, 114, 32, 53, 32,
  45, 101, 108, 101, 118, 97, 116, 105, 111, 110, 51, 100, 32, 48, 46, 53,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 49, 50, 56, 44,
  49, 50, 56, 44, 49, 44, 51, 44, 63, 40, 50, 53, 53, 41, 32, 45,
  112, 108, 97, 115, 109, 97, 32, 49, 48, 44, 51, 32, 45, 98, 108, 117,
  114, 32, 52, 32, 45, 115, 104, 97, 114, 112, 101, 110, 32, 49, 48, 48,
  48, 48, 32, 45, 101, 108, 101, 118, 97, 116, 105, 111, 110, 51, 100, 91,
  45, 49, 93, 32, 39, 88, 61, 40, 120, 45, 54, 52, 41, 47, 54, 59,
  89, 61, 40, 121, 45, 54, 52, 41, 47, 54, 59, 49, 48, 48, 42, 101,
  120, 112, 40, 45, 40, 88, 94, 50, 43, 89, 94, 50, 41, 47, 51, 48,
  41, 42, 97, 98, 115, 40, 99, 111, 115, 40, 88, 41, 42, 115, 105, 110,
  40, 89, 41, 41, 39, 10, 35, 64, 103, 109, 105, 99, 32, 101, 109, 112,
  116, 121, 51, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 110,
  112, 117, 116, 32, 101, 109, 112, 116, 121, 32, 51, 100, 32, 111, 98, 106,
  101, 99, 116, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  45, 101, 109, 112, 116, 121, 51, 100, 10, 101, 109, 112, 116, 121, 51, 100,
  32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117,
  116, 32, 101, 109, 112, 116, 121, 32, 51, 100, 32, 111, 98, 106, 101, 99,
  116, 46, 34, 10, 45, 118, 32, 45, 32, 40, 54, 55, 46, 53, 59, 55,
  51, 46, 53, 59, 49, 48, 57, 46, 53, 59, 49, 48, 51, 46, 53, 59,
  53, 49, 46, 53, 59, 49, 48, 48, 46, 53, 59, 48, 59, 48, 41, 32,
  45, 110, 109, 91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 101, 109, 112,
  116, 121, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  101, 120, 116, 114, 117, 100, 101, 51, 100, 32, 58, 32, 95, 100, 101, 112,
  116, 104, 62, 48, 44, 95, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110,
  62, 48, 44, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 91, 37,
  93, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 71, 101,
  110, 101, 114, 97, 116, 101, 32, 101, 120, 116, 114, 117, 100, 101, 100, 32,
  51, 100, 32, 111, 98, 106, 101, 99, 116, 32, 102, 114, 111, 109, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 98, 105, 110, 97, 114, 121, 32, 88,
  89, 45, 112, 114, 111, 102, 105, 108, 101, 115, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108,
  117, 101, 115, 58, 32, 39, 100, 101, 112, 116, 104, 61, 49, 54, 39, 44,
  32, 39, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 61, 49, 48, 50,
  52, 39, 32, 97, 110, 100, 32, 39, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 61, 48, 46, 53, 37, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 53, 48, 37, 32, 45, 101,
  120, 116, 114, 117, 100, 101, 51, 100, 32, 49, 54, 10, 101, 120, 116, 114,
  117, 100, 101, 51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  36, 123, 49, 61, 49, 54, 125, 62, 48, 32, 38, 38, 32, 36, 123, 50,
  61, 49, 48, 50, 52, 125, 62, 48, 32, 38, 38, 32, 36, 123, 51, 61,
  48, 46, 53, 37, 125, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 71, 101, 110, 101, 114, 97, 116, 101, 32, 101, 120, 116, 114,
  117, 100, 101, 100, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 32, 102,
  114, 111, 109, 32, 88, 89, 45, 112, 114, 111, 102, 105, 108, 101, 36, 63,
  44, 32, 119, 105, 116, 104, 32, 100, 101, 112, 116, 104, 32, 36, 49, 44,
  32, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 32, 36, 50, 32, 97,
  110, 100, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 51,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 110, 111, 114, 109, 32, 45, 110,
  32, 48, 44, 49, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 48,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 119, 114, 61,
  123, 114, 111, 117, 110, 100, 40, 109, 97, 120, 40, 49, 44, 105, 102, 40,
  119, 62, 104, 44, 109, 105, 110, 40, 36, 50, 44, 119, 41, 44, 109, 105,
  110, 40, 36, 50, 44, 104, 41, 42, 119, 47, 104, 41, 41, 41, 125, 10,
  104, 114, 61, 123, 114, 111, 117, 110, 100, 40, 109, 97, 120, 40, 49, 44,
  105, 102, 40, 119, 62, 104, 44, 109, 105, 110, 40, 36, 50, 44, 119, 41,
  42, 104, 47, 119, 44, 109, 105, 110, 40, 36, 50, 44, 104, 41, 41, 41,
  41, 125, 10, 102, 97, 99, 116, 61, 123, 36, 49, 47, 109, 97, 120, 40,
  119, 47, 36, 119, 114, 44, 104, 47, 36, 104, 114, 41, 125, 10, 45, 98,
  32, 36, 51, 44, 48, 32, 45, 114, 32, 36, 119, 114, 44, 36, 104, 114,
  44, 49, 44, 49, 44, 50, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120,
  121, 122, 32, 49, 44, 48, 10, 45, 105, 115, 111, 115, 117, 114, 102, 97,
  99, 101, 51, 100, 32, 53, 48, 37, 32, 45, 42, 51, 100, 32, 49, 44,
  49, 44, 36, 102, 97, 99, 116, 32, 45, 114, 118, 51, 100, 10, 45, 110,
  109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  102, 51, 100, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 102,
  111, 99, 97, 108, 101, 51, 100, 39, 46, 32, 58, 32, 40, 43, 41, 10,
  35, 64, 103, 109, 105, 99, 32, 102, 111, 99, 97, 108, 101, 51, 100, 32,
  58, 32, 102, 111, 99, 97, 108, 101, 32, 58, 32, 40, 43, 41, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 83, 101, 116, 32, 51, 100, 32, 102,
  111, 99, 97, 108, 101, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 102, 51, 100, 39, 41, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 101, 116, 32, 39, 102,
  111, 99, 97, 108, 101, 39, 32, 116, 111, 32, 48, 32, 116, 111, 32, 101,
  110, 97, 98, 108, 101, 32, 112, 97, 114, 97, 108, 108, 101, 108, 32, 112,
  114, 111, 106, 101, 99, 116, 105, 111, 110, 32, 40, 105, 110, 115, 116, 101,
  97, 100, 32, 111, 102, 32, 112, 101, 114, 115, 112, 101, 99, 116, 105, 118,
  101, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 101, 116,
  32, 110, 101, 103, 97, 116, 105, 118, 101, 32, 39, 102, 111, 99, 97, 108,
  101, 39, 32, 119, 105, 108, 108, 32, 100, 105, 115, 97, 98, 108, 101, 32,
  51, 100, 32, 115, 112, 114, 105, 116, 101, 32, 122, 111, 111, 109, 105, 110,
  103, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 102, 111, 99, 97,
  108, 101, 61, 55, 48, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 45, 114, 101, 112, 101, 97, 116, 32, 53, 32, 45, 116,
  111, 114, 117, 115, 51, 100, 32, 49, 48, 48, 44, 51, 48, 32, 45, 114,
  111, 116, 97, 116, 101, 51, 100, 91, 45, 49, 93, 32, 49, 44, 49, 44,
  48, 44, 54, 48, 32, 45, 102, 111, 99, 97, 108, 101, 51, 100, 32, 123,
  36, 60, 42, 57, 48, 125, 32, 45, 115, 110, 97, 112, 115, 104, 111, 116,
  51, 100, 91, 45, 49, 93, 32, 52, 48, 48, 32, 45, 100, 111, 110, 101,
  32, 45, 114, 101, 109, 111, 118, 101, 91, 48, 93, 10, 35, 64, 103, 109,
  105, 99, 32, 103, 97, 117, 115, 115, 105, 97, 110, 115, 51, 100, 32, 58,
  32, 95, 115, 105, 122, 101, 62, 48, 44, 95, 111, 112, 97, 99, 105, 116,
  121, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101,
  114, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 51, 100, 32, 111,
  98, 106, 101, 99, 116, 115, 32, 105, 110, 116, 111, 32, 115, 101, 116, 32,
  111, 102, 32, 51, 100, 32, 103, 97, 117, 115, 115, 105, 97, 110, 45, 115,
  104, 97, 112, 101, 100, 32, 115, 112, 114, 105, 116, 101, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 114, 50, 100, 121, 32, 51, 50, 32, 45, 100, 105,
  115, 116, 114, 105, 98, 117, 116, 105, 111, 110, 51, 100, 32, 45, 103, 97,
  117, 115, 115, 105, 97, 110, 115, 51, 100, 32, 50, 48, 32, 45, 99, 111,
  108, 111, 114, 99, 117, 98, 101, 51, 100, 32, 45, 112, 114, 105, 109, 105,
  116, 105, 118, 101, 115, 51, 100, 91, 45, 49, 93, 32, 49, 32, 45, 43,
  51, 100, 10, 103, 97, 117, 115, 115, 105, 97, 110, 115, 51, 100, 32, 58,
  32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 51, 50, 125,
  62, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 48, 46,
  51, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118,
  101, 114, 116, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 36, 63, 32,
  105, 110, 116, 111, 32, 115, 101, 116, 115, 32, 111, 102, 32, 103, 97, 117,
  115, 115, 105, 97, 110, 45, 115, 104, 97, 112, 101, 100, 32, 51, 100, 32,
  115, 112, 114, 105, 116, 101, 115, 44, 32, 119, 105, 116, 104, 32, 115, 105,
  122, 101, 32, 36, 49, 32, 97, 110, 100, 32, 111, 112, 97, 99, 105, 116,
  121, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 45, 112, 51, 100,
  32, 50, 32, 45, 112, 51, 100, 32, 48, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64,
  123, 48, 44, 110, 125, 32, 45, 115, 51, 100, 10, 110, 98, 118, 61, 123,
  104, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 40, 45, 49, 50, 56,
  59, 36, 49, 59, 36, 49, 59, 49, 41, 10, 36, 49, 44, 36, 49, 32,
  45, 103, 97, 117, 115, 115, 105, 97, 110, 91, 45, 49, 93, 32, 51, 53,
  37, 44, 51, 53, 37, 44, 48, 32, 45, 99, 91, 45, 49, 93, 32, 51,
  48, 37, 44, 49, 48, 48, 37, 32, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 36, 50, 32, 45, 121, 91, 45, 49, 93, 32, 45, 97, 91, 45, 50,
  44, 45, 49, 93, 32, 121, 10, 45, 105, 102, 32, 123, 36, 110, 98, 118,
  62, 49, 125, 32, 52, 44, 123, 36, 110, 98, 118, 45, 49, 125, 44, 49,
  44, 49, 44, 45, 49, 50, 56, 44, 48, 44, 48, 44, 48, 32, 45, 121,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 97, 91, 45, 50, 44, 45, 49,
  93, 32, 121, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 32, 121, 10,
  45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 103, 109, 105, 99, 51, 100, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 73, 110, 112, 117, 116, 32, 97, 32, 51, 100, 32, 71, 39, 77,
  73, 67, 32, 108, 111, 103, 111, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 45, 103, 109, 105, 99, 51, 100, 32, 45, 45, 112, 114,
  105, 109, 105, 116, 105, 118, 101, 115, 51, 100, 32, 49, 10, 103, 109, 105,
  99, 51, 100, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73,
  110, 112, 117, 116, 32, 51, 100, 32, 71, 39, 77, 73, 67, 32, 108, 111,
  103, 111, 46, 34, 10, 45, 118, 32, 45, 10, 45, 116, 101, 120, 116, 51,
  100, 32, 71, 44, 54, 48, 44, 50, 48, 44, 50, 32, 45, 99, 111, 108,
  51, 100, 91, 45, 49, 93, 32, 49, 54, 44, 54, 52, 44, 50, 53, 53,
  10, 45, 116, 101, 120, 116, 51, 100, 32, 92, 39, 44, 54, 48, 44, 50,
  48, 44, 50, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 51, 48, 32,
  45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 54, 52, 44, 49, 50,
  56, 44, 50, 53, 53, 10, 45, 116, 101, 120, 116, 51, 100, 32, 77, 44,
  54, 48, 44, 50, 48, 44, 50, 32, 45, 43, 51, 100, 91, 45, 49, 93,
  32, 52, 48, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 57,
  54, 44, 49, 57, 54, 44, 50, 53, 53, 10, 45, 116, 101, 120, 116, 51,
  100, 32, 73, 44, 54, 48, 44, 50, 48, 44, 50, 32, 45, 43, 51, 100,
  91, 45, 49, 93, 32, 55, 48, 32, 45, 99, 111, 108, 51, 100, 91, 45,
  49, 93, 32, 54, 52, 44, 49, 50, 56, 44, 50, 53, 53, 10, 45, 116,
  101, 120, 116, 51, 100, 32, 67, 44, 54, 48, 44, 50, 48, 44, 50, 32,
  45, 43, 51, 100, 91, 45, 49, 93, 32, 57, 53, 32, 45, 99, 111, 108,
  51, 100, 91, 45, 49, 93, 32, 49, 54, 44, 54, 52, 44, 50, 53, 53,
  10, 45, 115, 112, 104, 101, 114, 101, 51, 100, 32, 56, 32, 45, 43, 51,
  100, 91, 45, 49, 93, 32, 56, 53, 44, 45, 49, 48, 44, 49, 53, 32,
  45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 49, 57, 50, 44, 49,
  50, 56, 44, 50, 53, 53, 10, 45, 43, 51, 100, 91, 45, 54, 45, 45,
  49, 93, 32, 45, 99, 51, 100, 91, 45, 49, 93, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 51, 48, 10, 45, 98, 111, 120, 51, 100, 32, 123, 109,
  105, 110, 40, 51, 43, 64, 123, 60, 44, 45, 49, 125, 47, 50, 44, 49,
  48, 41, 125, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 123,
  51, 48, 42, 36, 62, 125, 44, 123, 50, 48, 43, 56, 48, 42, 36, 62,
  125, 44, 123, 49, 48, 42, 36, 62, 125, 44, 48, 46, 53, 10, 45, 114,
  51, 100, 91, 45, 49, 93, 32, 49, 44, 49, 44, 49, 44, 123, 36, 62,
  42, 49, 50, 125, 10, 45, 43, 51, 100, 91, 45, 49, 93, 32, 123, 56,
  48, 42, 99, 111, 115, 40, 48, 46, 53, 43, 49, 46, 48, 50, 42, 36,
  62, 42, 49, 50, 42, 112, 105, 47, 49, 56, 48, 41, 125, 44, 123, 51,
  48, 42, 115, 105, 110, 40, 48, 46, 56, 43, 36, 62, 42, 49, 50, 42,
  112, 105, 47, 49, 56, 48, 41, 125, 44, 123, 50, 42, 36, 62, 45, 55,
  53, 125, 10, 45, 100, 111, 110, 101, 10, 45, 43, 51, 100, 91, 45, 51,
  48, 45, 45, 49, 93, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 48,
  44, 53, 44, 51, 48, 32, 45, 43, 51, 100, 91, 45, 50, 45, 45, 49,
  93, 32, 45, 110, 109, 91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 103,
  109, 105, 99, 93, 10, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 103, 121, 114, 111, 105, 100, 51, 100, 32, 58, 32, 95, 114, 101, 115,
  111, 108, 117, 116, 105, 111, 110, 62, 48, 44, 95, 122, 111, 111, 109, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 110, 112, 117, 116, 32, 51,
  100, 32, 103, 121, 114, 111, 105, 100, 32, 97, 116, 32, 40, 48, 44, 48,
  44, 48, 41, 44, 32, 119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102,
  105, 101, 100, 32, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116,
  32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 114, 101, 115, 111, 108, 117,
  116, 105, 111, 110, 61, 51, 50, 39, 32, 97, 110, 100, 32, 39, 122, 111,
  111, 109, 61, 53, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 45, 103, 121, 114, 111, 105, 100, 51, 100, 32, 52, 56, 32, 45,
  45, 112, 114, 105, 109, 105, 116, 105, 118, 101, 115, 51, 100, 32, 49, 10,
  103, 121, 114, 111, 105, 100, 51, 100, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 36, 123, 49, 61, 51, 50, 125, 62, 48, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 50, 61, 53, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 73, 110, 112, 117, 116, 32, 51, 100, 32, 103, 121, 114, 111, 105,
  100, 44, 32, 119, 105, 116, 104, 32, 114, 101, 115, 111, 108, 117, 116, 105,
  111, 110, 32, 36, 49, 32, 97, 110, 100, 32, 114, 97, 110, 103, 101, 32,
  36, 50, 46, 34, 10, 45, 118, 32, 45, 10, 45, 105, 115, 111, 115, 117,
  114, 102, 97, 99, 101, 51, 100, 32, 34, 39, 48, 46, 52, 57, 42, 40,
  92, 10, 99, 111, 115, 40, 32, 50, 42, 120, 32, 43, 32, 121, 32, 43,
  32, 122, 32, 45, 32, 112, 105, 41, 32, 43, 32, 99, 111, 115, 40, 32,
  50, 42, 120, 32, 45, 32, 121, 32, 43, 32, 122, 32, 45, 32, 112, 105,
  41, 92, 10, 43, 32, 99, 111, 115, 40, 45, 32, 50, 42, 120, 32, 43,
  32, 121, 32, 45, 32, 122, 32, 45, 32, 112, 105, 41, 32, 43, 32, 99,
  111, 115, 40, 45, 32, 50, 42, 120, 32, 45, 32, 121, 32, 45, 32, 122,
  32, 45, 32, 112, 105, 41, 92, 10, 43, 32, 99, 111, 115, 40, 32, 120,
  32, 43, 32, 50, 42, 121, 32, 43, 32, 122, 32, 45, 32, 112, 105, 41,
  32, 43, 32, 99, 111, 115, 40, 32, 120, 32, 43, 32, 50, 42, 121, 32,
  45, 32, 122, 32, 45, 32, 112, 105, 41, 92, 10, 43, 32, 99, 111, 115,
  40, 45, 32, 120, 32, 45, 32, 50, 42, 121, 32, 43, 32, 122, 32, 45,
  32, 112, 105, 41, 32, 43, 32, 99, 111, 115, 40, 45, 32, 120, 32, 45,
  32, 50, 42, 121, 32, 45, 32, 122, 32, 45, 32, 112, 105, 41, 92, 10,
  43, 32, 99, 111, 115, 40, 32, 120, 32, 43, 32, 121, 32, 43, 32, 50,
  42, 122, 32, 45, 32, 112, 105, 41, 32, 43, 32, 99, 111, 115, 40, 45,
  32, 120, 32, 43, 32, 121, 32, 43, 32, 50, 42, 122, 32, 45, 32, 112,
  105, 41, 92, 10, 43, 32, 99, 111, 115, 40, 32, 120, 32, 45, 32, 121,
  32, 45, 32, 50, 42, 122, 32, 45, 32, 112, 105, 41, 32, 43, 32, 99,
  111, 115, 40, 45, 32, 120, 32, 45, 32, 121, 32, 45, 32, 50, 42, 122,
  32, 45, 32, 112, 105, 41, 92, 10, 43, 32, 99, 111, 115, 40, 45, 32,
  50, 42, 120, 32, 43, 32, 121, 32, 43, 32, 122, 41, 32, 43, 32, 99,
  111, 115, 40, 32, 50, 42, 120, 32, 43, 32, 121, 32, 45, 32, 122, 41,
  92, 10, 43, 32, 99, 111, 115, 40, 45, 32, 50, 42, 120, 32, 45, 32,
  121, 32, 43, 32, 122, 41, 32, 43, 32, 99, 111, 115, 40, 32, 50, 42,
  120, 32, 45, 32, 121, 32, 45, 32, 122, 41, 92, 10, 43, 32, 99, 111,
  115, 40, 45, 32, 120, 32, 43, 32, 50, 42, 121, 32, 43, 32, 122, 41,
  32, 43, 32, 99, 111, 115, 40, 32, 120, 32, 45, 32, 50, 42, 121, 32,
  43, 32, 122, 41, 92, 10, 43, 32, 99, 111, 115, 40, 45, 32, 120, 32,
  43, 32, 50, 42, 121, 32, 45, 32, 122, 41, 32, 43, 32, 99, 111, 115,
  40, 32, 120, 32, 45, 32, 50, 42, 121, 32, 45, 32, 122, 41, 92, 10,
  43, 32, 99, 111, 115, 40, 32, 120, 32, 45, 32, 121, 32, 43, 32, 50,
  42, 122, 41, 32, 43, 32, 99, 111, 115, 40, 32, 120, 32, 43, 32, 121,
  32, 45, 32, 50, 42, 122, 41, 92, 10, 43, 32, 99, 111, 115, 40, 45,
  32, 120, 32, 45, 32, 121, 32, 43, 32, 50, 42, 122, 41, 32, 43, 32,
  99, 111, 115, 40, 45, 32, 120, 32, 43, 32, 121, 32, 45, 32, 50, 42,
  122, 41, 92, 10, 41, 32, 43, 32, 48, 46, 50, 55, 42, 40, 32, 92,
  10, 99, 111, 115, 40, 45, 32, 50, 42, 120, 32, 43, 32, 50, 42, 121,
  32, 45, 32, 112, 105, 41, 32, 43, 32, 99, 111, 115, 40, 32, 50, 42,
  120, 32, 45, 32, 50, 42, 121, 32, 45, 32, 112, 105, 41, 92, 10, 43,
  32, 99, 111, 115, 40, 32, 50, 42, 120, 32, 43, 32, 50, 42, 121, 32,
  45, 32, 112, 105, 41, 32, 43, 32, 99, 111, 115, 40, 45, 32, 50, 42,
  120, 32, 45, 32, 50, 42, 121, 32, 45, 32, 112, 105, 41, 92, 10, 43,
  32, 99, 111, 115, 40, 45, 32, 50, 42, 121, 32, 43, 32, 50, 42, 122,
  32, 45, 32, 112, 105, 41, 32, 43, 32, 99, 111, 115, 40, 32, 50, 42,
  121, 32, 45, 32, 50, 42, 122, 32, 45, 32, 112, 105, 41, 92, 10, 43,
  32, 99, 111, 115, 40, 32, 50, 42, 121, 32, 43, 32, 50, 42, 122, 32,
  45, 32, 112, 105, 41, 32, 43, 32, 99, 111, 115, 40, 45, 32, 50, 42,
  121, 32, 45, 32, 50, 42, 122, 32, 45, 32, 112, 105, 41, 92, 10, 43,
  32, 99, 111, 115, 40, 45, 32, 50, 42, 122, 32, 43, 32, 50, 42, 120,
  32, 45, 32, 112, 105, 41, 32, 43, 32, 99, 111, 115, 40, 32, 50, 42,
  122, 32, 45, 32, 50, 42, 120, 32, 45, 32, 112, 105, 41, 92, 10, 43,
  32, 99, 111, 115, 40, 32, 50, 42, 122, 32, 43, 32, 50, 42, 120, 32,
  45, 32, 112, 105, 41, 32, 43, 32, 99, 111, 115, 40, 45, 32, 50, 42,
  122, 32, 45, 32, 50, 42, 120, 32, 45, 32, 112, 105, 41, 92, 10, 41,
  32, 45, 32, 48, 46, 54, 57, 39, 34, 44, 48, 44, 123, 45, 36, 50,
  125, 44, 123, 45, 36, 50, 125, 44, 123, 45, 36, 50, 125, 44, 36, 50,
  44, 36, 50, 44, 36, 50, 44, 36, 49, 44, 36, 49, 44, 36, 49, 10,
  45, 99, 51, 100, 91, 45, 49, 93, 32, 45, 110, 51, 100, 91, 45, 49,
  93, 32, 45, 110, 109, 91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 103,
  121, 114, 111, 105, 100, 93, 10, 45, 118, 32, 43, 10, 35, 64, 103, 109,
  105, 99, 32, 104, 105, 115, 116, 111, 103, 114, 97, 109, 51, 100, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 71, 101, 116, 32, 51, 100, 32, 99,
  111, 108, 111, 114, 32, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 111,
  102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 104, 105, 115, 116, 111, 103, 114,
  97, 109, 51, 100, 32, 45, 99, 111, 108, 111, 114, 99, 117, 98, 101, 51,
  100, 32, 45, 112, 114, 105, 109, 105, 116, 105, 118, 101, 115, 51, 100, 91,
  45, 49, 93, 32, 49, 32, 45, 97, 100, 100, 51, 100, 10, 104, 105, 115,
  116, 111, 103, 114, 97, 109, 51, 100, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 71, 101, 116, 32, 51, 100, 32, 99, 111, 108, 111, 114,
  32, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 111, 102, 32, 105, 109,
  97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 116, 111,
  95, 114, 103, 98, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 114, 32, 123, 119, 42, 104, 125, 44,
  51, 44, 49, 44, 49, 44, 45, 49, 32, 45, 112, 111, 105, 110, 116, 99,
  108, 111, 117, 100, 32, 49, 32, 45, 110, 32, 48, 44, 50, 53, 53, 32,
  45, 109, 97, 112, 32, 51, 32, 45, 112, 111, 105, 110, 116, 99, 108, 111,
  117, 100, 51, 100, 32, 45, 110, 109, 32, 34, 91, 51, 100, 32, 104, 105,
  115, 116, 111, 103, 114, 97, 109, 93, 34, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 105, 109, 97, 103, 101, 54, 99, 117, 98, 101, 51, 100, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 71, 101, 110, 101, 114, 97, 116, 101,
  32, 51, 100, 32, 109, 97, 112, 112, 101, 100, 32, 99, 117, 98, 101, 115,
  32, 102, 114, 111, 109, 32, 54, 45, 115, 101, 116, 115, 32, 111, 102, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 97, 110, 105, 109, 97, 116, 101, 32, 102,
  108, 111, 119, 101, 114, 44, 34, 51, 48, 44, 48, 34, 44, 34, 51, 48,
  44, 53, 34, 44, 54, 32, 45, 105, 109, 97, 103, 101, 54, 99, 117, 98,
  101, 51, 100, 10, 105, 109, 97, 103, 101, 54, 99, 117, 98, 101, 51, 100,
  32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 71, 101, 110, 101,
  114, 97, 116, 101, 32, 51, 100, 32, 109, 97, 112, 112, 101, 100, 32, 99,
  117, 98, 101, 115, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36,
  63, 46, 34, 10, 45, 118, 32, 45, 32, 77, 61, 123, 109, 97, 120, 40,
  64, 123, 45, 109, 97, 120, 95, 119, 104, 125, 41, 125, 32, 45, 114, 32,
  36, 77, 44, 36, 77, 44, 49, 44, 51, 32, 45, 105, 109, 97, 103, 101,
  112, 108, 97, 110, 101, 51, 100, 32, 45, 110, 51, 100, 32, 45, 99, 51,
  100, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64,
  35, 47, 54, 41, 125, 10, 45, 43, 51, 100, 91, 45, 54, 93, 32, 48,
  44, 48, 44, 45, 48, 46, 53, 10, 45, 114, 51, 100, 91, 45, 53, 93,
  32, 49, 44, 48, 44, 48, 44, 49, 56, 48, 32, 45, 43, 51, 100, 91,
  45, 53, 93, 32, 48, 44, 48, 44, 48, 46, 53, 10, 45, 114, 51, 100,
  91, 45, 52, 93, 32, 48, 44, 49, 44, 48, 44, 45, 57, 48, 32, 45,
  43, 51, 100, 91, 45, 52, 93, 32, 45, 48, 46, 53, 44, 48, 44, 48,
  10, 45, 114, 51, 100, 91, 45, 51, 93, 32, 48, 44, 49, 44, 48, 44,
  57, 48, 32, 45, 43, 51, 100, 91, 45, 51, 93, 32, 48, 46, 53, 44,
  48, 44, 48, 10, 45, 114, 51, 100, 91, 45, 50, 93, 32, 49, 44, 48,
  44, 48, 44, 57, 48, 32, 45, 43, 51, 100, 91, 45, 50, 93, 32, 48,
  44, 45, 48, 46, 53, 44, 48, 10, 45, 114, 51, 100, 91, 45, 49, 93,
  32, 49, 44, 48, 44, 48, 44, 45, 57, 48, 32, 45, 43, 51, 100, 91,
  45, 49, 93, 32, 48, 44, 48, 46, 53, 44, 48, 10, 45, 43, 51, 100,
  91, 45, 54, 45, 45, 49, 93, 32, 45, 110, 109, 91, 45, 49, 93, 32,
  34, 91, 51, 100, 32, 105, 109, 97, 103, 101, 32, 99, 117, 98, 101, 93,
  34, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 105, 109,
  97, 103, 101, 98, 108, 111, 99, 107, 115, 51, 100, 32, 58, 32, 95, 109,
  97, 120, 105, 109, 117, 109, 95, 101, 108, 101, 118, 97, 116, 105, 111, 110,
  44, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 91, 37, 93, 62,
  61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 71, 101, 110, 101,
  114, 97, 116, 101, 32, 51, 100, 32, 98, 108, 111, 99, 107, 115, 32, 102,
  114, 111, 109, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 84, 114,
  97, 110, 115, 112, 97, 114, 101, 110, 99, 121, 32, 111, 102, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 105, 115,
  32, 116, 97, 107, 101, 110, 32, 105, 110, 116, 111, 32, 97, 99, 99, 111,
  117, 110, 116, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101,
  102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 109,
  97, 120, 105, 109, 117, 109, 95, 101, 108, 101, 118, 97, 116, 105, 111, 110,
  61, 49, 48, 39, 32, 97, 110, 100, 32, 39, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114,
  101, 115, 105, 122, 101, 50, 100, 121, 32, 51, 50, 32, 45, 105, 109, 97,
  103, 101, 98, 108, 111, 99, 107, 115, 51, 100, 32, 45, 50, 48, 32, 45,
  109, 51, 100, 32, 51, 10, 105, 109, 97, 103, 101, 98, 108, 111, 99, 107,
  115, 51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 123, 50,
  61, 48, 125, 62, 61, 48, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49,
  61, 49, 48, 125, 44, 36, 123, 51, 61, 48, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 71, 101, 110, 101, 114, 97, 116, 101, 32, 51, 100,
  32, 98, 108, 111, 99, 107, 115, 32, 102, 114, 111, 109, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 109, 97, 120, 105, 109,
  117, 109, 32, 101, 108, 101, 118, 97, 116, 105, 111, 110, 32, 36, 49, 32,
  97, 110, 100, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36,
  50, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 61, 123, 119, 125,
  32, 104, 61, 123, 104, 125, 10, 45, 115, 112, 108, 105, 116, 95, 111, 112,
  97, 99, 105, 116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93,
  32, 105, 115, 95, 111, 112, 97, 99, 105, 116, 121, 61, 123, 64, 35, 61,
  61, 50, 125, 10, 45, 108, 91, 93, 32, 45, 98, 111, 120, 51, 100, 32,
  49, 44, 49, 44, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36,
  119, 45, 49, 125, 32, 45, 45, 43, 51, 100, 91, 45, 49, 93, 32, 49,
  44, 48, 44, 48, 32, 45, 100, 111, 110, 101, 32, 45, 43, 51, 100, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 104, 45, 49, 125, 32, 45,
  45, 43, 51, 100, 91, 45, 49, 93, 32, 48, 44, 49, 44, 48, 32, 45,
  100, 111, 110, 101, 32, 45, 43, 51, 100, 10, 45, 101, 110, 100, 108, 10,
  45, 115, 51, 100, 91, 45, 49, 93, 10, 45, 45, 110, 111, 114, 109, 91,
  48, 93, 32, 45, 98, 91, 45, 49, 93, 32, 36, 50, 10, 45, 121, 91,
  45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 36, 49, 10,
  45, 114, 91, 45, 53, 93, 32, 50, 52, 44, 64, 123, 45, 53, 44, 114,
  111, 117, 110, 100, 40, 119, 42, 104, 47, 50, 52, 41, 125, 44, 49, 44,
  49, 44, 45, 49, 10, 45, 105, 102, 32, 123, 36, 49, 60, 48, 125, 32,
  45, 106, 91, 45, 53, 93, 32, 91, 45, 49, 93, 44, 50, 32, 45, 106,
  91, 45, 53, 93, 32, 91, 45, 49, 93, 44, 53, 32, 45, 106, 91, 45,
  53, 93, 32, 91, 45, 49, 93, 44, 56, 32, 45, 106, 91, 45, 53, 93,
  32, 91, 45, 49, 93, 44, 49, 49, 10, 45, 101, 108, 115, 101, 32, 45,
  106, 91, 45, 53, 93, 32, 91, 45, 49, 93, 44, 49, 52, 32, 45, 106,
  91, 45, 53, 93, 32, 91, 45, 49, 93, 44, 49, 55, 32, 45, 106, 91,
  45, 53, 93, 32, 91, 45, 49, 93, 44, 50, 48, 32, 45, 106, 91, 45,
  53, 93, 32, 91, 45, 49, 93, 44, 50, 51, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 121, 91, 45, 52, 93,
  10, 45, 114, 109, 91, 45, 50, 93, 32, 45, 114, 91, 48, 93, 32, 64,
  123, 48, 44, 119, 42, 104, 125, 44, 49, 44, 49, 44, 49, 48, 48, 37,
  44, 45, 49, 32, 45, 112, 101, 114, 109, 117, 116, 101, 91, 48, 93, 32,
  99, 120, 121, 122, 32, 45, 114, 91, 48, 93, 32, 54, 48, 48, 37, 44,
  49, 48, 48, 37, 44, 49, 44, 49, 44, 48, 44, 50, 32, 45, 121, 91,
  48, 93, 32, 45, 109, 118, 91, 48, 93, 32, 45, 49, 10, 45, 105, 102,
  32, 36, 105, 115, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 109, 118, 91, 48, 93, 32, 64, 35, 32, 45,
  47, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 121, 91, 45, 49, 93,
  32, 45, 114, 91, 45, 49, 93, 32, 54, 44, 49, 48, 48, 37, 44, 49,
  44, 49, 32, 45, 121, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 97, 32, 121, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 105, 109,
  97, 103, 101, 99, 117, 98, 101, 51, 100, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 71, 101, 110, 101, 114, 97, 116, 101, 32, 51, 100, 32, 109,
  97, 112, 112, 101, 100, 32, 99, 117, 98, 101, 115, 32, 102, 114, 111, 109,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 105, 109, 97, 103, 101, 99, 117, 98,
  101, 51, 100, 10, 105, 109, 97, 103, 101, 99, 117, 98, 101, 51, 100, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 71, 101, 110, 101, 114,
  97, 116, 101, 32, 51, 100, 32, 109, 97, 112, 112, 101, 100, 32, 99, 117,
  98, 101, 115, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36, 63,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 115, 108, 105, 99, 101, 115, 32,
  53, 48, 37, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109,
  61, 64, 123, 48, 44, 110, 125, 10, 119, 49, 61, 123, 119, 45, 49, 125,
  32, 104, 49, 61, 123, 104, 45, 49, 125, 10, 45, 105, 91, 45, 50, 93,
  32, 40, 54, 55, 46, 53, 59, 55, 51, 46, 53, 59, 49, 48, 57, 46,
  53, 59, 49, 48, 51, 46, 53, 59, 53, 49, 46, 53, 59, 49, 48, 48,
  46, 53, 59, 92, 10, 56, 59, 54, 59, 92, 10, 45, 48, 46, 53, 59,
  45, 48, 46, 53, 59, 45, 48, 46, 53, 59, 92, 10, 48, 46, 53, 59,
  45, 48, 46, 53, 59, 45, 48, 46, 53, 59, 92, 10, 48, 46, 53, 59,
  48, 46, 53, 59, 45, 48, 46, 53, 59, 92, 10, 45, 48, 46, 53, 59,
  48, 46, 53, 59, 45, 48, 46, 53, 59, 92, 10, 45, 48, 46, 53, 59,
  45, 48, 46, 53, 59, 48, 46, 53, 59, 92, 10, 48, 46, 53, 59, 45,
  48, 46, 53, 59, 48, 46, 53, 59, 92, 10, 48, 46, 53, 59, 48, 46,
  53, 59, 48, 46, 53, 59, 92, 10, 45, 48, 46, 53, 59, 48, 46, 53,
  59, 48, 46, 53, 59, 92, 10, 49, 50, 59, 48, 59, 51, 59, 50, 59,
  49, 59, 48, 59, 48, 59, 48, 59, 36, 104, 49, 59, 36, 119, 49, 59,
  36, 104, 49, 59, 36, 119, 49, 59, 48, 59, 92, 10, 49, 50, 59, 49,
  59, 50, 59, 54, 59, 53, 59, 48, 59, 48, 59, 48, 59, 36, 104, 49,
  59, 36, 119, 49, 59, 36, 104, 49, 59, 36, 119, 49, 59, 48, 59, 92,
  10, 49, 50, 59, 53, 59, 54, 59, 55, 59, 52, 59, 48, 59, 48, 59,
  48, 59, 36, 104, 49, 59, 36, 119, 49, 59, 36, 104, 49, 59, 36, 119,
  49, 59, 48, 59, 92, 10, 49, 50, 59, 52, 59, 55, 59, 51, 59, 48,
  59, 48, 59, 48, 59, 48, 59, 36, 104, 49, 59, 36, 119, 49, 59, 36,
  104, 49, 59, 36, 119, 49, 59, 48, 59, 92, 10, 49, 50, 59, 52, 59,
  48, 59, 49, 59, 53, 59, 48, 59, 48, 59, 48, 59, 36, 104, 49, 59,
  36, 119, 49, 59, 36, 104, 49, 59, 36, 119, 49, 59, 48, 59, 92, 10,
  49, 50, 59, 51, 59, 55, 59, 54, 59, 50, 59, 48, 59, 48, 59, 48,
  59, 36, 104, 49, 59, 36, 119, 49, 59, 36, 104, 49, 59, 36, 119, 49,
  59, 48, 59, 92, 10, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104,
  125, 59, 123, 115, 125, 41, 10, 45, 121, 91, 45, 49, 93, 10, 40, 45,
  49, 50, 56, 59, 48, 59, 48, 59, 48, 59, 45, 49, 50, 56, 59, 48,
  59, 48, 59, 48, 59, 45, 49, 50, 56, 59, 48, 59, 48, 59, 48, 59,
  45, 49, 50, 56, 59, 48, 59, 48, 59, 48, 59, 45, 49, 50, 56, 59,
  48, 59, 48, 59, 48, 59, 49, 59, 49, 59, 49, 59, 49, 59, 49, 59,
  49, 41, 10, 45, 97, 32, 121, 10, 45, 110, 109, 32, 36, 110, 109, 44,
  49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 105, 109, 97, 103, 101, 112,
  108, 97, 110, 101, 51, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  71, 101, 110, 101, 114, 97, 116, 101, 32, 51, 100, 32, 109, 97, 112, 112,
  101, 100, 32, 112, 108, 97, 110, 101, 115, 32, 102, 114, 111, 109, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 105, 109, 97, 103, 101, 112, 108, 97, 110, 101,
  51, 100, 10, 105, 109, 97, 103, 101, 112, 108, 97, 110, 101, 51, 100, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 71, 101, 110, 101, 114,
  97, 116, 101, 32, 51, 100, 32, 109, 97, 112, 112, 101, 100, 32, 112, 108,
  97, 110, 101, 115, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36,
  63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 115, 108, 105, 99, 101, 115,
  32, 53, 48, 37, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110,
  109, 61, 64, 123, 48, 44, 110, 125, 10, 119, 49, 61, 123, 119, 45, 49,
  125, 32, 104, 49, 61, 123, 104, 45, 49, 125, 10, 45, 105, 91, 45, 50,
  93, 32, 40, 54, 55, 46, 53, 59, 55, 51, 46, 53, 59, 49, 48, 57,
  46, 53, 59, 49, 48, 51, 46, 53, 59, 53, 49, 46, 53, 59, 49, 48,
  48, 46, 53, 59, 92, 10, 52, 59, 49, 59, 92, 10, 48, 59, 48, 59,
  48, 59, 92, 10, 123, 119, 125, 59, 48, 59, 48, 59, 92, 10, 123, 119,
  125, 59, 123, 104, 125, 59, 48, 59, 92, 10, 123, 48, 125, 59, 123, 104,
  125, 59, 48, 59, 92, 10, 49, 50, 59, 48, 59, 51, 59, 50, 59, 49,
  59, 48, 59, 48, 59, 48, 59, 36, 104, 49, 59, 36, 119, 49, 59, 36,
  104, 49, 59, 36, 119, 49, 59, 48, 59, 92, 10, 45, 49, 50, 56, 59,
  123, 119, 125, 59, 123, 104, 125, 59, 123, 115, 125, 41, 10, 45, 121, 91,
  45, 49, 93, 10, 40, 49, 41, 10, 45, 97, 32, 121, 10, 45, 110, 109,
  32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 105,
  109, 97, 103, 101, 112, 121, 114, 97, 109, 105, 100, 51, 100, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 71, 101, 110, 101, 114, 97, 116, 101, 32,
  51, 100, 32, 109, 97, 112, 112, 101, 100, 32, 112, 121, 114, 97, 109, 105,
  100, 101, 115, 32, 102, 114, 111, 109, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  105, 109, 97, 103, 101, 112, 121, 114, 97, 109, 105, 100, 51, 100, 10, 105,
  109, 97, 103, 101, 112, 121, 114, 97, 109, 105, 100, 51, 100, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 71, 101, 110, 101, 114, 97, 116,
  101, 32, 51, 100, 32, 109, 97, 112, 112, 101, 100, 32, 112, 121, 114, 97,
  109, 105, 100, 115, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36,
  63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123,
  48, 44, 110, 125, 10, 119, 49, 61, 123, 119, 45, 49, 125, 32, 104, 49,
  61, 123, 104, 45, 49, 125, 32, 119, 50, 61, 123, 119, 47, 50, 125, 10,
  45, 105, 91, 45, 50, 93, 32, 40, 54, 55, 46, 53, 59, 55, 51, 46,
  53, 59, 49, 48, 57, 46, 53, 59, 49, 48, 51, 46, 53, 59, 53, 49,
  46, 53, 59, 49, 48, 48, 46, 53, 59, 92, 10, 53, 59, 53, 59, 92,
  10, 45, 48, 46, 53, 59, 45, 48, 46, 53, 59, 45, 48, 46, 53, 59,
  92, 10, 48, 46, 53, 59, 45, 48, 46, 53, 59, 45, 48, 46, 53, 59,
  92, 10, 48, 46, 53, 59, 48, 46, 53, 59, 45, 48, 46, 53, 59, 92,
  10, 45, 48, 46, 53, 59, 48, 46, 53, 59, 45, 48, 46, 53, 59, 92,
  10, 48, 59, 48, 59, 48, 46, 53, 59, 92, 10, 49, 50, 59, 48, 59,
  51, 59, 50, 59, 49, 59, 48, 59, 48, 59, 48, 59, 36, 104, 49, 59,
  36, 119, 49, 59, 36, 104, 49, 59, 36, 119, 49, 59, 48, 59, 92, 10,
  57, 59, 48, 59, 52, 59, 51, 59, 48, 59, 36, 104, 49, 59, 36, 119,
  50, 59, 48, 59, 36, 119, 49, 59, 36, 104, 49, 59, 92, 10, 57, 59,
  49, 59, 52, 59, 48, 59, 48, 59, 36, 104, 49, 59, 36, 119, 50, 59,
  48, 59, 36, 119, 49, 59, 36, 104, 49, 59, 92, 10, 57, 59, 50, 59,
  52, 59, 49, 59, 48, 59, 36, 104, 49, 59, 36, 119, 50, 59, 48, 59,
  36, 119, 49, 59, 36, 104, 49, 59, 92, 10, 57, 59, 51, 59, 52, 59,
  50, 59, 48, 59, 36, 104, 49, 59, 36, 119, 50, 59, 48, 59, 36, 119,
  49, 59, 36, 104, 49, 59, 92, 10, 45, 49, 50, 56, 59, 123, 119, 125,
  59, 123, 104, 125, 59, 123, 115, 125, 41, 10, 45, 121, 91, 45, 49, 93,
  10, 40, 45, 49, 50, 56, 59, 48, 59, 48, 59, 48, 59, 45, 49, 50,
  56, 59, 48, 59, 48, 59, 48, 59, 45, 49, 50, 56, 59, 48, 59, 48,
  59, 48, 59, 45, 49, 50, 56, 59, 48, 59, 48, 59, 48, 59, 49, 59,
  49, 59, 49, 59, 49, 59, 49, 41, 10, 45, 97, 32, 121, 10, 45, 110,
  109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  105, 109, 97, 103, 101, 114, 117, 98, 105, 107, 51, 100, 32, 58, 32, 95,
  120, 121, 95, 116, 105, 108, 101, 115, 62, 61, 49, 44, 48, 60, 61, 120,
  121, 95, 115, 104, 105, 102, 116, 60, 61, 49, 48, 48, 44, 48, 60, 61,
  122, 95, 115, 104, 105, 102, 116, 60, 61, 49, 48, 48, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 71, 101, 110, 101, 114, 97, 116, 101, 32, 51,
  100, 32, 109, 97, 112, 112, 101, 100, 32, 114, 117, 98, 105, 107, 39, 115,
  32, 99, 117, 98, 101, 115, 32, 102, 114, 111, 109, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 120, 121, 95, 116, 105, 108, 101, 115, 61,
  51, 39, 44, 32, 39, 120, 121, 95, 115, 104, 105, 102, 116, 61, 53, 39,
  32, 97, 110, 100, 32, 39, 122, 95, 115, 104, 105, 102, 116, 61, 53, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 105, 109, 97, 103, 101, 114, 117, 98,
  105, 107, 51, 100, 32, 44, 10, 105, 109, 97, 103, 101, 114, 117, 98, 105,
  107, 51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123,
  49, 61, 51, 125, 62, 61, 49, 32, 38, 38, 32, 36, 123, 50, 61, 53,
  125, 62, 61, 48, 32, 38, 38, 32, 36, 50, 60, 61, 49, 48, 48, 32,
  38, 38, 32, 36, 123, 51, 61, 53, 125, 62, 61, 48, 32, 38, 38, 32,
  36, 51, 60, 61, 49, 48, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 71, 101, 110, 101, 114, 97, 116, 101, 32, 51, 100, 32, 109, 97,
  112, 112, 101, 100, 32, 114, 117, 98, 105, 107, 39, 115, 32, 99, 117, 98,
  101, 115, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  119, 105, 116, 104, 32, 36, 49, 32, 120, 121, 45, 116, 105, 108, 101, 115,
  44, 32, 120, 121, 45, 115, 104, 105, 102, 116, 32, 36, 50, 32, 97, 110,
  100, 32, 122, 45, 115, 104, 105, 102, 116, 32, 36, 51, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10,
  40, 123, 39, 67, 73, 109, 103, 51, 100, 39, 125, 41, 32, 45, 43, 91,
  45, 49, 93, 32, 48, 46, 53, 10, 40, 56, 44, 53, 41, 10, 40, 48,
  44, 48, 44, 48, 59, 92, 10, 49, 48, 48, 44, 48, 44, 48, 59, 92,
  10, 49, 48, 48, 44, 49, 48, 48, 44, 48, 59, 92, 10, 48, 44, 49,
  48, 48, 44, 48, 59, 92, 10, 36, 50, 44, 36, 50, 44, 123, 45, 36,
  51, 125, 59, 92, 10, 123, 49, 48, 48, 45, 36, 50, 125, 44, 36, 50,
  44, 123, 45, 36, 51, 125, 59, 92, 10, 123, 49, 48, 48, 45, 36, 50,
  125, 44, 123, 49, 48, 48, 45, 36, 50, 125, 44, 123, 45, 36, 51, 125,
  59, 92, 10, 36, 50, 44, 123, 49, 48, 48, 45, 36, 50, 125, 44, 123,
  45, 36, 51, 125, 41, 10, 40, 52, 44, 52, 44, 55, 44, 54, 44, 53,
  59, 92, 10, 52, 44, 48, 44, 52, 44, 53, 44, 49, 59, 92, 10, 52,
  44, 51, 44, 50, 44, 54, 44, 55, 59, 92, 10, 52, 44, 48, 44, 51,
  44, 55, 44, 52, 59, 92, 10, 52, 44, 49, 44, 53, 44, 54, 44, 50,
  41, 10, 51, 44, 53, 44, 49, 44, 49, 44, 50, 48, 48, 10, 49, 44,
  53, 44, 49, 44, 49, 44, 49, 10, 45, 121, 91, 45, 54, 45, 45, 49,
  93, 32, 45, 97, 91, 45, 54, 45, 45, 49, 93, 32, 121, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 123, 36, 49, 45, 49, 125, 32, 45, 45, 43,
  51, 100, 91, 45, 49, 93, 32, 49, 48, 48, 32, 45, 100, 111, 110, 101,
  32, 45, 43, 51, 100, 91, 45, 36, 49, 45, 45, 49, 93, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 123, 36, 49, 45, 49, 125, 32, 45, 45, 43,
  51, 100, 91, 45, 49, 93, 32, 48, 44, 49, 48, 48, 32, 45, 100, 111,
  110, 101, 32, 45, 43, 51, 100, 91, 45, 36, 49, 45, 45, 49, 93, 10,
  45, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 114,
  109, 91, 45, 50, 93, 10, 45, 47, 51, 100, 91, 45, 49, 93, 32, 36,
  49, 32, 45, 45, 51, 100, 91, 45, 49, 93, 32, 53, 48, 44, 53, 48,
  44, 53, 48, 10, 45, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44,
  49, 44, 48, 44, 45, 57, 48, 32, 45, 45, 114, 51, 100, 91, 45, 49,
  93, 32, 48, 44, 49, 44, 48, 44, 45, 57, 48, 32, 45, 45, 114, 51,
  100, 91, 45, 49, 93, 32, 48, 44, 49, 44, 48, 44, 45, 57, 48, 10,
  45, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 48, 44, 49, 44,
  45, 57, 48, 32, 45, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44,
  48, 44, 49, 44, 49, 56, 48, 10, 45, 43, 51, 100, 10, 45, 110, 109,
  32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 105,
  109, 97, 103, 101, 115, 112, 104, 101, 114, 101, 51, 100, 32, 58, 32, 95,
  114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 49, 62, 61, 51, 44, 95,
  114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 50, 62, 61, 51, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 71, 101, 110, 101, 114, 97, 116, 101,
  32, 51, 100, 32, 109, 97, 112, 112, 101, 100, 32, 115, 112, 104, 101, 114,
  101, 32, 102, 114, 111, 109, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58,
  32, 39, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 49, 61, 51, 50,
  39, 32, 97, 110, 100, 32, 39, 114, 101, 115, 111, 108, 117, 116, 105, 111,
  110, 115, 50, 61, 49, 54, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 105,
  109, 97, 103, 101, 115, 112, 104, 101, 114, 101, 51, 100, 32, 51, 50, 44,
  49, 54, 10, 105, 109, 97, 103, 101, 115, 112, 104, 101, 114, 101, 51, 100,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 51,
  50, 125, 62, 61, 51, 32, 38, 38, 32, 36, 123, 50, 61, 49, 54, 125,
  62, 61, 51, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 71, 101,
  110, 101, 114, 97, 116, 101, 32, 51, 100, 32, 109, 97, 112, 112, 101, 100,
  32, 115, 112, 104, 101, 114, 101, 32, 102, 114, 111, 109, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 114, 101, 115, 111, 108,
  117, 116, 105, 111, 110, 115, 32, 40, 36, 49, 44, 36, 50, 41, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32,
  110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 116, 119, 61, 123, 119, 45,
  49, 125, 32, 116, 104, 61, 123, 104, 45, 49, 125, 10, 110, 98, 118, 61,
  123, 50, 43, 36, 49, 42, 40, 36, 50, 45, 50, 41, 125, 10, 110, 98,
  112, 61, 123, 36, 49, 42, 40, 36, 50, 45, 49, 41, 125, 10, 40, 54,
  55, 46, 53, 59, 55, 51, 46, 53, 59, 49, 48, 57, 46, 53, 59, 49,
  48, 51, 46, 53, 59, 53, 49, 46, 53, 59, 49, 48, 48, 46, 53, 59,
  92, 10, 36, 110, 98, 118, 59, 36, 110, 98, 112, 41, 10, 40, 48, 59,
  48, 59, 49, 41, 32, 40, 48, 59, 48, 59, 45, 49, 41, 32, 40, 48,
  44, 123, 50, 42, 112, 105, 125, 59, 48, 44, 123, 50, 42, 112, 105, 125,
  94, 48, 44, 48, 59, 123, 112, 105, 125, 44, 123, 112, 105, 125, 41, 10,
  45, 114, 91, 45, 49, 93, 32, 123, 36, 49, 43, 49, 125, 44, 36, 50,
  44, 49, 44, 50, 44, 51, 32, 45, 122, 91, 45, 49, 93, 32, 48, 44,
  49, 44, 123, 119, 45, 50, 125, 44, 123, 104, 45, 50, 125, 32, 45, 115,
  91, 45, 49, 93, 32, 99, 10, 45, 45, 115, 105, 110, 91, 45, 49, 93,
  32, 45, 45, 115, 105, 110, 91, 45, 51, 93, 32, 45, 42, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 45, 99, 111, 115, 91, 45, 50, 93, 32, 45,
  115, 105, 110, 91, 45, 51, 93, 32, 45, 99, 111, 115, 91, 45, 52, 93,
  32, 45, 42, 91, 45, 52, 44, 45, 51, 93, 10, 45, 97, 91, 45, 51,
  45, 45, 49, 93, 32, 99, 32, 45, 112, 101, 114, 109, 117, 116, 101, 91,
  45, 49, 93, 32, 99, 120, 121, 122, 32, 45, 121, 91, 45, 49, 93, 32,
  45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 121, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 36, 49, 10, 116, 120, 48, 61, 123, 36, 62, 42, 36,
  116, 119, 47, 36, 49, 125, 32, 116, 120, 49, 61, 123, 40, 36, 62, 43,
  49, 41, 42, 36, 116, 119, 47, 36, 49, 125, 32, 116, 121, 49, 61, 123,
  36, 116, 104, 47, 40, 36, 50, 45, 49, 41, 125, 10, 40, 57, 59, 48,
  59, 123, 50, 43, 36, 62, 125, 59, 123, 50, 43, 40, 36, 62, 43, 49,
  41, 37, 36, 49, 125, 59, 123, 36, 116, 119, 47, 50, 125, 59, 48, 59,
  36, 116, 120, 48, 59, 36, 116, 121, 49, 59, 36, 116, 120, 49, 59, 36,
  116, 121, 49, 41, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 50,
  45, 51, 125, 10, 116, 121, 48, 61, 36, 116, 121, 49, 32, 116, 121, 49,
  61, 123, 40, 36, 62, 43, 50, 41, 42, 36, 116, 104, 47, 40, 36, 50,
  45, 49, 41, 125, 32, 105, 48, 61, 123, 50, 43, 36, 62, 42, 36, 49,
  43, 64, 123, 62, 44, 45, 50, 125, 125, 32, 105, 49, 61, 123, 50, 43,
  36, 62, 42, 36, 49, 43, 40, 64, 123, 62, 44, 45, 50, 125, 43, 49,
  41, 37, 36, 49, 125, 10, 40, 49, 50, 59, 36, 105, 48, 59, 123, 36,
  105, 48, 43, 36, 49, 125, 59, 123, 36, 105, 49, 43, 36, 49, 125, 59,
  36, 105, 49, 59, 36, 116, 120, 48, 59, 36, 116, 121, 48, 59, 36, 116,
  120, 48, 59, 36, 116, 121, 49, 59, 36, 116, 120, 49, 59, 36, 116, 121,
  49, 59, 36, 116, 120, 49, 59, 36, 116, 121, 48, 41, 10, 45, 100, 111,
  110, 101, 10, 40, 57, 59, 49, 59, 123, 50, 43, 36, 49, 42, 40, 36,
  50, 45, 51, 41, 43, 40, 36, 62, 43, 49, 41, 37, 36, 49, 125, 59,
  123, 50, 43, 36, 49, 42, 40, 36, 50, 45, 51, 41, 43, 36, 62, 125,
  59, 123, 36, 116, 119, 47, 50, 125, 59, 36, 116, 104, 59, 36, 116, 120,
  49, 59, 36, 116, 121, 49, 59, 36, 116, 120, 48, 59, 36, 116, 121, 49,
  41, 10, 45, 100, 111, 110, 101, 10, 45, 97, 91, 45, 36, 110, 98, 112,
  45, 45, 49, 93, 32, 121, 10, 45, 109, 118, 91, 45, 52, 93, 32, 64,
  35, 32, 45, 105, 91, 45, 50, 93, 32, 40, 45, 49, 50, 56, 59, 123,
  119, 125, 59, 123, 104, 125, 59, 51, 41, 32, 45, 121, 91, 45, 49, 93,
  32, 49, 44, 123, 52, 42, 40, 36, 110, 98, 112, 45, 49, 41, 125, 44,
  49, 44, 49, 44, 45, 49, 50, 56, 44, 48, 44, 48, 44, 48, 32, 49,
  44, 36, 110, 98, 112, 44, 49, 44, 49, 44, 49, 32, 45, 97, 32, 121,
  10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109,
  105, 99, 32, 105, 115, 111, 108, 105, 110, 101, 51, 100, 32, 58, 32, 105,
  115, 111, 118, 97, 108, 117, 101, 91, 37, 93, 32, 58, 32, 39, 102, 111,
  114, 109, 117, 108, 97, 39, 44, 118, 97, 108, 117, 101, 44, 95, 120, 48,
  44, 95, 121, 48, 44, 95, 120, 49, 44, 95, 121, 49, 44, 95, 115, 105,
  122, 101, 95, 120, 62, 48, 91, 37, 93, 44, 95, 115, 105, 122, 101, 95,
  121, 62, 48, 91, 37, 93, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 69, 120, 116, 114, 97, 99, 116, 32, 51, 100,
  32, 105, 115, 111, 108, 105, 110, 101, 115, 32, 119, 105, 116, 104, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 118, 97, 108, 117, 101, 32, 102,
  114, 111, 109, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 32, 111, 114, 32, 102, 114, 111, 109, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 102, 111, 114, 109, 117, 108, 97, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32,
  118, 97, 108, 117, 101, 115, 58, 32, 39, 120, 48, 61, 121, 48, 61, 45,
  51, 39, 44, 32, 39, 120, 49, 61, 121, 49, 61, 51, 39, 32, 97, 110,
  100, 32, 39, 115, 105, 122, 101, 95, 120, 61, 115, 105, 122, 101, 95, 121,
  61, 50, 53, 54, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 98, 108, 117,
  114, 32, 49, 32, 45, 105, 115, 111, 108, 105, 110, 101, 51, 100, 32, 53,
  48, 37, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 105,
  115, 111, 108, 105, 110, 101, 51, 100, 32, 39, 88, 61, 120, 45, 119, 47,
  50, 59, 89, 61, 121, 45, 104, 47, 50, 59, 40, 88, 94, 50, 43, 89,
  94, 50, 41, 37, 50, 48, 39, 44, 49, 48, 44, 45, 49, 48, 44, 45,
  49, 48, 44, 49, 48, 44, 49, 48, 10, 35, 64, 103, 109, 105, 99, 32,
  105, 115, 111, 115, 117, 114, 102, 97, 99, 101, 51, 100, 32, 58, 32, 105,
  115, 111, 118, 97, 108, 117, 101, 91, 37, 93, 32, 58, 32, 39, 102, 111,
  114, 109, 117, 108, 97, 39, 44, 118, 97, 108, 117, 101, 44, 95, 120, 48,
  44, 95, 121, 48, 44, 95, 122, 48, 44, 95, 120, 49, 44, 95, 121, 49,
  44, 95, 122, 49, 44, 95, 115, 105, 122, 101, 95, 120, 62, 48, 91, 37,
  93, 44, 95, 115, 105, 122, 101, 95, 121, 62, 48, 91, 37, 93, 44, 95,
  115, 105, 122, 101, 95, 122, 62, 48, 91, 37, 93, 32, 58, 32, 40, 43,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 69, 120, 116, 114, 97,
  99, 116, 32, 51, 100, 32, 105, 115, 111, 115, 117, 114, 102, 97, 99, 101,
  115, 32, 119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100,
  32, 118, 97, 108, 117, 101, 32, 102, 114, 111, 109, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 111, 114, 32, 102,
  114, 111, 109, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 102, 111,
  114, 109, 117, 108, 97, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 120, 48, 61, 121, 48, 61, 122, 48, 61, 45, 51, 39, 44, 32, 39,
  120, 49, 61, 121, 49, 61, 122, 49, 61, 51, 39, 32, 97, 110, 100, 32,
  39, 115, 105, 122, 101, 95, 120, 61, 115, 105, 122, 101, 95, 121, 61, 115,
  105, 122, 101, 95, 122, 61, 51, 50, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 114, 101, 115, 105, 122, 101, 50, 100, 121, 32, 49, 50, 56, 32, 45,
  108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 116, 104, 114, 101, 115,
  104, 111, 108, 100, 32, 53, 48, 37, 32, 45, 101, 120, 112, 97, 110, 100,
  95, 122, 32, 50, 44, 48, 32, 45, 98, 108, 117, 114, 32, 49, 32, 45,
  105, 115, 111, 115, 117, 114, 102, 97, 99, 101, 51, 100, 32, 53, 48, 37,
  32, 45, 109, 117, 108, 51, 100, 32, 49, 44, 49, 44, 51, 48, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 105, 115, 111, 115, 117,
  114, 102, 97, 99, 101, 51, 100, 32, 39, 120, 94, 50, 43, 121, 94, 50,
  43, 97, 98, 115, 40, 122, 41, 94, 97, 98, 115, 40, 52, 42, 99, 111,
  115, 40, 120, 42, 121, 42, 122, 42, 51, 41, 41, 39, 44, 51, 10, 35,
  64, 103, 109, 105, 99, 32, 108, 97, 98, 101, 108, 95, 112, 111, 105, 110,
  116, 115, 51, 100, 32, 58, 32, 95, 108, 97, 98, 101, 108, 95, 115, 105,
  122, 101, 62, 48, 44, 95, 111, 112, 97, 99, 105, 116, 121, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 65, 100, 100, 32, 97, 32, 110, 117, 109,
  98, 101, 114, 101, 100, 32, 108, 97, 98, 101, 108, 32, 116, 111, 32, 97,
  108, 108, 32, 118, 101, 114, 116, 105, 99, 101, 115, 32, 111, 102, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 51, 100, 32, 111, 98, 106, 101, 99,
  116, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 108, 97,
  98, 101, 108, 95, 115, 105, 122, 101, 61, 49, 51, 39, 32, 97, 110, 100,
  32, 39, 111, 112, 97, 99, 105, 116, 121, 61, 48, 46, 56, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 116, 111, 114, 117,
  115, 51, 100, 32, 49, 48, 48, 44, 52, 48, 44, 54, 44, 54, 32, 45,
  108, 97, 98, 101, 108, 95, 112, 111, 105, 110, 116, 115, 51, 100, 32, 50,
  52, 44, 49, 32, 45, 109, 111, 100, 101, 51, 100, 32, 49, 10, 108, 97,
  98, 101, 108, 95, 112, 111, 105, 110, 116, 115, 51, 100, 32, 58, 32, 45,
  99, 104, 101, 99, 107, 32, 36, 123, 49, 61, 49, 51, 125, 62, 48, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 48, 46, 56, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 76, 97, 98, 101, 108, 32, 118, 101,
  114, 116, 105, 99, 101, 115, 32, 111, 102, 32, 51, 100, 32, 111, 98, 106,
  101, 99, 116, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 10, 45, 45, 112, 51, 100, 91, 36, 62,
  93, 32, 48, 32, 45, 108, 91, 45, 49, 93, 32, 45, 115, 51, 100, 32,
  45, 114, 109, 91, 45, 51, 45, 45, 49, 93, 10, 110, 98, 112, 61, 64,
  123, 45, 50, 44, 48, 125, 32, 45, 61, 91, 45, 50, 93, 32, 36, 110,
  98, 112, 44, 48, 44, 49, 10, 40, 49, 44, 48, 59, 49, 44, 123, 36,
  110, 98, 112, 45, 49, 125, 41, 32, 45, 114, 91, 45, 49, 93, 32, 50,
  44, 36, 110, 98, 112, 44, 49, 44, 49, 44, 51, 32, 45, 114, 91, 45,
  49, 93, 32, 49, 44, 123, 50, 42, 104, 125, 44, 49, 44, 49, 44, 45,
  49, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 110, 98, 112, 10, 48,
  32, 45, 116, 91, 45, 49, 93, 32, 36, 62, 44, 48, 44, 48, 44, 36,
  49, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32,
  45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 48, 10,
  45, 105, 91, 45, 50, 93, 32, 40, 45, 49, 50, 56, 59, 123, 119, 125,
  59, 123, 104, 125, 59, 51, 41, 32, 45, 121, 91, 45, 49, 93, 10, 45,
  100, 111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 110, 98,
  112, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 36, 62, 44, 48, 44,
  48, 44, 36, 49, 44, 49, 44, 36, 50, 32, 45, 97, 117, 116, 111, 99,
  114, 111, 112, 91, 45, 49, 93, 32, 48, 10, 45, 105, 91, 45, 50, 93,
  32, 40, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 49,
  41, 32, 45, 121, 91, 45, 49, 93, 10, 45, 100, 111, 110, 101, 10, 45,
  97, 32, 121, 10, 45, 101, 110, 100, 108, 10, 45, 43, 51, 100, 91, 36,
  62, 44, 45, 49, 93, 10, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 108, 97, 116, 104, 101, 51, 100, 32,
  58, 32, 95, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 62, 48, 44,
  95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 91, 37, 93, 62, 61,
  48, 44, 95, 109, 97, 120, 95, 97, 110, 103, 108, 101, 62, 61, 48, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 71, 101, 110, 101, 114, 97, 116,
  101, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 32, 102, 114, 111, 109,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 98, 105, 110, 97, 114, 121,
  32, 88, 89, 45, 112, 114, 111, 102, 105, 108, 101, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 114, 101, 115, 111, 108, 117, 116, 105,
  111, 110, 61, 49, 50, 56, 39, 44, 32, 39, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 61, 48, 46, 53, 37, 39, 32, 97, 110, 100, 32, 39,
  109, 97, 120, 95, 97, 110, 103, 108, 101, 61, 51, 54, 49, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 51, 48, 48, 44, 51,
  48, 48, 32, 45, 114, 97, 110, 100, 32, 45, 49, 44, 49, 32, 45, 98,
  108, 117, 114, 32, 52, 48, 32, 45, 115, 105, 103, 110, 32, 45, 110, 111,
  114, 109, 97, 108, 105, 122, 101, 32, 48, 44, 50, 53, 53, 32, 45, 108,
  97, 116, 104, 101, 51, 100, 32, 44, 10, 108, 97, 116, 104, 101, 51, 100,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 49,
  50, 56, 125, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 48, 46, 53,
  37, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 51, 61, 51, 54, 49,
  125, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 71,
  101, 110, 101, 114, 97, 116, 101, 32, 108, 97, 116, 104, 101, 100, 32, 51,
  100, 32, 111, 98, 106, 101, 99, 116, 32, 102, 114, 111, 109, 32, 88, 89,
  45, 112, 114, 111, 102, 105, 108, 101, 36, 63, 44, 32, 119, 105, 116, 104,
  32, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 32, 36, 49, 44, 32,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 50, 32, 97, 110,
  100, 32, 109, 97, 120, 105, 109, 117, 109, 32, 97, 110, 103, 108, 101, 32,
  36, 51, 32, 100, 101, 103, 46, 34, 10, 45, 118, 32, 45, 32, 116, 109,
  97, 120, 61, 123, 40, 36, 51, 45, 49, 56, 48, 41, 42, 112, 105, 47,
  49, 56, 48, 125, 32, 45, 110, 111, 114, 109, 32, 45, 110, 32, 48, 44,
  49, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 48, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  119, 114, 61, 123, 109, 97, 120, 40, 49, 44, 119, 50, 61, 50, 42, 119,
  59, 105, 102, 40, 119, 50, 62, 104, 44, 109, 105, 110, 40, 36, 49, 44,
  119, 50, 41, 44, 109, 105, 110, 40, 36, 49, 44, 104, 41, 42, 119, 50,
  47, 104, 41, 41, 125, 10, 104, 114, 61, 123, 109, 97, 120, 40, 49, 44,
  119, 50, 61, 50, 42, 119, 59, 105, 102, 40, 119, 50, 62, 104, 44, 109,
  105, 110, 40, 36, 49, 44, 119, 50, 41, 42, 104, 47, 119, 50, 44, 109,
  105, 110, 40, 36, 49, 44, 104, 41, 41, 41, 125, 10, 114, 109, 97, 120,
  61, 123, 115, 113, 114, 116, 40, 40, 36, 119, 114, 41, 94, 50, 43, 40,
  36, 104, 114, 41, 94, 50, 41, 47, 50, 125, 10, 36, 119, 114, 44, 49,
  44, 36, 119, 114, 44, 49, 44, 34, 120, 99, 61, 120, 45, 119, 47, 50,
  59, 32, 122, 99, 61, 122, 45, 100, 47, 50, 59, 32, 116, 61, 97, 116,
  97, 110, 50, 40, 122, 99, 44, 120, 99, 41, 59, 32, 105, 102, 40, 116,
  62, 34, 36, 116, 109, 97, 120, 34, 44, 34, 36, 114, 109, 97, 120, 34,
  44, 115, 113, 114, 116, 40, 120, 99, 42, 120, 99, 43, 122, 99, 42, 122,
  99, 41, 41, 34, 10, 45, 42, 91, 45, 49, 93, 32, 123, 50, 42, 40,
  64, 123, 45, 50, 44, 119, 125, 45, 49, 41, 47, 40, 119, 45, 49, 41,
  125, 32, 45, 114, 91, 45, 49, 93, 32, 36, 119, 114, 44, 36, 104, 114,
  44, 36, 119, 114, 10, 40, 48, 59, 123, 64, 123, 45, 50, 44, 104, 125,
  45, 49, 125, 41, 32, 45, 114, 91, 45, 49, 93, 32, 36, 119, 114, 44,
  36, 104, 114, 44, 36, 119, 114, 44, 49, 44, 51, 32, 45, 97, 91, 45,
  50, 45, 45, 49, 93, 32, 99, 10, 45, 119, 97, 114, 112, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 44, 48, 44, 49, 44, 48, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 122,
  32, 49, 48, 44, 48, 32, 45, 98, 32, 36, 50, 32, 45, 105, 115, 111,
  115, 117, 114, 102, 97, 99, 101, 51, 100, 32, 53, 48, 37, 32, 45, 114,
  118, 51, 100, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 108, 51, 100, 32,
  58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 108, 105, 103, 104, 116,
  51, 100, 39, 46, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 108, 105, 103, 104, 116, 51, 100, 32, 58, 32, 112, 111, 115, 105,
  116, 105, 111, 110, 95, 120, 44, 112, 111, 115, 105, 116, 105, 111, 110, 95,
  121, 44, 112, 111, 115, 105, 116, 105, 111, 110, 95, 122, 32, 58, 32, 91,
  116, 101, 120, 116, 117, 114, 101, 93, 32, 58, 32, 40, 110, 111, 32, 97,
  114, 103, 115, 41, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 83, 101, 116, 32, 116, 104, 101, 32, 108, 105, 103, 104,
  116, 32, 99, 111, 111, 114, 100, 105, 110, 97, 116, 101, 115, 32, 111, 114,
  32, 116, 104, 101, 32, 108, 105, 103, 104, 116, 32, 116, 101, 120, 116, 117,
  114, 101, 32, 102, 111, 114, 32, 51, 100, 32, 114, 101, 110, 100, 101, 114,
  105, 110, 103, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101,
  113, 46, 32, 116, 111, 32, 39, 45, 108, 51, 100, 39, 41, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 40, 110, 111, 97, 114, 103, 115, 41,
  32, 114, 101, 115, 101, 116, 115, 32, 116, 104, 101, 32, 51, 100, 32, 108,
  105, 103, 104, 116, 32, 116, 111, 32, 100, 101, 102, 97, 117, 108, 116, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 116, 111, 114,
  117, 115, 51, 100, 32, 49, 48, 48, 44, 51, 48, 32, 45, 100, 111, 117,
  98, 108, 101, 51, 100, 32, 48, 32, 45, 115, 112, 101, 99, 115, 51, 100,
  32, 49, 46, 50, 32, 45, 114, 101, 112, 101, 97, 116, 32, 53, 32, 45,
  108, 105, 103, 104, 116, 51, 100, 32, 123, 36, 62, 42, 49, 48, 48, 125,
  44, 48, 44, 45, 51, 48, 48, 32, 45, 45, 115, 110, 97, 112, 115, 104,
  111, 116, 51, 100, 91, 48, 93, 32, 52, 48, 48, 32, 45, 100, 111, 110,
  101, 32, 45, 114, 101, 109, 111, 118, 101, 91, 48, 93, 10, 35, 64, 103,
  109, 105, 99, 32, 108, 105, 110, 101, 51, 100, 32, 58, 32, 120, 48, 44,
  121, 48, 44, 122, 48, 44, 120, 49, 44, 121, 49, 44, 122, 49, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 73, 110, 112, 117, 116, 32, 51, 100,
  32, 108, 105, 110, 101, 32, 97, 116, 32, 115, 112, 101, 99, 105, 102, 105,
  101, 100, 32, 99, 111, 111, 114, 100, 105, 110, 97, 116, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 49, 48, 48, 32, 97, 61, 123, 36, 62, 42, 112, 105, 47,
  53, 48, 125, 32, 45, 108, 105, 110, 101, 51, 100, 32, 48, 44, 48, 44,
  48, 44, 123, 99, 111, 115, 40, 51, 42, 36, 97, 41, 125, 44, 123, 115,
  105, 110, 40, 50, 42, 36, 97, 41, 125, 44, 48, 32, 45, 99, 111, 108,
  111, 114, 51, 100, 91, 45, 49, 93, 32, 64, 123, 45, 82, 71, 66, 125,
  32, 45, 100, 111, 110, 101, 32, 45, 97, 100, 100, 51, 100, 10, 108, 105,
  110, 101, 51, 100, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  73, 110, 112, 117, 116, 32, 51, 100, 32, 108, 105, 110, 101, 32, 40, 36,
  123, 49, 45, 51, 125, 41, 45, 40, 36, 123, 52, 45, 54, 125, 41, 46,
  34, 10, 45, 118, 32, 45, 32, 49, 44, 50, 49, 44, 49, 44, 49, 44,
  54, 55, 46, 53, 44, 55, 51, 46, 53, 44, 49, 48, 57, 46, 53, 44,
  49, 48, 51, 46, 53, 44, 53, 49, 46, 53, 44, 49, 48, 48, 46, 53,
  44, 50, 44, 49, 44, 36, 123, 49, 45, 54, 125, 44, 50, 44, 48, 44,
  49, 44, 50, 48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44, 49, 32,
  45, 110, 109, 91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 108, 105, 110,
  101, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 108,
  105, 115, 115, 97, 106, 111, 117, 115, 51, 100, 32, 58, 32, 114, 101, 115,
  111, 108, 117, 116, 105, 111, 110, 62, 49, 44, 97, 44, 65, 44, 98, 44,
  66, 44, 99, 44, 67, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73,
  110, 112, 117, 116, 32, 51, 100, 32, 108, 105, 115, 115, 97, 106, 111, 117,
  115, 32, 99, 117, 114, 118, 101, 115, 32, 40, 120, 40, 116, 41, 61, 115,
  105, 110, 40, 97, 42, 116, 43, 65, 42, 50, 42, 112, 105, 41, 44, 121,
  40, 116, 41, 61, 115, 105, 110, 40, 98, 42, 116, 43, 66, 42, 50, 42,
  112, 105, 41, 44, 122, 40, 116, 41, 61, 115, 105, 110, 40, 99, 42, 116,
  43, 67, 42, 50, 42, 112, 105, 41, 41, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117,
  101, 115, 58, 32, 39, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 61,
  49, 48, 50, 52, 39, 44, 32, 39, 97, 61, 50, 39, 44, 32, 39, 65,
  61, 48, 39, 44, 32, 39, 98, 61, 49, 39, 44, 32, 39, 66, 61, 48,
  39, 44, 32, 39, 99, 61, 48, 39, 32, 97, 110, 100, 32, 39, 67, 61,
  48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45,
  108, 105, 115, 115, 97, 106, 111, 117, 115, 51, 100, 32, 44, 10, 108, 105,
  115, 115, 97, 106, 111, 117, 115, 51, 100, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 36, 123, 49, 61, 49, 48, 50, 52, 125, 62, 49, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 50, 61, 50, 125, 44, 36, 123, 51, 61,
  48, 125, 44, 36, 123, 52, 61, 49, 125, 44, 36, 123, 53, 61, 48, 125,
  44, 36, 123, 54, 61, 48, 125, 44, 36, 123, 55, 61, 48, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 51, 100,
  32, 108, 105, 115, 115, 97, 106, 111, 117, 115, 32, 99, 117, 114, 118, 101,
  44, 32, 119, 105, 116, 104, 32, 114, 101, 115, 111, 108, 117, 116, 105, 111,
  110, 32, 36, 49, 44, 32, 40, 97, 44, 65, 41, 61, 40, 36, 50, 44,
  36, 51, 41, 44, 32, 40, 98, 44, 66, 41, 61, 40, 36, 52, 44, 36,
  53, 41, 32, 97, 110, 100, 32, 40, 99, 44, 67, 41, 61, 40, 36, 54,
  44, 36, 55, 41, 46, 34, 10, 45, 118, 32, 45, 10, 114, 101, 115, 61,
  123, 114, 111, 117, 110, 100, 40, 36, 49, 41, 125, 10, 40, 54, 55, 46,
  53, 59, 55, 51, 46, 53, 59, 49, 48, 57, 46, 53, 59, 49, 48, 51,
  46, 53, 59, 53, 49, 46, 53, 59, 49, 48, 48, 46, 53, 59, 36, 114,
  101, 115, 59, 123, 36, 114, 101, 115, 45, 49, 125, 41, 10, 40, 48, 44,
  123, 50, 42, 112, 105, 125, 41, 32, 45, 114, 91, 45, 49, 93, 32, 36,
  114, 101, 115, 44, 49, 44, 49, 44, 49, 44, 51, 32, 91, 45, 49, 93,
  120, 50, 10, 45, 42, 91, 45, 51, 93, 32, 36, 50, 32, 45, 43, 91,
  45, 51, 93, 32, 123, 36, 51, 42, 50, 42, 112, 105, 125, 32, 45, 42,
  91, 45, 50, 93, 32, 36, 52, 32, 45, 43, 91, 45, 50, 93, 32, 123,
  36, 53, 42, 50, 42, 112, 105, 125, 32, 45, 42, 91, 45, 49, 93, 32,
  36, 54, 32, 45, 43, 91, 45, 49, 93, 32, 123, 36, 55, 42, 50, 42,
  112, 105, 125, 10, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 121, 32,
  45, 115, 105, 110, 91, 45, 49, 93, 32, 45, 116, 114, 97, 110, 115, 112,
  111, 115, 101, 91, 45, 49, 93, 32, 45, 114, 91, 45, 49, 93, 32, 49,
  44, 123, 119, 42, 104, 125, 44, 49, 44, 49, 44, 45, 49, 10, 49, 44,
  123, 36, 114, 101, 115, 45, 49, 125, 44, 49, 44, 49, 44, 50, 32, 40,
  48, 59, 123, 36, 114, 101, 115, 45, 50, 125, 41, 32, 45, 114, 91, 45,
  49, 93, 32, 49, 44, 123, 36, 114, 101, 115, 45, 49, 125, 44, 49, 44,
  49, 44, 51, 32, 45, 45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 97,
  91, 45, 51, 45, 45, 49, 93, 32, 120, 32, 45, 114, 111, 117, 110, 100,
  91, 45, 49, 93, 32, 49, 32, 45, 114, 91, 45, 49, 93, 32, 49, 44,
  123, 119, 42, 104, 125, 44, 49, 44, 49, 44, 45, 49, 10, 49, 44, 123,
  51, 42, 40, 36, 114, 101, 115, 45, 49, 41, 125, 44, 49, 44, 49, 44,
  50, 48, 48, 32, 49, 44, 123, 36, 114, 101, 115, 45, 49, 125, 44, 49,
  44, 49, 44, 49, 32, 45, 97, 91, 45, 53, 45, 45, 49, 93, 32, 121,
  32, 45, 110, 109, 91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 108, 105,
  115, 115, 97, 106, 111, 117, 93, 10, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 109, 51, 100, 32, 58, 32, 101, 113, 46, 32, 116, 111,
  32, 39, 45, 109, 111, 100, 101, 51, 100, 39, 46, 32, 58, 32, 40, 43,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 109, 111, 100, 101, 51, 100, 32,
  58, 32, 95, 109, 111, 100, 101, 32, 58, 32, 40, 43, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 83, 101, 116, 32, 115, 116, 97, 116, 105,
  99, 32, 51, 100, 32, 114, 101, 110, 100, 101, 114, 105, 110, 103, 32, 109,
  111, 100, 101, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101,
  113, 46, 32, 116, 111, 32, 39, 45, 109, 51, 100, 39, 41, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 39, 109, 111, 100, 101, 39, 32, 99,
  97, 110, 32, 98, 101, 32, 123, 32, 45, 49, 61, 98, 111, 117, 110, 100,
  105, 110, 103, 45, 98, 111, 120, 32, 124, 32, 48, 61, 100, 111, 116, 115,
  32, 124, 32, 49, 61, 119, 105, 114, 101, 102, 114, 97, 109, 101, 32, 124,
  32, 50, 61, 102, 108, 97, 116, 32, 124, 32, 51, 61, 102, 108, 97, 116,
  45, 115, 104, 97, 100, 101, 100, 32, 124, 32, 52, 61, 103, 111, 117, 114,
  97, 117, 100, 45, 115, 104, 97, 100, 101, 100, 32, 124, 32, 53, 61, 112,
  104, 111, 110, 103, 45, 115, 104, 97, 100, 101, 100, 32, 125, 46, 34, 41,
  59, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 66, 111, 117, 110, 100,
  105, 110, 103, 45, 98, 111, 120, 32, 109, 111, 100, 101, 32, 40, 39, 109,
  111, 100, 101, 61, 61, 45, 49, 39, 41, 32, 105, 115, 32, 97, 99, 116,
  105, 118, 101, 32, 111, 110, 108, 121, 32, 102, 111, 114, 32, 116, 104, 101,
  32, 105, 110, 116, 101, 114, 97, 99, 116, 105, 118, 101, 32, 51, 100, 32,
  118, 105, 101, 119, 101, 114, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32,
  39, 109, 111, 100, 101, 61, 52, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 40, 48, 44, 49, 44, 50, 44, 51, 44, 52, 44,
  53, 41, 32, 45, 100, 111, 117, 98, 108, 101, 51, 100, 32, 48, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 119, 125, 32, 45, 116, 111, 114, 117,
  115, 51, 100, 32, 49, 48, 48, 44, 51, 48, 32, 45, 114, 111, 116, 97,
  116, 101, 51, 100, 91, 45, 49, 93, 32, 49, 44, 49, 44, 48, 44, 54,
  48, 32, 45, 109, 111, 100, 101, 51, 100, 32, 64, 123, 48, 44, 36, 62,
  125, 32, 45, 115, 110, 97, 112, 115, 104, 111, 116, 51, 100, 91, 45, 49,
  93, 32, 51, 48, 48, 32, 45, 100, 111, 110, 101, 32, 45, 114, 101, 109,
  111, 118, 101, 91, 48, 93, 10, 35, 64, 103, 109, 105, 99, 32, 109, 100,
  51, 100, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 109, 111,
  100, 101, 100, 51, 100, 39, 46, 32, 58, 32, 40, 43, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 109, 111, 100, 101, 100, 51, 100, 32, 58, 32, 95,
  109, 111, 100, 101, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 83, 101, 116, 32, 100, 121, 110, 97, 109, 105, 99, 32,
  51, 100, 32, 114, 101, 110, 100, 101, 114, 105, 110, 103, 32, 109, 111, 100,
  101, 32, 102, 111, 114, 32, 105, 110, 116, 101, 114, 97, 99, 116, 105, 118,
  101, 32, 51, 100, 32, 118, 105, 101, 119, 101, 114, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45,
  109, 100, 51, 100, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 39, 109, 111, 100, 101, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123,
  32, 45, 49, 61, 98, 111, 117, 110, 100, 105, 110, 103, 45, 98, 111, 120,
  32, 124, 32, 48, 61, 100, 111, 116, 115, 32, 124, 32, 49, 61, 119, 105,
  114, 101, 102, 114, 97, 109, 101, 32, 124, 32, 50, 61, 102, 108, 97, 116,
  32, 124, 32, 51, 61, 102, 108, 97, 116, 45, 115, 104, 97, 100, 101, 100,
  32, 124, 32, 52, 61, 103, 111, 117, 114, 97, 117, 100, 45, 115, 104, 97,
  100, 101, 100, 32, 124, 32, 53, 61, 112, 104, 111, 110, 103, 45, 115, 104,
  97, 100, 101, 100, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32,
  39, 109, 111, 100, 101, 61, 45, 49, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 42, 51, 100, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39,
  45, 109, 117, 108, 51, 100, 39, 46, 32, 58, 32, 40, 43, 41, 10, 35,
  64, 103, 109, 105, 99, 32, 109, 117, 108, 51, 100, 32, 58, 32, 102, 97,
  99, 116, 111, 114, 32, 58, 32, 102, 97, 99, 116, 111, 114, 95, 120, 44,
  102, 97, 99, 116, 111, 114, 95, 121, 44, 95, 102, 97, 99, 116, 111, 114,
  95, 122, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 83, 99, 97, 108, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 115, 32, 105, 115, 111, 116,
  114, 111, 112, 105, 99, 97, 108, 108, 121, 32, 111, 114, 32, 97, 110, 105,
  115, 111, 116, 114, 111, 112, 105, 99, 97, 108, 108, 121, 44, 32, 119, 105,
  116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 102, 97, 99,
  116, 111, 114, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40,
  101, 113, 46, 32, 116, 111, 32, 39, 45, 42, 51, 100, 39, 41, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116,
  32, 118, 97, 108, 117, 101, 58, 32, 39, 102, 97, 99, 116, 111, 114, 95,
  122, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 45, 116, 111, 114, 117, 115, 51, 100, 32, 53, 44, 50, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 53, 32, 45, 45, 97, 100, 100, 51, 100, 91,
  45, 49, 93, 32, 49, 48, 44, 48, 44, 48, 32, 45, 109, 117, 108, 51,
  100, 91, 45, 49, 93, 32, 49, 46, 50, 32, 45, 99, 111, 108, 111, 114,
  51, 100, 91, 45, 49, 93, 32, 64, 123, 45, 82, 71, 66, 125, 32, 45,
  100, 111, 110, 101, 32, 45, 97, 100, 100, 51, 100, 10, 35, 64, 103, 109,
  105, 99, 32, 110, 51, 100, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32,
  39, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 51, 100, 39, 46, 10,
  110, 51, 100, 32, 58, 10, 45, 95, 110, 111, 114, 109, 97, 108, 105, 122,
  101, 51, 100, 10, 35, 64, 103, 109, 105, 99, 32, 110, 111, 114, 109, 97,
  108, 105, 122, 101, 51, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  78, 111, 114, 109, 97, 108, 105, 122, 101, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 115, 32, 116, 111,
  32, 117, 110, 105, 116, 32, 115, 105, 122, 101, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 110,
  51, 100, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 49, 48, 48, 32, 45, 99, 105,
  114, 99, 108, 101, 51, 100, 32, 123, 63, 40, 51, 41, 125, 44, 123, 63,
  40, 51, 41, 125, 44, 123, 63, 40, 51, 41, 125, 44, 48, 46, 49, 32,
  45, 100, 111, 110, 101, 32, 45, 97, 100, 100, 51, 100, 32, 45, 99, 111,
  108, 111, 114, 51, 100, 91, 45, 49, 93, 32, 50, 53, 53, 44, 48, 44,
  48, 32, 45, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 51, 100, 91,
  45, 49, 93, 32, 45, 99, 111, 108, 111, 114, 51, 100, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 44, 48, 32, 45, 97, 100, 100, 51, 100, 10,
  110, 111, 114, 109, 97, 108, 105, 122, 101, 51, 100, 32, 58, 10, 45, 95,
  36, 48, 10, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 51, 100, 32,
  58, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 78, 111, 114, 109,
  97, 108, 105, 122, 101, 32, 115, 105, 122, 101, 32, 111, 102, 32, 51, 100,
  32, 111, 98, 106, 101, 99, 116, 36, 63, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 99, 104, 101, 99, 107, 51, 100, 32, 48, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 110, 61,
  123, 105, 91, 54, 93, 125, 10, 45, 105, 102, 32, 123, 36, 110, 62, 48,
  125, 10, 45, 115, 104, 32, 56, 44, 123, 55, 43, 51, 42, 36, 110, 125,
  44, 48, 44, 48, 32, 45, 114, 91, 45, 49, 93, 32, 51, 44, 123, 104,
  47, 51, 125, 44, 49, 44, 49, 44, 45, 49, 32, 45, 115, 91, 45, 49,
  93, 32, 120, 10, 45, 115, 104, 91, 45, 52, 93, 32, 56, 44, 123, 55,
  43, 51, 42, 36, 110, 125, 44, 48, 44, 48, 32, 45, 47, 91, 45, 49,
  93, 32, 123, 118, 97, 108, 61, 109, 97, 120, 40, 64, 123, 45, 51, 44,
  105, 77, 125, 45, 64, 123, 45, 51, 44, 105, 109, 125, 44, 64, 123, 45,
  50, 44, 105, 77, 125, 45, 64, 123, 45, 50, 44, 105, 109, 125, 44, 105,
  77, 45, 105, 109, 41, 59, 105, 102, 40, 118, 97, 108, 44, 118, 97, 108,
  44, 49, 41, 125, 10, 45, 114, 109, 91, 45, 52, 45, 45, 49, 93, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 110, 109, 32, 64, 123, 48, 44, 110,
  125, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 111, 51, 100, 32,
  58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 111, 112, 97, 99, 105,
  116, 121, 51, 100, 39, 46, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103,
  109, 105, 99, 32, 111, 112, 97, 99, 105, 116, 121, 51, 100, 32, 58, 32,
  95, 111, 112, 97, 99, 105, 116, 121, 32, 58, 32, 40, 43, 41, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 83, 101, 116, 32, 111, 112, 97, 99,
  105, 116, 121, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  51, 100, 32, 111, 98, 106, 101, 99, 116, 115, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 111,
  51, 100, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 111,
  112, 97, 99, 105, 116, 121, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 45, 116, 111, 114, 117, 115, 51, 100, 32, 49,
  48, 48, 44, 49, 48, 32, 45, 100, 111, 117, 98, 108, 101, 51, 100, 32,
  48, 32, 45, 114, 101, 112, 101, 97, 116, 32, 55, 32, 45, 45, 114, 111,
  116, 97, 116, 101, 51, 100, 91, 45, 49, 93, 32, 49, 44, 48, 44, 48,
  44, 50, 48, 32, 45, 111, 112, 97, 99, 105, 116, 121, 51, 100, 91, 45,
  49, 93, 32, 123, 63, 125, 32, 45, 100, 111, 110, 101, 32, 45, 97, 100,
  100, 51, 100, 10, 35, 64, 103, 109, 105, 99, 32, 112, 97, 114, 97, 109,
  101, 116, 114, 105, 99, 51, 100, 32, 58, 32, 95, 120, 40, 97, 44, 98,
  41, 44, 95, 121, 40, 97, 44, 98, 41, 44, 95, 122, 40, 97, 44, 98,
  41, 44, 95, 97, 109, 105, 110, 44, 95, 97, 109, 97, 120, 44, 95, 98,
  109, 105, 110, 44, 95, 98, 109, 97, 120, 44, 95, 114, 101, 115, 95, 97,
  62, 48, 44, 95, 114, 101, 115, 95, 98, 62, 48, 44, 95, 114, 101, 115,
  95, 120, 62, 48, 44, 95, 114, 101, 115, 95, 121, 62, 48, 44, 95, 114,
  101, 115, 95, 122, 62, 48, 44, 95, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 62, 61, 48, 44, 95, 105, 115, 111, 118, 97, 108, 117, 101, 62,
  61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 110, 112, 117,
  116, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 32, 102, 114, 111, 109,
  32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 112, 97, 114, 97, 109,
  101, 116, 114, 105, 99, 32, 115, 117, 114, 102, 97, 99, 101, 32, 40, 120,
  40, 97, 44, 98, 41, 44, 121, 40, 97, 44, 98, 41, 44, 122, 40, 97,
  44, 98, 41, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39,
  120, 61, 40, 50, 43, 99, 111, 115, 40, 98, 41, 41, 42, 115, 105, 110,
  40, 97, 41, 39, 44, 32, 39, 121, 61, 40, 50, 43, 99, 111, 115, 40,
  98, 41, 41, 42, 99, 111, 115, 40, 97, 41, 39, 44, 32, 39, 99, 61,
  115, 105, 110, 40, 98, 41, 39, 44, 32, 39, 97, 109, 105, 110, 61, 45,
  112, 105, 39, 44, 32, 39, 97, 109, 97, 120, 61, 39, 112, 105, 39, 44,
  32, 39, 98, 109, 105, 110, 61, 45, 112, 105, 39, 44, 32, 39, 98, 109,
  97, 120, 61, 39, 112, 105, 39, 44, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 39, 114, 101, 115, 95, 97, 61, 53, 49, 50, 39, 44, 32, 39,
  114, 101, 115, 95, 98, 61, 114, 101, 115, 95, 97, 39, 44, 32, 39, 114,
  101, 115, 95, 120, 61, 54, 52, 39, 44, 32, 39, 114, 101, 115, 95, 121,
  61, 114, 101, 115, 95, 120, 39, 44, 32, 39, 114, 101, 115, 95, 122, 61,
  114, 101, 115, 95, 121, 39, 44, 32, 39, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 61, 50, 37, 39, 32, 97, 110, 100, 32, 39, 105, 115, 111,
  118, 97, 108, 117, 101, 61, 49, 48, 37, 39, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 45, 112, 97, 114, 97, 109, 101, 116, 114,
  105, 99, 51, 100, 32, 44, 10, 112, 97, 114, 97, 109, 101, 116, 114, 105,
  99, 51, 100, 32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36, 123, 49,
  61, 40, 50, 43, 99, 111, 115, 40, 98, 41, 41, 42, 115, 105, 110, 40,
  97, 41, 125, 34, 44, 34, 36, 123, 50, 61, 40, 50, 43, 99, 111, 115,
  40, 98, 41, 41, 42, 99, 111, 115, 40, 97, 41, 125, 34, 44, 34, 36,
  123, 51, 61, 115, 105, 110, 40, 98, 41, 125, 34, 10, 45, 115, 107, 105,
  112, 32, 36, 123, 52, 61, 123, 45, 112, 105, 125, 125, 44, 36, 123, 53,
  61, 123, 112, 105, 125, 125, 44, 36, 123, 54, 61, 123, 45, 112, 105, 125,
  125, 44, 36, 123, 55, 61, 123, 112, 105, 125, 125, 10, 45, 99, 104, 101,
  99, 107, 32, 34, 36, 123, 56, 61, 53, 49, 50, 125, 62, 48, 32, 38,
  38, 32, 36, 123, 57, 61, 36, 56, 125, 62, 48, 32, 38, 38, 32, 36,
  123, 49, 48, 61, 54, 52, 125, 62, 48, 32, 38, 38, 32, 36, 123, 49,
  49, 61, 36, 49, 48, 125, 62, 48, 32, 38, 38, 32, 36, 123, 49, 50,
  61, 36, 49, 49, 125, 62, 48, 32, 38, 38, 32, 92, 10, 36, 123, 49,
  51, 61, 50, 37, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 49, 52,
  61, 49, 48, 37, 125, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 73, 110, 112, 117, 116, 32, 51, 100, 32, 111, 98, 106, 101,
  99, 116, 32, 102, 114, 111, 109, 32, 112, 97, 114, 97, 109, 101, 116, 114,
  105, 99, 32, 115, 117, 114, 102, 97, 99, 101, 32, 40, 36, 49, 44, 36,
  50, 44, 36, 51, 41, 46, 34, 10, 45, 118, 32, 45, 10, 40, 36, 52,
  44, 36, 53, 59, 36, 52, 44, 36, 53, 94, 36, 54, 44, 36, 54, 59,
  36, 55, 44, 36, 55, 41, 32, 45, 114, 91, 45, 49, 93, 32, 36, 56,
  44, 36, 57, 44, 49, 44, 50, 44, 51, 32, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 91, 45, 49, 93, 32, 48, 44, 50, 10, 45, 102, 91, 45,
  49, 93, 32, 34, 97, 61, 105, 40, 120, 44, 121, 44, 48, 44, 48, 41,
  59, 98, 61, 105, 40, 120, 44, 121, 44, 48, 44, 49, 41, 59, 105, 102,
  40, 99, 61, 61, 48, 44, 36, 49, 44, 105, 102, 40, 99, 61, 61, 49,
  44, 36, 50, 44, 36, 51, 41, 41, 34, 10, 45, 115, 104, 91, 45, 49,
  93, 32, 48, 44, 48, 32, 120, 109, 105, 110, 61, 123, 105, 109, 125, 32,
  120, 109, 97, 120, 61, 123, 105, 77, 125, 32, 45, 110, 91, 45, 49, 93,
  32, 49, 54, 44, 123, 36, 49, 48, 45, 49, 55, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 115, 104, 91, 45, 49, 93, 32, 49, 44, 49,
  32, 121, 109, 105, 110, 61, 123, 105, 109, 125, 32, 121, 109, 97, 120, 61,
  123, 105, 77, 125, 32, 45, 110, 91, 45, 49, 93, 32, 49, 54, 44, 123,
  36, 49, 49, 45, 49, 55, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 115, 104, 91, 45, 49, 93, 32, 50, 44, 50, 32, 122, 109, 105, 110,
  61, 123, 105, 109, 125, 32, 122, 109, 97, 120, 61, 123, 105, 77, 125, 32,
  45, 110, 91, 45, 49, 93, 32, 49, 54, 44, 123, 36, 49, 50, 45, 49,
  55, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 114, 91, 45, 49,
  93, 32, 123, 119, 42, 104, 125, 44, 51, 44, 49, 44, 49, 44, 45, 49,
  10, 45, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 91, 45, 49, 93,
  32, 49, 32, 45, 114, 91, 45, 49, 93, 32, 36, 49, 48, 44, 36, 49,
  49, 44, 36, 49, 50, 44, 49, 44, 48, 32, 45, 98, 91, 45, 49, 93,
  32, 36, 49, 51, 44, 48, 10, 45, 105, 115, 111, 115, 117, 114, 102, 97,
  99, 101, 51, 100, 91, 45, 49, 93, 32, 36, 49, 52, 10, 45, 99, 51,
  100, 91, 45, 49, 93, 32, 45, 110, 51, 100, 91, 45, 49, 93, 32, 45,
  42, 51, 100, 91, 45, 49, 93, 32, 123, 36, 120, 109, 97, 120, 45, 36,
  120, 109, 105, 110, 125, 44, 123, 36, 121, 109, 97, 120, 45, 36, 121, 109,
  105, 110, 125, 44, 123, 36, 122, 109, 97, 120, 45, 36, 122, 109, 105, 110,
  125, 32, 45, 110, 109, 91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 112,
  97, 114, 97, 109, 101, 116, 114, 105, 99, 93, 10, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 112, 99, 97, 95, 112, 97, 116, 99, 104,
  51, 100, 32, 58, 32, 95, 112, 97, 116, 99, 104, 95, 115, 105, 122, 101,
  62, 48, 44, 95, 77, 62, 48, 44, 95, 78, 62, 48, 44, 95, 110, 111,
  114, 109, 97, 108, 105, 122, 101, 95, 105, 110, 112, 117, 116, 61, 123, 32,
  48, 32, 124, 32, 49, 32, 125, 44, 95, 110, 111, 114, 109, 97, 108, 105,
  122, 101, 95, 111, 117, 116, 112, 117, 116, 61, 123, 32, 48, 32, 124, 32,
  49, 32, 125, 44, 95, 108, 97, 109, 98, 100, 97, 95, 120, 121, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 71, 101, 116, 32, 51, 100, 32, 112,
  97, 116, 99, 104, 45, 112, 99, 97, 32, 114, 101, 112, 114, 101, 115, 101,
  110, 116, 97, 116, 105, 111, 110, 32, 111, 102, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 84, 104, 101, 32, 51, 100, 32, 112, 97, 116, 99,
  104, 45, 112, 99, 97, 32, 105, 115, 32, 101, 115, 116, 105, 109, 97, 116,
  101, 100, 32, 102, 114, 111, 109, 32, 77, 32, 112, 97, 116, 99, 104, 101,
  115, 32, 111, 110, 32, 116, 104, 101, 32, 105, 110, 112, 117, 116, 32, 105,
  109, 97, 103, 101, 44, 32, 97, 110, 100, 32, 100, 105, 115, 112, 108, 97,
  121, 101, 100, 32, 97, 115, 32, 97, 32, 99, 108, 111, 117, 100, 32, 111,
  102, 32, 78, 32, 51, 100, 32, 112, 111, 105, 110, 116, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32,
  118, 97, 108, 117, 101, 115, 58, 32, 39, 112, 97, 116, 99, 104, 95, 115,
  105, 122, 101, 61, 55, 39, 44, 32, 39, 77, 61, 49, 48, 48, 48, 39,
  44, 32, 39, 78, 61, 51, 48, 48, 48, 39, 44, 32, 39, 110, 111, 114,
  109, 97, 108, 105, 122, 101, 95, 105, 110, 112, 117, 116, 61, 49, 39, 44,
  32, 39, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 111, 117, 116, 112,
  117, 116, 61, 48, 39, 44, 32, 97, 110, 100, 32, 39, 108, 97, 109, 98,
  100, 97, 95, 120, 121, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  112, 99, 97, 95, 112, 97, 116, 99, 104, 51, 100, 32, 55, 10, 112, 99,
  97, 95, 112, 97, 116, 99, 104, 51, 100, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 55, 125,
  41, 32, 38, 38, 32, 36, 49, 62, 48, 32, 38, 38, 32, 105, 115, 105,
  110, 116, 40, 36, 123, 50, 61, 49, 48, 48, 48, 125, 41, 32, 38, 38,
  32, 36, 50, 62, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36,
  123, 51, 61, 51, 48, 48, 48, 125, 41, 32, 38, 38, 32, 36, 51, 62,
  48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 52, 61, 49, 125, 44,
  36, 123, 53, 61, 48, 125, 44, 36, 123, 54, 61, 48, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 71, 101, 116, 32, 51, 100, 32, 112, 97,
  116, 99, 104, 45, 112, 99, 97, 32, 114, 101, 112, 114, 101, 115, 101, 110,
  116, 97, 116, 105, 111, 110, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49,
  43, 40, 64, 35, 62, 49, 41, 44, 115, 44, 34, 34, 125, 34, 32, 111,
  102, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 102, 114, 111, 109, 32,
  36, 50, 32, 36, 49, 120, 36, 49, 32, 105, 110, 112, 117, 116, 32, 112,
  97, 116, 99, 104, 115, 44, 10, 119, 105, 116, 104, 32, 36, 51, 32, 111,
  117, 116, 112, 117, 116, 32, 112, 97, 116, 99, 104, 115, 44, 32, 105, 110,
  112, 117, 116, 32, 110, 111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111,
  110, 32, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 33, 36, 52,
  44, 101, 110, 97, 98, 108, 101, 100, 44, 100, 105, 115, 97, 98, 108, 101,
  100, 125, 34, 44, 32, 111, 117, 116, 112, 117, 116, 32, 110, 111, 114, 109,
  97, 108, 105, 122, 97, 116, 105, 111, 110, 10, 34, 64, 123, 45, 97, 114,
  103, 92, 32, 49, 43, 33, 36, 53, 44, 101, 110, 97, 98, 108, 101, 100,
  44, 100, 105, 115, 97, 98, 108, 101, 100, 125, 34, 32, 97, 110, 100, 32,
  108, 97, 109, 98, 100, 97, 95, 120, 121, 32, 36, 54, 46, 34, 10, 45,
  118, 32, 45, 10, 80, 49, 61, 123, 105, 110, 116, 40, 36, 49, 47, 50,
  41, 125, 10, 80, 50, 61, 123, 36, 49, 45, 36, 80, 49, 45, 49, 125,
  10, 45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 114, 111, 117, 110, 100,
  32, 49, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 115,
  61, 123, 115, 125, 10, 49, 44, 36, 50, 32, 45, 114, 97, 110, 100, 91,
  45, 49, 93, 32, 48, 44, 64, 123, 48, 44, 119, 45, 49, 125, 32, 45,
  45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44, 64, 123, 48, 44,
  104, 45, 49, 125, 32, 45, 45, 102, 91, 45, 49, 93, 32, 48, 32, 45,
  97, 91, 45, 51, 45, 45, 49, 93, 32, 120, 32, 45, 114, 111, 117, 110,
  100, 91, 45, 49, 93, 32, 49, 32, 45, 45, 112, 97, 116, 99, 104, 101,
  115, 91, 48, 93, 32, 36, 49, 44, 36, 49, 44, 49, 44, 64, 45, 49,
  32, 45, 121, 91, 50, 45, 45, 49, 93, 32, 45, 97, 91, 50, 45, 45,
  49, 93, 32, 120, 10, 45, 122, 91, 49, 93, 32, 48, 44, 49, 32, 45,
  116, 114, 97, 110, 115, 112, 111, 115, 101, 91, 49, 93, 32, 45, 42, 91,
  49, 93, 32, 36, 54, 32, 45, 97, 91, 49, 44, 50, 93, 32, 121, 32,
  45, 115, 91, 94, 48, 93, 32, 120, 10, 45, 45, 43, 91, 94, 48, 93,
  32, 45, 47, 91, 45, 49, 93, 32, 36, 50, 32, 45, 45, 91, 49, 45,
  45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 97, 91, 94, 48, 93, 32, 120, 10, 45, 105, 102, 32, 36, 52,
  32, 45, 108, 91, 45, 49, 93, 32, 45, 115, 32, 121, 32, 45, 47, 32,
  39, 115, 113, 114, 116, 40, 49, 101, 45, 56, 43, 105, 118, 41, 39, 32,
  45, 97, 32, 121, 32, 45, 101, 110, 100, 108, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 45, 116, 114, 97, 110, 115, 112, 111, 115, 101, 91, 45, 49,
  93, 32, 45, 42, 42, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 105,
  103, 101, 110, 91, 45, 49, 93, 32, 45, 114, 111, 119, 115, 91, 45, 50,
  93, 32, 48, 44, 50, 32, 45, 99, 111, 108, 117, 109, 110, 115, 91, 45,
  49, 93, 32, 48, 44, 50, 32, 45, 116, 114, 97, 110, 115, 112, 111, 115,
  101, 91, 45, 49, 93, 10, 45, 105, 102, 32, 36, 53, 32, 45, 115, 113,
  114, 116, 91, 45, 50, 93, 32, 45, 47, 91, 45, 50, 93, 32, 64, 123,
  45, 50, 44, 77, 125, 32, 45, 114, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 32, 45, 47, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 50, 93, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 36, 51, 10, 120, 61, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 64, 123, 48, 44, 119, 125, 41, 41, 125, 10, 121, 61, 123,
  114, 111, 117, 110, 100, 40, 63, 40, 64, 123, 48, 44, 104, 125, 41, 41,
  125, 10, 40, 123, 36, 54, 42, 36, 120, 125, 59, 123, 36, 54, 42, 36,
  121, 125, 41, 10, 45, 45, 122, 91, 48, 93, 32, 123, 36, 120, 45, 36,
  80, 49, 125, 44, 123, 36, 121, 45, 36, 80, 49, 125, 44, 123, 36, 120,
  43, 36, 80, 50, 125, 44, 123, 36, 121, 43, 36, 80, 50, 125, 44, 49,
  10, 45, 121, 91, 45, 49, 93, 32, 45, 97, 91, 45, 50, 44, 45, 49,
  93, 32, 121, 10, 45, 100, 111, 110, 101, 10, 45, 45, 97, 91, 50, 45,
  45, 49, 93, 32, 120, 32, 45, 42, 42, 91, 49, 44, 45, 49, 93, 32,
  45, 116, 114, 97, 110, 115, 112, 111, 115, 101, 91, 49, 93, 10, 45, 114,
  111, 119, 115, 91, 50, 45, 45, 49, 93, 32, 50, 44, 49, 48, 48, 37,
  10, 45, 105, 102, 32, 123, 36, 115, 33, 61, 51, 125, 10, 45, 114, 91,
  50, 45, 45, 49, 93, 32, 36, 49, 44, 36, 49, 44, 49, 44, 123, 109,
  105, 110, 40, 51, 44, 36, 115, 41, 125, 44, 45, 49, 10, 45, 114, 91,
  50, 45, 45, 49, 93, 32, 36, 49, 44, 36, 49, 44, 49, 44, 51, 44,
  123, 105, 102, 40, 36, 115, 33, 61, 49, 44, 48, 44, 49, 41, 125, 10,
  45, 121, 91, 50, 45, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 91, 50, 45, 45, 50, 93, 32, 40, 45, 49, 50, 56, 59, 36,
  49, 59, 36, 49, 59, 51, 41, 32, 45, 97, 91, 50, 45, 45, 49, 93,
  32, 121, 10, 45, 114, 109, 91, 48, 93, 10, 45, 105, 91, 48, 93, 32,
  40, 123, 39, 67, 73, 109, 103, 51, 100, 39, 125, 41, 10, 45, 105, 91,
  49, 93, 32, 40, 36, 51, 59, 36, 51, 41, 10, 45, 105, 91, 51, 93,
  32, 50, 44, 36, 51, 44, 49, 44, 49, 44, 105, 102, 40, 120, 61, 61,
  48, 44, 49, 44, 121, 41, 10, 49, 44, 36, 51, 44, 49, 44, 49, 44,
  49, 10, 45, 121, 32, 45, 97, 91, 45, 54, 45, 45, 49, 93, 32, 121,
  10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109,
  105, 99, 32, 112, 108, 97, 110, 101, 51, 100, 32, 58, 32, 95, 115, 105,
  122, 101, 95, 120, 44, 95, 115, 105, 122, 101, 95, 121, 44, 95, 110, 98,
  95, 115, 117, 98, 100, 105, 118, 105, 115, 105, 111, 110, 115, 95, 120, 62,
  48, 44, 95, 110, 98, 95, 115, 117, 98, 100, 105, 115, 105, 118, 105, 111,
  110, 115, 95, 121, 62, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  73, 110, 112, 117, 116, 32, 51, 100, 32, 112, 108, 97, 110, 101, 32, 97,
  116, 32, 40, 48, 44, 48, 44, 48, 41, 44, 32, 119, 105, 116, 104, 32,
  115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 103, 101, 111, 109, 101, 116,
  114, 121, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 115, 105,
  122, 101, 95, 120, 61, 49, 39, 44, 32, 39, 115, 105, 122, 101, 95, 121,
  61, 115, 105, 122, 101, 95, 120, 39, 32, 97, 110, 100, 32, 39, 110, 98,
  95, 115, 117, 98, 100, 105, 118, 105, 115, 105, 111, 110, 115, 95, 120, 61,
  110, 98, 95, 115, 117, 98, 100, 105, 118, 105, 115, 105, 111, 110, 115, 95,
  121, 61, 50, 52, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 45, 112, 108, 97, 110, 101, 51, 100, 32, 53, 48, 44, 51, 48,
  32, 45, 45, 112, 114, 105, 109, 105, 116, 105, 118, 101, 115, 51, 100, 32,
  49, 32, 45, 99, 111, 108, 111, 114, 51, 100, 91, 45, 50, 93, 32, 64,
  123, 45, 82, 71, 66, 125, 10, 112, 108, 97, 110, 101, 51, 100, 32, 58,
  32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 51, 61, 50, 52, 125,
  62, 48, 32, 38, 38, 32, 36, 123, 52, 61, 50, 52, 125, 62, 48, 34,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 125, 44, 36, 123,
  50, 61, 36, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73,
  110, 112, 117, 116, 32, 51, 100, 32, 112, 108, 97, 110, 101, 44, 32, 119,
  105, 116, 104, 32, 115, 105, 122, 101, 32, 40, 36, 123, 49, 44, 50, 125,
  41, 32, 97, 110, 100, 32, 115, 117, 98, 100, 105, 118, 105, 115, 105, 111,
  110, 115, 32, 40, 36, 123, 51, 44, 52, 125, 41, 46, 34, 10, 45, 118,
  32, 45, 32, 123, 36, 51, 43, 49, 125, 44, 123, 36, 52, 43, 49, 125,
  32, 45, 101, 108, 101, 118, 97, 116, 105, 111, 110, 51, 100, 91, 45, 49,
  93, 32, 48, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 123, 36, 49,
  47, 36, 51, 125, 44, 123, 36, 50, 47, 36, 52, 125, 32, 45, 99, 111,
  108, 51, 100, 91, 45, 49, 93, 32, 50, 48, 48, 32, 45, 110, 109, 91,
  45, 49, 93, 32, 91, 51, 100, 92, 32, 112, 108, 97, 110, 101, 93, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 112, 111, 105, 110,
  116, 51, 100, 32, 58, 32, 120, 48, 44, 121, 48, 44, 122, 48, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 73, 110, 112, 117, 116, 32, 51, 100,
  32, 112, 111, 105, 110, 116, 32, 97, 116, 32, 115, 112, 101, 99, 105, 102,
  105, 101, 100, 32, 99, 111, 111, 114, 100, 105, 110, 97, 116, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 49, 48, 48, 48, 32, 97, 61, 123, 36, 62, 42, 112,
  105, 47, 53, 48, 48, 125, 32, 45, 112, 111, 105, 110, 116, 51, 100, 32,
  123, 99, 111, 115, 40, 51, 42, 36, 97, 41, 125, 44, 123, 115, 105, 110,
  40, 50, 42, 36, 97, 41, 125, 44, 48, 32, 45, 99, 111, 108, 111, 114,
  51, 100, 91, 45, 49, 93, 32, 64, 123, 45, 82, 71, 66, 125, 32, 45,
  100, 111, 110, 101, 32, 45, 97, 100, 100, 51, 100, 10, 112, 111, 105, 110,
  116, 51, 100, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73,
  110, 112, 117, 116, 32, 51, 100, 32, 112, 111, 105, 110, 116, 32, 40, 36,
  49, 44, 36, 50, 44, 36, 51, 41, 46, 34, 10, 45, 118, 32, 45, 32,
  49, 44, 49, 55, 44, 49, 44, 49, 44, 54, 55, 46, 53, 44, 55, 51,
  46, 53, 44, 49, 48, 57, 46, 53, 44, 49, 48, 51, 46, 53, 44, 53,
  49, 46, 53, 44, 49, 48, 48, 46, 53, 44, 49, 44, 49, 44, 36, 123,
  49, 45, 51, 125, 44, 49, 44, 48, 44, 50, 48, 48, 44, 50, 48, 48,
  44, 50, 48, 48, 44, 49, 32, 45, 110, 109, 91, 45, 49, 93, 32, 91,
  51, 100, 92, 32, 112, 111, 105, 110, 116, 93, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 112, 111, 105, 110, 116, 99, 108, 111, 117,
  100, 51, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110,
  118, 101, 114, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 112, 108,
  97, 110, 97, 114, 32, 111, 114, 32, 118, 111, 108, 117, 109, 101, 116, 114,
  105, 99, 32, 105, 109, 97, 103, 101, 115, 32, 116, 111, 32, 51, 100, 32,
  112, 111, 105, 110, 116, 32, 99, 108, 111, 117, 100, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 114,
  101, 115, 105, 122, 101, 50, 100, 121, 32, 49, 48, 48, 32, 45, 116, 104,
  114, 101, 115, 104, 111, 108, 100, 32, 53, 48, 37, 32, 45, 42, 32, 50,
  53, 53, 32, 45, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 51, 100,
  32, 45, 99, 111, 108, 111, 114, 51, 100, 91, 45, 49, 93, 32, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 112, 111, 105, 110, 116, 99,
  108, 111, 117, 100, 51, 100, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36,
  63, 32, 116, 111, 32, 51, 100, 32, 112, 111, 105, 110, 116, 32, 99, 108,
  111, 117, 100, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109,
  61, 64, 123, 48, 44, 110, 125, 10, 45, 115, 32, 122, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45,
  45, 110, 111, 114, 109, 32, 45, 33, 61, 91, 45, 49, 93, 32, 48, 10,
  45, 105, 91, 45, 50, 93, 32, 40, 49, 44, 123, 119, 125, 59, 49, 44,
  123, 119, 125, 94, 49, 44, 49, 59, 123, 104, 125, 44, 123, 104, 125, 41,
  32, 45, 114, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 91, 45, 49,
  93, 44, 49, 44, 50, 44, 51, 32, 45, 42, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 45, 112, 101,
  114, 109, 117, 116, 101, 91, 45, 49, 93, 32, 99, 120, 121, 122, 10, 45,
  108, 91, 45, 49, 93, 32, 45, 115, 32, 45, 44, 48, 32, 45, 97, 32,
  121, 32, 105, 115, 95, 112, 111, 105, 110, 116, 115, 61, 64, 35, 32, 45,
  101, 110, 100, 108, 10, 45, 105, 102, 32, 36, 105, 115, 95, 112, 111, 105,
  110, 116, 115, 10, 45, 45, 91, 45, 49, 93, 32, 49, 32, 45, 114, 91,
  45, 49, 93, 32, 50, 44, 123, 104, 47, 50, 125, 44, 49, 44, 49, 44,
  45, 49, 32, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 49, 93, 32,
  99, 121, 122, 120, 32, 45, 45, 119, 97, 114, 112, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 51, 93,
  10, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 50, 93, 32, 99, 121,
  122, 120, 32, 45, 105, 91, 45, 50, 93, 32, 49, 44, 123, 104, 125, 44,
  49, 44, 49, 44, 36, 62, 32, 45, 97, 91, 45, 51, 44, 45, 50, 93,
  32, 120, 10, 45, 105, 91, 45, 51, 93, 32, 40, 123, 39, 67, 73, 109,
  103, 51, 100, 39, 125, 41, 32, 45, 105, 91, 45, 51, 93, 32, 40, 123,
  104, 125, 44, 123, 104, 125, 41, 10, 45, 105, 91, 45, 50, 93, 32, 49,
  44, 123, 104, 125, 44, 49, 44, 49, 44, 49, 32, 45, 105, 91, 45, 50,
  93, 32, 49, 44, 123, 104, 125, 44, 49, 44, 49, 44, 121, 32, 45, 97,
  91, 45, 51, 44, 45, 50, 93, 32, 120, 10, 45, 112, 101, 114, 109, 117,
  116, 101, 91, 45, 49, 93, 32, 99, 121, 122, 120, 10, 45, 105, 102, 32,
  123, 119, 61, 61, 49, 125, 32, 45, 114, 91, 45, 49, 93, 32, 51, 44,
  123, 104, 125, 44, 49, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123, 119,
  62, 51, 125, 32, 45, 105, 91, 45, 50, 93, 32, 52, 44, 123, 104, 125,
  44, 49, 44, 49, 44, 45, 49, 50, 56, 44, 49, 44, 49, 44, 123, 119,
  125, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 10, 45, 101,
  108, 115, 101, 32, 45, 114, 91, 45, 49, 93, 32, 51, 44, 123, 104, 125,
  44, 49, 44, 49, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 49, 44,
  123, 104, 125, 44, 49, 44, 49, 44, 49, 10, 45, 121, 91, 45, 54, 45,
  45, 49, 93, 32, 45, 97, 91, 45, 54, 45, 45, 49, 93, 32, 121, 10,
  45, 101, 108, 115, 101, 32, 45, 114, 109, 32, 45, 101, 109, 112, 116, 121,
  51, 100, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 45, 43, 51, 100, 10, 45, 110, 109, 32, 36,
  110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 112, 111, 115,
  101, 51, 100, 32, 58, 32, 118, 97, 108, 117, 101, 49, 44, 46, 46, 44,
  118, 97, 108, 117, 101, 49, 54, 32, 58, 32, 40, 110, 111, 97, 114, 103,
  115, 41, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 83, 101, 116, 32, 116, 104, 101, 32, 99, 111, 101, 102, 102, 105,
  99, 105, 101, 110, 116, 115, 32, 111, 102, 32, 116, 104, 101, 32, 51, 100,
  32, 112, 111, 115, 101, 32, 109, 97, 116, 114, 105, 120, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 40, 110, 111, 97, 114, 103, 115, 41, 32,
  114, 101, 115, 101, 116, 115, 32, 116, 104, 101, 32, 51, 100, 32, 112, 111,
  115, 101, 32, 109, 97, 116, 114, 105, 120, 32, 116, 111, 32, 100, 101, 102,
  97, 117, 108, 116, 46, 10, 35, 64, 103, 109, 105, 99, 32, 112, 51, 100,
  32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 112, 114, 105, 109,
  105, 116, 105, 118, 101, 115, 51, 100, 39, 46, 32, 58, 32, 40, 43, 41,
  10, 35, 64, 103, 109, 105, 99, 32, 112, 114, 105, 109, 105, 116, 105, 118,
  101, 115, 51, 100, 32, 58, 32, 109, 111, 100, 101, 32, 58, 32, 40, 43,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101,
  114, 116, 32, 112, 114, 105, 109, 105, 116, 105, 118, 101, 115, 32, 111, 102,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 51, 100, 32, 111, 98, 106,
  101, 99, 116, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40,
  101, 113, 46, 32, 116, 111, 32, 39, 45, 112, 51, 100, 39, 41, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 109, 111, 100, 101, 39, 32,
  99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 112, 111, 105, 110, 116,
  115, 32, 124, 32, 49, 61, 115, 101, 103, 109, 101, 110, 116, 115, 32, 124,
  32, 50, 61, 110, 111, 110, 45, 116, 101, 120, 116, 117, 114, 101, 100, 32,
  125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 115,
  112, 104, 101, 114, 101, 51, 100, 32, 51, 48, 32, 45, 112, 114, 105, 109,
  105, 116, 105, 118, 101, 115, 51, 100, 32, 49, 32, 45, 116, 111, 114, 117,
  115, 51, 100, 32, 53, 48, 44, 49, 48, 32, 45, 99, 111, 108, 111, 114,
  51, 100, 91, 45, 49, 93, 32, 64, 123, 45, 82, 71, 66, 125, 32, 45,
  97, 100, 100, 51, 100, 10, 35, 64, 103, 109, 105, 99, 32, 112, 114, 111,
  106, 101, 99, 116, 105, 111, 110, 115, 51, 100, 32, 58, 32, 95, 120, 91,
  37, 93, 44, 95, 121, 91, 37, 93, 44, 95, 122, 91, 37, 93, 44, 95,
  105, 115, 95, 98, 111, 117, 110, 100, 105, 110, 103, 95, 98, 111, 120, 61,
  123, 32, 48, 32, 124, 32, 49, 32, 125, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 71, 101, 110, 101, 114, 97, 116, 101, 32, 51, 100, 32, 120,
  121, 44, 120, 122, 44, 121, 122, 32, 112, 114, 111, 106, 101, 99, 116, 105,
  111, 110, 32, 112, 108, 97, 110, 101, 115, 32, 102, 114, 111, 109, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 118, 111, 108, 117, 109, 101, 116,
  114, 105, 99, 32, 105, 109, 97, 103, 101, 115, 46, 10, 112, 114, 111, 106,
  101, 99, 116, 105, 111, 110, 115, 51, 100, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 49, 61, 53, 48, 37, 125, 44, 36, 123, 50, 61, 53,
  48, 37, 125, 44, 36, 123, 51, 61, 53, 48, 37, 125, 44, 36, 123, 52,
  61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 71, 101, 110,
  101, 114, 97, 116, 101, 32, 51, 100, 32, 120, 121, 44, 120, 122, 44, 121,
  122, 32, 112, 114, 111, 106, 101, 99, 116, 105, 111, 110, 32, 112, 108, 97,
  110, 101, 115, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36, 63,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 110, 32, 48, 44, 50, 53, 53,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 32, 100,
  61, 123, 100, 125, 10, 120, 61, 123, 105, 102, 40, 64, 123, 45, 105, 115,
  95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 49, 125, 44, 36, 49,
  42, 119, 44, 36, 49, 41, 125, 10, 121, 61, 123, 105, 102, 40, 64, 123,
  45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 50, 125,
  44, 36, 50, 42, 104, 44, 36, 50, 41, 125, 10, 122, 61, 123, 105, 102,
  40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32,
  36, 51, 125, 44, 36, 51, 42, 100, 44, 36, 51, 41, 125, 10, 45, 45,
  114, 111, 119, 115, 32, 36, 50, 44, 36, 50, 32, 45, 114, 91, 45, 49,
  93, 32, 123, 119, 125, 44, 123, 100, 125, 44, 49, 44, 49, 48, 48, 37,
  44, 45, 49, 10, 45, 45, 99, 111, 108, 117, 109, 110, 115, 91, 45, 50,
  93, 32, 36, 49, 44, 36, 49, 32, 45, 112, 101, 114, 109, 117, 116, 101,
  91, 45, 49, 93, 32, 122, 121, 120, 99, 10, 45, 115, 108, 105, 99, 101,
  115, 91, 45, 51, 93, 32, 36, 51, 44, 36, 51, 32, 45, 114, 91, 45,
  51, 45, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  49, 44, 51, 10, 45, 105, 109, 97, 103, 101, 112, 108, 97, 110, 101, 51,
  100, 91, 45, 51, 45, 45, 49, 93, 10, 45, 114, 51, 100, 91, 45, 49,
  93, 32, 48, 44, 49, 44, 48, 44, 57, 48, 32, 45, 114, 51, 100, 91,
  45, 50, 93, 32, 49, 44, 48, 44, 48, 44, 45, 57, 48, 10, 45, 43,
  51, 100, 91, 45, 51, 93, 32, 48, 44, 48, 44, 36, 122, 32, 45, 43,
  51, 100, 91, 45, 50, 93, 32, 48, 44, 36, 121, 44, 48, 32, 45, 43,
  51, 100, 91, 45, 49, 93, 32, 36, 120, 44, 48, 44, 48, 10, 45, 43,
  51, 100, 91, 45, 51, 45, 45, 49, 93, 32, 45, 111, 51, 100, 91, 45,
  49, 93, 32, 48, 46, 56, 10, 45, 105, 102, 32, 36, 52, 32, 45, 98,
  111, 120, 51, 100, 32, 36, 119, 44, 36, 104, 44, 36, 100, 32, 45, 112,
  51, 100, 91, 45, 49, 93, 32, 49, 32, 45, 111, 51, 100, 91, 45, 49,
  93, 32, 48, 46, 52, 32, 45, 43, 51, 100, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 112, 121, 114, 97, 109, 105, 100, 51, 100, 32, 58, 32, 119, 105, 100,
  116, 104, 44, 104, 101, 105, 103, 104, 116, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 73, 110, 112, 117, 116, 32, 51, 100, 32, 112, 121, 114, 97,
  109, 105, 100, 32, 97, 116, 32, 40, 48, 44, 48, 44, 48, 41, 44, 32,
  119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 103,
  101, 111, 109, 101, 116, 114, 121, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 45, 112, 121, 114, 97, 109, 105, 100, 51, 100, 32, 49,
  48, 48, 44, 49, 48, 48, 32, 45, 45, 112, 114, 105, 109, 105, 116, 105,
  118, 101, 115, 51, 100, 32, 49, 32, 45, 99, 111, 108, 111, 114, 51, 100,
  91, 45, 50, 93, 32, 64, 123, 45, 82, 71, 66, 125, 10, 112, 121, 114,
  97, 109, 105, 100, 51, 100, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 73, 110, 112, 117, 116, 32, 110, 101, 119, 32, 51, 100, 32, 112,
  121, 114, 97, 109, 105, 100, 44, 32, 119, 105, 116, 104, 32, 119, 105, 100,
  116, 104, 32, 36, 49, 32, 97, 110, 100, 32, 104, 101, 105, 103, 104, 116,
  32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 10, 40, 54, 55, 46, 53,
  59, 55, 51, 46, 53, 59, 49, 48, 57, 46, 53, 59, 49, 48, 51, 46,
  53, 59, 53, 49, 46, 53, 59, 49, 48, 48, 46, 53, 59, 92, 10, 53,
  59, 53, 59, 92, 10, 123, 45, 36, 49, 47, 50, 125, 59, 123, 45, 36,
  49, 47, 50, 125, 59, 123, 45, 36, 50, 47, 50, 125, 59, 92, 10, 123,
  36, 49, 47, 50, 125, 59, 123, 45, 36, 49, 47, 50, 125, 59, 123, 45,
  36, 50, 47, 50, 125, 59, 92, 10, 123, 36, 49, 47, 50, 125, 59, 123,
  36, 49, 47, 50, 125, 59, 123, 45, 36, 50, 47, 50, 125, 59, 92, 10,
  123, 45, 36, 49, 47, 50, 125, 59, 123, 36, 49, 47, 50, 125, 59, 123,
  45, 36, 50, 47, 50, 125, 59, 92, 10, 48, 59, 48, 59, 123, 36, 50,
  47, 50, 125, 59, 92, 10, 52, 59, 48, 59, 51, 59, 50, 59, 49, 59,
  92, 10, 51, 59, 48, 59, 52, 59, 51, 59, 92, 10, 51, 59, 49, 59,
  52, 59, 48, 59, 92, 10, 51, 59, 50, 59, 52, 59, 49, 59, 92, 10,
  51, 59, 51, 59, 52, 59, 50, 41, 10, 49, 44, 49, 53, 44, 49, 44,
  49, 44, 50, 48, 48, 32, 49, 44, 53, 44, 49, 44, 49, 44, 49, 32,
  45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 121, 32, 45, 110, 109, 91,
  45, 49, 93, 32, 91, 51, 100, 92, 32, 112, 121, 114, 97, 109, 105, 100,
  93, 10, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 113, 117,
  97, 100, 114, 97, 110, 103, 108, 101, 51, 100, 32, 58, 32, 120, 48, 44,
  121, 48, 44, 122, 48, 44, 120, 49, 44, 121, 49, 44, 122, 49, 44, 120,
  50, 44, 121, 50, 44, 122, 50, 44, 120, 51, 44, 121, 51, 44, 122, 51,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 110, 112, 117, 116, 32,
  51, 100, 32, 113, 117, 97, 100, 114, 97, 110, 103, 108, 101, 32, 97, 116,
  32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 99, 111, 111, 114, 100,
  105, 110, 97, 116, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 45, 113, 117, 97, 100, 114, 97, 110, 103, 108, 101, 51, 100,
  32, 45, 49, 48, 44, 45, 49, 48, 44, 49, 48, 44, 49, 48, 44, 45,
  49, 48, 44, 49, 48, 44, 49, 48, 44, 49, 48, 44, 49, 48, 44, 45,
  49, 48, 44, 49, 48, 44, 49, 48, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 49, 48, 32, 45, 45, 114, 111, 116, 97, 116, 101, 51, 100, 91, 45,
  49, 93, 32, 48, 44, 49, 44, 48, 44, 51, 48, 32, 45, 99, 111, 108,
  111, 114, 51, 100, 91, 45, 49, 93, 32, 64, 123, 45, 82, 71, 66, 125,
  44, 48, 46, 54, 32, 45, 100, 111, 110, 101, 32, 45, 97, 100, 100, 51,
  100, 32, 45, 109, 111, 100, 101, 51, 100, 32, 50, 10, 113, 117, 97, 100,
  114, 97, 110, 103, 108, 101, 51, 100, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 51, 100, 32, 113, 117, 97,
  100, 114, 97, 110, 103, 108, 101, 32, 40, 36, 49, 44, 36, 50, 44, 36,
  51, 41, 45, 40, 36, 52, 44, 36, 53, 44, 36, 54, 41, 45, 40, 36,
  55, 44, 36, 56, 44, 36, 57, 41, 45, 40, 36, 49, 48, 44, 36, 49,
  49, 44, 36, 49, 50, 41, 46, 34, 10, 45, 118, 32, 45, 32, 49, 44,
  50, 57, 44, 49, 44, 49, 44, 54, 55, 46, 53, 44, 55, 51, 46, 53,
  44, 49, 48, 57, 46, 53, 44, 49, 48, 51, 46, 53, 44, 53, 49, 46,
  53, 44, 49, 48, 48, 46, 53, 44, 52, 44, 49, 44, 36, 123, 49, 45,
  49, 50, 125, 44, 52, 44, 48, 44, 49, 44, 50, 44, 51, 44, 50, 48,
  48, 44, 50, 48, 48, 44, 50, 48, 48, 44, 49, 32, 45, 110, 109, 91,
  45, 49, 93, 32, 91, 51, 100, 92, 32, 113, 117, 97, 100, 114, 97, 110,
  103, 108, 101, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 114, 118, 51, 100, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39,
  45, 114, 101, 118, 101, 114, 115, 101, 51, 100, 39, 46, 32, 58, 32, 40,
  43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 114, 101, 118, 101, 114, 115,
  101, 51, 100, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 82, 101, 118, 101, 114, 115, 101, 32, 112, 114, 105, 109, 105,
  116, 105, 118, 101, 32, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110,
  115, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 51, 100,
  32, 111, 98, 106, 101, 99, 116, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 114, 118, 51,
  100, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  45, 116, 111, 114, 117, 115, 51, 100, 32, 49, 48, 48, 44, 52, 48, 32,
  45, 100, 111, 117, 98, 108, 101, 51, 100, 32, 48, 32, 45, 45, 114, 101,
  118, 101, 114, 115, 101, 51, 100, 10, 35, 64, 103, 109, 105, 99, 32, 114,
  51, 100, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 114, 111,
  116, 97, 116, 101, 51, 100, 39, 46, 32, 58, 32, 40, 43, 41, 10, 35,
  64, 103, 109, 105, 99, 32, 114, 111, 116, 97, 116, 101, 51, 100, 32, 58,
  32, 117, 44, 118, 44, 119, 44, 97, 110, 103, 108, 101, 32, 58, 32, 40,
  43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 111, 116, 97,
  116, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 51, 100, 32, 111,
  98, 106, 101, 99, 116, 115, 32, 97, 114, 111, 117, 110, 100, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 97, 120, 105, 115, 32, 119, 105, 116,
  104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 97, 110, 103, 108,
  101, 32, 40, 105, 110, 32, 100, 101, 103, 46, 41, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45,
  114, 51, 100, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 45, 116, 111, 114, 117, 115, 51, 100, 32, 49, 48, 48, 44, 49,
  48, 32, 45, 100, 111, 117, 98, 108, 101, 51, 100, 32, 48, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 55, 32, 45, 45, 114, 111, 116, 97, 116, 101,
  51, 100, 91, 45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 50, 48, 32,
  45, 100, 111, 110, 101, 32, 45, 97, 100, 100, 51, 100, 10, 35, 64, 103,
  109, 105, 99, 32, 114, 111, 116, 97, 116, 105, 111, 110, 51, 100, 32, 58,
  32, 117, 44, 118, 44, 119, 44, 97, 110, 103, 108, 101, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 73, 110, 112, 117, 116, 32, 51, 120, 51, 32,
  114, 111, 116, 97, 116, 105, 111, 110, 32, 109, 97, 116, 114, 105, 120, 32,
  119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 97,
  120, 105, 115, 32, 97, 110, 100, 32, 97, 110, 103, 108, 101, 32, 40, 105,
  110, 32, 100, 101, 103, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 45, 114, 111, 116, 97, 116, 105, 111, 110, 51, 100, 32, 49,
  44, 48, 44, 48, 44, 48, 32, 45, 114, 111, 116, 97, 116, 105, 111, 110,
  51, 100, 32, 49, 44, 48, 44, 48, 44, 57, 48, 32, 45, 114, 111, 116,
  97, 116, 105, 111, 110, 51, 100, 32, 49, 44, 48, 44, 48, 44, 49, 56,
  48, 10, 114, 111, 116, 97, 116, 105, 111, 110, 51, 100, 32, 58, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 51, 100,
  32, 114, 111, 116, 97, 116, 105, 111, 110, 32, 109, 97, 116, 114, 105, 120,
  32, 97, 114, 111, 117, 110, 100, 32, 97, 120, 105, 115, 32, 40, 36, 49,
  44, 36, 50, 44, 36, 51, 41, 32, 119, 105, 116, 104, 32, 97, 110, 103,
  108, 101, 32, 36, 52, 32, 100, 101, 103, 46, 34, 10, 45, 118, 32, 45,
  10, 40, 36, 49, 94, 36, 50, 94, 36, 51, 94, 48, 41, 32, 45, 111,
  114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 91, 45, 49, 93, 32, 45,
  121, 91, 45, 49, 93, 32, 120, 32, 45, 42, 91, 45, 49, 93, 32, 123,
  115, 105, 110, 40, 36, 52, 42, 112, 105, 47, 51, 54, 48, 41, 125, 32,
  45, 61, 91, 45, 49, 93, 32, 123, 99, 111, 115, 40, 36, 52, 42, 112,
  105, 47, 51, 54, 48, 41, 125, 44, 51, 10, 120, 120, 61, 123, 105, 40,
  48, 41, 42, 105, 40, 48, 41, 125, 32, 120, 121, 61, 123, 105, 40, 48,
  41, 42, 105, 40, 49, 41, 125, 32, 120, 122, 61, 123, 105, 40, 48, 41,
  42, 105, 40, 50, 41, 125, 32, 120, 119, 61, 123, 105, 40, 48, 41, 42,
  105, 40, 51, 41, 125, 10, 121, 121, 61, 123, 105, 40, 49, 41, 42, 105,
  40, 49, 41, 125, 32, 121, 122, 61, 123, 105, 40, 49, 41, 42, 105, 40,
  50, 41, 125, 32, 121, 119, 61, 123, 105, 40, 49, 41, 42, 105, 40, 51,
  41, 125, 10, 122, 122, 61, 123, 105, 40, 50, 41, 42, 105, 40, 50, 41,
  125, 32, 122, 119, 61, 123, 105, 40, 50, 41, 42, 105, 40, 51, 41, 125,
  10, 45, 114, 109, 91, 45, 49, 93, 10, 40, 123, 49, 45, 50, 42, 40,
  36, 121, 121, 43, 36, 122, 122, 41, 125, 44, 123, 50, 42, 40, 36, 120,
  121, 43, 36, 122, 119, 41, 125, 44, 123, 50, 42, 40, 36, 120, 122, 45,
  36, 121, 119, 41, 125, 59, 92, 10, 123, 50, 42, 40, 36, 120, 121, 45,
  36, 122, 119, 41, 125, 44, 123, 49, 45, 50, 42, 40, 36, 120, 120, 43,
  36, 122, 122, 41, 125, 44, 123, 50, 42, 40, 36, 121, 122, 43, 36, 120,
  119, 41, 125, 59, 92, 10, 123, 50, 42, 40, 36, 120, 122, 43, 36, 121,
  119, 41, 125, 44, 123, 50, 42, 40, 36, 121, 122, 45, 36, 120, 119, 41,
  125, 44, 123, 49, 45, 50, 42, 40, 36, 120, 120, 43, 36, 121, 121, 41,
  125, 41, 10, 45, 110, 109, 91, 45, 49, 93, 32, 91, 51, 100, 92, 32,
  114, 111, 116, 97, 116, 105, 111, 110, 93, 10, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 115, 105, 101, 114, 112, 105, 110, 115, 107, 105,
  51, 100, 32, 58, 32, 95, 114, 101, 99, 117, 114, 115, 105, 111, 110, 95,
  108, 101, 118, 101, 108, 62, 61, 48, 44, 95, 119, 105, 100, 116, 104, 44,
  95, 104, 101, 105, 103, 104, 116, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 73, 110, 112, 117, 116, 32, 51, 100, 32, 83, 105, 101, 114, 112, 105,
  110, 115, 107, 105, 32, 112, 121, 114, 97, 109, 105, 100, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 115, 105, 101, 114, 112, 105,
  110, 115, 107, 105, 51, 100, 32, 51, 32, 45, 45, 112, 114, 105, 109, 105,
  116, 105, 118, 101, 115, 51, 100, 32, 49, 32, 45, 99, 111, 108, 111, 114,
  51, 100, 91, 45, 50, 93, 32, 64, 123, 45, 82, 71, 66, 125, 10, 115,
  105, 101, 114, 112, 105, 110, 115, 107, 105, 51, 100, 32, 58, 32, 45, 99,
  104, 101, 99, 107, 32, 36, 123, 49, 61, 52, 125, 62, 61, 48, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 50, 61, 49, 125, 44, 36, 123, 51, 61,
  49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117,
  116, 32, 51, 100, 32, 83, 105, 101, 114, 112, 105, 110, 115, 107, 105, 32,
  112, 121, 114, 97, 109, 105, 100, 32, 111, 102, 32, 100, 101, 103, 114, 101,
  101, 32, 36, 49, 44, 32, 119, 105, 116, 104, 32, 119, 105, 100, 116, 104,
  32, 36, 50, 32, 97, 110, 100, 32, 104, 101, 105, 103, 104, 116, 32, 36,
  51, 46, 34, 10, 45, 118, 32, 45, 32, 45, 108, 91, 93, 32, 45, 95,
  115, 105, 101, 114, 112, 105, 110, 115, 107, 105, 51, 100, 32, 123, 45, 36,
  50, 47, 50, 125, 44, 123, 45, 36, 50, 47, 50, 125, 44, 123, 45, 36,
  51, 47, 50, 125, 44, 123, 36, 50, 47, 50, 125, 44, 123, 45, 36, 50,
  47, 50, 125, 44, 123, 45, 36, 51, 47, 50, 125, 44, 123, 36, 50, 47,
  50, 125, 44, 123, 36, 50, 47, 50, 125, 44, 123, 45, 36, 51, 47, 50,
  125, 44, 123, 45, 36, 50, 47, 50, 125, 44, 123, 36, 50, 47, 50, 125,
  44, 123, 45, 36, 51, 47, 50, 125, 44, 48, 44, 48, 44, 123, 36, 51,
  47, 50, 125, 44, 36, 49, 32, 45, 43, 51, 100, 32, 45, 101, 110, 100,
  108, 10, 45, 110, 109, 91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 115,
  105, 101, 114, 112, 105, 110, 115, 107, 105, 93, 32, 45, 118, 32, 43, 10,
  95, 115, 105, 101, 114, 112, 105, 110, 115, 107, 105, 51, 100, 32, 58, 10,
  45, 105, 102, 32, 123, 36, 49, 54, 60, 61, 48, 125, 10, 40, 54, 55,
  46, 53, 59, 55, 51, 46, 53, 59, 49, 48, 57, 46, 53, 59, 49, 48,
  51, 46, 53, 59, 53, 49, 46, 53, 59, 49, 48, 48, 46, 53, 59, 92,
  10, 53, 59, 53, 59, 92, 10, 36, 49, 59, 36, 50, 59, 36, 51, 59,
  92, 10, 36, 52, 59, 36, 53, 59, 36, 54, 59, 92, 10, 36, 55, 59,
  36, 56, 59, 36, 57, 59, 92, 10, 36, 49, 48, 59, 36, 49, 49, 59,
  36, 49, 50, 59, 92, 10, 36, 49, 51, 59, 36, 49, 52, 59, 36, 49,
  53, 59, 92, 10, 52, 59, 48, 59, 51, 59, 50, 59, 49, 59, 92, 10,
  51, 59, 48, 59, 52, 59, 51, 59, 92, 10, 51, 59, 49, 59, 52, 59,
  48, 59, 92, 10, 51, 59, 50, 59, 52, 59, 49, 59, 92, 10, 51, 59,
  51, 59, 52, 59, 50, 41, 10, 49, 44, 49, 53, 44, 49, 44, 49, 44,
  50, 48, 48, 32, 49, 44, 53, 44, 49, 44, 49, 44, 49, 32, 45, 97,
  91, 45, 51, 45, 45, 49, 93, 32, 121, 10, 45, 114, 101, 116, 117, 114,
  110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 115, 105, 101, 114, 112,
  105, 110, 115, 107, 105, 51, 100, 32, 36, 49, 44, 36, 50, 44, 36, 51,
  44, 92, 10, 123, 40, 36, 49, 43, 36, 52, 41, 47, 50, 125, 44, 123,
  40, 36, 50, 43, 36, 53, 41, 47, 50, 125, 44, 123, 40, 36, 51, 43,
  36, 54, 41, 47, 50, 125, 44, 92, 10, 123, 40, 36, 49, 43, 36, 52,
  43, 36, 55, 43, 36, 49, 48, 41, 47, 52, 125, 44, 123, 40, 36, 50,
  43, 36, 53, 43, 36, 56, 43, 36, 49, 49, 41, 47, 52, 125, 44, 123,
  40, 36, 51, 43, 36, 54, 43, 36, 57, 43, 36, 49, 50, 41, 47, 52,
  125, 44, 92, 10, 123, 40, 36, 49, 43, 36, 49, 48, 41, 47, 50, 125,
  44, 123, 40, 36, 50, 43, 36, 49, 49, 41, 47, 50, 125, 44, 123, 40,
  36, 51, 43, 36, 49, 50, 41, 47, 50, 125, 44, 92, 10, 123, 40, 36,
  49, 43, 36, 49, 51, 41, 47, 50, 125, 44, 123, 40, 36, 50, 43, 36,
  49, 52, 41, 47, 50, 125, 44, 123, 40, 36, 51, 43, 36, 49, 53, 41,
  47, 50, 125, 44, 92, 10, 123, 36, 49, 54, 45, 49, 125, 10, 45, 95,
  115, 105, 101, 114, 112, 105, 110, 115, 107, 105, 51, 100, 32, 123, 40, 36,
  49, 43, 36, 52, 41, 47, 50, 125, 44, 123, 40, 36, 50, 43, 36, 53,
  41, 47, 50, 125, 44, 123, 40, 36, 51, 43, 36, 54, 41, 47, 50, 125,
  44, 92, 10, 36, 52, 44, 36, 53, 44, 36, 54, 44, 92, 10, 123, 40,
  36, 52, 43, 36, 55, 41, 47, 50, 125, 44, 123, 40, 36, 53, 43, 36,
  56, 41, 47, 50, 125, 44, 123, 40, 36, 54, 43, 36, 57, 41, 47, 50,
  125, 44, 92, 10, 123, 40, 36, 49, 43, 36, 52, 43, 36, 55, 43, 36,
  49, 48, 41, 47, 52, 125, 44, 123, 40, 36, 50, 43, 36, 53, 43, 36,
  56, 43, 36, 49, 49, 41, 47, 52, 125, 44, 123, 40, 36, 51, 43, 36,
  54, 43, 36, 57, 43, 36, 49, 50, 41, 47, 52, 125, 44, 92, 10, 123,
  40, 36, 52, 43, 36, 49, 51, 41, 47, 50, 125, 44, 123, 40, 36, 53,
  43, 36, 49, 52, 41, 47, 50, 125, 44, 123, 40, 36, 54, 43, 36, 49,
  53, 41, 47, 50, 125, 44, 92, 10, 123, 36, 49, 54, 45, 49, 125, 10,
  45, 95, 115, 105, 101, 114, 112, 105, 110, 115, 107, 105, 51, 100, 32, 123,
  40, 36, 49, 43, 36, 52, 43, 36, 55, 43, 36, 49, 48, 41, 47, 52,
  125, 44, 123, 40, 36, 50, 43, 36, 53, 43, 36, 56, 43, 36, 49, 49,
  41, 47, 52, 125, 44, 123, 40, 36, 51, 43, 36, 54, 43, 36, 57, 43,
  36, 49, 50, 41, 47, 52, 125, 44, 92, 10, 123, 40, 36, 52, 43, 36,
  55, 41, 47, 50, 125, 44, 123, 40, 36, 53, 43, 36, 56, 41, 47, 50,
  125, 44, 123, 40, 36, 54, 43, 36, 57, 41, 47, 50, 125, 44, 92, 10,
  36, 55, 44, 36, 56, 44, 36, 57, 44, 92, 10, 123, 40, 36, 55, 43,
  36, 49, 48, 41, 47, 50, 125, 44, 123, 40, 36, 56, 43, 36, 49, 49,
  41, 47, 50, 125, 44, 123, 40, 36, 57, 43, 36, 49, 50, 41, 47, 50,
  125, 44, 92, 10, 123, 40, 36, 55, 43, 36, 49, 51, 41, 47, 50, 125,
  44, 123, 40, 36, 56, 43, 36, 49, 52, 41, 47, 50, 125, 44, 123, 40,
  36, 57, 43, 36, 49, 53, 41, 47, 50, 125, 44, 92, 10, 123, 36, 49,
  54, 45, 49, 125, 10, 45, 95, 115, 105, 101, 114, 112, 105, 110, 115, 107,
  105, 51, 100, 32, 123, 40, 36, 49, 43, 36, 49, 48, 41, 47, 50, 125,
  44, 123, 40, 36, 50, 43, 36, 49, 49, 41, 47, 50, 125, 44, 123, 40,
  36, 51, 43, 36, 49, 50, 41, 47, 50, 125, 44, 92, 10, 123, 40, 36,
  49, 43, 36, 52, 43, 36, 55, 43, 36, 49, 48, 41, 47, 52, 125, 44,
  123, 40, 36, 50, 43, 36, 53, 43, 36, 56, 43, 36, 49, 49, 41, 47,
  52, 125, 44, 123, 40, 36, 51, 43, 36, 54, 43, 36, 57, 43, 36, 49,
  50, 41, 47, 52, 125, 44, 92, 10, 123, 40, 36, 55, 43, 36, 49, 48,
  41, 47, 50, 125, 44, 123, 40, 36, 56, 43, 36, 49, 49, 41, 47, 50,
  125, 44, 123, 40, 36, 57, 43, 36, 49, 50, 41, 47, 50, 125, 44, 92,
  10, 36, 49, 48, 44, 36, 49, 49, 44, 36, 49, 50, 44, 92, 10, 123,
  40, 36, 49, 48, 43, 36, 49, 51, 41, 47, 50, 125, 44, 123, 40, 36,
  49, 49, 43, 36, 49, 52, 41, 47, 50, 125, 44, 123, 40, 36, 49, 50,
  43, 36, 49, 53, 41, 47, 50, 125, 44, 92, 10, 123, 36, 49, 54, 45,
  49, 125, 10, 45, 95, 115, 105, 101, 114, 112, 105, 110, 115, 107, 105, 51,
  100, 32, 123, 40, 36, 49, 43, 36, 49, 51, 41, 47, 50, 125, 44, 123,
  40, 36, 50, 43, 36, 49, 52, 41, 47, 50, 125, 44, 123, 40, 36, 51,
  43, 36, 49, 53, 41, 47, 50, 125, 44, 92, 10, 123, 40, 36, 52, 43,
  36, 49, 51, 41, 47, 50, 125, 44, 123, 40, 36, 53, 43, 36, 49, 52,
  41, 47, 50, 125, 44, 123, 40, 36, 54, 43, 36, 49, 53, 41, 47, 50,
  125, 44, 92, 10, 123, 40, 36, 55, 43, 36, 49, 51, 41, 47, 50, 125,
  44, 123, 40, 36, 56, 43, 36, 49, 52, 41, 47, 50, 125, 44, 123, 40,
  36, 57, 43, 36, 49, 53, 41, 47, 50, 125, 44, 92, 10, 123, 40, 36,
  49, 48, 43, 36, 49, 51, 41, 47, 50, 125, 44, 123, 40, 36, 49, 49,
  43, 36, 49, 52, 41, 47, 50, 125, 44, 123, 40, 36, 49, 50, 43, 36,
  49, 53, 41, 47, 50, 125, 44, 92, 10, 36, 49, 51, 44, 36, 49, 52,
  44, 36, 49, 53, 44, 92, 10, 123, 36, 49, 54, 45, 49, 125, 10, 35,
  64, 103, 109, 105, 99, 32, 115, 110, 97, 112, 115, 104, 111, 116, 51, 100,
  32, 58, 32, 95, 115, 105, 122, 101, 62, 48, 44, 95, 122, 111, 111, 109,
  62, 61, 48, 44, 95, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 82,
  44, 95, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 71, 44, 95, 98,
  97, 99, 107, 103, 114, 111, 117, 110, 100, 66, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 84, 97, 107, 101, 32, 50, 100, 32, 115, 110, 97, 112,
  115, 104, 111, 116, 115, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 83, 101, 116, 32, 39, 122, 111, 111, 109,
  39, 32, 116, 111, 32, 48, 32, 116, 111, 32, 100, 105, 115, 97, 98, 108,
  101, 32, 111, 98, 106, 101, 99, 116, 32, 97, 117, 116, 111, 45, 115, 99,
  97, 108, 105, 110, 103, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 115, 105, 122, 101, 61, 53, 49, 50, 39, 44, 32, 39, 122, 111, 111,
  109, 61, 49, 39, 32, 97, 110, 100, 32, 39, 98, 97, 99, 107, 103, 114,
  111, 117, 110, 100, 82, 61, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100,
  71, 61, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 66, 61, 40, 117,
  110, 100, 101, 102, 105, 110, 101, 100, 41, 39, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 45, 116, 111, 114, 117, 115, 51, 100, 32,
  49, 48, 48, 44, 50, 48, 32, 45, 115, 110, 97, 112, 115, 104, 111, 116,
  51, 100, 32, 52, 48, 48, 44, 49, 46, 50, 44, 49, 50, 56, 44, 54,
  52, 44, 51, 50, 10, 115, 110, 97, 112, 115, 104, 111, 116, 51, 100, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 53, 49,
  50, 125, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 49, 125, 62, 61,
  48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 34, 34, 125,
  10, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40, 36, 51, 41, 125, 10,
  45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 84, 97, 107, 101, 32, 36,
  49, 120, 36, 49, 32, 115, 110, 97, 112, 115, 104, 111, 116, 36, 63, 32,
  111, 102, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 36, 63, 44, 32,
  119, 105, 116, 104, 32, 122, 111, 111, 109, 32, 102, 97, 99, 116, 111, 114,
  32, 36, 50, 32, 97, 110, 100, 32, 98, 97, 99, 107, 103, 114, 111, 117,
  110, 100, 32, 99, 111, 108, 111, 114, 32, 36, 123, 51, 45, 45, 49, 125,
  46, 34, 10, 45, 101, 108, 115, 101, 10, 45, 101, 91, 48, 45, 45, 51,
  93, 32, 34, 84, 97, 107, 101, 32, 36, 49, 120, 36, 49, 32, 115, 110,
  97, 112, 115, 104, 111, 116, 36, 63, 32, 111, 102, 32, 51, 100, 32, 111,
  98, 106, 101, 99, 116, 36, 63, 44, 32, 119, 105, 116, 104, 32, 122, 111,
  111, 109, 32, 102, 97, 99, 116, 111, 114, 32, 36, 50, 46, 34, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102,
  32, 123, 36, 50, 33, 61, 48, 125, 32, 45, 99, 51, 100, 32, 45, 110,
  51, 100, 32, 45, 42, 51, 100, 32, 123, 51, 42, 36, 49, 42, 36, 50,
  47, 52, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  110, 97, 114, 103, 40, 36, 51, 41, 125, 32, 40, 36, 123, 51, 45, 45,
  49, 125, 41, 32, 45, 121, 91, 45, 49, 93, 32, 99, 32, 45, 101, 108,
  115, 101, 32, 49, 44, 50, 44, 49, 44, 51, 44, 51, 50, 44, 54, 52,
  44, 51, 50, 44, 49, 49, 54, 44, 54, 52, 44, 57, 54, 32, 45, 101,
  110, 100, 105, 102, 32, 45, 114, 91, 45, 49, 93, 32, 36, 49, 44, 36,
  49, 44, 49, 44, 51, 44, 51, 10, 45, 111, 98, 106, 101, 99, 116, 51,
  100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 53, 48, 37, 44, 53,
  48, 37, 44, 48, 44, 49, 32, 45, 110, 109, 91, 45, 49, 93, 32, 64,
  123, 45, 50, 44, 110, 125, 44, 49, 32, 45, 114, 109, 91, 45, 50, 93,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 108, 51, 100, 32, 58, 32,
  101, 113, 46, 32, 116, 111, 32, 39, 45, 115, 112, 101, 99, 108, 51, 100,
  39, 46, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32,
  115, 112, 101, 99, 108, 51, 100, 32, 58, 32, 118, 97, 108, 117, 101, 62,
  61, 48, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 83, 101, 116, 32, 108, 105, 103, 104, 116, 110, 101, 115, 115, 32,
  111, 102, 32, 51, 100, 32, 115, 112, 101, 99, 117, 108, 97, 114, 32, 108,
  105, 103, 104, 116, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40,
  101, 113, 46, 32, 116, 111, 32, 39, 45, 115, 108, 51, 100, 39, 41, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108,
  116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 118, 97, 108, 117, 101, 61,
  48, 46, 49, 53, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 40, 48, 44, 48, 46, 51, 44, 48, 46, 54, 44, 48, 46, 57,
  44, 49, 46, 50, 41, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 119,
  125, 32, 45, 116, 111, 114, 117, 115, 51, 100, 32, 49, 48, 48, 44, 51,
  48, 32, 45, 114, 111, 116, 97, 116, 101, 51, 100, 91, 45, 49, 93, 32,
  49, 44, 49, 44, 48, 44, 54, 48, 32, 45, 99, 111, 108, 111, 114, 51,
  100, 91, 45, 49, 93, 32, 50, 53, 53, 44, 48, 44, 48, 32, 45, 115,
  112, 101, 99, 108, 51, 100, 32, 64, 123, 48, 44, 36, 62, 125, 32, 45,
  115, 110, 97, 112, 115, 104, 111, 116, 51, 100, 91, 45, 49, 93, 32, 52,
  48, 48, 32, 45, 100, 111, 110, 101, 32, 45, 114, 101, 109, 111, 118, 101,
  91, 48, 93, 10, 35, 64, 103, 109, 105, 99, 32, 115, 115, 51, 100, 32,
  58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 115, 112, 101, 99, 115,
  51, 100, 39, 46, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 115, 112, 101, 99, 115, 51, 100, 32, 58, 32, 118, 97, 108, 117,
  101, 62, 61, 48, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 83, 101, 116, 32, 115, 104, 105, 110, 105, 110, 101, 115,
  115, 32, 111, 102, 32, 51, 100, 32, 115, 112, 101, 99, 117, 108, 97, 114,
  32, 108, 105, 103, 104, 116, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 115, 115, 51, 100, 39,
  41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 118, 97, 108, 117,
  101, 61, 48, 46, 56, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 40, 48, 44, 48, 46, 51, 44, 48, 46, 54, 44, 48, 46,
  57, 44, 49, 46, 50, 41, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  119, 125, 32, 45, 116, 111, 114, 117, 115, 51, 100, 32, 49, 48, 48, 44,
  51, 48, 32, 45, 114, 111, 116, 97, 116, 101, 51, 100, 91, 45, 49, 93,
  32, 49, 44, 49, 44, 48, 44, 54, 48, 32, 45, 99, 111, 108, 111, 114,
  51, 100, 91, 45, 49, 93, 32, 50, 53, 53, 44, 48, 44, 48, 32, 45,
  115, 112, 101, 99, 115, 51, 100, 32, 64, 123, 48, 44, 36, 62, 125, 32,
  45, 115, 110, 97, 112, 115, 104, 111, 116, 51, 100, 91, 45, 49, 93, 32,
  52, 48, 48, 32, 45, 100, 111, 110, 101, 32, 45, 114, 101, 109, 111, 118,
  101, 91, 48, 93, 10, 35, 64, 103, 109, 105, 99, 32, 115, 112, 104, 101,
  114, 101, 51, 100, 32, 58, 32, 114, 97, 100, 105, 117, 115, 44, 95, 110,
  98, 95, 114, 101, 99, 117, 114, 115, 105, 111, 110, 115, 62, 61, 48, 32,
  58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73,
  110, 112, 117, 116, 32, 51, 100, 32, 115, 112, 104, 101, 114, 101, 32, 97,
  116, 32, 40, 48, 44, 48, 44, 48, 41, 44, 32, 119, 105, 116, 104, 32,
  115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 103, 101, 111, 109, 101, 116,
  114, 121, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 110, 98, 95,
  114, 101, 99, 117, 114, 115, 105, 111, 110, 115, 61, 51, 39, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 115, 112, 104, 101, 114,
  101, 51, 100, 32, 49, 48, 48, 32, 45, 45, 112, 114, 105, 109, 105, 116,
  105, 118, 101, 115, 51, 100, 32, 49, 32, 32, 45, 99, 111, 108, 111, 114,
  51, 100, 91, 45, 50, 93, 32, 64, 123, 45, 82, 71, 66, 125, 10, 35,
  64, 103, 109, 105, 99, 32, 115, 112, 104, 101, 114, 105, 99, 97, 108, 51,
  100, 32, 58, 32, 95, 110, 98, 95, 97, 122, 105, 109, 117, 116, 104, 62,
  61, 51, 44, 95, 110, 98, 95, 122, 101, 110, 105, 116, 104, 62, 61, 51,
  44, 95, 114, 97, 100, 105, 117, 115, 95, 102, 117, 110, 99, 116, 105, 111,
  110, 40, 112, 104, 105, 44, 116, 104, 101, 116, 97, 41, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 73, 110, 112, 117, 116, 32, 51, 100, 32, 115,
  112, 104, 101, 114, 105, 99, 97, 108, 32, 111, 98, 106, 101, 99, 116, 32,
  97, 116, 32, 40, 48, 44, 48, 44, 48, 41, 44, 32, 119, 105, 116, 104,
  32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 103, 101, 111, 109, 101,
  116, 114, 121, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101,
  102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 110,
  98, 95, 122, 101, 110, 105, 116, 104, 61, 110, 98, 95, 97, 122, 105, 109,
  117, 116, 61, 54, 52, 39, 32, 97, 110, 100, 32, 39, 114, 97, 100, 105,
  117, 115, 95, 102, 117, 110, 99, 116, 105, 111, 110, 61, 34, 97, 98, 115,
  40, 49, 43, 48, 46, 53, 42, 99, 111, 115, 40, 51, 42, 112, 104, 105,
  41, 42, 115, 105, 110, 40, 52, 42, 116, 104, 101, 116, 97, 41, 41, 34,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 115,
  112, 104, 101, 114, 105, 99, 97, 108, 51, 100, 32, 54, 52, 32, 45, 45,
  112, 114, 105, 109, 105, 116, 105, 118, 101, 115, 51, 100, 32, 49, 10, 115,
  112, 104, 101, 114, 105, 99, 97, 108, 51, 100, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 36, 123, 49, 61, 54, 52, 125, 62, 61, 51, 32,
  38, 38, 32, 36, 123, 50, 61, 36, 49, 125, 62, 61, 51, 34, 32, 45,
  115, 107, 105, 112, 32, 34, 36, 123, 51, 61, 97, 98, 115, 40, 49, 43,
  48, 46, 53, 42, 99, 111, 115, 40, 51, 42, 112, 104, 105, 41, 42, 115,
  105, 110, 40, 52, 42, 116, 104, 101, 116, 97, 41, 41, 125, 34, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 51, 100,
  32, 115, 112, 104, 101, 114, 105, 99, 97, 108, 32, 111, 98, 106, 101, 99,
  116, 44, 32, 119, 105, 116, 104, 32, 115, 117, 98, 100, 105, 118, 105, 115,
  105, 111, 110, 115, 32, 40, 36, 49, 44, 36, 50, 41, 32, 97, 110, 100,
  32, 104, 101, 105, 103, 104, 116, 32, 102, 117, 110, 99, 116, 105, 111, 110,
  32, 39, 36, 51, 39, 46, 34, 10, 45, 118, 32, 45, 10, 40, 123, 39,
  67, 73, 109, 103, 51, 100, 39, 125, 41, 32, 45, 121, 91, 45, 49, 93,
  10, 110, 49, 61, 123, 114, 111, 117, 110, 100, 40, 36, 49, 41, 125, 32,
  110, 50, 61, 123, 114, 111, 117, 110, 100, 40, 36, 50, 41, 125, 10, 36,
  110, 49, 44, 123, 36, 110, 50, 45, 49, 125, 44, 49, 44, 51, 44, 34,
  112, 104, 105, 61, 50, 42, 112, 105, 42, 40, 120, 43, 48, 46, 53, 41,
  47, 119, 59, 92, 10, 116, 104, 101, 116, 97, 61, 45, 112, 105, 47, 50,
  43, 112, 105, 42, 40, 121, 43, 48, 46, 53, 41, 47, 104, 59, 92, 10,
  99, 112, 61, 99, 111, 115, 40, 112, 104, 105, 41, 59, 92, 10, 115, 112,
  61, 115, 105, 110, 40, 112, 104, 105, 41, 59, 92, 10, 99, 116, 61, 99,
  111, 115, 40, 116, 104, 101, 116, 97, 41, 59, 92, 10, 40, 36, 51, 41,
  42, 105, 102, 40, 99, 61, 61, 48, 44, 99, 116, 42, 99, 112, 44, 105,
  102, 40, 99, 61, 61, 49, 44, 99, 116, 42, 115, 112, 44, 115, 105, 110,
  40, 116, 104, 101, 116, 97, 41, 41, 41, 34, 10, 45, 114, 91, 45, 49,
  93, 32, 123, 119, 42, 104, 125, 44, 51, 44, 49, 44, 49, 44, 45, 49,
  32, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 49, 93, 32, 121, 120,
  122, 99, 10, 45, 105, 91, 45, 50, 93, 32, 40, 48, 44, 48, 44, 123,
  112, 104, 105, 61, 48, 59, 116, 104, 101, 116, 97, 61, 45, 112, 105, 47,
  50, 59, 45, 36, 51, 125, 59, 48, 44, 48, 44, 123, 112, 104, 105, 61,
  48, 59, 116, 104, 101, 116, 97, 61, 112, 105, 47, 50, 59, 36, 51, 125,
  41, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 10, 110, 98,
  118, 61, 123, 104, 125, 32, 45, 121, 91, 45, 49, 93, 10, 36, 110, 49,
  44, 123, 36, 110, 50, 45, 50, 125, 44, 49, 44, 52, 44, 34, 110, 120,
  61, 40, 120, 43, 49, 41, 37, 119, 59, 110, 121, 61, 40, 121, 43, 49,
  41, 59, 50, 43, 105, 102, 40, 99, 61, 61, 48, 44, 120, 43, 121, 42,
  34, 36, 110, 49, 34, 44, 105, 102, 40, 99, 61, 61, 49, 44, 110, 120,
  43, 121, 42, 34, 36, 110, 49, 34, 44, 105, 102, 40, 99, 61, 61, 50,
  44, 110, 120, 43, 110, 121, 42, 34, 36, 110, 49, 34, 44, 120, 43, 110,
  121, 42, 34, 36, 110, 49, 34, 41, 41, 41, 34, 10, 45, 114, 91, 45,
  49, 93, 32, 123, 119, 42, 104, 125, 44, 52, 44, 49, 44, 49, 44, 45,
  49, 32, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 49, 93, 32, 121,
  120, 122, 99, 32, 45, 105, 91, 45, 50, 93, 32, 49, 44, 123, 104, 125,
  44, 49, 44, 49, 44, 52, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93,
  32, 120, 10, 50, 44, 36, 110, 49, 44, 49, 44, 49, 44, 51, 44, 48,
  32, 49, 44, 36, 110, 49, 44, 49, 44, 49, 44, 39, 121, 39, 32, 45,
  45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 37, 91, 45, 49, 93, 32,
  123, 104, 125, 32, 50, 44, 36, 110, 49, 44, 49, 44, 49, 44, 51, 44,
  49, 32, 91, 45, 51, 44, 45, 50, 93, 10, 45, 43, 91, 45, 53, 44,
  45, 52, 93, 32, 50, 32, 45, 114, 118, 91, 45, 53, 44, 45, 52, 93,
  32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 123, 36, 110, 98, 118,
  45, 36, 110, 49, 125, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32,
  120, 32, 45, 97, 91, 45, 52, 45, 45, 50, 93, 32, 120, 10, 110, 98,
  112, 61, 123, 104, 43, 64, 123, 45, 50, 44, 104, 125, 43, 64, 123, 45,
  51, 44, 104, 125, 125, 10, 45, 121, 91, 45, 51, 45, 45, 49, 93, 32,
  45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 121, 10, 45, 105, 91, 45,
  51, 93, 32, 40, 36, 110, 98, 118, 59, 36, 110, 98, 112, 41, 10, 49,
  44, 123, 51, 42, 36, 110, 98, 112, 125, 44, 49, 44, 49, 44, 50, 48,
  48, 32, 49, 44, 36, 110, 98, 112, 44, 49, 44, 49, 44, 49, 32, 45,
  97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 10, 45, 97, 91, 45, 53,
  45, 45, 49, 93, 32, 121, 32, 45, 110, 109, 91, 45, 49, 93, 32, 34,
  91, 51, 100, 32, 115, 112, 104, 101, 114, 105, 99, 97, 108, 32, 115, 117,
  114, 102, 97, 99, 101, 32, 39, 36, 51, 39, 93, 34, 10, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 112, 108, 105, 110, 101, 51,
  100, 32, 58, 32, 120, 48, 91, 37, 93, 44, 121, 48, 91, 37, 93, 44,
  122, 48, 91, 37, 93, 44, 117, 48, 91, 37, 93, 44, 118, 48, 91, 37,
  93, 44, 119, 48, 91, 37, 93, 44, 120, 49, 91, 37, 93, 44, 121, 49,
  91, 37, 93, 44, 122, 49, 91, 37, 93, 44, 117, 49, 91, 37, 93, 44,
  118, 49, 91, 37, 93, 44, 119, 49, 91, 37, 93, 44, 95, 110, 98, 95,
  118, 101, 114, 116, 105, 99, 101, 115, 62, 61, 50, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 73, 110, 112, 117, 116, 32, 51, 100, 32, 115, 112,
  108, 105, 110, 101, 32, 119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102,
  105, 101, 100, 32, 103, 101, 111, 109, 101, 116, 114, 121, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 110, 98, 95, 118, 101, 114, 116, 105,
  99, 101, 115, 61, 49, 50, 56, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 45, 114, 101, 112, 101, 97, 116, 32, 49, 48, 48,
  32, 45, 115, 112, 108, 105, 110, 101, 51, 100, 32, 123, 63, 125, 44, 123,
  63, 125, 44, 123, 63, 125, 44, 123, 63, 125, 44, 123, 63, 125, 44, 123,
  63, 125, 44, 123, 63, 125, 44, 123, 63, 125, 44, 123, 63, 125, 44, 123,
  63, 125, 44, 123, 63, 125, 44, 123, 63, 125, 44, 49, 50, 56, 32, 45,
  99, 111, 108, 111, 114, 51, 100, 91, 45, 49, 93, 32, 64, 123, 45, 82,
  71, 66, 125, 32, 45, 100, 111, 110, 101, 32, 45, 98, 111, 120, 51, 100,
  32, 49, 32, 45, 112, 114, 105, 109, 105, 116, 105, 118, 101, 115, 51, 100,
  91, 45, 49, 93, 32, 49, 32, 45, 43, 51, 100, 10, 115, 112, 108, 105,
  110, 101, 51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 123,
  49, 51, 61, 49, 50, 56, 125, 62, 61, 50, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 110, 101, 119, 32, 51, 100,
  32, 115, 112, 108, 105, 110, 101, 32, 102, 114, 111, 109, 32, 40, 36, 123,
  49, 45, 51, 125, 41, 32, 91, 36, 123, 52, 45, 54, 125, 93, 32, 116,
  111, 32, 40, 36, 123, 55, 45, 57, 125, 41, 32, 91, 36, 123, 49, 48,
  45, 49, 50, 125, 93, 32, 119, 105, 116, 104, 32, 36, 49, 51, 32, 118,
  101, 114, 116, 105, 99, 101, 115, 46, 34, 10, 45, 118, 32, 45, 10, 40,
  123, 39, 67, 73, 109, 103, 51, 100, 39, 125, 41, 32, 45, 43, 91, 45,
  49, 93, 32, 48, 46, 53, 10, 40, 36, 49, 51, 59, 123, 36, 49, 51,
  45, 49, 125, 41, 10, 49, 44, 36, 49, 51, 44, 49, 44, 49, 44, 49,
  32, 40, 48, 59, 49, 41, 32, 45, 114, 91, 45, 49, 93, 32, 49, 44,
  36, 49, 51, 44, 49, 44, 49, 44, 51, 32, 45, 45, 115, 113, 114, 91,
  45, 49, 93, 32, 45, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  97, 91, 45, 52, 45, 45, 49, 93, 32, 120, 10, 45, 45, 42, 91, 45,
  49, 93, 32, 39, 36, 50, 44, 36, 53, 44, 123, 51, 42, 40, 40, 36,
  56, 41, 45, 40, 36, 50, 41, 41, 45, 50, 42, 40, 36, 53, 41, 45,
  40, 36, 49, 49, 41, 125, 44, 123, 40, 36, 53, 41, 43, 40, 36, 49,
  49, 41, 43, 50, 42, 40, 40, 36, 50, 41, 45, 40, 36, 56, 41, 41,
  125, 39, 32, 45, 108, 91, 45, 49, 93, 32, 45, 115, 32, 120, 32, 45,
  43, 32, 45, 101, 110, 100, 108, 10, 45, 45, 42, 91, 45, 50, 93, 32,
  39, 36, 51, 44, 36, 54, 44, 123, 51, 42, 40, 40, 36, 57, 41, 45,
  40, 36, 51, 41, 41, 45, 50, 42, 40, 36, 54, 41, 45, 40, 36, 49,
  50, 41, 125, 44, 123, 40, 36, 54, 41, 43, 40, 36, 49, 50, 41, 43,
  50, 42, 40, 40, 36, 51, 41, 45, 40, 36, 57, 41, 41, 125, 39, 32,
  45, 108, 91, 45, 49, 93, 32, 45, 115, 32, 120, 32, 45, 43, 32, 45,
  101, 110, 100, 108, 10, 45, 42, 91, 45, 51, 93, 32, 39, 36, 49, 44,
  36, 52, 44, 123, 51, 42, 40, 40, 36, 55, 41, 45, 40, 36, 49, 41,
  41, 45, 50, 42, 40, 36, 52, 41, 45, 40, 36, 49, 48, 41, 125, 44,
  123, 40, 36, 52, 41, 43, 40, 36, 49, 48, 41, 43, 50, 42, 40, 40,
  36, 49, 41, 45, 40, 36, 55, 41, 41, 125, 39, 32, 45, 108, 91, 45,
  51, 93, 32, 45, 115, 32, 120, 32, 45, 43, 32, 45, 101, 110, 100, 108,
  10, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 120, 10, 49, 44, 123,
  36, 49, 51, 45, 49, 125, 44, 49, 44, 49, 44, 50, 32, 40, 48, 44,
  49, 59, 123, 36, 49, 51, 45, 50, 125, 44, 123, 36, 49, 51, 45, 49,
  125, 41, 32, 45, 114, 91, 45, 49, 93, 32, 50, 44, 91, 45, 50, 93,
  44, 49, 44, 49, 44, 51, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49,
  93, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 10, 49, 44,
  123, 51, 42, 40, 36, 49, 51, 45, 49, 41, 125, 44, 49, 44, 49, 44,
  50, 48, 48, 32, 49, 44, 123, 36, 49, 51, 45, 49, 125, 44, 49, 44,
  49, 44, 49, 10, 45, 121, 91, 45, 51, 44, 45, 52, 44, 45, 54, 93,
  32, 45, 97, 91, 45, 54, 45, 45, 49, 93, 32, 121, 10, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 51, 100, 32, 58, 32, 101,
  113, 46, 32, 116, 111, 32, 39, 45, 115, 112, 108, 105, 116, 51, 100, 39,
  46, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 115,
  112, 108, 105, 116, 51, 100, 32, 58, 32, 95, 107, 101, 101, 112, 95, 115,
  104, 97, 114, 101, 100, 95, 100, 97, 116, 97, 61, 123, 32, 48, 32, 124,
  32, 49, 32, 125, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 83, 112, 108, 105, 116, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 115, 32, 105, 110,
  116, 111, 32, 54, 32, 102, 101, 97, 116, 117, 114, 101, 32, 118, 101, 99,
  116, 111, 114, 115, 32, 58, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  123, 32, 104, 101, 97, 100, 101, 114, 44, 32, 115, 105, 122, 101, 115, 44,
  32, 118, 101, 114, 116, 105, 99, 101, 115, 44, 32, 112, 114, 105, 109, 105,
  116, 105, 118, 101, 115, 44, 32, 99, 111, 108, 111, 114, 115, 44, 32, 111,
  112, 97, 99, 105, 116, 105, 101, 115, 32, 125, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 115,
  51, 100, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 84,
  111, 32, 114, 101, 99, 114, 101, 97, 116, 101, 32, 116, 104, 101, 32, 51,
  100, 32, 111, 98, 106, 101, 99, 116, 44, 32, 97, 112, 112, 101, 110, 100,
  32, 116, 104, 101, 115, 101, 32, 54, 32, 105, 109, 97, 103, 101, 115, 32,
  97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 121, 45, 97, 120, 105, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117,
  108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 107, 101, 101, 112, 95,
  115, 104, 97, 114, 101, 100, 95, 100, 97, 116, 97, 61, 49, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 98, 111, 120, 51,
  100, 32, 49, 48, 48, 32, 45, 45, 115, 112, 108, 105, 116, 51, 100, 10,
  35, 64, 103, 109, 105, 99, 32, 115, 112, 114, 105, 116, 101, 51, 100, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  32, 97, 115, 32, 51, 100, 32, 115, 112, 114, 105, 116, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 32, 119, 105, 116, 104, 32, 97, 108, 112,
  104, 97, 32, 99, 104, 97, 110, 110, 101, 108, 115, 32, 97, 114, 101, 32,
  109, 97, 110, 97, 103, 101, 100, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 115,
  112, 114, 105, 116, 101, 51, 100, 10, 115, 112, 114, 105, 116, 101, 51, 100,
  32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118,
  101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 97, 115, 32, 51,
  100, 32, 115, 112, 114, 105, 116, 101, 115, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 45, 115, 112,
  108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 10, 45, 105, 91, 48,
  93, 32, 40, 54, 55, 46, 53, 59, 55, 51, 46, 53, 59, 49, 48, 57,
  46, 53, 59, 49, 48, 51, 46, 53, 59, 53, 49, 46, 53, 59, 49, 48,
  48, 46, 53, 59, 49, 59, 49, 59, 48, 59, 48, 59, 48, 59, 49, 59,
  48, 59, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 64,
  123, 48, 44, 115, 125, 41, 32, 45, 121, 91, 49, 93, 10, 45, 105, 102,
  32, 123, 64, 35, 61, 61, 50, 125, 32, 40, 49, 41, 32, 45, 97, 32,
  121, 10, 45, 101, 108, 115, 101, 32, 45, 47, 91, 45, 49, 93, 32, 50,
  53, 53, 32, 45, 105, 91, 45, 50, 93, 32, 40, 45, 49, 50, 56, 59,
  123, 119, 125, 59, 123, 104, 125, 59, 123, 115, 125, 41, 32, 45, 121, 91,
  45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 97, 32, 121, 10,
  45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 115, 112, 114, 105, 116, 101, 115, 51, 100, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 115,
  32, 97, 115, 32, 115, 112, 114, 105, 116, 101, 115, 32, 99, 108, 111, 117,
  100, 115, 44, 32, 119, 104, 101, 114, 101, 32, 116, 104, 101, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 50, 100, 32, 115, 112, 114, 105, 116,
  101, 32, 105, 115, 32, 116, 104, 101, 32, 108, 97, 115, 116, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 73, 102, 32, 116, 104, 101, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 115, 112, 114, 105, 116, 101, 32, 104, 97,
  115, 32, 97, 32, 52, 116, 104, 32, 99, 104, 97, 110, 110, 101, 108, 44,
  32, 105, 116, 32, 115, 116, 97, 110, 100, 115, 32, 102, 111, 114, 32, 116,
  104, 101, 32, 115, 112, 114, 105, 116, 101, 32, 97, 108, 112, 104, 97, 45,
  99, 104, 97, 110, 110, 101, 108, 32, 40, 105, 110, 32, 91, 48, 44, 50,
  53, 53, 93, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 45, 116, 111, 114, 117, 115, 51, 100, 32, 49, 48, 48, 44, 50, 48,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 114, 101, 115, 105,
  122, 101, 50, 100, 121, 91, 45, 49, 93, 32, 54, 52, 32, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 32, 45, 103, 97, 117, 115, 115, 105, 97, 110,
  91, 45, 49, 93, 32, 51, 48, 37, 44, 51, 48, 37, 32, 45, 42, 91,
  45, 49, 93, 32, 50, 53, 53, 32, 45, 97, 112, 112, 101, 110, 100, 91,
  45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 45, 115, 112, 114, 105, 116,
  101, 115, 51, 100, 32, 45, 100, 114, 103, 98, 97, 91, 45, 50, 93, 10,
  115, 112, 114, 105, 116, 101, 115, 51, 100, 32, 58, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97,
  103, 101, 36, 63, 32, 97, 115, 32, 51, 100, 32, 115, 112, 114, 105, 116,
  101, 115, 32, 99, 108, 111, 117, 100, 115, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 10,
  45, 105, 102, 32, 123, 33, 64, 123, 36, 62, 44, 40, 48, 44, 55, 41,
  125, 125, 32, 45, 99, 111, 110, 116, 105, 110, 117, 101, 32, 45, 101, 110,
  100, 105, 102, 10, 91, 45, 49, 93, 32, 45, 108, 91, 36, 62, 44, 45,
  49, 93, 10, 45, 115, 51, 100, 91, 48, 93, 32, 78, 61, 64, 123, 49,
  44, 48, 125, 32, 45, 61, 91, 49, 93, 32, 36, 78, 44, 48, 44, 49,
  10, 45, 114, 109, 91, 51, 45, 53, 93, 32, 45, 105, 91, 51, 93, 32,
  40, 49, 44, 48, 59, 49, 44, 123, 36, 78, 45, 49, 125, 41, 32, 45,
  114, 91, 51, 93, 32, 50, 44, 36, 78, 44, 49, 44, 49, 44, 51, 32,
  45, 114, 111, 117, 110, 100, 91, 51, 93, 10, 45, 105, 102, 32, 123, 115,
  61, 61, 52, 125, 10, 45, 115, 91, 45, 49, 93, 32, 99, 44, 45, 51,
  32, 45, 47, 91, 45, 49, 93, 32, 50, 53, 53, 10, 45, 105, 91, 45,
  51, 93, 32, 40, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104, 125,
  59, 51, 41, 10, 45, 105, 102, 32, 123, 36, 78, 62, 49, 125, 32, 45,
  105, 91, 45, 50, 93, 32, 49, 44, 123, 52, 42, 40, 36, 78, 45, 49,
  41, 125, 44, 49, 44, 49, 44, 45, 49, 50, 56, 44, 48, 44, 48, 44,
  48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 91, 45, 50, 93, 32,
  40, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 49, 41,
  10, 45, 105, 102, 32, 123, 36, 78, 62, 49, 125, 32, 49, 44, 123, 52,
  42, 40, 36, 78, 45, 49, 41, 125, 44, 49, 44, 49, 44, 45, 49, 50,
  56, 44, 48, 44, 48, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 108, 115, 101, 10, 45, 105, 91, 45, 50, 93, 32, 40, 45, 49, 50,
  56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 123, 115, 125, 41, 32, 45,
  121, 91, 45, 51, 44, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 78,
  62, 49, 125, 32, 49, 44, 123, 52, 42, 40, 36, 78, 45, 49, 41, 125,
  44, 49, 44, 49, 44, 45, 49, 50, 56, 44, 48, 44, 48, 44, 48, 32,
  45, 101, 110, 100, 105, 102, 10, 49, 44, 36, 78, 44, 49, 44, 49, 44,
  49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 121, 32, 45, 97, 32, 121,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 115, 116, 97, 114, 51, 100, 32, 58, 32, 95, 110, 98, 95, 98, 114,
  97, 110, 99, 104, 101, 115, 62, 48, 44, 48, 60, 61, 95, 116, 104, 105,
  99, 107, 110, 101, 115, 115, 60, 61, 49, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 73, 110, 112, 117, 116, 32, 51, 100, 32, 115, 116, 97, 114,
  32, 97, 116, 32, 40, 48, 44, 48, 44, 48, 41, 44, 32, 119, 105, 116,
  104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 103, 101, 111, 109,
  101, 116, 114, 121, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39,
  110, 98, 95, 98, 114, 97, 110, 99, 104, 101, 115, 61, 53, 39, 32, 97,
  110, 100, 32, 39, 116, 104, 105, 99, 107, 110, 101, 115, 115, 61, 48, 46,
  51, 56, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  45, 115, 116, 97, 114, 51, 100, 32, 44, 32, 45, 45, 112, 114, 105, 109,
  105, 116, 105, 118, 101, 115, 51, 100, 32, 49, 32, 45, 99, 111, 108, 111,
  114, 51, 100, 91, 45, 50, 93, 32, 64, 123, 45, 82, 71, 66, 125, 10,
  115, 116, 97, 114, 51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 36, 123, 49, 61, 53, 125, 62, 48, 32, 38, 38, 32, 36, 123, 50,
  61, 48, 46, 51, 56, 125, 62, 61, 48, 32, 38, 38, 32, 36, 50, 60,
  61, 49, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112,
  117, 116, 32, 51, 100, 32, 115, 116, 97, 114, 44, 32, 119, 105, 116, 104,
  32, 36, 49, 32, 98, 114, 97, 110, 99, 104, 101, 115, 32, 97, 110, 100,
  32, 116, 104, 105, 99, 107, 110, 101, 115, 115, 32, 36, 50, 46, 34, 10,
  45, 118, 32, 45, 10, 78, 61, 123, 50, 42, 36, 49, 125, 32, 40, 123,
  39, 67, 73, 109, 103, 51, 100, 39, 125, 41, 32, 45, 43, 91, 45, 49,
  93, 32, 48, 46, 53, 32, 40, 123, 36, 78, 43, 49, 125, 59, 36, 78,
  41, 10, 40, 123, 45, 112, 105, 47, 50, 125, 59, 123, 51, 42, 112, 105,
  47, 50, 125, 41, 32, 45, 114, 91, 45, 49, 93, 32, 49, 44, 123, 36,
  78, 43, 49, 125, 44, 49, 44, 49, 44, 51, 32, 45, 114, 111, 119, 115,
  91, 45, 49, 93, 32, 48, 44, 123, 104, 45, 50, 125, 32, 45, 45, 115,
  105, 110, 91, 45, 49, 93, 32, 45, 99, 111, 115, 91, 45, 50, 93, 32,
  45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 10, 40, 49, 44, 49,
  59, 36, 50, 44, 36, 50, 41, 32, 45, 42, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 122, 91, 45, 49, 93, 32, 48, 44, 50, 32, 45, 114, 91,
  45, 49, 93, 32, 51, 44, 123, 104, 43, 49, 125, 44, 49, 44, 49, 44,
  48, 10, 40, 51, 44, 36, 78, 44, 49, 44, 48, 59, 51, 44, 36, 78,
  44, 36, 78, 44, 123, 36, 78, 45, 49, 125, 41, 32, 45, 114, 91, 45,
  49, 93, 32, 52, 44, 36, 78, 44, 49, 44, 49, 44, 51, 32, 45, 114,
  111, 117, 110, 100, 91, 45, 49, 93, 32, 45, 61, 91, 45, 49, 93, 32,
  48, 44, 50, 44, 49, 48, 48, 37, 10, 51, 44, 36, 78, 44, 49, 44,
  49, 44, 50, 48, 48, 32, 49, 44, 36, 78, 44, 49, 44, 49, 44, 49,
  32, 45, 121, 91, 45, 54, 44, 45, 52, 45, 45, 50, 93, 32, 45, 97,
  91, 45, 54, 45, 45, 49, 93, 32, 121, 32, 45, 110, 109, 91, 45, 49,
  93, 32, 91, 51, 100, 92, 32, 115, 116, 97, 114, 93, 10, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 116, 114, 101, 97, 109, 108,
  105, 110, 101, 51, 100, 32, 58, 32, 120, 91, 37, 93, 44, 121, 91, 37,
  93, 44, 122, 91, 37, 93, 44, 95, 76, 62, 61, 48, 44, 95, 100, 108,
  62, 48, 44, 95, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111,
  110, 44, 95, 105, 115, 95, 98, 97, 99, 107, 119, 97, 114, 100, 61, 123,
  32, 48, 32, 124, 32, 49, 32, 125, 44, 95, 105, 115, 95, 111, 114, 105,
  101, 110, 116, 101, 100, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 32,
  58, 32, 39, 102, 111, 114, 109, 117, 108, 97, 39, 44, 120, 44, 121, 44,
  122, 44, 95, 76, 62, 61, 48, 44, 95, 100, 108, 62, 48, 44, 95, 105,
  110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 44, 95, 105, 115,
  95, 98, 97, 99, 107, 119, 97, 114, 100, 61, 123, 32, 48, 32, 124, 32,
  49, 32, 125, 44, 95, 105, 115, 95, 111, 114, 105, 101, 110, 116, 101, 100,
  61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 32, 58, 32, 40, 43, 41,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 69, 120, 116, 114, 97, 99,
  116, 32, 51, 100, 32, 115, 116, 114, 101, 97, 109, 108, 105, 110, 101, 115,
  32, 102, 114, 111, 109, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 118,
  101, 99, 116, 111, 114, 32, 102, 105, 101, 108, 100, 115, 32, 111, 114, 32,
  102, 114, 111, 109, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 102,
  111, 114, 109, 117, 108, 97, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 39, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 39,
  32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 110, 101, 97, 114,
  101, 115, 116, 32, 105, 110, 116, 101, 103, 101, 114, 32, 124, 32, 49, 61,
  49, 115, 116, 45, 111, 114, 100, 101, 114, 32, 124, 32, 50, 61, 50, 110,
  100, 45, 111, 114, 100, 101, 114, 32, 124, 32, 51, 61, 52, 116, 104, 45,
  111, 114, 100, 101, 114, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115,
  58, 32, 39, 100, 108, 61, 48, 46, 49, 39, 44, 32, 39, 105, 110, 116,
  101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 61, 50, 39, 44, 32, 39,
  105, 115, 95, 98, 97, 99, 107, 119, 97, 114, 100, 61, 48, 39, 32, 97,
  110, 100, 32, 39, 105, 115, 95, 111, 114, 105, 101, 110, 116, 101, 100, 61,
  48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 49,
  48, 48, 44, 49, 48, 48, 44, 49, 48, 48, 44, 51, 32, 45, 114, 97,
  110, 100, 32, 45, 49, 48, 44, 49, 48, 32, 45, 98, 108, 117, 114, 32,
  51, 32, 45, 114, 101, 112, 101, 97, 116, 32, 51, 48, 48, 32, 45, 45,
  115, 116, 114, 101, 97, 109, 108, 105, 110, 101, 51, 100, 91, 48, 93, 32,
  123, 63, 40, 49, 48, 48, 41, 125, 44, 123, 63, 40, 49, 48, 48, 41,
  125, 44, 123, 63, 40, 49, 48, 48, 41, 125, 44, 49, 48, 48, 48, 44,
  49, 44, 49, 32, 45, 99, 111, 108, 111, 114, 51, 100, 91, 45, 49, 93,
  32, 64, 123, 45, 82, 71, 66, 125, 32, 45, 100, 111, 110, 101, 32, 45,
  114, 101, 109, 111, 118, 101, 91, 48, 93, 32, 45, 98, 111, 120, 51, 100,
  32, 49, 48, 48, 32, 45, 112, 114, 105, 109, 105, 116, 105, 118, 101, 115,
  51, 100, 91, 45, 49, 93, 32, 49, 32, 45, 97, 100, 100, 51, 100, 10,
  35, 64, 103, 109, 105, 99, 32, 45, 51, 100, 32, 58, 32, 101, 113, 46,
  32, 116, 111, 32, 39, 45, 115, 117, 98, 51, 100, 39, 46, 32, 58, 32,
  40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 115, 117, 98, 51, 100,
  32, 58, 32, 116, 120, 44, 95, 116, 121, 44, 95, 116, 122, 32, 58, 32,
  40, 43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 104, 105,
  102, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 51, 100, 32, 111,
  98, 106, 101, 99, 116, 115, 32, 119, 105, 116, 104, 32, 116, 104, 101, 32,
  111, 112, 112, 111, 115, 105, 116, 101, 32, 111, 102, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 100, 105, 115, 112, 108, 97, 99, 101, 109, 101,
  110, 116, 32, 118, 101, 99, 116, 111, 114, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 45, 51,
  100, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101,
  102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 116,
  121, 61, 116, 122, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 45, 115, 112, 104, 101, 114, 101, 51, 100, 32, 49, 48,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 53, 32, 45, 45, 115, 117, 98,
  51, 100, 91, 45, 49, 93, 32, 49, 48, 44, 123, 63, 40, 45, 49, 48,
  44, 49, 48, 41, 125, 44, 48, 32, 45, 99, 111, 108, 111, 114, 51, 100,
  91, 45, 49, 93, 32, 64, 123, 45, 82, 71, 66, 125, 32, 45, 100, 111,
  110, 101, 32, 45, 97, 100, 100, 51, 100, 10, 35, 64, 103, 109, 105, 99,
  32, 115, 117, 112, 101, 114, 102, 111, 114, 109, 117, 108, 97, 51, 100, 32,
  58, 32, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 62, 49, 44, 109,
  62, 61, 49, 44, 110, 49, 44, 110, 50, 44, 110, 51, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 73, 110, 112, 117, 116, 32, 50, 100, 32, 115,
  117, 112, 101, 114, 102, 111, 114, 109, 117, 108, 97, 32, 99, 117, 114, 118,
  101, 32, 97, 115, 32, 97, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117,
  108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 114, 101, 115, 111,
  108, 117, 116, 105, 111, 110, 61, 49, 48, 50, 52, 39, 44, 32, 39, 109,
  61, 56, 39, 44, 32, 39, 110, 49, 61, 49, 39, 44, 32, 39, 110, 50,
  61, 53, 39, 32, 97, 110, 100, 32, 39, 110, 51, 61, 56, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 115, 117, 112, 101,
  114, 102, 111, 114, 109, 117, 108, 97, 51, 100, 32, 44, 10, 115, 117, 112,
  101, 114, 102, 111, 114, 109, 117, 108, 97, 51, 100, 32, 58, 32, 45, 99,
  104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 49, 48, 50, 52, 125, 62,
  49, 32, 38, 38, 32, 36, 123, 50, 61, 56, 125, 62, 61, 49, 34, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 49, 125, 44, 36, 123, 52,
  61, 53, 125, 44, 36, 123, 53, 61, 56, 125, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 50, 100, 32, 115, 117, 112,
  101, 114, 102, 111, 114, 109, 117, 108, 97, 32, 99, 117, 114, 118, 101, 44,
  32, 119, 105, 116, 104, 32, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110,
  32, 36, 49, 44, 32, 109, 61, 36, 50, 32, 97, 110, 100, 32, 40, 110,
  49, 44, 110, 50, 44, 110, 51, 41, 61, 40, 36, 51, 44, 36, 52, 44,
  36, 53, 41, 46, 34, 10, 45, 118, 32, 45, 10, 114, 101, 115, 61, 123,
  114, 111, 117, 110, 100, 40, 36, 49, 41, 125, 10, 40, 54, 55, 46, 53,
  59, 55, 51, 46, 53, 59, 49, 48, 57, 46, 53, 59, 49, 48, 51, 46,
  53, 59, 53, 49, 46, 53, 59, 49, 48, 48, 46, 53, 59, 36, 114, 101,
  115, 59, 123, 36, 114, 101, 115, 45, 49, 125, 41, 10, 40, 48, 44, 123,
  50, 42, 112, 105, 125, 41, 32, 45, 114, 91, 45, 49, 93, 32, 36, 114,
  101, 115, 44, 49, 44, 49, 44, 49, 44, 51, 32, 91, 45, 49, 93, 10,
  45, 42, 91, 45, 49, 93, 32, 123, 36, 50, 47, 52, 125, 32, 45, 45,
  115, 105, 110, 91, 45, 49, 93, 32, 45, 99, 111, 115, 91, 45, 50, 93,
  32, 45, 97, 98, 115, 91, 45, 50, 44, 45, 49, 93, 10, 45, 94, 91,
  45, 50, 93, 32, 36, 52, 32, 45, 94, 91, 45, 49, 93, 32, 36, 53,
  32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 94, 91, 45, 49,
  93, 32, 123, 45, 49, 47, 36, 51, 125, 10, 45, 45, 115, 105, 110, 91,
  45, 50, 93, 32, 45, 99, 111, 115, 91, 45, 51, 93, 32, 45, 42, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 42, 91, 45, 51, 44, 45,
  50, 93, 32, 45, 110, 91, 45, 50, 44, 45, 49, 93, 32, 45, 49, 44,
  49, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 32, 45, 114,
  111, 119, 115, 91, 45, 49, 93, 32, 48, 44, 50, 32, 45, 116, 114, 97,
  110, 115, 112, 111, 115, 101, 91, 45, 49, 93, 32, 45, 114, 91, 45, 49,
  93, 32, 49, 44, 123, 119, 42, 104, 125, 44, 49, 44, 49, 44, 45, 49,
  10, 49, 44, 123, 36, 114, 101, 115, 45, 49, 125, 44, 49, 44, 49, 44,
  50, 32, 40, 48, 59, 123, 36, 114, 101, 115, 45, 50, 125, 41, 32, 45,
  114, 91, 45, 49, 93, 32, 49, 44, 123, 36, 114, 101, 115, 45, 49, 125,
  44, 49, 44, 49, 44, 51, 32, 45, 45, 43, 91, 45, 49, 93, 32, 49,
  32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 120, 32, 45, 114, 111,
  117, 110, 100, 91, 45, 49, 93, 32, 49, 32, 45, 114, 91, 45, 49, 93,
  32, 49, 44, 123, 119, 42, 104, 125, 44, 49, 44, 49, 44, 45, 49, 10,
  49, 44, 123, 51, 42, 40, 36, 114, 101, 115, 45, 49, 41, 125, 44, 49,
  44, 49, 44, 50, 48, 48, 32, 49, 44, 123, 36, 114, 101, 115, 45, 49,
  125, 44, 49, 44, 49, 44, 49, 32, 45, 97, 91, 45, 53, 45, 45, 49,
  93, 32, 121, 32, 45, 110, 109, 91, 45, 49, 93, 32, 91, 51, 100, 92,
  32, 115, 117, 112, 101, 114, 102, 111, 114, 109, 117, 108, 97, 93, 10, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 116, 101, 120, 116, 95,
  112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 51, 100, 32, 58, 32, 95,
  34, 116, 101, 120, 116, 49, 34, 44, 95, 34, 116, 101, 120, 116, 50, 34,
  44, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 73, 110, 112, 117, 116, 32, 51, 100, 32, 116,
  101, 120, 116, 32, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 32, 102,
  114, 111, 109, 32, 116, 104, 101, 32, 116, 119, 111, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 115, 116, 114, 105, 110, 103, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32,
  118, 97, 108, 117, 101, 115, 58, 32, 39, 116, 101, 120, 116, 49, 61, 34,
  116, 101, 120, 116, 49, 34, 39, 44, 32, 39, 116, 101, 120, 116, 50, 61,
  34, 116, 101, 120, 116, 50, 34, 39, 32, 97, 110, 100, 32, 39, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 61, 49, 39, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 45, 116, 101, 120, 116, 95, 112, 111,
  105, 110, 116, 99, 108, 111, 117, 100, 51, 100, 32, 34, 71, 39, 77, 73,
  67, 34, 44, 34, 82, 111, 99, 107, 115, 33, 34, 10, 116, 101, 120, 116,
  95, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 51, 100, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 34, 116, 101, 120, 116, 49,
  34, 125, 44, 36, 123, 50, 61, 34, 116, 101, 120, 116, 50, 34, 125, 44,
  36, 123, 51, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  73, 110, 112, 117, 116, 32, 51, 100, 32, 112, 111, 105, 110, 116, 99, 108,
  111, 117, 100, 32, 116, 101, 120, 116, 32, 111, 98, 106, 101, 99, 116, 32,
  102, 114, 111, 109, 32, 115, 116, 114, 105, 110, 103, 115, 32, 39, 36, 49,
  39, 32, 97, 110, 100, 32, 39, 36, 50, 39, 44, 32, 119, 105, 116, 104,
  32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 51, 46, 34,
  10, 45, 118, 32, 45, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 34,
  36, 49, 34, 44, 48, 44, 48, 44, 53, 55, 44, 49, 44, 49, 10, 48,
  32, 45, 116, 91, 45, 49, 93, 32, 34, 36, 50, 34, 44, 48, 44, 48,
  44, 53, 55, 44, 49, 44, 49, 32, 45, 109, 105, 114, 114, 111, 114, 91,
  45, 49, 93, 32, 121, 10, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121,
  91, 45, 50, 44, 45, 49, 93, 32, 50, 44, 48, 32, 45, 100, 105, 108,
  97, 116, 101, 91, 45, 50, 44, 45, 49, 93, 32, 50, 10, 45, 112, 101,
  114, 109, 117, 116, 101, 91, 45, 49, 93, 32, 122, 121, 120, 99, 32, 45,
  114, 91, 45, 50, 44, 45, 49, 93, 32, 64, 123, 45, 109, 97, 120, 95,
  119, 104, 100, 125, 32, 45, 97, 110, 100, 91, 45, 50, 44, 45, 49, 93,
  10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 114, 97, 110, 100,
  91, 45, 49, 93, 32, 48, 44, 123, 64, 123, 45, 50, 44, 100, 125, 45,
  49, 125, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 45, 114,
  91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 102, 91, 45, 49, 93,
  32, 39, 105, 102, 40, 122, 61, 61, 105, 44, 49, 44, 48, 41, 39, 10,
  45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32,
  45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 45, 102, 91, 45, 49, 93,
  32, 49, 32, 45, 114, 118, 91, 45, 50, 44, 45, 49, 93, 32, 45, 47,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 91,
  45, 50, 93, 10, 45, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93,
  32, 48, 44, 48, 44, 123, 100, 125, 32, 45, 61, 61, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 91, 45, 50, 93, 10,
  49, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 114, 97, 110,
  100, 91, 45, 49, 93, 32, 48, 44, 123, 64, 123, 45, 50, 44, 119, 125,
  45, 49, 125, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 45,
  114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 102, 91, 45, 49,
  93, 32, 39, 105, 102, 40, 120, 61, 61, 105, 44, 49, 44, 48, 41, 39,
  10, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49,
  32, 45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 45, 102, 91, 45, 49,
  93, 32, 49, 32, 45, 114, 118, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  47, 91, 45, 50, 44, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32,
  91, 45, 51, 93, 10, 45, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49,
  93, 32, 48, 44, 48, 44, 123, 100, 125, 32, 45, 61, 61, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 42, 91, 45, 51, 44, 45, 49, 93, 10, 45,
  111, 114, 91, 45, 50, 44, 45, 49, 93, 10, 45, 98, 91, 45, 49, 93,
  32, 36, 51, 32, 45, 105, 115, 111, 115, 117, 114, 102, 97, 99, 101, 51,
  100, 91, 45, 49, 93, 32, 50, 53, 37, 10, 45, 99, 51, 100, 91, 45,
  49, 93, 32, 45, 110, 51, 100, 91, 45, 49, 93, 32, 45, 110, 109, 91,
  45, 49, 93, 32, 34, 91, 51, 100, 32, 116, 101, 120, 116, 32, 112, 111,
  105, 110, 116, 99, 108, 111, 117, 100, 93, 34, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 116, 101, 120, 116, 51, 100, 32, 58, 32,
  116, 101, 120, 116, 44, 95, 102, 111, 110, 116, 95, 104, 101, 105, 103, 104,
  116, 62, 48, 44, 95, 100, 101, 112, 116, 104, 62, 48, 44, 95, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 73, 110, 112, 117, 116, 32, 97, 32, 51, 100, 32, 116, 101, 120,
  116, 32, 111, 98, 106, 101, 99, 116, 32, 102, 114, 111, 109, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 116, 101, 120, 116, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 102, 111, 110, 116, 95, 104, 101, 105,
  103, 104, 116, 61, 53, 55, 39, 44, 32, 39, 100, 101, 112, 116, 104, 61,
  49, 48, 39, 32, 97, 110, 100, 32, 39, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 61, 49, 46, 53, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 45, 116, 101, 120, 116, 51, 100, 32, 34, 71, 39,
  77, 73, 67, 32, 97, 115, 32, 97, 92, 110, 51, 68, 32, 108, 111, 103,
  111, 33, 34, 10, 116, 101, 120, 116, 51, 100, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 50, 61, 53, 55, 125, 44, 36, 123, 51, 61, 49,
  48, 125, 44, 36, 123, 52, 61, 49, 46, 53, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 51, 100, 32, 116, 101,
  120, 116, 32, 111, 98, 106, 101, 99, 116, 32, 39, 36, 49, 39, 32, 119,
  105, 116, 104, 32, 115, 105, 122, 101, 32, 36, 50, 44, 32, 100, 101, 112,
  116, 104, 32, 36, 51, 32, 97, 110, 100, 32, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 36, 52, 46, 34, 10, 45, 118, 32, 45, 32, 48,
  32, 45, 116, 91, 45, 49, 93, 32, 34, 36, 49, 34, 44, 48, 44, 48,
  44, 36, 50, 44, 49, 44, 49, 32, 45, 97, 117, 116, 111, 99, 114, 111,
  112, 91, 45, 49, 93, 32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 36, 51, 32, 45, 101, 120, 112,
  97, 110, 100, 95, 120, 121, 122, 91, 45, 49, 93, 32, 49, 48, 44, 48,
  10, 45, 98, 91, 45, 49, 93, 32, 36, 52, 32, 45, 105, 115, 111, 115,
  117, 114, 102, 97, 99, 101, 51, 100, 91, 45, 49, 93, 32, 52, 48, 37,
  32, 45, 114, 118, 51, 100, 91, 45, 49, 93, 32, 45, 110, 109, 91, 45,
  49, 93, 32, 34, 91, 51, 100, 32, 116, 101, 120, 116, 32, 39, 36, 49,
  39, 93, 34, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  116, 51, 100, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 116,
  101, 120, 116, 117, 114, 105, 122, 101, 51, 100, 39, 46, 32, 58, 32, 40,
  43, 41, 10, 35, 64, 103, 109, 105, 99, 32, 116, 101, 120, 116, 117, 114,
  105, 122, 101, 51, 100, 32, 58, 32, 91, 105, 110, 100, 95, 116, 101, 120,
  116, 117, 114, 101, 93, 44, 95, 91, 105, 110, 100, 95, 99, 111, 111, 114,
  100, 115, 93, 32, 58, 32, 40, 43, 41, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 84, 101, 120, 116, 117, 114, 105, 122, 101, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 115,
  32, 119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  116, 101, 120, 116, 117, 114, 101, 32, 97, 110, 100, 32, 99, 111, 111, 114,
  100, 105, 110, 97, 116, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 116, 51, 100, 39,
  41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 87, 104, 101, 110,
  32, 39, 91, 105, 110, 100, 95, 99, 111, 111, 114, 100, 115, 93, 39, 32,
  105, 115, 32, 111, 109, 105, 116, 116, 101, 100, 44, 32, 100, 101, 102, 97,
  117, 108, 116, 32, 88, 89, 32, 116, 101, 120, 116, 117, 114, 101, 32, 112,
  114, 111, 106, 101, 99, 116, 105, 111, 110, 32, 105, 115, 32, 112, 101, 114,
  102, 111, 114, 109, 101, 100, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32,
  39, 105, 110, 100, 95, 99, 111, 111, 114, 100, 115, 61, 40, 117, 110, 100,
  101, 102, 105, 110, 101, 100, 41, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  116, 111, 114, 117, 115, 51, 100, 32, 49, 48, 48, 44, 51, 48, 32, 45,
  116, 101, 120, 116, 117, 114, 105, 122, 101, 51, 100, 91, 45, 49, 93, 32,
  91, 45, 50, 93, 32, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 35,
  64, 103, 109, 105, 99, 32, 116, 111, 114, 117, 115, 51, 100, 32, 58, 32,
  95, 114, 97, 100, 105, 117, 115, 49, 44, 95, 114, 97, 100, 105, 117, 115,
  50, 44, 95, 110, 98, 95, 115, 117, 98, 100, 105, 118, 105, 115, 105, 111,
  110, 115, 49, 62, 50, 44, 95, 110, 98, 95, 115, 117, 98, 100, 105, 118,
  105, 115, 105, 111, 110, 115, 50, 62, 50, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 73, 110, 112, 117, 116, 32, 51, 100, 32, 116, 111, 114, 117,
  115, 32, 97, 116, 32, 40, 48, 44, 48, 44, 48, 41, 44, 32, 119, 105,
  116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 103, 101, 111,
  109, 101, 116, 114, 121, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 114, 97, 100, 105, 117, 115, 49, 61, 49, 39, 44, 32, 39, 114, 97,
  100, 105, 117, 115, 50, 61, 48, 46, 51, 39, 44, 32, 39, 110, 98, 95,
  115, 117, 98, 100, 105, 118, 105, 115, 105, 111, 110, 115, 49, 61, 50, 52,
  39, 32, 97, 110, 100, 32, 39, 110, 98, 95, 115, 117, 98, 100, 105, 118,
  105, 115, 105, 111, 110, 115, 50, 61, 49, 50, 39, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 45, 116, 111, 114, 117, 115, 51, 100,
  32, 49, 48, 44, 51, 32, 45, 45, 112, 114, 105, 109, 105, 116, 105, 118,
  101, 115, 51, 100, 32, 49, 32, 45, 99, 111, 108, 111, 114, 51, 100, 91,
  45, 50, 93, 32, 64, 123, 45, 82, 71, 66, 125, 10, 116, 111, 114, 117,
  115, 51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123,
  51, 61, 50, 52, 125, 62, 50, 32, 38, 38, 32, 36, 123, 52, 61, 49,
  50, 125, 62, 50, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  49, 125, 44, 36, 123, 50, 61, 48, 46, 51, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 51, 100, 32, 116, 111,
  114, 117, 115, 44, 32, 119, 105, 116, 104, 32, 114, 97, 100, 105, 105, 32,
  40, 36, 49, 44, 36, 50, 41, 32, 97, 110, 100, 32, 115, 117, 98, 100,
  105, 118, 105, 115, 105, 111, 110, 115, 32, 40, 36, 51, 44, 36, 52, 41,
  46, 34, 10, 45, 118, 32, 45, 10, 110, 98, 112, 61, 123, 36, 51, 42,
  36, 52, 125, 10, 49, 44, 56, 44, 49, 44, 49, 44, 54, 55, 46, 53,
  44, 55, 51, 46, 53, 44, 49, 48, 57, 46, 53, 44, 49, 48, 51, 46,
  53, 44, 53, 49, 46, 53, 44, 49, 48, 48, 46, 53, 44, 36, 110, 98,
  112, 44, 123, 36, 52, 42, 36, 51, 125, 10, 40, 48, 59, 123, 50, 42,
  112, 105, 125, 41, 32, 45, 45, 121, 91, 45, 49, 93, 32, 120, 10, 45,
  114, 91, 45, 50, 93, 32, 49, 44, 123, 36, 51, 43, 49, 125, 44, 49,
  44, 49, 44, 51, 32, 45, 122, 91, 45, 50, 93, 32, 48, 44, 48, 44,
  48, 44, 123, 36, 51, 45, 49, 125, 10, 45, 114, 91, 45, 49, 93, 32,
  123, 36, 52, 43, 49, 125, 44, 49, 44, 49, 44, 49, 44, 51, 32, 45,
  122, 91, 45, 49, 93, 32, 48, 44, 123, 36, 52, 45, 49, 125, 10, 45,
  45, 115, 105, 110, 91, 45, 50, 44, 45, 49, 93, 32, 45, 99, 111, 115,
  91, 45, 52, 44, 45, 51, 93, 32, 45, 114, 91, 45, 52, 45, 45, 49,
  93, 32, 36, 52, 44, 36, 51, 10, 45, 42, 91, 45, 51, 93, 32, 36,
  50, 32, 45, 43, 91, 45, 51, 93, 32, 36, 49, 32, 45, 42, 91, 45,
  49, 93, 32, 36, 50, 32, 45, 42, 91, 45, 52, 93, 32, 91, 45, 51,
  93, 32, 45, 42, 91, 45, 51, 44, 45, 50, 93, 10, 45, 121, 91, 45,
  51, 45, 45, 49, 93, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32,
  120, 10, 49, 44, 36, 51, 44, 49, 44, 49, 44, 39, 121, 39, 32, 45,
  42, 91, 45, 49, 93, 32, 36, 52, 32, 45, 45, 115, 104, 105, 102, 116,
  91, 45, 49, 93, 32, 48, 44, 45, 49, 32, 36, 52, 44, 49, 44, 49,
  44, 49, 44, 39, 120, 39, 32, 45, 45, 115, 104, 105, 102, 116, 91, 45,
  49, 93, 32, 45, 49, 32, 45, 114, 91, 45, 52, 45, 45, 49, 93, 32,
  36, 52, 44, 36, 51, 10, 45, 45, 43, 91, 45, 52, 44, 45, 49, 93,
  32, 45, 43, 91, 45, 50, 93, 32, 91, 45, 52, 93, 32, 45, 43, 91,
  45, 53, 93, 32, 91, 45, 51, 93, 32, 45, 43, 91, 45, 52, 44, 45,
  51, 93, 32, 45, 121, 91, 45, 52, 45, 45, 49, 93, 32, 45, 105, 91,
  45, 53, 93, 32, 49, 44, 123, 104, 125, 44, 49, 44, 49, 44, 52, 32,
  45, 97, 91, 45, 53, 45, 45, 49, 93, 32, 120, 10, 51, 44, 123, 104,
  125, 44, 49, 44, 49, 44, 50, 48, 48, 32, 49, 44, 123, 104, 125, 44,
  49, 44, 49, 44, 49, 32, 45, 121, 91, 45, 52, 45, 45, 50, 93, 32,
  45, 97, 91, 45, 53, 45, 45, 49, 93, 32, 121, 10, 45, 110, 109, 91,
  45, 49, 93, 32, 91, 51, 100, 92, 32, 116, 111, 114, 117, 115, 93, 10,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 116, 114, 105, 97,
  110, 103, 108, 101, 51, 100, 32, 58, 32, 120, 48, 44, 121, 48, 44, 122,
  48, 44, 120, 49, 44, 121, 49, 44, 122, 49, 44, 120, 50, 44, 121, 50,
  44, 122, 50, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 110, 112,
  117, 116, 32, 51, 100, 32, 116, 114, 105, 97, 110, 103, 108, 101, 32, 97,
  116, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 99, 111, 111, 114,
  100, 105, 110, 97, 116, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 45, 114, 101, 112, 101, 97, 116, 32, 49, 48, 48, 32,
  97, 61, 123, 36, 62, 42, 112, 105, 47, 53, 48, 125, 32, 45, 116, 114,
  105, 97, 110, 103, 108, 101, 51, 100, 32, 48, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 51, 44, 123, 99, 111, 115, 40, 51, 42, 36, 97, 41, 125,
  44, 123, 115, 105, 110, 40, 50, 42, 36, 97, 41, 125, 44, 48, 32, 45,
  99, 111, 108, 111, 114, 51, 100, 91, 45, 49, 93, 32, 64, 123, 45, 82,
  71, 66, 125, 32, 45, 100, 111, 110, 101, 32, 45, 97, 100, 100, 51, 100,
  10, 116, 114, 105, 97, 110, 103, 108, 101, 51, 100, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 51, 100, 32,
  116, 114, 105, 97, 110, 103, 108, 101, 32, 40, 36, 49, 44, 36, 50, 44,
  36, 51, 41, 45, 40, 36, 52, 44, 36, 53, 44, 36, 54, 41, 45, 40,
  36, 55, 44, 36, 56, 44, 36, 57, 41, 46, 34, 10, 45, 118, 32, 45,
  32, 49, 44, 50, 53, 44, 49, 44, 49, 44, 54, 55, 46, 53, 44, 55,
  51, 46, 53, 44, 49, 48, 57, 46, 53, 44, 49, 48, 51, 46, 53, 44,
  53, 49, 46, 53, 44, 49, 48, 48, 46, 53, 44, 51, 44, 49, 44, 36,
  123, 49, 45, 57, 125, 44, 51, 44, 48, 44, 49, 44, 50, 44, 50, 48,
  48, 44, 50, 48, 48, 44, 50, 48, 48, 44, 49, 32, 45, 110, 109, 91,
  45, 49, 93, 32, 91, 51, 100, 92, 32, 116, 114, 105, 97, 110, 103, 108,
  101, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 118,
  111, 108, 117, 109, 101, 51, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 84, 114, 97, 110, 115, 102, 111, 114, 109, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 51, 100, 32, 118, 111, 108, 117, 109, 101, 116, 114, 105,
  99, 32, 105, 109, 97, 103, 101, 115, 32, 97, 115, 32, 51, 100, 32, 112,
  97, 114, 97, 108, 108, 101, 108, 101, 112, 105, 112, 101, 100, 105, 99, 32,
  111, 98, 106, 101, 99, 116, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 97,
  110, 105, 109, 97, 116, 101, 32, 98, 108, 117, 114, 44, 48, 44, 53, 44,
  51, 48, 32, 45, 97, 32, 122, 32, 45, 118, 111, 108, 117, 109, 101, 51,
  100, 10, 118, 111, 108, 117, 109, 101, 51, 100, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 84, 114, 97, 110, 115, 102, 111, 114, 109, 32,
  105, 109, 97, 103, 101, 36, 63, 32, 97, 115, 32, 51, 100, 32, 112, 97,
  114, 97, 108, 108, 101, 108, 101, 112, 105, 112, 101, 100, 105, 99, 32, 111,
  98, 106, 101, 99, 116, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 32, 100, 61, 123, 100,
  125, 10, 45, 45, 115, 108, 105, 99, 101, 115, 32, 48, 32, 45, 45, 115,
  108, 105, 99, 101, 115, 91, 48, 93, 32, 49, 48, 48, 37, 32, 45, 109,
  105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 121, 10, 45, 45, 99, 111,
  108, 117, 109, 110, 115, 91, 48, 93, 32, 48, 32, 45, 45, 99, 111, 108,
  117, 109, 110, 115, 91, 48, 93, 32, 49, 48, 48, 37, 32, 45, 112, 101,
  114, 109, 117, 116, 101, 91, 45, 50, 44, 45, 49, 93, 32, 122, 121, 120,
  99, 32, 45, 109, 105, 114, 114, 111, 114, 91, 45, 50, 93, 32, 120, 10,
  45, 45, 114, 111, 119, 115, 91, 48, 93, 32, 48, 32, 45, 45, 114, 111,
  119, 115, 91, 48, 93, 32, 49, 48, 48, 37, 32, 45, 112, 101, 114, 109,
  117, 116, 101, 91, 45, 50, 44, 45, 49, 93, 32, 120, 122, 121, 99, 32,
  45, 109, 105, 114, 114, 111, 114, 91, 45, 50, 93, 32, 121, 10, 45, 114,
  109, 91, 48, 93, 32, 45, 105, 109, 97, 103, 101, 54, 99, 117, 98, 101,
  51, 100, 32, 45, 42, 51, 100, 32, 36, 119, 44, 36, 104, 44, 36, 100,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 119, 101, 105, 114, 100, 51, 100,
  32, 58, 32, 95, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 62, 48,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 110, 112, 117, 116, 32,
  51, 100, 32, 119, 101, 105, 114, 100, 32, 111, 98, 106, 101, 99, 116, 32,
  97, 116, 32, 40, 48, 44, 48, 44, 48, 41, 44, 32, 119, 105, 116, 104,
  32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 114, 101, 115, 111, 108,
  117, 116, 105, 111, 110, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39,
  114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 61, 51, 50, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 119, 101, 105, 114,
  100, 51, 100, 32, 52, 56, 32, 45, 45, 112, 114, 105, 109, 105, 116, 105,
  118, 101, 115, 51, 100, 32, 49, 32, 45, 99, 111, 108, 111, 114, 51, 100,
  91, 45, 50, 93, 32, 64, 123, 45, 82, 71, 66, 125, 10, 119, 101, 105,
  114, 100, 51, 100, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49,
  61, 51, 50, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110,
  112, 117, 116, 32, 51, 100, 32, 119, 101, 105, 114, 100, 32, 111, 98, 106,
  101, 99, 116, 44, 32, 119, 105, 116, 104, 32, 114, 101, 115, 111, 108, 117,
  116, 105, 111, 110, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 10, 45,
  105, 115, 111, 115, 117, 114, 102, 97, 99, 101, 51, 100, 32, 34, 39, 92,
  10, 84, 32, 61, 32, 49, 46, 54, 49, 56, 48, 51, 51, 57, 57, 59,
  92, 10, 50, 32, 45, 32, 40, 99, 111, 115, 40, 120, 32, 43, 32, 84,
  42, 121, 41, 32, 43, 32, 99, 111, 115, 40, 120, 32, 45, 32, 84, 42,
  121, 41, 32, 43, 32, 99, 111, 115, 40, 121, 32, 43, 32, 84, 42, 122,
  41, 32, 43, 32, 99, 111, 115, 40, 121, 32, 45, 32, 84, 42, 122, 41,
  32, 43, 32, 99, 111, 115, 40, 122, 32, 45, 32, 84, 42, 120, 41, 32,
  43, 32, 99, 111, 115, 40, 122, 32, 43, 32, 84, 42, 120, 41, 41, 92,
  10, 39, 34, 44, 48, 44, 45, 52, 46, 55, 44, 45, 52, 46, 55, 44,
  45, 52, 46, 55, 44, 52, 46, 55, 44, 52, 46, 55, 44, 52, 46, 55,
  44, 36, 49, 44, 36, 49, 44, 36, 49, 10, 45, 99, 51, 100, 91, 45,
  49, 93, 32, 45, 110, 51, 100, 91, 45, 49, 93, 32, 45, 110, 109, 91,
  45, 49, 93, 32, 91, 51, 100, 92, 32, 119, 101, 105, 114, 100, 93, 10,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 58, 58, 32, 80,
  114, 111, 103, 114, 97, 109, 32, 99, 111, 110, 116, 114, 111, 108, 115, 10,
  35, 64, 103, 109, 105, 99, 32, 97, 112, 112, 108, 121, 95, 112, 97, 114,
  97, 108, 108, 101, 108, 32, 58, 32, 34, 99, 111, 109, 109, 97, 110, 100,
  34, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 65, 112, 112, 108, 121, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100,
  32, 99, 111, 109, 109, 97, 110, 100, 32, 111, 110, 32, 101, 97, 99, 104,
  32, 111, 102, 32, 116, 104, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 44, 32, 98, 121, 32, 112, 97, 114, 97,
  108, 108, 101, 108, 105, 122, 105, 110, 103, 32, 105, 116, 32, 102, 111, 114,
  32, 97, 108, 108, 32, 105, 109, 97, 103, 101, 32, 111, 102, 32, 116, 104,
  101, 32, 108, 105, 115, 116, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 109,
  105, 114, 114, 111, 114, 32, 120, 32, 45, 45, 109, 105, 114, 114, 111, 114,
  32, 121, 32, 45, 97, 112, 112, 108, 121, 95, 112, 97, 114, 97, 108, 108,
  101, 108, 32, 34, 45, 98, 108, 117, 114, 32, 51, 34, 10, 97, 112, 112,
  108, 121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 69, 120, 101, 99, 117, 116, 101, 32, 99,
  111, 109, 109, 97, 110, 100, 32, 39, 36, 42, 39, 32, 111, 110, 32, 97,
  108, 108, 32, 105, 109, 97, 103, 101, 36, 63, 32, 105, 110, 32, 112, 97,
  114, 97, 108, 108, 101, 108, 44, 32, 117, 115, 105, 110, 103, 32, 34, 64,
  42, 34, 32, 116, 104, 114, 101, 97, 100, 115, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 109, 32, 34, 95, 97, 112, 112, 108, 121, 95, 112, 97, 114,
  97, 108, 108, 101, 108, 32, 58, 32, 36, 42, 34, 32, 78, 61, 64, 35,
  10, 45, 108, 91, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 42,
  32, 40, 123, 39, 45, 95, 97, 112, 112, 108, 121, 95, 112, 97, 114, 97,
  108, 108, 101, 108, 91, 36, 62, 93, 39, 125, 41, 32, 45, 100, 111, 110,
  101, 32, 45, 105, 102, 32, 123, 64, 35, 62, 49, 125, 32, 45, 105, 91,
  49, 45, 45, 50, 93, 32, 40, 123, 39, 44, 39, 125, 41, 32, 45, 101,
  110, 100, 105, 102, 32, 45, 97, 32, 120, 32, 97, 114, 103, 48, 61, 64,
  123, 45, 49, 44, 116, 125, 32, 45, 114, 109, 10, 45, 105, 102, 32, 123,
  36, 78, 37, 64, 42, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  36, 78, 37, 64, 42, 125, 32, 40, 123, 39, 45, 95, 97, 112, 112, 108,
  121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 91, 36, 62, 93, 39, 125,
  41, 32, 45, 100, 111, 110, 101, 32, 45, 105, 102, 32, 123, 64, 35, 62,
  49, 125, 32, 45, 105, 91, 49, 45, 45, 50, 93, 32, 40, 123, 39, 44,
  39, 125, 41, 32, 45, 101, 110, 100, 105, 102, 32, 45, 97, 32, 120, 32,
  97, 114, 103, 49, 61, 64, 123, 45, 49, 44, 116, 125, 32, 45, 114, 109,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 123, 114, 111, 117, 110, 100, 40, 64, 35, 47,
  64, 42, 44, 49, 44, 49, 41, 125, 32, 45, 108, 91, 123, 64, 42, 42,
  36, 62, 125, 45, 123, 109, 105, 110, 40, 64, 42, 42, 36, 62, 43, 64,
  42, 45, 49, 44, 64, 35, 45, 49, 41, 125, 93, 10, 45, 112, 97, 114,
  97, 108, 108, 101, 108, 32, 36, 123, 97, 114, 103, 123, 64, 35, 33, 61,
  64, 42, 125, 125, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 45, 117, 110, 99, 111, 109, 109, 97, 110, 100, 32, 95, 97, 112, 112,
  108, 121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 32, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 97, 112, 112, 108, 121, 95, 112, 97,
  114, 97, 108, 108, 101, 108, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  58, 32, 34, 99, 111, 109, 109, 97, 110, 100, 34, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 115, 112, 101, 99, 105,
  102, 105, 101, 100, 32, 99, 111, 109, 109, 97, 110, 100, 32, 111, 110, 32,
  101, 97, 99, 104, 32, 111, 102, 32, 116, 104, 101, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 44, 32, 98, 121, 32,
  112, 97, 114, 97, 108, 108, 101, 108, 105, 122, 105, 110, 103, 32, 105, 116,
  32, 102, 111, 114, 32, 97, 108, 108, 32, 99, 104, 97, 110, 110, 101, 108,
  32, 111, 102, 32, 116, 104, 101, 32, 105, 109, 97, 103, 101, 115, 32, 105,
  110, 100, 101, 112, 101, 110, 100, 101, 110, 116, 108, 121, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 97, 112, 112, 108, 121, 95, 112, 97, 114, 97, 108, 108,
  101, 108, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 98, 108,
  117, 114, 32, 51, 34, 10, 97, 112, 112, 108, 121, 95, 112, 97, 114, 97,
  108, 108, 101, 108, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 69, 120, 101, 99, 117, 116, 101,
  32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 42, 39, 32, 111, 110,
  32, 97, 108, 108, 32, 99, 104, 97, 110, 110, 101, 108, 115, 32, 111, 102,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 105, 110, 32, 112, 97, 114, 97,
  108, 108, 101, 108, 44, 32, 117, 115, 105, 110, 103, 32, 34, 64, 42, 34,
  32, 116, 104, 114, 101, 97, 100, 115, 46, 34, 10, 45, 118, 32, 45, 32,
  78, 61, 64, 35, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 78, 32,
  115, 36, 62, 61, 64, 123, 36, 62, 44, 115, 125, 32, 45, 100, 111, 110,
  101, 32, 45, 115, 32, 99, 10, 45, 97, 112, 112, 108, 121, 95, 112, 97,
  114, 97, 108, 108, 101, 108, 32, 34, 36, 49, 34, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 36, 78, 32, 45, 97, 91, 36, 62, 45, 123, 36, 62,
  43, 36, 123, 115, 36, 62, 125, 45, 49, 125, 93, 32, 99, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  97, 112, 112, 108, 121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111,
  118, 101, 114, 108, 97, 112, 32, 58, 32, 34, 99, 111, 109, 109, 97, 110,
  100, 34, 44, 111, 118, 101, 114, 108, 97, 112, 91, 37, 93, 44, 110, 98,
  95, 116, 104, 114, 101, 97, 100, 115, 61, 123, 32, 48, 61, 97, 117, 116,
  111, 32, 124, 32, 49, 32, 124, 32, 50, 32, 124, 32, 52, 32, 124, 32,
  56, 32, 124, 32, 49, 54, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 65, 112, 112, 108, 121, 32, 115, 112, 101, 99, 105, 102, 105, 101,
  100, 32, 99, 111, 109, 109, 97, 110, 100, 32, 111, 110, 32, 101, 97, 99,
  104, 32, 111, 102, 32, 116, 104, 101, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 44, 32, 98, 121, 32, 112, 97, 114,
  97, 108, 108, 101, 108, 105, 122, 105, 110, 103, 32, 105, 116, 32, 111, 110,
  32, 39, 110, 98, 95, 116, 104, 114, 101, 97, 100, 115, 39, 32, 111, 118,
  101, 114, 108, 97, 112, 112, 101, 100, 32, 115, 117, 98, 45, 105, 109, 97,
  103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 110,
  98, 95, 116, 104, 114, 101, 97, 100, 115, 39, 32, 109, 117, 115, 116, 32,
  98, 101, 32, 97, 32, 112, 111, 119, 101, 114, 32, 111, 102, 32, 50, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108,
  116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 111, 118, 101, 114, 108,
  97, 112, 61, 48, 39, 44, 39, 110, 98, 95, 116, 104, 114, 101, 97, 100,
  115, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 97, 112, 112,
  108, 121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114,
  108, 97, 112, 32, 34, 45, 115, 109, 111, 111, 116, 104, 32, 53, 48, 48,
  44, 48, 44, 49, 34, 44, 49, 54, 10, 97, 112, 112, 108, 121, 95, 112,
  97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 50, 61, 48, 125,
  62, 61, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 51,
  61, 48, 125, 41, 32, 38, 38, 32, 36, 51, 62, 61, 48, 34, 10, 45,
  118, 32, 45, 32, 78, 61, 123, 105, 102, 40, 36, 51, 44, 109, 97, 120,
  40, 49, 44, 114, 111, 117, 110, 100, 40, 36, 51, 41, 41, 44, 64, 42,
  41, 125, 32, 78, 61, 123, 50, 94, 105, 110, 116, 40, 108, 111, 103, 50,
  40, 109, 105, 110, 40, 49, 54, 44, 36, 78, 41, 41, 41, 125, 32, 45,
  118, 32, 43, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112,
  108, 121, 32, 112, 97, 114, 97, 108, 108, 101, 108, 105, 122, 101, 100, 32,
  99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110, 32,
  105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 111, 118,
  101, 114, 108, 97, 112, 32, 36, 50, 32, 97, 110, 100, 32, 34, 36, 78,
  34, 32, 116, 104, 114, 101, 97, 100, 115, 46, 34, 10, 45, 118, 32, 45,
  10, 45, 109, 32, 34, 95, 99, 104, 101, 99, 107, 49, 32, 58, 32, 45,
  105, 102, 32, 123, 64, 35, 33, 61, 49, 125, 32, 45, 101, 114, 114, 111,
  114, 91, 48, 45, 45, 57, 93, 32, 92, 34, 83, 112, 101, 99, 105, 102,
  105, 101, 100, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 49, 39,
  32, 99, 104, 97, 110, 103, 101, 115, 32, 116, 104, 101, 32, 115, 105, 122,
  101, 32, 111, 102, 32, 116, 104, 101, 32, 105, 109, 97, 103, 101, 32, 115,
  116, 97, 99, 107, 46, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 95, 97, 112, 112, 108, 121, 95, 112, 97, 114, 97, 108, 108,
  101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 36, 78, 32, 34, 36, 49,
  34, 44, 36, 50, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 45, 117, 110, 99, 111, 109, 109, 97, 110, 100, 32, 95, 99, 104, 101,
  99, 107, 49, 10, 45, 118, 32, 43, 10, 95, 97, 112, 112, 108, 121, 95,
  112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112,
  49, 32, 58, 10, 36, 49, 10, 95, 97, 112, 112, 108, 121, 95, 112, 97,
  114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 50, 32,
  58, 10, 45, 105, 102, 32, 123, 119, 62, 61, 104, 125, 10, 111, 118, 120,
  61, 123, 114, 111, 117, 110, 100, 40, 105, 102, 40, 64, 123, 34, 45, 105,
  115, 95, 112, 101, 114, 99, 101, 110, 116, 32, 36, 50, 34, 125, 44, 119,
  42, 36, 50, 44, 36, 50, 41, 41, 125, 32, 119, 50, 61, 123, 105, 110,
  116, 40, 119, 47, 50, 41, 125, 10, 45, 45, 122, 91, 48, 93, 32, 123,
  36, 119, 50, 45, 36, 111, 118, 120, 125, 44, 49, 48, 48, 37, 32, 45,
  122, 91, 48, 93, 32, 48, 44, 123, 36, 119, 50, 43, 36, 111, 118, 120,
  45, 49, 125, 10, 45, 112, 97, 114, 97, 108, 108, 101, 108, 32, 34, 45,
  108, 91, 48, 93, 32, 36, 49, 32, 45, 95, 99, 104, 101, 99, 107, 49,
  32, 45, 101, 110, 100, 108, 34, 44, 34, 45, 108, 91, 49, 93, 32, 36,
  49, 32, 45, 95, 99, 104, 101, 99, 107, 49, 32, 45, 101, 110, 100, 108,
  34, 10, 45, 122, 91, 48, 93, 32, 48, 44, 64, 123, 48, 44, 119, 45,
  49, 45, 36, 111, 118, 120, 125, 32, 45, 122, 91, 49, 93, 32, 36, 111,
  118, 120, 44, 49, 48, 48, 37, 32, 45, 97, 32, 120, 10, 45, 101, 108,
  115, 101, 10, 111, 118, 121, 61, 123, 114, 111, 117, 110, 100, 40, 105, 102,
  40, 64, 123, 34, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 32,
  36, 50, 34, 125, 44, 104, 42, 36, 50, 44, 36, 50, 41, 41, 125, 32,
  104, 50, 61, 123, 105, 110, 116, 40, 104, 47, 50, 41, 125, 10, 45, 45,
  114, 111, 119, 115, 91, 48, 93, 32, 123, 36, 104, 50, 45, 36, 111, 118,
  121, 125, 44, 49, 48, 48, 37, 32, 45, 114, 111, 119, 115, 91, 48, 93,
  32, 48, 44, 123, 36, 104, 50, 43, 36, 111, 118, 121, 45, 49, 125, 10,
  45, 112, 97, 114, 97, 108, 108, 101, 108, 32, 34, 45, 108, 91, 48, 93,
  32, 36, 49, 32, 45, 95, 99, 104, 101, 99, 107, 49, 32, 45, 101, 110,
  100, 108, 34, 44, 34, 45, 108, 91, 49, 93, 32, 36, 49, 32, 45, 95,
  99, 104, 101, 99, 107, 49, 32, 45, 101, 110, 100, 108, 34, 10, 45, 114,
  111, 119, 115, 91, 48, 93, 32, 48, 44, 64, 123, 48, 44, 104, 45, 49,
  45, 36, 111, 118, 121, 125, 32, 45, 114, 111, 119, 115, 91, 49, 93, 32,
  36, 111, 118, 121, 44, 49, 48, 48, 37, 32, 45, 97, 32, 121, 10, 45,
  101, 110, 100, 105, 102, 10, 95, 97, 112, 112, 108, 121, 95, 112, 97, 114,
  97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 52, 32, 58,
  10, 45, 105, 102, 32, 123, 109, 97, 120, 40, 119, 44, 104, 41, 47, 109,
  105, 110, 40, 119, 44, 104, 41, 62, 61, 51, 125, 10, 45, 95, 97, 112,
  112, 108, 121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101,
  114, 108, 97, 112, 50, 32, 34, 45, 95, 97, 112, 112, 108, 121, 95, 112,
  97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 50,
  32, 92, 34, 36, 49, 92, 34, 44, 36, 50, 34, 44, 36, 50, 10, 45,
  101, 108, 115, 101, 10, 111, 118, 120, 61, 123, 114, 111, 117, 110, 100, 40,
  105, 102, 40, 64, 123, 34, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110,
  116, 32, 36, 50, 34, 125, 44, 119, 42, 36, 50, 44, 36, 50, 41, 41,
  125, 32, 119, 50, 61, 123, 105, 110, 116, 40, 119, 47, 50, 41, 125, 10,
  111, 118, 121, 61, 123, 114, 111, 117, 110, 100, 40, 105, 102, 40, 64, 123,
  34, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 32, 36, 50, 34,
  125, 44, 104, 42, 36, 50, 44, 36, 50, 41, 41, 125, 32, 104, 50, 61,
  123, 105, 110, 116, 40, 104, 47, 50, 41, 125, 10, 45, 45, 122, 91, 48,
  93, 32, 123, 36, 119, 50, 45, 36, 111, 118, 120, 125, 44, 48, 44, 49,
  48, 48, 37, 44, 123, 36, 104, 50, 43, 36, 111, 118, 121, 45, 49, 125,
  32, 45, 45, 122, 91, 48, 93, 32, 48, 44, 123, 36, 104, 50, 45, 36,
  111, 118, 121, 125, 44, 123, 36, 119, 50, 43, 36, 111, 118, 120, 45, 49,
  125, 44, 49, 48, 48, 37, 10, 45, 45, 122, 91, 48, 93, 32, 123, 36,
  119, 50, 45, 36, 111, 118, 120, 125, 44, 123, 36, 104, 50, 45, 36, 111,
  118, 121, 125, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 122,
  91, 48, 93, 32, 48, 44, 48, 44, 123, 36, 119, 50, 43, 36, 111, 118,
  120, 45, 49, 125, 44, 123, 36, 104, 50, 43, 36, 111, 118, 121, 45, 49,
  125, 10, 45, 112, 97, 114, 97, 108, 108, 101, 108, 32, 34, 45, 108, 91,
  48, 93, 32, 36, 49, 32, 45, 95, 99, 104, 101, 99, 107, 49, 32, 45,
  101, 110, 100, 108, 34, 44, 34, 45, 108, 91, 49, 93, 32, 36, 49, 32,
  45, 95, 99, 104, 101, 99, 107, 49, 32, 45, 101, 110, 100, 108, 34, 44,
  34, 45, 108, 91, 50, 93, 32, 36, 49, 32, 45, 95, 99, 104, 101, 99,
  107, 49, 32, 45, 101, 110, 100, 108, 34, 44, 34, 45, 108, 91, 51, 93,
  32, 36, 49, 32, 45, 95, 99, 104, 101, 99, 107, 49, 32, 45, 101, 110,
  100, 108, 34, 10, 45, 122, 91, 48, 93, 32, 48, 44, 48, 44, 64, 123,
  48, 44, 119, 45, 49, 45, 36, 111, 118, 120, 125, 44, 64, 123, 48, 44,
  104, 45, 49, 45, 36, 111, 118, 121, 125, 32, 45, 122, 91, 49, 93, 32,
  36, 111, 118, 120, 44, 48, 44, 49, 48, 48, 37, 44, 64, 123, 49, 44,
  104, 45, 49, 45, 36, 111, 118, 121, 125, 10, 45, 122, 91, 50, 93, 32,
  48, 44, 36, 111, 118, 121, 44, 64, 123, 50, 44, 119, 45, 49, 45, 36,
  111, 118, 120, 125, 44, 49, 48, 48, 37, 32, 45, 122, 91, 51, 93, 32,
  36, 111, 118, 120, 44, 36, 111, 118, 121, 44, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 10, 45, 97, 91, 48, 44, 49, 93, 32, 120, 32, 45, 97,
  91, 49, 44, 50, 93, 32, 120, 32, 45, 97, 32, 121, 10, 45, 101, 110,
  100, 105, 102, 10, 95, 97, 112, 112, 108, 121, 95, 112, 97, 114, 97, 108,
  108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 56, 32, 58, 10, 45,
  95, 97, 112, 112, 108, 121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95,
  111, 118, 101, 114, 108, 97, 112, 50, 32, 34, 45, 95, 97, 112, 112, 108,
  121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108,
  97, 112, 52, 32, 92, 34, 36, 49, 92, 34, 44, 36, 50, 34, 44, 36,
  50, 10, 95, 97, 112, 112, 108, 121, 95, 112, 97, 114, 97, 108, 108, 101,
  108, 95, 111, 118, 101, 114, 108, 97, 112, 49, 54, 32, 58, 10, 45, 95,
  97, 112, 112, 108, 121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111,
  118, 101, 114, 108, 97, 112, 52, 32, 34, 45, 95, 97, 112, 112, 108, 121,
  95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97,
  112, 52, 32, 92, 34, 36, 49, 92, 34, 44, 36, 50, 34, 44, 36, 50,
  10, 35, 64, 103, 109, 105, 99, 32, 99, 104, 101, 99, 107, 32, 58, 32,
  101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 58, 32, 40, 42, 41,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 69, 118, 97, 108, 117, 97,
  116, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 101, 120, 112,
  114, 101, 115, 115, 105, 111, 110, 32, 97, 110, 100, 32, 100, 105, 115, 112,
  108, 97, 121, 32, 97, 110, 32, 101, 114, 114, 111, 114, 32, 109, 101, 115,
  115, 97, 103, 101, 32, 105, 102, 32, 101, 118, 97, 108, 117, 97, 116, 101,
  100, 32, 116, 111, 32, 102, 97, 108, 115, 101, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 73, 102, 32, 39, 101, 120, 112, 114, 101, 115, 115,
  105, 111, 110, 39, 32, 105, 115, 32, 110, 111, 116, 32, 101, 118, 97, 108,
  117, 97, 98, 108, 101, 44, 32, 105, 116, 32, 105, 115, 32, 114, 101, 103,
  97, 114, 100, 101, 100, 32, 97, 115, 32, 97, 32, 102, 105, 108, 101, 110,
  97, 109, 101, 32, 97, 110, 100, 32, 99, 104, 101, 99, 107, 101, 100, 32,
  105, 102, 32, 105, 116, 32, 101, 120, 105, 115, 116, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 99, 104, 101, 99, 107, 51, 100, 32, 58, 32, 95,
  105, 115, 95, 102, 117, 108, 108, 95, 99, 104, 101, 99, 107, 61, 123, 32,
  48, 32, 124, 32, 49, 32, 125, 32, 58, 32, 40, 42, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 67, 104, 101, 99, 107, 32, 118, 97, 108,
  105, 100, 105, 116, 121, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 51, 100, 32, 118, 101, 99, 116, 111, 114, 32, 111, 98, 106, 101,
  99, 116, 115, 44, 32, 97, 110, 100, 32, 100, 105, 115, 112, 108, 97, 121,
  32, 97, 110, 32, 101, 114, 114, 111, 114, 32, 109, 101, 115, 115, 97, 103,
  101, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 105, 102, 32, 111, 110,
  101, 32, 111, 102, 32, 116, 104, 101, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 32, 105, 115, 32, 110, 111, 116, 32, 97,
  32, 118, 97, 108, 105, 100, 32, 51, 100, 32, 118, 101, 99, 116, 111, 114,
  32, 111, 98, 106, 101, 99, 116, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 70, 117, 108, 108, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116,
  32, 99, 104, 101, 99, 107, 32, 105, 115, 32, 115, 108, 111, 119, 101, 114,
  32, 98, 117, 116, 32, 109, 111, 114, 101, 32, 112, 114, 101, 99, 105, 115,
  101, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 105, 115, 95, 102,
  117, 108, 108, 95, 99, 104, 101, 99, 107, 61, 49, 39, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 99, 111, 110, 116, 105, 110, 117, 101, 32, 58, 32,
  40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 71, 111, 32,
  116, 111, 32, 101, 110, 100, 32, 111, 102, 32, 99, 117, 114, 114, 101, 110,
  116, 32, 98, 108, 111, 99, 107, 32, 39, 114, 101, 112, 101, 97, 116, 46,
  46, 100, 111, 110, 101, 39, 44, 32, 39, 100, 111, 46, 46, 119, 104, 105,
  108, 101, 39, 32, 111, 114, 32, 39, 108, 111, 99, 97, 108, 46, 46, 101,
  110, 100, 108, 111, 99, 97, 108, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 49, 48, 32, 45, 98, 108, 117, 114, 32,
  49, 32, 45, 105, 102, 32, 123, 49, 61, 61, 49, 125, 32, 45, 99, 111,
  110, 116, 105, 110, 117, 101, 32, 45, 101, 110, 100, 105, 102, 32, 45, 100,
  101, 102, 111, 114, 109, 32, 49, 48, 32, 45, 100, 111, 110, 101, 10, 35,
  64, 103, 109, 105, 99, 32, 98, 114, 101, 97, 107, 32, 58, 32, 40, 42,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 66, 114, 101, 97, 107,
  32, 99, 117, 114, 114, 101, 110, 116, 32, 39, 114, 101, 112, 101, 97, 116,
  46, 46, 100, 111, 110, 101, 39, 44, 32, 39, 100, 111, 46, 46, 119, 104,
  105, 108, 101, 39, 32, 111, 114, 32, 39, 108, 111, 99, 97, 108, 46, 46,
  101, 110, 100, 108, 111, 99, 97, 108, 39, 32, 98, 108, 111, 99, 107, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 114, 101, 112, 101, 97, 116, 32, 49, 48,
  32, 45, 98, 108, 117, 114, 32, 49, 32, 45, 105, 102, 32, 123, 49, 61,
  61, 49, 125, 32, 45, 98, 114, 101, 97, 107, 32, 45, 101, 110, 100, 105,
  102, 32, 45, 100, 101, 102, 111, 114, 109, 32, 49, 48, 32, 45, 100, 111,
  110, 101, 10, 35, 64, 103, 109, 105, 99, 32, 100, 111, 32, 58, 32, 40,
  42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 116, 97, 114,
  116, 32, 97, 32, 39, 100, 111, 46, 46, 119, 104, 105, 108, 101, 39, 32,
  98, 108, 111, 99, 107, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 108, 117, 109,
  105, 110, 97, 110, 99, 101, 32, 105, 61, 123, 105, 97, 43, 50, 125, 32,
  45, 100, 111, 32, 45, 115, 101, 116, 32, 50, 53, 53, 44, 123, 63, 40,
  49, 48, 48, 41, 125, 37, 44, 123, 63, 40, 49, 48, 48, 41, 125, 37,
  32, 45, 119, 104, 105, 108, 101, 32, 123, 105, 97, 60, 36, 105, 125, 10,
  35, 64, 103, 109, 105, 99, 32, 100, 111, 110, 101, 32, 58, 32, 40, 42,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 69, 110, 100, 32, 97,
  32, 39, 114, 101, 112, 101, 97, 116, 46, 46, 100, 111, 110, 101, 39, 32,
  98, 108, 111, 99, 107, 44, 32, 97, 110, 100, 32, 103, 111, 32, 116, 111,
  32, 97, 115, 115, 111, 99, 105, 97, 116, 101, 100, 32, 39, 45, 114, 101,
  112, 101, 97, 116, 39, 32, 112, 111, 115, 105, 116, 105, 111, 110, 44, 32,
  105, 102, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 114, 101,
  109, 97, 105, 110, 46, 10, 35, 64, 103, 109, 105, 99, 32, 101, 108, 105,
  102, 32, 58, 32, 98, 111, 111, 108, 101, 97, 110, 32, 58, 32, 102, 105,
  108, 101, 110, 97, 109, 101, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 83, 116, 97, 114, 116, 32, 97, 32, 39, 101,
  108, 105, 102, 46, 46, 91, 101, 108, 115, 101, 93, 46, 46, 101, 110, 100,
  105, 102, 39, 32, 98, 108, 111, 99, 107, 32, 105, 102, 32, 112, 114, 101,
  118, 105, 111, 117, 115, 32, 39, 45, 105, 102, 39, 32, 119, 97, 115, 32,
  110, 111, 116, 32, 118, 101, 114, 105, 102, 105, 101, 100, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 97, 110, 100, 32, 116, 101, 115, 116, 32, 105,
  102, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 98, 111, 111, 108,
  101, 97, 110, 32, 105, 115, 32, 116, 114, 117, 101, 44, 32, 111, 114, 32,
  105, 102, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 102, 105, 108,
  101, 110, 97, 109, 101, 32, 101, 120, 105, 115, 116, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 39, 98, 111, 111, 108, 101, 97, 110, 39,
  32, 99, 97, 110, 32, 98, 101, 32, 97, 32, 102, 108, 111, 97, 116, 32,
  110, 117, 109, 98, 101, 114, 32, 115, 116, 97, 110, 100, 105, 110, 103, 32,
  102, 111, 114, 32, 123, 32, 48, 61, 102, 97, 108, 115, 101, 32, 124, 32,
  111, 116, 104, 101, 114, 61, 116, 114, 117, 101, 32, 125, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 101, 108, 115, 101, 32, 58, 32, 40, 42, 41, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 69, 120, 101, 99, 117, 116, 101,
  32, 102, 111, 108, 108, 111, 119, 105, 110, 103, 32, 99, 111, 109, 109, 97,
  110, 100, 115, 32, 105, 102, 32, 112, 114, 101, 118, 105, 111, 117, 115, 32,
  39, 45, 105, 102, 39, 32, 111, 114, 32, 39, 45, 101, 108, 105, 102, 39,
  32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 115, 32, 102, 97, 105, 108,
  101, 100, 46, 10, 35, 64, 103, 109, 105, 99, 32, 101, 110, 100, 105, 102,
  32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  69, 110, 100, 32, 97, 32, 39, 105, 102, 46, 46, 91, 101, 108, 105, 102,
  93, 46, 46, 91, 101, 108, 115, 101, 93, 46, 46, 101, 110, 100, 105, 102,
  39, 32, 98, 108, 111, 99, 107, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  101, 110, 100, 108, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45,
  101, 110, 100, 108, 111, 99, 97, 108, 39, 46, 32, 58, 32, 40, 42, 41,
  10, 35, 64, 103, 109, 105, 99, 32, 101, 110, 100, 108, 111, 99, 97, 108,
  32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  69, 110, 100, 32, 97, 32, 39, 108, 111, 99, 97, 108, 46, 46, 101, 110,
  100, 108, 111, 99, 97, 108, 39, 32, 98, 108, 111, 99, 107, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111, 32,
  39, 45, 101, 110, 100, 108, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 101, 114, 114, 111, 114, 32, 58, 32, 109, 101, 115, 115, 97, 103, 101,
  32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  80, 114, 105, 110, 116, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  101, 114, 114, 111, 114, 32, 109, 101, 115, 115, 97, 103, 101, 32, 111, 110,
  32, 116, 104, 101, 32, 115, 116, 97, 110, 100, 97, 114, 100, 32, 101, 114,
  114, 111, 114, 32, 40, 115, 116, 100, 101, 114, 114, 41, 32, 97, 110, 100,
  32, 101, 120, 105, 116, 32, 105, 110, 116, 101, 114, 112, 114, 101, 116, 101,
  114, 44, 32, 101, 120, 99, 101, 112, 116, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 105, 102, 32, 101, 114, 114, 111, 114, 32, 105, 115, 32, 99,
  97, 117, 103, 104, 116, 32, 98, 121, 32, 97, 32, 39, 45, 111, 110, 102,
  97, 105, 108, 39, 32, 99, 111, 109, 109, 97, 110, 100, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 67, 111, 109, 109, 97, 110, 100, 32, 115,
  117, 98, 115, 101, 116, 32, 40, 105, 102, 32, 97, 110, 121, 41, 32, 115,
  116, 97, 110, 100, 115, 32, 102, 111, 114, 32, 100, 105, 115, 112, 108, 97,
  121, 101, 100, 32, 115, 99, 111, 112, 101, 32, 105, 110, 100, 105, 99, 101,
  115, 32, 105, 110, 115, 116, 101, 97, 100, 32, 111, 102, 32, 105, 109, 97,
  103, 101, 32, 105, 110, 100, 105, 99, 101, 115, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 120, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45,
  101, 120, 101, 99, 39, 46, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103,
  109, 105, 99, 32, 101, 120, 101, 99, 32, 58, 32, 99, 111, 109, 109, 97,
  110, 100, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 69, 120, 101, 99, 117, 116, 101, 32, 101, 120, 116, 101, 114, 110,
  97, 108, 32, 99, 111, 109, 109, 97, 110, 100, 32, 117, 115, 105, 110, 103,
  32, 97, 32, 115, 121, 115, 116, 101, 109, 32, 99, 97, 108, 108, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 84, 104, 101, 32, 115, 116, 97,
  116, 117, 115, 32, 118, 97, 108, 117, 101, 32, 105, 115, 32, 116, 104, 101,
  110, 32, 115, 101, 116, 32, 116, 111, 32, 116, 104, 101, 32, 101, 114, 114,
  111, 114, 32, 99, 111, 100, 101, 32, 114, 101, 116, 117, 114, 110, 101, 100,
  32, 98, 121, 32, 116, 104, 101, 32, 115, 121, 115, 116, 101, 109, 32, 99,
  97, 108, 108, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101,
  113, 46, 32, 116, 111, 32, 39, 45, 120, 39, 41, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 105, 102, 32, 58, 32, 98, 111, 111, 108, 101, 97, 110,
  32, 58, 32, 102, 105, 108, 101, 110, 97, 109, 101, 32, 58, 32, 40, 42,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 116, 97, 114, 116,
  32, 97, 32, 39, 105, 102, 46, 46, 91, 101, 108, 105, 102, 93, 46, 46,
  91, 101, 108, 115, 101, 93, 46, 46, 101, 110, 100, 105, 102, 39, 32, 98,
  108, 111, 99, 107, 32, 97, 110, 100, 32, 116, 101, 115, 116, 32, 105, 102,
  32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 98, 111, 111, 108, 101,
  97, 110, 32, 105, 115, 32, 116, 114, 117, 101, 44, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 111, 114, 32, 105, 102, 32, 115, 112, 101, 99, 105,
  102, 105, 101, 100, 32, 102, 105, 108, 101, 110, 97, 109, 101, 32, 101, 120,
  105, 115, 116, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39,
  98, 111, 111, 108, 101, 97, 110, 39, 32, 99, 97, 110, 32, 98, 101, 32,
  97, 32, 102, 108, 111, 97, 116, 32, 110, 117, 109, 98, 101, 114, 32, 115,
  116, 97, 110, 100, 105, 110, 103, 32, 102, 111, 114, 32, 123, 32, 48, 61,
  102, 97, 108, 115, 101, 32, 124, 32, 111, 116, 104, 101, 114, 61, 116, 114,
  117, 101, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 105, 102, 32, 123,
  105, 97, 60, 54, 52, 125, 32, 45, 97, 100, 100, 32, 53, 48, 37, 32,
  45, 101, 108, 105, 102, 32, 123, 105, 97, 60, 49, 50, 56, 125, 32, 45,
  97, 100, 100, 32, 50, 53, 37, 32, 45, 101, 108, 105, 102, 32, 123, 105,
  97, 60, 49, 57, 50, 125, 32, 45, 115, 117, 98, 32, 50, 53, 37, 32,
  45, 101, 108, 115, 101, 32, 45, 115, 117, 98, 32, 53, 48, 37, 32, 45,
  101, 110, 100, 105, 102, 32, 45, 99, 117, 116, 32, 48, 44, 50, 53, 53,
  10, 35, 64, 103, 109, 105, 99, 32, 108, 32, 58, 32, 101, 113, 46, 32,
  116, 111, 32, 39, 45, 108, 111, 99, 97, 108, 39, 46, 32, 58, 32, 40,
  42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 108, 111, 99, 97, 108, 32,
  58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83,
  116, 97, 114, 116, 32, 97, 32, 39, 108, 111, 99, 97, 108, 46, 46, 91,
  111, 110, 102, 97, 105, 108, 93, 46, 46, 101, 110, 100, 108, 111, 99, 97,
  108, 39, 32, 98, 108, 111, 99, 107, 44, 32, 119, 105, 116, 104, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101, 113, 46, 32, 116, 111,
  32, 39, 45, 108, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 108, 111,
  99, 97, 108, 91, 93, 32, 51, 48, 48, 44, 51, 48, 48, 44, 49, 44,
  51, 32, 45, 114, 97, 110, 100, 91, 48, 93, 32, 48, 44, 50, 53, 53,
  32, 45, 98, 108, 117, 114, 32, 52, 32, 45, 115, 104, 97, 114, 112, 101,
  110, 32, 49, 48, 48, 48, 32, 45, 101, 110, 100, 108, 111, 99, 97, 108,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 108, 111, 99, 97, 108, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 51, 32, 45, 100, 101, 102, 111, 114, 109, 32,
  50, 48, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 108, 111, 99,
  97, 108, 10, 35, 64, 103, 109, 105, 99, 32, 109, 117, 116, 101, 120, 32,
  58, 32, 105, 110, 100, 105, 99, 101, 44, 95, 97, 99, 116, 105, 111, 110,
  61, 123, 32, 48, 61, 117, 110, 108, 111, 99, 107, 32, 124, 32, 49, 61,
  108, 111, 99, 107, 32, 125, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 76, 111, 99, 107, 32, 111, 114, 32, 117, 110,
  108, 111, 99, 107, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 109,
  117, 116, 101, 120, 32, 102, 111, 114, 32, 109, 117, 108, 116, 105, 45, 116,
  104, 114, 101, 97, 100, 101, 100, 32, 112, 114, 111, 103, 114, 97, 109, 109,
  105, 110, 103, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 32,
  108, 111, 99, 107, 101, 100, 32, 109, 117, 116, 101, 120, 32, 99, 97, 110,
  32, 98, 101, 32, 117, 110, 108, 111, 99, 107, 101, 100, 32, 111, 110, 108,
  121, 32, 98, 121, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 116, 104,
  114, 101, 97, 100, 46, 32, 65, 108, 108, 32, 109, 117, 116, 101, 120, 101,
  115, 32, 97, 114, 101, 32, 117, 110, 108, 111, 99, 107, 101, 100, 32, 98,
  121, 32, 100, 101, 102, 97, 117, 108, 116, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 39, 105, 110, 100, 105, 99, 101, 39, 32, 100, 101, 115,
  105, 103, 110, 97, 116, 101, 115, 32, 116, 104, 101, 32, 109, 117, 116, 101,
  120, 32, 105, 110, 100, 105, 99, 101, 44, 32, 105, 110, 32, 91, 48, 44,
  50, 53, 53, 93, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 97,
  99, 116, 105, 111, 110, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 111, 110, 102, 97, 105, 108, 32, 58, 32, 40, 42, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 69, 120, 101, 99, 117, 116, 101, 32, 102,
  111, 108, 108, 111, 119, 105, 110, 103, 32, 99, 111, 109, 109, 97, 110, 100,
  115, 32, 119, 104, 101, 110, 32, 97, 110, 32, 101, 114, 114, 111, 114, 32,
  105, 115, 32, 101, 110, 99, 111, 117, 110, 116, 101, 114, 101, 100, 32, 105,
  110, 32, 116, 104, 101, 32, 98, 111, 100, 121, 32, 111, 102, 32, 116, 104,
  101, 32, 39, 108, 111, 99, 97, 108, 46, 46, 101, 110, 100, 108, 111, 99,
  97, 108, 39, 32, 98, 108, 111, 99, 107, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 84, 104, 101, 32, 115, 116, 97, 116, 117, 115, 32, 118,
  97, 108, 117, 101, 32, 105, 115, 32, 115, 101, 116, 32, 119, 105, 116, 104,
  32, 116, 104, 101, 32, 99, 111, 114, 114, 101, 115, 112, 111, 110, 100, 105,
  110, 103, 32, 101, 114, 114, 111, 114, 32, 109, 101, 115, 115, 97, 103, 101,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 45, 108, 111, 99, 97, 108, 32, 45,
  98, 108, 117, 114, 32, 45, 51, 32, 45, 111, 110, 102, 97, 105, 108, 32,
  45, 109, 105, 114, 114, 111, 114, 32, 120, 32, 45, 101, 110, 100, 108, 111,
  99, 97, 108, 10, 35, 64, 103, 109, 105, 99, 32, 112, 97, 114, 97, 108,
  108, 101, 108, 32, 58, 32, 95, 119, 97, 105, 116, 95, 116, 104, 114, 101,
  97, 100, 115, 44, 34, 99, 111, 109, 109, 97, 110, 100, 49, 34, 44, 34,
  99, 111, 109, 109, 97, 110, 100, 50, 34, 44, 46, 46, 46, 32, 58, 32,
  40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 69, 120, 101,
  99, 117, 116, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 99,
  111, 109, 109, 97, 110, 100, 115, 32, 105, 110, 32, 112, 97, 114, 97, 108,
  108, 101, 108, 44, 32, 101, 97, 99, 104, 32, 105, 110, 32, 97, 32, 100,
  105, 102, 102, 101, 114, 101, 110, 116, 32, 116, 104, 114, 101, 97, 100, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 108, 108, 32, 114, 117,
  110, 110, 105, 110, 103, 32, 116, 104, 114, 101, 97, 100, 115, 32, 115, 104,
  97, 114, 101, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32,
  108, 105, 115, 116, 32, 111, 102, 32, 105, 109, 97, 103, 101, 115, 32, 97,
  110, 100, 32, 116, 104, 101, 32, 103, 108, 111, 98, 97, 108, 32, 118, 97,
  114, 105, 97, 98, 108, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 39, 119, 97, 105, 116, 95, 116, 104, 114, 101, 97, 100, 115, 39,
  32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 110, 101, 118, 101,
  114, 32, 124, 32, 49, 61, 97, 116, 32, 114, 101, 116, 117, 114, 110, 32,
  112, 111, 105, 110, 116, 32, 124, 32, 50, 61, 105, 109, 109, 101, 100, 105,
  97, 116, 101, 108, 121, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58,
  32, 39, 119, 97, 105, 116, 95, 116, 104, 114, 101, 97, 100, 115, 61, 50,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 91, 48, 93, 32, 45, 112, 97, 114,
  97, 108, 108, 101, 108, 32, 34, 45, 98, 108, 117, 114, 91, 48, 93, 32,
  51, 34, 44, 34, 45, 109, 105, 114, 114, 111, 114, 91, 49, 93, 32, 99,
  34, 10, 112, 97, 114, 97, 108, 108, 101, 108, 32, 58, 10, 45, 105, 102,
  32, 123, 36, 49, 61, 61, 48, 124, 124, 36, 49, 61, 61, 49, 124, 124,
  36, 49, 61, 61, 50, 125, 32, 45, 101, 91, 48, 45, 45, 51, 93, 32,
  34, 69, 120, 101, 99, 117, 116, 101, 32, 34, 123, 36, 35, 45, 49, 125,
  34, 32, 99, 111, 109, 109, 97, 110, 100, 115, 32, 39, 36, 123, 50, 45,
  45, 49, 125, 39, 32, 105, 110, 32, 112, 97, 114, 97, 108, 108, 101, 108,
  32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 101,
  108, 115, 101, 32, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 69, 120,
  101, 99, 117, 116, 101, 32, 34, 36, 35, 34, 32, 99, 111, 109, 109, 97,
  110, 100, 115, 32, 39, 36, 42, 39, 32, 105, 110, 32, 112, 97, 114, 97,
  108, 108, 101, 108, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46,
  34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 32, 45, 112,
  97, 114, 97, 108, 108, 101, 108, 32, 36, 34, 42, 34, 32, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 112, 114, 111, 103, 114, 101, 115,
  115, 32, 58, 32, 48, 60, 61, 118, 97, 108, 117, 101, 60, 61, 49, 48,
  48, 32, 58, 32, 45, 49, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 83, 101, 116, 32, 116, 104, 101, 32, 112, 114,
  111, 103, 114, 101, 115, 115, 32, 105, 110, 100, 105, 99, 101, 32, 111, 102,
  32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 112, 114, 111,
  99, 101, 115, 115, 105, 110, 103, 32, 112, 105, 112, 101, 108, 105, 110, 101,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 84, 104, 105, 115, 32,
  99, 111, 109, 109, 97, 110, 100, 32, 105, 115, 32, 117, 115, 101, 102, 117,
  108, 32, 111, 110, 108, 121, 32, 119, 104, 101, 110, 32, 71, 39, 77, 73,
  67, 32, 105, 115, 32, 117, 115, 101, 100, 32, 98, 121, 32, 97, 110, 32,
  101, 109, 98, 101, 100, 100, 105, 110, 103, 32, 97, 112, 112, 108, 105, 99,
  97, 116, 105, 111, 110, 46, 10, 35, 64, 103, 109, 105, 99, 32, 113, 32,
  58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45, 113, 117, 105, 116, 39,
  46, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 113,
  117, 105, 116, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 81, 117, 105, 116, 32, 105, 110, 116, 101, 114, 112, 114, 101,
  116, 101, 114, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 101,
  113, 46, 32, 116, 111, 32, 39, 45, 113, 39, 41, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 114, 101, 112, 101, 97, 116, 32, 58, 32, 110, 98, 95,
  105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 58, 32, 40, 42, 41,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 116, 97, 114, 116, 32,
  105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 111, 102, 32, 97, 32,
  39, 114, 101, 112, 101, 97, 116, 46, 46, 100, 111, 110, 101, 39, 32, 98,
  108, 111, 99, 107, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 115, 112, 108, 105,
  116, 32, 121, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  115, 104, 105, 102, 116, 91, 36, 62, 93, 32, 36, 60, 44, 48, 44, 48,
  44, 48, 44, 50, 32, 45, 100, 111, 110, 101, 32, 45, 97, 112, 112, 101,
  110, 100, 32, 121, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 109, 111, 100, 101, 51,
  100, 32, 50, 32, 45, 114, 101, 112, 101, 97, 116, 32, 52, 32, 45, 105,
  109, 97, 103, 101, 99, 117, 98, 101, 51, 100, 32, 45, 114, 111, 116, 97,
  116, 101, 51, 100, 32, 49, 44, 49, 44, 48, 44, 52, 48, 32, 45, 115,
  110, 97, 112, 115, 104, 111, 116, 51, 100, 32, 52, 48, 48, 44, 49, 46,
  52, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 109, 105, 99, 32, 114,
  101, 116, 117, 114, 110, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 82, 101, 116, 117, 114, 110, 32, 102, 114, 111, 109,
  32, 99, 117, 114, 114, 101, 110, 116, 32, 99, 117, 115, 116, 111, 109, 32,
  99, 111, 109, 109, 97, 110, 100, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  114, 112, 114, 111, 103, 114, 101, 115, 115, 32, 58, 32, 48, 60, 61, 118,
  97, 108, 117, 101, 60, 61, 49, 48, 48, 32, 124, 32, 45, 49, 32, 124,
  32, 34, 99, 111, 109, 109, 97, 110, 100, 34, 44, 48, 60, 61, 118, 97,
  108, 117, 101, 95, 109, 105, 110, 60, 61, 49, 48, 48, 44, 48, 60, 61,
  118, 97, 108, 117, 101, 95, 109, 97, 120, 60, 61, 49, 48, 48, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 83, 101, 116, 32, 116, 104, 101, 32,
  112, 114, 111, 103, 114, 101, 115, 115, 32, 105, 110, 100, 105, 99, 101, 32,
  111, 102, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 112,
  114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 112, 105, 112, 101, 108, 105,
  110, 101, 32, 40, 114, 101, 108, 97, 116, 105, 118, 101, 108, 121, 32, 116,
  111, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 112, 114, 101, 118, 105,
  111, 117, 115, 108, 121, 32, 100, 101, 102, 105, 110, 101, 100, 32, 112, 114,
  111, 103, 114, 101, 115, 115, 32, 98, 111, 117, 110, 100, 115, 41, 44, 32,
  111, 114, 32, 99, 97, 108, 108, 32, 116, 104, 101, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 99, 111, 109, 109, 97, 110, 100, 32, 119, 105,
  116, 104, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 112, 114, 111, 103, 114, 101, 115, 115, 32, 98,
  111, 117, 110, 100, 115, 46, 10, 114, 112, 114, 111, 103, 114, 101, 115, 115,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 34, 34, 125,
  10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 123, 33, 110, 97, 114, 103,
  40, 36, 95, 112, 114, 111, 103, 114, 101, 115, 115, 95, 98, 111, 117, 110,
  100, 115, 41, 125, 32, 95, 112, 114, 111, 103, 114, 101, 115, 115, 95, 98,
  111, 117, 110, 100, 115, 61, 48, 44, 49, 48, 48, 32, 45, 101, 110, 100,
  105, 102, 10, 109, 61, 123, 97, 114, 103, 40, 45, 50, 44, 36, 95, 112,
  114, 111, 103, 114, 101, 115, 115, 95, 98, 111, 117, 110, 100, 115, 41, 125,
  32, 77, 61, 123, 97, 114, 103, 40, 45, 49, 44, 36, 95, 112, 114, 111,
  103, 114, 101, 115, 115, 95, 98, 111, 117, 110, 100, 115, 41, 125, 10, 45,
  105, 102, 32, 123, 36, 35, 61, 61, 50, 38, 38, 33, 110, 97, 114, 103,
  40, 36, 50, 41, 125, 10, 45, 118, 32, 43, 32, 45, 101, 91, 48, 45,
  45, 51, 93, 32, 34, 83, 101, 116, 32, 114, 101, 108, 97, 116, 105, 118,
  101, 32, 112, 114, 111, 103, 114, 101, 115, 115, 32, 105, 110, 100, 105, 99,
  101, 32, 116, 111, 32, 36, 49, 37, 46, 34, 32, 45, 118, 32, 45, 10,
  45, 112, 114, 111, 103, 114, 101, 115, 115, 32, 123, 105, 102, 40, 36, 49,
  60, 48, 44, 45, 49, 44, 109, 105, 110, 40, 49, 48, 48, 44, 109, 97,
  120, 40, 48, 44, 36, 109, 43, 40, 36, 77, 45, 36, 109, 41, 42, 36,
  49, 37, 41, 41, 41, 125, 10, 45, 101, 108, 105, 102, 32, 123, 36, 35,
  61, 61, 51, 125, 10, 110, 109, 61, 123, 109, 105, 110, 40, 36, 50, 44,
  36, 45, 49, 41, 125, 32, 110, 77, 61, 123, 109, 97, 120, 40, 36, 50,
  44, 36, 45, 49, 41, 125, 10, 45, 118, 32, 43, 32, 45, 101, 91, 48,
  45, 45, 51, 93, 32, 34, 67, 97, 108, 108, 32, 99, 111, 109, 109, 97,
  110, 100, 32, 39, 36, 49, 39, 32, 119, 105, 116, 104, 32, 112, 114, 111,
  103, 114, 101, 115, 115, 32, 98, 111, 117, 110, 100, 115, 32, 91, 34, 36,
  110, 109, 44, 36, 110, 77, 34, 93, 46, 34, 32, 45, 118, 32, 45, 10,
  45, 112, 114, 111, 103, 114, 101, 115, 115, 32, 36, 109, 32, 95, 112, 114,
  111, 103, 114, 101, 115, 115, 95, 98, 111, 117, 110, 100, 115, 61, 36, 95,
  112, 114, 111, 103, 114, 101, 115, 115, 95, 98, 111, 117, 110, 100, 115, 44,
  123, 36, 109, 43, 36, 110, 109, 42, 40, 36, 77, 45, 36, 109, 41, 47,
  49, 48, 48, 125, 44, 123, 36, 109, 43, 36, 110, 77, 42, 40, 36, 77,
  45, 36, 109, 41, 47, 49, 48, 48, 125, 10, 45, 95, 114, 112, 114, 111,
  103, 114, 101, 115, 115, 32, 34, 36, 49, 34, 10, 45, 112, 114, 111, 103,
  114, 101, 115, 115, 32, 36, 77, 32, 40, 36, 95, 112, 114, 111, 103, 114,
  101, 115, 115, 95, 98, 111, 117, 110, 100, 115, 41, 32, 95, 112, 114, 111,
  103, 114, 101, 115, 115, 95, 98, 111, 117, 110, 100, 115, 61, 64, 123, 45,
  49, 44, 48, 45, 45, 51, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 101, 108, 115, 101, 32, 45, 101, 114, 114, 111, 114, 91, 48, 45, 45,
  51, 93, 32, 34, 67, 111, 109, 109, 97, 110, 100, 32, 39, 45, 114, 112,
  114, 111, 103, 114, 101, 115, 115, 39, 32, 58, 32, 73, 110, 118, 97, 108,
  105, 100, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 39, 36, 42, 39,
  46, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 95,
  114, 112, 114, 111, 103, 114, 101, 115, 115, 32, 58, 32, 36, 42, 10, 35,
  64, 103, 109, 105, 99, 32, 115, 107, 105, 112, 32, 58, 32, 105, 116, 101,
  109, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 111, 32, 110, 111, 116, 104, 105, 110, 103, 32, 98, 117, 116, 32,
  115, 107, 105, 112, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 105,
  116, 101, 109, 46, 10, 35, 64, 103, 109, 105, 99, 32, 117, 32, 58, 32,
  101, 113, 46, 32, 116, 111, 32, 39, 45, 115, 116, 97, 116, 117, 115, 39,
  46, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 115,
  116, 97, 116, 117, 115, 32, 58, 32, 118, 97, 108, 117, 101, 32, 58, 32,
  40, 42, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 101, 116,
  32, 99, 117, 114, 114, 101, 110, 116, 32, 115, 116, 97, 116, 117, 115, 32,
  118, 97, 108, 117, 101, 46, 32, 85, 115, 101, 100, 32, 116, 111, 32, 100,
  101, 102, 105, 110, 101, 32, 97, 32, 114, 101, 116, 117, 114, 110, 105, 110,
  103, 32, 118, 97, 108, 117, 101, 32, 105, 110, 32, 97, 32, 102, 117, 110,
  99, 116, 105, 111, 110, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 117, 39, 41, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 99, 111, 109, 109, 97, 110, 100, 32, 34, 102, 111,
  111, 32, 58, 32, 117, 48, 61, 68, 97, 114, 107, 32, 117, 49, 61, 66,
  114, 105, 103, 104, 116, 32, 45, 115, 116, 97, 116, 117, 115, 32, 36, 123,
  117, 123, 105, 97, 62, 61, 49, 50, 56, 125, 125, 34, 32, 45, 116, 101,
  120, 116, 95, 111, 117, 116, 108, 105, 110, 101, 32, 64, 123, 45, 102, 111,
  111, 125, 44, 50, 44, 50, 44, 50, 52, 44, 50, 44, 49, 44, 50, 53,
  53, 10, 35, 64, 103, 109, 105, 99, 32, 119, 104, 105, 108, 101, 32, 58,
  32, 98, 111, 111, 108, 101, 97, 110, 32, 58, 32, 102, 105, 108, 101, 110,
  97, 109, 101, 32, 58, 32, 40, 42, 41, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 69, 110, 100, 32, 97, 32, 39, 100, 111, 46, 46, 119, 104,
  105, 108, 101, 39, 32, 98, 108, 111, 99, 107, 32, 97, 110, 100, 32, 103,
  111, 32, 98, 97, 99, 107, 32, 116, 111, 32, 97, 115, 115, 111, 99, 105,
  97, 116, 101, 100, 32, 39, 45, 100, 111, 39, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 105, 102, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100,
  32, 98, 111, 111, 108, 101, 97, 110, 32, 105, 115, 32, 116, 114, 117, 101,
  32, 111, 114, 32, 105, 102, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100,
  32, 102, 105, 108, 101, 110, 97, 109, 101, 32, 101, 120, 105, 115, 116, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 98, 111, 111, 108,
  101, 97, 110, 39, 32, 99, 97, 110, 32, 98, 101, 32, 97, 32, 102, 108,
  111, 97, 116, 32, 110, 117, 109, 98, 101, 114, 32, 115, 116, 97, 110, 100,
  105, 110, 103, 32, 102, 111, 114, 32, 123, 32, 48, 61, 102, 97, 108, 115,
  101, 32, 124, 32, 111, 116, 104, 101, 114, 61, 116, 114, 117, 101, 32, 125,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 58, 32, 65, 114, 114, 97,
  121, 115, 44, 32, 116, 105, 108, 101, 115, 32, 97, 110, 100, 32, 102, 114,
  97, 109, 101, 115, 10, 35, 64, 103, 109, 105, 99, 32, 97, 114, 114, 97,
  121, 32, 58, 32, 77, 62, 48, 44, 95, 78, 62, 48, 44, 95, 101, 120,
  112, 97, 110, 100, 95, 116, 121, 112, 101, 61, 123, 32, 48, 61, 109, 105,
  110, 32, 124, 32, 49, 61, 109, 97, 120, 32, 124, 32, 50, 61, 97, 108,
  108, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 114, 101,
  97, 116, 101, 32, 77, 120, 78, 32, 97, 114, 114, 97, 121, 32, 102, 114,
  111, 109, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 78, 61,
  77, 39, 32, 97, 110, 100, 32, 39, 101, 120, 112, 97, 110, 100, 95, 116,
  121, 112, 101, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 97, 114,
  114, 97, 121, 32, 51, 44, 50, 44, 50, 10, 97, 114, 114, 97, 121, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110, 116, 40,
  36, 49, 41, 32, 38, 38, 32, 36, 49, 62, 48, 32, 38, 38, 32, 105,
  115, 105, 110, 116, 40, 36, 123, 50, 61, 36, 49, 125, 41, 32, 38, 38,
  32, 36, 50, 62, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51,
  61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 114, 101,
  97, 116, 101, 32, 36, 49, 120, 36, 50, 32, 97, 114, 114, 97, 121, 32,
  102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105,
  116, 104, 32, 101, 120, 112, 97, 110, 100, 32, 116, 121, 112, 101, 32, 36,
  51, 46, 34, 10, 45, 118, 32, 45, 32, 114, 48, 61, 123, 49, 48, 48,
  47, 109, 97, 120, 40, 36, 49, 44, 36, 50, 41, 125, 32, 114, 49, 61,
  123, 49, 48, 48, 47, 109, 105, 110, 40, 36, 49, 44, 36, 50, 41, 125,
  32, 114, 50, 61, 49, 48, 48, 10, 45, 114, 32, 36, 123, 114, 36, 51,
  125, 37, 44, 36, 123, 114, 36, 51, 125, 37, 44, 49, 44, 49, 48, 48,
  37, 44, 50, 32, 45, 114, 32, 123, 36, 49, 42, 49, 48, 48, 125, 37,
  44, 123, 36, 50, 42, 49, 48, 48, 125, 37, 44, 49, 44, 49, 48, 48,
  37, 44, 48, 44, 50, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 97, 114, 114, 97, 121, 95, 102, 97, 100, 101, 32, 58, 32, 77,
  62, 48, 44, 95, 78, 62, 48, 44, 48, 60, 61, 95, 102, 97, 100, 101,
  95, 115, 116, 97, 114, 116, 60, 61, 49, 48, 48, 44, 48, 60, 61, 95,
  102, 97, 100, 101, 95, 101, 110, 100, 60, 61, 49, 48, 48, 44, 95, 101,
  120, 112, 97, 110, 100, 95, 116, 121, 112, 101, 61, 123, 48, 61, 109, 105,
  110, 32, 124, 32, 49, 61, 109, 97, 120, 32, 124, 32, 50, 61, 97, 108,
  108, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 114, 101, 97,
  116, 101, 32, 77, 120, 78, 32, 97, 114, 114, 97, 121, 32, 102, 114, 111,
  109, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 78, 61, 77,
  39, 44, 32, 39, 102, 97, 100, 101, 95, 115, 116, 97, 114, 116, 61, 54,
  48, 39, 44, 32, 39, 102, 97, 100, 101, 95, 101, 110, 100, 61, 57, 48,
  39, 32, 97, 110, 100, 32, 39, 101, 120, 112, 97, 110, 100, 95, 116, 121,
  112, 101, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 97, 114, 114,
  97, 121, 95, 102, 97, 100, 101, 32, 51, 44, 50, 10, 97, 114, 114, 97,
  121, 95, 102, 97, 100, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 50, 61, 36, 49, 125, 44, 36, 123, 51, 61, 54, 48, 125, 44, 36,
  123, 52, 61, 57, 48, 125, 44, 36, 123, 53, 61, 49, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 114, 101, 97, 116, 101, 32, 36, 49,
  120, 36, 50, 32, 97, 114, 114, 97, 121, 32, 111, 102, 32, 40, 36, 51,
  37, 44, 36, 52, 37, 41, 32, 102, 97, 100, 101, 100, 32, 116, 105, 108,
  101, 115, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 119, 105, 116, 104, 32, 101, 120, 112, 97, 110, 100, 32, 116, 121, 112,
  101, 32, 36, 53, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 91, 45,
  49, 93, 32, 45, 115, 104, 105, 102, 116, 91, 45, 50, 93, 32, 53, 48,
  37, 44, 53, 48, 37, 44, 49, 44, 49, 44, 50, 32, 45, 102, 97, 100,
  101, 95, 100, 105, 97, 109, 111, 110, 100, 32, 36, 51, 44, 36, 52, 32,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 97, 114, 114,
  97, 121, 32, 36, 49, 44, 36, 50, 44, 36, 53, 10, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 97, 114, 114, 97, 121, 95, 109, 105,
  114, 114, 111, 114, 32, 58, 32, 78, 62, 61, 48, 44, 95, 100, 105, 114,
  61, 123, 32, 48, 61, 120, 32, 124, 32, 49, 61, 121, 32, 124, 32, 50,
  61, 120, 121, 32, 124, 32, 51, 61, 116, 114, 105, 45, 120, 121, 32, 125,
  44, 95, 101, 120, 112, 97, 110, 100, 95, 116, 121, 112, 101, 61, 123, 32,
  48, 32, 124, 32, 49, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 67, 114, 101, 97, 116, 101, 32, 50, 94, 78, 120, 50, 94, 78, 32,
  97, 114, 114, 97, 121, 32, 102, 114, 111, 109, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108,
  117, 101, 115, 58, 32, 39, 100, 105, 114, 61, 50, 39, 32, 97, 110, 100,
  32, 39, 101, 120, 112, 97, 110, 100, 95, 116, 121, 112, 101, 61, 48, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 97, 114, 114, 97, 121, 95, 109, 105,
  114, 114, 111, 114, 32, 50, 10, 97, 114, 114, 97, 121, 95, 109, 105, 114,
  114, 111, 114, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61,
  50, 125, 44, 36, 123, 51, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 114, 101, 97, 116, 101, 32, 97, 32, 50, 94, 36, 49,
  120, 50, 94, 36, 49, 32, 109, 105, 114, 114, 111, 114, 101, 100, 45, 97,
  114, 114, 97, 121, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 119, 105, 116, 104, 32, 101, 120, 112, 97, 110, 100, 32, 116,
  121, 112, 101, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 49, 10, 45, 105, 102, 32, 123, 36, 51,
  61, 61, 48, 125, 10, 45, 105, 102, 32, 123, 36, 50, 62, 61, 51, 125,
  32, 45, 114, 32, 51, 51, 37, 44, 51, 51, 37, 44, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 50, 10, 45, 101, 108, 115, 101, 32, 45, 114,
  32, 53, 48, 37, 44, 53, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 50, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 36, 50, 61, 61, 48, 125,
  32, 45, 45, 109, 105, 114, 114, 111, 114, 32, 120, 32, 45, 97, 32, 120,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 61, 61, 49, 125, 32, 45,
  45, 109, 105, 114, 114, 111, 114, 32, 121, 32, 45, 97, 32, 121, 10, 45,
  101, 108, 115, 101, 32, 45, 45, 109, 105, 114, 114, 111, 114, 32, 120, 32,
  45, 97, 32, 120, 32, 45, 45, 109, 105, 114, 114, 111, 114, 32, 121, 32,
  45, 97, 32, 121, 32, 45, 105, 102, 32, 123, 36, 50, 61, 61, 51, 125,
  32, 45, 114, 32, 49, 53, 48, 37, 44, 49, 53, 48, 37, 44, 49, 44,
  49, 48, 48, 37, 44, 48, 44, 50, 44, 49, 44, 49, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 97, 114, 114, 97, 121, 95, 114,
  97, 110, 100, 111, 109, 32, 58, 32, 77, 115, 62, 48, 44, 95, 78, 115,
  62, 48, 44, 95, 77, 100, 62, 48, 44, 95, 78, 100, 62, 48, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 67, 114, 101, 97, 116, 101, 32, 77,
  100, 120, 78, 100, 32, 97, 114, 114, 97, 121, 32, 111, 102, 32, 116, 105,
  108, 101, 115, 32, 102, 114, 111, 109, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 77, 115, 120, 78, 115, 32, 115, 111, 117, 114, 99, 101, 32, 97,
  114, 114, 97, 121, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 78, 115, 61, 77, 115, 39, 44, 32, 39, 77, 100, 61, 77, 115, 39,
  32, 97, 110, 100, 32, 39, 78, 100, 61, 78, 115, 39, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 45, 97, 114, 114, 97, 121, 95, 114, 97, 110, 100, 111,
  109, 32, 56, 44, 56, 44, 49, 53, 44, 49, 48, 10, 97, 114, 114, 97,
  121, 95, 114, 97, 110, 100, 111, 109, 32, 58, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 50, 61, 36, 49, 125, 44, 36, 123, 51, 61, 36, 49, 125,
  44, 36, 123, 52, 61, 36, 50, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 67, 114, 101, 97, 116, 101, 32, 36, 51, 120, 36, 52, 32, 97,
  114, 114, 97, 121, 32, 111, 102, 32, 116, 105, 108, 101, 115, 32, 102, 114,
  111, 109, 32, 36, 49, 120, 36, 50, 32, 97, 114, 114, 97, 121, 36, 63,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48,
  44, 110, 125, 10, 45, 115, 112, 108, 105, 116, 95, 116, 105, 108, 101, 115,
  32, 36, 49, 44, 36, 50, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36,
  51, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 52, 32, 91, 123, 63,
  40, 36, 49, 42, 36, 50, 45, 49, 41, 125, 93, 32, 45, 100, 111, 110,
  101, 32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 48, 45, 123, 36,
  49, 42, 36, 50, 45, 49, 125, 93, 32, 45, 97, 112, 112, 101, 110, 100,
  95, 116, 105, 108, 101, 115, 32, 36, 51, 44, 36, 52, 10, 45, 110, 109,
  32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 102,
  114, 97, 109, 101, 32, 58, 32, 101, 113, 46, 32, 116, 111, 32, 39, 45,
  102, 114, 97, 109, 101, 95, 120, 121, 39, 46, 10, 102, 114, 97, 109, 101,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48,
  32, 38, 38, 32, 36, 123, 50, 61, 36, 49, 125, 62, 61, 48, 34, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 50, 53, 53, 125, 44, 36,
  123, 52, 61, 36, 51, 125, 44, 36, 123, 53, 61, 36, 52, 125, 44, 36,
  123, 54, 61, 50, 53, 53, 125, 10, 45, 118, 32, 45, 32, 95, 95, 115,
  61, 34, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 102, 114, 97, 109,
  101, 95, 120, 121, 32, 36, 123, 49, 45, 45, 49, 125, 10, 35, 64, 103,
  109, 105, 99, 32, 102, 114, 97, 109, 101, 95, 98, 108, 117, 114, 32, 58,
  32, 95, 115, 104, 97, 114, 112, 110, 101, 115, 115, 62, 48, 44, 95, 115,
  105, 122, 101, 62, 61, 48, 44, 95, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 44, 95, 115, 104, 97, 100, 105, 110, 103, 44, 95, 98, 108, 117,
  114, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 114, 97, 119, 32,
  82, 71, 66, 65, 45, 99, 111, 108, 111, 114, 101, 100, 32, 114, 111, 117,
  110, 100, 32, 102, 114, 97, 109, 101, 32, 105, 110, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 115, 104, 97, 114, 112, 110, 101, 115, 115,
  61, 49, 48, 39, 44, 32, 39, 115, 105, 122, 101, 61, 51, 48, 39, 44,
  32, 39, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 48, 39, 44,
  32, 39, 115, 104, 97, 100, 105, 110, 103, 61, 49, 39, 32, 97, 110, 100,
  32, 39, 98, 108, 117, 114, 61, 51, 37, 39, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 102, 114, 97, 109, 101, 95, 98, 108, 117, 114, 32, 51, 44, 51,
  48, 44, 56, 44, 49, 48, 37, 10, 102, 114, 97, 109, 101, 95, 98, 108,
  117, 114, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49,
  48, 125, 44, 36, 123, 50, 61, 51, 48, 125, 44, 36, 123, 51, 61, 48,
  125, 44, 36, 123, 52, 61, 49, 125, 44, 36, 123, 53, 61, 51, 37, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 114, 97, 119, 32, 114,
  111, 117, 110, 100, 32, 102, 114, 97, 109, 101, 32, 111, 110, 32, 105, 109,
  97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 115, 104, 97, 114,
  112, 110, 101, 115, 115, 32, 36, 49, 44, 32, 115, 105, 122, 101, 32, 36,
  50, 44, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 51,
  44, 32, 115, 104, 97, 100, 105, 110, 103, 32, 36, 52, 32, 97, 110, 100,
  32, 98, 108, 117, 114, 32, 36, 53, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123,
  48, 44, 110, 125, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 49, 44, 34, 45, 40, 97, 98, 115, 40, 120, 47, 119, 45, 48, 46,
  53, 41, 94, 36, 49, 32, 43, 32, 97, 98, 115, 40, 121, 47, 104, 45,
  48, 46, 53, 41, 94, 36, 49, 41, 94, 40, 49, 47, 36, 49, 41, 34,
  32, 45, 103, 101, 91, 45, 49, 93, 32, 36, 50, 37, 10, 45, 105, 102,
  32, 36, 52, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49,
  93, 32, 49, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45,
  42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 43, 91, 45, 49, 93, 32,
  49, 32, 45, 94, 91, 45, 49, 93, 32, 123, 49, 47, 36, 52, 125, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 98, 91, 45, 49, 93, 32, 36, 51,
  32, 45, 45, 98, 91, 45, 50, 93, 32, 36, 53, 32, 45, 109, 118, 91,
  45, 49, 93, 32, 45, 51, 32, 45, 98, 108, 101, 110, 100, 95, 102, 97,
  100, 101, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 102, 114, 97, 109, 101, 95, 99, 117, 98, 101, 32,
  58, 32, 95, 100, 101, 112, 116, 104, 62, 61, 48, 44, 95, 120, 95, 99,
  101, 110, 116, 101, 114, 44, 95, 121, 95, 99, 101, 110, 116, 101, 114, 44,
  95, 108, 101, 102, 116, 95, 115, 105, 100, 101, 61, 123, 48, 61, 110, 111,
  114, 109, 97, 108, 32, 124, 32, 49, 61, 109, 105, 114, 114, 111, 114, 45,
  120, 32, 124, 32, 50, 61, 109, 105, 114, 114, 111, 114, 45, 121, 32, 124,
  32, 51, 61, 109, 105, 114, 114, 111, 114, 45, 120, 121, 125, 44, 95, 114,
  105, 103, 104, 116, 95, 115, 105, 100, 101, 44, 95, 108, 111, 119, 101, 114,
  95, 115, 105, 100, 101, 44, 95, 117, 112, 112, 101, 114, 95, 115, 105, 100,
  101, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 110, 115, 101, 114,
  116, 32, 51, 100, 32, 102, 114, 97, 109, 101, 115, 32, 105, 110, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116,
  32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 100, 101, 112, 116, 104, 61,
  49, 39, 44, 32, 39, 120, 95, 99, 101, 110, 116, 101, 114, 61, 121, 95,
  99, 101, 110, 116, 101, 114, 61, 48, 39, 32, 97, 110, 100, 32, 39, 108,
  101, 102, 116, 95, 115, 105, 100, 101, 61, 114, 105, 103, 104, 116, 95, 115,
  105, 100, 101, 44, 108, 111, 119, 101, 114, 95, 115, 105, 100, 101, 61, 117,
  112, 112, 101, 114, 95, 115, 105, 100, 101, 61, 48, 39, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 102, 114, 97, 109, 101, 95, 99, 117, 98, 101, 32, 44,
  10, 102, 114, 97, 109, 101, 95, 99, 117, 98, 101, 32, 58, 32, 45, 99,
  104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 49, 125, 62, 61, 48, 34,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 48, 125, 44, 36, 123,
  51, 61, 48, 125, 44, 36, 123, 52, 61, 48, 125, 44, 36, 123, 53, 61,
  48, 125, 44, 36, 123, 54, 61, 48, 125, 44, 36, 123, 55, 61, 48, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 115, 101, 114, 116,
  32, 51, 100, 32, 102, 114, 97, 109, 101, 32, 105, 110, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 100, 101, 112, 116, 104,
  32, 36, 49, 44, 32, 99, 101, 110, 116, 101, 114, 32, 40, 36, 50, 44,
  36, 51, 41, 32, 97, 110, 100, 32, 111, 114, 105, 101, 110, 116, 97, 116,
  105, 111, 110, 115, 32, 40, 36, 123, 52, 45, 45, 49, 125, 41, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110,
  125, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121,
  10, 45, 105, 102, 32, 123, 64, 35, 61, 61, 50, 125, 32, 45, 102, 114,
  97, 109, 101, 95, 99, 117, 98, 101, 32, 36, 123, 49, 45, 45, 49, 125,
  32, 45, 97, 32, 99, 10, 45, 101, 108, 115, 101, 10, 109, 61, 123, 109,
  97, 120, 40, 119, 44, 104, 41, 125, 32, 119, 61, 123, 119, 125, 32, 104,
  61, 123, 104, 125, 32, 115, 61, 123, 115, 125, 10, 45, 105, 109, 97, 103,
  101, 112, 108, 97, 110, 101, 51, 100, 32, 45, 99, 51, 100, 32, 45, 47,
  51, 100, 91, 45, 49, 93, 32, 36, 119, 44, 36, 104, 44, 49, 10, 45,
  45, 95, 102, 114, 97, 109, 101, 95, 99, 117, 98, 101, 91, 48, 93, 32,
  36, 52, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 49, 44,
  48, 44, 57, 48, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 45, 48,
  46, 53, 44, 48, 44, 45, 48, 46, 53, 10, 45, 45, 95, 102, 114, 97,
  109, 101, 95, 99, 117, 98, 101, 91, 48, 93, 32, 36, 53, 32, 45, 114,
  51, 100, 91, 45, 49, 93, 32, 48, 44, 49, 44, 48, 44, 45, 57, 48,
  32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 48, 46, 53, 44, 48, 44,
  45, 48, 46, 53, 10, 45, 45, 95, 102, 114, 97, 109, 101, 95, 99, 117,
  98, 101, 91, 48, 93, 32, 36, 54, 32, 45, 114, 51, 100, 91, 45, 49,
  93, 32, 49, 44, 48, 44, 48, 44, 57, 48, 32, 45, 43, 51, 100, 91,
  45, 49, 93, 32, 48, 44, 48, 46, 53, 44, 45, 48, 46, 53, 10, 45,
  45, 95, 102, 114, 97, 109, 101, 95, 99, 117, 98, 101, 91, 48, 93, 32,
  36, 55, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 49, 44, 48, 44,
  48, 44, 45, 57, 48, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 48,
  44, 45, 48, 46, 53, 44, 45, 48, 46, 53, 10, 45, 43, 51, 100, 32,
  48, 44, 48, 44, 49, 32, 45, 43, 51, 100, 32, 45, 42, 51, 100, 32,
  36, 119, 44, 36, 104, 44, 36, 109, 10, 102, 61, 49, 48, 48, 48, 10,
  99, 120, 61, 36, 50, 42, 36, 119, 47, 50, 42, 40, 36, 102, 43, 36,
  109, 42, 36, 49, 41, 47, 36, 102, 10, 99, 121, 61, 36, 51, 42, 36,
  104, 47, 50, 42, 40, 36, 102, 43, 36, 109, 42, 36, 49, 41, 47, 36,
  102, 10, 45, 115, 51, 100, 32, 45, 114, 91, 50, 93, 32, 51, 44, 123,
  64, 123, 50, 44, 104, 125, 47, 51, 125, 44, 49, 44, 49, 44, 45, 49,
  10, 45, 102, 91, 50, 93, 32, 34, 105, 102, 40, 105, 40, 50, 44, 121,
  41, 60, 48, 46, 53, 44, 105, 44, 105, 43, 105, 102, 40, 120, 61, 61,
  48, 44, 34, 36, 99, 120, 34, 44, 105, 102, 40, 120, 61, 61, 49, 44,
  34, 36, 99, 121, 34, 44, 40, 36, 49, 45, 49, 41, 42, 34, 36, 109,
  34, 41, 41, 41, 34, 10, 45, 121, 91, 50, 93, 32, 45, 97, 32, 121,
  10, 45, 42, 51, 100, 32, 50, 32, 123, 50, 42, 36, 119, 125, 44, 123,
  50, 42, 36, 104, 125, 44, 49, 44, 36, 115, 32, 45, 102, 51, 100, 32,
  123, 50, 42, 36, 102, 125, 10, 45, 111, 98, 106, 101, 99, 116, 51, 100,
  91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 53, 48, 37, 44, 53, 48,
  37, 44, 48, 44, 49, 44, 50, 44, 48, 44, 48, 32, 45, 114, 109, 91,
  45, 50, 93, 10, 45, 114, 32, 36, 119, 44, 36, 104, 44, 49, 44, 49,
  48, 48, 37, 44, 50, 10, 45, 101, 110, 100, 105, 102, 10, 45, 110, 109,
  32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 45, 118, 32, 43, 10, 95, 102, 114, 97, 109, 101, 95, 99,
  117, 98, 101, 32, 58, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 49,
  125, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 49, 44, 48,
  44, 49, 56, 48, 32, 45, 114, 118, 51, 100, 91, 45, 49, 93, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 50, 125, 32, 45, 114, 51,
  100, 91, 45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 49, 56, 48, 32,
  45, 114, 118, 51, 100, 91, 45, 49, 93, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 49, 61, 61, 51, 125, 32, 45, 114, 51, 100, 91, 45, 49, 93,
  32, 48, 44, 48, 44, 49, 44, 49, 56, 48, 10, 45, 101, 110, 100, 105,
  102, 10, 35, 64, 103, 109, 105, 99, 32, 102, 114, 97, 109, 101, 95, 102,
  117, 122, 122, 121, 32, 58, 32, 115, 105, 122, 101, 95, 120, 62, 61, 48,
  44, 95, 115, 105, 122, 101, 95, 121, 62, 61, 48, 44, 95, 102, 117, 122,
  122, 121, 110, 101, 115, 115, 62, 61, 48, 44, 95, 115, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 62, 61, 48, 44, 95, 82, 44, 95, 71, 44, 95,
  66, 44, 95, 65, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 114,
  97, 119, 32, 82, 71, 66, 65, 45, 99, 111, 108, 111, 114, 101, 100, 32,
  102, 117, 122, 122, 121, 32, 102, 114, 97, 109, 101, 32, 105, 110, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116,
  32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 115, 105, 122, 101, 95, 121,
  61, 115, 105, 122, 101, 95, 120, 39, 44, 32, 39, 102, 117, 122, 122, 121,
  110, 101, 115, 115, 61, 53, 39, 44, 32, 39, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 61, 49, 39, 32, 97, 110, 100, 32, 39, 82, 61, 71,
  61, 66, 61, 65, 61, 50, 53, 53, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 102, 114, 97, 109, 101, 95, 102, 117, 122, 122, 121, 32, 50, 48, 10,
  102, 114, 97, 109, 101, 95, 102, 117, 122, 122, 121, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 50, 61, 36, 49, 125, 44, 36, 123, 51, 61,
  53, 125, 44, 36, 123, 52, 61, 49, 125, 44, 36, 123, 53, 61, 50, 53,
  53, 125, 44, 36, 123, 54, 61, 36, 53, 125, 44, 36, 123, 55, 61, 36,
  54, 125, 44, 36, 123, 56, 61, 50, 53, 53, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 68, 114, 97, 119, 32, 36, 49, 120, 36, 50, 32,
  102, 117, 122, 122, 121, 32, 102, 114, 97, 109, 101, 32, 111, 110, 32, 105,
  109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 102, 117, 122,
  122, 121, 110, 101, 115, 115, 32, 36, 51, 44, 32, 115, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 36, 52, 32, 97, 110, 100, 32, 82, 71, 66,
  65, 32, 99, 111, 108, 111, 114, 32, 40, 36, 53, 44, 36, 54, 44, 36,
  55, 44, 36, 56, 41, 46, 34, 10, 45, 118, 32, 45, 32, 45, 116, 111,
  95, 114, 103, 98, 97, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110,
  125, 10, 45, 105, 91, 48, 93, 32, 40, 36, 49, 59, 36, 50, 41, 32,
  45, 42, 91, 48, 93, 32, 50, 32, 40, 36, 53, 94, 36, 54, 94, 36,
  55, 94, 36, 56, 41, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50,
  93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 10, 45, 114, 101, 99,
  116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 49,
  48, 48, 37, 44, 64, 123, 48, 44, 49, 125, 44, 49, 44, 49, 10, 45,
  114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48, 44,
  48, 44, 64, 123, 48, 44, 48, 125, 44, 49, 48, 48, 37, 44, 49, 44,
  49, 10, 45, 114, 109, 91, 48, 93, 32, 45, 115, 104, 105, 102, 116, 91,
  45, 49, 93, 32, 45, 36, 49, 44, 45, 36, 50, 44, 48, 44, 48, 44,
  50, 32, 45, 115, 112, 114, 101, 97, 100, 91, 45, 49, 93, 32, 36, 51,
  32, 45, 98, 91, 45, 49, 93, 32, 36, 52, 32, 45, 95, 102, 97, 100,
  101, 32, 53, 48, 44, 56, 48, 10, 45, 110, 109, 32, 36, 110, 109, 44,
  49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 102, 114, 97, 109, 101, 95,
  112, 97, 105, 110, 116, 105, 110, 103, 32, 58, 32, 95, 115, 105, 122, 101,
  91, 37, 93, 62, 61, 48, 44, 48, 60, 61, 95, 99, 111, 110, 116, 114,
  97, 115, 116, 60, 61, 49, 44, 95, 112, 114, 111, 102, 105, 108, 101, 95,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 91, 37, 93, 62, 61, 48,
  44, 95, 82, 44, 95, 71, 44, 95, 66, 44, 95, 118, 105, 103, 110, 101,
  116, 116, 101, 95, 115, 105, 122, 101, 91, 37, 93, 62, 61, 48, 44, 95,
  118, 105, 103, 110, 101, 116, 116, 101, 95, 99, 111, 110, 116, 114, 97, 115,
  116, 62, 61, 48, 44, 95, 100, 101, 102, 101, 99, 116, 115, 95, 99, 111,
  110, 116, 114, 97, 115, 116, 62, 61, 48, 44, 48, 60, 61, 95, 100, 101,
  102, 101, 99, 116, 115, 95, 100, 101, 110, 115, 105, 116, 121, 60, 61, 49,
  48, 48, 44, 95, 100, 101, 102, 101, 99, 116, 115, 95, 115, 105, 122, 101,
  62, 61, 48, 44, 95, 100, 101, 102, 101, 99, 116, 115, 95, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 91, 37, 93, 62, 61, 48, 44, 95, 115,
  101, 114, 105, 97, 108, 95, 110, 117, 109, 98, 101, 114, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 65, 100, 100, 32, 97, 32, 112, 97, 105, 110,
  116, 105, 110, 103, 32, 102, 114, 97, 109, 101, 32, 116, 111, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32,
  118, 97, 108, 117, 101, 115, 58, 32, 39, 115, 105, 122, 101, 61, 49, 48,
  37, 39, 44, 32, 39, 99, 111, 110, 116, 114, 97, 115, 116, 61, 48, 46,
  52, 39, 44, 32, 39, 112, 114, 111, 102, 105, 108, 101, 95, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 61, 54, 37, 39, 44, 32, 39, 82, 61,
  50, 50, 53, 39, 44, 32, 39, 71, 61, 50, 48, 48, 39, 44, 32, 39,
  66, 61, 49, 50, 48, 39, 44, 32, 39, 118, 105, 103, 110, 101, 116, 116,
  101, 95, 115, 105, 122, 101, 61, 50, 37, 39, 44, 32, 39, 118, 105, 103,
  110, 101, 116, 116, 101, 95, 99, 111, 110, 116, 114, 97, 115, 116, 61, 52,
  48, 48, 39, 44, 32, 39, 100, 101, 102, 101, 99, 116, 115, 95, 99, 111,
  110, 116, 114, 97, 115, 116, 61, 53, 48, 39, 44, 32, 39, 100, 101, 102,
  101, 99, 116, 115, 95, 100, 101, 110, 115, 105, 116, 121, 61, 49, 48, 39,
  44, 32, 39, 100, 101, 102, 101, 99, 116, 115, 95, 115, 105, 122, 101, 61,
  49, 39, 44, 32, 39, 100, 101, 102, 101, 99, 116, 115, 95, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 61, 48, 46, 53, 37, 39, 32, 97, 110,
  100, 32, 39, 115, 101, 114, 105, 97, 108, 95, 110, 117, 109, 98, 101, 114,
  61, 49, 50, 51, 52, 53, 54, 55, 56, 57, 39, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 102, 114, 97, 109, 101, 95, 112, 97, 105, 110, 116, 105, 110,
  103, 32, 44, 10, 102, 114, 97, 109, 101, 95, 112, 97, 105, 110, 116, 105,
  110, 103, 32, 58, 10, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49,
  61, 49, 48, 37, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61,
  48, 46, 52, 125, 62, 61, 48, 32, 38, 38, 32, 36, 50, 60, 61, 49,
  32, 38, 38, 32, 36, 123, 51, 61, 54, 37, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 123, 55, 61, 50, 37, 125, 62, 61, 48, 32, 38, 38, 32,
  36, 123, 56, 61, 52, 48, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36,
  123, 57, 61, 53, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 49,
  48, 61, 49, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 49, 48, 60,
  61, 49, 48, 48, 32, 38, 38, 32, 36, 123, 49, 49, 61, 49, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 123, 49, 50, 61, 48, 46, 53, 37, 125,
  62, 61, 48, 34, 10, 45, 115, 107, 105, 112, 32, 36, 123, 52, 61, 50,
  50, 53, 125, 44, 36, 123, 53, 61, 50, 48, 48, 125, 44, 36, 123, 54,
  61, 49, 50, 48, 125, 44, 36, 123, 49, 51, 61, 49, 50, 51, 52, 53,
  54, 55, 56, 57, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65,
  100, 100, 32, 112, 97, 105, 110, 116, 105, 110, 103, 32, 102, 114, 97, 109,
  101, 32, 116, 111, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105,
  116, 104, 32, 115, 105, 122, 101, 32, 36, 49, 44, 32, 99, 111, 110, 116,
  114, 97, 115, 116, 32, 36, 50, 44, 32, 112, 114, 111, 102, 105, 108, 101,
  32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 51, 44, 32,
  99, 111, 108, 111, 114, 32, 40, 36, 123, 52, 45, 54, 125, 41, 44, 32,
  118, 105, 103, 110, 101, 116, 116, 101, 32, 115, 105, 122, 101, 32, 36, 55,
  44, 32, 34, 92, 10, 34, 118, 105, 103, 110, 101, 116, 116, 101, 32, 115,
  116, 114, 101, 110, 103, 116, 104, 32, 36, 56, 44, 32, 100, 101, 102, 101,
  99, 116, 115, 32, 99, 111, 110, 116, 114, 97, 115, 116, 32, 36, 57, 44,
  32, 100, 101, 102, 101, 99, 116, 115, 32, 100, 101, 110, 115, 105, 116, 121,
  32, 36, 49, 48, 44, 32, 100, 101, 102, 101, 99, 116, 115, 32, 115, 105,
  122, 101, 32, 36, 49, 49, 44, 32, 100, 101, 102, 101, 99, 116, 115, 32,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 49, 50, 32, 97,
  110, 100, 32, 115, 101, 114, 105, 97, 108, 32, 110, 117, 109, 98, 101, 114,
  32, 36, 49, 51, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105,
  102, 32, 123, 33, 36, 49, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32,
  45, 101, 110, 100, 105, 102, 10, 36, 49, 44, 36, 49, 32, 115, 61, 123,
  109, 97, 120, 40, 119, 44, 104, 41, 125, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 40, 123, 39, 64, 123, 45, 100, 101, 99, 50, 98, 105, 110, 92,
  32, 36, 49, 51, 125, 39, 125, 41, 32, 45, 45, 91, 45, 49, 93, 32,
  123, 39, 48, 39, 125, 32, 45, 114, 91, 45, 49, 93, 32, 36, 115, 10,
  45, 116, 114, 97, 110, 115, 112, 111, 115, 101, 91, 45, 49, 93, 32, 45,
  98, 91, 45, 49, 93, 32, 36, 51, 32, 45, 110, 91, 45, 49, 93, 32,
  123, 49, 45, 36, 50, 125, 44, 123, 49, 43, 36, 50, 125, 10, 45, 45,
  114, 91, 45, 49, 93, 32, 123, 64, 123, 45, 50, 44, 119, 125, 43, 50,
  42, 36, 115, 125, 44, 49, 48, 48, 37, 44, 49, 44, 49, 10, 45, 45,
  109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 121, 10, 45, 109, 118,
  91, 45, 51, 93, 32, 64, 35, 32, 45, 116, 114, 97, 110, 115, 112, 111,
  115, 101, 91, 45, 49, 93, 32, 45, 114, 91, 45, 49, 93, 32, 49, 48,
  48, 37, 44, 123, 64, 123, 45, 52, 44, 104, 125, 43, 50, 42, 36, 115,
  125, 44, 49, 44, 49, 10, 45, 45, 109, 105, 114, 114, 111, 114, 91, 45,
  49, 93, 32, 120, 10, 91, 45, 51, 93, 44, 91, 45, 51, 93, 44, 49,
  44, 49, 44, 49, 32, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49,
  93, 32, 51, 44, 48, 44, 48, 44, 123, 36, 115, 45, 49, 125, 44, 123,
  36, 115, 45, 49, 125, 44, 48, 44, 123, 36, 115, 45, 49, 125, 44, 49,
  44, 48, 32, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32,
  51, 44, 49, 48, 48, 37, 44, 48, 44, 123, 119, 45, 36, 115, 125, 44,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 48, 10, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 49,
  44, 49, 32, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32,
  51, 44, 49, 44, 48, 44, 49, 48, 48, 37, 44, 123, 36, 115, 45, 50,
  125, 44, 49, 48, 48, 37, 44, 48, 32, 45, 112, 111, 108, 121, 103, 111,
  110, 91, 45, 49, 93, 32, 51, 44, 49, 44, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 123, 104, 45, 36, 115, 43, 49, 125, 44, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 49, 44, 48, 10, 45, 95, 102, 114, 97,
  109, 101, 95, 112, 97, 105, 110, 116, 105, 110, 103, 91, 45, 54, 45, 45,
  51, 93, 32, 36, 123, 52, 45, 54, 125, 44, 36, 123, 57, 45, 49, 50,
  125, 10, 123, 64, 123, 45, 55, 44, 119, 125, 43, 50, 42, 36, 115, 125,
  44, 123, 64, 123, 45, 55, 44, 104, 125, 43, 50, 42, 36, 115, 125, 44,
  49, 44, 51, 10, 45, 106, 91, 45, 49, 93, 32, 91, 45, 55, 93, 44,
  48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 51, 93, 44, 49,
  32, 45, 114, 109, 91, 45, 55, 93, 32, 45, 109, 105, 114, 114, 111, 114,
  91, 45, 51, 93, 32, 121, 10, 45, 106, 91, 45, 49, 93, 32, 91, 45,
  54, 93, 44, 48, 44, 123, 104, 45, 36, 115, 125, 44, 48, 44, 48, 44,
  49, 44, 91, 45, 51, 93, 44, 49, 32, 45, 114, 109, 91, 45, 54, 44,
  45, 51, 93, 10, 45, 106, 91, 45, 49, 93, 32, 91, 45, 52, 93, 44,
  48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 50, 93, 44, 49,
  32, 45, 114, 109, 91, 45, 52, 93, 32, 45, 109, 105, 114, 114, 111, 114,
  91, 45, 50, 93, 32, 120, 10, 45, 106, 91, 45, 49, 93, 32, 91, 45,
  51, 93, 44, 123, 119, 45, 36, 115, 125, 44, 48, 44, 48, 44, 48, 44,
  49, 44, 91, 45, 50, 93, 44, 49, 32, 45, 114, 109, 91, 45, 51, 44,
  45, 50, 93, 10, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 49, 44,
  49, 44, 45, 50, 53, 53, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 49, 44, 48, 44, 48, 44,
  48, 46, 53, 44, 48, 46, 53, 32, 45, 43, 91, 45, 49, 93, 32, 50,
  53, 53, 32, 45, 45, 98, 91, 45, 49, 93, 32, 36, 55, 32, 45, 110,
  91, 45, 49, 93, 32, 48, 44, 36, 56, 32, 45, 109, 97, 120, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 10, 45, 97, 91, 45, 50, 45, 45, 49, 93, 32, 99, 10, 45,
  114, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 91, 45, 49, 93, 44,
  49, 44, 49, 48, 48, 37, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48,
  46, 53, 32, 45, 98, 108, 101, 110, 100, 32, 97, 108, 112, 104, 97, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 95, 102, 114, 97, 109, 101, 95, 112, 97, 105, 110, 116, 105, 110, 103,
  32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 45, 42, 91, 45, 49, 93, 32, 36, 50, 32,
  45, 45, 42, 91, 45, 50, 93, 32, 36, 51, 32, 45, 42, 91, 45, 51,
  93, 32, 36, 49, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 99,
  10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 10, 105, 61, 48, 32, 45,
  100, 111, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44, 49,
  32, 45, 114, 101, 109, 111, 118, 101, 95, 112, 105, 120, 101, 108, 115, 91,
  45, 49, 93, 32, 123, 49, 48, 48, 45, 36, 53, 125, 32, 45, 98, 91,
  45, 49, 93, 32, 36, 54, 32, 45, 103, 101, 91, 45, 49, 93, 32, 53,
  48, 37, 32, 105, 61, 123, 36, 105, 43, 49, 125, 32, 45, 119, 104, 105,
  108, 101, 32, 123, 34, 109, 61, 36, 53, 47, 50, 48, 48, 59, 40, 105,
  97, 60, 109, 45, 48, 46, 50, 32, 124, 124, 32, 105, 97, 62, 109, 43,
  48, 46, 50, 41, 32, 38, 38, 32, 34, 36, 105, 34, 60, 49, 48, 34,
  125, 10, 45, 98, 91, 45, 49, 93, 32, 36, 55, 32, 45, 103, 91, 45,
  49, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 110, 91,
  45, 49, 93, 32, 45, 36, 52, 44, 36, 52, 10, 45, 43, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64,
  103, 109, 105, 99, 32, 102, 114, 97, 109, 101, 95, 112, 97, 116, 116, 101,
  114, 110, 32, 58, 32, 77, 62, 61, 51, 44, 95, 112, 97, 116, 116, 101,
  114, 110, 32, 61, 32, 123, 32, 48, 61, 102, 105, 114, 115, 116, 32, 105,
  109, 97, 103, 101, 32, 124, 32, 49, 61, 115, 101, 108, 102, 32, 125, 44,
  95, 99, 111, 110, 115, 116, 114, 97, 105, 110, 95, 115, 105, 122, 101, 32,
  61, 32, 123, 32, 48, 32, 124, 32, 49, 32, 125, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 73, 110, 115, 101, 114, 116, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 112, 97, 116, 116, 101, 114, 110, 32, 102, 114, 97,
  109, 101, 32, 105, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 112, 97, 116, 116, 101, 114, 110, 61, 48, 39, 32, 97, 110, 100, 32,
  39, 99, 111, 110, 115, 116, 114, 97, 105, 110, 95, 115, 105, 122, 101, 61,
  48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 102, 114, 97, 109, 101, 95,
  112, 97, 116, 116, 101, 114, 110, 32, 56, 10, 102, 114, 97, 109, 101, 95,
  112, 97, 116, 116, 101, 114, 110, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 36, 49, 62, 61, 51, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50,
  61, 48, 125, 44, 36, 123, 51, 61, 48, 125, 10, 45, 118, 32, 45, 32,
  45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48, 10,
  45, 105, 102, 32, 123, 64, 35, 61, 61, 49, 124, 124, 36, 50, 125, 10,
  45, 118, 32, 43, 32, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110,
  115, 101, 114, 116, 32, 36, 49, 120, 36, 49, 32, 115, 101, 108, 102, 45,
  112, 97, 116, 116, 101, 114, 110, 32, 102, 114, 97, 109, 101, 32, 111, 110,
  32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 32, 45, 118, 32, 45, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 119, 104, 61, 123, 119, 125, 44, 123, 104, 125, 10, 45, 45, 114,
  32, 123, 119, 47, 40, 36, 49, 45, 50, 41, 125, 44, 123, 104, 47, 40,
  36, 49, 45, 50, 41, 125, 44, 49, 44, 49, 48, 48, 37, 44, 50, 32,
  45, 114, 91, 45, 50, 93, 32, 123, 36, 49, 42, 119, 125, 44, 123, 36,
  49, 42, 104, 125, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44, 48, 44,
  48, 46, 53, 44, 48, 46, 53, 10, 91, 45, 49, 93, 120, 123, 36, 49,
  43, 50, 125, 32, 45, 97, 91, 123, 45, 36, 49, 45, 50, 125, 45, 45,
  49, 93, 32, 120, 32, 45, 106, 91, 45, 51, 93, 32, 91, 45, 49, 93,
  44, 48, 44, 48, 32, 45, 106, 91, 45, 51, 93, 32, 91, 45, 49, 93,
  44, 48, 44, 123, 64, 123, 45, 51, 44, 104, 125, 45, 49, 45, 104, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 91, 45, 49, 93, 120, 123, 36,
  49, 43, 49, 125, 32, 45, 97, 91, 123, 45, 36, 49, 45, 50, 125, 45,
  45, 49, 93, 32, 121, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 48, 44, 48, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 123, 64, 123, 45, 50, 44, 119, 125, 45, 49, 45, 119, 125, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 105, 102, 32, 36, 51, 32, 45,
  114, 32, 36, 119, 104, 44, 49, 44, 49, 48, 48, 37, 44, 50, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 45, 101, 108, 115, 101, 10, 45, 118, 32, 43, 32, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 73, 110, 115, 101, 114, 116, 32, 36, 49, 120,
  36, 49, 32, 112, 97, 116, 116, 101, 114, 110, 32, 102, 114, 97, 109, 101,
  32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 117, 115, 105,
  110, 103, 32, 102, 105, 114, 115, 116, 32, 105, 109, 97, 103, 101, 46, 34,
  32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64,
  35, 45, 49, 125, 10, 119, 104, 61, 123, 119, 125, 44, 123, 104, 125, 10,
  45, 45, 114, 91, 48, 93, 32, 123, 119, 47, 40, 36, 49, 45, 50, 41,
  125, 44, 123, 104, 47, 40, 36, 49, 45, 50, 41, 125, 44, 49, 44, 49,
  48, 48, 37, 44, 50, 10, 45, 114, 91, 45, 50, 93, 32, 123, 64, 123,
  45, 50, 44, 119, 125, 43, 50, 42, 119, 125, 44, 123, 64, 123, 45, 50,
  44, 104, 125, 43, 50, 42, 104, 125, 44, 49, 44, 49, 48, 48, 37, 44,
  48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 91, 45, 49, 93,
  120, 123, 36, 49, 43, 50, 125, 32, 45, 97, 91, 123, 45, 36, 49, 45,
  50, 125, 45, 45, 49, 93, 32, 120, 32, 45, 106, 91, 45, 51, 93, 32,
  91, 45, 49, 93, 44, 48, 44, 48, 32, 45, 106, 91, 45, 51, 93, 32,
  91, 45, 49, 93, 44, 48, 44, 123, 64, 123, 45, 51, 44, 104, 125, 45,
  49, 45, 104, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 91, 45, 49,
  93, 120, 123, 36, 49, 43, 49, 125, 32, 45, 97, 91, 123, 45, 36, 49,
  45, 50, 125, 45, 45, 49, 93, 32, 121, 32, 45, 106, 91, 45, 50, 93,
  32, 91, 45, 49, 93, 44, 48, 44, 48, 32, 45, 106, 91, 45, 50, 93,
  32, 91, 45, 49, 93, 44, 123, 64, 123, 45, 50, 44, 119, 125, 45, 49,
  45, 119, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 105, 102, 32,
  36, 51, 32, 45, 114, 91, 45, 49, 93, 32, 36, 119, 104, 44, 49, 44,
  49, 48, 48, 37, 44, 50, 32, 45, 101, 110, 100, 105, 102, 10, 45, 109,
  118, 91, 45, 49, 93, 32, 49, 32, 45, 100, 111, 110, 101, 32, 45, 114,
  109, 91, 48, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 102, 114, 97, 109, 101, 95, 114, 111,
  117, 110, 100, 32, 58, 32, 95, 115, 104, 97, 114, 112, 110, 101, 115, 115,
  62, 48, 44, 95, 115, 105, 122, 101, 62, 61, 48, 44, 95, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 44, 95, 115, 104, 97, 100, 105, 110, 103,
  44, 95, 82, 44, 95, 71, 44, 95, 66, 44, 95, 65, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 114, 97, 119, 32, 82, 71, 66, 65, 45,
  99, 111, 108, 111, 114, 101, 100, 32, 114, 111, 117, 110, 100, 32, 102, 114,
  97, 109, 101, 32, 105, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58,
  32, 39, 115, 104, 97, 114, 112, 110, 101, 115, 115, 61, 49, 48, 39, 44,
  32, 39, 115, 105, 122, 101, 61, 49, 48, 39, 44, 32, 39, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 61, 48, 39, 44, 32, 39, 115, 104, 97,
  100, 105, 110, 103, 61, 48, 39, 32, 97, 110, 100, 32, 39, 82, 61, 71,
  61, 66, 61, 65, 61, 50, 53, 53, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 102, 114, 97, 109, 101, 95, 114, 111, 117, 110, 100, 32, 49, 48, 10,
  102, 114, 97, 109, 101, 95, 114, 111, 117, 110, 100, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 49, 61, 49, 48, 125, 44, 36, 123, 50, 61,
  49, 48, 125, 44, 36, 123, 51, 61, 48, 125, 44, 36, 123, 52, 61, 48,
  125, 44, 36, 123, 53, 61, 50, 53, 53, 125, 44, 36, 123, 54, 61, 36,
  53, 125, 44, 36, 123, 55, 61, 36, 54, 125, 44, 36, 123, 56, 61, 50,
  53, 53, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 114, 97,
  119, 32, 114, 111, 117, 110, 100, 32, 102, 114, 97, 109, 101, 32, 111, 110,
  32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 115,
  104, 97, 114, 112, 110, 101, 115, 115, 32, 36, 49, 44, 32, 115, 105, 122,
  101, 32, 36, 50, 44, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  32, 36, 51, 44, 32, 115, 104, 97, 100, 105, 110, 103, 32, 36, 52, 32,
  97, 110, 100, 32, 82, 71, 66, 65, 32, 99, 111, 108, 111, 114, 32, 40,
  36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 41, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110,
  109, 61, 64, 123, 48, 44, 110, 125, 10, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 44, 49, 44, 34, 45, 40, 97, 98, 115, 40, 120, 47,
  119, 45, 48, 46, 53, 41, 94, 36, 49, 32, 43, 32, 97, 98, 115, 40,
  121, 47, 104, 45, 48, 46, 53, 41, 94, 36, 49, 41, 94, 40, 49, 47,
  36, 49, 41, 34, 32, 45, 103, 101, 91, 45, 49, 93, 32, 36, 50, 37,
  10, 45, 105, 102, 32, 36, 52, 32, 45, 100, 105, 115, 116, 97, 110, 99,
  101, 91, 45, 49, 93, 32, 49, 32, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 49, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 43, 91,
  45, 49, 93, 32, 49, 32, 45, 94, 91, 45, 49, 93, 32, 123, 49, 47,
  36, 52, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 98, 91, 45, 49,
  93, 32, 36, 51, 32, 45, 105, 91, 45, 51, 93, 32, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 44, 52, 32, 45, 102, 99, 91, 45, 51,
  93, 32, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 32, 45, 98,
  108, 101, 110, 100, 95, 102, 97, 100, 101, 10, 45, 110, 109, 32, 36, 110,
  109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 102, 114, 97, 109,
  101, 95, 120, 32, 58, 32, 115, 105, 122, 101, 95, 120, 91, 37, 93, 62,
  61, 48, 44, 95, 99, 111, 108, 49, 44, 46, 46, 46, 44, 95, 99, 111,
  108, 78, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 110, 115, 101,
  114, 116, 32, 99, 111, 108, 111, 114, 101, 100, 32, 102, 114, 97, 109, 101,
  32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 120, 45, 97, 120, 105,
  115, 32, 105, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39,
  99, 111, 108, 49, 61, 99, 111, 108, 50, 61, 99, 111, 108, 51, 61, 50,
  53, 53, 39, 32, 97, 110, 100, 32, 39, 99, 111, 108, 52, 61, 50, 53,
  53, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 102, 114, 97, 109, 101, 95,
  120, 32, 50, 48, 44, 50, 53, 53, 44, 48, 44, 50, 53, 53, 10, 102,
  114, 97, 109, 101, 95, 120, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 36, 49, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  50, 61, 50, 53, 53, 125, 44, 36, 123, 51, 61, 36, 50, 125, 44, 36,
  123, 52, 61, 36, 51, 125, 44, 36, 123, 53, 61, 50, 53, 53, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 115, 101, 114, 116, 32,
  36, 49, 32, 111, 117, 116, 101, 114, 32, 102, 114, 97, 109, 101, 32, 105,
  110, 32, 105, 109, 97, 103, 101, 36, 63, 32, 97, 108, 111, 110, 103, 32,
  116, 104, 101, 32, 120, 45, 97, 120, 105, 115, 44, 32, 119, 105, 116, 104,
  32, 99, 111, 108, 111, 114, 32, 40, 36, 123, 50, 45, 45, 49, 125, 41,
  46, 34, 10, 45, 95, 102, 114, 97, 109, 101, 32, 36, 49, 44, 48, 44,
  48, 44, 36, 123, 50, 45, 45, 49, 125, 10, 35, 64, 103, 109, 105, 99,
  32, 102, 114, 97, 109, 101, 95, 120, 121, 32, 58, 32, 115, 105, 122, 101,
  95, 120, 91, 37, 93, 62, 61, 48, 44, 95, 115, 105, 122, 101, 95, 121,
  91, 37, 93, 62, 61, 48, 44, 95, 99, 111, 108, 49, 44, 46, 46, 46,
  44, 95, 99, 111, 108, 78, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  73, 110, 115, 101, 114, 116, 32, 99, 111, 108, 111, 114, 101, 100, 32, 102,
  114, 97, 109, 101, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 120,
  45, 97, 120, 105, 115, 32, 105, 110, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  115, 58, 32, 39, 115, 105, 122, 101, 95, 121, 61, 115, 105, 122, 101, 95,
  120, 39, 44, 32, 39, 99, 111, 108, 49, 61, 99, 111, 108, 50, 61, 99,
  111, 108, 51, 61, 50, 53, 53, 39, 32, 97, 110, 100, 32, 39, 99, 111,
  108, 52, 61, 50, 53, 53, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39, 45, 102, 114, 97, 109,
  101, 39, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 102, 114, 97, 109, 101,
  95, 120, 121, 32, 49, 44, 49, 44, 48, 32, 45, 102, 114, 97, 109, 101,
  95, 120, 121, 32, 50, 48, 44, 49, 48, 44, 50, 53, 53, 44, 48, 44,
  50, 53, 53, 10, 102, 114, 97, 109, 101, 95, 120, 121, 32, 58, 32, 45,
  99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48, 32, 38, 38, 32,
  36, 123, 50, 61, 36, 49, 125, 62, 61, 48, 34, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 51, 61, 50, 53, 53, 125, 44, 36, 123, 52, 61, 36,
  51, 125, 44, 36, 123, 53, 61, 36, 52, 125, 44, 36, 123, 54, 61, 50,
  53, 53, 125, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63,
  34, 32, 45, 118, 32, 43, 10, 45, 95, 36, 48, 32, 36, 123, 49, 45,
  45, 49, 125, 10, 95, 102, 114, 97, 109, 101, 95, 120, 121, 32, 58, 10,
  45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 73, 110, 115, 101, 114, 116,
  32, 36, 49, 120, 36, 50, 32, 111, 117, 116, 101, 114, 32, 102, 114, 97,
  109, 101, 32, 105, 110, 32, 105, 109, 97, 103, 101, 34, 36, 95, 95, 115,
  34, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 120, 121, 45, 97,
  120, 101, 115, 44, 32, 119, 105, 116, 104, 32, 99, 111, 108, 111, 114, 32,
  40, 36, 123, 51, 45, 45, 49, 125, 41, 46, 34, 10, 45, 95, 102, 114,
  97, 109, 101, 32, 36, 49, 44, 36, 50, 44, 48, 44, 36, 123, 51, 45,
  45, 49, 125, 10, 35, 64, 103, 109, 105, 99, 32, 102, 114, 97, 109, 101,
  95, 120, 121, 122, 32, 58, 32, 115, 105, 122, 101, 95, 120, 91, 37, 93,
  62, 61, 48, 44, 95, 115, 105, 122, 101, 95, 121, 91, 37, 93, 62, 61,
  48, 44, 95, 115, 105, 122, 101, 95, 122, 91, 37, 93, 62, 61, 48, 95,
  99, 111, 108, 49, 44, 46, 46, 46, 44, 95, 99, 111, 108, 78, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 73, 110, 115, 101, 114, 116, 32, 99,
  111, 108, 111, 114, 101, 100, 32, 102, 114, 97, 109, 101, 32, 97, 108, 111,
  110, 103, 32, 116, 104, 101, 32, 120, 45, 97, 120, 105, 115, 32, 105, 110,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117,
  108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 115, 105, 122, 101,
  95, 121, 61, 115, 105, 122, 101, 95, 120, 61, 115, 105, 122, 101, 95, 122,
  39, 44, 32, 39, 99, 111, 108, 49, 61, 99, 111, 108, 50, 61, 99, 111,
  108, 51, 61, 50, 53, 53, 39, 32, 97, 110, 100, 32, 39, 99, 111, 108,
  52, 61, 50, 53, 53, 39, 46, 10, 102, 114, 97, 109, 101, 95, 120, 121,
  122, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61,
  48, 32, 38, 38, 32, 36, 123, 50, 61, 36, 49, 125, 62, 61, 48, 32,
  38, 38, 32, 36, 123, 51, 61, 36, 50, 125, 62, 61, 48, 34, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 52, 61, 50, 53, 53, 125, 44, 36, 123,
  53, 61, 36, 52, 125, 44, 36, 123, 54, 61, 36, 53, 125, 44, 36, 123,
  55, 61, 50, 53, 53, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  73, 110, 115, 101, 114, 116, 32, 36, 49, 120, 36, 50, 120, 36, 51, 32,
  111, 117, 116, 101, 114, 32, 102, 114, 97, 109, 101, 32, 105, 110, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101,
  32, 120, 121, 122, 45, 97, 120, 101, 115, 44, 32, 119, 105, 116, 104, 32,
  99, 111, 108, 111, 114, 32, 40, 36, 123, 52, 45, 45, 49, 125, 41, 46,
  34, 10, 45, 95, 102, 114, 97, 109, 101, 32, 36, 49, 44, 36, 50, 44,
  36, 51, 44, 36, 123, 52, 45, 45, 49, 125, 10, 35, 64, 103, 109, 105,
  99, 32, 102, 114, 97, 109, 101, 95, 121, 32, 58, 32, 115, 105, 122, 101,
  95, 121, 91, 37, 93, 62, 61, 48, 44, 95, 99, 111, 108, 49, 44, 46,
  46, 46, 44, 95, 99, 111, 108, 78, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 73, 110, 115, 101, 114, 116, 32, 99, 111, 108, 111, 114, 101, 100,
  32, 102, 114, 97, 109, 101, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101,
  32, 121, 45, 97, 120, 105, 115, 32, 105, 110, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108,
  117, 101, 115, 58, 32, 39, 99, 111, 108, 49, 61, 99, 111, 108, 50, 61,
  99, 111, 108, 51, 61, 50, 53, 53, 39, 32, 97, 110, 100, 32, 39, 99,
  111, 108, 52, 61, 50, 53, 53, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  102, 114, 97, 109, 101, 95, 121, 32, 50, 48, 44, 50, 53, 53, 44, 48,
  44, 50, 53, 53, 10, 102, 114, 97, 109, 101, 95, 121, 32, 58, 32, 45,
  99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48, 34, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 50, 61, 50, 53, 53, 125, 44, 36, 123, 51,
  61, 36, 50, 125, 44, 36, 123, 52, 61, 36, 51, 125, 44, 36, 123, 53,
  61, 50, 53, 53, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73,
  110, 115, 101, 114, 116, 32, 36, 49, 32, 111, 117, 116, 101, 114, 32, 102,
  114, 97, 109, 101, 32, 105, 110, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 121, 45, 97, 120, 105, 115,
  44, 32, 119, 105, 116, 104, 32, 99, 111, 108, 111, 114, 32, 40, 36, 123,
  50, 45, 45, 49, 125, 41, 46, 34, 10, 45, 95, 102, 114, 97, 109, 101,
  32, 48, 44, 36, 49, 44, 48, 44, 36, 123, 50, 45, 45, 49, 125, 10,
  95, 102, 114, 97, 109, 101, 32, 58, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  119, 61, 123, 114, 111, 117, 110, 100, 40, 36, 49, 42, 105, 102, 40, 64,
  123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 49,
  125, 44, 119, 44, 49, 41, 41, 125, 10, 104, 61, 123, 114, 111, 117, 110,
  100, 40, 36, 50, 42, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101,
  114, 99, 101, 110, 116, 92, 32, 36, 50, 125, 44, 104, 44, 49, 41, 41,
  125, 10, 100, 61, 123, 114, 111, 117, 110, 100, 40, 36, 51, 42, 105, 102,
  40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32,
  36, 51, 125, 44, 100, 44, 49, 41, 41, 125, 10, 45, 114, 32, 123, 119,
  43, 50, 42, 36, 119, 125, 44, 123, 104, 43, 50, 42, 36, 104, 125, 44,
  123, 100, 43, 50, 42, 36, 100, 125, 44, 49, 48, 48, 37, 44, 48, 44,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 105,
  102, 32, 123, 36, 119, 125, 32, 36, 119, 44, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 102, 99, 91, 45, 49, 93,
  32, 36, 123, 52, 45, 45, 49, 125, 32, 45, 106, 91, 48, 93, 32, 91,
  49, 93, 32, 45, 106, 91, 48, 93, 32, 91, 49, 93, 44, 64, 123, 48,
  44, 119, 45, 36, 119, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 104, 125, 32, 49,
  48, 48, 37, 44, 36, 104, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  32, 45, 102, 99, 91, 45, 49, 93, 32, 36, 123, 52, 45, 45, 49, 125,
  32, 45, 106, 91, 48, 93, 32, 91, 49, 93, 32, 45, 106, 91, 48, 93,
  32, 91, 49, 93, 44, 48, 44, 64, 123, 48, 44, 104, 45, 36, 104, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 100, 125, 32, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 36, 100, 44, 49, 48, 48, 37, 32, 45, 102, 99, 91, 45,
  49, 93, 32, 36, 123, 52, 45, 45, 49, 125, 32, 45, 106, 91, 48, 93,
  32, 91, 49, 93, 32, 45, 106, 91, 48, 93, 32, 91, 49, 93, 44, 48,
  44, 48, 44, 64, 123, 48, 44, 100, 45, 36, 100, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 105, 109, 97, 103, 101, 103, 114, 105, 100, 32, 58, 32,
  77, 62, 48, 44, 95, 78, 62, 48, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 67, 114, 101, 97, 116, 101, 32, 77, 120, 78, 32, 105, 109, 97,
  103, 101, 32, 103, 114, 105, 100, 32, 102, 114, 111, 109, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 58, 32, 39, 78, 61, 77, 39, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 105, 109, 97, 103, 101, 103, 114, 105, 100, 32, 49, 54, 10,
  105, 109, 97, 103, 101, 103, 114, 105, 100, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 50, 61, 36, 49, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 114, 101, 97, 116, 101, 32, 36, 49, 120, 36, 50, 32,
  105, 109, 97, 103, 101, 32, 103, 114, 105, 100, 32, 102, 114, 111, 109, 32,
  105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 40, 123, 119, 125, 44, 123, 104, 125, 41, 32, 40, 36, 49, 44, 36,
  50, 41, 32, 45, 47, 91, 45, 50, 44, 45, 49, 93, 32, 45, 114, 111,
  117, 110, 100, 91, 45, 49, 93, 32, 49, 32, 45, 114, 91, 45, 50, 93,
  32, 64, 45, 49, 44, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 50,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 40, 123, 119, 125, 44, 123, 104,
  125, 41, 32, 40, 36, 49, 44, 36, 50, 41, 32, 45, 42, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 114, 91, 45, 50, 93, 32, 64, 45, 49, 44,
  91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 50, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 36, 49, 44, 36, 50, 44, 49, 44, 91, 45, 49, 93,
  44, 49, 32, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 49, 44,
  49, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44,
  50, 32, 45, 42, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 108, 105, 110,
  101, 97, 114, 105, 122, 101, 95, 116, 105, 108, 101, 115, 32, 58, 32, 77,
  62, 48, 44, 95, 78, 62, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 76, 105, 110, 101, 97, 114, 105, 122, 101, 32, 77, 120, 78, 32, 116,
  105, 108, 101, 115, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58,
  32, 39, 78, 61, 77, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 108,
  105, 110, 101, 97, 114, 105, 122, 101, 95, 116, 105, 108, 101, 115, 32, 49,
  54, 10, 108, 105, 110, 101, 97, 114, 105, 122, 101, 95, 116, 105, 108, 101,
  115, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 48,
  32, 38, 38, 32, 36, 123, 50, 61, 36, 49, 125, 62, 48, 34, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 76, 105, 110, 101, 97, 114, 105, 122,
  101, 32, 36, 49, 120, 36, 50, 32, 116, 105, 108, 101, 115, 32, 111, 110,
  32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 115, 61, 123, 115,
  125, 32, 45, 115, 112, 108, 105, 116, 95, 116, 105, 108, 101, 115, 32, 36,
  49, 44, 36, 50, 32, 45, 115, 32, 99, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 104, 61, 123,
  119, 125, 44, 123, 104, 125, 10, 45, 45, 102, 32, 120, 32, 45, 45, 102,
  91, 45, 49, 93, 32, 121, 32, 45, 45, 102, 91, 45, 49, 93, 32, 49,
  32, 45, 121, 32, 45, 97, 91, 94, 48, 93, 32, 120, 32, 45, 115, 111,
  108, 118, 101, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 36, 119, 104, 44, 49, 44, 49, 44, 64, 123, 45,
  49, 44, 48, 125, 34, 42, 120, 32, 43, 32, 34, 64, 123, 45, 49, 44,
  49, 125, 34, 42, 121, 32, 43, 32, 34, 64, 123, 45, 49, 44, 50, 125,
  32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110,
  116, 40, 64, 35, 47, 36, 115, 41, 125, 32, 45, 97, 91, 45, 36, 115,
  45, 45, 49, 93, 32, 99, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48,
  32, 45, 100, 111, 110, 101, 32, 45, 97, 112, 112, 101, 110, 100, 95, 116,
  105, 108, 101, 115, 32, 36, 49, 44, 36, 50, 10, 45, 110, 109, 32, 36,
  110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 109, 97, 112,
  95, 115, 112, 114, 105, 116, 101, 115, 32, 58, 32, 95, 110, 98, 95, 115,
  99, 97, 108, 101, 115, 62, 61, 49, 44, 95, 97, 108, 108, 111, 119, 95,
  114, 111, 116, 97, 116, 105, 111, 110, 61, 123, 32, 48, 61, 110, 111, 110,
  101, 32, 124, 32, 49, 61, 57, 48, 32, 100, 101, 103, 46, 32, 124, 32,
  50, 61, 49, 56, 48, 32, 100, 101, 103, 46, 32, 125, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 77, 97, 112, 32, 115, 101, 116, 32, 111, 102,
  32, 115, 112, 114, 105, 116, 101, 115, 32, 40, 100, 101, 102, 105, 110, 101,
  100, 32, 97, 115, 32, 116, 104, 101, 32, 39, 110, 98, 95, 115, 99, 97,
  108, 101, 115, 39, 32, 108, 97, 116, 101, 115, 116, 32, 105, 109, 97, 103,
  101, 115, 32, 111, 102, 32, 116, 104, 101, 32, 115, 101, 108, 101, 99, 116,
  105, 111, 110, 41, 32, 116, 111, 32, 111, 116, 104, 101, 114, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 44, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 97, 99, 99, 111, 114, 100, 105, 110,
  103, 32, 116, 111, 32, 116, 104, 101, 32, 108, 117, 109, 105, 110, 111, 115,
  105, 116, 121, 32, 111, 102, 32, 116, 104, 101, 105, 114, 32, 112, 105, 120,
  101, 108, 32, 118, 97, 108, 117, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 114, 50, 100, 121, 32, 52, 56, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 49, 54, 32, 45, 98, 97, 108, 108, 32, 123, 56, 43, 50, 42, 36,
  62, 125, 44, 64, 123, 45, 82, 71, 66, 125, 32, 45, 42, 91, 45, 49,
  93, 32, 123, 40, 49, 43, 36, 62, 41, 47, 49, 54, 125, 32, 45, 100,
  111, 110, 101, 32, 45, 109, 97, 112, 95, 115, 112, 114, 105, 116, 101, 115,
  32, 49, 54, 10, 109, 97, 112, 95, 115, 112, 114, 105, 116, 101, 115, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110, 116, 40,
  36, 49, 41, 32, 38, 38, 32, 36, 49, 62, 48, 32, 38, 38, 32, 105,
  115, 105, 110, 116, 40, 36, 123, 50, 61, 48, 125, 41, 32, 38, 38, 32,
  36, 50, 62, 61, 48, 32, 38, 38, 32, 36, 50, 60, 61, 50, 34, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 77, 97, 112, 32, 115, 101, 116,
  32, 111, 102, 32, 36, 49, 32, 115, 112, 114, 105, 116, 101, 115, 32, 116,
  111, 32, 105, 109, 97, 103, 101, 32, 115, 101, 108, 101, 99, 116, 105, 111,
  110, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 110, 111, 114, 109,
  91, 48, 45, 45, 123, 36, 49, 43, 49, 125, 93, 32, 45, 113, 117, 97,
  110, 116, 105, 122, 101, 91, 48, 45, 45, 123, 36, 49, 43, 49, 125, 93,
  32, 36, 49, 44, 48, 44, 49, 10, 45, 115, 108, 105, 99, 101, 115, 91,
  45, 36, 49, 45, 45, 49, 93, 32, 48, 32, 45, 114, 91, 45, 36, 49,
  45, 45, 49, 93, 32, 64, 123, 45, 109, 97, 120, 95, 119, 104, 91, 45,
  36, 49, 45, 45, 49, 93, 125, 44, 49, 44, 49, 48, 48, 37, 44, 48,
  44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 105, 102, 32, 123,
  36, 50, 61, 61, 49, 125, 10, 78, 61, 123, 52, 42, 36, 49, 125, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 36, 49, 125, 32,
  45, 42, 91, 36, 62, 93, 32, 52, 32, 45, 45, 114, 97, 110, 100, 91,
  36, 62, 93, 32, 48, 44, 51, 32, 45, 114, 111, 117, 110, 100, 91, 45,
  49, 93, 32, 45, 43, 91, 36, 62, 44, 45, 49, 93, 32, 45, 100, 111,
  110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 32, 45, 108,
  91, 123, 49, 43, 36, 60, 125, 93, 32, 45, 45, 109, 105, 114, 114, 111,
  114, 32, 120, 121, 32, 45, 45, 114, 111, 116, 97, 116, 101, 32, 57, 48,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 50, 61, 61, 50, 125, 10, 78, 61, 123, 50, 42,
  36, 49, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45,
  36, 49, 125, 32, 45, 42, 91, 36, 62, 93, 32, 50, 32, 45, 45, 114,
  97, 110, 100, 91, 36, 62, 93, 32, 48, 44, 49, 32, 45, 114, 111, 117,
  110, 100, 91, 45, 49, 93, 32, 45, 43, 91, 36, 62, 44, 45, 49, 93,
  32, 45, 100, 111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36,
  49, 32, 45, 108, 91, 123, 49, 43, 36, 60, 125, 93, 32, 45, 45, 109,
  105, 114, 114, 111, 114, 32, 120, 121, 32, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 45, 101, 108, 115, 101, 32, 78, 61, 36, 49, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 114, 91, 45, 36, 78, 45, 45, 49,
  93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 64, 123,
  45, 109, 97, 120, 95, 115, 91, 45, 36, 78, 45, 45, 49, 93, 125, 32,
  119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 32, 45, 97, 91, 45,
  36, 78, 45, 45, 49, 93, 32, 120, 10, 45, 114, 91, 94, 45, 49, 93,
  32, 36, 123, 119, 125, 48, 48, 37, 44, 36, 123, 104, 125, 48, 48, 37,
  44, 49, 44, 49, 32, 45, 42, 91, 94, 45, 49, 93, 32, 36, 119, 10,
  40, 48, 44, 123, 36, 119, 45, 49, 125, 59, 48, 44, 123, 36, 119, 45,
  49, 125, 94, 48, 44, 48, 59, 123, 36, 104, 45, 49, 125, 44, 123, 36,
  104, 45, 49, 125, 41, 32, 45, 114, 91, 45, 49, 93, 32, 36, 119, 44,
  36, 104, 44, 49, 44, 50, 44, 51, 32, 45, 114, 111, 117, 110, 100, 91,
  45, 49, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45,
  50, 125, 32, 45, 45, 114, 91, 45, 49, 93, 32, 91, 36, 62, 93, 44,
  91, 36, 62, 93, 44, 49, 44, 50, 44, 48, 44, 50, 32, 45, 114, 91,
  36, 62, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44,
  50, 44, 48, 32, 45, 43, 91, 36, 62, 44, 45, 49, 93, 32, 45, 45,
  119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 36, 62, 93, 44, 48, 44,
  48, 32, 45, 114, 118, 91, 36, 62, 44, 45, 49, 93, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 112, 117, 122, 122, 108, 101, 32, 58, 32, 95, 119, 105, 100, 116,
  104, 62, 48, 44, 95, 104, 101, 105, 103, 104, 116, 62, 48, 44, 95, 77,
  62, 61, 49, 44, 95, 78, 62, 61, 49, 44, 95, 99, 117, 114, 118, 97,
  116, 117, 114, 101, 44, 95, 99, 101, 110, 116, 101, 114, 105, 110, 103, 44,
  95, 99, 111, 110, 110, 101, 99, 116, 111, 114, 115, 95, 118, 97, 114, 105,
  97, 98, 105, 108, 105, 116, 121, 44, 95, 114, 101, 115, 111, 108, 117, 116,
  105, 111, 110, 62, 61, 49, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  73, 110, 112, 117, 116, 32, 112, 117, 122, 122, 108, 101, 32, 98, 105, 110,
  97, 114, 121, 32, 109, 97, 115, 107, 32, 119, 105, 116, 104, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 115, 105, 122, 101, 32, 97, 110, 100,
  32, 103, 101, 111, 109, 101, 116, 114, 121, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117,
  101, 115, 58, 32, 39, 119, 105, 100, 116, 104, 61, 104, 101, 105, 103, 104,
  116, 61, 53, 49, 50, 39, 44, 32, 39, 77, 61, 78, 61, 53, 39, 44,
  32, 39, 99, 117, 114, 118, 97, 116, 117, 114, 101, 61, 48, 46, 53, 39,
  44, 32, 39, 99, 101, 110, 116, 101, 114, 105, 110, 103, 61, 48, 46, 53,
  39, 44, 32, 39, 99, 111, 110, 110, 101, 99, 116, 111, 114, 115, 95, 118,
  97, 114, 105, 97, 98, 105, 108, 105, 116, 121, 61, 48, 46, 53, 39, 32,
  97, 110, 100, 32, 39, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 61,
  54, 52, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  45, 112, 117, 122, 122, 108, 101, 32, 44, 10, 112, 117, 122, 122, 108, 101,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110, 116,
  40, 36, 123, 49, 61, 53, 49, 50, 125, 41, 32, 38, 38, 32, 36, 49,
  62, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 50, 61,
  36, 49, 125, 41, 32, 38, 38, 32, 36, 50, 62, 48, 32, 38, 38, 32,
  105, 115, 105, 110, 116, 40, 36, 123, 51, 61, 53, 125, 41, 32, 38, 38,
  32, 36, 51, 62, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36,
  123, 52, 61, 36, 51, 125, 41, 32, 38, 38, 32, 36, 52, 62, 48, 32,
  38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 56, 61, 54, 52, 125,
  41, 32, 38, 38, 32, 36, 56, 62, 48, 34, 10, 45, 115, 107, 105, 112,
  32, 36, 123, 53, 61, 48, 46, 53, 125, 44, 36, 123, 54, 61, 48, 46,
  53, 125, 44, 36, 123, 55, 61, 48, 46, 53, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 68, 114, 97, 119, 32, 36, 51, 120, 36, 52, 32,
  112, 117, 122, 122, 108, 101, 32, 112, 97, 116, 116, 101, 114, 110, 32, 111,
  110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32,
  99, 117, 114, 118, 97, 116, 117, 114, 101, 32, 36, 53, 44, 32, 99, 101,
  110, 116, 101, 114, 105, 110, 103, 32, 36, 54, 44, 32, 99, 111, 110, 110,
  101, 99, 116, 111, 114, 115, 32, 118, 97, 114, 105, 97, 98, 105, 108, 105,
  116, 121, 32, 36, 55, 32, 97, 110, 100, 32, 114, 101, 115, 111, 108, 117,
  116, 105, 111, 110, 32, 36, 56, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  108, 91, 93, 10, 45, 105, 102, 32, 123, 36, 52, 62, 61, 50, 125, 32,
  45, 95, 112, 117, 122, 122, 108, 101, 91, 93, 32, 36, 51, 44, 123, 36,
  52, 45, 49, 125, 44, 36, 123, 53, 45, 56, 125, 32, 45, 43, 51, 100,
  91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 51, 62, 61, 50, 125, 32, 45, 95, 112, 117,
  122, 122, 108, 101, 91, 93, 32, 36, 52, 44, 123, 36, 51, 45, 49, 125,
  44, 36, 123, 53, 45, 56, 125, 32, 45, 114, 51, 100, 91, 45, 49, 93,
  32, 48, 44, 48, 44, 49, 44, 57, 48, 32, 45, 43, 51, 100, 91, 45,
  49, 93, 32, 49, 44, 36, 52, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  42, 51, 100, 32, 123, 36, 49, 47, 36, 51, 125, 44, 123, 36, 50, 47,
  36, 52, 125, 32, 45, 113, 117, 97, 100, 114, 97, 110, 103, 108, 101, 51,
  100, 32, 48, 44, 48, 44, 48, 44, 123, 36, 49, 45, 49, 125, 44, 48,
  44, 48, 44, 123, 36, 49, 45, 49, 125, 44, 123, 36, 50, 45, 49, 125,
  44, 48, 44, 48, 44, 123, 36, 50, 45, 49, 125, 44, 48, 32, 45, 112,
  51, 100, 91, 45, 49, 93, 32, 49, 32, 45, 43, 51, 100, 32, 45, 99,
  111, 108, 51, 100, 32, 49, 10, 36, 49, 44, 36, 50, 32, 45, 111, 98,
  106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44,
  48, 44, 48, 44, 48, 44, 49, 44, 49, 44, 48, 44, 48, 32, 45, 114,
  109, 91, 45, 50, 93, 10, 45, 101, 110, 100, 108, 32, 45, 118, 32, 43,
  10, 95, 112, 117, 122, 122, 108, 101, 32, 58, 10, 82, 61, 123, 36, 54,
  42, 36, 49, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 50, 10,
  40, 123, 39, 67, 73, 109, 103, 51, 100, 39, 125, 44, 36, 82, 44, 123,
  36, 82, 45, 49, 125, 41, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36,
  49, 10, 115, 105, 103, 110, 61, 123, 105, 102, 40, 63, 60, 61, 48, 46,
  53, 44, 45, 49, 44, 49, 41, 125, 10, 99, 101, 110, 116, 101, 114, 61,
  123, 36, 52, 42, 63, 40, 45, 48, 46, 50, 53, 44, 48, 46, 50, 53,
  41, 125, 10, 107, 110, 111, 98, 61, 123, 36, 53, 42, 63, 40, 45, 48,
  46, 48, 53, 44, 48, 46, 49, 50, 41, 125, 10, 40, 36, 62, 44, 48,
  59, 92, 10, 123, 48, 46, 50, 43, 36, 99, 101, 110, 116, 101, 114, 43,
  36, 62, 125, 44, 123, 45, 36, 115, 105, 103, 110, 42, 36, 51, 42, 48,
  46, 49, 125, 59, 92, 10, 123, 48, 46, 52, 43, 36, 99, 101, 110, 116,
  101, 114, 43, 36, 62, 125, 44, 48, 59, 92, 10, 123, 48, 46, 51, 53,
  43, 36, 99, 101, 110, 116, 101, 114, 43, 36, 62, 125, 44, 123, 48, 46,
  49, 42, 36, 115, 105, 103, 110, 125, 59, 92, 10, 123, 48, 46, 52, 53,
  43, 36, 99, 101, 110, 116, 101, 114, 43, 36, 62, 125, 44, 123, 40, 48,
  46, 49, 53, 43, 36, 107, 110, 111, 98, 41, 42, 36, 115, 105, 103, 110,
  125, 59, 92, 10, 123, 48, 46, 53, 53, 43, 36, 99, 101, 110, 116, 101,
  114, 43, 36, 62, 125, 44, 123, 40, 48, 46, 49, 53, 43, 36, 107, 110,
  111, 98, 41, 42, 36, 115, 105, 103, 110, 125, 59, 92, 10, 123, 48, 46,
  54, 53, 43, 36, 99, 101, 110, 116, 101, 114, 43, 36, 62, 125, 44, 123,
  48, 46, 49, 42, 36, 115, 105, 103, 110, 125, 59, 92, 10, 123, 48, 46,
  54, 43, 36, 99, 101, 110, 116, 101, 114, 43, 36, 62, 125, 44, 48, 59,
  92, 10, 123, 48, 46, 56, 43, 36, 99, 101, 110, 116, 101, 114, 43, 36,
  62, 125, 44, 123, 45, 36, 115, 105, 103, 110, 42, 36, 51, 42, 48, 46,
  49, 125, 41, 10, 45, 100, 111, 110, 101, 10, 40, 36, 49, 44, 48, 41,
  32, 45, 97, 91, 45, 123, 36, 49, 43, 49, 125, 45, 45, 49, 93, 32,
  121, 32, 45, 114, 91, 45, 49, 93, 32, 50, 44, 36, 82, 44, 49, 44,
  49, 44, 53, 32, 45, 122, 91, 45, 49, 93, 32, 48, 44, 50, 10, 40,
  50, 44, 48, 44, 49, 59, 50, 44, 123, 36, 82, 45, 50, 125, 44, 123,
  36, 82, 45, 49, 125, 41, 32, 45, 114, 91, 45, 49, 93, 32, 51, 44,
  123, 36, 82, 45, 49, 125, 44, 49, 44, 49, 44, 51, 32, 45, 114, 111,
  117, 110, 100, 91, 45, 49, 93, 10, 51, 44, 123, 104, 125, 44, 49, 44,
  49, 44, 50, 53, 53, 32, 49, 44, 123, 104, 125, 44, 49, 44, 49, 44,
  50, 53, 53, 32, 45, 121, 91, 45, 53, 45, 45, 49, 93, 32, 121, 32,
  45, 97, 91, 45, 53, 45, 45, 49, 93, 32, 121, 32, 45, 43, 51, 100,
  91, 45, 49, 93, 32, 48, 44, 36, 62, 10, 45, 100, 111, 110, 101, 32,
  45, 43, 51, 100, 10, 35, 64, 103, 109, 105, 99, 32, 113, 117, 97, 100,
  114, 97, 116, 105, 122, 101, 95, 116, 105, 108, 101, 115, 32, 58, 32, 77,
  62, 48, 44, 95, 78, 62, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 81, 117, 97, 100, 114, 97, 116, 105, 122, 101, 32, 77, 120, 78, 32,
  116, 105, 108, 101, 115, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  58, 32, 39, 78, 61, 77, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45,
  113, 117, 97, 100, 114, 97, 116, 105, 122, 101, 95, 116, 105, 108, 101, 115,
  32, 49, 54, 10, 113, 117, 97, 100, 114, 97, 116, 105, 122, 101, 95, 116,
  105, 108, 101, 115, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36,
  49, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 36, 49, 125, 62, 48,
  34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 81, 117, 97, 100, 114,
  97, 116, 105, 122, 101, 32, 36, 49, 120, 36, 50, 32, 116, 105, 108, 101,
  115, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10,
  115, 61, 123, 115, 125, 32, 45, 115, 112, 108, 105, 116, 95, 116, 105, 108,
  101, 115, 32, 36, 49, 44, 36, 50, 32, 45, 115, 32, 99, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  119, 104, 61, 123, 119, 125, 44, 123, 104, 125, 10, 45, 45, 102, 32, 120,
  94, 50, 32, 45, 45, 102, 91, 45, 49, 93, 32, 121, 94, 50, 32, 45,
  45, 102, 91, 45, 49, 93, 32, 120, 42, 121, 32, 45, 45, 102, 91, 45,
  49, 93, 32, 120, 32, 45, 45, 102, 91, 45, 49, 93, 32, 121, 32, 45,
  45, 102, 91, 45, 49, 93, 32, 49, 32, 45, 121, 32, 45, 97, 91, 94,
  48, 93, 32, 120, 32, 45, 115, 111, 108, 118, 101, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 36, 119, 104,
  44, 49, 44, 49, 44, 64, 123, 45, 49, 44, 48, 125, 34, 42, 120, 94,
  50, 32, 43, 32, 34, 64, 123, 45, 49, 44, 49, 125, 34, 42, 121, 94,
  50, 32, 43, 32, 34, 64, 123, 45, 49, 44, 50, 125, 34, 42, 120, 42,
  121, 32, 43, 34, 64, 123, 45, 49, 44, 51, 125, 34, 42, 120, 32, 43,
  32, 34, 64, 123, 45, 49, 44, 52, 125, 34, 42, 121, 32, 43, 32, 34,
  64, 123, 45, 49, 44, 53, 125, 32, 45, 114, 109, 91, 45, 50, 93, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 36, 115, 41, 125,
  32, 45, 97, 91, 45, 36, 115, 45, 45, 49, 93, 32, 99, 32, 45, 109,
  118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 32, 45, 97,
  112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 32, 36, 49, 44, 36,
  50, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 114, 111, 116, 97, 116, 101, 95, 116, 105, 108, 101, 115,
  32, 58, 32, 97, 110, 103, 108, 101, 44, 95, 77, 62, 48, 44, 78, 62,
  48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121,
  32, 77, 120, 78, 32, 116, 105, 108, 101, 100, 45, 114, 111, 116, 97, 116,
  105, 111, 110, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32,
  118, 97, 108, 117, 101, 115, 58, 32, 39, 77, 61, 56, 39, 32, 97, 110,
  100, 32, 39, 78, 61, 77, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 116,
  111, 95, 114, 103, 98, 97, 32, 45, 114, 111, 116, 97, 116, 101, 95, 116,
  105, 108, 101, 115, 32, 49, 48, 44, 56, 32, 45, 100, 114, 111, 112, 95,
  115, 104, 97, 100, 111, 119, 32, 49, 48, 44, 49, 48, 32, 45, 100, 105,
  115, 112, 108, 97, 121, 95, 114, 103, 98, 97, 10, 114, 111, 116, 97, 116,
  101, 95, 116, 105, 108, 101, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32,
  36, 123, 50, 61, 56, 125, 44, 36, 123, 51, 61, 36, 50, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 36, 50,
  120, 36, 51, 32, 116, 105, 108, 101, 100, 45, 114, 111, 116, 97, 116, 105,
  111, 110, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 97, 110, 103, 108, 101,
  32, 36, 49, 32, 100, 101, 103, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  115, 112, 108, 105, 116, 95, 116, 105, 108, 101, 115, 32, 36, 50, 44, 36,
  51, 44, 49, 32, 45, 114, 111, 116, 97, 116, 101, 32, 36, 49, 32, 45,
  97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 32, 36, 50, 44,
  36, 51, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115,
  104, 105, 102, 116, 95, 116, 105, 108, 101, 115, 32, 58, 32, 77, 62, 48,
  44, 95, 78, 62, 48, 44, 95, 97, 109, 112, 108, 105, 116, 117, 100, 101,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32,
  77, 120, 78, 32, 116, 105, 108, 101, 100, 45, 115, 104, 105, 102, 116, 32,
  101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117,
  101, 115, 58, 32, 39, 78, 61, 77, 39, 32, 97, 110, 100, 32, 39, 97,
  109, 112, 108, 105, 116, 117, 100, 101, 61, 50, 48, 39, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 45, 115, 104, 105, 102, 116, 95, 116, 105, 108, 101, 115,
  32, 56, 44, 56, 44, 49, 48, 10, 115, 104, 105, 102, 116, 95, 116, 105,
  108, 101, 115, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123,
  50, 61, 36, 49, 125, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32,
  36, 123, 51, 61, 50, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 65, 112, 112, 108, 121, 32, 36, 49, 120, 36, 50, 32, 116, 105, 108,
  101, 100, 45, 115, 104, 105, 102, 116, 32, 101, 102, 102, 101, 99, 116, 32,
  111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104,
  32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 36, 51, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 36, 49, 44, 36, 50, 44, 49, 44, 50,
  32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 36, 51, 32, 45,
  114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44,
  49, 44, 50, 32, 45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 44, 49, 44, 49, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 116, 97, 113, 117, 105, 110, 32,
  58, 32, 77, 62, 48, 44, 95, 78, 62, 48, 44, 95, 114, 101, 109, 111,
  118, 101, 95, 116, 105, 108, 101, 61, 123, 32, 48, 61, 110, 111, 110, 101,
  32, 124, 32, 49, 61, 102, 105, 114, 115, 116, 32, 124, 32, 50, 61, 108,
  97, 115, 116, 32, 124, 32, 51, 61, 114, 97, 110, 100, 111, 109, 32, 125,
  44, 95, 114, 101, 108, 105, 101, 102, 44, 95, 98, 111, 114, 100, 101, 114,
  95, 116, 104, 105, 99, 107, 110, 101, 115, 115, 91, 37, 93, 44, 95, 98,
  111, 114, 100, 101, 114, 95, 111, 117, 116, 108, 105, 110, 101, 91, 37, 93,
  44, 95, 111, 117, 116, 108, 105, 110, 101, 95, 99, 111, 108, 111, 114, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 114, 101, 97, 116, 101, 32,
  77, 120, 78, 32, 116, 97, 113, 117, 105, 110, 32, 112, 117, 122, 122, 108,
  101, 32, 102, 114, 111, 109, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32,
  39, 78, 61, 77, 39, 44, 32, 39, 114, 101, 108, 105, 101, 102, 61, 53,
  48, 39, 44, 32, 39, 98, 111, 114, 100, 101, 114, 95, 116, 104, 105, 99,
  107, 110, 101, 115, 115, 61, 53, 39, 44, 32, 39, 98, 111, 114, 100, 101,
  114, 95, 111, 117, 116, 108, 105, 110, 101, 61, 48, 39, 32, 97, 110, 100,
  32, 39, 114, 101, 109, 111, 118, 101, 95, 116, 105, 108, 101, 61, 48, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 45, 116, 97, 113, 117, 105, 110, 32,
  56, 10, 116, 97, 113, 117, 105, 110, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 49, 41, 32, 38, 38, 32,
  36, 49, 62, 48, 32, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 50,
  61, 36, 49, 125, 41, 32, 38, 38, 32, 36, 50, 62, 48, 34, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 51, 61, 48, 125, 44, 36, 123, 52, 61,
  53, 48, 125, 44, 36, 123, 53, 61, 53, 37, 125, 44, 36, 123, 54, 61,
  48, 125, 44, 36, 123, 55, 61, 48, 125, 44, 36, 123, 56, 61, 36, 55,
  125, 44, 36, 123, 57, 61, 36, 56, 125, 44, 36, 123, 49, 48, 61, 50,
  53, 53, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 114, 101,
  97, 116, 101, 32, 36, 49, 120, 36, 50, 32, 116, 97, 113, 117, 105, 110,
  32, 112, 117, 122, 122, 108, 101, 32, 102, 114, 111, 109, 32, 105, 109, 97,
  103, 101, 32, 36, 63, 44, 32, 119, 105, 116, 104, 32, 114, 101, 108, 105,
  101, 102, 32, 36, 52, 44, 32, 98, 111, 114, 100, 101, 114, 32, 116, 104,
  105, 99, 107, 110, 101, 115, 115, 32, 36, 53, 44, 32, 98, 111, 114, 100,
  101, 114, 32, 111, 117, 116, 108, 105, 110, 101, 32, 36, 54, 32, 97, 110,
  100, 32, 111, 117, 116, 108, 105, 110, 101, 32, 99, 111, 108, 111, 114, 32,
  40, 36, 123, 55, 45, 45, 49, 125, 41, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 45, 115, 112,
  108, 105, 116, 95, 116, 105, 108, 101, 115, 32, 36, 49, 44, 36, 50, 32,
  45, 114, 32, 64, 123, 45, 109, 105, 110, 95, 119, 104, 125, 44, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 48, 10, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 49, 44, 49, 44, 49, 10, 45, 105, 102, 32, 64, 123,
  34, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 32, 36, 53, 34,
  125, 32, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93,
  32, 123, 49, 48, 48, 42, 36, 53, 47, 50, 125, 37, 44, 123, 49, 48,
  48, 42, 36, 53, 47, 50, 125, 37, 44, 123, 49, 48, 48, 45, 53, 48,
  42, 36, 53, 125, 37, 44, 123, 49, 48, 48, 45, 53, 48, 42, 36, 53,
  125, 37, 44, 49, 44, 48, 10, 45, 101, 108, 115, 101, 32, 45, 114, 101,
  99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 36, 53, 44, 36,
  53, 44, 123, 119, 45, 49, 45, 36, 53, 125, 44, 123, 104, 45, 49, 45,
  36, 53, 125, 44, 49, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  42, 91, 45, 49, 93, 32, 39, 49, 45, 50, 42, 40, 120, 60, 121, 41,
  39, 32, 45, 42, 91, 45, 49, 93, 32, 36, 52, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 45, 108, 91, 36, 62,
  44, 45, 49, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99,
  105, 116, 121, 91, 48, 93, 32, 45, 43, 91, 48, 93, 32, 91, 45, 49,
  93, 32, 45, 97, 91, 94, 45, 49, 93, 32, 99, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 102, 114, 97, 109, 101, 32,
  36, 54, 44, 36, 54, 44, 36, 123, 55, 45, 49, 48, 125, 10, 45, 105,
  102, 32, 123, 36, 51, 61, 61, 51, 125, 32, 45, 102, 91, 45, 49, 93,
  32, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 109, 118, 91, 36, 62, 93, 32, 123, 63, 40,
  64, 35, 41, 125, 32, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123,
  36, 51, 61, 61, 49, 125, 32, 45, 102, 91, 48, 93, 32, 48, 32, 45,
  101, 108, 105, 102, 32, 123, 36, 51, 61, 61, 50, 125, 32, 45, 102, 91,
  45, 49, 93, 32, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 112,
  112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 32, 36, 49, 44, 36, 50,
  10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109,
  105, 99, 32, 116, 117, 110, 110, 101, 108, 32, 58, 32, 95, 108, 101, 118,
  101, 108, 62, 61, 48, 44, 95, 102, 97, 99, 116, 111, 114, 62, 48, 44,
  95, 99, 120, 44, 95, 99, 121, 44, 95, 111, 112, 97, 99, 105, 116, 121,
  44, 95, 97, 110, 103, 108, 101, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 65, 112, 112, 108, 121, 32, 116, 117, 110, 110, 101, 108, 32, 101, 102,
  102, 101, 99, 116, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115,
  58, 32, 39, 108, 101, 118, 101, 108, 61, 57, 39, 44, 32, 39, 102, 97,
  99, 116, 111, 114, 61, 56, 48, 37, 39, 44, 32, 39, 99, 120, 61, 99,
  121, 61, 48, 46, 53, 39, 44, 32, 39, 111, 112, 97, 99, 105, 116, 121,
  61, 49, 39, 32, 97, 110, 100, 32, 39, 97, 110, 103, 108, 101, 61, 48,
  39, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 45, 116, 117, 110, 110, 101, 108, 32,
  50, 48, 10, 116, 117, 110, 110, 101, 108, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 36, 123, 49, 61, 57, 125, 62, 61, 48, 32, 38, 38,
  32, 36, 123, 50, 61, 56, 48, 37, 125, 62, 48, 34, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 51, 61, 48, 46, 53, 125, 44, 36, 123, 52, 61,
  48, 46, 53, 125, 44, 36, 123, 53, 61, 48, 46, 49, 125, 44, 36, 123,
  54, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112,
  112, 108, 121, 32, 116, 117, 110, 110, 101, 108, 32, 101, 102, 102, 101, 99,
  116, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105,
  116, 104, 32, 100, 101, 112, 116, 104, 32, 36, 49, 44, 32, 102, 97, 99,
  116, 111, 114, 32, 36, 50, 44, 32, 99, 101, 110, 116, 101, 114, 105, 110,
  103, 32, 40, 36, 51, 44, 36, 52, 41, 44, 32, 111, 112, 97, 99, 105,
  116, 121, 32, 36, 53, 32, 97, 110, 100, 32, 97, 110, 103, 108, 101, 32,
  36, 54, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 36, 49, 32, 45, 45, 114, 91, 45, 49, 93, 32, 36,
  50, 44, 36, 50, 44, 49, 44, 49, 48, 48, 37, 44, 53, 10, 45, 105,
  102, 32, 36, 54, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 49, 44, 49, 32, 45, 114, 111, 116, 97, 116, 101, 91, 45, 50, 44,
  45, 49, 93, 32, 36, 54, 44, 49, 44, 48, 32, 45, 101, 114, 111, 100,
  101, 91, 45, 49, 93, 32, 51, 32, 45, 106, 91, 45, 51, 93, 32, 91,
  45, 50, 93, 44, 123, 40, 64, 123, 45, 51, 44, 119, 125, 45, 119, 41,
  42, 36, 51, 125, 44, 123, 40, 64, 123, 45, 51, 44, 104, 125, 45, 104,
  41, 42, 36, 52, 125, 44, 48, 44, 48, 44, 36, 53, 44, 91, 45, 49,
  93, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 108,
  115, 101, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 123,
  40, 64, 123, 45, 50, 44, 119, 125, 45, 119, 41, 42, 36, 51, 125, 44,
  123, 40, 64, 123, 45, 50, 44, 104, 125, 45, 104, 41, 42, 36, 52, 125,
  44, 48, 44, 48, 44, 36, 53, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 99, 32, 48, 44, 50, 53,
  53, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 58, 58,
  32, 65, 114, 116, 105, 115, 116, 105, 99, 10, 35, 64, 103, 109, 105, 99,
  32, 98, 111, 120, 102, 105, 116, 116, 105, 110, 103, 32, 58, 32, 95, 109,
  105, 110, 95, 98, 111, 120, 95, 115, 105, 122, 101, 62, 61, 49, 44, 95,
  109, 97, 120, 95, 98, 111, 120, 95, 115, 105, 122, 101, 62, 61, 48, 44,
  95, 105, 110, 105, 116, 105, 97, 108, 95, 100, 101, 110, 115, 105, 116, 121,
  62, 61, 48, 44, 95, 110, 98, 95, 97, 116, 116, 101, 109, 112, 116, 115,
  62, 61, 49, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112,
  108, 121, 32, 98, 111, 120, 32, 102, 105, 116, 116, 105, 110, 103, 32, 101,
  102, 102, 101, 99, 116, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 44, 32, 97, 115, 32, 100, 105, 115,
  112, 108, 97, 121, 101, 100, 32, 116, 104, 101, 32, 119, 101, 98, 32, 112,
  97, 103, 101, 58, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 91, 104,
  116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 99, 111, 109, 112, 108, 101,
  120, 105, 102, 105, 99, 97, 116, 105, 111, 110, 46, 110, 101, 116, 47, 103,
  97, 108, 108, 101, 114, 121, 47, 109, 97, 99, 104, 105, 110, 101, 115, 47,
  98, 111, 120, 70, 105, 116, 116, 105, 110, 103, 73, 109, 103, 47, 93, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116,
  32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 109, 105, 110, 95, 98, 111,
  120, 95, 115, 105, 122, 101, 61, 49, 39, 44, 32, 39, 109, 97, 120, 95,
  98, 111, 120, 95, 115, 105, 122, 101, 61, 48, 39, 44, 32, 39, 105, 110,
  105, 116, 105, 97, 108, 95, 100, 101, 110, 115, 105, 116, 121, 61, 48, 46,
  49, 39, 32, 97, 110, 100, 32, 39, 110, 98, 95, 116, 114, 105, 101, 115,
  61, 51, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 98, 111, 120, 102,
  105, 116, 116, 105, 110, 103, 32, 44, 10, 98, 111, 120, 102, 105, 116, 116,
  105, 110, 103, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115,
  105, 110, 116, 40, 36, 123, 49, 61, 51, 125, 41, 32, 38, 38, 32, 36,
  49, 62, 61, 49, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123,
  50, 61, 48, 125, 41, 32, 38, 38, 32, 36, 50, 62, 61, 48, 32, 38,
  38, 32, 36, 123, 51, 61, 48, 46, 49, 125, 62, 61, 48, 32, 38, 38,
  32, 105, 115, 105, 110, 116, 40, 36, 123, 52, 61, 51, 125, 41, 32, 38,
  38, 32, 36, 52, 62, 61, 49, 34, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 65, 112, 112, 108, 121, 32, 98, 111, 120, 32, 102, 105, 116, 116,
  105, 110, 103, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109,
  97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 98, 111, 120, 32,
  115, 105, 122, 101, 115, 32, 40, 36, 49, 44, 36, 50, 41, 44, 32, 100,
  101, 110, 115, 105, 116, 121, 32, 36, 51, 32, 97, 110, 100, 32, 36, 52,
  32, 97, 116, 116, 101, 109, 112, 116, 115, 46, 34, 10, 45, 118, 32, 45,
  10, 109, 105, 110, 95, 115, 105, 122, 101, 61, 36, 49, 10, 109, 97, 120,
  95, 115, 105, 122, 101, 61, 123, 105, 102, 40, 36, 50, 44, 36, 50, 44,
  109, 97, 120, 40, 119, 44, 104, 41, 41, 125, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 110, 98, 95,
  97, 116, 116, 101, 109, 112, 116, 115, 61, 48, 32, 112, 114, 101, 99, 61,
  53, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 49, 101, 56, 10, 45, 105, 102, 32, 123, 36, 62, 60,
  49, 125, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 110, 111,
  105, 115, 101, 91, 45, 49, 93, 32, 123, 109, 97, 120, 40, 49, 101, 45,
  51, 44, 36, 51, 41, 125, 44, 50, 10, 45, 101, 108, 115, 101, 10, 45,
  45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32,
  45, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45,
  42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 109, 97, 120, 95, 112, 97,
  116, 99, 104, 91, 45, 49, 93, 32, 123, 114, 111, 117, 110, 100, 40, 36,
  112, 114, 101, 99, 42, 36, 109, 105, 110, 95, 115, 105, 122, 101, 41, 125,
  10, 112, 114, 101, 99, 61, 123, 109, 97, 120, 40, 49, 44, 36, 112, 114,
  101, 99, 42, 48, 46, 57, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 36, 109, 105, 110,
  95, 115, 105, 122, 101, 32, 45, 97, 114, 101, 97, 95, 102, 103, 91, 45,
  49, 93, 32, 48, 44, 49, 32, 45, 101, 113, 91, 45, 49, 93, 32, 123,
  40, 36, 109, 105, 110, 95, 115, 105, 122, 101, 41, 94, 50, 125, 10, 45,
  45, 100, 105, 108, 97, 116, 101, 91, 45, 50, 93, 32, 51, 32, 45, 101,
  113, 91, 45, 49, 93, 32, 48, 32, 45, 42, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 97, 114, 101, 97, 95, 102, 103, 91, 45, 49, 93, 32, 48,
  44, 49, 32, 45, 101, 113, 91, 45, 49, 93, 32, 123, 40, 36, 109, 105,
  110, 95, 115, 105, 122, 101, 41, 94, 50, 125, 10, 45, 105, 102, 32, 123,
  33, 105, 77, 125, 32, 110, 98, 95, 97, 116, 116, 101, 109, 112, 116, 115,
  61, 123, 36, 110, 98, 95, 97, 116, 116, 101, 109, 112, 116, 115, 43, 49,
  125, 32, 45, 105, 102, 32, 123, 36, 110, 98, 95, 97, 116, 116, 101, 109,
  112, 116, 115, 62, 36, 52, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 98, 114, 101, 97, 107, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  108, 115, 101, 32, 110, 98, 95, 97, 116, 116, 101, 109, 112, 116, 115, 61,
  48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 43, 91, 45, 50, 44, 45,
  49, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40,
  40, 36, 109, 97, 120, 95, 115, 105, 122, 101, 45, 36, 109, 105, 110, 95,
  115, 105, 122, 101, 41, 47, 50, 41, 125, 10, 45, 45, 100, 105, 108, 97,
  116, 101, 91, 45, 49, 93, 32, 51, 32, 45, 97, 114, 101, 97, 95, 102,
  103, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 101, 113, 91, 45, 49,
  93, 32, 123, 40, 36, 109, 105, 110, 95, 115, 105, 122, 101, 43, 50, 42,
  36, 62, 43, 50, 41, 94, 50, 125, 10, 45, 105, 102, 32, 123, 33, 105,
  77, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 98, 114, 101, 97,
  107, 32, 45, 101, 110, 100, 105, 102, 10, 45, 111, 114, 91, 45, 50, 44,
  45, 49, 93, 10, 45, 100, 111, 110, 101, 10, 45, 100, 111, 110, 101, 10,
  45, 98, 108, 101, 110, 100, 32, 115, 104, 97, 112, 101, 97, 118, 101, 114,
  97, 103, 101, 48, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 99, 97, 114,
  116, 111, 111, 110, 32, 58, 32, 95, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 44, 95, 115, 104, 97, 114, 112, 101, 110, 105, 110, 103, 44, 95,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 62, 61, 48, 44, 95, 116, 104,
  105, 99, 107, 110, 101, 115, 115, 62, 61, 48, 44, 95, 99, 111, 108, 111,
  114, 62, 61, 48, 44, 113, 117, 97, 110, 116, 105, 122, 97, 116, 105, 111,
  110, 62, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112,
  108, 121, 32, 99, 97, 114, 116, 111, 111, 110, 32, 101, 102, 102, 101, 99,
  116, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 51, 39, 44, 32, 39,
  115, 104, 97, 114, 112, 101, 110, 105, 110, 103, 61, 49, 53, 48, 39, 44,
  32, 39, 116, 104, 114, 101, 115, 104, 111, 108, 100, 61, 50, 48, 39, 44,
  32, 39, 116, 104, 105, 99, 107, 110, 101, 115, 115, 61, 48, 46, 50, 53,
  39, 44, 32, 39, 99, 111, 108, 111, 114, 61, 49, 46, 53, 39, 32, 97,
  110, 100, 32, 39, 113, 117, 97, 110, 116, 105, 122, 97, 116, 105, 111, 110,
  61, 56, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 99, 97, 114, 116,
  111, 111, 110, 32, 51, 44, 56, 48, 44, 49, 53, 10, 99, 97, 114, 116,
  111, 111, 110, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  51, 125, 44, 36, 123, 50, 61, 49, 53, 48, 125, 44, 36, 123, 51, 61,
  50, 48, 125, 44, 36, 123, 52, 61, 48, 46, 50, 53, 125, 44, 36, 123,
  53, 61, 49, 46, 53, 125, 44, 36, 123, 54, 61, 56, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 97, 114,
  116, 111, 111, 110, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105,
  109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 36, 49, 44, 32, 115, 104, 97, 114,
  112, 101, 110, 105, 110, 103, 32, 36, 50, 44, 32, 116, 104, 114, 101, 115,
  104, 111, 108, 100, 32, 36, 51, 44, 32, 116, 104, 105, 99, 107, 110, 101,
  115, 115, 32, 36, 52, 44, 32, 99, 111, 108, 111, 114, 32, 36, 53, 32,
  97, 110, 100, 32, 113, 117, 97, 110, 116, 105, 122, 97, 116, 105, 111, 110,
  32, 36, 54, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112,
  108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91, 48,
  93, 32, 45, 116, 111, 95, 114, 103, 98, 10, 45, 98, 32, 36, 49, 32,
  45, 115, 104, 97, 114, 112, 101, 110, 32, 36, 50, 44, 49, 32, 45, 99,
  32, 48, 44, 50, 53, 53, 32, 45, 110, 32, 48, 44, 50, 53, 53, 10,
  45, 45, 101, 100, 103, 101, 115, 32, 36, 51, 32, 45, 98, 91, 45, 49,
  93, 32, 36, 52, 32, 45, 103, 101, 91, 45, 49, 93, 32, 48, 46, 57,
  10, 45, 114, 103, 98, 50, 108, 97, 98, 91, 45, 50, 93, 32, 45, 115,
  91, 45, 50, 93, 32, 99, 32, 45, 42, 91, 45, 51, 44, 45, 50, 93,
  32, 36, 53, 32, 45, 97, 91, 45, 52, 45, 45, 50, 93, 32, 99, 32,
  45, 108, 97, 98, 50, 114, 103, 98, 91, 45, 50, 93, 32, 45, 113, 117,
  97, 110, 116, 105, 122, 101, 91, 45, 50, 93, 32, 36, 54, 44, 49, 44,
  48, 32, 45, 110, 91, 45, 50, 93, 32, 48, 44, 50, 53, 53, 32, 45,
  42, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 99, 105, 114, 99, 108, 105, 115, 109, 32, 58, 32,
  95, 114, 97, 100, 105, 117, 115, 95, 109, 105, 110, 62, 48, 44, 95, 114,
  97, 100, 105, 117, 115, 95, 109, 97, 120, 62, 48, 44, 95, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 91, 37, 93, 62, 61, 48, 44, 95, 114,
  97, 100, 105, 117, 115, 95, 108, 105, 110, 101, 97, 114, 105, 116, 121, 62,
  61, 48, 44, 95, 108, 111, 99, 97, 116, 105, 111, 110, 95, 108, 105, 110,
  101, 97, 114, 105, 116, 121, 62, 61, 48, 44, 95, 115, 104, 97, 112, 101,
  61, 123, 48, 61, 115, 113, 117, 97, 114, 101, 115, 32, 124, 32, 49, 61,
  100, 105, 97, 109, 111, 110, 100, 115, 32, 124, 32, 50, 61, 99, 105, 114,
  99, 108, 101, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65,
  112, 112, 108, 121, 32, 99, 105, 114, 99, 108, 105, 115, 109, 32, 101, 102,
  102, 101, 99, 116, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 32, 40, 101, 102, 102, 101, 99, 116, 32,
  105, 110, 115, 112, 105, 114, 101, 100, 32, 98, 121, 32, 66, 101, 110, 32,
  72, 101, 105, 110, 101, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58,
  32, 39, 114, 97, 100, 105, 117, 115, 95, 109, 105, 110, 61, 50, 39, 44,
  32, 39, 114, 97, 100, 105, 117, 115, 95, 109, 97, 120, 61, 50, 48, 39,
  44, 32, 39, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 49, 39,
  44, 32, 39, 114, 97, 100, 105, 117, 115, 95, 108, 105, 110, 101, 97, 114,
  105, 116, 121, 61, 48, 46, 52, 39, 44, 32, 39, 108, 111, 99, 97, 116,
  105, 111, 110, 95, 108, 105, 110, 101, 97, 114, 105, 116, 121, 61, 51, 39,
  32, 97, 110, 100, 32, 39, 115, 104, 97, 112, 101, 61, 49, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 45, 99, 105, 114, 99, 108, 105, 115, 109, 32,
  44, 10, 99, 105, 114, 99, 108, 105, 115, 109, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 36, 123, 49, 61, 50, 125, 62, 48, 32, 38, 38,
  32, 36, 123, 50, 61, 50, 48, 125, 62, 48, 32, 38, 38, 32, 36, 123,
  51, 61, 49, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 52, 61, 48,
  46, 52, 125, 62, 48, 32, 38, 38, 32, 36, 123, 53, 61, 51, 125, 62,
  61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 54, 61, 50, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32,
  99, 105, 114, 99, 108, 105, 115, 109, 32, 101, 102, 102, 101, 99, 116, 32,
  111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104,
  32, 114, 97, 100, 105, 105, 32, 40, 36, 49, 44, 36, 50, 41, 44, 32,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 51, 44, 32, 114,
  97, 100, 105, 117, 115, 32, 108, 105, 110, 101, 97, 114, 105, 116, 121, 32,
  36, 52, 32, 97, 110, 100, 32, 108, 111, 99, 97, 116, 105, 111, 110, 32,
  108, 105, 110, 101, 97, 114, 105, 116, 121, 32, 36, 53, 46, 92, 110, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 103, 114, 97, 100, 105, 101,
  110, 116, 95, 110, 111, 114, 109, 32, 45, 98, 91, 45, 49, 93, 32, 36,
  51, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 45, 94,
  91, 45, 49, 93, 32, 36, 53, 32, 45, 94, 91, 45, 50, 93, 32, 36,
  52, 32, 115, 117, 109, 103, 48, 61, 64, 123, 45, 49, 44, 43, 125, 32,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 10, 105, 116, 61, 48, 32, 102,
  97, 105, 108, 101, 100, 61, 48, 32, 110, 111, 101, 100, 103, 101, 115, 61,
  48, 32, 115, 118, 103, 61, 34, 45, 49, 44, 45, 49, 34, 10, 45, 100,
  111, 10, 45, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93,
  32, 49, 44, 51, 10, 45, 105, 102, 32, 36, 110, 111, 101, 100, 103, 101,
  115, 32, 120, 121, 122, 99, 61, 64, 123, 45, 49, 44, 67, 125, 32, 45,
  101, 108, 115, 101, 32, 45, 45, 42, 91, 45, 51, 44, 45, 49, 93, 32,
  120, 121, 122, 99, 61, 64, 123, 45, 49, 44, 67, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 110, 61, 64, 123,
  45, 52, 44, 40, 36, 120, 121, 122, 99, 41, 125, 10, 120, 61, 123, 97,
  114, 103, 40, 49, 44, 36, 120, 121, 122, 99, 41, 125, 10, 121, 61, 123,
  97, 114, 103, 40, 50, 44, 36, 120, 121, 122, 99, 41, 125, 10, 114, 61,
  123, 109, 105, 110, 40, 109, 97, 120, 40, 36, 49, 44, 36, 50, 42, 40,
  49, 45, 36, 110, 41, 41, 44, 115, 113, 114, 116, 40, 64, 123, 45, 49,
  44, 40, 36, 120, 121, 122, 99, 41, 125, 41, 45, 50, 41, 125, 10, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 114, 62, 61,
  36, 49, 125, 10, 45, 105, 102, 32, 123, 36, 54, 61, 61, 50, 125, 10,
  45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 120, 44,
  36, 121, 44, 36, 114, 44, 36, 114, 44, 48, 44, 49, 44, 49, 32, 45,
  101, 108, 108, 105, 112, 115, 101, 91, 45, 50, 93, 32, 36, 120, 44, 36,
  121, 44, 123, 36, 114, 43, 36, 49, 125, 44, 123, 36, 114, 43, 36, 49,
  125, 44, 48, 44, 49, 44, 45, 49, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 54, 61, 61, 49, 125, 10, 120, 48, 61, 123, 36, 120, 45, 36, 114,
  47, 50, 125, 32, 121, 48, 61, 123, 36, 121, 45, 36, 114, 47, 50, 125,
  32, 120, 49, 61, 123, 36, 120, 43, 36, 114, 47, 50, 125, 32, 121, 49,
  61, 123, 36, 121, 43, 36, 114, 47, 50, 125, 10, 45, 114, 101, 99, 116,
  97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 36, 120, 48, 44, 36, 121,
  48, 44, 36, 120, 49, 44, 36, 121, 49, 44, 49, 44, 49, 10, 120, 48,
  61, 123, 36, 120, 45, 40, 36, 114, 43, 36, 49, 41, 47, 50, 125, 32,
  121, 48, 61, 123, 36, 121, 45, 40, 36, 114, 43, 36, 49, 41, 47, 50,
  125, 32, 120, 49, 61, 123, 36, 120, 43, 40, 36, 114, 43, 36, 49, 41,
  47, 50, 125, 32, 121, 49, 61, 123, 36, 121, 43, 40, 36, 114, 43, 36,
  49, 41, 47, 50, 125, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101,
  91, 45, 50, 93, 32, 36, 120, 48, 44, 36, 121, 48, 44, 36, 120, 49,
  44, 36, 121, 49, 44, 49, 44, 45, 49, 10, 45, 101, 108, 115, 101, 10,
  120, 48, 61, 123, 114, 111, 117, 110, 100, 40, 36, 120, 45, 36, 114, 47,
  50, 41, 125, 32, 121, 48, 61, 123, 114, 111, 117, 110, 100, 40, 36, 121,
  45, 36, 114, 47, 50, 41, 125, 32, 120, 49, 61, 123, 114, 111, 117, 110,
  100, 40, 36, 120, 43, 36, 114, 47, 50, 41, 125, 32, 121, 49, 61, 123,
  114, 111, 117, 110, 100, 40, 36, 121, 43, 36, 114, 47, 50, 41, 125, 10,
  45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 52, 44, 36,
  120, 48, 44, 36, 121, 44, 36, 120, 44, 36, 121, 48, 44, 36, 120, 49,
  44, 36, 121, 44, 36, 120, 44, 36, 121, 49, 44, 49, 44, 49, 10, 120,
  48, 61, 123, 114, 111, 117, 110, 100, 40, 36, 120, 45, 40, 36, 114, 43,
  36, 49, 41, 47, 50, 41, 125, 32, 121, 48, 61, 123, 114, 111, 117, 110,
  100, 40, 36, 121, 45, 40, 36, 114, 43, 36, 49, 41, 47, 50, 41, 125,
  32, 120, 49, 61, 123, 114, 111, 117, 110, 100, 40, 36, 120, 43, 40, 36,
  114, 43, 36, 49, 41, 47, 50, 41, 125, 32, 121, 49, 61, 123, 114, 111,
  117, 110, 100, 40, 36, 121, 43, 40, 36, 114, 43, 36, 49, 41, 47, 50,
  41, 125, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 50, 93, 32,
  52, 44, 36, 120, 48, 44, 36, 121, 44, 36, 120, 44, 36, 121, 48, 44,
  36, 120, 49, 44, 36, 121, 44, 36, 120, 44, 36, 121, 49, 44, 49, 44,
  45, 49, 10, 45, 101, 110, 100, 105, 102, 10, 102, 97, 105, 108, 101, 100,
  61, 48, 10, 45, 101, 108, 115, 101, 10, 45, 61, 91, 45, 50, 93, 32,
  45, 49, 44, 36, 120, 44, 36, 121, 10, 102, 97, 105, 108, 101, 100, 61,
  123, 36, 102, 97, 105, 108, 101, 100, 43, 49, 125, 10, 45, 105, 102, 32,
  123, 36, 102, 97, 105, 108, 101, 100, 61, 61, 49, 48, 48, 125, 32, 102,
  97, 105, 108, 101, 100, 61, 48, 32, 45, 105, 102, 32, 36, 110, 111, 101,
  100, 103, 101, 115, 32, 110, 61, 45, 49, 32, 45, 101, 108, 115, 101, 32,
  110, 111, 101, 100, 103, 101, 115, 61, 49, 32, 45, 101, 110, 100, 105, 102,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 105,
  116, 61, 123, 36, 105, 116, 43, 49, 125, 10, 45, 105, 102, 32, 123, 33,
  40, 36, 105, 116, 37, 53, 48, 41, 125, 10, 112, 61, 123, 114, 111, 117,
  110, 100, 40, 49, 48, 48, 42, 40, 40, 36, 115, 117, 109, 103, 48, 45,
  64, 123, 45, 50, 44, 43, 125, 41, 47, 64, 123, 45, 50, 44, 119, 104,
  125, 41, 94, 51, 41, 125, 10, 45, 114, 112, 114, 111, 103, 114, 101, 115,
  115, 32, 36, 112, 32, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34,
  92, 114, 32, 32, 34, 36, 112, 37, 32, 45, 118, 32, 45, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123, 36, 110, 62,
  61, 48, 125, 10, 45, 114, 109, 91, 45, 51, 44, 45, 50, 93, 32, 45,
  114, 112, 114, 111, 103, 114, 101, 115, 115, 32, 45, 49, 10, 45, 98, 108,
  101, 110, 100, 32, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97, 103, 101,
  48, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 99, 111, 108, 111, 114, 95,
  101, 108, 108, 105, 112, 115, 101, 115, 32, 58, 32, 95, 99, 111, 117, 110,
  116, 62, 48, 44, 95, 114, 97, 100, 105, 117, 115, 62, 61, 48, 44, 95,
  111, 112, 97, 99, 105, 116, 121, 62, 61, 48, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 65, 100, 100, 32, 114, 97, 110, 100, 111, 109, 32, 99,
  111, 108, 111, 114, 32, 101, 108, 108, 105, 112, 115, 101, 115, 32, 116, 111,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117,
  108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 99, 111, 117, 110,
  116, 61, 52, 48, 48, 39, 44, 32, 39, 114, 97, 100, 105, 117, 115, 61,
  53, 39, 32, 97, 110, 100, 32, 39, 111, 112, 97, 99, 105, 116, 121, 61,
  48, 46, 49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 99, 111, 108,
  111, 114, 95, 101, 108, 108, 105, 112, 115, 101, 115, 32, 44, 44, 48, 46,
  49, 53, 10, 99, 111, 108, 111, 114, 95, 101, 108, 108, 105, 112, 115, 101,
  115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 52,
  48, 48, 125, 44, 36, 123, 50, 61, 53, 125, 44, 36, 123, 51, 61, 48,
  46, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 100, 100,
  32, 36, 49, 32, 114, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111, 114,
  32, 101, 108, 108, 105, 112, 115, 101, 115, 32, 116, 111, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 109, 97, 120, 105, 109,
  117, 109, 32, 114, 97, 100, 105, 117, 115, 32, 36, 50, 32, 97, 110, 100,
  32, 111, 112, 97, 99, 105, 116, 121, 32, 36, 49, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 32, 45, 101,
  108, 108, 105, 112, 115, 101, 32, 123, 63, 40, 48, 44, 49, 48, 48, 41,
  125, 37, 44, 123, 63, 40, 48, 44, 49, 48, 48, 41, 125, 37, 44, 123,
  63, 40, 48, 44, 36, 50, 41, 125, 37, 44, 123, 63, 40, 48, 44, 36,
  50, 41, 125, 37, 44, 123, 63, 40, 48, 44, 51, 54, 48, 41, 125, 44,
  36, 51, 44, 123, 63, 40, 54, 48, 44, 50, 53, 53, 41, 125, 44, 123,
  63, 40, 54, 48, 44, 50, 53, 53, 41, 125, 44, 123, 63, 40, 54, 48,
  44, 50, 53, 53, 41, 125, 44, 50, 53, 53, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 99, 117, 98,
  105, 115, 109, 32, 58, 32, 95, 100, 101, 110, 115, 105, 116, 121, 62, 61,
  48, 44, 48, 60, 61, 95, 116, 104, 105, 99, 107, 110, 101, 115, 115, 60,
  61, 53, 48, 44, 95, 109, 97, 120, 95, 97, 110, 103, 108, 101, 44, 95,
  111, 112, 97, 99, 105, 116, 121, 44, 95, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  65, 112, 112, 108, 121, 32, 99, 117, 98, 105, 115, 109, 32, 101, 102, 102,
  101, 99, 116, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58,
  32, 39, 100, 101, 110, 115, 105, 116, 121, 61, 53, 48, 39, 44, 32, 39,
  116, 104, 105, 99, 107, 110, 101, 115, 115, 61, 49, 48, 39, 44, 32, 39,
  109, 97, 120, 95, 97, 110, 103, 108, 101, 61, 55, 53, 39, 44, 32, 39,
  111, 112, 97, 99, 105, 116, 121, 61, 48, 46, 55, 39, 32, 97, 110, 100,
  32, 39, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 48, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 99, 117, 98, 105, 115, 109, 32, 44,
  10, 99, 117, 98, 105, 115, 109, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 34, 36, 123, 49, 61, 53, 48, 125, 62, 61, 48, 32, 38, 38, 32,
  36, 123, 50, 61, 49, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 50,
  60, 61, 53, 48, 32, 38, 38, 32, 36, 123, 53, 61, 48, 125, 62, 61,
  48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 55, 53, 125,
  44, 36, 123, 52, 61, 48, 46, 55, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 117, 98, 105, 115, 109, 32,
  101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 119, 105, 116, 104, 32, 100, 101, 110, 115, 105, 116, 121, 32,
  36, 49, 44, 32, 116, 104, 105, 99, 107, 110, 101, 115, 115, 32, 36, 50,
  44, 32, 109, 97, 120, 105, 109, 117, 109, 32, 97, 110, 103, 108, 101, 32,
  36, 51, 32, 100, 101, 103, 46, 44, 32, 111, 112, 97, 99, 105, 116, 121,
  32, 36, 52, 32, 97, 110, 100, 32, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 36, 53, 46, 34, 10, 45, 105, 102, 32, 123, 34, 33, 36,
  49, 32, 124, 124, 32, 33, 36, 50, 32, 124, 124, 32, 33, 36, 51, 32,
  124, 124, 32, 33, 36, 52, 34, 125, 32, 45, 114, 101, 116, 117, 114, 110,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119,
  61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 32, 115, 61, 123, 115, 125,
  10, 80, 61, 123, 114, 111, 117, 110, 100, 40, 36, 50, 42, 109, 97, 120,
  40, 119, 44, 104, 41, 47, 50, 48, 48, 41, 125, 10, 78, 61, 123, 114,
  111, 117, 110, 100, 40, 49, 46, 53, 42, 36, 49, 42, 119, 42, 104, 47,
  40, 52, 42, 36, 80, 41, 47, 49, 48, 48, 41, 125, 10, 40, 123, 39,
  67, 73, 109, 103, 51, 100, 39, 125, 41, 32, 45, 43, 91, 45, 49, 93,
  32, 48, 46, 53, 32, 40, 123, 52, 42, 36, 78, 125, 59, 36, 78, 41,
  10, 49, 44, 36, 78, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32,
  36, 80, 44, 123, 36, 119, 45, 49, 45, 36, 80, 125, 32, 45, 45, 114,
  97, 110, 100, 91, 45, 49, 93, 32, 36, 80, 44, 123, 36, 104, 45, 49,
  45, 36, 80, 125, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120,
  32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 10, 45, 45, 43, 91,
  45, 49, 93, 32, 39, 45, 36, 80, 44, 45, 36, 80, 39, 32, 45, 45,
  43, 91, 45, 50, 93, 32, 39, 36, 80, 44, 45, 36, 80, 39, 32, 45,
  45, 43, 91, 45, 51, 93, 32, 39, 36, 80, 44, 36, 80, 39, 32, 45,
  45, 43, 91, 45, 52, 93, 32, 39, 45, 36, 80, 44, 36, 80, 39, 10,
  45, 97, 91, 45, 52, 45, 45, 49, 93, 32, 120, 32, 45, 105, 91, 45,
  50, 93, 32, 40, 49, 50, 44, 48, 44, 49, 44, 50, 44, 51, 59, 49,
  50, 44, 123, 52, 42, 40, 36, 78, 45, 49, 41, 125, 44, 123, 52, 42,
  40, 36, 78, 45, 49, 41, 43, 49, 125, 44, 123, 52, 42, 40, 36, 78,
  45, 49, 41, 43, 50, 125, 44, 123, 52, 42, 40, 36, 78, 45, 49, 41,
  43, 51, 125, 41, 10, 45, 114, 91, 45, 50, 93, 32, 53, 44, 36, 78,
  44, 49, 44, 49, 44, 51, 32, 45, 114, 111, 117, 110, 100, 91, 45, 50,
  93, 32, 49, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 10,
  49, 44, 36, 78, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 123,
  50, 50, 53, 45, 36, 51, 125, 44, 123, 50, 50, 53, 43, 36, 51, 125,
  32, 45, 42, 91, 45, 49, 93, 32, 123, 112, 105, 47, 49, 56, 48, 125,
  10, 45, 45, 115, 105, 110, 91, 45, 49, 93, 32, 45, 99, 111, 115, 91,
  45, 50, 93, 32, 45, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 91,
  45, 51, 93, 32, 45, 97, 91, 45, 52, 45, 45, 51, 93, 32, 120, 32,
  45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 122, 91, 45,
  52, 44, 45, 50, 44, 45, 49, 93, 32, 48, 44, 50, 32, 45, 45, 42,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 49, 32, 45, 97, 91, 45, 52,
  45, 45, 49, 93, 32, 120, 32, 45, 42, 91, 45, 49, 93, 32, 123, 115,
  113, 114, 116, 40, 50, 41, 42, 36, 80, 125, 10, 45, 114, 91, 45, 51,
  93, 32, 52, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44,
  48, 44, 50, 32, 45, 43, 91, 45, 51, 44, 45, 49, 93, 10, 40, 45,
  49, 50, 56, 59, 36, 119, 59, 36, 104, 59, 36, 115, 41, 32, 45, 45,
  98, 91, 48, 93, 32, 36, 53, 10, 45, 105, 102, 32, 123, 36, 78, 62,
  49, 125, 32, 52, 44, 123, 36, 78, 45, 49, 125, 44, 49, 44, 49, 44,
  45, 49, 50, 56, 44, 48, 44, 48, 44, 48, 32, 45, 101, 110, 100, 105,
  102, 10, 49, 44, 36, 78, 44, 49, 44, 49, 44, 49, 10, 45, 121, 91,
  49, 45, 45, 49, 93, 32, 45, 97, 91, 49, 45, 45, 49, 93, 32, 121,
  32, 45, 114, 118, 51, 100, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123,
  36, 52, 62, 61, 49, 125, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100,
  91, 48, 93, 32, 91, 49, 93, 44, 48, 44, 48, 44, 48, 44, 49, 44,
  50, 44, 48, 44, 48, 32, 45, 114, 109, 91, 49, 93, 10, 45, 101, 108,
  115, 101, 32, 45, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 48, 93,
  32, 91, 49, 93, 44, 48, 44, 48, 44, 48, 44, 49, 44, 50, 44, 48,
  44, 48, 32, 45, 114, 109, 91, 49, 93, 32, 45, 98, 108, 101, 110, 100,
  32, 97, 108, 112, 104, 97, 44, 36, 52, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 100, 114, 97, 119, 95, 119, 104,
  105, 114, 108, 32, 58, 32, 95, 97, 109, 112, 108, 105, 116, 117, 100, 101,
  62, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112,
  108, 121, 32, 119, 104, 105, 114, 108, 32, 100, 114, 97, 119, 105, 110, 103,
  32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108,
  117, 101, 58, 32, 39, 97, 109, 112, 108, 105, 116, 117, 100, 101, 61, 49,
  48, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 100, 114, 97, 119,
  95, 119, 104, 105, 114, 108, 32, 44, 10, 100, 114, 97, 119, 95, 119, 104,
  105, 114, 108, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  49, 48, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112,
  112, 108, 121, 32, 119, 104, 105, 114, 108, 32, 100, 114, 97, 119, 105, 110,
  103, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109, 97, 103,
  101, 36, 63, 32, 119, 105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117,
  100, 101, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 110, 111, 105, 115, 101, 91,
  45, 49, 93, 32, 55, 48, 44, 50, 32, 45, 42, 91, 45, 49, 93, 32,
  50, 53, 53, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32,
  45, 97, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 45, 115, 109, 111,
  111, 116, 104, 91, 45, 49, 93, 32, 36, 49, 44, 48, 44, 49, 44, 50,
  44, 50, 10, 45, 115, 113, 114, 116, 91, 45, 49, 93, 32, 45, 110, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 113, 117, 97, 108,
  105, 122, 101, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  100, 114, 97, 119, 105, 110, 103, 32, 58, 32, 95, 97, 109, 112, 108, 105,
  116, 117, 100, 101, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 65, 112, 112, 108, 121, 32, 100, 114, 97, 119, 105, 110, 103, 32, 101,
  102, 102, 101, 99, 116, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  58, 32, 39, 97, 109, 112, 108, 105, 116, 117, 100, 101, 61, 50, 48, 48,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 100, 114, 97, 119, 105, 110,
  103, 32, 44, 10, 100, 114, 97, 119, 105, 110, 103, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 49, 61, 50, 48, 48, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 100, 114, 97, 119,
  105, 110, 103, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 119, 105, 116, 104, 32, 97, 109, 112, 108, 105,
  116, 117, 100, 101, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32,
  45, 108, 91, 48, 93, 32, 45, 116, 111, 95, 114, 103, 98, 10, 45, 115,
  109, 111, 111, 116, 104, 32, 36, 49, 44, 48, 46, 50, 44, 49, 44, 51,
  44, 51, 32, 45, 98, 32, 50, 32, 45, 115, 104, 97, 114, 112, 101, 110,
  32, 49, 48, 48, 48, 32, 91, 48, 93, 10, 45, 114, 91, 48, 93, 32,
  50, 48, 44, 50, 48, 44, 49, 44, 51, 44, 50, 32, 45, 101, 113, 117,
  97, 108, 105, 122, 101, 91, 48, 93, 32, 45, 105, 110, 100, 101, 120, 91,
  49, 93, 32, 91, 48, 93, 44, 49, 44, 49, 10, 45, 110, 109, 91, 49,
  93, 32, 64, 123, 48, 44, 110, 125, 44, 49, 32, 45, 114, 109, 91, 48,
  93, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119,
  32, 58, 32, 95, 111, 102, 102, 115, 101, 116, 95, 120, 91, 37, 93, 44,
  95, 111, 102, 102, 115, 101, 116, 95, 121, 91, 37, 93, 44, 95, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 91, 37, 93, 62, 61, 48, 44, 48,
  60, 61, 95, 99, 117, 114, 118, 97, 116, 117, 114, 101, 60, 61, 49, 44,
  95, 101, 120, 112, 97, 110, 100, 95, 115, 105, 122, 101, 61, 123, 32, 48,
  32, 124, 32, 49, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 114, 111, 112, 32, 115, 104, 97, 100, 111, 119, 32, 98, 101, 104, 105,
  110, 100, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 111, 102,
  102, 115, 101, 116, 95, 120, 61, 50, 48, 39, 44, 32, 39, 111, 102, 102,
  115, 101, 116, 95, 121, 61, 111, 102, 102, 115, 101, 116, 95, 120, 39, 44,
  32, 39, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 53, 39, 44,
  32, 39, 99, 117, 114, 118, 97, 116, 117, 114, 101, 61, 48, 39, 32, 97,
  110, 100, 32, 39, 101, 120, 112, 97, 110, 100, 95, 115, 105, 122, 101, 61,
  49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 100, 114, 111, 112, 95, 115,
  104, 97, 100, 111, 119, 32, 49, 48, 44, 50, 48, 44, 53, 44, 48, 46,
  53, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 32, 50, 48, 44,
  48, 32, 45, 100, 105, 115, 112, 108, 97, 121, 95, 114, 103, 98, 97, 10,
  100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119, 32, 58, 32, 45, 99,
  104, 101, 99, 107, 32, 34, 36, 123, 51, 61, 53, 125, 62, 61, 48, 32,
  38, 38, 32, 36, 123, 52, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32,
  36, 52, 60, 61, 49, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49,
  61, 50, 48, 125, 44, 36, 123, 50, 61, 36, 49, 125, 44, 36, 123, 53,
  61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 114, 111,
  112, 32, 115, 104, 97, 100, 111, 119, 32, 98, 101, 104, 105, 110, 100, 32,
  105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 111, 102,
  102, 115, 101, 116, 115, 32, 40, 36, 49, 44, 36, 50, 41, 44, 32, 115,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 51, 32, 97, 110, 100,
  32, 99, 117, 114, 118, 97, 116, 117, 114, 101, 32, 36, 52, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 116, 111, 95, 97, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 100, 120, 61,
  123, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110,
  116, 92, 32, 36, 49, 125, 44, 119, 42, 36, 49, 44, 36, 49, 41, 125,
  10, 100, 121, 61, 123, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101,
  114, 99, 101, 110, 116, 92, 32, 36, 50, 125, 44, 104, 42, 36, 50, 44,
  36, 50, 41, 125, 10, 115, 105, 103, 109, 97, 61, 123, 105, 102, 40, 64,
  123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 51,
  125, 44, 109, 97, 120, 40, 119, 44, 104, 41, 42, 36, 51, 44, 36, 51,
  41, 125, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 32, 115,
  61, 123, 115, 125, 32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  49, 48, 48, 37, 32, 99, 111, 111, 114, 100, 115, 61, 64, 123, 45, 97,
  117, 116, 111, 99, 114, 111, 112, 95, 99, 111, 111, 114, 100, 115, 91, 45,
  49, 93, 92, 32, 48, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  99, 114, 111, 112, 32, 36, 99, 111, 111, 114, 100, 115, 10, 45, 114, 32,
  123, 119, 43, 97, 98, 115, 40, 36, 100, 120, 41, 125, 44, 123, 104, 43,
  97, 98, 115, 40, 36, 100, 121, 41, 125, 44, 49, 44, 49, 48, 48, 37,
  44, 48, 44, 48, 44, 123, 105, 102, 40, 36, 100, 120, 62, 48, 44, 48,
  44, 49, 41, 125, 44, 123, 105, 102, 40, 36, 100, 121, 62, 48, 44, 48,
  44, 49, 41, 125, 32, 45, 114, 91, 45, 49, 93, 32, 123, 119, 43, 52,
  42, 36, 115, 105, 103, 109, 97, 125, 44, 123, 104, 43, 52, 42, 36, 115,
  105, 103, 109, 97, 125, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 91, 45, 49, 93, 32, 49, 48, 48, 37, 10, 45, 105, 102,
  32, 123, 33, 36, 52, 125, 32, 45, 115, 104, 105, 102, 116, 91, 45, 49,
  93, 32, 36, 100, 120, 44, 36, 100, 121, 10, 45, 101, 108, 115, 101, 10,
  40, 48, 59, 123, 112, 105, 125, 41, 32, 45, 114, 91, 45, 49, 93, 32,
  91, 45, 50, 93, 44, 51, 32, 45, 115, 105, 110, 91, 45, 49, 93, 32,
  45, 42, 91, 45, 49, 93, 32, 45, 36, 52, 32, 45, 43, 91, 45, 49,
  93, 32, 49, 32, 45, 42, 91, 45, 49, 93, 32, 36, 100, 120, 10, 40,
  48, 44, 123, 112, 105, 125, 41, 32, 45, 114, 91, 45, 49, 93, 32, 91,
  45, 50, 93, 44, 51, 32, 45, 115, 105, 110, 91, 45, 49, 93, 32, 45,
  42, 91, 45, 49, 93, 32, 45, 36, 52, 32, 45, 43, 91, 45, 49, 93,
  32, 49, 32, 45, 42, 91, 45, 49, 93, 32, 36, 100, 121, 10, 45, 97,
  91, 45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 119, 97, 114, 112, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 48, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 98,
  91, 45, 49, 93, 32, 36, 115, 105, 103, 109, 97, 44, 48, 10, 45, 114,
  91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 50, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 32, 45,
  109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 98, 108, 101, 110, 100, 32,
  97, 108, 112, 104, 97, 10, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115,
  91, 45, 49, 93, 32, 49, 48, 48, 37, 32, 45, 103, 101, 91, 45, 49,
  93, 32, 49, 32, 45, 42, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112,
  32, 48, 10, 45, 105, 102, 32, 123, 33, 36, 53, 125, 32, 36, 119, 44,
  36, 104, 44, 49, 44, 36, 115, 32, 45, 106, 91, 45, 49, 93, 32, 91,
  45, 50, 93, 44, 123, 97, 114, 103, 40, 49, 44, 36, 99, 111, 111, 114,
  100, 115, 41, 125, 44, 123, 97, 114, 103, 40, 50, 44, 36, 99, 111, 111,
  114, 100, 115, 41, 125, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 101, 108, 108,
  105, 112, 115, 105, 111, 110, 105, 115, 109, 32, 58, 32, 95, 82, 62, 48,
  91, 37, 93, 44, 95, 114, 62, 48, 91, 37, 93, 44, 95, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 62, 61, 48, 91, 37, 93, 44, 95, 111,
  112, 97, 99, 105, 116, 121, 44, 95, 111, 117, 116, 108, 105, 110, 101, 62,
  48, 44, 95, 100, 101, 110, 115, 105, 116, 121, 62, 48, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 101, 108, 108, 105,
  112, 115, 105, 111, 110, 105, 115, 109, 32, 102, 105, 108, 116, 101, 114, 32,
  116, 111, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 82, 61,
  49, 48, 39, 44, 32, 39, 114, 61, 51, 39, 44, 32, 39, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 61, 49, 37, 39, 44, 32, 39, 111, 112,
  97, 99, 105, 116, 121, 61, 48, 46, 55, 39, 44, 32, 39, 111, 117, 116,
  108, 105, 115, 101, 61, 56, 39, 32, 97, 110, 100, 32, 39, 100, 101, 110,
  115, 105, 116, 121, 61, 48, 46, 54, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 45, 101, 108, 108, 105, 112, 115, 105, 111, 110, 105, 115, 109, 32, 44,
  10, 101, 108, 108, 105, 112, 115, 105, 111, 110, 105, 115, 109, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 49, 48, 125, 62,
  48, 32, 38, 38, 32, 36, 123, 50, 61, 51, 125, 62, 48, 32, 38, 38,
  32, 36, 123, 53, 61, 56, 125, 62, 48, 32, 38, 38, 32, 36, 123, 54,
  61, 48, 46, 54, 125, 62, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 51, 61, 49, 37, 125, 44, 36, 123, 52, 61, 48, 46, 55, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 101,
  108, 108, 105, 112, 115, 105, 111, 110, 105, 115, 109, 32, 102, 105, 108, 116,
  101, 114, 32, 116, 111, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119,
  105, 116, 104, 32, 114, 97, 100, 105, 105, 32, 40, 36, 49, 44, 36, 50,
  41, 44, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 51,
  44, 32, 111, 112, 97, 99, 105, 116, 121, 32, 36, 52, 32, 97, 110, 100,
  32, 111, 117, 116, 108, 105, 110, 101, 32, 36, 53, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45,
  108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 103, 91, 45, 49, 93,
  32, 120, 121, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32,
  45, 98, 91, 45, 49, 93, 32, 36, 51, 32, 45, 111, 114, 105, 101, 110,
  116, 97, 116, 105, 111, 110, 91, 45, 49, 93, 10, 45, 115, 104, 91, 45,
  49, 93, 32, 48, 44, 48, 32, 45, 115, 104, 91, 45, 50, 93, 32, 49,
  44, 49, 32, 45, 97, 116, 97, 110, 50, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 32, 45, 42, 91, 45, 49, 93, 32, 123, 49, 56, 48, 47, 112,
  105, 125, 32, 45, 43, 91, 45, 49, 93, 32, 57, 48, 32, 45, 114, 109,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 99, 104, 97, 110, 110, 101, 108,
  115, 91, 45, 49, 93, 32, 49, 44, 49, 10, 91, 45, 50, 93, 44, 91,
  45, 50, 93, 44, 49, 44, 91, 45, 50, 93, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 36, 54, 42, 119, 42, 104, 47, 109, 97, 120, 40, 36,
  49, 44, 36, 50, 41, 125, 10, 120, 121, 61, 123, 63, 40, 119, 41, 125,
  44, 123, 63, 40, 104, 41, 125, 10, 45, 101, 108, 108, 105, 112, 115, 101,
  91, 45, 49, 93, 32, 36, 120, 121, 44, 36, 49, 44, 36, 50, 44, 64,
  123, 45, 50, 44, 40, 36, 120, 121, 41, 125, 44, 36, 52, 44, 92, 10,
  64, 123, 45, 51, 44, 40, 36, 120, 121, 44, 48, 44, 48, 41, 125, 44,
  64, 123, 45, 51, 44, 40, 36, 120, 121, 44, 48, 44, 49, 41, 125, 44,
  64, 123, 45, 51, 44, 40, 36, 120, 121, 44, 48, 44, 50, 41, 125, 44,
  64, 123, 45, 51, 44, 40, 36, 120, 121, 44, 48, 44, 51, 41, 125, 10,
  45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 120, 121,
  44, 36, 49, 44, 36, 50, 44, 64, 123, 45, 50, 44, 40, 36, 120, 121,
  41, 125, 44, 36, 52, 44, 48, 120, 49, 44, 92, 10, 123, 64, 123, 45,
  51, 44, 40, 36, 120, 121, 44, 48, 44, 48, 41, 125, 47, 36, 53, 125,
  44, 123, 64, 123, 45, 51, 44, 40, 36, 120, 121, 44, 48, 44, 49, 41,
  125, 47, 36, 53, 125, 44, 123, 64, 123, 45, 51, 44, 40, 36, 120, 121,
  44, 48, 44, 50, 41, 125, 47, 36, 53, 125, 44, 123, 64, 123, 45, 51,
  44, 40, 36, 120, 121, 44, 48, 44, 51, 41, 125, 47, 36, 53, 125, 10,
  45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 110,
  91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 98, 108, 101, 110, 100,
  91, 45, 50, 44, 45, 49, 93, 32, 97, 108, 112, 104, 97, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 102, 105, 114, 101, 95, 101, 100, 103, 101, 115,
  32, 58, 32, 95, 101, 100, 103, 101, 115, 62, 61, 48, 44, 48, 60, 61,
  95, 97, 116, 116, 101, 110, 117, 97, 116, 105, 111, 110, 60, 61, 49, 44,
  95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 62, 61, 48, 44, 95,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 62, 61, 48, 44, 95, 110, 98,
  95, 102, 114, 97, 109, 101, 115, 62, 48, 44, 95, 115, 116, 97, 114, 116,
  105, 110, 103, 95, 102, 114, 97, 109, 101, 62, 61, 48, 44, 102, 114, 97,
  109, 101, 95, 115, 107, 105, 112, 62, 61, 48, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 71, 101, 110, 101, 114, 97, 116, 101, 32, 102, 105, 114,
  101, 32, 101, 102, 102, 101, 99, 116, 32, 102, 114, 111, 109, 32, 101, 100,
  103, 101, 115, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58,
  32, 39, 101, 100, 103, 101, 115, 61, 48, 46, 55, 39, 44, 32, 39, 97,
  116, 116, 101, 110, 117, 97, 116, 105, 111, 110, 61, 48, 46, 50, 53, 39,
  44, 32, 39, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 48, 46,
  53, 39, 44, 32, 39, 116, 104, 114, 101, 115, 104, 111, 108, 100, 61, 50,
  53, 39, 44, 32, 39, 110, 98, 95, 102, 114, 97, 109, 101, 115, 61, 49,
  39, 44, 32, 39, 115, 116, 97, 114, 116, 105, 110, 103, 95, 102, 114, 97,
  109, 101, 61, 50, 48, 39, 32, 97, 110, 100, 32, 39, 102, 114, 97, 109,
  101, 95, 115, 107, 105, 112, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 102, 105, 114, 101, 95, 101, 100, 103, 101, 115, 32, 44, 10, 102, 105,
  114, 101, 95, 101, 100, 103, 101, 115, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 34, 36, 123, 49, 61, 48, 46, 55, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 123, 50, 61, 48, 46, 50, 53, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 50, 60, 61, 49, 32, 38, 38, 32, 36, 123, 51, 61, 48,
  46, 53, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 52, 61, 50, 53,
  125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 53, 61, 49, 125, 62, 48,
  32, 38, 38, 32, 36, 123, 54, 61, 50, 48, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 123, 55, 61, 48, 125, 62, 61, 48, 34, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 71, 101, 110, 101, 114, 97, 116, 101, 32, 102,
  105, 114, 101, 32, 101, 102, 102, 101, 99, 116, 32, 102, 114, 111, 109, 32,
  101, 100, 103, 101, 115, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63,
  44, 32, 119, 105, 116, 104, 32, 101, 100, 103, 101, 115, 32, 36, 49, 44,
  32, 97, 116, 116, 101, 110, 117, 97, 116, 105, 111, 110, 32, 36, 50, 44,
  32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 51, 44, 32,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 36, 52, 44, 32, 34, 92,
  10, 34, 36, 53, 32, 102, 114, 97, 109, 101, 115, 44, 32, 115, 116, 97,
  114, 116, 105, 110, 103, 32, 102, 114, 97, 109, 101, 32, 36, 54, 32, 97,
  110, 100, 32, 102, 114, 97, 109, 101, 32, 115, 107, 105, 112, 32, 36, 55,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48,
  44, 110, 125, 10, 45, 110, 111, 114, 109, 32, 45, 45, 103, 114, 97, 100,
  105, 101, 110, 116, 95, 110, 111, 114, 109, 32, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 49, 32, 45, 114, 111, 117, 110, 100, 105, 102, 121, 91, 45,
  49, 93, 32, 36, 49, 32, 45, 102, 91, 48, 93, 32, 48, 10, 40, 48,
  44, 48, 44, 48, 59, 48, 44, 48, 44, 48, 59, 49, 44, 49, 44, 49,
  59, 48, 44, 49, 44, 48, 41, 32, 45, 42, 91, 45, 49, 93, 32, 123,
  40, 49, 45, 36, 50, 94, 52, 41, 47, 52, 125, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 36, 53, 42, 40, 49, 43, 36, 55, 41, 43, 36,
  54, 125, 10, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125,
  32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  32, 45, 42, 91, 45, 49, 93, 32, 91, 49, 93, 10, 45, 98, 91, 45,
  49, 93, 32, 36, 51, 10, 45, 105, 102, 32, 36, 52, 32, 45, 103, 101,
  91, 45, 49, 93, 32, 36, 52, 37, 32, 45, 101, 108, 115, 101, 32, 45,
  101, 113, 117, 97, 108, 105, 122, 101, 91, 45, 49, 93, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  10, 45, 106, 91, 48, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 49, 44, 91, 49, 93, 44, 49, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 99, 111, 114, 114, 101, 108, 97, 116, 101, 91, 48,
  93, 32, 91, 50, 93, 10, 45, 105, 102, 32, 123, 36, 62, 62, 61, 36,
  54, 34, 32, 38, 38, 32, 34, 40, 36, 62, 45, 36, 54, 41, 37, 40,
  36, 55, 43, 49, 41, 61, 61, 48, 125, 32, 91, 48, 93, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48,
  45, 50, 93, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 40, 48, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 94, 48, 44, 48,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 94, 48, 44, 48,
  44, 48, 44, 49, 50, 56, 44, 50, 53, 53, 41, 32, 45, 114, 91, 45,
  49, 93, 32, 50, 53, 54, 44, 49, 44, 49, 44, 51, 44, 51, 10, 45,
  109, 97, 112, 91, 94, 45, 49, 93, 32, 91, 45, 49, 93, 32, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 103, 108, 111, 119, 32, 58, 32, 95, 97, 109, 112, 108, 105, 116,
  117, 100, 101, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  65, 100, 100, 32, 115, 111, 102, 116, 32, 103, 108, 111, 119, 32, 111, 110,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117,
  108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 97, 109, 112, 108, 105,
  116, 117, 100, 101, 61, 49, 37, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  45, 103, 108, 111, 119, 32, 44, 10, 103, 108, 111, 119, 32, 58, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 37, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 100, 100, 32, 115, 111, 102, 116, 32, 103,
  108, 111, 119, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32,
  119, 105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 36,
  49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105,
  116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 45, 98, 91, 48, 93,
  32, 36, 49, 32, 45, 110, 91, 45, 49, 93, 32, 91, 48, 93, 32, 45,
  98, 108, 101, 110, 100, 95, 101, 100, 103, 101, 115, 91, 48, 44, 45, 49,
  93, 32, 49, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 104, 97, 108, 102, 116, 111, 110, 101, 32, 58, 32, 110, 98, 95, 108,
  101, 118, 101, 108, 115, 62, 61, 50, 44, 95, 115, 105, 122, 101, 95, 100,
  97, 114, 107, 62, 61, 50, 44, 95, 115, 105, 122, 101, 95, 98, 114, 105,
  103, 104, 116, 62, 61, 50, 44, 95, 115, 104, 97, 112, 101, 61, 123, 32,
  48, 61, 115, 113, 117, 97, 114, 101, 32, 124, 32, 49, 61, 100, 105, 97,
  109, 111, 110, 100, 32, 124, 32, 50, 61, 99, 105, 114, 99, 108, 101, 32,
  124, 32, 51, 61, 105, 110, 118, 45, 115, 113, 117, 97, 114, 101, 32, 124,
  32, 52, 61, 105, 110, 118, 45, 100, 105, 97, 109, 111, 110, 100, 32, 124,
  32, 53, 61, 105, 110, 118, 45, 99, 105, 114, 99, 108, 101, 32, 125, 44,
  95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 91, 37, 93, 62, 61,
  48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121,
  32, 104, 97, 108, 102, 116, 111, 110, 101, 32, 100, 105, 116, 104, 101, 114,
  105, 110, 103, 32, 116, 111, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58,
  32, 39, 110, 98, 95, 108, 101, 118, 101, 108, 115, 61, 53, 39, 44, 32,
  39, 115, 105, 122, 101, 95, 100, 97, 114, 107, 61, 56, 39, 44, 32, 39,
  115, 105, 122, 101, 95, 98, 114, 105, 103, 104, 116, 61, 56, 39, 44, 32,
  39, 115, 104, 97, 112, 101, 61, 53, 39, 32, 97, 110, 100, 32, 39, 115,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 115, 61, 48, 39, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 45, 104, 97, 108, 102, 116, 111, 110, 101, 32, 44,
  10, 104, 97, 108, 102, 116, 111, 110, 101, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 36, 123, 49, 61, 53, 125, 62, 61, 50, 32, 38, 38,
  32, 36, 123, 50, 61, 56, 125, 62, 61, 50, 32, 38, 38, 32, 36, 123,
  51, 61, 56, 125, 62, 61, 50, 32, 38, 38, 32, 36, 123, 53, 61, 48,
  125, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 52, 61,
  53, 125, 10, 45, 118, 32, 45, 32, 115, 48, 61, 34, 115, 113, 117, 97,
  114, 101, 34, 32, 115, 49, 61, 34, 100, 105, 97, 109, 111, 110, 100, 34,
  32, 115, 50, 61, 34, 99, 105, 114, 99, 108, 101, 34, 32, 115, 51, 61,
  34, 105, 110, 118, 45, 115, 113, 117, 97, 114, 101, 34, 32, 115, 52, 61,
  34, 105, 110, 118, 45, 100, 105, 97, 109, 111, 110, 100, 34, 32, 115, 53,
  61, 34, 105, 110, 118, 45, 99, 105, 114, 99, 108, 101, 34, 32, 45, 118,
  32, 43, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108,
  121, 32, 104, 97, 108, 102, 116, 111, 110, 101, 32, 100, 105, 116, 104, 101,
  114, 105, 110, 103, 32, 116, 111, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 119, 105, 116, 104, 32, 36, 49, 32, 108, 101, 118, 101, 108, 115, 44,
  32, 100, 97, 114, 107, 32, 115, 105, 122, 101, 32, 36, 51, 44, 32, 98,
  114, 105, 103, 104, 116, 32, 115, 105, 122, 101, 32, 36, 52, 44, 32, 34,
  36, 123, 115, 36, 52, 125, 34, 32, 115, 104, 97, 112, 101, 32, 97, 110,
  100, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 53, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 32, 99, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  40, 48, 44, 50, 53, 53, 41, 32, 45, 97, 32, 121, 32, 45, 113, 117,
  97, 110, 116, 105, 122, 101, 32, 36, 49, 44, 48, 32, 45, 114, 111, 119,
  115, 32, 48, 44, 123, 104, 45, 50, 125, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 36, 49, 10, 115, 61, 123, 114, 111, 117, 110, 100, 40, 40, 36,
  50, 42, 36, 60, 43, 36, 51, 42, 36, 62, 41, 47, 40, 36, 49, 45,
  49, 41, 41, 125, 10, 36, 115, 44, 36, 115, 32, 45, 61, 91, 45, 49,
  93, 32, 49, 44, 53, 48, 37, 44, 53, 48, 37, 32, 45, 100, 105, 115,
  116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 44, 123, 36, 52, 37,
  51, 125, 32, 45, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 53,
  48, 37, 44, 53, 48, 37, 44, 48, 44, 48, 44, 50, 32, 45, 109, 105,
  110, 91, 45, 50, 44, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 52,
  62, 61, 51, 125, 32, 45, 108, 116, 91, 45, 49, 93, 32, 123, 49, 48,
  48, 42, 36, 60, 47, 40, 36, 49, 45, 49, 46, 49, 41, 125, 37, 32,
  45, 42, 91, 45, 49, 93, 32, 123, 45, 50, 53, 53, 125, 32, 45, 43,
  91, 45, 49, 93, 32, 123, 50, 53, 53, 45, 36, 62, 125, 10, 45, 101,
  108, 115, 101, 32, 45, 108, 116, 91, 45, 49, 93, 32, 123, 49, 48, 48,
  42, 36, 62, 47, 40, 36, 49, 45, 49, 46, 49, 41, 125, 37, 32, 45,
  42, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 45, 91, 45, 49, 93,
  32, 36, 62, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 91, 45, 49,
  93, 32, 91, 45, 50, 93, 44, 48, 44, 50, 32, 45, 98, 91, 45, 49,
  93, 32, 36, 53, 32, 45, 45, 101, 113, 91, 45, 50, 93, 32, 36, 62,
  32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 43, 91, 45, 50,
  44, 45, 49, 93, 10, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 104, 97, 114, 100, 115, 107, 101, 116, 99, 104, 98, 119,
  32, 58, 32, 95, 97, 109, 112, 108, 105, 116, 117, 100, 101, 62, 61, 48,
  44, 95, 100, 101, 110, 115, 105, 116, 121, 62, 61, 48, 44, 95, 111, 112,
  97, 99, 105, 116, 121, 44, 48, 60, 61, 95, 101, 100, 103, 101, 95, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 60, 61, 49, 48, 48, 44, 95, 105,
  115, 95, 102, 97, 115, 116, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32,
  104, 97, 114, 100, 32, 66, 38, 87, 32, 115, 107, 101, 116, 99, 104, 32,
  101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117,
  101, 115, 58, 32, 39, 97, 109, 112, 108, 105, 116, 117, 100, 101, 61, 49,
  48, 48, 48, 39, 44, 32, 39, 115, 97, 109, 112, 108, 105, 110, 103, 61,
  51, 39, 44, 32, 39, 111, 112, 97, 99, 105, 116, 121, 61, 48, 46, 49,
  39, 44, 32, 39, 101, 100, 103, 101, 95, 116, 104, 114, 101, 115, 104, 111,
  108, 100, 61, 50, 48, 39, 32, 97, 110, 100, 32, 39, 105, 115, 95, 102,
  97, 115, 116, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 104,
  97, 114, 100, 115, 107, 101, 116, 99, 104, 98, 119, 32, 50, 48, 48, 44,
  55, 48, 44, 48, 46, 49, 44, 49, 48, 32, 45, 109, 101, 100, 105, 97,
  110, 91, 45, 49, 93, 32, 50, 32, 45, 45, 108, 111, 99, 97, 108, 32,
  45, 114, 101, 118, 101, 114, 115, 101, 32, 45, 98, 108, 117, 114, 91, 45,
  49, 93, 32, 51, 32, 45, 98, 108, 101, 110, 100, 32, 111, 118, 101, 114,
  108, 97, 121, 32, 45, 101, 110, 100, 108, 111, 99, 97, 108, 10, 104, 97,
  114, 100, 115, 107, 101, 116, 99, 104, 98, 119, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 49, 61, 51, 48, 48, 125, 44, 36, 123, 50, 61,
  53, 48, 125, 44, 36, 123, 51, 61, 48, 46, 49, 125, 44, 36, 123, 52,
  61, 50, 48, 125, 44, 36, 123, 53, 61, 48, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 104, 97, 114, 100, 32,
  66, 38, 87, 32, 115, 107, 101, 116, 99, 104, 32, 101, 102, 102, 101, 99,
  116, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105,
  116, 104, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 36, 49, 44,
  32, 100, 101, 110, 115, 105, 116, 121, 32, 36, 50, 44, 32, 111, 112, 97,
  99, 105, 116, 121, 32, 36, 51, 32, 97, 110, 100, 32, 101, 100, 103, 101,
  32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 36, 52, 46, 34, 10,
  45, 105, 102, 32, 123, 33, 36, 50, 125, 32, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 48, 32, 45, 102, 32, 50, 53, 53, 32, 45, 114, 101,
  116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45,
  32, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 110, 32, 48,
  44, 49, 10, 45, 105, 102, 32, 36, 53, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64,
  123, 48, 44, 110, 125, 10, 45, 103, 32, 120, 121, 32, 45, 114, 118, 32,
  45, 42, 91, 45, 50, 93, 32, 45, 49, 32, 45, 97, 32, 99, 10, 45,
  105, 102, 32, 36, 52, 32, 45, 45, 110, 111, 114, 109, 32, 45, 103, 101,
  91, 45, 49, 93, 32, 36, 52, 37, 32, 45, 42, 32, 45, 101, 110, 100,
  105, 102, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49,
  44, 50, 53, 53, 32, 45, 113, 117, 105, 118, 101, 114, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 44, 123, 109, 97, 120, 40, 49, 44, 49, 48, 45,
  36, 50, 47, 54, 41, 125, 44, 36, 49, 44, 48, 44, 36, 51, 32, 45,
  114, 109, 91, 45, 50, 93, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108,
  115, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 119,
  61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 32, 45, 103, 32, 120, 121,
  32, 45, 114, 118, 32, 45, 42, 91, 45, 50, 93, 32, 45, 49, 32, 45,
  97, 32, 99, 32, 45, 42, 32, 36, 49, 10, 45, 45, 110, 111, 114, 109,
  32, 45, 103, 101, 91, 45, 49, 93, 32, 36, 52, 37, 32, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49,
  93, 32, 36, 50, 44, 50, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93,
  10, 45, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 51, 100, 91, 45,
  49, 93, 32, 45, 115, 51, 100, 91, 45, 49, 93, 32, 45, 114, 109, 91,
  45, 54, 45, 45, 53, 44, 45, 51, 45, 45, 49, 93, 32, 45, 114, 91,
  45, 49, 93, 32, 51, 44, 123, 104, 47, 51, 125, 44, 49, 44, 49, 44,
  45, 49, 32, 45, 115, 91, 45, 49, 93, 32, 120, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10,
  45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48,
  44, 48, 32, 45, 45, 45, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32,
  45, 43, 91, 45, 51, 44, 45, 50, 93, 32, 45, 115, 91, 45, 50, 44,
  45, 49, 93, 32, 99, 10, 45, 105, 91, 45, 51, 93, 32, 49, 44, 123,
  104, 125, 32, 49, 44, 123, 104, 125, 32, 45, 97, 91, 45, 54, 45, 45,
  49, 93, 32, 120, 10, 45, 105, 91, 45, 50, 93, 32, 40, 123, 39, 67,
  73, 109, 103, 51, 100, 39, 125, 41, 32, 45, 105, 91, 45, 50, 93, 32,
  40, 123, 50, 42, 104, 125, 44, 123, 104, 125, 41, 10, 49, 44, 123, 104,
  125, 44, 49, 44, 49, 44, 50, 32, 49, 44, 123, 104, 125, 44, 49, 44,
  49, 44, 50, 42, 121, 32, 45, 45, 43, 91, 45, 49, 93, 32, 49, 32,
  45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 120, 10, 51, 44, 123, 104,
  125, 32, 49, 44, 123, 104, 125, 44, 49, 44, 49, 44, 36, 51, 32, 45,
  121, 91, 45, 54, 45, 45, 49, 93, 32, 45, 97, 91, 45, 54, 45, 45,
  49, 93, 32, 121, 10, 36, 119, 44, 36, 104, 44, 49, 44, 49, 44, 50,
  53, 53, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 44, 49, 44, 49, 44,
  48, 44, 48, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 110, 109, 32,
  36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 45, 101, 110, 100, 105, 102, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 104, 101, 97, 114, 116, 115, 32, 58, 32, 95, 100,
  101, 110, 115, 105, 116, 121, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 65, 112, 112, 108, 121, 32, 104, 101, 97, 114, 116, 32, 101,
  102, 102, 101, 99, 116, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  58, 32, 39, 100, 101, 110, 115, 105, 116, 121, 61, 49, 48, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 45, 104, 101, 97, 114, 116, 115, 32, 44, 10,
  104, 101, 97, 114, 116, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 49, 61, 49, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  65, 112, 112, 108, 121, 32, 104, 101, 97, 114, 116, 32, 102, 105, 108, 116,
  101, 114, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119,
  105, 116, 104, 32, 100, 101, 110, 115, 105, 116, 121, 32, 36, 49, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 44, 49, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 36,
  49, 44, 50, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32,
  45, 110, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 42, 91, 45, 49,
  44, 45, 50, 93, 32, 45, 95, 104, 101, 97, 114, 116, 57, 120, 55, 10,
  45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 121, 32, 45, 100,
  105, 108, 97, 116, 101, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 95, 104, 101, 97, 114, 116, 57, 120,
  55, 32, 58, 10, 40, 48, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48,
  44, 49, 44, 49, 44, 48, 59, 49, 44, 49, 44, 49, 44, 49, 44, 48,
  44, 49, 44, 49, 44, 49, 44, 49, 59, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 59, 48, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 48, 59, 48, 44, 48,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 48, 44, 48, 59, 48,
  44, 48, 44, 48, 44, 49, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48,
  59, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48,
  44, 48, 41, 10, 35, 64, 103, 109, 105, 99, 32, 104, 111, 117, 103, 104,
  115, 107, 101, 116, 99, 104, 98, 119, 32, 58, 32, 95, 100, 101, 110, 115,
  105, 116, 121, 62, 61, 48, 44, 95, 114, 97, 100, 105, 117, 115, 62, 48,
  44, 48, 60, 61, 95, 116, 104, 114, 101, 115, 104, 111, 108, 100, 60, 61,
  49, 48, 48, 44, 48, 60, 61, 95, 111, 112, 97, 99, 105, 116, 121, 60,
  61, 49, 44, 95, 118, 111, 116, 101, 115, 105, 122, 101, 91, 37, 93, 62,
  48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121,
  32, 104, 111, 117, 103, 104, 32, 66, 38, 87, 32, 115, 107, 101, 116, 99,
  104, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 100, 101, 110, 115, 105, 116, 121, 61, 56,
  39, 44, 32, 39, 114, 97, 100, 105, 117, 115, 61, 53, 39, 44, 32, 39,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 61, 56, 48, 39, 44, 32, 39,
  111, 112, 97, 99, 105, 116, 121, 61, 48, 46, 49, 39, 32, 97, 110, 100,
  32, 39, 118, 111, 116, 101, 115, 105, 122, 101, 61, 49, 48, 48, 37, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 45, 104, 111, 117, 103, 104, 115, 107,
  101, 116, 99, 104, 98, 119, 32, 44, 10, 104, 111, 117, 103, 104, 115, 107,
  101, 116, 99, 104, 98, 119, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 36, 123, 49, 61, 56, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123,
  50, 61, 53, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 51, 61, 56,
  48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 51, 60, 61, 49, 48, 48,
  32, 38, 38, 32, 36, 123, 52, 61, 48, 46, 49, 125, 62, 61, 48, 32,
  38, 38, 32, 36, 52, 60, 61, 49, 32, 38, 38, 32, 36, 123, 53, 61,
  49, 48, 48, 37, 125, 62, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 65, 112, 112, 108, 121, 32, 104, 111, 117, 103, 104, 32, 66, 38,
  87, 32, 115, 107, 101, 116, 99, 104, 32, 101, 102, 102, 101, 99, 116, 32,
  111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104,
  32, 100, 101, 110, 115, 105, 116, 121, 32, 36, 49, 44, 32, 114, 97, 100,
  105, 117, 115, 32, 36, 50, 44, 32, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 32, 36, 51, 44, 32, 111, 112, 97, 99, 105, 116, 121, 32, 36, 52,
  32, 97, 110, 100, 32, 118, 111, 116, 101, 115, 105, 122, 101, 32, 36, 53,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 108, 117, 109, 105, 110, 97, 110,
  99, 101, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 114,
  101, 115, 61, 123, 114, 111, 117, 110, 100, 40, 105, 102, 40, 64, 123, 45,
  105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 53, 125, 44,
  36, 53, 42, 109, 97, 120, 40, 119, 44, 104, 41, 44, 36, 53, 41, 41,
  125, 32, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 32, 114, 104,
  111, 109, 97, 120, 61, 123, 115, 113, 114, 116, 40, 119, 94, 50, 43, 104,
  94, 50, 41, 47, 50, 125, 10, 45, 104, 111, 117, 103, 104, 32, 36, 114,
  101, 115, 44, 36, 114, 101, 115, 32, 45, 110, 32, 48, 44, 50, 53, 53,
  10, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 108, 111, 99, 97,
  108, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 32, 45, 103, 101, 91,
  45, 49, 93, 32, 36, 51, 37, 32, 45, 112, 111, 105, 110, 116, 99, 108,
  111, 117, 100, 51, 100, 91, 45, 49, 93, 10, 45, 115, 51, 100, 91, 45,
  49, 93, 32, 45, 114, 109, 91, 45, 54, 45, 45, 53, 44, 45, 51, 45,
  45, 49, 93, 32, 45, 114, 91, 45, 49, 93, 32, 51, 44, 123, 104, 47,
  51, 125, 44, 49, 44, 49, 44, 45, 49, 32, 45, 99, 111, 108, 117, 109,
  110, 115, 91, 45, 49, 93, 32, 48, 44, 49, 10, 45, 115, 91, 45, 49,
  93, 32, 120, 44, 50, 10, 45, 42, 91, 45, 50, 93, 32, 123, 50, 42,
  112, 105, 47, 36, 114, 101, 115, 125, 10, 45, 42, 91, 45, 49, 93, 32,
  123, 36, 114, 104, 111, 109, 97, 120, 47, 36, 114, 101, 115, 125, 10, 45,
  45, 99, 111, 115, 91, 45, 50, 93, 32, 45, 42, 91, 45, 49, 93, 32,
  91, 45, 50, 93, 32, 45, 43, 91, 45, 49, 93, 32, 123, 36, 119, 47,
  50, 125, 10, 45, 45, 115, 105, 110, 91, 45, 51, 93, 32, 45, 42, 91,
  45, 49, 93, 32, 91, 45, 51, 93, 32, 45, 43, 91, 45, 49, 93, 32,
  123, 36, 104, 47, 50, 125, 10, 45, 114, 109, 91, 45, 51, 93, 10, 45,
  105, 91, 45, 51, 93, 32, 91, 45, 51, 93, 10, 45, 99, 111, 115, 91,
  45, 52, 93, 32, 45, 115, 105, 110, 91, 45, 51, 93, 32, 45, 42, 91,
  45, 52, 44, 45, 51, 93, 32, 49, 48, 48, 48, 48, 10, 45, 45, 43,
  91, 45, 50, 93, 32, 91, 45, 51, 93, 10, 45, 45, 45, 91, 45, 50,
  93, 32, 91, 45, 53, 93, 10, 45, 45, 91, 45, 52, 93, 32, 91, 45,
  53, 93, 10, 45, 43, 91, 45, 51, 93, 32, 91, 45, 54, 93, 10, 45,
  114, 109, 91, 45, 54, 44, 45, 53, 93, 10, 45, 105, 91, 45, 51, 93,
  32, 49, 44, 123, 104, 125, 32, 49, 44, 123, 104, 125, 32, 45, 97, 91,
  45, 54, 45, 45, 49, 93, 32, 120, 10, 45, 105, 91, 45, 50, 93, 32,
  40, 123, 39, 67, 73, 109, 103, 51, 100, 39, 125, 41, 32, 45, 105, 91,
  45, 50, 93, 32, 40, 123, 50, 42, 104, 125, 44, 123, 104, 125, 41, 10,
  49, 44, 123, 104, 125, 44, 49, 44, 49, 44, 50, 32, 49, 44, 123, 104,
  125, 44, 49, 44, 49, 44, 50, 42, 121, 32, 45, 45, 43, 91, 45, 49,
  93, 32, 49, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 120, 10,
  51, 44, 123, 104, 125, 44, 49, 44, 49, 44, 48, 32, 49, 44, 123, 104,
  125, 44, 49, 44, 49, 44, 36, 52, 10, 45, 121, 91, 45, 54, 45, 45,
  49, 93, 32, 45, 97, 91, 45, 54, 45, 45, 49, 93, 32, 121, 10, 36,
  119, 44, 36, 104, 44, 49, 44, 49, 44, 50, 53, 53, 32, 45, 111, 98,
  106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44,
  48, 44, 48, 44, 48, 44, 49, 44, 49, 44, 48, 44, 48, 32, 45, 114,
  109, 91, 45, 50, 93, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 108, 105, 103, 104, 116, 114, 97, 121,
  115, 32, 58, 32, 49, 48, 48, 60, 61, 95, 100, 101, 110, 115, 105, 116,
  121, 60, 61, 48, 44, 95, 99, 120, 44, 95, 99, 121, 44, 95, 114, 97,
  121, 95, 108, 101, 110, 103, 116, 104, 62, 61, 48, 44, 95, 114, 97, 121,
  95, 97, 116, 116, 101, 110, 117, 97, 116, 105, 111, 110, 62, 61, 48, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 71, 101, 110, 101, 114, 97, 116,
  101, 32, 114, 97, 121, 32, 108, 105, 103, 104, 116, 115, 32, 102, 114, 111,
  109, 32, 116, 104, 101, 32, 101, 100, 103, 101, 115, 32, 111, 102, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116,
  115, 32, 118, 97, 108, 117, 101, 115, 32, 58, 32, 39, 100, 101, 110, 115,
  105, 116, 121, 61, 53, 48, 37, 39, 44, 32, 39, 99, 120, 61, 48, 46,
  53, 39, 44, 32, 39, 99, 121, 61, 48, 46, 53, 39, 44, 32, 39, 114,
  97, 121, 95, 108, 101, 110, 103, 116, 104, 61, 48, 46, 57, 39, 32, 97,
  110, 100, 32, 39, 114, 97, 121, 95, 97, 116, 116, 101, 110, 117, 97, 116,
  105, 111, 110, 61, 48, 46, 53, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  45, 108, 105, 103, 104, 116, 114, 97, 121, 115, 32, 44, 32, 45, 43, 32,
  45, 99, 32, 48, 44, 50, 53, 53, 10, 108, 105, 103, 104, 116, 114, 97,
  121, 115, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49,
  61, 53, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 49, 60, 61, 49,
  48, 48, 32, 38, 38, 32, 36, 123, 52, 61, 49, 125, 32, 38, 38, 32,
  36, 123, 53, 61, 49, 125, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 50, 61, 48, 46, 53, 125, 44, 36, 123, 51, 61, 48, 46,
  53, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 71, 101, 110, 101,
  114, 97, 116, 101, 32, 114, 97, 121, 32, 108, 105, 103, 104, 116, 115, 32,
  102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105,
  116, 104, 32, 100, 101, 110, 115, 105, 116, 121, 32, 36, 49, 44, 32, 99,
  101, 110, 116, 101, 114, 32, 40, 36, 50, 44, 36, 51, 41, 44, 32, 114,
  97, 121, 32, 108, 101, 110, 103, 116, 104, 32, 36, 52, 32, 97, 110, 100,
  32, 97, 116, 116, 101, 110, 117, 97, 116, 105, 111, 110, 32, 36, 53, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 103, 114, 97, 100, 105, 101,
  110, 116, 95, 110, 111, 114, 109, 32, 45, 42, 32, 45, 49, 32, 45, 108,
  116, 32, 36, 49, 37, 32, 45, 101, 117, 99, 108, 105, 100, 101, 97, 110,
  50, 112, 111, 108, 97, 114, 32, 36, 50, 44, 36, 51, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 108, 111, 103, 50, 40, 119, 41, 125, 32, 45,
  45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 123, 50, 94, 36, 62,
  125, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 100, 111, 110,
  101, 10, 45, 102, 117, 110, 99, 116, 105, 111, 110, 49, 100, 32, 48, 46,
  53, 44, 48, 44, 49, 44, 123, 36, 52, 42, 119, 125, 44, 49, 44, 123,
  49, 43, 40, 36, 52, 43, 49, 45, 36, 53, 41, 42, 119, 125, 44, 48,
  32, 45, 114, 91, 45, 49, 93, 32, 64, 123, 45, 50, 44, 119, 125, 44,
  49, 44, 49, 44, 49, 44, 48, 10, 40, 49, 44, 123, 119, 125, 41, 32,
  45, 114, 91, 45, 49, 93, 32, 64, 123, 45, 50, 44, 119, 125, 44, 49,
  44, 49, 44, 49, 44, 51, 32, 45, 47, 91, 45, 50, 44, 45, 49, 93,
  10, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 42, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 112, 111, 108, 97, 114, 50, 101, 117,
  99, 108, 105, 100, 101, 97, 110, 32, 36, 50, 44, 36, 51, 32, 45, 110,
  32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 108,
  105, 103, 104, 116, 95, 114, 101, 108, 105, 101, 102, 32, 58, 32, 95, 97,
  109, 98, 105, 101, 110, 116, 95, 108, 105, 103, 104, 116, 44, 95, 115, 112,
  101, 99, 117, 108, 97, 114, 95, 108, 105, 103, 104, 116, 110, 101, 115, 115,
  44, 95, 115, 112, 101, 99, 117, 108, 97, 114, 95, 115, 105, 122, 101, 44,
  95, 108, 105, 103, 104, 116, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 44, 95, 100, 97, 114, 107, 110, 101, 115, 115, 44, 95, 120, 108, 44,
  95, 121, 108, 44, 95, 122, 108, 44, 95, 122, 115, 99, 97, 108, 101, 44,
  95, 111, 112, 97, 99, 105, 116, 121, 95, 98, 117, 109, 112, 109, 97, 112,
  61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 114, 101, 108, 105, 101, 102,
  32, 108, 105, 103, 104, 116, 32, 116, 111, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117,
  101, 115, 40, 115, 41, 32, 58, 32, 39, 97, 109, 98, 105, 101, 110, 116,
  95, 108, 105, 103, 104, 116, 61, 48, 46, 51, 39, 44, 32, 39, 115, 112,
  101, 99, 117, 108, 97, 114, 95, 108, 105, 103, 104, 116, 110, 101, 115, 115,
  61, 48, 46, 53, 39, 44, 32, 39, 115, 112, 101, 99, 117, 108, 97, 114,
  95, 115, 105, 122, 101, 61, 48, 46, 50, 39, 44, 32, 39, 100, 97, 114,
  107, 110, 101, 115, 115, 61, 48, 39, 44, 32, 39, 120, 108, 61, 48, 46,
  50, 39, 44, 32, 39, 121, 108, 61, 122, 108, 61, 48, 46, 53, 39, 44,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 122, 115, 99, 97, 108,
  101, 61, 49, 39, 44, 32, 39, 111, 112, 97, 99, 105, 116, 121, 61, 49,
  39, 32, 97, 110, 100, 32, 39, 111, 112, 97, 99, 105, 116, 121, 95, 98,
  117, 109, 112, 109, 97, 112, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 45, 98, 108, 117, 114, 32, 50, 32, 45, 108, 105, 103, 104, 116, 95,
  114, 101, 108, 105, 101, 102, 91, 45, 49, 93, 32, 48, 46, 51, 44, 52,
  44, 48, 46, 49, 44, 48, 10, 108, 105, 103, 104, 116, 95, 114, 101, 108,
  105, 101, 102, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  48, 46, 51, 125, 44, 36, 123, 50, 61, 48, 46, 53, 125, 44, 36, 123,
  51, 61, 48, 46, 50, 125, 44, 36, 123, 52, 61, 48, 125, 44, 36, 123,
  53, 61, 48, 46, 50, 125, 44, 36, 123, 54, 61, 48, 46, 53, 125, 44,
  36, 123, 55, 61, 48, 46, 53, 125, 44, 36, 123, 56, 61, 49, 125, 44,
  36, 123, 57, 61, 49, 125, 44, 36, 123, 49, 48, 61, 48, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 114, 101,
  108, 105, 101, 102, 32, 108, 105, 103, 104, 116, 32, 116, 111, 32, 105, 109,
  97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 40,
  123, 45, 36, 54, 125, 44, 123, 49, 45, 36, 54, 125, 59, 123, 45, 36,
  54, 125, 44, 123, 49, 45, 36, 54, 125, 94, 123, 45, 36, 55, 125, 44,
  123, 45, 36, 55, 125, 59, 123, 49, 45, 36, 55, 125, 44, 123, 49, 45,
  36, 55, 125, 94, 36, 56, 44, 36, 56, 59, 36, 56, 44, 36, 56, 41,
  32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50,
  93, 44, 49, 44, 51, 44, 51, 10, 45, 105, 102, 32, 36, 49, 48, 32,
  45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 50, 93, 32, 51,
  32, 45, 116, 111, 95, 114, 103, 98, 91, 45, 51, 93, 32, 45, 101, 108,
  115, 101, 32, 45, 45, 116, 111, 95, 114, 103, 98, 91, 45, 50, 93, 32,
  45, 110, 111, 114, 109, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 98, 91, 45, 49, 93, 32, 36, 53, 37, 32, 45, 103, 91, 45,
  49, 93, 32, 120, 121, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  49, 44, 49, 44, 36, 57, 32, 32, 45, 97, 91, 45, 51, 45, 45, 49,
  93, 32, 99, 10, 45, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 42, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 115, 91, 45, 49, 93, 32, 99, 32, 45, 43, 91, 45, 51,
  45, 45, 49, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45,
  61, 91, 45, 49, 93, 32, 49, 44, 123, 36, 54, 42, 49, 48, 48, 125,
  37, 44, 123, 36, 55, 42, 49, 48, 48, 125, 37, 32, 45, 100, 105, 115,
  116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 115, 113, 114,
  91, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 10, 45,
  47, 91, 45, 49, 93, 32, 123, 40, 36, 51, 42, 109, 97, 120, 40, 119,
  44, 104, 41, 41, 94, 50, 125, 32, 45, 101, 120, 112, 91, 45, 49, 93,
  32, 45, 42, 91, 45, 49, 93, 32, 36, 50, 32, 45, 43, 91, 45, 49,
  93, 32, 36, 49, 10, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  45, 91, 45, 49, 93, 32, 36, 52, 32, 45, 42, 91, 45, 49, 93, 32,
  64, 123, 45, 50, 44, 77, 125, 10, 45, 115, 112, 108, 105, 116, 95, 111,
  112, 97, 99, 105, 116, 121, 91, 48, 93, 32, 45, 43, 91, 48, 44, 45,
  49, 93, 32, 45, 97, 32, 99, 32, 45, 99, 32, 48, 44, 50, 53, 53,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 109, 111, 115, 97, 105, 99, 32,
  58, 32, 95, 100, 101, 110, 115, 105, 116, 121, 62, 61, 48, 44, 95, 101,
  100, 103, 101, 115, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 67, 114, 101, 97, 116, 101, 32, 114,
  97, 110, 100, 111, 109, 32, 109, 111, 115, 97, 105, 99, 32, 102, 114, 111,
  109, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 100, 101, 110,
  115, 105, 116, 121, 61, 48, 46, 56, 39, 32, 97, 110, 100, 32, 39, 101,
  100, 103, 101, 115, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45,
  109, 111, 115, 97, 105, 99, 32, 44, 10, 109, 111, 115, 97, 105, 99, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 46, 56, 125,
  44, 36, 123, 50, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 65, 112, 112, 108, 121, 32, 109, 111, 115, 97, 105, 99, 32, 101, 102,
  102, 101, 99, 116, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 119, 105, 116, 104, 32, 100, 101, 110, 115, 105, 116, 121, 32, 36, 49,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 108, 97, 98, 101, 108, 48,
  61, 123, 49, 43, 105, 109, 125, 32, 45, 43, 32, 36, 108, 97, 98, 101,
  108, 48, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 110, 111,
  105, 115, 101, 91, 45, 49, 93, 32, 123, 36, 49, 42, 50, 125, 44, 50,
  32, 45, 42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 100, 105,
  115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 42, 91,
  45, 49, 93, 32, 45, 49, 32, 45, 119, 97, 116, 101, 114, 115, 104, 101,
  100, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 123, 105, 102, 40, 36,
  50, 44, 48, 44, 49, 41, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 105, 102, 32, 36, 50, 32, 45, 45, 108, 91, 45, 49, 93, 32, 45,
  103, 116, 32, 48, 32, 45, 115, 32, 99, 32, 45, 97, 110, 100, 32, 45,
  101, 110, 100, 108, 32, 45, 45, 91, 45, 50, 93, 32, 36, 108, 97, 98,
  101, 108, 48, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 101,
  108, 115, 101, 32, 45, 45, 91, 45, 49, 93, 32, 36, 108, 97, 98, 101,
  108, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 111, 108, 100, 95, 112, 104, 111, 116, 111, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 111, 108, 100, 32, 112,
  104, 111, 116, 111, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 45, 111, 108, 100, 95, 112, 104, 111, 116, 111,
  10, 111, 108, 100, 95, 112, 104, 111, 116, 111, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 111, 108, 100, 32,
  112, 104, 111, 116, 111, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32,
  105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  110, 111, 105, 115, 101, 32, 50, 48, 32, 45, 98, 105, 108, 97, 116, 101,
  114, 97, 108, 32, 51, 48, 44, 54, 48, 32, 45, 98, 32, 50, 32, 45,
  115, 104, 97, 114, 112, 101, 110, 32, 49, 48, 48, 32, 45, 102, 114, 97,
  109, 101, 95, 102, 117, 122, 122, 121, 32, 50, 48, 44, 50, 48, 44, 54,
  44, 51, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 115, 104, 97, 100,
  111, 119, 95, 112, 97, 116, 99, 104, 32, 48, 46, 55, 53, 32, 45, 110,
  32, 48, 44, 50, 53, 53, 32, 45, 115, 101, 112, 105, 97, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 112, 101, 110, 99, 105, 108,
  98, 119, 32, 58, 32, 95, 115, 105, 122, 101, 62, 61, 48, 44, 95, 97,
  109, 112, 108, 105, 116, 117, 100, 101, 62, 61, 48, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 66, 38, 87, 32, 112,
  101, 110, 99, 105, 108, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108,
  116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 115, 105, 122, 101, 61,
  48, 46, 51, 39, 32, 97, 110, 100, 32, 39, 97, 109, 112, 108, 105, 116,
  117, 100, 101, 61, 54, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45,
  112, 101, 110, 99, 105, 108, 98, 119, 32, 44, 10, 112, 101, 110, 99, 105,
  108, 98, 119, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  48, 46, 51, 125, 44, 36, 123, 50, 61, 54, 48, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 66, 38, 87, 32,
  112, 101, 110, 99, 105, 108, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110,
  32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 115,
  105, 122, 101, 32, 36, 49, 32, 97, 110, 100, 32, 97, 109, 112, 108, 105,
  116, 117, 100, 101, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32,
  45, 108, 91, 48, 93, 32, 45, 110, 111, 114, 109, 32, 45, 98, 32, 36,
  49, 32, 45, 115, 104, 97, 114, 112, 101, 110, 32, 52, 48, 48, 48, 32,
  45, 115, 109, 111, 111, 116, 104, 32, 36, 50, 44, 48, 44, 49, 32, 45,
  101, 113, 117, 97, 108, 105, 122, 101, 32, 45, 115, 113, 114, 116, 32, 45,
  110, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 108, 32, 45, 97,
  32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 112, 111, 108, 97, 114,
  111, 105, 100, 32, 58, 32, 95, 115, 105, 122, 101, 49, 62, 61, 48, 44,
  95, 115, 105, 122, 101, 50, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 67, 114, 101, 97, 116, 101, 32, 112, 111, 108, 97, 114, 111,
  105, 100, 32, 101, 102, 102, 101, 99, 116, 32, 105, 110, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 115, 105, 122, 101, 49, 61, 49, 48,
  39, 32, 97, 110, 100, 32, 39, 115, 105, 122, 101, 50, 61, 50, 48, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 116, 111, 95, 114, 103, 98, 97, 32,
  45, 112, 111, 108, 97, 114, 111, 105, 100, 32, 53, 44, 51, 48, 32, 45,
  114, 111, 116, 97, 116, 101, 32, 50, 48, 32, 45, 100, 114, 111, 112, 95,
  115, 104, 97, 100, 111, 119, 32, 44, 32, 45, 100, 105, 115, 112, 108, 97,
  121, 95, 114, 103, 98, 97, 10, 112, 111, 108, 97, 114, 111, 105, 100, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 49, 48,
  125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 50, 48, 125, 62,
  61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 114, 101,
  97, 116, 101, 32, 112, 111, 108, 97, 114, 111, 105, 100, 32, 101, 102, 102,
  101, 99, 116, 32, 105, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32,
  119, 105, 116, 104, 32, 98, 111, 114, 100, 101, 114, 115, 32, 115, 105, 122,
  101, 115, 32, 36, 49, 32, 97, 110, 100, 32, 36, 50, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 45, 32, 50, 53, 53, 32, 45, 114, 32, 123, 49,
  48, 48, 43, 36, 49, 125, 37, 44, 123, 49, 48, 48, 43, 36, 49, 125,
  37, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44, 48, 44, 48, 46, 53,
  44, 48, 46, 53, 32, 45, 114, 32, 49, 48, 48, 37, 44, 123, 49, 48,
  48, 43, 36, 50, 125, 37, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44,
  48, 44, 48, 32, 45, 43, 32, 50, 53, 53, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 112, 111, 108, 121, 103, 111, 110, 105, 122,
  101, 32, 58, 32, 95, 119, 97, 114, 112, 95, 97, 109, 112, 108, 105, 116,
  117, 100, 101, 62, 61, 48, 44, 95, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 91, 37, 93, 62, 61, 48, 44, 95, 109, 105, 110, 95, 97, 114,
  101, 97, 91, 37, 93, 62, 61, 48, 44, 95, 114, 101, 115, 111, 108, 117,
  116, 105, 111, 110, 95, 120, 91, 37, 93, 62, 48, 44, 95, 114, 101, 115,
  111, 108, 117, 116, 105, 111, 110, 95, 121, 91, 37, 93, 62, 48, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 112, 111,
  108, 121, 103, 111, 110, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108,
  116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 119, 97, 114, 112, 95,
  97, 109, 112, 108, 105, 116, 117, 100, 101, 61, 51, 48, 48, 39, 44, 32,
  39, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 50, 37, 39, 44,
  32, 39, 109, 105, 110, 95, 97, 114, 101, 97, 61, 48, 46, 49, 37, 39,
  44, 32, 39, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 95, 120, 61,
  114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 95, 121, 61, 49, 48, 37,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 112, 111, 108, 121, 103, 111,
  110, 105, 122, 101, 32, 44, 10, 112, 111, 108, 121, 103, 111, 110, 105, 122,
  101, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61,
  51, 48, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 50,
  37, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 51, 61, 48, 46, 49,
  37, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 52, 61, 49, 48, 37,
  125, 62, 48, 32, 38, 38, 32, 36, 123, 53, 61, 36, 52, 125, 62, 48,
  34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 80, 111, 108, 121, 103,
  111, 110, 105, 122, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 119, 105,
  116, 104, 32, 119, 97, 114, 112, 32, 97, 109, 112, 108, 105, 116, 117, 100,
  101, 32, 36, 49, 44, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  32, 36, 50, 44, 32, 109, 105, 110, 105, 109, 97, 108, 32, 97, 114, 101,
  97, 32, 36, 51, 32, 97, 110, 100, 32, 114, 101, 115, 111, 108, 117, 116,
  105, 111, 110, 115, 32, 40, 36, 52, 44, 36, 53, 41, 46, 34, 10, 45,
  118, 32, 45, 32, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 45, 98, 32, 36, 50, 32, 45, 103,
  114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 91, 45, 49, 93,
  32, 45, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32, 45,
  97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 99, 104, 97, 110,
  110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 44, 50, 32, 45, 42, 91,
  45, 49, 93, 32, 123, 49, 47, 48, 46, 49, 43, 109, 97, 120, 40, 97,
  98, 115, 40, 105, 109, 41, 44, 97, 98, 115, 40, 105, 77, 41, 41, 125,
  10, 114, 101, 115, 120, 61, 123, 109, 97, 120, 40, 49, 44, 114, 111, 117,
  110, 100, 40, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99,
  101, 110, 116, 92, 32, 36, 52, 125, 44, 119, 42, 36, 52, 44, 119, 47,
  36, 52, 41, 45, 49, 41, 41, 125, 10, 114, 101, 115, 121, 61, 123, 109,
  97, 120, 40, 49, 44, 114, 111, 117, 110, 100, 40, 105, 102, 40, 64, 123,
  45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 53, 125,
  44, 104, 42, 36, 53, 44, 104, 47, 36, 53, 41, 45, 49, 41, 41, 125,
  10, 45, 112, 108, 97, 110, 101, 51, 100, 32, 49, 44, 49, 44, 36, 114,
  101, 115, 120, 44, 36, 114, 101, 115, 121, 32, 45, 42, 51, 100, 91, 45,
  49, 93, 32, 64, 123, 48, 44, 119, 45, 49, 125, 44, 64, 123, 48, 44,
  104, 45, 49, 125, 44, 49, 10, 45, 115, 51, 100, 91, 45, 49, 93, 32,
  45, 114, 109, 91, 45, 50, 93, 32, 45, 105, 91, 45, 50, 93, 32, 40,
  48, 59, 123, 104, 45, 49, 125, 41, 32, 45, 114, 91, 45, 50, 93, 32,
  51, 44, 123, 104, 125, 44, 49, 44, 49, 44, 51, 32, 45, 114, 111, 117,
  110, 100, 91, 45, 50, 93, 32, 45, 121, 91, 45, 50, 93, 10, 91, 45,
  52, 93, 32, 45, 97, 91, 45, 55, 45, 45, 50, 93, 32, 121, 32, 45,
  114, 91, 45, 49, 93, 32, 51, 44, 123, 104, 47, 51, 125, 44, 49, 44,
  49, 44, 45, 49, 32, 45, 122, 91, 45, 49, 93, 32, 48, 44, 49, 32,
  45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 49, 93, 32, 121, 122, 99,
  120, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 32, 45, 45, 119,
  97, 114, 112, 91, 49, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 32,
  45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10,
  45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 49, 93, 32, 99, 120, 121,
  122, 32, 45, 122, 91, 45, 49, 93, 32, 48, 44, 50, 32, 45, 121, 91,
  45, 49, 93, 32, 45, 106, 91, 50, 93, 32, 91, 45, 49, 93, 44, 48,
  44, 56, 32, 45, 114, 109, 91, 45, 51, 44, 45, 49, 93, 10, 91, 48,
  93, 44, 91, 48, 93, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91,
  45, 49, 93, 32, 91, 49, 93, 44, 48, 44, 48, 44, 48, 44, 49, 44,
  50, 32, 45, 114, 109, 91, 49, 93, 10, 45, 105, 102, 32, 123, 36, 51,
  62, 48, 125, 10, 109, 105, 110, 95, 97, 114, 101, 97, 61, 64, 123, 48,
  44, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110,
  116, 92, 32, 36, 51, 125, 44, 36, 51, 42, 119, 42, 104, 44, 36, 51,
  41, 125, 10, 45, 45, 97, 114, 101, 97, 91, 45, 49, 93, 32, 48, 44,
  49, 32, 45, 103, 101, 91, 45, 49, 93, 32, 36, 109, 105, 110, 95, 97,
  114, 101, 97, 32, 45, 43, 91, 45, 50, 93, 32, 49, 32, 45, 42, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 100, 105, 115, 116, 97, 110,
  99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 42, 91, 45, 49, 93, 32,
  45, 49, 32, 45, 119, 97, 116, 101, 114, 115, 104, 101, 100, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 98, 108, 101, 110, 100, 91, 48, 44, 45,
  49, 93, 32, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97, 103, 101, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 112, 111, 115, 116, 101, 114, 95, 101,
  100, 103, 101, 115, 32, 58, 32, 48, 60, 61, 95, 101, 100, 103, 101, 95,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 60, 61, 49, 48, 48, 44, 48,
  60, 61, 95, 101, 100, 103, 101, 95, 115, 104, 97, 100, 101, 60, 61, 49,
  48, 48, 44, 95, 101, 100, 103, 101, 95, 116, 104, 105, 99, 107, 110, 101,
  115, 115, 62, 61, 48, 44, 95, 101, 100, 103, 101, 95, 97, 110, 116, 105,
  97, 108, 105, 97, 115, 105, 110, 103, 62, 61, 48, 44, 48, 60, 61, 95,
  112, 111, 115, 116, 101, 114, 105, 122, 97, 116, 105, 111, 110, 95, 108, 101,
  118, 101, 108, 60, 61, 49, 53, 44, 95, 112, 111, 115, 116, 101, 114, 105,
  122, 97, 116, 105, 111, 110, 95, 97, 110, 116, 105, 97, 108, 105, 97, 115,
  105, 110, 103, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  65, 112, 112, 108, 121, 32, 112, 111, 115, 116, 101, 114, 32, 101, 100, 103,
  101, 115, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 101, 100, 103, 101, 95, 116, 104, 114,
  101, 115, 104, 111, 108, 100, 61, 52, 48, 39, 44, 32, 39, 101, 100, 103,
  101, 95, 115, 104, 97, 100, 101, 61, 53, 39, 44, 32, 39, 101, 100, 103,
  101, 95, 116, 104, 105, 99, 107, 110, 101, 115, 115, 61, 48, 46, 53, 39,
  44, 32, 39, 101, 100, 103, 101, 95, 97, 110, 116, 105, 97, 108, 105, 97,
  115, 105, 110, 103, 61, 49, 48, 39, 44, 32, 39, 112, 111, 115, 116, 101,
  114, 105, 122, 97, 116, 105, 111, 110, 95, 108, 101, 118, 101, 108, 61, 49,
  50, 39, 32, 97, 110, 100, 32, 39, 112, 111, 115, 116, 101, 114, 105, 122,
  97, 116, 105, 111, 110, 95, 97, 110, 116, 105, 97, 108, 105, 97, 115, 105,
  110, 103, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 112, 111,
  115, 116, 101, 114, 95, 101, 100, 103, 101, 115, 32, 44, 10, 112, 111, 115,
  116, 101, 114, 95, 101, 100, 103, 101, 115, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 36, 123, 49, 61, 52, 48, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 49, 60, 61, 49, 48, 48, 32, 38, 38, 32, 36, 123, 50,
  61, 53, 125, 62, 61, 48, 32, 38, 38, 32, 36, 50, 60, 61, 49, 48,
  48, 32, 38, 38, 32, 36, 123, 51, 61, 48, 46, 53, 125, 62, 61, 48,
  32, 38, 38, 32, 36, 123, 52, 61, 49, 48, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 123, 53, 61, 49, 50, 125, 62, 61, 48, 32, 38, 38, 32,
  36, 53, 60, 61, 49, 53, 32, 38, 38, 32, 36, 123, 54, 61, 48, 125,
  62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112,
  112, 108, 121, 32, 112, 111, 115, 116, 101, 114, 32, 101, 100, 103, 101, 32,
  111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104,
  32, 101, 100, 103, 101, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32,
  36, 49, 44, 32, 101, 100, 103, 101, 32, 115, 104, 97, 100, 101, 32, 36,
  50, 44, 32, 101, 100, 103, 101, 32, 116, 104, 105, 99, 107, 110, 101, 115,
  115, 32, 36, 51, 44, 32, 101, 100, 103, 101, 32, 97, 110, 116, 105, 97,
  108, 105, 97, 115, 105, 110, 103, 32, 36, 52, 44, 32, 36, 53, 32, 108,
  101, 118, 101, 108, 32, 111, 102, 32, 112, 111, 115, 116, 101, 114, 105, 122,
  97, 116, 105, 111, 110, 32, 97, 110, 100, 32, 112, 111, 115, 116, 101, 114,
  105, 122, 97, 116, 105, 111, 110, 32, 97, 110, 116, 105, 97, 108, 105, 97,
  115, 105, 110, 103, 32, 36, 54, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32,
  45, 108, 91, 48, 93, 10, 45, 45, 103, 114, 97, 100, 105, 101, 110, 116,
  32, 120, 121, 44, 49, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32,
  99, 32, 45, 110, 111, 114, 109, 91, 45, 49, 93, 32, 45, 98, 91, 45,
  49, 93, 32, 36, 51, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 10, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 91,
  45, 49, 93, 32, 49, 44, 48, 44, 49, 44, 123, 109, 97, 120, 40, 48,
  44, 40, 49, 48, 48, 45, 40, 36, 49, 37, 41, 94, 48, 46, 49, 42,
  49, 48, 48, 41, 42, 50, 53, 53, 37, 41, 125, 44, 48, 46, 57, 57,
  44, 123, 109, 105, 110, 40, 50, 53, 53, 44, 40, 49, 48, 49, 45, 40,
  36, 49, 37, 41, 94, 48, 46, 49, 42, 49, 48, 48, 43, 36, 50, 41,
  42, 50, 53, 53, 37, 41, 125, 44, 48, 46, 48, 49, 44, 50, 53, 53,
  44, 48, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 49, 10, 45, 105,
  102, 32, 36, 52, 32, 45, 115, 109, 111, 111, 116, 104, 91, 45, 49, 93,
  32, 123, 109, 105, 110, 40, 53, 48, 44, 36, 52, 41, 125, 44, 48, 44,
  49, 44, 123, 36, 52, 47, 52, 48, 125, 44, 123, 36, 52, 47, 52, 48,
  125, 44, 48, 46, 56, 44, 57, 48, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 36, 53, 32, 45, 97, 117, 116, 111, 105, 110, 100, 101,
  120, 91, 48, 93, 32, 123, 114, 111, 117, 110, 100, 40, 40, 52, 45, 115,
  113, 114, 116, 40, 36, 53, 43, 49, 41, 41, 42, 51, 50, 43, 50, 41,
  125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 54, 32,
  45, 115, 109, 111, 111, 116, 104, 91, 48, 93, 32, 123, 109, 105, 110, 40,
  53, 48, 44, 36, 54, 41, 125, 44, 48, 44, 49, 44, 123, 36, 54, 47,
  52, 48, 125, 44, 123, 36, 54, 47, 52, 48, 125, 44, 48, 46, 56, 44,
  57, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 42, 10, 45, 101, 110,
  100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  112, 111, 115, 116, 101, 114, 95, 104, 111, 112, 101, 32, 58, 32, 95, 115,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 62, 61, 48, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 72, 111, 112, 101,
  32, 115, 116, 101, 110, 99, 105, 108, 32, 112, 111, 115, 116, 101, 114, 32,
  101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117,
  101, 58, 32, 39, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 51,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 112, 111, 115, 116, 101, 114,
  95, 104, 111, 112, 101, 32, 44, 10, 112, 111, 115, 116, 101, 114, 95, 104,
  111, 112, 101, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123,
  49, 61, 51, 125, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 65, 112, 112, 108, 121, 32, 72, 111, 112, 101, 32, 115, 116, 101,
  110, 99, 105, 108, 32, 112, 111, 115, 116, 101, 114, 32, 101, 102, 102, 101,
  99, 116, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119,
  105, 116, 104, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36,
  49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 116, 111, 95, 114,
  103, 98, 10, 45, 97, 112, 112, 108, 121, 95, 112, 97, 114, 97, 108, 108,
  101, 108, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 115, 109,
  111, 111, 116, 104, 32, 50, 48, 48, 44, 48, 44, 49, 44, 36, 49, 44,
  49, 34, 10, 45, 113, 117, 97, 110, 116, 105, 122, 101, 32, 55, 44, 48,
  32, 45, 102, 32, 39, 105, 102, 40, 105, 33, 61, 53, 44, 105, 44, 105,
  43, 49, 45, 50, 42, 40, 121, 37, 50, 41, 41, 39, 10, 40, 48, 44,
  51, 50, 44, 52, 55, 59, 48, 44, 51, 50, 44, 52, 55, 59, 50, 48,
  57, 44, 49, 44, 50, 51, 59, 50, 48, 57, 44, 49, 44, 50, 51, 59,
  57, 48, 44, 49, 52, 49, 44, 49, 52, 53, 59, 45, 49, 44, 45, 49,
  44, 45, 49, 59, 50, 53, 51, 44, 50, 50, 49, 44, 49, 51, 56, 41,
  32, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 49, 93, 32, 121, 122,
  99, 120, 10, 45, 109, 97, 112, 91, 48, 93, 32, 91, 49, 93, 32, 45,
  114, 109, 91, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 114, 111,
  100, 105, 108, 105, 117, 115, 32, 58, 32, 48, 60, 61, 95, 97, 109, 112,
  108, 105, 116, 117, 100, 101, 60, 61, 49, 48, 48, 44, 95, 48, 60, 61,
  116, 104, 105, 99, 107, 110, 101, 115, 115, 60, 61, 49, 48, 48, 44, 95,
  115, 104, 97, 114, 112, 110, 101, 115, 115, 62, 61, 48, 44, 95, 110, 98,
  95, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 115, 62, 48, 44,
  95, 111, 102, 102, 115, 101, 116, 44, 95, 99, 111, 108, 111, 114, 95, 109,
  111, 100, 101, 61, 123, 32, 48, 61, 100, 97, 114, 107, 101, 114, 32, 124,
  32, 49, 61, 98, 114, 105, 103, 104, 116, 101, 114, 32, 125, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 114, 111, 100,
  105, 108, 105, 117, 115, 32, 40, 102, 114, 97, 99, 116, 97, 108, 105, 117,
  115, 45, 108, 105, 107, 101, 41, 32, 102, 105, 108, 116, 101, 114, 32, 111,
  110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 97, 109, 112,
  108, 105, 116, 117, 100, 101, 61, 49, 48, 39, 44, 32, 39, 116, 104, 105,
  99, 107, 110, 101, 115, 115, 61, 49, 48, 39, 44, 32, 39, 115, 104, 97,
  114, 112, 110, 101, 115, 115, 61, 52, 48, 48, 39, 44, 32, 39, 110, 98,
  95, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 115, 61, 55, 39,
  44, 32, 39, 111, 102, 102, 115, 101, 116, 61, 48, 39, 32, 97, 110, 100,
  32, 39, 99, 111, 108, 111, 114, 95, 109, 111, 100, 101, 61, 49, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 114, 111, 100, 105, 108, 105, 117, 115,
  32, 49, 50, 44, 49, 48, 44, 51, 48, 48, 44, 49, 48, 32, 45, 110,
  111, 114, 109, 97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 91, 45,
  49, 93, 32, 49, 48, 44, 54, 10, 114, 111, 100, 105, 108, 105, 117, 115,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 49,
  48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 49, 60, 61, 50, 48, 48,
  32, 38, 38, 32, 36, 123, 50, 61, 49, 48, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 50, 60, 61, 49, 48, 48, 32, 38, 38, 32, 36, 123, 51,
  61, 52, 48, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 52, 61,
  55, 125, 62, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 53, 61,
  48, 125, 44, 36, 123, 54, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 65, 112, 112, 108, 121, 32, 114, 111, 100, 105, 108, 105, 117,
  115, 32, 102, 105, 108, 116, 101, 114, 32, 111, 110, 32, 105, 109, 97, 103,
  101, 36, 63, 32, 119, 105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117,
  100, 101, 32, 36, 49, 44, 32, 116, 104, 105, 99, 107, 110, 101, 115, 115,
  32, 36, 50, 44, 32, 115, 104, 97, 114, 112, 110, 101, 115, 115, 32, 36,
  51, 44, 32, 36, 52, 32, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111,
  110, 115, 44, 32, 111, 102, 102, 115, 101, 116, 32, 36, 53, 32, 97, 110,
  100, 32, 34, 92, 10, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 33,
  36, 54, 44, 98, 114, 105, 103, 104, 116, 101, 114, 44, 100, 97, 114, 107,
  101, 114, 125, 34, 32, 99, 111, 108, 111, 114, 32, 109, 111, 100, 101, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95,
  111, 112, 97, 99, 105, 116, 121, 32, 45, 114, 118, 10, 45, 105, 102, 32,
  123, 33, 36, 54, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91,
  45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 102, 91, 45,
  49, 93, 32, 48, 32, 45, 110, 109, 91, 45, 49, 93, 32, 64, 123, 45,
  50, 44, 110, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 114, 111,
  117, 110, 100, 40, 36, 52, 41, 125, 10, 97, 110, 103, 108, 101, 61, 123,
  36, 53, 43, 36, 62, 42, 49, 56, 48, 47, 114, 111, 117, 110, 100, 40,
  36, 52, 41, 125, 10, 45, 45, 98, 108, 117, 114, 95, 108, 105, 110, 101,
  97, 114, 91, 45, 50, 93, 32, 36, 49, 37, 44, 123, 36, 49, 42, 36,
  50, 47, 49, 48, 48, 125, 37, 44, 36, 97, 110, 103, 108, 101, 44, 49,
  32, 45, 98, 91, 45, 49, 93, 32, 48, 46, 55, 32, 45, 115, 104, 97,
  114, 112, 101, 110, 91, 45, 49, 93, 32, 36, 51, 32, 45, 109, 97, 120,
  91, 45, 50, 44, 45, 49, 93, 10, 45, 100, 111, 110, 101, 32, 45, 114,
  109, 91, 45, 50, 93, 10, 45, 105, 102, 32, 123, 33, 36, 54, 125, 32,
  45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 118, 32, 45, 97, 32, 99, 32, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 115, 116, 97, 105, 110, 101, 100, 95, 103, 108,
  97, 115, 115, 32, 58, 32, 95, 101, 100, 103, 101, 115, 91, 37, 93, 62,
  61, 48, 44, 32, 115, 104, 97, 100, 105, 110, 103, 62, 61, 48, 44, 32,
  105, 115, 95, 116, 104, 105, 110, 95, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 115, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 71, 101, 110, 101, 114, 97, 116, 101, 32, 115,
  116, 97, 105, 110, 101, 100, 32, 103, 108, 97, 115, 115, 32, 102, 114, 111,
  109, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 101, 100, 103,
  101, 115, 61, 52, 48, 37, 39, 44, 32, 39, 115, 104, 97, 100, 105, 110,
  103, 61, 48, 46, 50, 39, 32, 97, 110, 100, 32, 39, 105, 115, 95, 112,
  114, 101, 99, 105, 115, 101, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 45, 115, 116, 97, 105, 110, 101, 100, 95, 103, 108, 97, 115, 115, 32,
  44, 10, 115, 116, 97, 105, 110, 101, 100, 95, 103, 108, 97, 115, 115, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 52, 48,
  37, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 48, 46, 50,
  125, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61,
  48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108,
  121, 32, 115, 116, 97, 105, 110, 101, 100, 32, 103, 108, 97, 115, 115, 32,
  101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 119, 105, 116, 104, 32, 101, 100, 103, 101, 115, 32, 36, 49,
  44, 32, 115, 104, 97, 100, 105, 110, 103, 32, 36, 50, 32, 97, 110, 100,
  32, 116, 104, 105, 110, 45, 115, 101, 112, 97, 114, 97, 116, 111, 114, 115,
  32, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 33, 36, 51, 44,
  101, 110, 97, 98, 108, 101, 100, 44, 100, 105, 115, 97, 98, 108, 101, 100,
  125, 34, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 105, 109, 61, 123,
  49, 43, 105, 109, 125, 32, 45, 43, 32, 36, 105, 109, 10, 45, 45, 103,
  114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 32, 45, 103, 101,
  91, 45, 49, 93, 32, 36, 49, 32, 45, 42, 91, 45, 50, 93, 32, 91,
  45, 49, 93, 10, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49,
  93, 32, 49, 32, 45, 115, 104, 97, 114, 112, 101, 110, 91, 45, 49, 93,
  32, 49, 101, 49, 48, 32, 45, 110, 101, 113, 91, 45, 49, 93, 32, 48,
  10, 45, 105, 102, 32, 36, 51, 32, 45, 115, 107, 101, 108, 101, 116, 111,
  110, 91, 45, 49, 93, 32, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45,
  119, 97, 116, 101, 114, 115, 104, 101, 100, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 32, 45, 45, 91, 45, 50, 93, 32, 36, 105, 109, 10, 45, 110,
  91, 45, 49, 93, 32, 48, 44, 49, 32, 32, 45, 94, 91, 45, 49, 93,
  32, 36, 50, 32, 45, 42, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115,
  116, 97, 114, 32, 58, 32, 95, 119, 105, 100, 116, 104, 62, 48, 44, 95,
  104, 101, 105, 103, 104, 116, 62, 48, 44, 95, 110, 98, 95, 98, 114, 97,
  110, 99, 104, 101, 115, 62, 48, 44, 48, 60, 61, 95, 116, 104, 105, 99,
  107, 110, 101, 115, 115, 60, 61, 49, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 73, 110, 112, 117, 116, 32, 115, 116, 97, 114, 32, 98, 105, 110,
  97, 114, 121, 32, 109, 97, 115, 107, 32, 119, 105, 116, 104, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 115, 105, 122, 101, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 119, 105, 100, 116, 104, 61, 104, 101,
  105, 103, 104, 116, 61, 53, 49, 50, 39, 44, 32, 39, 110, 98, 95, 98,
  114, 97, 110, 99, 104, 101, 115, 61, 53, 39, 32, 97, 110, 100, 32, 39,
  116, 104, 105, 99, 107, 110, 101, 115, 115, 61, 48, 46, 51, 56, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 115, 116, 97,
  114, 32, 44, 10, 115, 116, 97, 114, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 34, 36, 123, 49, 61, 53, 49, 50, 125, 62, 61, 49, 32, 38,
  38, 32, 36, 123, 50, 61, 36, 49, 125, 62, 61, 49, 32, 38, 38, 32,
  36, 123, 51, 61, 53, 125, 62, 48, 32, 38, 38, 32, 36, 123, 52, 61,
  48, 46, 53, 125, 62, 61, 48, 32, 38, 38, 32, 36, 52, 60, 61, 49,
  34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116,
  32, 36, 49, 120, 36, 50, 32, 115, 116, 97, 114, 32, 98, 105, 110, 97,
  114, 121, 32, 109, 97, 115, 107, 44, 32, 119, 105, 116, 104, 32, 36, 51,
  32, 98, 114, 97, 110, 99, 104, 101, 115, 32, 97, 110, 100, 32, 116, 104,
  105, 99, 107, 110, 101, 115, 115, 32, 36, 52, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 108, 91, 93, 10, 45, 115, 116, 97, 114, 51, 100, 32, 36,
  51, 44, 36, 52, 32, 45, 99, 111, 108, 51, 100, 32, 49, 32, 45, 99,
  51, 100, 32, 45, 110, 51, 100, 32, 45, 42, 51, 100, 32, 36, 49, 44,
  36, 50, 10, 36, 49, 44, 36, 50, 32, 45, 111, 98, 106, 101, 99, 116,
  51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 53, 48, 37, 44,
  53, 48, 37, 44, 48, 44, 49, 44, 50, 32, 45, 114, 109, 91, 45, 50,
  93, 10, 45, 110, 109, 32, 34, 91, 72, 101, 97, 114, 116, 32, 98, 105,
  110, 97, 114, 121, 32, 109, 97, 115, 107, 93, 34, 10, 45, 101, 110, 100,
  108, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 116,
  97, 114, 115, 32, 58, 32, 95, 100, 101, 110, 115, 105, 116, 121, 91, 37,
  93, 62, 61, 48, 44, 95, 100, 101, 112, 116, 104, 62, 61, 48, 44, 95,
  115, 105, 122, 101, 62, 48, 44, 95, 110, 98, 95, 98, 114, 97, 110, 99,
  104, 101, 115, 62, 61, 49, 44, 48, 60, 61, 95, 116, 104, 105, 99, 107,
  110, 101, 115, 115, 60, 61, 49, 44, 95, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 91, 37, 93, 62, 61, 48, 44, 95, 82, 44, 95, 71, 44,
  95, 66, 44, 95, 111, 112, 97, 99, 105, 116, 121, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 65, 100, 100, 32, 114, 97, 110, 100, 111, 109, 32,
  115, 116, 97, 114, 115, 32, 116, 111, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  115, 58, 32, 39, 100, 101, 110, 115, 105, 116, 121, 61, 49, 48, 37, 39,
  44, 32, 39, 100, 101, 112, 116, 104, 61, 49, 39, 44, 32, 39, 115, 105,
  122, 101, 61, 51, 50, 39, 44, 32, 39, 110, 98, 95, 98, 114, 97, 110,
  99, 104, 101, 115, 61, 53, 39, 44, 32, 39, 116, 104, 105, 99, 107, 110,
  101, 115, 115, 61, 48, 46, 51, 56, 39, 44, 32, 39, 115, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 61, 48, 46, 53, 39, 44, 32, 39, 82, 61,
  71, 61, 66, 61, 50, 48, 48, 39, 32, 97, 110, 100, 32, 39, 111, 112,
  97, 99, 105, 116, 121, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  115, 116, 97, 114, 115, 32, 44, 10, 115, 116, 97, 114, 115, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 49, 48, 37, 125,
  62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 49, 125, 62, 61, 48,
  32, 38, 38, 32, 36, 123, 51, 61, 51, 50, 125, 62, 48, 32, 38, 38,
  32, 36, 123, 52, 61, 53, 125, 62, 61, 49, 32, 38, 38, 32, 36, 123,
  53, 61, 48, 46, 51, 56, 125, 62, 61, 48, 32, 38, 38, 32, 36, 53,
  60, 61, 49, 32, 38, 38, 32, 36, 123, 54, 61, 48, 46, 53, 125, 62,
  61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 55, 61, 50, 48,
  48, 125, 44, 36, 123, 56, 61, 36, 55, 125, 44, 36, 123, 57, 61, 36,
  56, 125, 44, 36, 123, 49, 48, 61, 49, 125, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 65, 100, 100, 32, 36, 49, 32, 114, 97, 110, 100, 111,
  109, 32, 115, 116, 97, 114, 115, 32, 116, 111, 32, 105, 109, 97, 103, 101,
  36, 63, 44, 32, 119, 105, 116, 104, 32, 100, 101, 112, 116, 104, 32, 36,
  50, 44, 32, 115, 105, 122, 101, 32, 36, 51, 44, 32, 36, 52, 32, 98,
  114, 97, 110, 99, 104, 101, 115, 44, 32, 116, 104, 105, 99, 107, 110, 101,
  115, 115, 32, 36, 53, 44, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 36, 54, 44, 32, 99, 111, 108, 111, 114, 32, 40, 36, 55, 44,
  36, 56, 44, 36, 57, 41, 32, 97, 110, 100, 32, 111, 112, 97, 99, 105,
  116, 121, 32, 36, 49, 48, 46, 34, 10, 45, 118, 32, 45, 10, 45, 115,
  116, 97, 114, 51, 100, 32, 36, 52, 44, 36, 53, 32, 45, 99, 111, 108,
  51, 100, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 42, 51, 100, 91,
  45, 49, 93, 32, 36, 51, 10, 45, 108, 91, 45, 49, 93, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 52, 32, 123, 114, 111, 117, 110, 100, 40, 50,
  42, 36, 51, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 50, 42, 36,
  51, 41, 125, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 49,
  93, 32, 91, 48, 93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44,
  49, 44, 50, 44, 48, 44, 48, 32, 45, 114, 51, 100, 91, 48, 93, 32,
  48, 44, 48, 44, 49, 44, 57, 48, 32, 45, 100, 111, 110, 101, 32, 45,
  114, 109, 91, 48, 93, 32, 45, 101, 110, 100, 108, 10, 45, 97, 117, 116,
  111, 99, 114, 111, 112, 91, 45, 52, 45, 45, 49, 93, 32, 48, 32, 45,
  114, 50, 100, 121, 91, 45, 52, 45, 45, 49, 93, 32, 36, 51, 32, 45,
  98, 91, 45, 52, 45, 45, 49, 93, 32, 36, 54, 44, 48, 32, 45, 114,
  91, 45, 52, 45, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 44, 49, 44, 52, 10, 45, 114, 101, 112, 101, 97, 116, 32, 52, 32,
  45, 115, 104, 91, 123, 45, 49, 45, 36, 62, 125, 93, 32, 48, 44, 50,
  32, 45, 102, 99, 91, 45, 49, 93, 32, 36, 55, 44, 36, 56, 44, 36,
  57, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 91,
  45, 52, 45, 45, 49, 93, 32, 45, 108, 91, 36, 62, 44, 45, 52, 45,
  45, 49, 93, 10, 78, 61, 123, 114, 111, 117, 110, 100, 40, 105, 102, 40,
  64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36,
  49, 125, 44, 119, 42, 104, 42, 36, 49, 44, 36, 49, 41, 47, 52, 44,
  49, 44, 49, 41, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 52, 10,
  50, 44, 36, 78, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 45,
  49, 44, 49, 32, 49, 44, 36, 78, 32, 45, 114, 97, 110, 100, 91, 45,
  49, 93, 32, 48, 44, 49, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93,
  32, 120, 10, 45, 105, 91, 45, 50, 93, 32, 40, 123, 39, 67, 73, 109,
  103, 51, 100, 39, 125, 41, 32, 45, 43, 91, 45, 50, 93, 32, 48, 46,
  53, 32, 45, 105, 91, 45, 50, 93, 32, 40, 36, 78, 59, 36, 78, 41,
  10, 40, 49, 44, 48, 59, 49, 44, 123, 36, 78, 45, 49, 125, 41, 32,
  45, 114, 91, 45, 49, 93, 32, 50, 44, 36, 78, 44, 49, 44, 49, 44,
  51, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 52, 44, 36,
  78, 44, 49, 44, 49, 44, 49, 32, 45, 121, 91, 45, 53, 44, 45, 51,
  45, 45, 49, 93, 32, 45, 97, 91, 45, 53, 45, 45, 49, 93, 32, 121,
  10, 45, 114, 118, 91, 45, 50, 44, 45, 49, 93, 32, 45, 115, 112, 114,
  105, 116, 101, 115, 51, 100, 91, 45, 50, 44, 45, 49, 93, 32, 45, 42,
  51, 100, 91, 45, 49, 93, 32, 123, 48, 46, 55, 53, 42, 64, 123, 48,
  44, 119, 125, 125, 44, 123, 48, 46, 55, 53, 42, 64, 123, 48, 44, 104,
  125, 125, 44, 123, 49, 48, 48, 48, 42, 36, 50, 125, 10, 45, 111, 98,
  106, 101, 99, 116, 51, 100, 91, 48, 93, 32, 91, 45, 49, 93, 44, 53,
  48, 37, 44, 53, 48, 37, 44, 48, 44, 36, 49, 48, 44, 48, 44, 48,
  44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 100, 111, 110, 101,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 114, 109,
  91, 45, 52, 45, 45, 49, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 115, 107, 101, 116, 99, 104, 98, 119, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 95, 110, 98, 95, 111, 114, 105, 101, 110, 116,
  115, 62, 48, 44, 95, 115, 116, 97, 114, 116, 95, 97, 110, 103, 108, 101,
  44, 95, 97, 110, 103, 108, 101, 95, 114, 97, 110, 103, 101, 62, 61, 48,
  44, 95, 108, 101, 110, 103, 116, 104, 62, 61, 48, 44, 95, 116, 104, 114,
  101, 115, 104, 111, 108, 100, 62, 61, 48, 44, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 95, 111, 112, 97, 99, 105, 116, 121, 44, 95, 98, 103,
  102, 97, 99, 116, 111, 114, 62, 61, 48, 44, 95, 100, 101, 110, 115, 105,
  116, 121, 62, 48, 44, 95, 115, 104, 97, 114, 112, 110, 101, 115, 115, 62,
  61, 48, 44, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 95, 97, 110,
  105, 115, 111, 116, 114, 111, 112, 121, 62, 61, 48, 44, 95, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 62, 61, 48, 44, 95, 99, 111, 104, 101,
  114, 101, 110, 99, 101, 62, 61, 48, 44, 95, 105, 115, 95, 98, 111, 111,
  115, 116, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 44, 95, 105, 115,
  95, 99, 117, 114, 118, 101, 100, 61, 123, 32, 48, 32, 124, 32, 49, 32,
  125, 92, 110, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112,
  108, 121, 32, 115, 107, 101, 116, 99, 104, 32, 101, 102, 102, 101, 99, 116,
  32, 116, 111, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101,
  102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 110,
  98, 95, 111, 114, 105, 101, 110, 116, 115, 61, 50, 39, 44, 32, 39, 115,
  116, 97, 114, 116, 95, 97, 110, 103, 108, 101, 61, 52, 53, 39, 44, 32,
  39, 97, 110, 103, 108, 101, 95, 114, 97, 110, 103, 101, 61, 49, 56, 48,
  39, 44, 32, 39, 108, 101, 110, 103, 116, 104, 61, 51, 48, 39, 44, 32,
  39, 116, 104, 114, 101, 115, 104, 111, 108, 100, 61, 49, 39, 44, 32, 39,
  111, 112, 97, 99, 105, 116, 121, 61, 48, 46, 48, 51, 39, 44, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 39, 98, 103, 102, 97, 99, 116, 111,
  114, 61, 48, 39, 44, 32, 39, 100, 101, 110, 115, 105, 116, 121, 61, 48,
  46, 54, 39, 44, 32, 39, 115, 104, 97, 114, 112, 110, 101, 115, 115, 61,
  48, 46, 49, 39, 44, 32, 39, 97, 110, 105, 115, 111, 116, 114, 111, 112,
  121, 61, 48, 46, 54, 39, 44, 32, 39, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 61, 48, 46, 50, 53, 39, 44, 32, 39, 99, 111, 104, 101,
  114, 101, 110, 99, 101, 61, 49, 39, 44, 32, 39, 105, 115, 95, 98, 111,
  111, 115, 116, 61, 48, 39, 32, 97, 110, 100, 32, 39, 105, 115, 95, 99,
  117, 114, 118, 101, 100, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  45, 115, 107, 101, 116, 99, 104, 98, 119, 32, 49, 32, 45, 45, 108, 111,
  99, 97, 108, 32, 45, 114, 101, 118, 101, 114, 115, 101, 32, 45, 98, 108,
  117, 114, 91, 45, 49, 93, 32, 51, 32, 45, 98, 108, 101, 110, 100, 32,
  111, 118, 101, 114, 108, 97, 121, 32, 45, 101, 110, 100, 108, 111, 99, 97,
  108, 10, 115, 107, 101, 116, 99, 104, 98, 119, 32, 58, 10, 45, 99, 104,
  101, 99, 107, 32, 34, 36, 123, 49, 61, 50, 125, 62, 48, 32, 38, 38,
  32, 36, 123, 51, 61, 49, 56, 48, 125, 62, 61, 48, 32, 38, 38, 32,
  36, 123, 52, 61, 51, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123,
  53, 61, 49, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 55, 61, 48,
  125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 56, 61, 48, 46, 54, 125,
  62, 48, 32, 38, 38, 32, 36, 123, 57, 61, 48, 46, 49, 125, 62, 61,
  48, 32, 38, 38, 32, 36, 123, 49, 48, 61, 48, 46, 54, 125, 62, 61,
  48, 32, 38, 38, 32, 36, 123, 49, 49, 61, 48, 46, 50, 53, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 123, 49, 50, 61, 49, 125, 62, 61, 48,
  34, 10, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 52, 53, 125, 44,
  36, 123, 54, 61, 48, 46, 48, 51, 125, 44, 36, 123, 49, 51, 61, 48,
  125, 44, 36, 123, 49, 52, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 65, 112, 112, 108, 121, 32, 66, 38, 87, 32, 115, 107, 101,
  116, 99, 104, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109,
  97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 100, 105,
  102, 102, 117, 115, 105, 111, 110, 116, 101, 110, 115, 111, 114, 115, 32, 36,
  57, 44, 36, 49, 48, 44, 36, 49, 49, 44, 36, 49, 50, 10, 119, 61,
  49, 32, 104, 61, 49, 32, 45, 105, 91, 48, 93, 32, 49, 32, 45, 109,
  51, 100, 32, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35,
  45, 49, 125, 10, 45, 47, 91, 45, 49, 93, 32, 123, 109, 97, 120, 40,
  105, 77, 44, 105, 109, 41, 125, 32, 45, 115, 91, 45, 49, 93, 32, 99,
  10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 50,
  53, 53, 32, 45, 110, 109, 91, 45, 49, 93, 32, 64, 123, 45, 52, 44,
  110, 125, 44, 49, 10, 45, 105, 102, 32, 123, 36, 119, 33, 61, 119, 124,
  124, 36, 104, 33, 61, 104, 125, 10, 45, 114, 109, 91, 48, 93, 32, 123,
  36, 56, 42, 119, 42, 104, 47, 40, 36, 49, 42, 115, 113, 114, 116, 40,
  36, 52, 41, 41, 125, 10, 45, 45, 114, 97, 110, 100, 91, 45, 49, 93,
  32, 48, 44, 123, 64, 123, 45, 50, 44, 104, 125, 45, 49, 125, 32, 45,
  114, 97, 110, 100, 91, 45, 50, 93, 32, 48, 44, 123, 64, 123, 45, 51,
  44, 119, 125, 45, 49, 125, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93,
  32, 121, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 10, 119, 61, 123,
  119, 125, 32, 104, 61, 123, 104, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 36, 49, 52, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  36, 49, 10, 97, 108, 112, 104, 97, 61, 123, 40, 36, 50, 43, 36, 62,
  42, 36, 51, 47, 36, 49, 41, 42, 112, 105, 47, 49, 56, 48, 125, 10,
  45, 45, 42, 91, 45, 52, 93, 32, 123, 99, 111, 115, 40, 36, 97, 108,
  112, 104, 97, 41, 125, 32, 45, 45, 42, 91, 45, 52, 93, 32, 123, 115,
  105, 110, 40, 36, 97, 108, 112, 104, 97, 41, 125, 32, 45, 43, 91, 45,
  50, 44, 45, 49, 93, 10, 45, 45, 42, 91, 45, 52, 93, 32, 123, 99,
  111, 115, 40, 36, 97, 108, 112, 104, 97, 41, 125, 32, 45, 45, 42, 91,
  45, 52, 93, 32, 123, 115, 105, 110, 40, 36, 97, 108, 112, 104, 97, 41,
  125, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 97, 91, 45,
  50, 44, 45, 49, 93, 32, 99, 32, 45, 99, 104, 97, 110, 110, 101, 108,
  115, 91, 45, 49, 93, 32, 48, 44, 50, 10, 45, 105, 102, 32, 36, 49,
  51, 32, 45, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 91, 45,
  49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 123, 48, 44, 119, 125, 10, 120, 121, 61, 64, 123, 48, 44,
  40, 36, 62, 44, 48, 41, 125, 44, 64, 123, 48, 44, 40, 36, 62, 44,
  49, 41, 125, 10, 45, 105, 102, 32, 123, 64, 123, 45, 53, 44, 40, 36,
  120, 121, 41, 125, 43, 64, 123, 45, 51, 44, 40, 36, 120, 121, 41, 125,
  60, 36, 53, 125, 32, 111, 112, 97, 99, 61, 36, 54, 32, 45, 101, 108,
  115, 101, 32, 111, 112, 97, 99, 61, 123, 36, 55, 42, 36, 54, 125, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 111, 112, 97, 99,
  10, 45, 45, 115, 116, 114, 101, 97, 109, 108, 105, 110, 101, 51, 100, 91,
  45, 49, 93, 32, 36, 120, 121, 44, 48, 44, 36, 52, 44, 48, 46, 56,
  44, 48, 44, 48, 44, 49, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49,
  93, 32, 48, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 51,
  93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 44, 48, 44, 36, 111, 112,
  97, 99, 44, 49, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 45, 115, 116, 114, 101, 97, 109, 108, 105, 110, 101, 51, 100, 91,
  45, 49, 93, 32, 36, 120, 121, 44, 48, 44, 36, 52, 44, 48, 46, 56,
  44, 48, 44, 49, 44, 49, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49,
  93, 32, 48, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 51,
  93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 44, 48, 44, 36, 111, 112,
  97, 99, 44, 49, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 100, 111, 110, 101, 10, 45, 101, 108, 115,
  101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 10, 97, 108, 112,
  104, 97, 61, 123, 40, 36, 50, 43, 36, 62, 42, 36, 51, 47, 36, 49,
  41, 42, 112, 105, 47, 49, 56, 48, 125, 10, 45, 45, 42, 91, 45, 52,
  93, 32, 123, 99, 111, 115, 40, 36, 97, 108, 112, 104, 97, 41, 125, 32,
  45, 45, 42, 91, 45, 52, 93, 32, 123, 115, 105, 110, 40, 36, 97, 108,
  112, 104, 97, 41, 125, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10,
  45, 45, 42, 91, 45, 52, 93, 32, 123, 99, 111, 115, 40, 36, 97, 108,
  112, 104, 97, 41, 125, 32, 45, 45, 42, 91, 45, 52, 93, 32, 123, 115,
  105, 110, 40, 36, 97, 108, 112, 104, 97, 41, 125, 32, 45, 43, 91, 45,
  50, 44, 45, 49, 93, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32,
  99, 10, 45, 105, 102, 32, 36, 49, 51, 32, 45, 111, 114, 105, 101, 110,
  116, 97, 116, 105, 111, 110, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 123, 48, 44, 119, 125,
  10, 120, 61, 64, 123, 48, 44, 40, 36, 62, 44, 48, 41, 125, 32, 121,
  61, 64, 123, 48, 44, 40, 36, 62, 44, 49, 41, 125, 10, 45, 105, 102,
  32, 123, 64, 123, 45, 53, 44, 40, 36, 120, 44, 36, 121, 41, 125, 43,
  64, 123, 45, 51, 44, 40, 36, 120, 44, 36, 121, 41, 125, 60, 36, 53,
  125, 32, 111, 112, 97, 99, 61, 36, 54, 32, 45, 101, 108, 115, 101, 32,
  111, 112, 97, 99, 61, 123, 36, 55, 42, 36, 54, 125, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 36, 111, 112, 97, 99, 10, 45, 108,
  105, 110, 101, 91, 45, 50, 93, 32, 123, 36, 120, 45, 36, 52, 42, 64,
  123, 45, 49, 44, 40, 36, 120, 44, 36, 121, 44, 48, 44, 48, 41, 125,
  125, 44, 123, 36, 121, 45, 36, 52, 42, 64, 123, 45, 49, 44, 40, 36,
  120, 44, 36, 121, 44, 48, 44, 49, 41, 125, 125, 44, 92, 10, 123, 36,
  120, 43, 36, 52, 42, 64, 123, 45, 49, 44, 40, 36, 120, 44, 36, 121,
  44, 48, 44, 48, 41, 125, 125, 44, 123, 36, 121, 43, 36, 52, 42, 64,
  123, 45, 49, 44, 40, 36, 120, 44, 36, 121, 44, 48, 44, 49, 41, 125,
  125, 44, 92, 10, 123, 51, 42, 36, 111, 112, 97, 99, 125, 44, 48, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 114, 109, 91, 45, 52, 45, 45, 50, 93, 10, 45, 109, 118,
  91, 45, 49, 93, 32, 49, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109,
  91, 48, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  115, 112, 111, 110, 103, 101, 32, 58, 32, 95, 115, 105, 122, 101, 62, 48,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32,
  115, 112, 111, 110, 103, 101, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117,
  108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 115, 105, 122, 101, 61,
  49, 51, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 115, 112, 111, 110,
  103, 101, 32, 44, 10, 115, 112, 111, 110, 103, 101, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 49, 61, 49, 51, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 115, 112, 111, 110, 103,
  101, 32, 102, 105, 108, 116, 101, 114, 32, 111, 110, 32, 105, 109, 97, 103,
  101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 98, 114, 117, 115, 104, 32,
  115, 105, 122, 101, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 32, 45,
  110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 50, 48, 44, 50, 32, 45,
  114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 110, 91, 45, 49,
  93, 32, 48, 44, 49, 32, 45, 42, 91, 45, 49, 44, 45, 50, 93, 10,
  45, 95, 99, 105, 114, 99, 108, 101, 32, 36, 49, 32, 45, 100, 105, 108,
  97, 116, 101, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 95, 99, 105, 114, 99, 108, 101, 32, 58, 10,
  45, 105, 102, 32, 123, 36, 49, 37, 50, 61, 61, 48, 125, 32, 45, 105,
  32, 50, 44, 50, 32, 45, 101, 108, 115, 101, 32, 45, 105, 32, 49, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 43, 91, 45, 49, 93, 32, 49, 32,
  45, 114, 91, 45, 49, 93, 32, 36, 49, 44, 36, 49, 44, 49, 44, 49,
  44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 100, 105,
  115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 110, 91,
  45, 49, 93, 32, 48, 44, 49, 32, 45, 115, 113, 114, 116, 91, 45, 49,
  93, 32, 45, 99, 91, 45, 49, 93, 32, 48, 46, 56, 53, 44, 48, 46,
  56, 54, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 110, 91,
  45, 49, 93, 32, 48, 44, 49, 10, 35, 64, 103, 109, 105, 99, 32, 115,
  116, 101, 110, 99, 105, 108, 32, 58, 32, 95, 114, 97, 100, 105, 117, 115,
  91, 37, 93, 62, 61, 48, 44, 95, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 62, 61, 48, 44, 95, 105, 116, 101, 114, 97, 116, 105, 111, 110,
  115, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112,
  112, 108, 121, 32, 115, 116, 101, 110, 99, 105, 108, 32, 102, 105, 108, 116,
  101, 114, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 114, 97, 100, 105, 117, 115, 61, 51, 39, 44, 32, 39, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 61, 49, 39, 32, 97, 110, 100, 32, 39,
  105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 61, 56, 39, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 45, 115, 116, 101, 110, 99, 105, 108, 32, 49, 44,
  49, 48, 44, 51, 10, 115, 116, 101, 110, 99, 105, 108, 32, 58, 32, 45,
  99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 51, 125, 62, 61, 48,
  32, 38, 38, 32, 36, 123, 50, 61, 49, 125, 62, 61, 48, 32, 38, 38,
  32, 36, 123, 51, 61, 56, 125, 62, 61, 48, 34, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 115, 116, 101, 110, 99,
  105, 108, 32, 102, 105, 108, 116, 101, 114, 32, 111, 110, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 114, 97, 100, 105, 117,
  115, 32, 36, 49, 44, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  32, 36, 50, 32, 97, 110, 100, 32, 36, 51, 32, 105, 116, 101, 114, 97,
  116, 105, 111, 110, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 110, 32,
  48, 44, 49, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 51, 32, 45,
  98, 32, 36, 49, 32, 45, 117, 110, 115, 104, 97, 114, 112, 32, 123, 36,
  49, 43, 36, 50, 125, 44, 49, 48, 48, 48, 32, 45, 99, 32, 48, 44,
  50, 53, 53, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 115, 116, 101, 110, 99, 105, 108, 98, 119, 32,
  58, 32, 95, 101, 100, 103, 101, 115, 62, 61, 48, 44, 95, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 62, 61, 48, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 66, 38, 87, 32, 115, 116,
  101, 110, 99, 105, 108, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108,
  116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 101, 100, 103, 101, 115,
  61, 49, 53, 39, 32, 97, 110, 100, 32, 39, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 61, 49, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  45, 115, 116, 101, 110, 99, 105, 108, 98, 119, 32, 52, 48, 44, 52, 10,
  115, 116, 101, 110, 99, 105, 108, 98, 119, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 49, 61, 49, 53, 125, 44, 36, 123, 50, 61, 49, 48,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121,
  32, 66, 38, 87, 32, 115, 116, 101, 110, 99, 105, 108, 32, 101, 102, 102,
  101, 99, 116, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32,
  119, 105, 116, 104, 32, 101, 100, 103, 101, 115, 32, 36, 49, 32, 97, 110,
  100, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 50, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95,
  111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 117, 109, 105, 110, 97, 110,
  99, 101, 91, 48, 93, 32, 45, 110, 91, 48, 93, 32, 48, 44, 50, 53,
  53, 10, 45, 45, 101, 100, 103, 101, 115, 91, 48, 93, 32, 36, 49, 32,
  45, 113, 117, 97, 110, 116, 105, 122, 101, 91, 48, 93, 32, 51, 44, 48,
  44, 49, 32, 45, 98, 91, 48, 93, 32, 36, 50, 10, 45, 115, 104, 97,
  114, 112, 101, 110, 91, 48, 93, 32, 49, 48, 48, 48, 48, 48, 48, 32,
  45, 110, 91, 48, 93, 32, 48, 44, 49, 32, 45, 42, 91, 48, 44, 45,
  49, 93, 32, 45, 110, 91, 48, 93, 32, 48, 44, 50, 53, 53, 10, 45,
  97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 116, 101, 116, 114,
  105, 115, 32, 58, 32, 95, 115, 99, 97, 108, 101, 62, 48, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 116, 101, 116,
  114, 105, 115, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32,
  118, 97, 108, 117, 101, 58, 32, 39, 115, 99, 97, 108, 101, 61, 49, 48,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 116, 101, 116, 114, 105, 115,
  32, 49, 48, 10, 116, 101, 116, 114, 105, 115, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 49, 61, 49, 48, 125, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 116, 101, 116, 114, 105, 115,
  32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109, 97, 103, 101,
  36, 63, 44, 32, 119, 105, 116, 104, 32, 115, 99, 97, 108, 101, 32, 36,
  49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 104, 61, 123, 119,
  125, 44, 123, 104, 125, 44, 49, 44, 123, 115, 125, 32, 45, 114, 32, 36,
  49, 37, 44, 36, 49, 37, 44, 36, 49, 37, 44, 49, 48, 48, 37, 44,
  50, 32, 45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 113, 117, 97, 110,
  116, 105, 122, 101, 32, 49, 48, 44, 49, 44, 48, 32, 45, 114, 32, 36,
  119, 104, 32, 45, 98, 32, 50, 32, 45, 115, 104, 97, 114, 112, 101, 110,
  32, 51, 48, 48, 44, 49, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 119,
  97, 114, 104, 111, 108, 32, 58, 32, 95, 77, 62, 48, 44, 95, 78, 62,
  48, 44, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 62, 61, 48,
  44, 95, 99, 111, 108, 111, 114, 62, 61, 48, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 67, 114, 101, 97, 116, 101, 32, 77, 120, 78, 32, 65,
  110, 100, 121, 32, 87, 97, 114, 104, 111, 108, 45, 108, 105, 107, 101, 32,
  97, 114, 116, 119, 111, 114, 107, 32, 102, 114, 111, 109, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 77, 61, 51, 39, 44, 32, 39, 78,
  61, 77, 39, 44, 32, 39, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  61, 50, 39, 32, 97, 110, 100, 32, 39, 99, 111, 108, 111, 114, 61, 50,
  48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 119, 97, 114, 104, 111,
  108, 32, 53, 44, 51, 44, 51, 44, 52, 48, 10, 119, 97, 114, 104, 111,
  108, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 51, 125,
  44, 36, 123, 50, 61, 36, 49, 125, 44, 36, 123, 51, 61, 50, 125, 44,
  36, 123, 52, 61, 50, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 67, 114, 101, 97, 116, 101, 32, 36, 49, 120, 36, 50, 32, 65, 110,
  100, 121, 32, 87, 97, 114, 104, 111, 108, 45, 108, 105, 107, 101, 32, 97,
  114, 116, 119, 111, 114, 107, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103,
  101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 114, 48, 61, 123, 49,
  48, 48, 47, 109, 97, 120, 40, 36, 49, 44, 36, 50, 41, 125, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 110, 111, 114, 109, 32, 45, 98, 32, 36, 51, 32, 45, 114, 32,
  36, 114, 48, 37, 44, 36, 114, 48, 37, 44, 49, 44, 49, 48, 48, 37,
  44, 50, 32, 45, 113, 117, 97, 110, 116, 105, 122, 101, 32, 54, 32, 45,
  110, 32, 48, 44, 53, 32, 45, 114, 111, 117, 110, 100, 32, 49, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 36, 49, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 36, 50, 10, 40, 48, 44, 49, 44, 50, 44, 51, 44, 52, 44,
  53, 41, 32, 45, 110, 91, 45, 49, 93, 32, 51, 50, 44, 50, 50, 52,
  32, 54, 44, 49, 44, 49, 44, 50, 44, 49, 50, 56, 32, 45, 110, 111,
  105, 115, 101, 91, 45, 49, 93, 32, 36, 52, 44, 48, 32, 45, 99, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 97, 91, 45, 50, 44,
  45, 49, 93, 32, 99, 32, 45, 121, 99, 98, 99, 114, 50, 114, 103, 98,
  91, 45, 49, 93, 32, 45, 45, 109, 97, 112, 91, 48, 93, 32, 91, 45,
  49, 93, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 100, 111, 110, 101,
  32, 45, 100, 111, 110, 101, 32, 45, 97, 112, 112, 101, 110, 100, 95, 116,
  105, 108, 101, 115, 91, 94, 48, 93, 32, 36, 49, 44, 36, 50, 32, 45,
  110, 109, 91, 49, 93, 32, 64, 123, 48, 44, 110, 125, 44, 49, 32, 45,
  114, 109, 91, 48, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 119, 101,
  97, 118, 101, 32, 58, 32, 95, 100, 101, 110, 115, 105, 116, 121, 62, 61,
  48, 44, 48, 60, 61, 95, 116, 104, 105, 99, 107, 110, 101, 115, 115, 60,
  61, 49, 48, 48, 44, 48, 60, 61, 95, 115, 104, 97, 100, 111, 119, 60,
  61, 49, 48, 48, 44, 95, 115, 104, 97, 100, 105, 110, 103, 62, 61, 48,
  44, 95, 102, 105, 98, 101, 114, 115, 95, 97, 109, 112, 108, 105, 116, 117,
  100, 101, 62, 61, 48, 44, 95, 102, 105, 98, 101, 114, 115, 95, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 62, 61, 48, 44, 95, 97, 110, 103,
  108, 101, 44, 45, 49, 60, 61, 95, 120, 95, 99, 117, 114, 118, 97, 116,
  117, 114, 101, 60, 61, 49, 44, 45, 49, 60, 61, 95, 121, 95, 99, 117,
  114, 118, 97, 116, 117, 114, 101, 60, 61, 49, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 119, 101, 97, 118, 101, 32,
  101, 102, 102, 101, 99, 116, 32, 116, 111, 32, 116, 104, 101, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 39, 97, 110, 103, 108, 101, 39, 32,
  99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 48, 32, 100, 101, 103,
  46, 32, 124, 32, 49, 61, 50, 50, 46, 53, 32, 100, 101, 103, 46, 32,
  124, 32, 50, 61, 52, 53, 32, 100, 101, 103, 46, 32, 124, 32, 51, 61,
  54, 55, 46, 53, 32, 100, 101, 103, 46, 32, 125, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 100, 101, 110, 115, 105, 116, 121, 61, 54,
  39, 44, 32, 39, 116, 104, 105, 99, 107, 110, 101, 115, 115, 61, 54, 53,
  39, 44, 32, 39, 115, 104, 97, 100, 111, 119, 61, 52, 48, 39, 44, 32,
  39, 115, 104, 97, 100, 105, 110, 103, 61, 48, 46, 53, 39, 44, 32, 39,
  102, 105, 98, 101, 114, 115, 95, 97, 109, 112, 108, 105, 116, 117, 100, 101,
  61, 48, 39, 44, 32, 39, 102, 105, 98, 101, 114, 115, 95, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 61, 48, 39, 44, 32, 39, 97, 110, 103,
  108, 101, 61, 48, 39, 32, 97, 110, 100, 32, 39, 99, 117, 114, 118, 97,
  116, 117, 114, 101, 95, 120, 61, 99, 117, 114, 118, 97, 116, 117, 114, 101,
  95, 121, 61, 48, 39, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 119, 101, 97,
  118, 101, 32, 44, 10, 119, 101, 97, 118, 101, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 36, 123, 49, 61, 54, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 123, 50, 61, 54, 53, 125, 62, 61, 48, 32, 38, 38, 32,
  36, 50, 60, 61, 49, 48, 48, 32, 38, 38, 32, 36, 123, 51, 61, 52,
  48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 51, 60, 61, 49, 48, 48,
  32, 38, 38, 32, 36, 123, 52, 61, 48, 46, 53, 125, 62, 61, 48, 34,
  10, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 53, 61, 48, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 123, 54, 61, 48, 125, 62, 61, 48, 32,
  38, 38, 32, 36, 123, 55, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32,
  36, 55, 60, 61, 51, 32, 38, 38, 32, 36, 123, 56, 61, 48, 125, 62,
  61, 45, 49, 32, 38, 38, 32, 36, 56, 60, 61, 49, 32, 38, 38, 32,
  36, 123, 57, 61, 48, 125, 62, 61, 45, 49, 32, 38, 38, 32, 36, 57,
  60, 61, 49, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112,
  112, 108, 121, 32, 119, 101, 97, 118, 101, 32, 101, 102, 102, 101, 99, 116,
  32, 116, 111, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116,
  104, 32, 36, 49, 32, 115, 116, 114, 105, 112, 115, 44, 32, 116, 104, 105,
  99, 107, 110, 101, 115, 115, 32, 36, 50, 44, 32, 115, 104, 97, 100, 111,
  119, 32, 36, 51, 44, 32, 115, 104, 97, 100, 105, 110, 103, 32, 36, 52,
  44, 32, 34, 92, 10, 34, 102, 105, 98, 101, 114, 115, 32, 97, 109, 112,
  108, 105, 116, 117, 100, 101, 32, 36, 53, 32, 97, 110, 100, 32, 102, 105,
  98, 101, 114, 115, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  36, 54, 44, 32, 97, 110, 103, 108, 101, 32, 34, 123, 36, 55, 42, 50,
  50, 46, 53, 125, 34, 32, 100, 101, 103, 46, 32, 97, 110, 100, 32, 99,
  117, 114, 118, 97, 116, 117, 114, 101, 115, 32, 40, 36, 56, 44, 36, 57,
  41, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105,
  116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91, 48, 93, 10,
  119, 61, 123, 114, 111, 117, 110, 100, 40, 109, 97, 120, 40, 119, 44, 104,
  41, 47, 36, 49, 44, 49, 44, 49, 41, 125, 32, 104, 61, 36, 119, 32,
  115, 61, 123, 40, 49, 48, 48, 45, 36, 51, 41, 42, 50, 53, 53, 37,
  125, 32, 112, 61, 123, 109, 97, 120, 40, 48, 46, 48, 49, 44, 36, 52,
  41, 125, 10, 49, 44, 36, 104, 32, 45, 61, 91, 45, 49, 93, 32, 49,
  44, 48, 44, 53, 48, 37, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101,
  91, 45, 49, 93, 32, 49, 32, 45, 94, 91, 45, 49, 93, 32, 36, 112,
  32, 45, 99, 91, 45, 49, 93, 32, 53, 48, 37, 44, 49, 48, 48, 37,
  32, 45, 114, 91, 45, 49, 93, 32, 123, 109, 97, 120, 40, 49, 44, 114,
  111, 117, 110, 100, 40, 36, 50, 42, 36, 119, 37, 41, 41, 125, 44, 49,
  48, 48, 37, 10, 36, 119, 44, 49, 32, 45, 61, 91, 45, 49, 93, 32,
  49, 44, 53, 48, 37, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91,
  45, 49, 93, 32, 49, 32, 45, 94, 91, 45, 49, 93, 32, 36, 112, 32,
  45, 99, 91, 45, 49, 93, 32, 53, 48, 37, 44, 49, 48, 48, 37, 32,
  45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 114, 91, 45, 49, 93,
  32, 49, 48, 48, 37, 44, 123, 109, 97, 120, 40, 49, 44, 114, 111, 117,
  110, 100, 40, 36, 50, 42, 36, 104, 37, 41, 41, 125, 10, 45, 45, 42,
  91, 45, 49, 93, 32, 45, 49, 32, 45, 45, 42, 91, 45, 51, 93, 32,
  45, 49, 32, 45, 110, 91, 45, 52, 44, 45, 50, 93, 32, 48, 44, 36,
  115, 32, 45, 110, 91, 45, 51, 44, 45, 49, 93, 32, 36, 115, 44, 50,
  53, 53, 10, 123, 119, 125, 44, 49, 32, 49, 44, 91, 45, 51, 93, 32,
  45, 114, 97, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 48, 44, 49,
  32, 45, 98, 91, 45, 50, 44, 45, 49, 93, 32, 36, 54, 37, 32, 45,
  110, 91, 45, 50, 44, 45, 49, 93, 32, 45, 36, 53, 44, 36, 53, 32,
  45, 114, 91, 45, 49, 93, 32, 91, 45, 52, 93, 32, 45, 43, 91, 45,
  53, 93, 32, 91, 45, 49, 93, 32, 45, 43, 91, 45, 52, 44, 45, 49,
  93, 32, 45, 43, 91, 45, 53, 93, 32, 91, 45, 49, 93, 32, 45, 43,
  91, 45, 50, 44, 45, 49, 93, 10, 45, 45, 102, 91, 45, 51, 93, 32,
  50, 53, 53, 32, 45, 97, 91, 45, 52, 44, 45, 49, 93, 32, 99, 32,
  45, 45, 102, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 97, 91, 45,
  50, 44, 45, 49, 93, 32, 99, 10, 97, 109, 112, 95, 120, 61, 123, 36,
  56, 42, 40, 36, 119, 45, 119, 41, 47, 50, 125, 32, 97, 109, 112, 95,
  121, 61, 123, 36, 57, 42, 40, 36, 119, 45, 119, 41, 47, 50, 125, 10,
  45, 114, 91, 45, 52, 45, 45, 49, 93, 32, 36, 119, 44, 36, 104, 44,
  49, 44, 49, 48, 48, 37, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48,
  46, 53, 10, 45, 102, 91, 45, 52, 93, 32, 39, 105, 40, 120, 43, 36,
  97, 109, 112, 95, 120, 42, 115, 105, 110, 40, 121, 47, 104, 42, 112, 105,
  41, 44, 121, 44, 48, 44, 99, 44, 49, 44, 50, 41, 39, 32, 45, 102,
  91, 45, 49, 93, 32, 39, 105, 40, 120, 45, 36, 97, 109, 112, 95, 120,
  42, 115, 105, 110, 40, 121, 47, 104, 42, 112, 105, 41, 44, 121, 44, 48,
  44, 99, 44, 49, 44, 50, 41, 39, 10, 45, 102, 91, 45, 51, 93, 32,
  39, 105, 40, 120, 44, 121, 43, 36, 97, 109, 112, 95, 121, 42, 115, 105,
  110, 40, 120, 47, 119, 42, 112, 105, 41, 44, 48, 44, 99, 44, 49, 44,
  50, 41, 39, 32, 45, 102, 91, 45, 50, 93, 32, 39, 105, 40, 120, 44,
  121, 45, 36, 97, 109, 112, 95, 121, 42, 115, 105, 110, 40, 120, 47, 119,
  42, 112, 105, 41, 44, 48, 44, 99, 44, 49, 44, 50, 41, 39, 10, 45,
  98, 108, 101, 110, 100, 91, 45, 52, 44, 45, 51, 93, 32, 97, 108, 112,
  104, 97, 32, 45, 98, 108, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93,
  32, 97, 108, 112, 104, 97, 32, 45, 99, 91, 45, 50, 44, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 10, 45, 47, 91, 45, 50, 44, 45, 49, 93,
  32, 50, 53, 53, 32, 91, 45, 49, 93, 32, 91, 45, 51, 93, 32, 45,
  97, 91, 45, 52, 44, 45, 50, 93, 32, 120, 32, 45, 97, 91, 45, 50,
  44, 45, 49, 93, 32, 120, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93,
  32, 121, 32, 45, 114, 111, 116, 97, 116, 101, 95, 116, 105, 108, 101, 97,
  98, 108, 101, 91, 45, 49, 93, 32, 123, 36, 55, 42, 50, 50, 46, 53,
  125, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45,
  50, 93, 44, 49, 44, 49, 44, 48, 44, 50, 32, 45, 42, 91, 45, 50,
  44, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 119, 104, 105, 114, 108, 115, 32, 58,
  32, 95, 116, 101, 120, 116, 117, 114, 101, 62, 61, 48, 44, 95, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 62, 61, 48, 44, 95, 100, 97, 114,
  107, 110, 101, 115, 115, 62, 61, 48, 44, 95, 108, 105, 103, 104, 116, 110,
  101, 115, 115, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  65, 100, 100, 32, 114, 97, 110, 100, 111, 109, 32, 119, 104, 105, 114, 108,
  32, 116, 101, 120, 116, 117, 114, 101, 32, 116, 111, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 116, 101, 120, 116, 117, 114, 101, 61, 51,
  39, 44, 32, 39, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 54,
  39, 44, 32, 39, 100, 97, 114, 107, 110, 101, 115, 115, 61, 48, 46, 53,
  39, 32, 97, 110, 100, 32, 39, 108, 105, 103, 104, 116, 110, 101, 115, 115,
  61, 49, 46, 56, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 119, 104,
  105, 114, 108, 115, 32, 44, 10, 119, 104, 105, 114, 108, 115, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 51, 125, 44, 36, 123, 50,
  61, 54, 125, 44, 36, 123, 51, 61, 48, 46, 53, 125, 44, 36, 123, 52,
  61, 49, 46, 56, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65,
  100, 100, 32, 114, 97, 110, 100, 111, 109, 32, 119, 104, 105, 114, 108, 32,
  116, 101, 120, 116, 117, 114, 101, 32, 116, 111, 32, 105, 109, 97, 103, 101,
  36, 63, 44, 32, 119, 105, 116, 104, 32, 116, 101, 120, 116, 117, 114, 101,
  32, 36, 49, 44, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  36, 50, 44, 32, 100, 97, 114, 107, 110, 101, 115, 115, 32, 36, 51, 32,
  97, 110, 100, 32, 108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 36, 52,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 48,
  46, 51, 44, 50, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 32,
  45, 98, 91, 45, 49, 93, 32, 36, 50, 32, 45, 103, 114, 97, 100, 105,
  101, 110, 116, 95, 110, 111, 114, 109, 91, 45, 49, 93, 32, 45, 94, 91,
  45, 49, 93, 32, 48, 46, 50, 32, 45, 100, 111, 110, 101, 10, 45, 110,
  91, 45, 49, 93, 32, 36, 51, 44, 36, 52, 32, 45, 114, 91, 45, 49,
  93, 32, 91, 45, 50, 93, 32, 45, 42, 32, 45, 99, 32, 48, 44, 50,
  53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 58, 58, 32, 87, 97,
  114, 112, 105, 110, 103, 115, 10, 35, 64, 103, 109, 105, 99, 32, 101, 117,
  99, 108, 105, 100, 101, 97, 110, 50, 112, 111, 108, 97, 114, 32, 58, 32,
  95, 99, 120, 44, 95, 99, 121, 44, 95, 110, 62, 48, 44, 95, 98, 111,
  117, 110, 100, 97, 114, 121, 61, 123, 32, 48, 61, 100, 105, 114, 105, 99,
  104, 108, 101, 116, 32, 124, 32, 49, 61, 110, 101, 117, 109, 97, 110, 110,
  32, 124, 32, 50, 61, 99, 121, 99, 108, 105, 99, 32, 125, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 101, 117, 99,
  108, 105, 100, 101, 97, 110, 32, 116, 111, 32, 112, 111, 108, 97, 114, 32,
  116, 114, 97, 110, 115, 102, 111, 114, 109, 32, 111, 110, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 99, 120, 61, 99, 121, 61, 48, 46,
  53, 39, 44, 32, 39, 110, 61, 49, 39, 32, 97, 110, 100, 32, 39, 98,
  111, 117, 110, 100, 97, 114, 121, 61, 49, 39, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 45, 101, 117, 99, 108, 105, 100, 101, 97, 110, 50, 112, 111, 108,
  97, 114, 32, 44, 10, 101, 117, 99, 108, 105, 100, 101, 97, 110, 50, 112,
  111, 108, 97, 114, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49,
  61, 48, 46, 53, 125, 44, 36, 123, 50, 61, 48, 46, 53, 125, 44, 36,
  123, 51, 61, 49, 125, 44, 36, 123, 52, 61, 49, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 101, 117, 99, 108,
  105, 100, 101, 97, 110, 32, 116, 111, 32, 112, 111, 108, 97, 114, 32, 116,
  114, 97, 110, 115, 102, 111, 114, 109, 32, 111, 110, 32, 105, 109, 97, 103,
  101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 40, 123, 119,
  125, 44, 123, 104, 125, 41, 32, 40, 36, 49, 44, 36, 50, 41, 32, 45,
  42, 91, 45, 50, 44, 45, 49, 93, 32, 40, 123, 34, 115, 113, 114, 116,
  40, 109, 97, 120, 40, 34, 64, 123, 45, 49, 44, 48, 125, 34, 44, 34,
  64, 123, 45, 50, 44, 119, 125, 34, 45, 34, 64, 123, 45, 49, 44, 48,
  125, 34, 41, 94, 50, 32, 43, 32, 109, 97, 120, 40, 34, 64, 123, 45,
  49, 44, 49, 125, 34, 44, 34, 64, 123, 45, 50, 44, 104, 125, 34, 45,
  34, 64, 123, 45, 49, 44, 49, 125, 34, 41, 94, 50, 41, 34, 125, 41,
  10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 10, 91, 45, 50,
  93, 44, 91, 45, 50, 93, 44, 49, 44, 49, 44, 64, 123, 45, 49, 44,
  50, 125, 34, 42, 40, 120, 47, 119, 41, 94, 36, 51, 42, 99, 111, 115,
  40, 121, 42, 50, 42, 112, 105, 47, 104, 41, 34, 32, 45, 43, 91, 45,
  49, 93, 32, 64, 123, 45, 50, 44, 48, 125, 10, 91, 45, 49, 93, 44,
  91, 45, 49, 93, 44, 49, 44, 49, 44, 64, 123, 45, 50, 44, 50, 125,
  34, 42, 40, 120, 47, 119, 41, 94, 36, 51, 42, 115, 105, 110, 40, 121,
  42, 50, 42, 112, 105, 47, 104, 41, 34, 32, 45, 43, 91, 45, 49, 93,
  32, 64, 123, 45, 51, 44, 49, 125, 10, 45, 114, 109, 91, 45, 51, 93,
  32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 119, 97,
  114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 49, 44,
  36, 52, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109,
  105, 99, 32, 100, 101, 102, 111, 114, 109, 32, 58, 32, 95, 97, 109, 112,
  108, 105, 116, 117, 100, 101, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 65, 112, 112, 108, 121, 32, 114, 97, 110, 100, 111, 109, 32,
  115, 109, 111, 111, 116, 104, 32, 100, 101, 102, 111, 114, 109, 97, 116, 105,
  111, 110, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39,
  97, 109, 112, 108, 105, 116, 117, 100, 101, 61, 49, 48, 39, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 45, 100, 101, 102, 111, 114, 109, 91, 48, 93, 32,
  49, 48, 32, 45, 45, 100, 101, 102, 111, 114, 109, 91, 48, 93, 32, 50,
  48, 10, 100, 101, 102, 111, 114, 109, 32, 58, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 49, 61, 49, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 65, 112, 112, 108, 121, 32, 114, 97, 110, 100, 111, 109, 32, 115,
  109, 111, 111, 116, 104, 32, 100, 101, 102, 111, 114, 109, 97, 116, 105, 111,
  110, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105,
  116, 104, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 36, 49, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 50, 37, 44, 50, 37, 44, 49,
  44, 50, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 36, 49,
  32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50,
  93, 44, 49, 44, 50, 44, 53, 32, 45, 119, 97, 114, 112, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 44, 49, 44, 49, 44, 49, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 102, 105, 115,
  104, 101, 121, 101, 32, 58, 32, 95, 120, 44, 95, 121, 44, 48, 60, 61,
  95, 114, 97, 100, 105, 117, 115, 60, 61, 49, 48, 48, 44, 95, 97, 109,
  112, 108, 105, 116, 117, 100, 101, 62, 61, 48, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 102, 105, 115, 104, 45, 101,
  121, 101, 32, 100, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 111,
  110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 120, 61, 121,
  61, 53, 48, 39, 44, 32, 39, 114, 97, 100, 105, 117, 115, 61, 53, 48,
  39, 32, 97, 110, 100, 32, 39, 97, 109, 112, 108, 105, 116, 117, 100, 101,
  61, 49, 46, 50, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 102, 105,
  115, 104, 101, 121, 101, 32, 44, 10, 102, 105, 115, 104, 101, 121, 101, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 53, 48, 125, 44,
  36, 123, 50, 61, 53, 48, 125, 44, 36, 123, 51, 61, 53, 48, 125, 44,
  36, 123, 52, 61, 49, 46, 50, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 65, 112, 112, 108, 121, 32, 70, 105, 115, 104, 45, 101, 121, 101,
  32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109, 97, 103, 101,
  36, 63, 44, 32, 99, 101, 110, 116, 101, 114, 101, 100, 32, 97, 116, 32,
  40, 36, 49, 37, 44, 36, 50, 37, 41, 32, 119, 105, 116, 104, 32, 114,
  97, 100, 105, 117, 115, 32, 36, 51, 37, 32, 97, 110, 100, 32, 97, 109,
  112, 108, 105, 116, 117, 100, 101, 32, 36, 52, 46, 34, 10, 45, 105, 102,
  32, 123, 36, 52, 61, 61, 48, 125, 32, 45, 114, 101, 116, 117, 114, 110,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 32, 45, 61, 91,
  45, 49, 93, 32, 49, 44, 36, 49, 37, 44, 36, 50, 37, 32, 45, 100,
  105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 99,
  91, 45, 49, 93, 32, 48, 44, 36, 51, 37, 32, 45, 42, 91, 45, 49,
  93, 32, 45, 49, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 49, 32,
  45, 94, 91, 45, 49, 93, 32, 123, 49, 47, 36, 52, 125, 10, 45, 105,
  91, 45, 50, 93, 32, 40, 123, 45, 36, 49, 47, 49, 48, 48, 125, 44,
  123, 49, 45, 36, 49, 47, 49, 48, 48, 125, 59, 123, 45, 36, 49, 47,
  49, 48, 48, 125, 44, 123, 49, 45, 36, 49, 47, 49, 48, 48, 125, 94,
  123, 45, 36, 50, 47, 49, 48, 48, 125, 44, 123, 45, 36, 50, 47, 49,
  48, 48, 125, 59, 123, 49, 45, 36, 50, 47, 49, 48, 48, 125, 44, 123,
  49, 45, 36, 50, 47, 49, 48, 48, 125, 41, 32, 45, 114, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 44, 91, 45, 49, 93, 44, 49, 44, 50, 44,
  51, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 123, 109, 97, 120, 40,
  119, 44, 104, 41, 125, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 10,
  45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49,
  44, 49, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 102, 108, 111, 119, 101, 114, 32, 58, 32, 95, 97,
  109, 112, 108, 105, 116, 117, 100, 101, 44, 95, 102, 114, 101, 113, 117, 101,
  110, 99, 121, 44, 95, 111, 102, 102, 115, 101, 116, 95, 114, 91, 37, 93,
  44, 95, 97, 110, 103, 108, 101, 44, 95, 99, 120, 44, 95, 99, 121, 44,
  95, 98, 111, 117, 110, 100, 97, 114, 121, 61, 123, 32, 48, 61, 100, 105,
  114, 105, 99, 104, 108, 101, 116, 32, 124, 32, 49, 61, 110, 101, 117, 109,
  97, 110, 110, 32, 124, 32, 50, 61, 99, 121, 99, 108, 105, 99, 32, 125,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32,
  102, 108, 111, 119, 101, 114, 32, 100, 101, 102, 111, 114, 109, 97, 116, 105,
  111, 110, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 97, 109, 112, 108, 105, 116, 117, 100, 101, 61, 51, 48, 39, 44, 32,
  39, 102, 114, 101, 113, 117, 101, 110, 99, 121, 61, 54, 39, 44, 32, 39,
  111, 102, 102, 115, 101, 116, 95, 114, 61, 48, 39, 44, 32, 39, 97, 110,
  103, 108, 101, 61, 48, 39, 44, 32, 39, 99, 120, 61, 99, 121, 61, 48,
  46, 53, 39, 32, 97, 110, 100, 32, 39, 98, 111, 117, 110, 100, 97, 114,
  121, 61, 50, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 102, 108, 111, 119,
  101, 114, 32, 44, 10, 102, 108, 111, 119, 101, 114, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 49, 61, 51, 48, 125, 44, 36, 123, 50, 61,
  54, 125, 44, 36, 123, 51, 61, 48, 125, 44, 36, 123, 52, 61, 48, 125,
  44, 36, 123, 53, 61, 48, 46, 53, 125, 44, 36, 123, 54, 61, 48, 46,
  53, 125, 44, 36, 123, 55, 61, 50, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 65, 112, 112, 108, 121, 32, 102, 108, 111, 119, 101, 114, 32,
  100, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 111, 110, 32, 105,
  109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 97, 109, 112,
  108, 105, 116, 117, 100, 101, 32, 36, 49, 44, 32, 102, 114, 101, 113, 117,
  101, 110, 99, 121, 32, 36, 50, 44, 32, 111, 102, 102, 115, 101, 116, 32,
  36, 51, 44, 32, 97, 110, 103, 108, 101, 32, 36, 52, 32, 100, 101, 103,
  46, 32, 97, 110, 100, 32, 99, 101, 110, 116, 101, 114, 32, 40, 36, 49,
  44, 36, 50, 41, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 101,
  117, 99, 108, 105, 100, 101, 97, 110, 50, 112, 111, 108, 97, 114, 32, 36,
  53, 44, 36, 54, 44, 49, 44, 36, 55, 32, 45, 115, 104, 105, 102, 116,
  32, 36, 51, 44, 48, 44, 48, 44, 48, 44, 50, 10, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 121, 32, 45, 47, 91, 45,
  49, 93, 32, 123, 104, 125, 32, 45, 42, 91, 45, 49, 93, 32, 36, 50,
  32, 40, 123, 36, 52, 47, 51, 54, 48, 125, 41, 32, 45, 43, 91, 45,
  50, 93, 32, 64, 45, 49, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  42, 91, 45, 49, 93, 32, 54, 46, 50, 56, 51, 49, 56, 53, 51, 32,
  45, 115, 105, 110, 91, 45, 49, 93, 10, 45, 42, 91, 45, 49, 93, 32,
  36, 49, 32, 45, 42, 91, 45, 49, 93, 32, 123, 119, 125, 32, 45, 47,
  91, 45, 49, 93, 32, 49, 48, 48, 10, 45, 99, 104, 97, 110, 110, 101,
  108, 115, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 119, 97, 114, 112,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 49, 44, 36, 55,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 112, 111, 108, 97, 114, 50,
  101, 117, 99, 108, 105, 100, 101, 97, 110, 32, 36, 53, 44, 36, 54, 44,
  49, 44, 49, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 107, 97, 108, 101,
  105, 100, 111, 115, 99, 111, 112, 101, 32, 58, 32, 95, 99, 120, 44, 95,
  99, 121, 44, 95, 114, 97, 100, 105, 117, 115, 44, 95, 97, 110, 103, 108,
  101, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121, 61, 123, 32, 48, 61,
  100, 105, 114, 105, 99, 104, 108, 101, 116, 32, 124, 32, 49, 61, 110, 101,
  117, 109, 97, 110, 110, 32, 124, 32, 50, 61, 99, 121, 99, 108, 105, 99,
  32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 114, 101, 97,
  116, 101, 32, 107, 97, 108, 101, 105, 100, 111, 115, 99, 111, 112, 101, 32,
  101, 102, 102, 101, 99, 116, 32, 102, 114, 111, 109, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 99, 120, 61, 99, 121, 61, 48, 46, 53,
  39, 44, 32, 39, 114, 97, 100, 105, 117, 115, 61, 49, 48, 48, 39, 44,
  32, 39, 97, 110, 103, 108, 101, 61, 51, 48, 39, 32, 97, 110, 100, 32,
  39, 98, 111, 117, 110, 100, 97, 114, 121, 61, 49, 39, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 45, 107, 97, 108, 101, 105, 100, 111, 115, 99, 111, 112,
  101, 32, 44, 10, 107, 97, 108, 101, 105, 100, 111, 115, 99, 111, 112, 101,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 46, 53,
  125, 44, 36, 123, 50, 61, 48, 46, 53, 125, 44, 36, 123, 51, 61, 49,
  48, 48, 125, 44, 36, 123, 52, 61, 51, 48, 125, 44, 36, 123, 53, 61,
  49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 114, 101, 97,
  116, 101, 32, 107, 97, 108, 101, 105, 100, 111, 115, 99, 111, 112, 101, 32,
  101, 102, 102, 101, 99, 116, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103,
  101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 99, 101, 110, 116, 101, 114,
  32, 40, 36, 49, 44, 36, 50, 41, 44, 32, 114, 97, 100, 105, 117, 115,
  32, 36, 51, 44, 32, 97, 110, 103, 108, 101, 32, 36, 52, 32, 100, 101,
  103, 46, 34, 10, 45, 118, 32, 45, 32, 45, 101, 117, 99, 108, 105, 100,
  101, 97, 110, 50, 112, 111, 108, 97, 114, 32, 36, 49, 44, 36, 50, 44,
  49, 44, 36, 53, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 45, 99, 111, 108, 117, 109, 110, 115,
  32, 48, 44, 36, 51, 37, 32, 45, 114, 111, 119, 115, 91, 45, 49, 93,
  32, 48, 44, 36, 52, 37, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 44, 48, 44, 50, 32, 45, 110, 109, 91, 49, 93, 32, 64, 123,
  48, 44, 110, 125, 32, 45, 114, 109, 91, 48, 93, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 112, 111, 108, 97, 114, 50, 101,
  117, 99, 108, 105, 100, 101, 97, 110, 32, 36, 49, 44, 36, 50, 44, 49,
  44, 36, 53, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  109, 97, 112, 95, 115, 112, 104, 101, 114, 101, 32, 58, 32, 95, 119, 105,
  100, 116, 104, 62, 48, 44, 95, 104, 101, 105, 103, 104, 116, 62, 48, 44,
  95, 114, 97, 100, 105, 117, 115, 44, 95, 100, 105, 108, 97, 116, 105, 111,
  110, 62, 48, 44, 95, 102, 97, 100, 105, 110, 103, 62, 61, 48, 44, 95,
  102, 97, 100, 105, 110, 103, 95, 112, 111, 119, 101, 114, 62, 61, 48, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 77, 97, 112, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 111, 110, 32,
  97, 32, 115, 112, 104, 101, 114, 101, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  115, 58, 32, 39, 119, 105, 100, 116, 104, 61, 104, 101, 105, 103, 104, 116,
  61, 53, 49, 50, 39, 44, 32, 39, 114, 97, 100, 105, 117, 115, 61, 49,
  48, 48, 39, 44, 32, 39, 100, 105, 108, 97, 116, 105, 111, 110, 61, 48,
  46, 53, 39, 44, 32, 39, 102, 97, 100, 105, 110, 103, 61, 48, 39, 32,
  97, 110, 100, 32, 39, 102, 97, 100, 105, 110, 103, 95, 112, 111, 119, 101,
  114, 61, 48, 46, 53, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 109,
  97, 112, 95, 115, 112, 104, 101, 114, 101, 32, 44, 10, 109, 97, 112, 95,
  115, 112, 104, 101, 114, 101, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 36, 123, 49, 61, 53, 49, 50, 125, 62, 48, 32, 38, 38, 32, 36,
  123, 50, 61, 53, 49, 50, 125, 62, 48, 32, 38, 38, 32, 36, 123, 53,
  61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 54, 61, 48, 46,
  53, 125, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51,
  61, 49, 48, 48, 125, 44, 36, 123, 52, 61, 48, 46, 53, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 77, 97, 112, 32, 105, 109, 97, 103,
  101, 36, 63, 32, 111, 110, 32, 115, 112, 104, 101, 114, 101, 115, 32, 105,
  110, 32, 36, 49, 120, 36, 50, 32, 105, 109, 97, 103, 101, 115, 44, 32,
  119, 105, 116, 104, 32, 114, 97, 100, 105, 117, 115, 32, 36, 51, 44, 32,
  100, 105, 108, 97, 116, 105, 111, 110, 32, 36, 52, 32, 97, 110, 100, 32,
  102, 97, 100, 105, 110, 103, 32, 36, 53, 46, 34, 10, 45, 118, 32, 45,
  32, 114, 50, 61, 123, 40, 36, 51, 42, 109, 105, 110, 40, 36, 49, 44,
  36, 50, 41, 47, 50, 48, 48, 41, 94, 50, 125, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105,
  91, 45, 50, 93, 32, 49, 48, 48, 37, 44, 49, 44, 49, 44, 49, 48,
  48, 37, 44, 48, 32, 45, 110, 109, 91, 48, 93, 32, 64, 123, 49, 44,
  110, 125, 32, 45, 97, 32, 121, 10, 40, 123, 45, 36, 49, 47, 50, 125,
  44, 123, 36, 49, 47, 50, 125, 41, 32, 40, 123, 45, 36, 50, 47, 50,
  125, 59, 123, 36, 50, 47, 50, 125, 41, 32, 45, 114, 91, 45, 50, 44,
  45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 49, 44, 49, 44, 51, 32,
  45, 97, 116, 97, 110, 50, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32,
  45, 114, 109, 91, 45, 50, 93, 10, 36, 49, 44, 36, 50, 32, 45, 61,
  91, 45, 49, 93, 32, 49, 44, 53, 48, 37, 44, 53, 48, 37, 32, 45,
  100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 44, 51,
  32, 45, 47, 91, 45, 49, 93, 32, 36, 114, 50, 32, 45, 115, 113, 114,
  116, 91, 45, 49, 93, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 49,
  10, 45, 97, 115, 105, 110, 91, 45, 49, 93, 10, 45, 43, 91, 45, 50,
  93, 32, 123, 112, 105, 125, 32, 45, 42, 91, 45, 50, 93, 32, 123, 40,
  64, 123, 45, 51, 44, 119, 125, 45, 49, 41, 47, 40, 50, 42, 112, 105,
  41, 125, 10, 45, 42, 91, 45, 49, 93, 32, 123, 50, 47, 112, 105, 125,
  32, 45, 94, 91, 45, 49, 93, 32, 36, 52, 32, 45, 42, 91, 45, 49,
  93, 32, 123, 64, 123, 45, 51, 44, 104, 125, 45, 49, 125, 32, 45, 42,
  91, 45, 49, 93, 32, 45, 49, 32, 45, 43, 91, 45, 49, 93, 32, 123,
  64, 123, 45, 51, 44, 104, 125, 45, 49, 125, 10, 45, 105, 102, 32, 36,
  53, 32, 45, 45, 103, 101, 91, 45, 49, 93, 32, 49, 32, 45, 100, 105,
  115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 99, 91,
  45, 49, 93, 32, 48, 44, 36, 53, 37, 32, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 49, 32, 45, 94, 91, 45, 49, 93, 32, 36, 54, 32, 45,
  99, 91, 45, 50, 93, 32, 49, 44, 49, 48, 48, 37, 32, 45, 45, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114,
  91, 45, 49, 44, 45, 50, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 44, 64, 123, 45, 51, 44, 100, 125, 10, 45, 45, 102, 91, 45, 49,
  93, 32, 122, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 99, 10,
  45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48,
  44, 49, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 112, 111, 108, 97, 114, 50, 101, 117, 99, 108, 105,
  100, 101, 97, 110, 32, 58, 32, 95, 99, 120, 44, 95, 99, 121, 44, 95,
  110, 62, 48, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121, 61, 123, 32,
  48, 61, 100, 105, 114, 105, 99, 104, 108, 101, 116, 32, 124, 32, 49, 61,
  110, 101, 117, 109, 97, 110, 110, 32, 124, 32, 50, 61, 99, 121, 99, 108,
  105, 99, 32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112,
  112, 108, 121, 32, 112, 111, 108, 97, 114, 32, 116, 111, 32, 101, 117, 99,
  108, 105, 100, 101, 97, 110, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109,
  32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101,
  102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 99,
  120, 61, 99, 121, 61, 48, 46, 53, 39, 44, 32, 39, 110, 61, 49, 39,
  32, 97, 110, 100, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 61, 49,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 101, 117, 99, 108, 105, 100,
  101, 97, 110, 50, 112, 111, 108, 97, 114, 32, 44, 32, 45, 109, 105, 114,
  114, 111, 114, 91, 45, 49, 93, 32, 120, 32, 45, 112, 111, 108, 97, 114,
  50, 101, 117, 99, 108, 105, 100, 101, 97, 110, 91, 45, 49, 93, 32, 44,
  10, 112, 111, 108, 97, 114, 50, 101, 117, 99, 108, 105, 100, 101, 97, 110,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 46, 53,
  125, 44, 36, 123, 50, 61, 48, 46, 53, 125, 44, 36, 123, 51, 61, 49,
  125, 44, 36, 123, 52, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 65, 112, 112, 108, 121, 32, 112, 111, 108, 97, 114, 32, 116, 111,
  32, 101, 117, 99, 108, 105, 100, 101, 97, 110, 32, 116, 114, 97, 110, 115,
  102, 111, 114, 109, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 40, 123, 119, 125, 44, 123, 104,
  125, 41, 32, 40, 36, 49, 44, 36, 50, 41, 32, 45, 42, 91, 45, 50,
  44, 45, 49, 93, 32, 40, 123, 34, 115, 113, 114, 116, 40, 109, 97, 120,
  40, 34, 64, 123, 45, 49, 44, 48, 125, 34, 44, 34, 64, 123, 45, 50,
  44, 119, 125, 34, 45, 34, 64, 123, 45, 49, 44, 48, 125, 34, 41, 94,
  50, 32, 43, 32, 109, 97, 120, 40, 34, 64, 123, 45, 49, 44, 49, 125,
  34, 44, 34, 64, 123, 45, 50, 44, 104, 125, 34, 45, 34, 64, 123, 45,
  49, 44, 49, 125, 34, 41, 94, 50, 41, 34, 125, 41, 10, 45, 97, 91,
  45, 50, 44, 45, 49, 93, 32, 120, 10, 91, 45, 50, 93, 44, 91, 45,
  50, 93, 44, 49, 44, 49, 44, 34, 119, 42, 40, 115, 113, 114, 116, 40,
  40, 120, 45, 34, 64, 123, 45, 49, 44, 48, 125, 34, 41, 94, 50, 32,
  43, 32, 40, 121, 45, 34, 64, 123, 45, 49, 44, 49, 125, 34, 41, 94,
  50, 41, 47, 34, 64, 123, 45, 49, 44, 50, 125, 34, 41, 94, 40, 49,
  47, 36, 51, 41, 34, 10, 91, 45, 49, 93, 44, 91, 45, 49, 93, 44,
  49, 44, 49, 44, 34, 40, 97, 116, 97, 110, 50, 40, 121, 45, 34, 64,
  123, 45, 50, 44, 49, 125, 34, 44, 120, 45, 34, 64, 123, 45, 50, 44,
  48, 125, 34, 41, 42, 104, 47, 40, 50, 42, 112, 105, 41, 43, 104, 41,
  37, 104, 34, 10, 45, 114, 109, 91, 45, 51, 93, 32, 45, 97, 91, 45,
  50, 44, 45, 49, 93, 32, 99, 32, 45, 119, 97, 114, 112, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 44, 48, 44, 49, 44, 36, 52, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 114, 97,
  105, 110, 100, 114, 111, 112, 115, 32, 58, 32, 95, 97, 109, 112, 108, 105,
  116, 117, 100, 101, 44, 95, 100, 101, 110, 115, 105, 116, 121, 62, 61, 48,
  44, 95, 119, 97, 118, 101, 108, 101, 110, 103, 116, 104, 62, 61, 48, 44,
  95, 109, 101, 114, 103, 105, 110, 103, 95, 115, 116, 101, 112, 115, 62, 61,
  48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121,
  32, 114, 97, 105, 110, 100, 114, 111, 112, 115, 32, 100, 101, 102, 111, 114,
  109, 97, 116, 105, 111, 110, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117,
  101, 115, 32, 58, 32, 39, 97, 109, 112, 108, 105, 116, 117, 100, 101, 61,
  56, 48, 39, 44, 39, 100, 101, 110, 115, 105, 116, 121, 61, 48, 46, 49,
  39, 44, 32, 39, 119, 97, 118, 101, 108, 101, 110, 103, 116, 104, 61, 49,
  39, 32, 97, 110, 100, 32, 39, 109, 101, 114, 103, 105, 110, 103, 95, 115,
  116, 101, 112, 115, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45,
  114, 97, 105, 110, 100, 114, 111, 112, 115, 32, 44, 10, 114, 97, 105, 110,
  100, 114, 111, 112, 115, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  36, 123, 50, 61, 48, 46, 49, 125, 62, 61, 48, 32, 38, 38, 32, 36,
  123, 51, 61, 49, 125, 62, 61, 48, 32, 38, 38, 32, 105, 115, 105, 110,
  116, 40, 36, 123, 52, 61, 48, 125, 41, 32, 38, 38, 32, 36, 52, 62,
  61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 56, 48,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121,
  32, 114, 97, 105, 110, 100, 114, 111, 112, 115, 32, 100, 101, 102, 111, 114,
  109, 97, 116, 105, 111, 110, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 119, 105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117, 100,
  101, 32, 36, 49, 44, 32, 100, 101, 110, 115, 105, 116, 121, 32, 36, 50,
  44, 32, 119, 97, 118, 101, 108, 101, 110, 103, 116, 104, 32, 36, 51, 32,
  97, 110, 100, 32, 36, 52, 32, 109, 101, 114, 103, 105, 110, 103, 32, 115,
  116, 101, 112, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 32, 45, 110, 111, 105, 115, 101, 91, 45,
  49, 93, 32, 36, 50, 44, 50, 32, 45, 100, 105, 115, 116, 97, 110, 99,
  101, 91, 45, 49, 93, 32, 49, 32, 45, 102, 91, 45, 49, 93, 32, 39,
  99, 111, 115, 40, 105, 41, 47, 40, 49, 43, 105, 47, 36, 51, 41, 39,
  10, 45, 105, 102, 32, 36, 52, 10, 45, 105, 91, 45, 50, 93, 32, 40,
  48, 44, 49, 44, 48, 59, 49, 44, 48, 44, 49, 59, 48, 44, 49, 44,
  48, 41, 32, 45, 47, 91, 45, 50, 93, 32, 50, 32, 91, 45, 49, 93,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 52, 32, 45, 45, 99, 111,
  110, 118, 111, 108, 118, 101, 91, 45, 49, 93, 32, 91, 45, 51, 93, 44,
  49, 32, 45, 45, 91, 45, 49, 93, 32, 91, 45, 51, 93, 32, 45, 114,
  109, 91, 45, 51, 93, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91,
  45, 51, 44, 45, 50, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 103,
  114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32, 45, 97, 91, 45,
  50, 44, 45, 49, 93, 32, 99, 32, 45, 42, 91, 45, 49, 93, 32, 123,
  36, 49, 47, 40, 49, 101, 45, 53, 43, 109, 97, 120, 40, 97, 98, 115,
  40, 105, 109, 41, 44, 97, 98, 115, 40, 105, 77, 41, 41, 41, 125, 10,
  45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 114, 105, 112, 112, 108, 101, 32, 58, 32, 95, 97, 109, 112, 108, 105,
  116, 117, 100, 101, 44, 95, 102, 114, 101, 113, 117, 101, 110, 99, 121, 44,
  95, 115, 104, 97, 112, 101, 61, 123, 32, 48, 61, 98, 108, 111, 99, 32,
  124, 32, 49, 61, 116, 114, 105, 97, 110, 103, 108, 101, 32, 124, 32, 50,
  61, 115, 105, 110, 101, 32, 124, 32, 51, 61, 115, 105, 110, 101, 43, 32,
  124, 32, 52, 61, 114, 97, 110, 100, 111, 109, 32, 125, 44, 95, 97, 110,
  103, 108, 101, 44, 95, 111, 102, 102, 115, 101, 116, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 114, 105, 112, 112, 108,
  101, 32, 100, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 111, 110,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117,
  108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 97, 109, 112, 108,
  105, 116, 117, 100, 101, 61, 49, 48, 39, 44, 32, 39, 102, 114, 101, 113,
  117, 101, 110, 99, 121, 61, 49, 48, 39, 44, 32, 39, 115, 104, 97, 112,
  101, 61, 50, 39, 44, 32, 39, 97, 110, 103, 108, 101, 61, 48, 39, 32,
  97, 110, 100, 32, 39, 111, 102, 102, 115, 101, 116, 61, 48, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 45, 114, 105, 112, 112, 108, 101, 32, 44, 10,
  114, 105, 112, 112, 108, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 49, 61, 49, 48, 125, 44, 36, 123, 50, 61, 50, 48, 125, 44, 36,
  123, 51, 61, 50, 125, 44, 36, 123, 52, 61, 48, 125, 44, 36, 123, 53,
  61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112,
  108, 121, 32, 114, 105, 112, 112, 108, 101, 32, 100, 101, 102, 111, 114, 109,
  97, 116, 105, 111, 110, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63,
  44, 32, 119, 105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101,
  32, 36, 49, 44, 32, 102, 114, 101, 113, 117, 101, 110, 99, 121, 32, 36,
  50, 44, 32, 115, 104, 97, 112, 101, 32, 36, 51, 44, 32, 97, 110, 103,
  108, 101, 32, 36, 52, 32, 100, 101, 103, 46, 32, 97, 110, 100, 32, 111,
  102, 102, 115, 101, 116, 32, 36, 53, 46, 34, 10, 45, 118, 32, 45, 10,
  116, 104, 101, 116, 97, 61, 123, 36, 52, 42, 112, 105, 47, 49, 56, 48,
  125, 32, 67, 61, 123, 99, 111, 115, 40, 36, 116, 104, 101, 116, 97, 41,
  125, 32, 83, 61, 123, 45, 115, 105, 110, 40, 36, 116, 104, 101, 116, 97,
  41, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 49, 44, 34, 120, 34, 32, 45, 45, 91, 45, 49, 93, 32, 123, 119,
  47, 50, 125, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44,
  49, 44, 39, 121, 39, 10, 45, 45, 91, 45, 49, 93, 32, 123, 104, 47,
  50, 45, 36, 53, 125, 32, 45, 42, 91, 45, 50, 93, 32, 36, 83, 32,
  45, 42, 91, 45, 49, 93, 32, 36, 67, 32, 45, 43, 91, 45, 50, 44,
  45, 49, 93, 10, 45, 95, 114, 105, 112, 112, 108, 101, 36, 51, 91, 45,
  49, 93, 32, 36, 49, 44, 36, 50, 10, 45, 45, 42, 91, 45, 49, 93,
  32, 123, 45, 36, 83, 125, 32, 45, 42, 91, 45, 50, 93, 32, 36, 67,
  32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 119, 97,
  114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 95, 114, 105, 112, 112, 108, 101, 48, 32,
  58, 32, 45, 102, 32, 123, 36, 49, 47, 50, 125, 42, 34, 40, 49, 45,
  50, 42, 40, 105, 37, 34, 123, 50, 42, 36, 50, 125, 34, 60, 36, 50,
  41, 41, 34, 10, 95, 114, 105, 112, 112, 108, 101, 49, 32, 58, 32, 45,
  102, 32, 34, 73, 61, 40, 105, 37, 36, 50, 41, 47, 36, 50, 59, 36,
  49, 42, 40, 50, 42, 105, 102, 40, 73, 60, 48, 46, 53, 44, 73, 44,
  49, 45, 73, 41, 45, 48, 46, 53, 41, 34, 10, 95, 114, 105, 112, 112,
  108, 101, 50, 32, 58, 32, 45, 102, 32, 123, 45, 36, 49, 47, 50, 125,
  42, 34, 99, 111, 115, 40, 105, 42, 34, 123, 50, 42, 112, 105, 47, 36,
  50, 125, 34, 41, 34, 10, 95, 114, 105, 112, 112, 108, 101, 51, 32, 58,
  32, 45, 102, 32, 123, 45, 36, 49, 47, 50, 125, 42, 34, 97, 98, 115,
  40, 99, 111, 115, 40, 105, 42, 34, 123, 50, 42, 112, 105, 47, 36, 50,
  125, 34, 41, 41, 34, 10, 95, 114, 105, 112, 112, 108, 101, 52, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 42, 32, 45, 110, 32, 48, 44, 123,
  104, 45, 49, 125, 32, 49, 44, 123, 104, 125, 32, 45, 114, 97, 110, 100,
  91, 45, 49, 93, 32, 123, 45, 36, 49, 47, 50, 125, 44, 123, 36, 49,
  47, 50, 125, 32, 109, 61, 123, 105, 109, 125, 32, 77, 61, 123, 105, 77,
  125, 32, 45, 98, 91, 45, 49, 93, 32, 123, 36, 50, 47, 49, 48, 125,
  32, 45, 110, 91, 45, 49, 93, 32, 36, 109, 44, 36, 77, 32, 45, 109,
  97, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 35, 64, 103, 109, 105, 99, 32, 114, 111, 116, 111, 105,
  100, 111, 115, 99, 111, 112, 101, 32, 58, 32, 95, 99, 120, 44, 95, 99,
  121, 44, 95, 116, 105, 108, 101, 115, 62, 48, 44, 95, 115, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 91, 37, 93, 62, 61, 48, 44, 95, 98, 111,
  117, 110, 100, 97, 114, 121, 61, 123, 32, 48, 61, 100, 105, 114, 105, 99,
  104, 108, 101, 116, 32, 124, 32, 49, 61, 110, 101, 117, 109, 97, 110, 110,
  32, 124, 32, 50, 61, 99, 121, 99, 108, 105, 99, 32, 125, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 67, 114, 101, 97, 116, 101, 32, 114, 111,
  116, 97, 116, 105, 111, 110, 97, 108, 32, 107, 97, 108, 101, 105, 100, 111,
  115, 99, 111, 112, 101, 32, 101, 102, 102, 101, 99, 116, 32, 102, 114, 111,
  109, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 99, 120, 61,
  99, 121, 61, 53, 48, 37, 39, 44, 32, 39, 116, 105, 108, 101, 115, 61,
  49, 48, 39, 44, 32, 39, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  61, 49, 39, 32, 97, 110, 100, 32, 39, 98, 111, 117, 110, 100, 97, 114,
  121, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 114, 111, 116,
  111, 105, 100, 111, 115, 99, 111, 112, 101, 32, 44, 10, 114, 111, 116, 111,
  105, 100, 111, 115, 99, 111, 112, 101, 32, 58, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 49, 61, 53, 48, 37, 125, 44, 36, 123, 50, 61, 53, 48,
  37, 125, 44, 36, 123, 53, 61, 49, 125, 32, 45, 99, 104, 101, 99, 107,
  32, 34, 36, 123, 51, 61, 49, 48, 125, 62, 48, 32, 38, 38, 32, 36,
  123, 52, 61, 49, 125, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 114, 101, 97, 116, 101, 32, 114, 111, 116, 97, 116, 105,
  111, 110, 97, 108, 32, 107, 97, 108, 101, 105, 100, 111, 115, 99, 111, 112,
  101, 32, 101, 102, 102, 101, 99, 116, 32, 102, 114, 111, 109, 32, 105, 109,
  97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 99, 101, 110, 116,
  101, 114, 32, 40, 36, 49, 44, 36, 50, 41, 44, 32, 36, 51, 32, 116,
  105, 108, 101, 115, 32, 97, 110, 100, 32, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 36, 52, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 36, 51, 32, 45, 45, 114, 111, 116,
  97, 116, 101, 91, 48, 93, 32, 123, 51, 54, 48, 47, 36, 51, 125, 44,
  49, 44, 36, 53, 44, 36, 49, 44, 36, 50, 32, 45, 98, 108, 101, 110,
  100, 95, 101, 100, 103, 101, 115, 32, 36, 52, 32, 45, 100, 111, 110, 101,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 121, 109, 109, 101, 116, 114,
  105, 122, 101, 32, 58, 32, 95, 120, 91, 37, 93, 44, 95, 121, 91, 37,
  93, 44, 95, 97, 110, 103, 108, 101, 44, 95, 98, 111, 117, 110, 100, 97,
  114, 121, 61, 123, 32, 48, 61, 100, 105, 114, 105, 99, 104, 108, 101, 116,
  32, 124, 32, 49, 61, 110, 101, 117, 109, 97, 110, 110, 32, 124, 32, 50,
  61, 99, 121, 99, 108, 105, 99, 32, 125, 44, 95, 105, 115, 95, 97, 110,
  116, 105, 115, 121, 109, 109, 101, 116, 114, 121, 61, 123, 32, 48, 32, 124,
  32, 49, 32, 125, 44, 95, 115, 119, 97, 112, 95, 115, 105, 100, 101, 115,
  61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 83, 121, 109, 109, 101, 116, 114, 105, 122, 101, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 32, 114, 101,
  103, 97, 114, 100, 105, 110, 103, 32, 115, 112, 101, 99, 105, 102, 105, 101,
  100, 32, 97, 120, 105, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58,
  32, 39, 120, 61, 121, 61, 53, 48, 37, 39, 44, 32, 39, 97, 110, 103,
  108, 101, 61, 57, 48, 39, 44, 32, 39, 98, 111, 117, 110, 100, 97, 114,
  121, 61, 49, 39, 44, 32, 39, 105, 115, 95, 97, 110, 116, 105, 115, 121,
  109, 109, 101, 116, 114, 121, 61, 48, 39, 32, 97, 110, 100, 32, 39, 115,
  119, 97, 112, 95, 115, 105, 100, 101, 115, 61, 48, 39, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 45, 115, 121, 109, 109, 101, 116, 114, 105, 122, 101, 32,
  53, 48, 37, 44, 53, 48, 37, 44, 52, 53, 32, 45, 45, 115, 121, 109,
  109, 101, 116, 114, 105, 122, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44,
  53, 48, 37, 44, 45, 52, 53, 10, 115, 121, 109, 109, 101, 116, 114, 105,
  122, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 53,
  48, 37, 125, 44, 36, 123, 50, 61, 53, 48, 37, 125, 44, 36, 123, 51,
  61, 57, 48, 125, 44, 36, 123, 52, 61, 49, 125, 44, 36, 123, 53, 61,
  48, 125, 44, 36, 123, 54, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 83, 121, 109, 109, 101, 116, 114, 105, 122, 101, 32, 105, 109,
  97, 103, 101, 36, 63, 44, 32, 114, 101, 103, 97, 114, 100, 105, 110, 103,
  32, 97, 120, 105, 115, 32, 40, 36, 49, 44, 36, 50, 44, 36, 51, 32,
  100, 101, 103, 46, 41, 46, 34, 10, 45, 118, 32, 45, 10, 116, 104, 101,
  116, 97, 61, 123, 36, 51, 42, 112, 105, 47, 49, 56, 48, 125, 32, 117,
  61, 123, 99, 111, 115, 40, 36, 116, 104, 101, 116, 97, 41, 125, 32, 118,
  61, 123, 115, 105, 110, 40, 36, 116, 104, 101, 116, 97, 41, 125, 10, 45,
  105, 102, 32, 36, 54, 32, 115, 121, 109, 109, 101, 116, 114, 121, 95, 99,
  111, 110, 100, 61, 65, 60, 48, 32, 45, 101, 108, 115, 101, 32, 115, 121,
  109, 109, 101, 116, 114, 121, 95, 99, 111, 110, 100, 61, 65, 62, 48, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 120, 48, 61, 123, 105, 102, 40,
  64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36,
  49, 125, 44, 119, 42, 36, 49, 44, 36, 49, 41, 125, 10, 121, 48, 61,
  123, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110,
  116, 92, 32, 36, 50, 125, 44, 104, 42, 36, 50, 44, 36, 50, 41, 125,
  10, 45, 105, 102, 32, 36, 53, 32, 45, 102, 32, 39, 65, 61, 40, 36,
  121, 48, 45, 121, 41, 42, 36, 117, 45, 40, 36, 120, 48, 45, 120, 41,
  42, 36, 118, 59, 88, 61, 120, 43, 50, 42, 40, 36, 120, 48, 45, 120,
  41, 59, 89, 61, 121, 43, 50, 42, 40, 36, 121, 48, 45, 121, 41, 59,
  105, 102, 40, 36, 115, 121, 109, 109, 101, 116, 114, 121, 95, 99, 111, 110,
  100, 44, 105, 40, 88, 44, 89, 44, 122, 44, 99, 44, 49, 44, 36, 52,
  41, 44, 105, 41, 39, 10, 45, 101, 108, 115, 101, 32, 45, 102, 32, 39,
  65, 61, 40, 36, 121, 48, 45, 121, 41, 42, 36, 117, 45, 40, 36, 120,
  48, 45, 120, 41, 42, 36, 118, 59, 88, 61, 120, 45, 50, 42, 36, 118,
  42, 65, 59, 89, 61, 121, 43, 50, 42, 36, 117, 42, 65, 59, 105, 102,
  40, 36, 115, 121, 109, 109, 101, 116, 114, 121, 95, 99, 111, 110, 100, 44,
  105, 40, 88, 44, 89, 44, 122, 44, 99, 44, 49, 44, 36, 52, 41, 44,
  105, 41, 39, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 45, 118, 32, 43, 10, 35, 64, 103, 109,
  105, 99, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 95, 112, 111, 108,
  97, 114, 32, 58, 32, 34, 101, 120, 112, 114, 95, 114, 97, 100, 105, 117,
  115, 34, 44, 95, 34, 101, 120, 112, 114, 95, 97, 110, 103, 108, 101, 34,
  44, 95, 120, 95, 99, 101, 110, 116, 101, 114, 44, 95, 121, 95, 99, 101,
  110, 116, 101, 114, 44, 95, 98, 111, 117, 110, 100, 97, 114, 121, 61, 123,
  32, 48, 61, 100, 105, 114, 105, 99, 104, 108, 101, 116, 32, 124, 32, 49,
  61, 110, 101, 117, 109, 97, 110, 110, 32, 125, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 117, 115, 101, 114, 45, 100,
  101, 102, 105, 110, 101, 100, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109,
  32, 111, 110, 32, 112, 111, 108, 97, 114, 32, 114, 101, 112, 114, 101, 115,
  101, 110, 116, 97, 116, 105, 111, 110, 32, 111, 102, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 101, 120, 112, 114, 95, 114, 97, 100, 105,
  117, 115, 61, 82, 45, 114, 39, 44, 32, 39, 101, 120, 112, 114, 95, 114,
  97, 110, 103, 108, 101, 61, 97, 39, 44, 32, 39, 120, 95, 99, 101, 110,
  116, 101, 114, 61, 121, 95, 99, 101, 110, 116, 101, 114, 61, 53, 48, 39,
  32, 97, 110, 100, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 61, 49,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 116, 114, 97, 110, 115, 102,
  111, 114, 109, 95, 112, 111, 108, 97, 114, 91, 48, 93, 32, 82, 42, 40,
  114, 47, 82, 41, 94, 50, 44, 97, 32, 45, 45, 116, 114, 97, 110, 115,
  102, 111, 114, 109, 95, 112, 111, 108, 97, 114, 91, 48, 93, 32, 114, 44,
  50, 42, 97, 10, 116, 114, 97, 110, 115, 102, 111, 114, 109, 95, 112, 111,
  108, 97, 114, 32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36, 123, 49,
  61, 82, 45, 114, 125, 34, 44, 34, 36, 123, 50, 61, 97, 125, 34, 44,
  36, 123, 51, 61, 53, 48, 125, 44, 36, 123, 52, 61, 53, 48, 125, 44,
  36, 123, 53, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  65, 112, 112, 108, 121, 32, 99, 117, 115, 116, 111, 109, 32, 112, 111, 108,
  97, 114, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32, 119, 105, 116,
  104, 32, 39, 110, 101, 119, 95, 114, 32, 61, 32, 36, 49, 39, 44, 32,
  39, 110, 101, 119, 95, 97, 32, 61, 32, 36, 50, 39, 44, 32, 99, 101,
  110, 116, 101, 114, 101, 100, 32, 97, 116, 32, 40, 36, 51, 37, 44, 36,
  52, 37, 41, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 82, 61, 123,
  34, 115, 113, 114, 116, 40, 40, 109, 97, 120, 40, 36, 51, 44, 49, 48,
  48, 45, 36, 51, 41, 42, 119, 47, 49, 48, 48, 41, 94, 50, 32, 43,
  32, 40, 109, 97, 120, 40, 36, 52, 44, 49, 48, 48, 45, 36, 52, 41,
  42, 104, 47, 49, 48, 48, 41, 94, 50, 41, 34, 125, 10, 119, 61, 123,
  34, 36, 51, 42, 119, 47, 49, 48, 48, 34, 125, 10, 104, 61, 123, 34,
  36, 52, 42, 104, 47, 49, 48, 48, 34, 125, 10, 45, 102, 32, 34, 82,
  32, 61, 34, 36, 82, 34, 59, 10, 114, 32, 61, 32, 115, 113, 114, 116,
  40, 40, 120, 45, 34, 36, 119, 34, 41, 94, 50, 32, 43, 32, 40, 121,
  45, 34, 36, 104, 34, 41, 94, 50, 41, 59, 10, 97, 32, 61, 32, 97,
  116, 97, 110, 50, 40, 121, 45, 34, 36, 104, 34, 44, 120, 45, 34, 36,
  119, 34, 41, 59, 10, 110, 114, 32, 61, 32, 36, 49, 59, 10, 110, 97,
  32, 61, 32, 36, 50, 59, 10, 105, 40, 34, 36, 119, 34, 32, 43, 32,
  110, 114, 42, 99, 111, 115, 40, 110, 97, 41, 44, 32, 34, 36, 104, 34,
  32, 43, 32, 110, 114, 42, 115, 105, 110, 40, 110, 97, 41, 44, 32, 122,
  44, 32, 99, 44, 32, 49, 44, 36, 53, 41, 34, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 116, 119, 105, 114, 108, 32, 58, 32, 95, 97, 109, 112,
  108, 105, 116, 117, 100, 101, 44, 95, 99, 120, 44, 95, 99, 121, 44, 95,
  98, 111, 117, 110, 100, 97, 114, 121, 61, 123, 32, 48, 61, 100, 105, 114,
  105, 99, 104, 108, 101, 116, 32, 124, 32, 49, 61, 110, 101, 117, 109, 97,
  110, 110, 32, 124, 32, 50, 61, 99, 121, 99, 108, 105, 99, 32, 125, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 116,
  119, 105, 114, 108, 32, 100, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110,
  32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101,
  102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 97,
  109, 112, 108, 105, 116, 117, 100, 101, 61, 49, 39, 44, 32, 39, 99, 120,
  61, 99, 121, 61, 48, 46, 53, 39, 32, 97, 110, 100, 32, 39, 98, 111,
  117, 110, 100, 97, 114, 121, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 45, 116, 119, 105, 114, 108, 32, 48, 46, 54, 10, 116, 119, 105, 114,
  108, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 125,
  44, 36, 123, 50, 61, 48, 46, 53, 125, 44, 36, 123, 51, 61, 48, 46,
  53, 125, 44, 36, 123, 52, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 65, 112, 112, 108, 121, 32, 116, 119, 105, 114, 108, 32, 100,
  101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 111, 110, 32, 105, 109,
  97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 97, 109, 112, 108,
  105, 116, 117, 100, 101, 32, 36, 49, 32, 97, 110, 100, 32, 99, 101, 110,
  116, 101, 114, 32, 97, 116, 32, 40, 36, 50, 37, 44, 36, 51, 37, 41,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 101, 117, 99, 108, 105, 100, 101,
  97, 110, 50, 112, 111, 108, 97, 114, 32, 36, 50, 44, 36, 51, 44, 49,
  44, 36, 52, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 91,
  36, 62, 93, 44, 91, 36, 62, 93, 44, 49, 44, 49, 44, 36, 49, 42,
  120, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32,
  45, 49, 44, 48, 32, 45, 119, 97, 114, 112, 91, 36, 62, 93, 32, 91,
  45, 49, 93, 44, 49, 44, 49, 44, 50, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 100, 111, 110, 101, 32, 45, 112, 111, 108, 97, 114, 50, 101,
  117, 99, 108, 105, 100, 101, 97, 110, 32, 36, 50, 44, 36, 51, 44, 49,
  44, 49, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 119,
  97, 114, 112, 95, 112, 101, 114, 115, 112, 101, 99, 116, 105, 118, 101, 32,
  58, 32, 95, 120, 45, 97, 110, 103, 108, 101, 44, 95, 121, 45, 97, 110,
  103, 108, 101, 44, 95, 122, 111, 111, 109, 62, 48, 44, 95, 120, 45, 99,
  101, 110, 116, 101, 114, 44, 95, 121, 45, 99, 101, 110, 116, 101, 114, 44,
  95, 98, 111, 117, 110, 100, 97, 114, 121, 61, 123, 32, 48, 61, 100, 105,
  114, 105, 99, 104, 108, 101, 116, 32, 124, 32, 49, 61, 110, 101, 117, 109,
  97, 110, 110, 32, 124, 32, 50, 61, 99, 121, 99, 108, 105, 99, 32, 125,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 87, 97, 114, 112, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 119,
  105, 116, 104, 32, 112, 101, 114, 115, 112, 101, 99, 116, 105, 118, 101, 32,
  100, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 120, 45, 97, 110, 103, 108, 101, 61, 49,
  46, 53, 39, 44, 32, 39, 121, 45, 97, 110, 103, 108, 101, 61, 48, 39,
  44, 32, 39, 122, 111, 111, 109, 61, 49, 39, 44, 32, 39, 120, 45, 99,
  101, 110, 116, 101, 114, 61, 121, 45, 99, 101, 110, 116, 101, 114, 61, 53,
  48, 39, 32, 97, 110, 100, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121,
  61, 50, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 119, 97, 114, 112,
  95, 112, 101, 114, 115, 112, 101, 99, 116, 105, 118, 101, 32, 44, 10, 119,
  97, 114, 112, 95, 112, 101, 114, 115, 112, 101, 99, 116, 105, 118, 101, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 46, 53, 125,
  44, 36, 123, 50, 61, 48, 125, 44, 36, 123, 51, 61, 49, 125, 44, 36,
  123, 52, 61, 53, 48, 125, 44, 36, 123, 53, 61, 53, 48, 125, 44, 36,
  123, 54, 61, 50, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65,
  112, 112, 108, 121, 32, 112, 101, 114, 115, 112, 101, 99, 116, 105, 118, 101,
  32, 119, 97, 114, 112, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63,
  44, 32, 119, 105, 116, 104, 32, 97, 110, 103, 108, 101, 115, 32, 40, 36,
  49, 32, 100, 101, 103, 46, 44, 36, 50, 32, 100, 101, 103, 46, 41, 44,
  32, 122, 111, 111, 109, 32, 36, 51, 32, 97, 110, 100, 32, 111, 102, 102,
  115, 101, 116, 115, 32, 40, 36, 52, 44, 36, 53, 41, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 40, 48, 44, 49, 48, 48, 41, 32, 45, 45,
  91, 45, 49, 93, 32, 36, 52, 32, 45, 47, 91, 45, 49, 93, 32, 49,
  48, 48, 32, 40, 48, 59, 49, 48, 48, 41, 32, 45, 45, 91, 45, 49,
  93, 32, 36, 53, 32, 45, 47, 91, 45, 49, 93, 32, 49, 48, 48, 32,
  45, 114, 91, 45, 50, 44, 45, 49, 93, 32, 91, 45, 51, 93, 44, 91,
  45, 51, 93, 44, 91, 45, 51, 93, 44, 49, 44, 51, 10, 45, 45, 42,
  91, 45, 50, 93, 32, 36, 50, 32, 45, 45, 42, 91, 45, 50, 93, 32,
  36, 49, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 43, 91,
  45, 49, 93, 32, 36, 51, 32, 45, 47, 91, 45, 51, 93, 32, 91, 45,
  49, 93, 32, 45, 47, 91, 45, 50, 44, 45, 49, 93, 10, 45, 42, 91,
  45, 50, 93, 32, 49, 48, 48, 32, 45, 43, 91, 45, 50, 93, 32, 36,
  52, 32, 45, 47, 91, 45, 50, 93, 32, 49, 48, 48, 32, 45, 42, 91,
  45, 50, 93, 32, 64, 123, 45, 51, 44, 119, 125, 10, 45, 42, 91, 45,
  49, 93, 32, 49, 48, 48, 32, 45, 43, 91, 45, 49, 93, 32, 36, 53,
  32, 45, 47, 91, 45, 49, 93, 32, 49, 48, 48, 32, 45, 42, 91, 45,
  49, 93, 32, 64, 123, 45, 51, 44, 104, 125, 10, 45, 97, 91, 45, 50,
  44, 45, 49, 93, 32, 99, 32, 45, 119, 97, 114, 112, 91, 45, 50, 93,
  32, 91, 45, 49, 93, 44, 48, 44, 49, 44, 36, 54, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 119, 97, 116,
  101, 114, 32, 58, 32, 95, 97, 109, 112, 108, 105, 116, 117, 100, 101, 62,
  61, 48, 44, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 62, 61,
  48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108, 121,
  32, 119, 97, 116, 101, 114, 32, 100, 101, 102, 111, 114, 109, 97, 116, 105,
  111, 110, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 97, 109, 112, 108, 105, 116, 117, 100, 101, 61, 51, 48, 39, 32, 97,
  110, 100, 32, 39, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 49,
  46, 53, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 119, 97, 116, 101,
  114, 32, 44, 10, 119, 97, 116, 101, 114, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 49, 61, 51, 48, 125, 44, 36, 123, 50, 61, 49, 46,
  53, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108,
  121, 32, 119, 97, 116, 101, 114, 32, 100, 101, 102, 111, 114, 109, 97, 116,
  105, 111, 110, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32,
  119, 105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 36,
  49, 32, 97, 110, 100, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 50, 53, 37,
  44, 50, 53, 37, 44, 50, 53, 37, 44, 49, 32, 45, 110, 111, 105, 115,
  101, 91, 45, 49, 93, 32, 36, 49, 32, 45, 103, 91, 45, 49, 93, 32,
  120, 121, 122, 32, 45, 43, 91, 45, 49, 44, 45, 50, 44, 45, 51, 93,
  32, 45, 98, 91, 45, 49, 93, 32, 36, 50, 32, 45, 42, 91, 45, 49,
  93, 32, 50, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44,
  91, 45, 50, 93, 44, 49, 44, 50, 44, 51, 32, 45, 119, 97, 114, 112,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 119, 97, 118, 101,
  32, 58, 32, 95, 97, 109, 112, 108, 105, 116, 117, 100, 101, 62, 61, 48,
  44, 95, 102, 114, 101, 113, 117, 101, 110, 99, 121, 62, 61, 48, 44, 95,
  99, 101, 110, 116, 101, 114, 95, 120, 44, 95, 99, 101, 110, 116, 101, 114,
  95, 121, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 112, 112, 108,
  121, 32, 119, 97, 118, 101, 32, 100, 101, 102, 111, 114, 109, 97, 116, 105,
  111, 110, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 97, 109, 112, 108, 105, 116, 117, 100, 101, 61, 52, 39, 44, 32, 39,
  102, 114, 101, 113, 117, 101, 110, 99, 121, 61, 48, 46, 52, 39, 32, 97,
  110, 100, 32, 39, 99, 101, 110, 116, 101, 114, 95, 120, 61, 99, 101, 110,
  116, 101, 114, 95, 121, 61, 53, 48, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 45, 119, 97, 118, 101, 32, 44, 10, 119, 97, 118, 101, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 52, 125, 44, 36, 123, 50,
  61, 48, 46, 52, 125, 44, 36, 123, 51, 61, 53, 48, 125, 44, 36, 123,
  52, 61, 53, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65,
  112, 112, 108, 121, 32, 119, 97, 118, 101, 32, 100, 101, 102, 111, 114, 109,
  97, 116, 105, 111, 110, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63,
  44, 32, 119, 105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101,
  32, 36, 49, 44, 32, 102, 114, 101, 113, 117, 101, 110, 99, 121, 32, 36,
  50, 32, 97, 110, 100, 32, 99, 101, 110, 116, 101, 114, 32, 97, 116, 32,
  40, 36, 51, 37, 44, 36, 52, 37, 41, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 61, 91,
  45, 49, 93, 32, 49, 44, 36, 51, 37, 44, 36, 52, 37, 32, 45, 100,
  105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 10, 45, 42,
  91, 45, 49, 93, 32, 36, 50, 32, 45, 45, 115, 105, 110, 91, 45, 49,
  93, 32, 45, 99, 111, 115, 91, 45, 50, 93, 32, 45, 97, 91, 45, 50,
  44, 45, 49, 93, 32, 99, 32, 45, 42, 91, 45, 49, 93, 32, 36, 49,
  10, 45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44,
  49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 119, 105, 110, 100, 32, 58, 32, 95, 97, 109, 112, 108, 105, 116,
  117, 100, 101, 62, 61, 48, 44, 95, 97, 110, 103, 108, 101, 44, 48, 60,
  61, 95, 97, 116, 116, 101, 110, 117, 97, 116, 105, 111, 110, 60, 61, 49,
  44, 95, 116, 104, 114, 101, 115, 104, 111, 108, 100, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 119, 105, 110, 100, 32,
  101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117,
  101, 115, 58, 32, 39, 97, 109, 112, 108, 105, 116, 117, 100, 101, 61, 50,
  48, 39, 44, 32, 39, 97, 110, 103, 108, 101, 61, 48, 39, 44, 32, 39,
  97, 116, 116, 101, 110, 117, 97, 116, 105, 111, 110, 61, 48, 46, 55, 39,
  32, 97, 110, 100, 32, 39, 116, 104, 114, 101, 115, 104, 111, 108, 100, 61,
  50, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 119, 105, 110, 100,
  32, 44, 10, 119, 105, 110, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 34, 105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 50, 48, 125, 41,
  32, 38, 38, 32, 36, 49, 62, 61, 48, 32, 38, 38, 32, 36, 123, 51,
  61, 48, 46, 55, 125, 62, 61, 48, 32, 38, 38, 32, 36, 51, 60, 61,
  49, 34, 32, 45, 115, 107, 105, 112, 32, 34, 36, 123, 50, 61, 48, 125,
  44, 36, 123, 52, 61, 50, 48, 125, 34, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 65, 112, 112, 108, 121, 32, 119, 105, 110, 100, 32, 101, 102,
  102, 101, 99, 116, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 119, 105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32,
  36, 49, 44, 32, 97, 110, 103, 108, 101, 32, 34, 123, 114, 111, 117, 110,
  100, 40, 36, 50, 47, 52, 53, 41, 42, 52, 53, 125, 34, 32, 100, 101,
  103, 46, 44, 32, 97, 116, 116, 101, 110, 117, 97, 116, 105, 111, 110, 32,
  36, 51, 32, 97, 110, 100, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100,
  32, 36, 52, 46, 34, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 123,
  33, 36, 49, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110,
  100, 105, 102, 10, 100, 120, 100, 121, 61, 64, 123, 45, 95, 119, 105, 110,
  100, 123, 114, 111, 117, 110, 100, 40, 36, 50, 47, 52, 53, 41, 37, 56,
  125, 125, 10, 102, 97, 99, 116, 61, 123, 40, 49, 45, 36, 51, 41, 94,
  40, 49, 47, 36, 49, 41, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 103, 114, 97, 100,
  105, 101, 110, 116, 95, 110, 111, 114, 109, 32, 45, 103, 101, 91, 45, 49,
  93, 32, 36, 52, 37, 10, 115, 117, 109, 61, 64, 123, 45, 49, 44, 43,
  125, 32, 45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 44, 91, 45, 50, 93, 32, 45, 42, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49,
  10, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 36, 100, 120, 100,
  121, 44, 48, 44, 48, 44, 48, 32, 45, 109, 97, 120, 91, 45, 50, 93,
  32, 91, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 36, 102, 97,
  99, 116, 10, 45, 114, 101, 109, 111, 118, 101, 95, 112, 105, 120, 101, 108,
  115, 91, 45, 49, 93, 32, 123, 49, 48, 48, 47, 36, 49, 125, 44, 36,
  115, 117, 109, 10, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 95, 119, 105, 110, 100, 48, 32, 58, 32, 45, 117, 32, 49,
  44, 48, 10, 95, 119, 105, 110, 100, 49, 32, 58, 32, 45, 117, 32, 49,
  44, 49, 10, 95, 119, 105, 110, 100, 50, 32, 58, 32, 45, 117, 32, 48,
  44, 49, 10, 95, 119, 105, 110, 100, 51, 32, 58, 32, 45, 117, 32, 45,
  49, 44, 49, 10, 95, 119, 105, 110, 100, 52, 32, 58, 32, 45, 117, 32,
  45, 49, 44, 48, 10, 95, 119, 105, 110, 100, 53, 32, 58, 32, 45, 117,
  32, 45, 49, 44, 45, 49, 10, 95, 119, 105, 110, 100, 54, 32, 58, 32,
  45, 117, 32, 48, 44, 45, 49, 10, 95, 119, 105, 110, 100, 55, 32, 58,
  32, 45, 117, 32, 49, 44, 45, 49, 10, 35, 64, 103, 109, 105, 99, 32,
  122, 111, 111, 109, 32, 58, 32, 95, 102, 97, 99, 116, 111, 114, 44, 95,
  99, 120, 44, 95, 99, 121, 44, 95, 99, 122, 44, 95, 98, 111, 117, 110,
  100, 97, 114, 121, 61, 123, 32, 48, 61, 100, 105, 114, 105, 99, 104, 108,
  101, 116, 32, 124, 32, 49, 61, 110, 101, 117, 109, 97, 110, 110, 32, 124,
  32, 50, 61, 99, 121, 99, 108, 105, 99, 32, 125, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 65, 112, 112, 108, 121, 32, 122, 111, 111, 109, 32,
  102, 97, 99, 116, 111, 114, 32, 116, 111, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117,
  101, 115, 58, 32, 39, 102, 97, 99, 116, 111, 114, 61, 49, 39, 44, 32,
  39, 99, 120, 61, 99, 121, 61, 99, 122, 61, 48, 46, 53, 39, 32, 97,
  110, 100, 32, 39, 98, 111, 117, 110, 100, 97, 114, 121, 61, 48, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 122, 111, 111, 109, 91, 48, 93, 32,
  48, 46, 54, 32, 45, 45, 122, 111, 111, 109, 91, 48, 93, 32, 49, 46,
  53, 10, 122, 111, 111, 109, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 49, 61, 50, 125, 44, 36, 123, 50, 61, 48, 46, 53, 125, 44, 36,
  123, 51, 61, 48, 46, 53, 125, 44, 36, 123, 52, 61, 48, 46, 53, 125,
  44, 36, 123, 53, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 65, 112, 112, 108, 121, 32, 122, 111, 111, 109, 32, 101, 102, 102, 101,
  99, 116, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119,
  105, 116, 104, 32, 102, 97, 99, 116, 111, 114, 32, 36, 49, 32, 97, 110,
  100, 32, 99, 101, 110, 116, 101, 114, 32, 40, 36, 50, 44, 36, 51, 41,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 100,
  61, 61, 49, 125, 10, 40, 123, 40, 119, 45, 49, 41, 42, 36, 50, 42,
  40, 49, 45, 49, 47, 36, 49, 41, 125, 44, 123, 40, 119, 45, 49, 41,
  42, 40, 36, 50, 43, 40, 49, 45, 36, 50, 41, 47, 36, 49, 41, 125,
  41, 10, 40, 123, 40, 64, 123, 45, 50, 44, 104, 125, 45, 49, 41, 42,
  36, 51, 42, 40, 49, 45, 49, 47, 36, 49, 41, 125, 59, 123, 40, 64,
  123, 45, 50, 44, 104, 125, 45, 49, 41, 42, 40, 36, 51, 43, 40, 49,
  45, 36, 51, 41, 47, 36, 49, 41, 125, 41, 10, 45, 114, 91, 45, 50,
  45, 45, 49, 93, 32, 91, 45, 51, 93, 44, 91, 45, 51, 93, 44, 49,
  44, 49, 44, 51, 32, 45, 97, 91, 45, 50, 45, 45, 49, 93, 32, 99,
  32, 45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44,
  48, 44, 49, 44, 36, 53, 10, 45, 101, 108, 115, 101, 10, 40, 123, 40,
  119, 45, 49, 41, 42, 36, 50, 42, 40, 49, 45, 49, 47, 36, 49, 41,
  125, 44, 123, 40, 119, 45, 49, 41, 42, 40, 36, 50, 43, 40, 49, 45,
  36, 50, 41, 47, 36, 49, 41, 125, 41, 10, 40, 123, 40, 64, 123, 45,
  50, 44, 104, 125, 45, 49, 41, 42, 36, 51, 42, 40, 49, 45, 49, 47,
  36, 49, 41, 125, 59, 123, 40, 64, 123, 45, 50, 44, 104, 125, 45, 49,
  41, 42, 40, 36, 51, 43, 40, 49, 45, 36, 51, 41, 47, 36, 49, 41,
  125, 41, 10, 40, 123, 40, 64, 123, 45, 51, 44, 100, 125, 45, 49, 41,
  42, 36, 52, 42, 40, 49, 45, 49, 47, 36, 49, 41, 125, 47, 123, 40,
  64, 123, 45, 51, 44, 100, 125, 45, 49, 41, 42, 40, 36, 52, 43, 40,
  49, 45, 36, 52, 41, 47, 36, 49, 41, 125, 41, 10, 45, 114, 91, 45,
  51, 45, 45, 49, 93, 32, 91, 45, 52, 93, 44, 91, 45, 52, 93, 44,
  91, 45, 52, 93, 44, 49, 44, 51, 32, 45, 97, 91, 45, 51, 45, 45,
  49, 93, 32, 99, 32, 45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91,
  45, 49, 93, 44, 48, 44, 49, 44, 36, 53, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 58, 32, 68, 101, 103, 114, 97, 100, 97, 116, 105, 111, 110,
  115, 10, 35, 64, 103, 109, 105, 99, 32, 99, 114, 97, 99, 107, 115, 32,
  58, 32, 95, 100, 101, 110, 115, 105, 116, 121, 62, 61, 48, 44, 95, 97,
  109, 112, 108, 105, 116, 117, 100, 101, 44, 95, 114, 101, 108, 105, 101, 102,
  61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 65, 100, 100, 32, 114, 97, 110, 100, 111, 109, 32, 99,
  114, 97, 99, 107, 115, 32, 116, 111, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  115, 58, 32, 39, 100, 101, 110, 115, 105, 116, 121, 61, 48, 46, 50, 39,
  44, 32, 39, 97, 109, 112, 108, 105, 116, 117, 100, 101, 61, 52, 48, 39,
  32, 97, 110, 100, 32, 39, 114, 101, 108, 105, 101, 102, 61, 48, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 99, 114, 97, 99, 107, 115, 32, 48,
  46, 50, 44, 54, 48, 44, 49, 10, 99, 114, 97, 99, 107, 115, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 46, 50, 125, 44,
  36, 123, 50, 61, 52, 48, 125, 44, 36, 123, 51, 61, 48, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 65, 100, 100, 32, 114, 97, 110, 100,
  111, 109, 32, 99, 114, 97, 99, 107, 115, 32, 116, 111, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 100, 101, 110, 115, 105,
  116, 121, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 40,
  123, 105, 109, 125, 44, 123, 105, 77, 125, 41, 32, 91, 45, 50, 93, 44,
  91, 45, 50, 93, 44, 49, 44, 49, 32, 45, 110, 111, 105, 115, 101, 91,
  45, 49, 93, 32, 36, 49, 44, 50, 32, 45, 100, 105, 115, 116, 97, 110,
  99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 115, 104, 97, 114, 112, 101,
  110, 91, 45, 49, 93, 32, 49, 48, 48, 48, 48, 10, 45, 105, 102, 32,
  36, 51, 32, 45, 103, 91, 45, 49, 93, 32, 120, 121, 32, 45, 43, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 45, 49,
  44, 49, 32, 45, 101, 108, 115, 101, 32, 45, 110, 91, 45, 49, 93, 32,
  48, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 42, 91, 45, 49,
  93, 32, 36, 50, 32, 45, 43, 91, 45, 51, 44, 45, 49, 93, 32, 45,
  99, 91, 45, 50, 93, 32, 64, 45, 49, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 108, 105, 103, 104, 116, 95,
  112, 97, 116, 99, 104, 32, 58, 32, 95, 100, 101, 110, 115, 105, 116, 121,
  62, 48, 44, 95, 100, 97, 114, 107, 110, 101, 115, 115, 62, 61, 48, 44,
  95, 108, 105, 103, 104, 116, 110, 101, 115, 115, 62, 61, 48, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 65, 100, 100, 32, 108, 105, 103, 104, 116,
  32, 112, 97, 116, 99, 104, 101, 115, 32, 116, 111, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 100, 101, 110, 115, 105, 116, 121, 61, 49,
  48, 39, 44, 32, 39, 100, 97, 114, 107, 110, 101, 115, 115, 61, 48, 46,
  57, 39, 32, 97, 110, 100, 32, 39, 108, 105, 103, 104, 116, 110, 101, 115,
  115, 61, 49, 46, 55, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 108,
  105, 103, 104, 116, 95, 112, 97, 116, 99, 104, 32, 50, 48, 44, 48, 46,
  57, 44, 52, 10, 108, 105, 103, 104, 116, 95, 112, 97, 116, 99, 104, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 48, 125, 44,
  36, 123, 50, 61, 48, 46, 57, 125, 44, 36, 123, 51, 61, 49, 46, 55,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121,
  32, 108, 105, 103, 104, 116, 32, 112, 97, 116, 99, 104, 101, 115, 32, 116,
  111, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32,
  100, 101, 110, 115, 105, 116, 121, 32, 36, 49, 44, 32, 100, 97, 114, 107,
  110, 101, 115, 115, 32, 36, 50, 32, 97, 110, 100, 32, 108, 105, 103, 104,
  116, 110, 101, 115, 115, 32, 36, 51, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 110, 32, 48, 44, 50, 53, 53, 32, 36, 49, 44, 36, 49,
  32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 52, 48, 32, 45,
  114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 53, 32, 45, 99, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 110, 91, 45, 49, 93,
  32, 36, 50, 44, 36, 51, 32, 45, 42, 32, 45, 99, 32, 48, 44, 50,
  53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 110, 111, 105, 115, 101,
  95, 104, 117, 114, 108, 32, 58, 32, 95, 97, 109, 112, 108, 105, 116, 117,
  100, 101, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65,
  100, 100, 32, 104, 117, 114, 108, 32, 110, 111, 105, 115, 101, 32, 116, 111,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117,
  108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 97, 109, 112, 108, 105,
  116, 117, 100, 101, 61, 49, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  45, 110, 111, 105, 115, 101, 95, 104, 117, 114, 108, 32, 44, 10, 110, 111,
  105, 115, 101, 95, 104, 117, 114, 108, 32, 58, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 49, 61, 49, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 65, 100, 100, 32, 104, 117, 114, 108, 32, 110, 111, 105, 115, 101,
  32, 116, 111, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116,
  104, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 36, 49, 37, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 102, 32, 48, 32, 45,
  110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 49, 48, 32, 45, 110, 91,
  45, 49, 93, 32, 64, 123, 45, 50, 44, 109, 125, 44, 64, 123, 45, 50,
  44, 77, 125, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44,
  49, 44, 45, 50, 10, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32,
  36, 49, 44, 50, 32, 45, 103, 101, 91, 45, 49, 93, 32, 48, 32, 45,
  114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 10, 45, 42, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49,
  32, 45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 42, 91, 45, 51, 44,
  45, 49, 93, 32, 45, 43, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 112,
  105, 120, 101, 108, 105, 122, 101, 32, 58, 32, 95, 115, 99, 97, 108, 101,
  95, 120, 62, 48, 44, 95, 115, 99, 97, 108, 101, 95, 121, 62, 48, 44,
  95, 115, 99, 97, 108, 101, 95, 122, 62, 48, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 80, 105, 120, 101, 108, 105, 122, 101, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 119, 105, 116,
  104, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 115, 99, 97, 108,
  101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 115, 99,
  97, 108, 101, 95, 120, 61, 50, 48, 39, 32, 97, 110, 100, 32, 39, 115,
  99, 97, 108, 101, 95, 121, 61, 115, 99, 97, 108, 101, 95, 122, 61, 115,
  99, 97, 108, 101, 95, 120, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45,
  112, 105, 120, 101, 108, 105, 122, 101, 32, 44, 10, 112, 105, 120, 101, 108,
  105, 122, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  50, 48, 125, 44, 36, 123, 50, 61, 36, 49, 125, 44, 36, 123, 51, 61,
  36, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 80, 105, 120,
  101, 108, 105, 122, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 119, 105,
  116, 104, 32, 115, 99, 97, 108, 101, 115, 32, 40, 36, 49, 37, 44, 36,
  50, 37, 44, 36, 51, 37, 41, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 119, 104, 100, 61, 123, 119, 125, 44, 123, 104, 125, 44, 123, 100, 125,
  32, 45, 114, 32, 36, 49, 37, 44, 36, 50, 37, 44, 36, 51, 37, 44,
  49, 48, 48, 37, 44, 50, 32, 45, 114, 32, 36, 119, 104, 100, 32, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 115, 104, 97, 100, 101, 95, 115, 116, 114,
  105, 112, 101, 115, 32, 58, 32, 95, 102, 114, 101, 113, 117, 101, 110, 99,
  121, 62, 61, 48, 44, 95, 100, 105, 114, 101, 99, 116, 105, 111, 110, 61,
  123, 32, 48, 61, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 32, 124,
  32, 49, 61, 118, 101, 114, 116, 105, 99, 97, 108, 32, 125, 44, 95, 100,
  97, 114, 107, 110, 101, 115, 115, 62, 61, 48, 44, 95, 108, 105, 103, 104,
  116, 110, 101, 115, 115, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 65, 100, 100, 32, 115, 104, 97, 100, 101, 32, 115, 116, 114, 105,
  112, 101, 115, 32, 116, 111, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58,
  32, 39, 102, 114, 101, 113, 117, 101, 110, 99, 121, 61, 53, 39, 44, 32,
  39, 100, 105, 114, 101, 99, 116, 105, 111, 110, 61, 49, 39, 44, 32, 39,
  100, 97, 114, 107, 110, 101, 115, 115, 61, 48, 46, 56, 39, 32, 97, 110,
  100, 32, 39, 108, 105, 103, 104, 116, 110, 101, 115, 115, 61, 50, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 115, 104, 97, 100, 101, 95, 115, 116,
  114, 105, 112, 101, 115, 32, 51, 48, 10, 115, 104, 97, 100, 101, 95, 115,
  116, 114, 105, 112, 101, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 49, 61, 53, 125, 44, 36, 123, 50, 61, 49, 125, 44, 36, 123, 51,
  61, 48, 46, 56, 125, 44, 36, 123, 52, 61, 50, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 100, 100, 32, 34, 64, 123, 45, 97, 114,
  103, 92, 32, 49, 43, 33, 36, 50, 44, 118, 101, 114, 116, 105, 99, 97,
  108, 44, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 125, 34, 32, 115,
  104, 97, 100, 101, 100, 32, 115, 116, 114, 105, 112, 101, 115, 32, 116, 111,
  32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 102,
  114, 101, 113, 117, 101, 110, 99, 121, 32, 36, 49, 44, 32, 100, 97, 114,
  107, 110, 101, 115, 115, 32, 36, 51, 32, 97, 110, 100, 32, 108, 105, 103,
  104, 116, 110, 101, 115, 115, 32, 36, 52, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 123, 109, 97, 120,
  40, 49, 44, 119, 42, 40, 36, 50, 33, 61, 48, 41, 41, 125, 44, 123,
  109, 97, 120, 40, 49, 44, 104, 42, 40, 36, 50, 61, 61, 48, 41, 41,
  125, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 36, 49, 44,
  50, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32,
  49, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 110,
  91, 45, 49, 93, 32, 36, 51, 44, 36, 52, 32, 45, 42, 32, 45, 99,
  32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115,
  104, 97, 100, 111, 119, 95, 112, 97, 116, 99, 104, 32, 58, 32, 95, 111,
  112, 97, 99, 105, 116, 121, 62, 61, 48, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 65, 100, 100, 32, 115, 104, 97, 100, 111, 119, 32, 112, 97,
  116, 99, 104, 101, 115, 32, 116, 111, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  58, 32, 39, 111, 112, 97, 99, 105, 116, 121, 61, 48, 46, 55, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 115, 104, 97, 100, 111, 119, 95, 112,
  97, 116, 99, 104, 32, 48, 46, 52, 10, 115, 104, 97, 100, 111, 119, 95,
  112, 97, 116, 99, 104, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  49, 61, 48, 46, 55, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  65, 112, 112, 108, 121, 32, 115, 104, 97, 100, 111, 119, 32, 112, 97, 116,
  99, 104, 101, 115, 32, 116, 111, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 119, 105, 116, 104, 32, 111, 112, 97, 99, 105, 116, 121, 32, 36, 49,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 49, 44, 49, 32, 45, 115, 104, 105, 102, 116, 91, 45,
  49, 93, 32, 45, 50, 44, 45, 50, 32, 45, 115, 104, 105, 102, 116, 91,
  45, 49, 93, 32, 49, 44, 49, 10, 45, 112, 108, 97, 115, 109, 97, 91,
  45, 49, 93, 32, 51, 44, 48, 46, 51, 44, 56, 32, 45, 97, 98, 115,
  91, 45, 49, 93, 32, 45, 98, 91, 45, 49, 93, 32, 49, 32, 45, 99,
  91, 45, 49, 93, 32, 51, 37, 44, 49, 53, 37, 32, 45, 114, 91, 45,
  49, 93, 32, 91, 45, 50, 93, 10, 45, 110, 91, 45, 49, 93, 32, 36,
  49, 44, 49, 32, 45, 42, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115,
  112, 114, 101, 97, 100, 32, 58, 32, 95, 100, 120, 62, 61, 48, 44, 95,
  100, 121, 62, 61, 48, 44, 95, 100, 122, 62, 61, 48, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 83, 112, 114, 101, 97, 100, 32, 112, 105, 120,
  101, 108, 32, 118, 97, 108, 117, 101, 115, 32, 111, 102, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 114, 97, 110,
  100, 111, 109, 108, 121, 32, 97, 108, 111, 110, 103, 32, 120, 44, 121, 32,
  97, 110, 100, 32, 122, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 100, 120, 61, 51, 39, 44, 32, 39, 100, 121, 61, 100, 120, 39, 32,
  97, 110, 100, 32, 39, 100, 122, 61, 48, 39, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 45, 115, 112, 114, 101, 97, 100, 32, 51, 10, 115, 112, 114, 101,
  97, 100, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 51,
  125, 44, 36, 123, 50, 61, 36, 49, 125, 44, 36, 123, 51, 61, 48, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 83, 112, 114, 101, 97, 100,
  32, 112, 105, 120, 101, 108, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36,
  63, 32, 114, 97, 110, 100, 111, 109, 108, 121, 44, 32, 119, 105, 116, 104,
  32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 115, 32, 40, 36, 49, 44,
  36, 50, 44, 36, 51, 41, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 51,
  10, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 48, 32, 45, 114, 97,
  110, 100, 91, 45, 49, 93, 32, 123, 45, 36, 49, 125, 44, 36, 49, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 45, 49, 93, 32,
  49, 44, 49, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 123, 45,
  36, 50, 125, 44, 36, 50, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  115, 104, 91, 45, 49, 93, 32, 50, 44, 50, 32, 45, 114, 97, 110, 100,
  91, 45, 49, 93, 32, 123, 45, 36, 51, 125, 44, 36, 51, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 119, 97, 114, 112, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 115, 116, 114, 105, 112, 101, 115, 95, 121,
  32, 58, 32, 95, 102, 114, 101, 113, 117, 101, 110, 99, 121, 62, 61, 48,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 100, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 32, 115, 116, 114, 105, 112, 101, 115, 32, 116,
  111, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 102, 114, 101, 113,
  117, 101, 110, 99, 121, 61, 49, 48, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 45, 115, 116, 114, 105, 112, 101, 115, 95, 121, 32, 44, 10, 115, 116,
  114, 105, 112, 101, 115, 95, 121, 32, 58, 32, 45, 115, 107, 105, 112, 32,
  36, 123, 49, 61, 49, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 65, 100, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 32, 115, 116,
  114, 105, 112, 101, 115, 32, 116, 111, 32, 105, 109, 97, 103, 101, 36, 63,
  44, 32, 119, 105, 116, 104, 32, 102, 114, 101, 113, 117, 101, 110, 99, 121,
  32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 110, 32,
  48, 44, 50, 53, 53, 32, 49, 48, 48, 37, 32, 45, 110, 111, 105, 115,
  101, 91, 45, 49, 93, 32, 36, 49, 44, 50, 32, 45, 42, 91, 45, 49,
  93, 32, 50, 53, 53, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50,
  93, 10, 45, 42, 91, 45, 49, 93, 32, 48, 46, 49, 53, 32, 45, 43,
  32, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 116, 101, 120, 116, 117, 114, 105, 122, 101, 95, 99, 97, 110, 118,
  97, 115, 32, 58, 32, 95, 97, 109, 112, 108, 105, 116, 117, 100, 101, 62,
  61, 48, 44, 95, 102, 105, 98, 114, 111, 117, 115, 110, 101, 115, 115, 62,
  61, 48, 44, 95, 101, 109, 98, 111, 115, 115, 95, 108, 101, 118, 101, 108,
  62, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 100, 100,
  32, 112, 97, 105, 110, 116, 32, 99, 97, 110, 118, 97, 115, 32, 116, 101,
  120, 116, 117, 114, 101, 32, 116, 111, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  115, 58, 32, 39, 97, 109, 112, 108, 105, 116, 117, 100, 101, 61, 50, 48,
  39, 44, 32, 39, 102, 105, 98, 114, 111, 117, 115, 110, 101, 115, 115, 61,
  51, 39, 32, 97, 110, 100, 32, 39, 101, 109, 98, 111, 115, 115, 95, 108,
  101, 118, 101, 108, 61, 48, 46, 54, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 45, 116, 101, 120, 116, 117, 114, 105, 122, 101, 95, 99, 97, 110, 118,
  97, 115, 32, 44, 10, 116, 101, 120, 116, 117, 114, 105, 122, 101, 95, 99,
  97, 110, 118, 97, 115, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  36, 123, 49, 61, 50, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123,
  50, 61, 51, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 51, 61, 48,
  46, 54, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 52, 61, 56, 48,
  125, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 100, 100, 32,
  99, 97, 110, 118, 97, 115, 32, 116, 101, 120, 116, 117, 114, 101, 32, 116,
  111, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32,
  97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 36, 49, 44, 32, 102, 105,
  98, 114, 111, 117, 115, 110, 101, 115, 115, 32, 36, 50, 32, 97, 110, 100,
  32, 101, 109, 98, 111, 115, 115, 32, 108, 101, 118, 101, 108, 32, 36, 51,
  46, 34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 123, 119, 125, 44, 123, 104, 125, 32, 45, 114, 97,
  110, 100, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 45, 98,
  108, 117, 114, 95, 120, 91, 45, 49, 93, 32, 36, 50, 32, 45, 98, 108,
  117, 114, 95, 121, 91, 45, 50, 93, 32, 36, 50, 32, 45, 43, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 103, 91, 45, 49, 93, 32, 45, 97, 91,
  45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 45, 99, 111, 109, 112, 111,
  115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32,
  43, 32, 45, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 91, 45,
  50, 93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 91, 45, 50, 93, 32, 43, 32, 45, 110, 91, 45, 50,
  93, 32, 36, 51, 44, 49, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 10, 45, 115, 104, 97, 114, 112, 101, 110, 91, 45, 49, 93,
  32, 56, 48, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 110,
  91, 45, 49, 93, 32, 45, 36, 49, 44, 36, 49, 32, 45, 43, 32, 45,
  99, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  116, 101, 120, 116, 117, 114, 105, 122, 101, 95, 112, 97, 112, 101, 114, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 65, 100, 100, 32, 112, 97, 112,
  101, 114, 32, 116, 101, 120, 116, 117, 114, 101, 32, 116, 111, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 45, 116, 101, 120, 116, 117, 114, 105, 122, 101, 95,
  112, 97, 112, 101, 114, 10, 116, 101, 120, 116, 117, 114, 105, 122, 101, 95,
  112, 97, 112, 101, 114, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 65, 100, 100, 32, 112, 97, 112, 101, 114, 32, 116, 101, 120, 116, 117,
  114, 101, 32, 116, 111, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 91, 45, 49, 93, 32, 51, 48, 37, 44,
  51, 48, 37, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 49,
  44, 50, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91,
  45, 50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 48, 32, 45, 105, 102,
  102, 116, 91, 45, 49, 93, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48,
  37, 44, 53, 48, 37, 44, 48, 44, 50, 32, 45, 115, 104, 97, 114, 112,
  101, 110, 91, 45, 49, 93, 32, 49, 32, 45, 110, 91, 45, 49, 93, 32,
  49, 44, 49, 46, 50, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50,
  93, 10, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 99, 91, 45,
  49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 32, 45, 114, 109,
  91, 45, 50, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 118, 105, 103,
  110, 101, 116, 116, 101, 32, 58, 32, 95, 115, 116, 114, 101, 110, 103, 116,
  104, 62, 61, 48, 44, 48, 60, 61, 95, 114, 97, 100, 105, 117, 115, 95,
  109, 105, 110, 60, 61, 49, 48, 48, 44, 48, 60, 61, 95, 114, 97, 100,
  105, 117, 115, 95, 109, 97, 120, 60, 61, 49, 48, 48, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 65, 100, 100, 32, 118, 105, 103, 110, 101, 116,
  116, 101, 32, 101, 102, 102, 101, 99, 116, 32, 116, 111, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 115, 116, 114, 101, 110, 103, 116, 104,
  61, 49, 48, 48, 39, 44, 32, 39, 114, 97, 100, 105, 117, 115, 95, 109,
  105, 110, 61, 55, 48, 39, 32, 97, 110, 100, 32, 39, 114, 97, 100, 105,
  117, 115, 95, 109, 97, 120, 61, 57, 48, 39, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 45, 118, 105, 103, 110, 101, 116, 116, 101, 32, 44, 10, 118, 105,
  103, 110, 101, 116, 116, 101, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 36, 123, 49, 61, 49, 48, 48, 125, 62, 61, 48, 32, 38, 38, 32,
  36, 123, 50, 61, 55, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 50,
  60, 61, 49, 48, 48, 32, 38, 38, 32, 36, 123, 51, 61, 57, 48, 125,
  62, 61, 48, 32, 38, 38, 32, 36, 51, 60, 61, 49, 48, 48, 34, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 100, 100, 32, 118, 105, 103,
  110, 101, 116, 116, 101, 32, 101, 102, 102, 101, 99, 116, 32, 116, 111, 32,
  105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 115, 116,
  114, 101, 110, 103, 116, 104, 32, 36, 49, 32, 97, 110, 100, 32, 115, 105,
  122, 101, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 109,
  77, 61, 123, 105, 109, 125, 44, 123, 105, 77, 125, 32, 100, 61, 123, 109,
  97, 120, 40, 119, 44, 104, 41, 125, 10, 36, 100, 44, 36, 100, 32, 45,
  61, 91, 45, 49, 93, 32, 49, 44, 53, 48, 37, 44, 53, 48, 37, 32,
  45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32,
  45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 50, 10, 45, 99,
  91, 45, 49, 93, 32, 36, 50, 37, 44, 36, 51, 37, 32, 45, 110, 91,
  45, 49, 93, 32, 48, 44, 36, 49, 32, 45, 45, 32, 45, 99, 32, 36,
  109, 77, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 119, 97, 116, 101, 114,
  109, 97, 114, 107, 95, 118, 105, 115, 105, 98, 108, 101, 32, 58, 32, 95,
  116, 101, 120, 116, 44, 48, 60, 95, 111, 112, 97, 99, 105, 116, 121, 60,
  49, 44, 95, 115, 105, 122, 101, 62, 48, 44, 95, 97, 110, 103, 108, 101,
  44, 95, 109, 111, 100, 101, 61, 123, 32, 48, 61, 114, 101, 109, 111, 118,
  101, 32, 124, 32, 49, 61, 97, 100, 100, 32, 125, 44, 95, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 62, 61, 48, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 65, 100, 100, 32, 111, 114, 32, 114, 101, 109, 111, 118,
  101, 32, 97, 32, 118, 105, 115, 105, 98, 108, 101, 32, 119, 97, 116, 101,
  114, 109, 97, 114, 107, 32, 111, 110, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 32, 40, 118, 97, 108, 117, 101, 32,
  114, 97, 110, 103, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 91, 48,
  44, 50, 53, 53, 93, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58,
  32, 39, 116, 101, 120, 116, 61, 40, 99, 41, 32, 71, 39, 77, 73, 67,
  39, 44, 32, 39, 111, 112, 97, 99, 105, 116, 121, 61, 48, 46, 51, 39,
  44, 32, 39, 115, 105, 122, 101, 61, 53, 55, 39, 44, 32, 39, 97, 110,
  103, 108, 101, 61, 50, 53, 39, 44, 32, 39, 109, 111, 100, 101, 61, 49,
  39, 32, 97, 110, 100, 32, 39, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 119, 97, 116,
  101, 114, 109, 97, 114, 107, 95, 118, 105, 115, 105, 98, 108, 101, 32, 44,
  48, 46, 55, 10, 119, 97, 116, 101, 114, 109, 97, 114, 107, 95, 118, 105,
  115, 105, 98, 108, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36,
  123, 49, 61, 92, 50, 53, 49, 92, 32, 71, 92, 39, 77, 73, 67, 125,
  34, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 50, 61, 48, 46,
  51, 125, 62, 48, 32, 38, 38, 32, 36, 50, 60, 49, 32, 38, 38, 32,
  36, 123, 51, 61, 53, 55, 125, 62, 48, 32, 38, 38, 32, 36, 123, 54,
  61, 48, 46, 53, 125, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32,
  36, 123, 52, 61, 50, 53, 125, 44, 36, 123, 53, 61, 49, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 64, 123, 45, 97, 114, 103, 92, 32, 49,
  43, 33, 36, 53, 44, 65, 100, 100, 44, 82, 101, 109, 111, 118, 101, 125,
  34, 32, 118, 105, 115, 105, 98, 108, 101, 32, 119, 97, 116, 101, 114, 109,
  97, 114, 107, 32, 39, 36, 49, 39, 32, 111, 110, 32, 105, 109, 97, 103,
  101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 111, 112, 97, 99, 105, 116,
  121, 32, 36, 50, 44, 32, 115, 105, 122, 101, 32, 36, 51, 44, 32, 97,
  110, 103, 108, 101, 32, 36, 52, 32, 100, 101, 103, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 36,
  49, 34, 44, 48, 44, 48, 44, 36, 51, 44, 49, 44, 50, 53, 53, 32,
  45, 114, 111, 116, 97, 116, 101, 91, 45, 49, 93, 32, 36, 52, 44, 48,
  44, 48, 32, 45, 98, 91, 45, 49, 93, 32, 36, 54, 32, 45, 110, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 114, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 44, 48, 44, 50, 32, 45, 43, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 10, 45, 105, 102, 32, 36, 53, 32, 45, 42, 91, 45, 49, 93,
  32, 36, 50, 32, 45, 42, 91, 45, 50, 93, 32, 123, 49, 45, 36, 50,
  125, 32, 45, 43, 10, 45, 101, 108, 115, 101, 32, 45, 42, 91, 45, 49,
  93, 32, 36, 50, 32, 45, 45, 32, 45, 47, 32, 123, 49, 45, 36, 50,
  125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 99, 32, 48, 44, 50, 53,
  53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 58, 58, 32, 66, 108, 101,
  110, 100, 105, 110, 103, 32, 97, 110, 100, 32, 102, 97, 100, 105, 110, 103,
  10, 35, 64, 103, 109, 105, 99, 32, 98, 108, 101, 110, 100, 32, 58, 32,
  98, 108, 101, 110, 100, 105, 110, 103, 95, 109, 111, 100, 101, 44, 48, 60,
  61, 95, 111, 112, 97, 99, 105, 116, 121, 60, 61, 49, 44, 95, 114, 101,
  118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 95, 111, 114, 100, 101, 114,
  61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 66, 108, 101, 110, 100, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 71, 44, 71, 65, 44, 82, 71, 66, 32, 111, 114, 32, 82,
  71, 66, 65, 32, 105, 109, 97, 103, 101, 115, 44, 32, 116, 119, 111, 45,
  98, 121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 109, 111, 100, 101, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 39, 98, 108, 101, 110, 100, 105, 110, 103,
  95, 109, 111, 100, 101, 39, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32,
  97, 100, 100, 32, 124, 32, 97, 108, 112, 104, 97, 32, 124, 32, 97, 110,
  100, 32, 124, 32, 97, 118, 101, 114, 97, 103, 101, 32, 124, 32, 98, 108,
  117, 101, 32, 124, 32, 98, 117, 114, 110, 32, 124, 32, 100, 97, 114, 107,
  101, 110, 32, 124, 32, 100, 105, 102, 102, 101, 114, 101, 110, 99, 101, 32,
  124, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 100, 105, 118, 105, 100,
  101, 32, 124, 32, 100, 111, 100, 103, 101, 32, 124, 32, 101, 120, 99, 108,
  117, 115, 105, 111, 110, 32, 124, 32, 102, 114, 101, 101, 122, 101, 32, 124,
  32, 103, 114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116, 32, 124, 32,
  103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 32, 124, 32, 103, 114, 101,
  101, 110, 32, 124, 32, 104, 97, 114, 100, 108, 105, 103, 104, 116, 32, 124,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 104, 97, 114, 100, 109, 105,
  120, 32, 124, 32, 104, 117, 101, 32, 124, 32, 105, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 105, 111, 110, 32, 124, 32, 108, 105, 103, 104, 116, 101,
  110, 32, 124, 32, 108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 124, 32,
  108, 105, 110, 101, 97, 114, 98, 117, 114, 110, 32, 124, 32, 108, 105, 110,
  101, 97, 114, 108, 105, 103, 104, 116, 32, 124, 32, 108, 117, 109, 105, 110,
  97, 110, 99, 101, 32, 124, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  109, 117, 108, 116, 105, 112, 108, 121, 32, 124, 32, 110, 101, 103, 97, 116,
  105, 111, 110, 32, 124, 32, 111, 114, 32, 124, 32, 111, 118, 101, 114, 108,
  97, 121, 32, 124, 32, 112, 105, 110, 108, 105, 103, 104, 116, 32, 124, 32,
  114, 101, 100, 32, 124, 32, 114, 101, 102, 108, 101, 99, 116, 32, 124, 32,
  115, 97, 116, 117, 114, 97, 116, 105, 111, 110, 32, 124, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 115, 99, 114, 101, 101, 110, 32, 124, 32, 115,
  104, 97, 112, 101, 97, 118, 101, 114, 97, 103, 101, 32, 124, 32, 115, 104,
  97, 112, 101, 97, 118, 101, 114, 97, 103, 101, 48, 32, 124, 32, 115, 111,
  102, 116, 98, 117, 114, 110, 32, 124, 32, 115, 111, 102, 116, 100, 111, 100,
  103, 101, 32, 124, 32, 115, 111, 102, 116, 108, 105, 103, 104, 116, 32, 124,
  32, 115, 116, 97, 109, 112, 32, 124, 32, 115, 117, 98, 116, 114, 97, 99,
  116, 32, 124, 32, 118, 97, 108, 117, 101, 32, 124, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 118, 105, 118, 105, 100, 108, 105, 103, 104, 116, 32,
  124, 32, 120, 111, 114, 32, 125, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115,
  58, 32, 39, 98, 108, 101, 110, 100, 105, 110, 103, 95, 109, 111, 100, 101,
  61, 97, 108, 112, 104, 97, 39, 44, 32, 39, 111, 112, 97, 99, 105, 116,
  121, 61, 49, 39, 32, 97, 110, 100, 32, 39, 114, 101, 118, 101, 114, 116,
  95, 108, 97, 121, 101, 114, 115, 61, 48, 39, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 45, 100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119, 32, 44,
  32, 45, 114, 101, 115, 105, 122, 101, 50, 100, 121, 91, 45, 49, 93, 32,
  50, 48, 48, 32, 45, 114, 111, 116, 97, 116, 101, 91, 45, 49, 93, 32,
  50, 48, 32, 45, 45, 98, 108, 101, 110, 100, 32, 97, 108, 112, 104, 97,
  32, 45, 100, 114, 103, 98, 97, 91, 45, 50, 93, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 116, 101, 115, 116, 105, 109, 97, 103, 101, 50, 100, 32, 123, 119,
  125, 44, 123, 104, 125, 32, 45, 98, 108, 101, 110, 100, 32, 111, 118, 101,
  114, 108, 97, 121, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  45, 109, 32, 34, 101, 120, 32, 58, 32, 36, 34, 34, 61, 97, 114, 103,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 34, 34, 35, 32, 45, 45,
  98, 108, 101, 110, 100, 91, 48, 44, 49, 93, 32, 36, 123, 97, 114, 103,
  123, 36, 62, 43, 49, 125, 125, 32, 45, 116, 101, 120, 116, 95, 111, 117,
  116, 108, 105, 110, 101, 91, 45, 49, 93, 32, 77, 111, 100, 101, 58, 92,
  34, 32, 92, 34, 36, 123, 97, 114, 103, 123, 36, 62, 43, 49, 125, 125,
  44, 50, 44, 50, 44, 50, 52, 44, 50, 44, 49, 44, 50, 53, 53, 32,
  45, 100, 111, 110, 101, 34, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 116, 101, 115, 116, 105, 109, 97, 103, 101, 50, 100, 32, 123, 119,
  125, 44, 123, 104, 125, 32, 45, 101, 120, 32, 97, 100, 100, 44, 97, 108,
  112, 104, 97, 44, 97, 110, 100, 44, 97, 118, 101, 114, 97, 103, 101, 44,
  98, 108, 117, 101, 44, 98, 117, 114, 110, 44, 100, 97, 114, 107, 101, 110,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 45, 109, 32, 34,
  101, 120, 32, 58, 32, 36, 34, 34, 61, 97, 114, 103, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 36, 34, 34, 35, 32, 45, 45, 98, 108, 101, 110,
  100, 91, 48, 44, 49, 93, 32, 36, 123, 97, 114, 103, 123, 36, 62, 43,
  49, 125, 125, 32, 45, 116, 101, 120, 116, 95, 111, 117, 116, 108, 105, 110,
  101, 91, 45, 49, 93, 32, 77, 111, 100, 101, 58, 92, 34, 32, 92, 34,
  36, 123, 97, 114, 103, 123, 36, 62, 43, 49, 125, 125, 44, 50, 44, 50,
  44, 50, 52, 44, 50, 44, 49, 44, 50, 53, 53, 32, 45, 100, 111, 110,
  101, 34, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 116, 101,
  115, 116, 105, 109, 97, 103, 101, 50, 100, 32, 123, 119, 125, 44, 123, 104,
  125, 32, 45, 101, 120, 32, 100, 105, 102, 102, 101, 114, 101, 110, 99, 101,
  44, 100, 105, 118, 105, 100, 101, 44, 100, 111, 100, 103, 101, 44, 101, 120,
  99, 108, 117, 115, 105, 111, 110, 44, 102, 114, 101, 101, 122, 101, 44, 103,
  114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116, 44, 103, 114, 97, 105,
  110, 109, 101, 114, 103, 101, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  36, 32, 45, 109, 32, 34, 101, 120, 32, 58, 32, 36, 34, 34, 61, 97,
  114, 103, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 34, 34, 35, 32,
  45, 45, 98, 108, 101, 110, 100, 91, 48, 44, 49, 93, 32, 36, 123, 97,
  114, 103, 123, 36, 62, 43, 49, 125, 125, 32, 45, 116, 101, 120, 116, 95,
  111, 117, 116, 108, 105, 110, 101, 91, 45, 49, 93, 32, 77, 111, 100, 101,
  58, 92, 34, 32, 92, 34, 36, 123, 97, 114, 103, 123, 36, 62, 43, 49,
  125, 125, 44, 50, 44, 50, 44, 50, 52, 44, 50, 44, 49, 44, 50, 53,
  53, 32, 45, 100, 111, 110, 101, 34, 32, 105, 109, 97, 103, 101, 46, 106,
  112, 103, 32, 45, 116, 101, 115, 116, 105, 109, 97, 103, 101, 50, 100, 32,
  123, 119, 125, 44, 123, 104, 125, 32, 45, 101, 120, 32, 103, 114, 101, 101,
  110, 44, 104, 97, 114, 100, 108, 105, 103, 104, 116, 44, 104, 97, 114, 100,
  109, 105, 120, 44, 104, 117, 101, 44, 105, 110, 116, 101, 114, 112, 111, 108,
  97, 116, 105, 111, 110, 44, 108, 105, 103, 104, 116, 101, 110, 44, 108, 105,
  103, 104, 116, 110, 101, 115, 115, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 45, 109, 32, 34, 101, 120, 32, 58, 32, 36, 34, 34, 61,
  97, 114, 103, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 34, 34, 35,
  32, 45, 45, 98, 108, 101, 110, 100, 91, 48, 44, 49, 93, 32, 36, 123,
  97, 114, 103, 123, 36, 62, 43, 49, 125, 125, 32, 45, 116, 101, 120, 116,
  95, 111, 117, 116, 108, 105, 110, 101, 91, 45, 49, 93, 32, 77, 111, 100,
  101, 58, 92, 34, 32, 92, 34, 36, 123, 97, 114, 103, 123, 36, 62, 43,
  49, 125, 125, 44, 50, 44, 50, 44, 50, 52, 44, 50, 44, 49, 44, 50,
  53, 53, 32, 45, 100, 111, 110, 101, 34, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 116, 101, 115, 116, 105, 109, 97, 103, 101, 50, 100,
  32, 123, 119, 125, 44, 123, 104, 125, 32, 45, 101, 120, 32, 108, 105, 110,
  101, 97, 114, 98, 117, 114, 110, 44, 108, 105, 110, 101, 97, 114, 108, 105,
  103, 104, 116, 44, 108, 117, 109, 105, 110, 97, 110, 99, 101, 44, 109, 117,
  108, 116, 105, 112, 108, 121, 44, 110, 101, 103, 97, 116, 105, 111, 110, 44,
  111, 114, 44, 111, 118, 101, 114, 108, 97, 121, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 45, 109, 32, 34, 101, 120, 32, 58, 32, 36,
  34, 34, 61, 97, 114, 103, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36,
  34, 34, 35, 32, 45, 45, 98, 108, 101, 110, 100, 91, 48, 44, 49, 93,
  32, 36, 123, 97, 114, 103, 123, 36, 62, 43, 49, 125, 125, 32, 45, 116,
  101, 120, 116, 95, 111, 117, 116, 108, 105, 110, 101, 91, 45, 49, 93, 32,
  77, 111, 100, 101, 58, 92, 34, 32, 92, 34, 36, 123, 97, 114, 103, 123,
  36, 62, 43, 49, 125, 125, 44, 50, 44, 50, 44, 50, 52, 44, 50, 44,
  49, 44, 50, 53, 53, 32, 45, 100, 111, 110, 101, 34, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 116, 101, 115, 116, 105, 109, 97, 103,
  101, 50, 100, 32, 123, 119, 125, 44, 123, 104, 125, 32, 45, 101, 120, 32,
  112, 105, 110, 108, 105, 103, 104, 116, 44, 114, 101, 100, 44, 114, 101, 102,
  108, 101, 99, 116, 44, 115, 97, 116, 117, 114, 97, 116, 105, 111, 110, 44,
  115, 99, 114, 101, 101, 110, 44, 115, 104, 97, 112, 101, 97, 118, 101, 114,
  97, 103, 101, 44, 115, 111, 102, 116, 98, 117, 114, 110, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 45, 109, 32, 34, 101, 120, 32, 58,
  32, 36, 34, 34, 61, 97, 114, 103, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 36, 34, 34, 35, 32, 45, 45, 98, 108, 101, 110, 100, 91, 48, 44,
  49, 93, 32, 36, 123, 97, 114, 103, 123, 36, 62, 43, 49, 125, 125, 32,
  45, 116, 101, 120, 116, 95, 111, 117, 116, 108, 105, 110, 101, 91, 45, 49,
  93, 32, 77, 111, 100, 101, 58, 92, 34, 32, 92, 34, 36, 123, 97, 114,
  103, 123, 36, 62, 43, 49, 125, 125, 44, 50, 44, 50, 44, 50, 52, 44,
  50, 44, 49, 44, 50, 53, 53, 32, 45, 100, 111, 110, 101, 34, 32, 105,
  109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 116, 101, 115, 116, 105, 109,
  97, 103, 101, 50, 100, 32, 123, 119, 125, 44, 123, 104, 125, 32, 45, 101,
  120, 32, 115, 111, 102, 116, 100, 111, 100, 103, 101, 44, 115, 111, 102, 116,
  108, 105, 103, 104, 116, 44, 115, 116, 97, 109, 112, 44, 115, 117, 98, 116,
  114, 97, 99, 116, 44, 118, 97, 108, 117, 101, 44, 118, 105, 118, 105, 100,
  108, 105, 103, 104, 116, 44, 120, 111, 114, 10, 98, 108, 101, 110, 100, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 97, 108, 112, 104,
  97, 125, 44, 36, 123, 50, 61, 49, 125, 44, 36, 123, 51, 61, 48, 125,
  44, 36, 123, 52, 61, 49, 125, 10, 45, 118, 32, 45, 32, 115, 48, 61,
  34, 34, 32, 115, 49, 61, 34, 40, 114, 101, 118, 101, 114, 116, 101, 100,
  32, 108, 97, 121, 101, 114, 115, 41, 32, 34, 32, 45, 118, 32, 43, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 66, 108, 101, 110, 100, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119,
  111, 44, 32, 117, 115, 105, 110, 103, 32, 39, 36, 49, 39, 32, 109, 111,
  100, 101, 32, 34, 36, 123, 115, 123, 36, 51, 33, 61, 48, 125, 125, 34,
  97, 110, 100, 32, 111, 112, 97, 99, 105, 116, 121, 32, 36, 50, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 108, 91, 93, 32, 99, 111, 100, 101, 61,
  64, 123, 45, 95, 98, 108, 101, 110, 100, 95, 36, 49, 125, 10, 45, 111,
  110, 102, 97, 105, 108, 32, 45, 118, 32, 43, 32, 45, 101, 114, 114, 111,
  114, 91, 48, 45, 45, 50, 93, 32, 34, 85, 110, 107, 110, 111, 119, 110,
  32, 98, 108, 101, 110, 100, 105, 110, 103, 32, 109, 111, 100, 101, 32, 39,
  36, 49, 39, 32, 114, 101, 113, 117, 101, 115, 116, 101, 100, 46, 34, 10,
  45, 101, 110, 100, 108, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105,
  110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44,
  123, 36, 62, 43, 49, 125, 93, 32, 45, 105, 102, 32, 36, 51, 32, 45,
  114, 118, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 91, 49, 93, 32,
  91, 48, 93, 44, 91, 48, 93, 44, 91, 48, 93, 44, 49, 48, 48, 37,
  44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 115, 61, 123,
  115, 48, 61, 105, 102, 40, 64, 123, 48, 44, 115, 125, 60, 51, 44, 49,
  44, 51, 41, 59, 115, 49, 61, 105, 102, 40, 115, 60, 51, 44, 49, 44,
  51, 41, 59, 109, 97, 120, 40, 115, 48, 44, 115, 49, 41, 125, 10, 45,
  116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 91, 48, 93, 32,
  123, 36, 115, 43, 49, 45, 40, 64, 123, 48, 44, 115, 125, 37, 50, 41,
  125, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 91,
  49, 93, 32, 123, 36, 115, 43, 49, 45, 40, 115, 37, 50, 41, 125, 10,
  45, 105, 102, 32, 123, 64, 123, 48, 44, 115, 125, 61, 61, 50, 124, 124,
  64, 123, 48, 44, 115, 125, 61, 61, 52, 125, 10, 45, 105, 102, 32, 123,
  115, 61, 61, 50, 124, 124, 115, 61, 61, 52, 125, 10, 45, 115, 104, 91,
  48, 44, 49, 93, 32, 48, 44, 123, 115, 45, 50, 125, 32, 45, 95, 98,
  108, 101, 110, 100, 91, 50, 44, 51, 93, 32, 36, 99, 111, 100, 101, 32,
  45, 114, 109, 91, 50, 44, 51, 93, 10, 45, 105, 102, 32, 123, 36, 49,
  39, 61, 61, 39, 97, 108, 112, 104, 97, 125, 10, 45, 115, 104, 91, 48,
  44, 49, 93, 32, 48, 44, 123, 64, 123, 48, 44, 115, 125, 45, 50, 125,
  32, 45, 115, 104, 91, 48, 44, 49, 93, 32, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 32, 45, 42, 91, 50, 44, 52, 93, 32, 45, 42, 91, 51,
  44, 52, 93, 32, 45, 114, 109, 91, 50, 44, 51, 93, 10, 45, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 91, 49, 93, 32, 49, 48, 48, 37, 32,
  45, 115, 104, 91, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  32, 45, 102, 91, 51, 93, 32, 50, 53, 53, 32, 45, 114, 109, 91, 51,
  93, 10, 45, 106, 91, 48, 93, 32, 91, 49, 93, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 123, 109, 97, 120, 40, 48, 44, 109, 105, 110, 40, 49,
  44, 36, 50, 41, 41, 125, 44, 91, 50, 93, 44, 50, 53, 53, 32, 45,
  114, 109, 91, 49, 44, 50, 93, 10, 45, 115, 104, 91, 48, 93, 32, 48,
  44, 123, 115, 45, 50, 125, 32, 45, 115, 104, 91, 48, 93, 32, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 32, 45, 43, 91, 50, 93, 32, 49, 101,
  45, 49, 48, 32, 45, 47, 91, 49, 44, 50, 93, 32, 45, 114, 109, 91,
  49, 93, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 101, 108, 115,
  101, 10, 45, 115, 104, 91, 49, 93, 32, 48, 44, 123, 115, 45, 50, 125,
  32, 45, 115, 104, 91, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 32, 45, 106, 91, 48, 93, 32, 91, 50, 93, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 123, 109, 97, 120, 40, 48, 44, 109, 105, 110, 40, 49,
  44, 36, 50, 41, 41, 125, 44, 91, 51, 93, 44, 50, 53, 53, 32, 45,
  114, 109, 91, 94, 48, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  108, 115, 101, 10, 45, 115, 104, 91, 48, 93, 32, 48, 44, 123, 64, 123,
  48, 44, 115, 125, 45, 50, 125, 32, 45, 114, 118, 91, 49, 44, 50, 93,
  32, 45, 95, 98, 108, 101, 110, 100, 91, 49, 44, 50, 93, 32, 36, 99,
  111, 100, 101, 32, 45, 106, 91, 49, 93, 32, 91, 50, 93, 44, 48, 44,
  48, 44, 48, 44, 48, 44, 123, 109, 97, 120, 40, 48, 44, 109, 105, 110,
  40, 49, 44, 36, 50, 41, 41, 125, 32, 45, 114, 109, 91, 94, 48, 93,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101, 10, 45, 105,
  102, 32, 123, 115, 61, 61, 50, 124, 124, 115, 61, 61, 52, 125, 10, 45,
  115, 104, 91, 49, 93, 32, 48, 44, 123, 115, 45, 50, 125, 32, 45, 95,
  98, 108, 101, 110, 100, 91, 48, 44, 50, 93, 32, 36, 99, 111, 100, 101,
  32, 45, 114, 109, 91, 50, 93, 10, 45, 115, 104, 91, 49, 93, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 106, 91, 48, 93, 32, 91,
  49, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 123, 109, 97, 120, 40,
  48, 44, 109, 105, 110, 40, 49, 44, 36, 50, 41, 41, 125, 44, 91, 50,
  93, 44, 50, 53, 53, 32, 45, 114, 109, 91, 94, 48, 93, 10, 45, 101,
  108, 115, 101, 10, 45, 95, 98, 108, 101, 110, 100, 32, 36, 99, 111, 100,
  101, 32, 45, 106, 91, 48, 93, 32, 91, 49, 93, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 123, 109, 97, 120, 40, 48, 44, 109, 105, 110, 40, 49,
  44, 36, 50, 41, 41, 125, 32, 45, 114, 109, 91, 49, 93, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 95, 98, 108,
  101, 110, 100, 32, 58, 32, 36, 42, 10, 95, 98, 108, 101, 110, 100, 95,
  97, 108, 112, 104, 97, 32, 58, 10, 45, 117, 32, 34, 34, 10, 95, 98,
  108, 101, 110, 100, 95, 97, 110, 100, 32, 58, 10, 45, 117, 32, 34, 45,
  97, 110, 100, 91, 49, 93, 32, 91, 48, 93, 34, 10, 95, 98, 108, 101,
  110, 100, 95, 97, 100, 100, 32, 58, 10, 45, 117, 32, 34, 45, 43, 91,
  49, 93, 32, 91, 48, 93, 32, 45, 99, 91, 49, 93, 32, 48, 44, 50,
  53, 53, 34, 10, 95, 98, 108, 101, 110, 100, 95, 97, 118, 101, 114, 97,
  103, 101, 32, 58, 10, 45, 117, 32, 34, 45, 43, 91, 49, 93, 32, 91,
  48, 93, 32, 45, 47, 91, 49, 93, 32, 50, 34, 10, 95, 98, 108, 101,
  110, 100, 95, 98, 108, 117, 101, 32, 58, 10, 45, 117, 32, 34, 45, 115,
  104, 91, 48, 93, 32, 48, 44, 49, 32, 45, 106, 91, 49, 93, 32, 91,
  50, 93, 32, 45, 114, 109, 91, 50, 93, 34, 10, 95, 98, 108, 101, 110,
  100, 95, 98, 117, 114, 110, 32, 58, 10, 45, 117, 32, 34, 45, 45, 45,
  91, 48, 93, 32, 50, 53, 53, 32, 45, 43, 91, 49, 93, 32, 48, 46,
  49, 32, 45, 47, 91, 50, 93, 32, 91, 49, 93, 32, 45, 114, 109, 91,
  49, 93, 32, 45, 43, 91, 49, 93, 32, 49, 32, 45, 42, 91, 49, 93,
  32, 50, 53, 53, 32, 45, 99, 91, 49, 93, 32, 48, 44, 50, 53, 53,
  34, 10, 95, 98, 108, 101, 110, 100, 95, 100, 97, 114, 107, 101, 110, 32,
  58, 10, 45, 117, 32, 34, 45, 109, 105, 110, 91, 49, 93, 32, 91, 48,
  93, 34, 10, 95, 98, 108, 101, 110, 100, 95, 100, 105, 102, 102, 101, 114,
  101, 110, 99, 101, 32, 58, 10, 45, 117, 32, 34, 45, 45, 91, 49, 93,
  32, 91, 48, 93, 32, 45, 97, 98, 115, 91, 49, 93, 34, 10, 95, 98,
  108, 101, 110, 100, 95, 100, 105, 118, 105, 100, 101, 32, 58, 10, 45, 117,
  32, 34, 45, 43, 91, 49, 93, 32, 48, 46, 49, 32, 45, 94, 91, 49,
  93, 32, 45, 49, 32, 45, 42, 91, 49, 93, 32, 91, 48, 93, 32, 45,
  42, 91, 49, 93, 32, 50, 53, 53, 32, 45, 99, 91, 49, 93, 32, 48,
  44, 50, 53, 53, 34, 10, 95, 98, 108, 101, 110, 100, 95, 100, 111, 100,
  103, 101, 32, 58, 10, 45, 117, 32, 34, 45, 45, 91, 49, 93, 32, 50,
  53, 53, 46, 49, 32, 45, 94, 91, 49, 93, 32, 45, 49, 32, 45, 42,
  91, 49, 93, 32, 91, 48, 93, 32, 45, 42, 91, 49, 93, 32, 45, 50,
  53, 53, 32, 45, 99, 91, 49, 93, 32, 48, 44, 50, 53, 53, 34, 10,
  95, 98, 108, 101, 110, 100, 95, 101, 120, 99, 108, 117, 115, 105, 111, 110,
  32, 58, 10, 45, 117, 32, 34, 45, 45, 42, 91, 48, 44, 49, 93, 32,
  45, 47, 91, 50, 93, 32, 45, 49, 50, 55, 46, 53, 32, 45, 43, 91,
  49, 44, 50, 93, 32, 45, 43, 91, 49, 93, 32, 91, 48, 93, 34, 10,
  95, 98, 108, 101, 110, 100, 95, 102, 114, 101, 101, 122, 101, 32, 58, 10,
  45, 117, 32, 34, 45, 42, 91, 49, 93, 32, 45, 50, 53, 53, 32, 45,
  45, 91, 49, 93, 32, 48, 46, 49, 32, 45, 45, 45, 91, 48, 93, 32,
  50, 53, 53, 32, 45, 115, 113, 114, 91, 50, 93, 32, 45, 47, 91, 50,
  93, 32, 91, 49, 93, 32, 45, 114, 109, 91, 49, 93, 32, 45, 43, 91,
  49, 93, 32, 49, 32, 45, 42, 91, 49, 93, 32, 50, 53, 53, 32, 45,
  99, 91, 49, 93, 32, 48, 44, 50, 53, 53, 34, 10, 95, 98, 108, 101,
  110, 100, 95, 103, 114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116, 32,
  58, 10, 45, 117, 32, 34, 45, 45, 91, 49, 93, 32, 91, 48, 93, 32,
  45, 42, 91, 49, 93, 32, 45, 49, 32, 45, 43, 91, 49, 93, 32, 49,
  50, 56, 32, 45, 99, 91, 49, 93, 32, 48, 44, 50, 53, 53, 34, 10,
  95, 98, 108, 101, 110, 100, 95, 103, 114, 97, 105, 110, 109, 101, 114, 103,
  101, 32, 58, 10, 45, 117, 32, 34, 45, 43, 91, 49, 93, 32, 91, 48,
  93, 32, 45, 45, 91, 49, 93, 32, 49, 50, 56, 32, 45, 99, 91, 49,
  93, 32, 48, 44, 50, 53, 53, 34, 10, 95, 98, 108, 101, 110, 100, 95,
  103, 114, 101, 101, 110, 32, 58, 10, 45, 117, 32, 34, 45, 115, 104, 91,
  48, 93, 32, 48, 44, 48, 32, 45, 115, 104, 91, 48, 93, 32, 50, 44,
  50, 32, 45, 106, 91, 49, 93, 32, 91, 50, 93, 32, 45, 106, 91, 49,
  93, 32, 91, 51, 93, 44, 48, 44, 48, 44, 48, 44, 50, 32, 45, 114,
  109, 91, 50, 44, 51, 93, 34, 10, 95, 98, 108, 101, 110, 100, 95, 104,
  97, 114, 100, 108, 105, 103, 104, 116, 32, 58, 10, 45, 117, 32, 34, 45,
  45, 42, 91, 48, 44, 49, 93, 32, 45, 47, 91, 50, 93, 32, 49, 50,
  55, 46, 53, 32, 45, 45, 43, 91, 48, 44, 49, 93, 32, 45, 42, 91,
  51, 93, 32, 50, 32, 45, 45, 91, 51, 93, 32, 50, 53, 53, 32, 45,
  45, 91, 51, 93, 32, 91, 50, 93, 32, 45, 103, 116, 91, 49, 93, 32,
  49, 50, 56, 32, 34, 92, 10, 34, 45, 106, 91, 50, 93, 32, 91, 51,
  93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 49, 93, 32,
  45, 114, 109, 91, 49, 44, 51, 93, 32, 45, 99, 91, 49, 93, 32, 48,
  44, 50, 53, 53, 34, 10, 95, 98, 108, 101, 110, 100, 95, 104, 97, 114,
  100, 109, 105, 120, 32, 58, 10, 45, 117, 32, 34, 45, 43, 91, 49, 93,
  32, 91, 48, 93, 32, 45, 103, 101, 91, 49, 93, 32, 50, 53, 53, 32,
  45, 42, 91, 49, 93, 32, 50, 53, 53, 34, 10, 95, 98, 108, 101, 110,
  100, 95, 104, 117, 101, 32, 58, 10, 45, 117, 32, 34, 45, 116, 111, 95,
  99, 111, 108, 111, 114, 32, 45, 115, 104, 32, 48, 44, 50, 32, 45, 114,
  103, 98, 50, 104, 115, 118, 91, 50, 44, 51, 93, 32, 45, 115, 104, 91,
  50, 93, 32, 49, 44, 50, 32, 45, 106, 91, 49, 93, 32, 91, 52, 93,
  44, 48, 44, 48, 44, 48, 44, 49, 32, 45, 114, 109, 91, 52, 93, 32,
  45, 104, 115, 118, 50, 114, 103, 98, 91, 50, 44, 51, 93, 32, 45, 114,
  109, 91, 50, 44, 51, 93, 34, 10, 95, 98, 108, 101, 110, 100, 95, 105,
  110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 32, 58, 10, 45,
  117, 32, 34, 45, 45, 42, 91, 48, 93, 32, 123, 112, 105, 47, 50, 53,
  53, 125, 32, 45, 42, 91, 49, 93, 32, 123, 112, 105, 47, 50, 53, 53,
  125, 32, 45, 99, 111, 115, 91, 49, 44, 50, 93, 32, 45, 43, 91, 49,
  44, 50, 93, 32, 45, 45, 91, 49, 93, 32, 50, 32, 45, 42, 91, 49,
  93, 32, 45, 54, 51, 46, 55, 53, 32, 45, 99, 91, 49, 93, 32, 48,
  44, 50, 53, 53, 34, 10, 95, 98, 108, 101, 110, 100, 95, 108, 105, 103,
  104, 116, 101, 110, 32, 58, 10, 45, 117, 32, 34, 45, 109, 97, 120, 91,
  49, 93, 32, 91, 48, 93, 34, 10, 95, 98, 108, 101, 110, 100, 95, 108,
  105, 103, 104, 116, 110, 101, 115, 115, 32, 58, 10, 45, 117, 32, 34, 45,
  116, 111, 95, 99, 111, 108, 111, 114, 32, 45, 115, 104, 32, 48, 44, 50,
  32, 45, 114, 103, 98, 50, 108, 97, 98, 91, 50, 44, 51, 93, 32, 45,
  115, 104, 91, 50, 93, 32, 49, 44, 50, 32, 45, 106, 91, 49, 93, 32,
  91, 52, 93, 44, 48, 44, 48, 44, 48, 44, 49, 32, 45, 114, 109, 91,
  52, 93, 32, 45, 108, 97, 98, 50, 114, 103, 98, 91, 50, 44, 51, 93,
  32, 45, 114, 109, 91, 50, 44, 51, 93, 34, 10, 95, 98, 108, 101, 110,
  100, 95, 108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 58, 10, 45, 117,
  32, 34, 45, 116, 111, 95, 99, 111, 108, 111, 114, 32, 45, 115, 104, 32,
  48, 44, 50, 32, 45, 114, 103, 98, 50, 121, 99, 98, 99, 114, 91, 50,
  44, 51, 93, 32, 45, 115, 104, 91, 50, 93, 32, 49, 44, 50, 32, 45,
  106, 91, 49, 93, 32, 91, 52, 93, 44, 48, 44, 48, 44, 48, 44, 49,
  32, 45, 114, 109, 91, 52, 93, 32, 45, 121, 99, 98, 99, 114, 50, 114,
  103, 98, 91, 50, 44, 51, 93, 32, 45, 114, 109, 91, 50, 44, 51, 93,
  34, 10, 95, 98, 108, 101, 110, 100, 95, 108, 105, 110, 101, 97, 114, 98,
  117, 114, 110, 32, 58, 10, 45, 117, 32, 34, 45, 43, 91, 49, 93, 32,
  91, 48, 93, 32, 45, 45, 91, 49, 93, 32, 50, 53, 53, 32, 45, 99,
  91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 34, 10, 95, 98, 108, 101,
  110, 100, 95, 108, 105, 110, 101, 97, 114, 108, 105, 103, 104, 116, 32, 58,
  10, 45, 117, 32, 34, 45, 42, 91, 49, 93, 32, 50, 32, 45, 43, 91,
  49, 93, 32, 91, 48, 93, 32, 45, 45, 91, 49, 93, 32, 50, 53, 53,
  32, 45, 99, 91, 49, 93, 32, 48, 44, 50, 53, 53, 34, 10, 95, 98,
  108, 101, 110, 100, 95, 109, 117, 108, 116, 105, 112, 108, 121, 32, 58, 10,
  45, 117, 32, 34, 45, 42, 91, 49, 93, 32, 91, 48, 93, 32, 45, 47,
  91, 49, 93, 32, 50, 53, 53, 34, 10, 95, 98, 108, 101, 110, 100, 95,
  110, 101, 103, 97, 116, 105, 111, 110, 32, 58, 10, 45, 117, 32, 34, 45,
  43, 91, 49, 93, 32, 91, 48, 93, 32, 45, 45, 91, 49, 93, 32, 50,
  53, 53, 32, 45, 97, 98, 115, 91, 49, 93, 32, 45, 42, 91, 49, 93,
  32, 45, 49, 32, 45, 43, 91, 49, 93, 32, 50, 53, 53, 34, 10, 95,
  98, 108, 101, 110, 100, 95, 111, 114, 32, 58, 10, 45, 117, 32, 34, 45,
  111, 114, 91, 49, 93, 32, 91, 48, 93, 34, 10, 95, 98, 108, 101, 110,
  100, 95, 111, 118, 101, 114, 108, 97, 121, 32, 58, 10, 45, 117, 32, 34,
  45, 45, 42, 91, 48, 44, 49, 93, 32, 45, 47, 91, 50, 93, 32, 49,
  50, 55, 46, 53, 32, 45, 43, 91, 49, 93, 32, 91, 48, 93, 32, 45,
  42, 91, 49, 93, 32, 50, 32, 45, 45, 91, 49, 93, 32, 50, 53, 53,
  32, 45, 45, 91, 49, 93, 32, 91, 50, 93, 32, 45, 45, 108, 116, 91,
  48, 93, 32, 49, 50, 56, 32, 45, 106, 91, 49, 93, 32, 91, 50, 93,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 51, 93, 32, 45,
  114, 109, 91, 50, 44, 51, 93, 32, 45, 99, 91, 49, 93, 32, 48, 44,
  50, 53, 53, 34, 10, 95, 98, 108, 101, 110, 100, 95, 112, 105, 110, 108,
  105, 103, 104, 116, 32, 58, 10, 45, 117, 32, 34, 45, 42, 91, 49, 93,
  32, 50, 32, 45, 45, 98, 108, 101, 110, 100, 32, 100, 97, 114, 107, 101,
  110, 32, 45, 45, 91, 49, 93, 32, 50, 53, 54, 32, 45, 45, 98, 108,
  101, 110, 100, 91, 48, 44, 49, 93, 32, 108, 105, 103, 104, 116, 101, 110,
  32, 45, 103, 101, 91, 49, 93, 32, 48, 32, 34, 92, 10, 34, 45, 106,
  91, 50, 93, 32, 91, 51, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44,
  49, 44, 91, 49, 93, 32, 45, 114, 109, 91, 49, 44, 51, 93, 34, 10,
  95, 98, 108, 101, 110, 100, 95, 114, 101, 102, 108, 101, 99, 116, 32, 58,
  10, 45, 117, 32, 34, 45, 45, 91, 49, 93, 32, 50, 53, 53, 46, 49,
  32, 45, 42, 91, 49, 93, 32, 45, 49, 32, 45, 45, 115, 113, 114, 91,
  48, 93, 32, 45, 47, 91, 50, 93, 32, 91, 49, 93, 32, 45, 114, 109,
  91, 49, 93, 32, 45, 99, 91, 49, 93, 32, 48, 44, 50, 53, 53, 34,
  10, 95, 98, 108, 101, 110, 100, 95, 114, 101, 100, 32, 58, 10, 45, 117,
  32, 34, 45, 115, 104, 91, 48, 93, 32, 49, 44, 49, 48, 48, 37, 32,
  45, 106, 91, 49, 93, 32, 91, 50, 93, 44, 48, 44, 48, 44, 48, 44,
  49, 32, 45, 114, 109, 91, 50, 93, 34, 10, 95, 98, 108, 101, 110, 100,
  95, 115, 97, 116, 117, 114, 97, 116, 105, 111, 110, 32, 58, 10, 45, 117,
  32, 34, 45, 116, 111, 95, 99, 111, 108, 111, 114, 32, 45, 115, 104, 32,
  48, 44, 50, 32, 45, 114, 103, 98, 50, 104, 115, 118, 91, 50, 44, 51,
  93, 32, 45, 115, 104, 105, 102, 116, 91, 50, 44, 51, 93, 32, 48, 44,
  48, 44, 48, 44, 45, 49, 44, 50, 32, 45, 115, 104, 91, 50, 93, 32,
  49, 44, 50, 32, 45, 106, 91, 49, 93, 32, 91, 52, 93, 44, 48, 44,
  48, 44, 48, 44, 49, 32, 45, 114, 109, 91, 52, 93, 32, 45, 115, 104,
  105, 102, 116, 91, 50, 44, 51, 93, 32, 48, 44, 48, 44, 48, 44, 49,
  44, 50, 32, 45, 104, 115, 118, 50, 114, 103, 98, 91, 50, 44, 51, 93,
  32, 45, 114, 109, 91, 50, 44, 51, 93, 34, 10, 95, 98, 108, 101, 110,
  100, 95, 115, 99, 114, 101, 101, 110, 32, 58, 10, 45, 117, 32, 34, 45,
  45, 45, 91, 48, 93, 32, 50, 53, 53, 32, 45, 45, 91, 49, 93, 32,
  50, 53, 53, 32, 45, 42, 91, 49, 44, 50, 93, 32, 45, 47, 91, 49,
  93, 32, 50, 53, 53, 32, 45, 42, 91, 49, 93, 32, 45, 49, 32, 45,
  43, 91, 49, 93, 32, 50, 53, 53, 34, 10, 95, 98, 108, 101, 110, 100,
  95, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97, 103, 101, 32, 58, 10,
  45, 117, 32, 34, 45, 110, 111, 114, 109, 91, 49, 93, 32, 45, 108, 97,
  98, 101, 108, 91, 49, 93, 32, 78, 61, 123, 105, 77, 43, 49, 125, 32,
  34, 92, 10, 34, 45, 114, 101, 112, 101, 97, 116, 32, 64, 123, 48, 44,
  115, 125, 32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48, 93,
  32, 36, 62, 32, 109, 61, 123, 105, 109, 125, 32, 77, 61, 123, 105, 77,
  125, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 123, 49, 45, 49, 47,
  50, 53, 54, 125, 32, 45, 43, 91, 45, 49, 93, 32, 91, 49, 93, 32,
  45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 49, 93, 32, 123,
  36, 78, 42, 50, 53, 54, 125, 44, 48, 44, 123, 36, 78, 45, 49, 47,
  50, 53, 54, 125, 32, 34, 92, 10, 34, 45, 105, 91, 45, 50, 93, 32,
  50, 53, 54, 44, 49, 44, 49, 44, 49, 44, 39, 120, 42, 40, 36, 77,
  45, 36, 109, 41, 47, 50, 53, 53, 43, 36, 109, 39, 32, 45, 114, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 50, 32, 45, 42, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 91, 45, 50, 44, 45,
  49, 93, 32, 36, 78, 44, 49, 44, 49, 44, 49, 44, 50, 32, 45, 43,
  91, 45, 49, 93, 32, 49, 101, 45, 56, 32, 45, 47, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 100, 111, 110, 101, 32, 34, 92, 10, 34, 45, 97,
  91, 50, 45, 45, 49, 93, 32, 99, 32, 45, 109, 97, 112, 91, 49, 93,
  32, 91, 50, 93, 32, 45, 114, 109, 91, 50, 93, 34, 10, 95, 98, 108,
  101, 110, 100, 95, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97, 103, 101,
  48, 32, 58, 10, 45, 117, 32, 34, 45, 110, 111, 114, 109, 91, 49, 93,
  32, 45, 45, 110, 101, 113, 91, 49, 93, 32, 48, 32, 45, 108, 97, 98,
  101, 108, 91, 49, 93, 32, 78, 61, 64, 123, 49, 44, 105, 77, 43, 49,
  125, 32, 34, 92, 10, 34, 45, 114, 101, 112, 101, 97, 116, 32, 64, 123,
  48, 44, 115, 125, 32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91,
  48, 93, 32, 36, 62, 32, 109, 61, 123, 105, 109, 125, 32, 77, 61, 123,
  105, 77, 125, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 123, 49, 45,
  49, 47, 50, 53, 54, 125, 32, 45, 43, 91, 45, 49, 93, 32, 91, 49,
  93, 32, 45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 49, 93,
  32, 123, 36, 78, 42, 50, 53, 54, 125, 44, 48, 44, 123, 36, 78, 45,
  49, 47, 50, 53, 54, 125, 32, 34, 92, 10, 34, 45, 105, 91, 45, 50,
  93, 32, 50, 53, 54, 44, 49, 44, 49, 44, 49, 44, 39, 120, 42, 40,
  36, 77, 45, 36, 109, 41, 47, 50, 53, 53, 43, 36, 109, 39, 32, 45,
  114, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 50, 32, 45,
  42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 91, 45, 50,
  44, 45, 49, 93, 32, 36, 78, 44, 49, 44, 49, 44, 49, 44, 50, 32,
  45, 43, 91, 45, 49, 93, 32, 49, 101, 45, 56, 32, 45, 47, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 100, 111, 110, 101, 32, 34, 92, 10, 34,
  45, 97, 91, 51, 45, 45, 49, 93, 32, 99, 32, 45, 109, 97, 112, 91,
  49, 93, 32, 91, 51, 93, 32, 45, 114, 109, 91, 51, 93, 32, 45, 42,
  91, 49, 44, 50, 93, 34, 10, 95, 98, 108, 101, 110, 100, 95, 115, 111,
  102, 116, 98, 117, 114, 110, 32, 58, 10, 45, 117, 32, 34, 45, 45, 45,
  91, 48, 93, 32, 50, 53, 53, 46, 49, 32, 45, 94, 91, 50, 93, 32,
  45, 49, 32, 45, 42, 91, 50, 93, 32, 91, 49, 93, 32, 45, 42, 91,
  50, 93, 32, 45, 49, 50, 55, 46, 53, 32, 45, 45, 45, 91, 48, 93,
  32, 50, 53, 53, 32, 45, 45, 43, 91, 49, 93, 32, 48, 46, 49, 32,
  45, 47, 91, 51, 44, 52, 93, 32, 45, 42, 91, 51, 93, 32, 49, 50,
  55, 46, 53, 32, 45, 43, 91, 51, 93, 32, 50, 53, 53, 32, 45, 43,
  91, 49, 93, 32, 91, 48, 93, 32, 45, 103, 116, 91, 49, 93, 32, 50,
  53, 53, 32, 34, 92, 10, 34, 45, 106, 91, 50, 93, 32, 91, 51, 93,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 49, 93, 32, 45,
  114, 109, 91, 49, 44, 51, 93, 32, 45, 99, 91, 49, 93, 32, 48, 44,
  50, 53, 53, 34, 10, 95, 98, 108, 101, 110, 100, 95, 115, 111, 102, 116,
  100, 111, 100, 103, 101, 32, 58, 10, 45, 117, 32, 34, 45, 45, 45, 91,
  49, 93, 32, 50, 53, 53, 46, 49, 32, 45, 94, 91, 50, 93, 32, 45,
  49, 32, 45, 42, 91, 50, 93, 32, 91, 48, 93, 32, 45, 42, 91, 50,
  93, 32, 45, 49, 50, 55, 46, 53, 32, 45, 45, 45, 91, 49, 93, 32,
  50, 53, 53, 32, 45, 45, 43, 91, 48, 93, 32, 48, 46, 49, 32, 45,
  47, 91, 51, 44, 52, 93, 32, 45, 42, 91, 51, 93, 32, 49, 50, 55,
  46, 53, 32, 45, 43, 91, 51, 93, 32, 50, 53, 53, 32, 45, 43, 91,
  49, 93, 32, 91, 48, 93, 32, 45, 103, 116, 91, 49, 93, 32, 50, 53,
  53, 32, 34, 92, 10, 34, 45, 106, 91, 50, 93, 32, 91, 51, 93, 44,
  48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 49, 93, 32, 45, 114,
  109, 91, 49, 44, 51, 93, 32, 45, 99, 91, 49, 93, 32, 48, 44, 50,
  53, 53, 34, 10, 95, 98, 108, 101, 110, 100, 95, 115, 111, 102, 116, 108,
  105, 103, 104, 116, 32, 58, 10, 45, 117, 32, 34, 45, 45, 47, 91, 48,
  93, 32, 50, 53, 53, 32, 45, 47, 91, 49, 93, 32, 50, 53, 53, 32,
  45, 45, 115, 113, 114, 91, 45, 49, 93, 32, 45, 42, 91, 50, 93, 32,
  91, 49, 93, 32, 45, 42, 91, 49, 93, 32, 91, 51, 93, 32, 45, 42,
  91, 49, 93, 32, 45, 50, 32, 45, 42, 91, 50, 93, 32, 50, 32, 45,
  43, 91, 49, 45, 51, 93, 32, 45, 42, 91, 49, 93, 32, 50, 53, 53,
  32, 45, 99, 91, 49, 93, 32, 48, 44, 50, 53, 53, 34, 10, 95, 98,
  108, 101, 110, 100, 95, 115, 116, 97, 109, 112, 32, 58, 10, 45, 117, 32,
  34, 45, 42, 91, 49, 93, 32, 50, 32, 45, 43, 91, 49, 93, 32, 91,
  48, 93, 32, 45, 45, 91, 49, 93, 32, 50, 53, 53, 32, 45, 99, 91,
  49, 93, 32, 48, 44, 50, 53, 53, 34, 10, 95, 98, 108, 101, 110, 100,
  95, 115, 117, 98, 116, 114, 97, 99, 116, 32, 58, 10, 45, 117, 32, 34,
  45, 45, 91, 49, 93, 32, 91, 48, 93, 32, 45, 42, 91, 49, 93, 32,
  45, 49, 32, 45, 99, 91, 49, 93, 32, 48, 44, 50, 53, 53, 34, 10,
  95, 98, 108, 101, 110, 100, 95, 118, 97, 108, 117, 101, 32, 58, 10, 45,
  117, 32, 34, 45, 116, 111, 95, 99, 111, 108, 111, 114, 32, 45, 115, 104,
  32, 48, 44, 50, 32, 45, 114, 103, 98, 50, 104, 115, 118, 91, 50, 44,
  51, 93, 32, 45, 115, 104, 91, 50, 93, 32, 48, 44, 49, 32, 45, 106,
  91, 49, 93, 32, 91, 52, 93, 32, 45, 114, 109, 91, 52, 93, 32, 45,
  104, 115, 118, 50, 114, 103, 98, 91, 50, 44, 51, 93, 32, 45, 114, 109,
  91, 50, 44, 51, 93, 34, 10, 95, 98, 108, 101, 110, 100, 95, 118, 105,
  118, 105, 100, 108, 105, 103, 104, 116, 32, 58, 10, 45, 117, 32, 34, 45,
  42, 91, 49, 93, 32, 50, 32, 45, 45, 98, 108, 101, 110, 100, 32, 98,
  117, 114, 110, 32, 45, 45, 91, 49, 93, 32, 50, 53, 54, 32, 45, 45,
  98, 108, 101, 110, 100, 91, 48, 44, 49, 93, 32, 100, 111, 100, 103, 101,
  32, 45, 103, 101, 91, 49, 93, 32, 48, 32, 34, 92, 10, 34, 45, 106,
  91, 50, 93, 32, 91, 51, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44,
  49, 44, 91, 49, 93, 32, 45, 114, 109, 91, 49, 44, 51, 93, 34, 10,
  95, 98, 108, 101, 110, 100, 95, 120, 111, 114, 32, 58, 10, 45, 117, 32,
  34, 45, 120, 111, 114, 91, 49, 93, 32, 91, 48, 93, 34, 10, 35, 64,
  103, 109, 105, 99, 32, 98, 108, 101, 110, 100, 95, 101, 100, 103, 101, 115,
  32, 58, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 91, 37, 93,
  62, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 66, 108, 101,
  110, 100, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 32, 116, 111, 103, 101, 116, 104, 101, 114, 115, 32, 117, 115, 105,
  110, 103, 32, 39, 101, 100, 103, 101, 115, 39, 32, 109, 111, 100, 101, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 116, 101, 115, 116, 105, 109, 97, 103, 101,
  50, 100, 32, 123, 119, 125, 44, 123, 104, 125, 32, 45, 45, 98, 108, 101,
  110, 100, 95, 101, 100, 103, 101, 115, 32, 48, 46, 56, 10, 98, 108, 101,
  110, 100, 95, 101, 100, 103, 101, 115, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 123, 36, 49, 62, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 66, 108, 101, 110, 100, 32, 105, 109, 97, 103, 101, 36, 63,
  32, 117, 115, 105, 110, 103, 32, 39, 101, 100, 103, 101, 115, 39, 32, 109,
  111, 100, 101, 44, 32, 119, 105, 116, 104, 32, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 36, 49, 46, 34, 10, 45, 105, 102, 32, 123, 64,
  35, 62, 49, 125, 32, 45, 118, 32, 45, 32, 45, 116, 111, 95, 114, 103,
  98, 32, 45, 114, 91, 94, 48, 93, 32, 91, 48, 93, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 103, 114, 97,
  100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 32, 45, 43, 91, 45, 49,
  93, 32, 49, 32, 45, 98, 91, 45, 49, 93, 32, 36, 49, 32, 45, 110,
  91, 45, 49, 93, 32, 49, 44, 49, 48, 32, 45, 115, 113, 114, 91, 45,
  49, 93, 32, 45, 115, 91, 45, 50, 93, 32, 99, 32, 45, 42, 91, 45,
  52, 45, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 97, 91, 45, 52,
  45, 45, 49, 93, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 114, 91, 94, 48, 93, 32, 91, 48, 93, 44, 48, 44,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 43, 32, 45, 115, 91,
  45, 49, 93, 32, 99, 32, 45, 47, 91, 45, 52, 45, 45, 50, 93, 32,
  91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 97, 91,
  45, 51, 45, 45, 49, 93, 32, 99, 32, 45, 118, 32, 43, 32, 45, 101,
  110, 100, 105, 102, 10, 35, 64, 103, 109, 105, 99, 32, 98, 108, 101, 110,
  100, 95, 102, 97, 100, 101, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  66, 108, 101, 110, 100, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105,
  109, 97, 103, 101, 115, 32, 116, 111, 103, 101, 116, 104, 101, 114, 32, 117,
  115, 105, 110, 103, 32, 97, 32, 103, 105, 118, 101, 110, 32, 102, 97, 100,
  105, 110, 103, 32, 112, 97, 116, 116, 101, 114, 110, 32, 40, 100, 101, 102,
  105, 110, 101, 100, 32, 97, 115, 32, 116, 104, 101, 32, 108, 97, 116, 101,
  115, 116, 32, 105, 109, 97, 103, 101, 41, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 116, 101, 115, 116, 105, 109, 97, 103, 101, 50, 100, 32, 123, 119, 125,
  44, 123, 104, 125, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 49, 44, 39, 99, 111, 115, 40, 121, 47, 49, 48, 41, 39, 32, 45,
  110, 111, 114, 109, 97, 108, 105, 122, 101, 91, 45, 49, 93, 32, 48, 44,
  49, 32, 45, 45, 98, 108, 101, 110, 100, 95, 102, 97, 100, 101, 10, 98,
  108, 101, 110, 100, 95, 102, 97, 100, 101, 32, 58, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 66, 108, 101, 110, 100, 32, 105, 109, 97, 103, 101,
  36, 63, 32, 117, 115, 105, 110, 103, 32, 39, 102, 97, 100, 101, 39, 32,
  109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 91, 94,
  45, 49, 93, 32, 64, 123, 45, 109, 97, 120, 95, 119, 104, 100, 115, 91,
  94, 45, 49, 93, 125, 44, 48, 10, 45, 114, 91, 45, 49, 93, 32, 91,
  45, 50, 93, 44, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 49, 48,
  48, 37, 44, 49, 32, 45, 109, 97, 120, 91, 45, 49, 93, 32, 48, 32,
  45, 109, 105, 110, 91, 45, 49, 93, 32, 123, 64, 35, 45, 50, 125, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 45,
  45, 45, 91, 45, 49, 93, 32, 36, 62, 32, 45, 97, 98, 115, 91, 45,
  49, 93, 32, 45, 45, 91, 45, 49, 93, 32, 49, 32, 45, 42, 91, 45,
  49, 93, 32, 45, 49, 32, 45, 109, 97, 120, 91, 45, 49, 93, 32, 48,
  32, 45, 42, 91, 36, 62, 44, 45, 49, 93, 32, 45, 100, 111, 110, 101,
  10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 43, 32, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 98, 108, 101, 110, 100, 95, 109, 101,
  100, 105, 97, 110, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 66, 108,
  101, 110, 100, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 32, 116, 111, 103, 101, 116, 104, 101, 114, 32, 117, 115, 105,
  110, 103, 32, 39, 109, 101, 100, 105, 97, 110, 39, 32, 109, 111, 100, 101,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 116, 101, 115, 116, 105, 109, 97, 103,
  101, 50, 100, 32, 123, 119, 125, 44, 123, 104, 125, 32, 45, 45, 109, 105,
  114, 114, 111, 114, 91, 48, 93, 32, 121, 32, 45, 45, 98, 108, 101, 110,
  100, 95, 109, 101, 100, 105, 97, 110, 10, 98, 108, 101, 110, 100, 95, 109,
  101, 100, 105, 97, 110, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 66, 108, 101, 110, 100, 32, 105, 109, 97, 103, 101, 36, 63, 32, 117,
  115, 105, 110, 103, 32, 39, 109, 101, 100, 105, 97, 110, 39, 32, 109, 111,
  100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 116, 111, 95, 99, 111,
  108, 111, 114, 109, 111, 100, 101, 32, 48, 32, 45, 114, 32, 64, 123, 45,
  109, 97, 120, 95, 119, 104, 100, 125, 44, 49, 48, 48, 37, 44, 48, 44,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 44, 48, 46, 53, 32, 119, 104,
  100, 61, 123, 119, 125, 44, 123, 104, 125, 44, 123, 100, 125, 32, 45, 114,
  32, 49, 48, 48, 37, 44, 123, 104, 42, 100, 125, 44, 49, 44, 49, 48,
  48, 37, 44, 45, 49, 10, 45, 105, 102, 32, 123, 64, 35, 61, 61, 50,
  125, 32, 45, 43, 32, 45, 47, 32, 50, 10, 45, 101, 108, 105, 102, 32,
  123, 64, 35, 62, 50, 125, 10, 45, 112, 101, 114, 109, 117, 116, 101, 32,
  120, 121, 99, 122, 32, 45, 97, 32, 99, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 115, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 115,
  45, 49, 45, 36, 62, 125, 10, 45, 115, 104, 91, 45, 49, 93, 32, 36,
  62, 44, 36, 62, 32, 45, 115, 104, 91, 45, 50, 93, 32, 123, 36, 62,
  43, 49, 125, 44, 123, 36, 62, 43, 49, 125, 32, 45, 45, 103, 116, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 45, 106, 91, 45, 51, 93, 32, 91,
  45, 50, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45,
  49, 93, 32, 45, 106, 91, 45, 51, 93, 32, 91, 45, 52, 93, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 50, 93, 32, 45, 106,
  91, 45, 52, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 52,
  45, 45, 49, 93, 10, 45, 100, 111, 110, 101, 10, 45, 100, 111, 110, 101,
  10, 45, 105, 102, 32, 123, 115, 37, 50, 125, 32, 45, 99, 104, 97, 110,
  110, 101, 108, 115, 32, 53, 48, 37, 32, 45, 101, 108, 115, 101, 32, 45,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 123, 115, 47, 50, 45, 49, 125,
  44, 123, 115, 47, 50, 125, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 43, 32, 45, 47, 32, 50, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 112, 101, 114, 109, 117, 116, 101, 32,
  120, 121, 99, 122, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 91, 45,
  49, 93, 32, 36, 119, 104, 100, 44, 49, 48, 48, 37, 44, 45, 49, 32,
  45, 118, 32, 43, 10, 95, 102, 97, 100, 101, 32, 58, 10, 45, 114, 91,
  45, 50, 93, 32, 91, 45, 51, 93, 44, 53, 32, 45, 114, 91, 45, 49,
  93, 32, 91, 45, 50, 93, 44, 51, 32, 45, 99, 91, 45, 49, 93, 32,
  36, 49, 37, 44, 36, 50, 37, 32, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 49, 32, 45, 106, 91, 45, 51, 93, 32, 91, 45, 50, 93, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 32, 45, 114,
  109, 91, 45, 50, 44, 45, 49, 93, 10, 35, 64, 103, 109, 105, 99, 32,
  102, 97, 100, 101, 95, 100, 105, 97, 109, 111, 110, 100, 32, 58, 32, 48,
  60, 61, 95, 115, 116, 97, 114, 116, 60, 61, 49, 48, 48, 44, 48, 60,
  61, 95, 101, 110, 100, 60, 61, 49, 48, 48, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 67, 114, 101, 97, 116, 101, 32, 100, 105, 97, 109, 111,
  110, 100, 32, 102, 97, 100, 105, 110, 103, 32, 102, 114, 111, 109, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116,
  32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 115, 116, 97, 114, 116, 61,
  56, 48, 39, 32, 97, 110, 100, 32, 39, 101, 110, 100, 61, 57, 48, 39,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97,
  103, 101, 46, 106, 112, 103, 32, 45, 116, 101, 115, 116, 105, 109, 97, 103,
  101, 50, 100, 32, 123, 119, 125, 44, 123, 104, 125, 32, 45, 45, 102, 97,
  100, 101, 95, 100, 105, 97, 109, 111, 110, 100, 32, 56, 48, 44, 56, 53,
  10, 102, 97, 100, 101, 95, 100, 105, 97, 109, 111, 110, 100, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 55, 48, 125, 44, 36, 123,
  50, 61, 57, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67,
  114, 101, 97, 116, 101, 32, 40, 36, 49, 37, 44, 36, 50, 37, 41, 32,
  100, 105, 97, 109, 111, 110, 100, 45, 115, 104, 97, 112, 101, 100, 32, 102,
  97, 100, 105, 110, 103, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101,
  36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108,
  91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 40, 48, 44, 49,
  44, 48, 59, 49, 44, 49, 44, 49, 59, 48, 44, 49, 44, 48, 41, 32,
  45, 95, 102, 97, 100, 101, 32, 36, 49, 44, 36, 50, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 102, 97, 100, 101, 95, 108, 105, 110, 101, 97, 114,
  32, 58, 32, 95, 97, 110, 103, 108, 101, 44, 48, 60, 61, 95, 115, 116,
  97, 114, 116, 60, 61, 49, 48, 48, 44, 48, 60, 61, 95, 101, 110, 100,
  60, 61, 49, 48, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67,
  114, 101, 97, 116, 101, 32, 108, 105, 110, 101, 97, 114, 32, 102, 97, 100,
  105, 110, 103, 32, 102, 114, 111, 109, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  115, 58, 32, 39, 97, 110, 103, 108, 101, 61, 52, 53, 39, 44, 32, 39,
  115, 116, 97, 114, 116, 61, 51, 48, 39, 32, 97, 110, 100, 32, 39, 101,
  110, 100, 61, 55, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 116, 101,
  115, 116, 105, 109, 97, 103, 101, 50, 100, 32, 123, 119, 125, 44, 123, 104,
  125, 32, 45, 45, 102, 97, 100, 101, 95, 108, 105, 110, 101, 97, 114, 32,
  52, 53, 44, 52, 56, 44, 53, 50, 10, 102, 97, 100, 101, 95, 108, 105,
  110, 101, 97, 114, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49,
  61, 52, 53, 125, 44, 36, 123, 50, 61, 51, 48, 125, 44, 36, 123, 51,
  61, 55, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 114,
  101, 97, 116, 101, 32, 40, 36, 50, 37, 44, 36, 51, 37, 41, 32, 108,
  105, 110, 101, 97, 114, 32, 102, 97, 100, 105, 110, 103, 32, 102, 114, 111,
  109, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32,
  97, 110, 103, 108, 101, 32, 36, 49, 32, 100, 101, 103, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116,
  40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36,
  62, 43, 49, 125, 93, 10, 54, 52, 44, 54, 52, 44, 49, 44, 49, 44,
  34, 120, 42, 99, 111, 115, 40, 36, 49, 42, 112, 105, 47, 49, 56, 48,
  41, 32, 43, 32, 121, 42, 115, 105, 110, 40, 36, 49, 42, 112, 105, 47,
  49, 56, 48, 41, 34, 32, 45, 95, 102, 97, 100, 101, 32, 36, 50, 44,
  36, 51, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 102, 97, 100, 101, 95,
  114, 97, 100, 105, 97, 108, 32, 58, 32, 48, 60, 61, 95, 115, 116, 97,
  114, 116, 60, 61, 49, 48, 48, 44, 48, 60, 61, 95, 101, 110, 100, 60,
  61, 49, 48, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 114,
  101, 97, 116, 101, 32, 114, 97, 100, 105, 97, 108, 32, 102, 97, 100, 105,
  110, 103, 32, 102, 114, 111, 109, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115,
  58, 32, 39, 115, 116, 97, 114, 116, 61, 51, 48, 39, 32, 97, 110, 100,
  32, 39, 101, 110, 100, 61, 55, 48, 39, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32,
  45, 116, 101, 115, 116, 105, 109, 97, 103, 101, 50, 100, 32, 123, 119, 125,
  44, 123, 104, 125, 32, 45, 45, 102, 97, 100, 101, 95, 114, 97, 100, 105,
  97, 108, 32, 51, 48, 44, 55, 48, 10, 102, 97, 100, 101, 95, 114, 97,
  100, 105, 97, 108, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49,
  61, 51, 48, 125, 44, 36, 123, 50, 61, 55, 48, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 114, 101, 97, 116, 101, 32, 40, 36, 49,
  37, 44, 36, 50, 37, 41, 32, 114, 97, 100, 105, 97, 108, 32, 102, 97,
  100, 105, 110, 103, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36,
  63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91,
  36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 32, 45, 61, 91, 45, 49, 93, 32, 49, 44, 53, 48,
  37, 44, 53, 48, 37, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91,
  45, 49, 93, 32, 49, 32, 45, 95, 102, 97, 100, 101, 32, 36, 49, 44,
  36, 50, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 102, 97, 100, 101, 95,
  120, 32, 58, 32, 48, 60, 61, 95, 115, 116, 97, 114, 116, 60, 61, 49,
  48, 48, 44, 48, 60, 61, 95, 101, 110, 100, 60, 61, 49, 48, 48, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 114, 101, 97, 116, 101, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 32, 102, 97, 100, 105, 110,
  103, 32, 102, 114, 111, 109, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58,
  32, 39, 115, 116, 97, 114, 116, 61, 51, 48, 39, 32, 97, 110, 100, 32,
  39, 101, 110, 100, 61, 55, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  116, 101, 115, 116, 105, 109, 97, 103, 101, 50, 100, 32, 123, 119, 125, 44,
  123, 104, 125, 32, 45, 45, 102, 97, 100, 101, 95, 120, 32, 51, 48, 44,
  55, 48, 10, 102, 97, 100, 101, 95, 120, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 49, 61, 51, 48, 125, 44, 36, 123, 50, 61, 55, 48,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 114, 101, 97, 116,
  101, 32, 40, 36, 49, 37, 44, 36, 50, 37, 41, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 32, 102, 97, 100, 105, 110, 103, 32, 102, 114,
  111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64,
  35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43,
  49, 125, 93, 32, 40, 48, 44, 49, 41, 32, 45, 95, 102, 97, 100, 101,
  32, 36, 49, 44, 36, 50, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 102,
  97, 100, 101, 95, 121, 32, 58, 32, 48, 60, 61, 95, 115, 116, 97, 114,
  116, 60, 61, 49, 48, 48, 44, 48, 60, 61, 95, 101, 110, 100, 60, 61,
  49, 48, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 114, 101,
  97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 32, 102, 97, 100,
  105, 110, 103, 32, 102, 114, 111, 109, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  115, 58, 32, 39, 115, 116, 97, 114, 116, 61, 51, 48, 39, 32, 97, 110,
  100, 32, 39, 101, 110, 100, 61, 55, 48, 39, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 116, 101, 115, 116, 105, 109, 97, 103, 101, 50, 100, 32, 123, 119,
  125, 44, 123, 104, 125, 32, 45, 45, 102, 97, 100, 101, 95, 121, 32, 51,
  48, 44, 55, 48, 10, 102, 97, 100, 101, 95, 121, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 49, 61, 51, 48, 125, 44, 36, 123, 50, 61,
  55, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 114, 101,
  97, 116, 101, 32, 40, 36, 49, 37, 44, 36, 50, 37, 41, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 32, 102, 97, 100, 105, 110, 103, 32, 102, 114,
  111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64,
  35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43,
  49, 125, 93, 32, 40, 48, 59, 49, 41, 32, 45, 95, 102, 97, 100, 101,
  32, 36, 49, 44, 36, 50, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 102,
  97, 100, 101, 95, 122, 32, 58, 32, 48, 60, 61, 95, 115, 116, 97, 114,
  116, 60, 61, 49, 48, 48, 44, 48, 60, 61, 95, 101, 110, 100, 60, 61,
  49, 48, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 114, 101,
  97, 116, 101, 32, 116, 114, 97, 110, 115, 118, 101, 114, 115, 97, 108, 32,
  102, 97, 100, 105, 110, 103, 32, 102, 114, 111, 109, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 115, 116, 97, 114, 116, 61, 51, 48, 39,
  32, 97, 110, 100, 32, 39, 101, 110, 100, 61, 55, 48, 39, 46, 10, 102,
  97, 100, 101, 95, 122, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  49, 61, 51, 48, 125, 44, 36, 123, 50, 61, 55, 48, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 114, 101, 97, 116, 101, 32, 40, 36,
  49, 37, 44, 36, 50, 37, 41, 32, 116, 114, 97, 110, 115, 118, 101, 114,
  115, 97, 108, 32, 102, 97, 100, 105, 110, 103, 32, 102, 114, 111, 109, 32,
  105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50,
  41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93,
  32, 40, 48, 47, 49, 41, 32, 45, 95, 102, 97, 100, 101, 32, 36, 49,
  44, 36, 50, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 58, 58, 32, 73,
  109, 97, 103, 101, 32, 115, 101, 113, 117, 101, 110, 99, 101, 115, 10, 35,
  64, 103, 109, 105, 99, 32, 97, 110, 105, 109, 97, 116, 101, 32, 58, 32,
  102, 105, 108, 116, 101, 114, 95, 110, 97, 109, 101, 44, 34, 112, 97, 114,
  97, 109, 49, 95, 115, 116, 97, 114, 116, 44, 46, 46, 44, 112, 97, 114,
  97, 109, 78, 95, 115, 116, 97, 114, 116, 34, 44, 34, 112, 97, 114, 97,
  109, 49, 95, 101, 110, 100, 44, 46, 46, 44, 112, 97, 114, 97, 109, 78,
  95, 101, 110, 100, 34, 44, 110, 98, 95, 102, 114, 97, 109, 101, 115, 62,
  61, 48, 44, 95, 111, 117, 116, 112, 117, 116, 95, 102, 114, 97, 109, 101,
  115, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 44, 95, 111, 117, 116,
  112, 117, 116, 95, 102, 105, 108, 101, 110, 97, 109, 101, 32, 58, 32, 100,
  101, 108, 97, 121, 62, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  65, 110, 105, 109, 97, 116, 101, 32, 102, 105, 108, 116, 101, 114, 32, 102,
  114, 111, 109, 32, 115, 116, 97, 114, 116, 105, 110, 103, 32, 112, 97, 114,
  97, 109, 101, 116, 101, 114, 115, 32, 116, 111, 32, 101, 110, 100, 105, 110,
  103, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 111, 114, 32,
  97, 110, 105, 109, 97, 116, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 105, 110, 32, 97, 32, 100, 105, 115, 112, 108, 97, 121, 32, 119, 105,
  110, 100, 111, 119, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 58, 32, 39, 100,
  101, 108, 97, 121, 61, 51, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  97, 110, 105, 109, 97, 116, 101, 32, 102, 108, 111, 119, 101, 114, 44, 34,
  48, 44, 51, 34, 44, 34, 50, 48, 44, 56, 34, 44, 57, 10, 97, 110,
  105, 109, 97, 116, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  49, 61, 51, 48, 125, 44, 36, 123, 50, 61, 48, 125, 44, 36, 123, 51,
  61, 34, 34, 125, 44, 36, 123, 52, 61, 49, 48, 125, 44, 36, 123, 53,
  61, 49, 125, 44, 34, 36, 123, 54, 61, 125, 34, 10, 45, 105, 102, 32,
  123, 105, 115, 118, 97, 108, 40, 36, 49, 41, 125, 10, 45, 105, 102, 32,
  36, 50, 32, 45, 101, 91, 48, 45, 45, 52, 93, 32, 34, 65, 110, 105,
  109, 97, 116, 101, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105,
  116, 104, 32, 97, 32, 100, 101, 108, 97, 121, 32, 111, 102, 32, 36, 49,
  32, 109, 115, 44, 32, 97, 110, 100, 32, 112, 105, 110, 103, 45, 112, 111,
  110, 103, 32, 109, 111, 100, 101, 46, 34, 10, 45, 101, 108, 115, 101, 32,
  45, 101, 91, 48, 45, 45, 52, 93, 32, 34, 65, 110, 105, 109, 97, 116,
  101, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32,
  97, 32, 100, 101, 108, 97, 121, 32, 111, 102, 32, 36, 49, 32, 109, 115,
  46, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 33,
  64, 35, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 118, 32, 45, 10, 115, 112, 101, 101, 100, 61, 36, 49,
  10, 112, 97, 117, 115, 101, 61, 45, 49, 10, 100, 105, 114, 101, 99, 116,
  105, 111, 110, 61, 49, 10, 102, 114, 97, 109, 101, 61, 48, 10, 45, 100,
  111, 10, 45, 119, 91, 36, 102, 114, 97, 109, 101, 93, 32, 45, 49, 44,
  45, 49, 44, 49, 44, 48, 44, 45, 49, 44, 45, 49, 44, 64, 123, 36,
  102, 114, 97, 109, 101, 44, 98, 125, 46, 64, 123, 36, 102, 114, 97, 109,
  101, 44, 120, 125, 10, 102, 114, 97, 109, 101, 61, 123, 36, 102, 114, 97,
  109, 101, 43, 36, 100, 105, 114, 101, 99, 116, 105, 111, 110, 125, 10, 45,
  105, 102, 32, 36, 50, 10, 45, 105, 102, 32, 123, 36, 102, 114, 97, 109,
  101, 61, 61, 45, 49, 125, 32, 102, 114, 97, 109, 101, 61, 48, 32, 100,
  105, 114, 101, 99, 116, 105, 111, 110, 61, 49, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 102, 114, 97, 109, 101, 61, 61, 64, 35, 125, 32, 102, 114,
  97, 109, 101, 61, 123, 64, 35, 45, 49, 125, 32, 100, 105, 114, 101, 99,
  116, 105, 111, 110, 61, 45, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 108, 115, 101, 32, 102, 114, 97, 109, 101, 61, 123, 36, 102, 114, 97,
  109, 101, 37, 64, 35, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 119,
  97, 105, 116, 32, 36, 115, 112, 101, 101, 100, 10, 45, 105, 102, 32, 123,
  40, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 34, 32,
  124, 124, 32, 34, 64, 123, 33, 44, 67, 84, 82, 76, 82, 73, 71, 72,
  84, 125, 41, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 68, 125, 125,
  32, 45, 119, 91, 93, 32, 123, 64, 123, 33, 44, 119, 125, 42, 49, 46,
  53, 125, 44, 123, 64, 123, 33, 44, 104, 125, 42, 49, 46, 53, 125, 32,
  45, 119, 97, 105, 116, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 40, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69,
  70, 84, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 44, 67, 84, 82,
  76, 82, 73, 71, 72, 84, 125, 41, 34, 32, 38, 38, 32, 34, 64, 123,
  33, 44, 67, 125, 125, 32, 45, 119, 91, 93, 32, 123, 64, 123, 33, 44,
  119, 125, 47, 49, 46, 53, 125, 44, 123, 64, 123, 33, 44, 104, 125, 47,
  49, 46, 53, 125, 32, 45, 119, 97, 105, 116, 32, 45, 49, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 40, 64, 123, 33, 44, 67,
  84, 82, 76, 76, 69, 70, 84, 125, 34, 32, 124, 124, 32, 34, 64, 123,
  33, 44, 67, 84, 82, 76, 82, 73, 71, 72, 84, 125, 41, 34, 32, 38,
  38, 32, 34, 64, 123, 33, 44, 82, 125, 125, 32, 45, 119, 91, 93, 32,
  64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125, 32, 45, 119,
  97, 105, 116, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 64, 123, 33, 44, 111, 125, 32, 115, 112, 101, 101, 100, 61, 123,
  109, 105, 110, 40, 53, 48, 48, 44, 109, 97, 120, 40, 49, 48, 44, 36,
  115, 112, 101, 101, 100, 45, 49, 48, 42, 64, 123, 33, 44, 111, 125, 41,
  41, 125, 32, 45, 119, 97, 105, 116, 32, 45, 49, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 64, 123, 33, 44, 83, 80, 65, 67, 69,
  125, 10, 45, 105, 102, 32, 123, 36, 112, 97, 117, 115, 101, 62, 61, 48,
  125, 32, 100, 105, 114, 101, 99, 116, 105, 111, 110, 61, 36, 112, 97, 117,
  115, 101, 32, 112, 97, 117, 115, 101, 61, 45, 49, 10, 45, 101, 108, 115,
  101, 32, 112, 97, 117, 115, 101, 61, 36, 100, 105, 114, 101, 99, 116, 105,
  111, 110, 32, 100, 105, 114, 101, 99, 116, 105, 111, 110, 61, 48, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 119, 97, 105, 116, 32, 45, 49, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 33,
  34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 34, 32, 38,
  38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67, 125, 125, 32, 45, 118,
  32, 43, 10, 45, 101, 108, 115, 101, 10, 45, 101, 91, 48, 45, 45, 51,
  93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 97, 110, 105, 109, 97,
  116, 101, 100, 32, 118, 101, 114, 115, 105, 111, 110, 32, 111, 102, 32, 102,
  105, 108, 116, 101, 114, 32, 39, 36, 49, 39, 44, 32, 102, 114, 111, 109,
  32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 36, 50, 32, 116,
  111, 32, 36, 51, 32, 119, 105, 116, 104, 32, 36, 52, 32, 102, 114, 97,
  109, 101, 115, 46, 34, 10, 45, 105, 102, 32, 123, 33, 40, 36, 53, 124,
  124, 110, 97, 114, 103, 40, 34, 36, 54, 34, 41, 41, 125, 32, 45, 114,
  101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32,
  45, 32, 40, 36, 50, 41, 32, 40, 36, 51, 41, 32, 45, 121, 91, 45,
  50, 44, 45, 49, 93, 32, 120, 32, 45, 97, 91, 45, 50, 44, 45, 49,
  93, 32, 121, 32, 45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44,
  36, 52, 44, 49, 44, 49, 44, 51, 32, 45, 109, 118, 91, 45, 49, 93,
  32, 48, 32, 45, 114, 112, 114, 111, 103, 114, 101, 115, 115, 32, 48, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 10, 45,
  118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 32, 62, 32, 65, 110, 105,
  109, 97, 116, 101, 32, 105, 109, 97, 103, 101, 32, 91, 34, 36, 62, 34,
  93, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  36, 52, 32, 45, 45, 108, 91, 48, 44, 49, 93, 10, 45, 36, 49, 91,
  45, 49, 93, 32, 64, 123, 48, 44, 123, 36, 62, 42, 64, 123, 48, 44,
  119, 125, 125, 45, 123, 40, 36, 62, 43, 49, 41, 42, 64, 123, 48, 44,
  119, 125, 45, 49, 125, 125, 32, 45, 114, 109, 91, 48, 93, 10, 45, 105,
  102, 32, 123, 110, 97, 114, 103, 40, 34, 36, 54, 34, 41, 125, 32, 45,
  111, 32, 64, 123, 45, 102, 105, 108, 101, 110, 97, 109, 101, 92, 32, 34,
  36, 54, 34, 44, 64, 123, 62, 44, 45, 50, 125, 44, 36, 62, 125, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 33, 36, 53, 125,
  32, 45, 114, 109, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 112, 114,
  111, 103, 114, 101, 115, 115, 32, 123, 49, 48, 48, 42, 40, 36, 62, 43,
  49, 41, 47, 36, 52, 125, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93,
  32, 34, 92, 114, 32, 62, 32, 65, 110, 105, 109, 97, 116, 101, 32, 105,
  109, 97, 103, 101, 32, 91, 34, 64, 123, 62, 44, 45, 50, 125, 34, 93,
  32, 58, 32, 70, 114, 97, 109, 101, 32, 34, 123, 36, 62, 43, 49, 125,
  34, 47, 36, 52, 32, 32, 32, 32, 34, 32, 45, 118, 32, 45, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 49,
  93, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 93, 32, 45,
  118, 32, 43, 10, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103, 109, 105,
  99, 32, 109, 111, 114, 112, 104, 32, 58, 32, 110, 98, 95, 102, 114, 97,
  109, 101, 115, 62, 48, 44, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 62, 61, 48, 44, 95, 112, 114, 101, 99, 105, 115, 105, 111, 110, 62,
  48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 114, 101, 97, 116,
  101, 32, 109, 111, 114, 112, 104, 105, 110, 103, 32, 115, 101, 113, 117, 101,
  110, 99, 101, 32, 98, 101, 116, 119, 101, 101, 110, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 61, 48, 46, 49, 39, 32, 97, 110, 100, 32, 39, 112, 114, 101, 99,
  105, 115, 105, 111, 110, 61, 53, 39, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45,
  45, 114, 111, 116, 97, 116, 101, 32, 50, 48, 44, 49, 44, 49, 44, 53,
  48, 37, 44, 53, 48, 37, 32, 45, 109, 111, 114, 112, 104, 32, 57, 10,
  109, 111, 114, 112, 104, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  50, 61, 48, 46, 49, 125, 44, 36, 123, 51, 61, 53, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 114, 101, 97, 116, 101, 32, 109, 111,
  114, 112, 104, 105, 110, 103, 32, 115, 101, 113, 117, 101, 110, 99, 101, 32,
  98, 101, 116, 119, 101, 101, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 119, 105, 116, 104, 32, 36, 49, 32, 105, 110, 116, 114, 97, 45, 102,
  114, 97, 109, 101, 115, 44, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 36, 50, 32, 97, 110, 100, 32, 112, 114, 101, 99, 105, 115, 105,
  111, 110, 32, 36, 51, 46, 92, 110, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 91, 94, 48, 93, 32, 91, 48, 93, 44, 51, 32, 45, 105, 91, 48,
  93, 32, 40, 64, 35, 41, 32, 45, 45, 91, 48, 93, 32, 49, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 48, 10, 45, 118, 32, 43, 32, 45,
  101, 91, 93, 32, 34, 92, 114, 32, 62, 32, 77, 111, 114, 112, 104, 32,
  105, 109, 97, 103, 101, 32, 34, 36, 62, 34, 32, 116, 111, 32, 105, 109,
  97, 103, 101, 32, 34, 123, 36, 62, 43, 49, 125, 34, 46, 32, 32, 32,
  32, 34, 32, 45, 118, 32, 45, 10, 45, 45, 101, 113, 117, 97, 108, 105,
  122, 101, 91, 45, 50, 44, 45, 49, 93, 32, 45, 110, 91, 45, 50, 44,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 45, 100, 105, 115, 112,
  108, 97, 99, 101, 109, 101, 110, 116, 91, 45, 49, 93, 32, 91, 45, 50,
  93, 44, 36, 50, 44, 36, 51, 32, 45, 45, 119, 97, 114, 112, 91, 45,
  53, 93, 32, 91, 45, 49, 93, 44, 49, 44, 49, 44, 49, 44, 36, 49,
  32, 45, 97, 91, 45, 36, 49, 45, 45, 49, 93, 32, 122, 32, 45, 114,
  109, 91, 45, 50, 93, 10, 45, 45, 100, 105, 115, 112, 108, 97, 99, 101,
  109, 101, 110, 116, 91, 45, 51, 93, 32, 91, 45, 50, 93, 44, 36, 50,
  44, 36, 51, 32, 45, 45, 119, 97, 114, 112, 91, 45, 53, 93, 32, 91,
  45, 49, 93, 44, 49, 44, 49, 44, 49, 44, 36, 49, 32, 45, 97, 91,
  45, 36, 49, 45, 45, 49, 93, 32, 122, 32, 45, 114, 109, 91, 45, 55,
  45, 45, 52, 44, 45, 50, 93, 10, 40, 49, 47, 48, 41, 32, 45, 114,
  91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 51, 32, 45, 42, 91, 45,
  51, 93, 32, 91, 45, 49, 93, 32, 45, 42, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 122, 32,
  45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 115, 91, 45, 49, 93,
  32, 122, 10, 45, 109, 118, 91, 45, 36, 49, 45, 45, 49, 93, 32, 49,
  32, 45, 109, 118, 91, 49, 93, 32, 64, 35, 10, 45, 100, 111, 110, 101,
  32, 45, 109, 118, 91, 45, 49, 93, 32, 49, 32, 45, 114, 109, 91, 48,
  93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 114, 101,
  103, 105, 115, 116, 101, 114, 95, 110, 111, 110, 114, 105, 103, 105, 100, 32,
  58, 32, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 62, 61, 48,
  44, 95, 112, 114, 101, 99, 105, 115, 105, 111, 110, 62, 48, 44, 95, 110,
  98, 95, 115, 99, 97, 108, 101, 62, 61, 48, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 82, 101, 103, 105, 115, 116, 101, 114, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 119, 105, 116,
  104, 32, 110, 111, 110, 45, 114, 105, 103, 105, 100, 32, 119, 97, 114, 112,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117,
  108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 115, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 61, 48, 46, 50, 39, 44, 32, 39, 112, 114,
  101, 99, 105, 115, 105, 111, 110, 61, 54, 39, 32, 97, 110, 100, 32, 39,
  110, 98, 95, 115, 99, 97, 108, 101, 61, 48, 40, 97, 117, 116, 111, 41,
  39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109,
  97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 114, 111, 116, 97, 116, 101,
  32, 50, 48, 44, 49, 44, 49, 44, 53, 48, 37, 44, 53, 48, 37, 32,
  45, 45, 114, 101, 103, 105, 115, 116, 101, 114, 95, 110, 111, 110, 114, 105,
  103, 105, 100, 32, 44, 32, 45, 114, 101, 109, 111, 118, 101, 91, 45, 50,
  93, 10, 114, 101, 103, 105, 115, 116, 101, 114, 95, 110, 111, 110, 114, 105,
  103, 105, 100, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  48, 46, 50, 125, 44, 36, 123, 50, 61, 53, 125, 44, 36, 123, 51, 61,
  48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 103, 105,
  115, 116, 101, 114, 32, 105, 109, 97, 103, 101, 36, 63, 32, 119, 105, 116,
  104, 32, 110, 111, 110, 45, 114, 105, 103, 105, 100, 32, 119, 97, 114, 112,
  44, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 49, 44,
  32, 112, 114, 101, 99, 105, 115, 105, 111, 110, 32, 36, 50, 32, 97, 110,
  100, 32, 36, 51, 32, 115, 99, 97, 108, 101, 40, 115, 41, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 45, 101, 113, 117, 97, 108, 105, 122, 101, 91,
  48, 93, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32,
  45, 109, 118, 91, 45, 49, 93, 32, 49, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 105, 102, 32, 123, 36, 62, 62, 49, 125, 10,
  45, 45, 101, 113, 117, 97, 108, 105, 122, 101, 91, 45, 49, 93, 32, 45,
  110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 45, 100, 105,
  115, 112, 108, 97, 99, 101, 109, 101, 110, 116, 91, 49, 93, 32, 91, 45,
  49, 93, 44, 36, 49, 44, 36, 50, 44, 36, 51, 32, 45, 114, 109, 91,
  45, 50, 93, 10, 45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 44, 49, 44, 49, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 109, 118, 91, 45, 49, 93, 32, 50, 32, 45, 101, 110, 100, 105,
  102, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 49, 93, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 114, 101, 103, 105, 115,
  116, 101, 114, 95, 114, 105, 103, 105, 100, 32, 58, 32, 95, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 62, 61, 48, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 82, 101, 103, 105, 115, 116, 101, 114, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 32, 119, 105, 116,
  104, 32, 114, 105, 103, 105, 100, 32, 119, 97, 114, 112, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 58, 32, 39, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 115, 104, 105,
  102, 116, 32, 51, 48, 44, 50, 48, 32, 45, 45, 114, 101, 103, 105, 115,
  116, 101, 114, 95, 114, 105, 103, 105, 100, 32, 44, 32, 45, 114, 101, 109,
  111, 118, 101, 91, 45, 50, 93, 10, 114, 101, 103, 105, 115, 116, 101, 114,
  95, 114, 105, 103, 105, 100, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 49, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82,
  101, 103, 105, 115, 116, 101, 114, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  119, 105, 116, 104, 32, 114, 105, 103, 105, 100, 32, 119, 97, 114, 112, 32,
  97, 110, 100, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36,
  49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 45, 101, 113, 117, 97, 108,
  105, 122, 101, 91, 48, 93, 32, 45, 98, 91, 45, 49, 93, 32, 36, 49,
  32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 109,
  118, 91, 45, 49, 93, 32, 49, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 105, 102, 32, 123, 36, 62, 62, 49, 125, 10, 45, 45,
  101, 113, 117, 97, 108, 105, 122, 101, 91, 45, 49, 93, 32, 45, 98, 91,
  45, 49, 93, 32, 36, 49, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 32, 45, 45, 112, 104, 97, 115, 101, 95, 99, 111, 114, 114,
  101, 108, 97, 116, 105, 111, 110, 91, 49, 44, 45, 49, 93, 32, 45, 114,
  109, 91, 45, 50, 93, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32,
  45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 49, 10, 45, 115, 104,
  105, 102, 116, 91, 45, 50, 93, 32, 64, 45, 49, 44, 48, 44, 49, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 109, 118, 91, 45, 49, 93, 32,
  50, 32, 45, 101, 110, 100, 105, 102, 32, 45, 100, 111, 110, 101, 32, 45,
  114, 109, 91, 49, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 95, 112, 108, 97,
  115, 109, 97, 32, 58, 32, 95, 110, 98, 95, 102, 114, 97, 109, 101, 115,
  62, 61, 50, 44, 95, 115, 99, 97, 108, 101, 62, 61, 48, 44, 95, 115,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 91, 37, 93, 62, 61, 48, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 114, 101, 97, 116, 101, 32,
  112, 108, 97, 115, 109, 97, 32, 116, 114, 97, 110, 115, 105, 116, 105, 111,
  110, 32, 115, 101, 113, 117, 101, 110, 99, 101, 32, 98, 101, 116, 119, 101,
  101, 110, 32, 99, 111, 110, 115, 101, 99, 117, 116, 105, 118, 101, 32, 105,
  109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 110, 98, 95, 102, 114, 97, 109, 101, 115, 61, 49, 48, 39, 44, 32,
  39, 115, 99, 97, 108, 101, 61, 53, 39, 32, 97, 110, 100, 32, 39, 115,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 48, 46, 53, 37, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 116, 101, 115, 116, 105, 109, 97, 103, 101,
  50, 100, 32, 123, 119, 125, 44, 123, 104, 125, 32, 45, 116, 114, 97, 110,
  115, 105, 116, 105, 111, 110, 95, 112, 108, 97, 115, 109, 97, 32, 57, 10,
  116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 95, 112, 108, 97, 115, 109,
  97, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110,
  116, 40, 36, 123, 49, 61, 49, 48, 125, 41, 32, 38, 38, 32, 36, 49,
  62, 61, 50, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 50,
  61, 53, 125, 41, 32, 38, 38, 32, 36, 50, 62, 61, 48, 32, 38, 38,
  32, 36, 123, 51, 61, 48, 46, 53, 37, 125, 62, 61, 48, 34, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 67, 114, 101, 97, 116, 101, 32, 112,
  108, 97, 115, 109, 97, 32, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110,
  32, 115, 101, 113, 117, 101, 110, 99, 101, 32, 98, 101, 116, 119, 101, 101,
  110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32,
  36, 49, 32, 102, 114, 97, 109, 101, 115, 44, 32, 115, 99, 97, 108, 101,
  32, 36, 50, 44, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  36, 51, 46, 92, 110, 34, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32,
  123, 64, 35, 60, 50, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 115, 108, 105, 99, 101, 115, 32, 48, 32,
  45, 114, 32, 64, 123, 45, 109, 97, 120, 95, 119, 104, 100, 115, 125, 44,
  51, 10, 111, 102, 102, 61, 48, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 64, 35, 45, 49, 125, 32, 45, 108, 91, 123, 36, 62, 43, 36, 111,
  102, 102, 125, 44, 123, 36, 62, 43, 36, 111, 102, 102, 43, 49, 125, 93,
  10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 114, 32, 62,
  32, 71, 101, 110, 101, 114, 97, 116, 101, 32, 116, 114, 97, 110, 115, 105,
  116, 105, 111, 110, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 32,
  34, 36, 62, 34, 32, 116, 111, 32, 105, 109, 97, 103, 101, 32, 34, 123,
  36, 62, 43, 49, 125, 34, 46, 32, 32, 32, 32, 34, 32, 45, 118, 32,
  45, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 112, 108, 97,
  115, 109, 97, 91, 45, 49, 93, 32, 49, 44, 48, 44, 36, 50, 32, 45,
  110, 91, 45, 49, 93, 32, 48, 44, 49, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 36, 49, 45, 50, 125, 32, 45, 45, 108, 101, 91, 50, 93,
  32, 123, 40, 36, 62, 43, 49, 41, 47, 36, 49, 125, 32, 45, 98, 91,
  45, 49, 93, 32, 36, 51, 32, 91, 48, 93, 32, 45, 106, 91, 45, 49,
  93, 32, 91, 49, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44,
  91, 45, 50, 93, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45, 114, 112,
  114, 111, 103, 114, 101, 115, 115, 32, 123, 36, 62, 42, 49, 48, 48, 47,
  40, 36, 49, 45, 50, 41, 125, 32, 45, 100, 111, 110, 101, 10, 45, 114,
  109, 91, 50, 93, 32, 45, 109, 118, 91, 50, 45, 45, 49, 93, 32, 49,
  32, 111, 102, 102, 61, 123, 36, 111, 102, 102, 43, 36, 49, 45, 50, 125,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 116, 114, 97, 110, 115, 105, 116,
  105, 111, 110, 51, 100, 32, 58, 32, 95, 110, 98, 95, 102, 114, 97, 109,
  101, 115, 62, 61, 50, 44, 95, 110, 98, 95, 120, 116, 105, 108, 101, 115,
  62, 48, 44, 95, 110, 98, 95, 121, 116, 105, 108, 101, 115, 62, 48, 44,
  95, 97, 120, 105, 115, 95, 120, 44, 95, 97, 120, 105, 115, 95, 121, 44,
  95, 97, 120, 105, 115, 95, 122, 44, 95, 105, 115, 95, 97, 110, 116, 105,
  97, 108, 105, 97, 115, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67,
  114, 101, 97, 116, 101, 32, 51, 100, 32, 116, 114, 97, 110, 115, 105, 116,
  105, 111, 110, 32, 115, 101, 113, 117, 101, 110, 99, 101, 32, 98, 101, 116,
  119, 101, 101, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 99, 111,
  110, 115, 101, 99, 117, 116, 105, 118, 101, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 39, 97, 120, 105, 115,
  95, 120, 39, 44, 32, 39, 97, 120, 105, 115, 95, 121, 39, 32, 97, 110,
  100, 32, 39, 97, 120, 105, 115, 95, 122, 39, 32, 99, 97, 110, 32, 98,
  101, 32, 115, 101, 116, 32, 97, 115, 32, 109, 97, 116, 104, 101, 109, 97,
  116, 105, 99, 97, 108, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110,
  115, 44, 32, 100, 101, 112, 101, 110, 100, 105, 110, 103, 32, 111, 110, 32,
  39, 120, 39, 32, 97, 110, 100, 32, 39, 121, 39, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 115, 58, 32, 39, 110, 98, 95, 102, 114, 97, 109, 101, 115,
  61, 49, 48, 39, 44, 32, 39, 110, 98, 95, 120, 116, 105, 108, 101, 115,
  61, 110, 98, 95, 121, 116, 105, 108, 101, 115, 61, 51, 39, 44, 32, 39,
  97, 120, 105, 115, 95, 120, 61, 49, 39, 44, 32, 39, 97, 120, 105, 115,
  95, 121, 61, 49, 39, 44, 32, 39, 97, 120, 105, 115, 95, 122, 61, 48,
  39, 32, 97, 110, 100, 32, 39, 105, 115, 95, 97, 110, 116, 105, 97, 108,
  105, 97, 115, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 98,
  108, 117, 114, 32, 53, 32, 45, 116, 114, 97, 110, 115, 105, 116, 105, 111,
  110, 51, 100, 32, 57, 32, 45, 100, 114, 103, 98, 97, 10, 116, 114, 97,
  110, 115, 105, 116, 105, 111, 110, 51, 100, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 49, 48,
  125, 41, 32, 38, 38, 32, 36, 49, 62, 61, 50, 32, 38, 38, 32, 105,
  115, 105, 110, 116, 40, 36, 123, 50, 61, 51, 125, 41, 32, 38, 38, 32,
  36, 50, 62, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123,
  51, 61, 36, 50, 125, 41, 32, 38, 38, 32, 36, 51, 62, 48, 34, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 52, 61, 49, 125, 44, 36, 123, 53,
  61, 49, 125, 44, 36, 123, 54, 61, 48, 125, 44, 36, 123, 55, 61, 49,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 114, 101, 97, 116,
  101, 32, 51, 100, 32, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 32,
  115, 101, 113, 117, 101, 110, 99, 101, 32, 98, 101, 116, 119, 101, 101, 110,
  32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 36,
  49, 32, 102, 114, 97, 109, 101, 115, 44, 32, 36, 50, 120, 36, 51, 32,
  116, 105, 108, 101, 115, 32, 97, 110, 100, 32, 114, 111, 116, 97, 116, 105,
  111, 110, 32, 97, 120, 105, 115, 32, 40, 36, 52, 44, 36, 53, 44, 36,
  54, 41, 46, 92, 110, 34, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32,
  123, 64, 35, 60, 50, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 115, 108, 105, 99, 101, 115, 32, 48, 32,
  45, 116, 111, 95, 114, 103, 98, 32, 45, 114, 32, 64, 123, 45, 109, 97,
  120, 95, 119, 104, 100, 115, 125, 44, 51, 10, 111, 102, 102, 61, 48, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 45,
  108, 91, 123, 36, 62, 43, 36, 111, 102, 102, 125, 44, 123, 36, 62, 43,
  36, 111, 102, 102, 43, 49, 125, 93, 10, 45, 118, 32, 43, 32, 45, 101,
  91, 93, 32, 34, 92, 114, 32, 62, 32, 71, 101, 110, 101, 114, 97, 116,
  101, 32, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 32, 102, 114, 111,
  109, 32, 105, 109, 97, 103, 101, 32, 34, 36, 62, 34, 32, 116, 111, 32,
  105, 109, 97, 103, 101, 32, 34, 123, 36, 62, 43, 49, 125, 34, 46, 32,
  32, 32, 32, 34, 32, 45, 118, 32, 45, 10, 36, 50, 44, 36, 51, 44,
  49, 44, 49, 44, 39, 36, 52, 39, 10, 36, 50, 44, 36, 51, 44, 49,
  44, 49, 44, 39, 36, 53, 39, 10, 36, 50, 44, 36, 51, 44, 49, 44,
  49, 44, 39, 36, 54, 39, 10, 45, 97, 91, 45, 51, 45, 45, 49, 93,
  32, 122, 10, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 49, 93, 32,
  122, 120, 121, 99, 32, 45, 114, 91, 45, 49, 93, 32, 51, 44, 123, 36,
  50, 42, 36, 51, 125, 44, 49, 44, 49, 44, 45, 49, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 104, 125, 32, 114, 111, 116, 36, 62, 61, 64,
  123, 45, 49, 44, 48, 45, 50, 125, 32, 45, 115, 104, 105, 102, 116, 91,
  45, 49, 93, 32, 48, 44, 45, 49, 44, 48, 44, 48, 32, 45, 100, 111,
  110, 101, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 45, 115, 112, 108,
  105, 116, 95, 116, 105, 108, 101, 115, 91, 45, 50, 44, 45, 49, 93, 32,
  36, 50, 44, 36, 51, 32, 45, 109, 118, 91, 48, 44, 49, 93, 32, 64,
  35, 10, 78, 61, 123, 36, 50, 42, 36, 51, 125, 32, 105, 61, 48, 32,
  121, 61, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 51, 10, 120,
  61, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 50, 10, 108, 119,
  61, 64, 123, 36, 105, 44, 119, 125, 32, 108, 104, 61, 64, 123, 36, 105,
  44, 104, 125, 10, 45, 105, 109, 97, 103, 101, 112, 108, 97, 110, 101, 51,
  100, 91, 36, 105, 93, 32, 45, 105, 109, 97, 103, 101, 112, 108, 97, 110,
  101, 51, 100, 91, 36, 78, 93, 32, 45, 114, 51, 100, 91, 36, 78, 93,
  32, 36, 123, 114, 111, 116, 36, 105, 125, 44, 45, 49, 56, 48, 32, 45,
  99, 51, 100, 91, 36, 105, 44, 36, 78, 93, 32, 45, 43, 51, 100, 91,
  36, 105, 44, 36, 78, 93, 10, 120, 36, 105, 61, 36, 120, 32, 121, 36,
  105, 61, 36, 121, 32, 120, 61, 123, 36, 120, 43, 36, 108, 119, 125, 32,
  105, 61, 123, 36, 105, 43, 49, 125, 10, 45, 100, 111, 110, 101, 10, 121,
  61, 123, 36, 121, 43, 36, 108, 104, 125, 10, 45, 100, 111, 110, 101, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 49, 45, 50, 125, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 36, 78, 32, 45, 114, 51, 100, 91, 36,
  62, 93, 32, 36, 123, 114, 111, 116, 36, 62, 125, 44, 123, 49, 56, 48,
  47, 40, 36, 49, 45, 49, 41, 125, 32, 45, 45, 43, 51, 100, 91, 36,
  62, 93, 32, 36, 123, 120, 36, 62, 125, 44, 36, 123, 121, 36, 62, 125,
  44, 48, 32, 45, 100, 111, 110, 101, 10, 45, 43, 51, 100, 91, 45, 36,
  78, 45, 45, 49, 93, 32, 45, 99, 51, 100, 91, 45, 49, 93, 10, 45,
  105, 102, 32, 36, 55, 10, 45, 105, 91, 45, 51, 93, 32, 123, 50, 42,
  64, 123, 45, 50, 44, 119, 125, 125, 44, 123, 50, 42, 64, 123, 45, 50,
  44, 104, 125, 125, 44, 49, 44, 51, 44, 45, 49, 10, 45, 42, 51, 100,
  91, 45, 49, 93, 32, 50, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100,
  91, 45, 51, 93, 32, 91, 45, 49, 93, 44, 53, 48, 37, 44, 53, 48,
  37, 44, 48, 44, 49, 44, 50, 44, 48, 44, 48, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 50, 93,
  32, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91,
  45, 50, 93, 32, 48, 44, 48, 44, 45, 49, 44, 45, 49, 44, 45, 49,
  44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 48, 10, 45, 114, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 44, 91, 45, 49, 93, 44, 49, 44,
  49, 48, 48, 37, 44, 50, 10, 45, 101, 108, 115, 101, 10, 45, 105, 91,
  45, 51, 93, 32, 64, 123, 45, 50, 44, 119, 125, 44, 64, 123, 45, 50,
  44, 104, 125, 44, 49, 44, 51, 44, 45, 49, 32, 45, 111, 98, 106, 101,
  99, 116, 51, 100, 91, 45, 51, 93, 32, 91, 45, 49, 93, 44, 53, 48,
  37, 44, 53, 48, 37, 44, 48, 44, 49, 44, 50, 44, 48, 44, 48, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 116, 111, 95, 114, 103, 98, 97,
  91, 45, 50, 93, 32, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111,
  108, 111, 114, 91, 45, 50, 93, 32, 48, 44, 48, 44, 45, 49, 44, 45,
  49, 44, 45, 49, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 48,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 114,
  109, 91, 48, 45, 123, 36, 78, 45, 49, 125, 93, 10, 45, 110, 109, 91,
  49, 45, 45, 50, 93, 32, 64, 123, 48, 44, 110, 125, 10, 111, 102, 102,
  61, 123, 36, 111, 102, 102, 43, 36, 49, 45, 50, 125, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 58, 32, 73, 110, 116, 101, 114, 97, 99, 116,
  105, 118, 101, 32, 100, 101, 109, 111, 115, 10, 35, 64, 103, 109, 105, 99,
  32, 100, 101, 109, 111, 32, 58, 32, 95, 114, 117, 110, 95, 105, 110, 95,
  112, 97, 114, 97, 108, 108, 101, 108, 61, 123, 32, 48, 61, 110, 111, 32,
  124, 32, 49, 61, 121, 101, 115, 32, 124, 32, 50, 61, 97, 117, 116, 111,
  32, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 83, 104, 111, 119,
  32, 97, 32, 109, 101, 110, 117, 32, 116, 111, 32, 115, 101, 108, 101, 99,
  116, 32, 97, 110, 100, 32, 118, 105, 101, 119, 32, 97, 108, 108, 32, 71,
  39, 77, 73, 67, 32, 105, 110, 116, 101, 114, 97, 99, 116, 105, 118, 101,
  32, 100, 101, 109, 111, 115, 46, 10, 100, 101, 109, 111, 32, 58, 32, 45,
  99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 123, 49,
  61, 50, 125, 41, 32, 38, 38, 32, 36, 49, 62, 61, 48, 32, 38, 38,
  32, 36, 49, 60, 61, 50, 34, 10, 45, 101, 91, 93, 32, 34, 92, 110,
  10, 45, 45, 45, 45, 45, 45, 32, 71, 39, 77, 73, 67, 32, 100, 101,
  109, 111, 115, 32, 109, 101, 110, 117, 32, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45,
  45, 92, 110, 10, 45, 45, 45, 45, 32, 77, 111, 117, 115, 101, 32, 98,
  117, 116, 116, 111, 110, 32, 116, 111, 32, 115, 101, 108, 101, 99, 116, 32,
  97, 32, 100, 101, 109, 111, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75,
  101, 121, 115, 32, 39, 67, 84, 82, 76, 43, 68, 39, 32, 116, 111, 32,
  100, 111, 117, 98, 108, 101, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105,
  122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32,
  39, 67, 84, 82, 76, 43, 67, 39, 32, 116, 111, 32, 114, 101, 115, 101,
  116, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110,
  10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 69, 83, 67, 39,
  32, 111, 114, 32, 39, 81, 39, 32, 116, 111, 32, 101, 120, 105, 116, 46,
  92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 34, 10, 45, 118, 32, 45, 32, 45, 108, 91, 93, 10, 112,
  97, 114, 97, 108, 108, 101, 108, 95, 109, 111, 100, 101, 61, 123, 50, 45,
  105, 102, 40, 36, 49, 33, 61, 50, 44, 36, 49, 44, 64, 42, 62, 50,
  41, 125, 10, 51, 48, 48, 44, 52, 50, 48, 44, 49, 44, 51, 32, 45,
  45, 112, 108, 97, 115, 109, 97, 91, 45, 49, 93, 32, 49, 44, 49, 44,
  53, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 51, 48, 32, 45,
  115, 104, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 47, 91, 45, 49,
  93, 32, 50, 46, 50, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 119,
  97, 116, 101, 114, 91, 45, 49, 93, 32, 49, 48, 48, 32, 45, 42, 91,
  45, 49, 93, 32, 48, 46, 49, 53, 10, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 44, 51, 10, 48, 32, 45, 116, 101, 120, 116, 91, 45,
  49, 93, 32, 34, 49, 45, 32, 66, 108, 111, 98, 115, 32, 101, 100, 105,
  116, 111, 114, 92, 110, 34, 92, 10, 34, 50, 45, 32, 66, 111, 117, 110,
  99, 105, 110, 103, 32, 98, 97, 108, 108, 115, 92, 110, 34, 92, 10, 34,
  51, 45, 32, 70, 105, 114, 101, 32, 101, 102, 102, 101, 99, 116, 92, 110,
  34, 92, 10, 34, 52, 45, 32, 70, 105, 114, 101, 119, 111, 114, 107, 115,
  92, 110, 34, 92, 10, 34, 53, 45, 32, 70, 105, 115, 104, 45, 101, 121,
  101, 32, 101, 102, 102, 101, 99, 116, 92, 110, 34, 92, 10, 34, 54, 45,
  32, 70, 111, 117, 114, 105, 101, 114, 32, 102, 105, 108, 116, 101, 114, 105,
  110, 103, 92, 110, 34, 92, 10, 34, 55, 45, 32, 72, 105, 115, 116, 111,
  103, 114, 97, 109, 32, 100, 101, 109, 111, 92, 110, 34, 92, 10, 34, 56,
  45, 32, 72, 111, 117, 103, 104, 32, 116, 114, 97, 110, 115, 102, 111, 114,
  109, 92, 110, 34, 92, 10, 34, 57, 45, 32, 74, 97, 119, 98, 114, 101,
  97, 107, 101, 114, 92, 110, 34, 92, 10, 34, 49, 48, 45, 32, 84, 104,
  101, 32, 103, 97, 109, 101, 32, 111, 102, 32, 108, 105, 102, 101, 92, 110,
  34, 92, 10, 34, 49, 49, 45, 32, 76, 105, 103, 104, 116, 32, 101, 102,
  102, 101, 99, 116, 92, 110, 34, 92, 10, 34, 49, 50, 45, 32, 77, 97,
  110, 100, 101, 108, 98, 114, 111, 116, 32, 101, 120, 112, 108, 111, 114, 101,
  114, 92, 110, 34, 92, 10, 34, 49, 51, 45, 32, 51, 100, 32, 109, 101,
  116, 97, 98, 97, 108, 108, 115, 92, 110, 34, 92, 10, 34, 49, 52, 45,
  32, 77, 105, 110, 101, 115, 119, 101, 101, 112, 101, 114, 92, 110, 34, 92,
  10, 34, 49, 53, 45, 32, 77, 105, 110, 105, 109, 97, 108, 32, 112, 97,
  116, 104, 92, 110, 34, 92, 10, 34, 49, 54, 45, 32, 80, 97, 99, 109,
  97, 110, 92, 110, 34, 92, 10, 34, 49, 55, 45, 32, 80, 97, 105, 110,
  116, 92, 110, 34, 92, 10, 34, 49, 56, 45, 32, 80, 108, 97, 115, 109,
  97, 32, 101, 102, 102, 101, 99, 116, 92, 110, 34, 92, 10, 34, 49, 57,
  45, 32, 82, 71, 66, 32, 113, 117, 97, 110, 116, 105, 122, 97, 116, 105,
  111, 110, 92, 110, 34, 92, 10, 34, 50, 48, 45, 32, 51, 100, 32, 114,
  101, 102, 108, 101, 99, 116, 105, 111, 110, 92, 110, 34, 92, 10, 34, 50,
  49, 45, 32, 51, 100, 32, 114, 117, 98, 98, 101, 114, 32, 111, 98, 106,
  101, 99, 116, 92, 110, 34, 92, 10, 34, 50, 50, 45, 32, 83, 104, 97,
  100, 101, 32, 98, 111, 98, 115, 92, 110, 34, 92, 10, 34, 50, 51, 45,
  32, 83, 112, 108, 105, 110, 101, 32, 101, 100, 105, 116, 111, 114, 92, 110,
  34, 92, 10, 34, 50, 52, 45, 32, 84, 101, 116, 114, 105, 115, 92, 110,
  34, 92, 10, 34, 50, 53, 45, 32, 84, 105, 99, 45, 116, 97, 99, 45,
  116, 111, 101, 92, 110, 34, 92, 10, 34, 50, 54, 45, 32, 73, 109, 97,
  103, 101, 32, 119, 97, 118, 101, 115, 92, 110, 34, 92, 10, 34, 50, 55,
  45, 32, 70, 114, 97, 99, 116, 97, 108, 32, 119, 104, 105, 114, 108, 115,
  34, 44, 48, 44, 48, 44, 49, 51, 44, 49, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 50, 53, 53, 10, 99, 111, 109, 109, 97, 110, 100, 115, 61,
  45, 120, 95, 98, 108, 111, 98, 115, 44, 45, 120, 95, 98, 111, 117, 110,
  99, 105, 110, 103, 44, 45, 120, 95, 102, 105, 114, 101, 44, 45, 120, 95,
  102, 105, 114, 101, 119, 111, 114, 107, 115, 44, 45, 120, 95, 102, 105, 115,
  104, 101, 121, 101, 44, 45, 120, 95, 102, 111, 117, 114, 105, 101, 114, 44,
  45, 120, 95, 104, 105, 115, 116, 111, 103, 114, 97, 109, 44, 45, 120, 95,
  104, 111, 117, 103, 104, 44, 92, 10, 45, 120, 95, 106, 97, 119, 98, 114,
  101, 97, 107, 101, 114, 44, 45, 120, 95, 108, 105, 102, 101, 44, 45, 120,
  95, 108, 105, 103, 104, 116, 44, 45, 120, 95, 109, 97, 110, 100, 101, 108,
  98, 114, 111, 116, 44, 45, 120, 95, 109, 101, 116, 97, 98, 97, 108, 108,
  115, 51, 100, 44, 45, 120, 95, 109, 105, 110, 101, 115, 119, 101, 101, 112,
  101, 114, 44, 45, 120, 95, 109, 105, 110, 105, 109, 97, 108, 95, 112, 97,
  116, 104, 44, 92, 10, 45, 120, 95, 112, 97, 99, 109, 97, 110, 44, 45,
  120, 95, 112, 97, 105, 110, 116, 44, 45, 120, 95, 112, 108, 97, 115, 109,
  97, 44, 45, 120, 95, 113, 117, 97, 110, 116, 105, 122, 101, 95, 114, 103,
  98, 44, 45, 120, 95, 114, 101, 102, 108, 101, 99, 116, 105, 111, 110, 51,
  100, 44, 45, 120, 95, 114, 117, 98, 98, 101, 114, 51, 100, 44, 45, 120,
  95, 115, 104, 97, 100, 101, 98, 111, 98, 115, 44, 92, 10, 45, 120, 95,
  115, 112, 108, 105, 110, 101, 44, 45, 120, 95, 116, 101, 116, 114, 105, 115,
  44, 45, 120, 95, 116, 105, 99, 116, 97, 99, 116, 111, 101, 44, 45, 120,
  95, 119, 97, 118, 101, 115, 44, 45, 120, 95, 119, 104, 105, 114, 108, 10,
  121, 48, 61, 53, 57, 10, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 50, 48, 44, 36, 121, 48, 44, 48, 44, 48, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91,
  45, 49, 93, 32, 48, 44, 49, 54, 44, 49, 48, 48, 37, 44, 52, 52,
  44, 49, 44, 49, 50, 48, 44, 49, 50, 48, 44, 51, 50, 10, 48, 32,
  45, 116, 101, 120, 116, 91, 45, 49, 93, 32, 34, 71, 39, 77, 73, 67,
  32, 34, 64, 123, 45, 115, 116, 114, 118, 101, 114, 125, 34, 32, 100, 101,
  109, 111, 115, 34, 44, 50, 44, 50, 44, 50, 52, 44, 49, 44, 49, 44,
  49, 44, 49, 32, 45, 98, 91, 45, 49, 93, 32, 48, 46, 53, 32, 45,
  110, 91, 45, 49, 93, 32, 48, 44, 49, 10, 40, 51, 50, 59, 50, 53,
  53, 94, 50, 53, 53, 59, 50, 53, 53, 94, 48, 59, 48, 41, 32, 45,
  114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44,
  49, 44, 51, 44, 51, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 49, 44, 45, 49, 32,
  45, 45, 110, 101, 113, 91, 45, 49, 93, 32, 48, 32, 45, 99, 104, 97,
  110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 49, 10, 45, 106, 91, 45,
  51, 93, 32, 91, 45, 50, 93, 44, 50, 48, 44, 49, 56, 44, 48, 44,
  48, 44, 49, 44, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45,
  49, 93, 32, 49, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93,
  32, 53, 10, 40, 56, 48, 59, 50, 53, 53, 59, 56, 48, 94, 48, 59,
  50, 53, 53, 59, 48, 94, 48, 59, 48, 59, 48, 41, 32, 40, 49, 48,
  59, 50, 53, 53, 59, 49, 48, 94, 48, 59, 49, 48, 48, 59, 48, 94,
  48, 59, 48, 59, 48, 41, 10, 45, 114, 91, 45, 50, 44, 45, 49, 93,
  32, 91, 45, 51, 93, 44, 49, 51, 44, 49, 44, 51, 44, 51, 32, 45,
  112, 111, 108, 121, 103, 111, 110, 91, 45, 50, 44, 45, 49, 93, 32, 51,
  44, 49, 44, 49, 44, 49, 44, 49, 49, 44, 49, 48, 44, 54, 44, 49,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 45, 109,
  105, 114, 114, 111, 114, 91, 45, 50, 44, 45, 49, 93, 32, 120, 10, 45,
  109, 97, 120, 91, 45, 52, 44, 45, 50, 93, 32, 45, 109, 97, 120, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 98, 97, 108, 108, 91, 93, 32, 54,
  52, 44, 50, 48, 48, 44, 49, 48, 48, 44, 54, 52, 32, 45, 110, 91,
  45, 49, 93, 32, 48, 44, 50, 51, 48, 32, 45, 115, 91, 45, 49, 93,
  32, 99, 44, 45, 51, 32, 45, 114, 103, 98, 50, 104, 115, 118, 91, 45,
  50, 93, 32, 45, 42, 91, 45, 49, 93, 32, 48, 46, 53, 32, 45, 97,
  91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 54, 10, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 48, 32,
  45, 102, 91, 45, 49, 93, 32, 123, 36, 62, 42, 51, 54, 48, 47, 54,
  125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 45, 115, 91, 45, 49,
  93, 32, 99, 44, 45, 51, 32, 45, 104, 115, 118, 50, 114, 103, 98, 91,
  45, 50, 93, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10,
  40, 123, 39, 67, 73, 109, 103, 51, 100, 39, 125, 41, 32, 40, 53, 44,
  53, 41, 32, 51, 44, 53, 32, 40, 49, 44, 48, 59, 49, 44, 52, 41,
  32, 45, 114, 91, 45, 49, 93, 32, 50, 44, 53, 44, 49, 44, 49, 44,
  51, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 52, 44, 53,
  32, 45, 121, 91, 45, 53, 45, 45, 49, 93, 32, 45, 97, 91, 45, 53,
  45, 45, 49, 93, 32, 121, 10, 45, 114, 118, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 115, 112, 114, 105, 116, 101, 115, 51, 100, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 114, 118, 91, 45, 50, 44, 45, 49, 93, 10, 45,
  100, 111, 110, 101, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 43, 51,
  100, 91, 45, 54, 45, 45, 49, 93, 10, 99, 102, 120, 61, 123, 48, 125,
  32, 99, 102, 121, 61, 123, 48, 125, 32, 99, 102, 122, 61, 123, 48, 125,
  32, 110, 102, 120, 61, 123, 103, 125, 32, 110, 102, 121, 61, 123, 103, 125,
  32, 110, 102, 122, 61, 123, 103, 125, 32, 97, 108, 112, 104, 97, 61, 48,
  32, 116, 105, 109, 101, 48, 61, 123, 64, 124, 45, 52, 125, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 61, 45, 49, 32, 45, 102, 51, 100, 32, 52,
  48, 48, 10, 45, 119, 91, 48, 93, 32, 45, 49, 44, 45, 49, 44, 48,
  44, 48, 44, 53, 48, 37, 44, 53, 48, 37, 44, 34, 91, 71, 39, 77,
  73, 67, 93, 32, 68, 101, 109, 111, 115, 32, 109, 101, 110, 117, 34, 10,
  45, 100, 111, 10, 116, 61, 123, 49, 46, 53, 42, 64, 124, 125, 10, 49,
  44, 51, 48, 44, 49, 44, 49, 44, 39, 40, 49, 45, 36, 97, 108, 112,
  104, 97, 41, 42, 99, 111, 115, 40, 36, 99, 102, 120, 42, 121, 43, 36,
  116, 41, 43, 36, 97, 108, 112, 104, 97, 42, 99, 111, 115, 40, 36, 110,
  102, 120, 42, 121, 43, 36, 116, 41, 39, 10, 49, 44, 51, 48, 44, 49,
  44, 49, 44, 39, 40, 49, 45, 36, 97, 108, 112, 104, 97, 41, 42, 115,
  105, 110, 40, 36, 99, 102, 121, 42, 121, 43, 36, 116, 41, 43, 36, 97,
  108, 112, 104, 97, 42, 115, 105, 110, 40, 36, 110, 102, 121, 42, 121, 43,
  36, 116, 41, 39, 10, 49, 44, 51, 48, 44, 49, 44, 49, 44, 39, 40,
  49, 45, 36, 97, 108, 112, 104, 97, 41, 42, 115, 105, 110, 40, 36, 99,
  102, 122, 42, 121, 43, 36, 116, 41, 43, 36, 97, 108, 112, 104, 97, 42,
  115, 105, 110, 40, 36, 110, 102, 122, 42, 121, 43, 36, 116, 41, 39, 10,
  45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 120, 32, 45, 115, 91, 45,
  49, 93, 32, 121, 44, 53, 32, 45, 97, 91, 45, 53, 45, 45, 49, 93,
  32, 120, 32, 45, 121, 91, 45, 49, 93, 10, 45, 106, 91, 54, 93, 32,
  91, 45, 49, 93, 44, 48, 44, 56, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 42, 51, 100, 91, 54, 93, 32, 64, 123, 48, 44, 119, 47, 50,
  45, 51, 48, 125, 44, 64, 123, 48, 44, 104, 47, 50, 45, 51, 48, 125,
  44, 51, 48, 48, 32, 45, 43, 51, 100, 91, 54, 93, 32, 48, 44, 48,
  44, 50, 48, 48, 10, 45, 42, 91, 48, 93, 32, 48, 46, 56, 53, 32,
  45, 43, 91, 48, 93, 32, 91, 49, 93, 32, 45, 111, 98, 106, 101, 99,
  116, 51, 100, 91, 48, 93, 32, 91, 54, 93, 44, 53, 48, 37, 44, 53,
  48, 37, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 32, 45, 106, 91,
  48, 93, 32, 91, 50, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49,
  44, 91, 51, 93, 44, 50, 53, 53, 10, 121, 61, 123, 64, 123, 33, 44,
  121, 125, 42, 64, 123, 48, 44, 104, 125, 47, 64, 123, 33, 44, 104, 125,
  125, 10, 45, 105, 102, 32, 123, 36, 121, 62, 61, 48, 125, 32, 121, 61,
  123, 109, 97, 120, 40, 48, 44, 109, 105, 110, 40, 50, 54, 44, 105, 110,
  116, 40, 40, 36, 121, 45, 36, 121, 48, 41, 47, 49, 51, 41, 41, 41,
  125, 32, 45, 106, 91, 48, 93, 32, 91, 123, 105, 102, 40, 36, 115, 101,
  108, 101, 99, 116, 101, 100, 62, 61, 48, 44, 53, 44, 52, 41, 125, 93,
  44, 48, 44, 123, 36, 121, 48, 43, 49, 51, 42, 36, 121, 125, 44, 48,
  44, 48, 44, 48, 46, 50, 32, 45, 101, 110, 100, 105, 102, 10, 45, 119,
  91, 48, 93, 32, 45, 119, 97, 105, 116, 32, 50, 48, 10, 45, 105, 102,
  32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38,
  38, 64, 123, 33, 44, 68, 125, 125, 32, 45, 119, 91, 48, 93, 32, 50,
  48, 48, 37, 44, 50, 48, 48, 37, 32, 45, 101, 108, 105, 102, 32, 123,
  64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64,
  123, 33, 44, 67, 125, 125, 32, 45, 119, 91, 48, 93, 32, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 40, 64, 123, 33, 44, 98, 125, 38, 49, 41, 38, 38, 36,
  115, 101, 108, 101, 99, 116, 101, 100, 60, 48, 125, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 61, 36, 121, 10, 45, 101, 108, 105, 102, 32, 123, 33,
  64, 123, 33, 44, 98, 125, 125, 10, 45, 105, 102, 32, 123, 36, 115, 101,
  108, 101, 99, 116, 101, 100, 62, 61, 48, 38, 38, 36, 121, 61, 61, 36,
  115, 101, 108, 101, 99, 116, 101, 100, 125, 10, 45, 109, 32, 34, 99, 111,
  109, 32, 58, 32, 45, 118, 32, 48, 32, 34, 64, 123, 45, 97, 114, 103,
  92, 32, 123, 49, 43, 36, 121, 125, 44, 36, 99, 111, 109, 109, 97, 110,
  100, 115, 125, 32, 45, 112, 97, 114, 97, 108, 108, 101, 108, 32, 36, 112,
  97, 114, 97, 108, 108, 101, 108, 95, 109, 111, 100, 101, 44, 34, 45, 108,
  91, 93, 32, 45, 99, 111, 109, 32, 45, 118, 32, 45, 49, 32, 45, 114,
  109, 32, 45, 101, 110, 100, 108, 34, 32, 45, 117, 110, 99, 111, 109, 109,
  97, 110, 100, 32, 99, 111, 109, 10, 45, 101, 110, 100, 105, 102, 10, 115,
  101, 108, 101, 99, 116, 101, 100, 61, 45, 49, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 64, 124, 45, 36, 116, 105, 109, 101, 48,
  62, 53, 125, 32, 97, 108, 112, 104, 97, 61, 123, 36, 97, 108, 112, 104,
  97, 43, 48, 46, 48, 51, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 97, 108, 112, 104, 97, 62, 49, 125, 32, 97, 108,
  112, 104, 97, 61, 123, 36, 97, 108, 112, 104, 97, 45, 49, 125, 32, 99,
  102, 120, 61, 36, 110, 102, 120, 32, 99, 102, 121, 61, 36, 110, 102, 121,
  32, 99, 102, 122, 61, 36, 110, 102, 122, 32, 110, 102, 120, 61, 123, 103,
  125, 32, 110, 102, 121, 61, 123, 103, 125, 32, 110, 102, 122, 61, 123, 103,
  125, 32, 116, 105, 109, 101, 48, 61, 123, 64, 124, 45, 63, 42, 51, 125,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123,
  64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67,
  125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125, 10,
  45, 114, 109, 32, 45, 119, 32, 48, 32, 45, 101, 110, 100, 108, 32, 45,
  118, 32, 48, 32, 45, 101, 91, 93, 32, 34, 34, 10, 35, 64, 103, 109,
  105, 99, 32, 120, 95, 98, 108, 111, 98, 115, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 76, 97, 117, 110, 99, 104, 32, 116, 104, 101, 32, 98,
  108, 111, 98, 115, 32, 101, 100, 105, 116, 111, 114, 46, 10, 120, 95, 98,
  108, 111, 98, 115, 32, 58, 10, 45, 101, 91, 93, 32, 34, 92, 110, 10,
  45, 45, 45, 45, 45, 45, 32, 66, 108, 111, 98, 115, 32, 101, 100, 105,
  116, 111, 114, 32, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110,
  10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32, 77, 111, 117,
  115, 101, 32, 116, 111, 32, 105, 110, 115, 101, 114, 116, 47, 109, 111, 118,
  101, 47, 100, 101, 108, 101, 116, 101, 32, 98, 108, 111, 98, 115, 46, 92,
  110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82,
  76, 43, 68, 39, 32, 116, 111, 32, 100, 111, 117, 98, 108, 101, 32, 119,
  105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45, 45,
  45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76, 43, 67, 39,
  32, 116, 111, 32, 114, 101, 115, 101, 116, 32, 119, 105, 110, 100, 111, 119,
  32, 115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101,
  121, 115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81, 39, 32,
  116, 111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45, 45, 92,
  110, 10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 10, 45, 114,
  109, 32, 40, 48, 59, 48, 94, 48, 59, 49, 50, 56, 94, 48, 59, 50,
  53, 53, 41, 32, 45, 114, 91, 45, 49, 93, 32, 51, 53, 48, 44, 51,
  53, 48, 44, 49, 44, 51, 44, 51, 32, 45, 102, 108, 111, 119, 101, 114,
  91, 45, 49, 93, 32, 51, 48, 44, 56, 44, 48, 44, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 44, 49, 32, 45, 119, 97, 116, 101, 114, 91, 45,
  49, 93, 32, 50, 48, 10, 45, 119, 32, 123, 119, 125, 44, 123, 104, 125,
  44, 48, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 66, 108,
  111, 98, 115, 32, 101, 100, 105, 116, 111, 114, 34, 10, 109, 111, 118, 105,
  110, 103, 61, 45, 49, 10, 45, 100, 111, 10, 120, 61, 123, 64, 123, 33,
  44, 120, 125, 42, 64, 123, 48, 44, 119, 125, 47, 64, 123, 33, 44, 119,
  125, 125, 10, 121, 61, 123, 64, 123, 33, 44, 121, 125, 42, 64, 123, 48,
  44, 104, 125, 47, 64, 123, 33, 44, 104, 125, 125, 10, 98, 61, 64, 123,
  33, 44, 98, 125, 32, 110, 101, 97, 114, 101, 115, 116, 61, 45, 49, 10,
  45, 105, 102, 32, 123, 64, 35, 62, 49, 125, 10, 64, 123, 48, 44, 119,
  125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 50, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 123, 49, 44, 104, 125, 10, 114, 61, 123, 64,
  123, 49, 44, 50, 125, 42, 40, 49, 43, 64, 123, 49, 44, 51, 125, 42,
  99, 111, 115, 40, 64, 123, 49, 44, 52, 125, 43, 64, 123, 49, 44, 53,
  125, 42, 64, 124, 42, 49, 48, 48, 48, 41, 41, 125, 10, 45, 101, 108,
  108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 64, 123, 49, 44, 48, 44,
  49, 125, 44, 36, 114, 44, 36, 114, 44, 48, 44, 49, 44, 64, 123, 49,
  44, 54, 45, 55, 125, 10, 100, 61, 123, 115, 113, 114, 116, 40, 40, 36,
  120, 45, 64, 123, 49, 44, 48, 125, 41, 94, 50, 43, 40, 36, 121, 45,
  64, 123, 49, 44, 49, 125, 41, 94, 50, 41, 125, 10, 45, 105, 102, 32,
  123, 36, 100, 60, 36, 114, 125, 32, 110, 101, 97, 114, 101, 115, 116, 61,
  36, 62, 32, 45, 101, 110, 100, 105, 102, 10, 45, 115, 104, 105, 102, 116,
  91, 49, 93, 32, 48, 44, 45, 49, 44, 48, 44, 48, 44, 50, 32, 45,
  100, 111, 110, 101, 10, 45, 98, 91, 45, 49, 93, 32, 49, 53, 10, 45,
  45, 110, 111, 114, 109, 91, 45, 49, 93, 32, 45, 45, 103, 101, 91, 45,
  49, 93, 32, 53, 48, 32, 45, 108, 101, 91, 45, 50, 93, 32, 52, 48,
  32, 45, 42, 91, 45, 51, 44, 45, 49, 93, 10, 45, 45, 42, 91, 48,
  44, 45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45, 114, 118,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 49,
  46, 54, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32,
  45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 119, 91, 45, 49, 93,
  10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69,
  70, 84, 125, 38, 38, 64, 123, 33, 44, 68, 125, 125, 32, 45, 119, 91,
  93, 32, 123, 50, 42, 119, 125, 44, 123, 50, 42, 104, 125, 32, 45, 101,
  108, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70,
  84, 125, 38, 38, 64, 123, 33, 44, 67, 125, 125, 32, 45, 119, 91, 93,
  32, 123, 119, 125, 44, 123, 104, 125, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 115, 101, 10, 45, 45,
  116, 101, 120, 116, 95, 111, 117, 116, 108, 105, 110, 101, 91, 48, 93, 32,
  34, 71, 39, 77, 73, 67, 32, 66, 108, 111, 98, 115, 32, 69, 100, 105,
  116, 111, 114, 34, 44, 54, 53, 44, 52, 48, 44, 50, 52, 44, 51, 44,
  49, 44, 50, 48, 48, 44, 49, 50, 56, 44, 50, 53, 53, 10, 45, 116,
  91, 45, 49, 93, 32, 34, 42, 32, 76, 101, 102, 116, 32, 109, 111, 117,
  115, 101, 32, 98, 117, 116, 116, 111, 110, 32, 58, 32, 67, 114, 101, 97,
  116, 101, 32, 97, 110, 100, 32, 109, 111, 118, 101, 32, 98, 108, 111, 98,
  115, 46, 92, 110, 92, 110, 92, 10, 42, 32, 82, 105, 103, 104, 116, 32,
  109, 111, 117, 115, 101, 32, 98, 117, 116, 116, 111, 110, 32, 58, 32, 82,
  101, 109, 111, 118, 101, 32, 98, 108, 111, 98, 46, 92, 110, 92, 110, 92,
  10, 42, 32, 77, 105, 100, 100, 108, 101, 32, 109, 111, 117, 115, 101, 32,
  98, 117, 116, 116, 111, 110, 32, 58, 32, 82, 101, 109, 111, 118, 101, 32,
  97, 108, 108, 32, 98, 108, 111, 98, 115, 46, 92, 110, 92, 110, 92, 10,
  42, 32, 75, 101, 121, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39,
  81, 39, 32, 58, 32, 81, 117, 105, 116, 46, 92, 110, 92, 110, 92, 10,
  42, 32, 67, 111, 108, 111, 114, 115, 32, 97, 110, 100, 32, 115, 105, 122,
  101, 115, 32, 111, 102, 32, 97, 112, 112, 101, 97, 114, 105, 110, 103, 32,
  98, 108, 111, 98, 115, 32, 97, 114, 101, 92, 110, 32, 32, 32, 99, 104,
  111, 115, 101, 110, 32, 114, 97, 110, 100, 111, 109, 108, 121, 34, 44, 92,
  10, 54, 48, 44, 49, 50, 48, 44, 49, 51, 44, 49, 44, 50, 53, 53,
  10, 45, 119, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 64, 123, 33,
  44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44,
  68, 125, 125, 32, 45, 119, 91, 93, 32, 123, 50, 42, 119, 125, 44, 123,
  50, 42, 104, 125, 32, 45, 101, 108, 105, 102, 32, 123, 64, 123, 33, 44,
  67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 67,
  125, 125, 32, 45, 119, 91, 93, 32, 123, 119, 125, 44, 123, 104, 125, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 119, 97, 105, 116, 32, 50, 48, 10, 45,
  105, 102, 32, 123, 36, 120, 60, 48, 124, 124, 36, 121, 60, 48, 125, 32,
  45, 99, 111, 110, 116, 105, 110, 117, 101, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 98, 38, 49, 125, 10, 45, 105, 102, 32,
  123, 36, 110, 101, 97, 114, 101, 115, 116, 62, 61, 48, 34, 32, 124, 124,
  32, 34, 36, 109, 111, 118, 105, 110, 103, 62, 61, 48, 125, 10, 45, 105,
  102, 32, 123, 36, 109, 111, 118, 105, 110, 103, 60, 48, 125, 32, 109, 111,
  118, 105, 110, 103, 61, 36, 110, 101, 97, 114, 101, 115, 116, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 61, 91, 49, 93, 32, 36, 120, 44, 48, 44,
  36, 109, 111, 118, 105, 110, 103, 32, 45, 61, 91, 49, 93, 32, 36, 121,
  44, 49, 44, 36, 109, 111, 118, 105, 110, 103, 10, 45, 101, 108, 115, 101,
  10, 40, 36, 120, 44, 36, 121, 44, 123, 63, 40, 50, 48, 44, 53, 48,
  41, 125, 44, 123, 63, 40, 45, 48, 46, 51, 44, 48, 46, 51, 41, 125,
  44, 123, 63, 40, 48, 44, 112, 105, 47, 50, 41, 125, 44, 123, 63, 40,
  48, 44, 48, 46, 48, 48, 57, 41, 125, 44, 123, 63, 40, 54, 52, 44,
  50, 53, 53, 41, 125, 44, 123, 63, 40, 54, 52, 44, 50, 53, 53, 41,
  125, 41, 32, 45, 97, 91, 94, 48, 93, 32, 121, 10, 109, 111, 118, 105,
  110, 103, 61, 123, 104, 45, 49, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 98, 38, 50, 125, 10, 45, 105, 102,
  32, 123, 36, 110, 101, 97, 114, 101, 115, 116, 62, 61, 48, 125, 32, 45,
  108, 91, 49, 93, 32, 45, 115, 32, 121, 32, 45, 114, 109, 91, 36, 110,
  101, 97, 114, 101, 115, 116, 93, 32, 45, 97, 32, 121, 32, 45, 101, 110,
  100, 108, 32, 110, 101, 97, 114, 101, 115, 116, 61, 45, 49, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 108, 105, 102, 32, 123, 36, 98, 38, 52,
  125, 10, 45, 107, 91, 48, 93, 10, 45, 101, 108, 115, 101, 10, 109, 111,
  118, 105, 110, 103, 61, 45, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  119, 104, 105, 108, 101, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34, 33,
  64, 123, 33, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64,
  123, 33, 44, 81, 125, 125, 10, 45, 114, 109, 32, 45, 119, 32, 48, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 120, 95, 98, 111,
  117, 110, 99, 105, 110, 103, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  76, 97, 117, 110, 99, 104, 32, 116, 104, 101, 32, 98, 111, 117, 110, 99,
  105, 110, 103, 32, 98, 97, 108, 108, 115, 32, 100, 101, 109, 111, 46, 10,
  120, 95, 98, 111, 117, 110, 99, 105, 110, 103, 32, 58, 10, 45, 101, 91,
  93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 66, 111, 117,
  110, 99, 105, 110, 103, 32, 98, 97, 108, 108, 115, 32, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45,
  45, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67,
  84, 82, 76, 43, 68, 39, 32, 116, 111, 32, 100, 111, 117, 98, 108, 101,
  32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10,
  45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76, 43,
  67, 39, 32, 116, 111, 32, 114, 101, 115, 101, 116, 32, 119, 105, 110, 100,
  111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32,
  75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81,
  39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45,
  45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 32,
  45, 108, 91, 93, 10, 53, 48, 48, 44, 51, 50, 48, 44, 49, 44, 51,
  32, 45, 112, 108, 97, 115, 109, 97, 32, 49, 44, 49, 44, 57, 32, 45,
  110, 32, 48, 44, 50, 50, 48, 10, 78, 61, 49, 50, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 36, 78, 10, 45, 98, 97, 108, 108, 91, 93, 32,
  123, 114, 111, 117, 110, 100, 40, 63, 40, 51, 50, 44, 56, 48, 41, 41,
  125, 44, 64, 123, 45, 82, 71, 66, 125, 10, 116, 36, 62, 61, 123, 63,
  40, 50, 48, 48, 41, 125, 32, 120, 36, 62, 61, 64, 123, 48, 44, 63,
  40, 49, 48, 44, 119, 45, 49, 48, 41, 125, 32, 104, 36, 62, 61, 123,
  63, 40, 49, 53, 48, 44, 51, 48, 48, 41, 125, 32, 118, 120, 36, 62,
  61, 123, 105, 102, 40, 63, 60, 48, 46, 53, 44, 49, 44, 45, 49, 41,
  42, 63, 40, 49, 44, 56, 41, 125, 10, 45, 100, 111, 110, 101, 10, 45,
  109, 118, 91, 48, 93, 32, 64, 35, 32, 45, 119, 91, 45, 49, 93, 32,
  45, 49, 44, 45, 49, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93,
  32, 66, 111, 117, 110, 99, 105, 110, 103, 32, 98, 97, 108, 108, 115, 34,
  10, 40, 48, 59, 48, 46, 55, 59, 49, 41, 32, 45, 114, 91, 45, 49,
  93, 32, 64, 123, 45, 50, 44, 119, 125, 44, 55, 48, 44, 49, 44, 49,
  44, 51, 10, 45, 100, 111, 10, 91, 36, 78, 93, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 36, 78, 10, 98, 119, 61, 64, 123, 36, 62, 44, 119,
  125, 32, 98, 104, 61, 64, 123, 36, 62, 44, 104, 125, 10, 121, 61, 123,
  36, 123, 104, 36, 62, 125, 42, 97, 98, 115, 40, 99, 111, 115, 40, 36,
  123, 116, 36, 62, 125, 42, 112, 105, 47, 54, 48, 41, 41, 45, 36, 98,
  104, 47, 50, 125, 10, 100, 116, 61, 49, 10, 45, 105, 102, 32, 123, 36,
  121, 60, 48, 125, 32, 100, 61, 123, 45, 36, 121, 125, 32, 121, 61, 48,
  32, 98, 104, 61, 123, 36, 98, 104, 45, 36, 100, 125, 32, 98, 119, 61,
  123, 36, 98, 119, 43, 36, 100, 125, 32, 100, 116, 61, 123, 109, 97, 120,
  40, 48, 46, 50, 44, 49, 45, 40, 36, 100, 47, 36, 98, 104, 41, 94,
  50, 41, 125, 32, 45, 101, 108, 115, 101, 32, 100, 116, 61, 49, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 123, 120, 36, 62,
  125, 43, 36, 98, 119, 47, 50, 62, 119, 125, 10, 100, 61, 123, 36, 123,
  120, 36, 62, 125, 43, 36, 98, 119, 47, 50, 45, 119, 125, 32, 98, 119,
  61, 123, 36, 98, 119, 45, 36, 100, 125, 32, 98, 104, 61, 123, 36, 98,
  104, 43, 48, 46, 53, 42, 36, 100, 125, 10, 45, 105, 102, 32, 123, 36,
  123, 120, 36, 62, 125, 43, 36, 98, 119, 47, 52, 62, 119, 125, 32, 118,
  120, 36, 62, 61, 123, 45, 36, 123, 118, 120, 36, 62, 125, 125, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 123, 120, 36, 62, 125, 45, 36, 98, 119, 47, 50, 60, 48,
  125, 10, 100, 61, 123, 36, 98, 119, 47, 50, 45, 36, 123, 120, 36, 62,
  125, 125, 32, 98, 119, 61, 123, 36, 98, 119, 45, 36, 100, 125, 32, 98,
  104, 61, 123, 36, 98, 104, 43, 48, 46, 53, 42, 36, 100, 125, 10, 45,
  105, 102, 32, 123, 36, 123, 120, 36, 62, 125, 45, 36, 98, 119, 47, 52,
  60, 48, 125, 32, 118, 120, 36, 62, 61, 123, 45, 36, 123, 118, 120, 36,
  62, 125, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 45, 114, 91, 36, 62, 93, 32, 36, 98, 119, 44, 36, 98,
  104, 44, 49, 44, 52, 44, 51, 32, 45, 115, 91, 45, 49, 93, 32, 99,
  44, 45, 51, 10, 45, 106, 91, 45, 51, 93, 32, 91, 45, 50, 93, 44,
  123, 109, 97, 120, 40, 48, 44, 109, 105, 110, 40, 64, 123, 36, 78, 44,
  119, 45, 36, 98, 119, 125, 44, 36, 123, 120, 36, 62, 125, 45, 36, 98,
  119, 47, 50, 41, 41, 125, 44, 123, 64, 123, 36, 78, 44, 104, 125, 45,
  64, 123, 45, 49, 44, 104, 125, 45, 36, 121, 45, 55, 48, 125, 44, 48,
  44, 48, 44, 49, 44, 91, 45, 49, 93, 44, 50, 53, 53, 32, 45, 114,
  109, 91, 45, 50, 44, 45, 49, 93, 10, 116, 36, 62, 61, 123, 36, 123,
  116, 36, 62, 125, 43, 36, 100, 116, 125, 10, 120, 36, 62, 61, 123, 36,
  123, 120, 36, 62, 125, 43, 36, 100, 116, 42, 36, 123, 118, 120, 36, 62,
  125, 125, 10, 45, 100, 111, 110, 101, 10, 45, 45, 114, 111, 119, 115, 91,
  45, 49, 93, 32, 123, 104, 45, 50, 42, 55, 48, 125, 44, 123, 104, 45,
  49, 45, 55, 48, 125, 32, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49,
  93, 32, 121, 32, 45, 42, 91, 45, 49, 93, 32, 91, 123, 36, 78, 43,
  49, 125, 93, 10, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44,
  48, 44, 64, 123, 45, 50, 44, 104, 45, 55, 49, 125, 44, 48, 44, 48,
  44, 48, 46, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 119, 91,
  45, 49, 93, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82,
  76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 68, 125, 125, 32,
  45, 119, 91, 93, 32, 123, 50, 42, 119, 125, 44, 123, 50, 42, 104, 125,
  32, 45, 101, 108, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76,
  76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 67, 125, 125, 32, 45,
  119, 91, 93, 32, 123, 119, 125, 44, 123, 104, 125, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 119, 97, 105, 116,
  32, 50, 48, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34, 32,
  38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67, 125, 34, 32, 38,
  38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125, 10, 45, 119, 32, 48,
  32, 45, 114, 109, 32, 45, 101, 110, 100, 108, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 120, 95, 102, 105, 114, 101, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 76, 97, 117, 110, 99, 104, 32, 116, 104,
  101, 32, 102, 105, 114, 101, 32, 101, 102, 102, 101, 99, 116, 32, 100, 101,
  109, 111, 46, 10, 120, 95, 102, 105, 114, 101, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 34, 36, 123, 49, 61, 71, 39, 77, 73, 67, 125, 34, 10,
  45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32,
  70, 105, 114, 101, 32, 101, 102, 102, 101, 99, 116, 32, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45,
  32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76, 43, 68, 39, 32, 116,
  111, 32, 100, 111, 117, 98, 108, 101, 32, 119, 105, 110, 100, 111, 119, 32,
  115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121,
  115, 32, 39, 67, 84, 82, 76, 43, 67, 39, 32, 116, 111, 32, 114, 101,
  115, 101, 116, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46,
  92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 69, 83,
  67, 39, 32, 111, 114, 32, 39, 81, 39, 32, 116, 111, 32, 101, 120, 105,
  116, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 10, 45, 105, 91, 48,
  93, 32, 49, 48, 48, 44, 51, 50, 32, 45, 119, 91, 48, 93, 32, 52,
  53, 48, 44, 50, 48, 48, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67,
  93, 32, 70, 105, 114, 101, 32, 101, 102, 102, 101, 99, 116, 34, 10, 45,
  105, 91, 49, 93, 32, 40, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 94, 48, 44, 48, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 94, 48, 44, 48, 44, 48, 44, 49, 50,
  56, 44, 50, 53, 53, 41, 32, 45, 114, 91, 49, 93, 32, 50, 53, 54,
  44, 49, 44, 49, 44, 51, 44, 51, 10, 45, 105, 91, 50, 93, 32, 40,
  48, 44, 48, 44, 48, 59, 48, 44, 48, 44, 48, 59, 49, 44, 49, 44,
  49, 59, 48, 44, 49, 44, 48, 41, 32, 45, 42, 91, 50, 93, 32, 48,
  46, 50, 49, 10, 45, 116, 101, 120, 116, 51, 100, 32, 34, 36, 49, 34,
  44, 51, 52, 44, 51, 44, 49, 32, 45, 109, 118, 91, 45, 49, 93, 32,
  51, 32, 45, 99, 51, 100, 91, 51, 93, 32, 45, 110, 51, 100, 91, 51,
  93, 32, 45, 42, 51, 100, 91, 51, 93, 32, 51, 50, 48, 32, 45, 99,
  111, 108, 51, 100, 91, 51, 93, 32, 50, 53, 53, 44, 50, 48, 53, 44,
  49, 51, 48, 32, 45, 100, 98, 51, 100, 32, 48, 32, 45, 102, 51, 100,
  32, 51, 48, 48, 10, 49, 48, 48, 44, 49, 48, 48, 32, 45, 114, 97,
  110, 100, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108,
  108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48,
  37, 44, 53, 44, 53, 44, 48, 44, 49, 44, 51, 48, 48, 32, 45, 98,
  91, 45, 49, 93, 32, 49, 48, 10, 45, 115, 104, 97, 114, 112, 101, 110,
  91, 45, 49, 93, 32, 49, 48, 48, 48, 32, 45, 115, 104, 114, 105, 110,
  107, 95, 120, 121, 91, 45, 49, 93, 32, 49, 32, 45, 110, 91, 45, 49,
  93, 32, 48, 44, 50, 53, 53, 32, 45, 116, 111, 95, 114, 103, 98, 91,
  45, 49, 93, 32, 45, 108, 105, 103, 104, 116, 51, 100, 32, 91, 45, 49,
  93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 97, 110, 103, 108, 101, 61,
  48, 10, 45, 100, 111, 10, 45, 99, 111, 114, 114, 101, 108, 97, 116, 101,
  91, 48, 93, 32, 91, 50, 93, 10, 64, 123, 48, 44, 119, 125, 44, 49,
  32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 49, 50, 56, 44, 50,
  53, 54, 32, 45, 106, 91, 48, 93, 32, 91, 45, 49, 93, 44, 48, 44,
  123, 64, 123, 48, 44, 104, 125, 45, 49, 125, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 45, 114, 91, 48, 93, 32, 52, 48, 48, 44, 50, 48,
  48, 44, 49, 44, 49, 44, 51, 32, 45, 109, 97, 112, 91, 45, 49, 93,
  32, 91, 49, 93, 10, 45, 45, 114, 51, 100, 91, 51, 93, 32, 48, 44,
  49, 44, 48, 44, 36, 97, 110, 103, 108, 101, 32, 45, 111, 98, 106, 101,
  99, 116, 51, 100, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 53, 48,
  37, 44, 53, 48, 37, 44, 48, 44, 49, 44, 53, 44, 48, 44, 48, 10,
  45, 42, 51, 100, 91, 45, 49, 93, 32, 48, 46, 50, 53, 44, 48, 46,
  49, 54, 44, 49, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 48,
  93, 32, 91, 45, 49, 93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48,
  44, 49, 44, 51, 44, 48, 44, 48, 10, 45, 114, 109, 91, 45, 49, 93,
  10, 97, 110, 103, 108, 101, 61, 123, 36, 97, 110, 103, 108, 101, 43, 51,
  125, 10, 45, 119, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 64, 123,
  33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33,
  44, 68, 125, 125, 32, 45, 119, 91, 93, 32, 123, 50, 42, 119, 125, 44,
  123, 50, 42, 104, 125, 32, 45, 101, 108, 105, 102, 32, 123, 64, 123, 33,
  44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44,
  67, 125, 125, 32, 45, 119, 91, 93, 32, 123, 119, 125, 44, 123, 104, 125,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 119, 97, 105, 116, 32, 52, 48, 10, 45, 119, 104, 105, 108, 101, 32,
  123, 64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83,
  67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125,
  10, 45, 114, 109, 91, 48, 45, 51, 93, 32, 45, 119, 32, 48, 10, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 120, 95, 102, 105, 114,
  101, 119, 111, 114, 107, 115, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  76, 97, 117, 110, 99, 104, 32, 116, 104, 101, 32, 102, 105, 114, 101, 119,
  111, 114, 107, 115, 32, 100, 101, 109, 111, 46, 10, 120, 95, 102, 105, 114,
  101, 119, 111, 114, 107, 115, 32, 58, 10, 45, 101, 91, 93, 32, 34, 92,
  110, 10, 45, 45, 45, 45, 45, 45, 32, 70, 105, 114, 101, 119, 111, 114,
  107, 115, 32, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45,
  45, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67,
  84, 82, 76, 43, 68, 39, 32, 116, 111, 32, 100, 111, 117, 98, 108, 101,
  32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10,
  45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76, 43,
  67, 39, 32, 116, 111, 32, 114, 101, 115, 101, 116, 32, 119, 105, 110, 100,
  111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32,
  75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81,
  39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45,
  45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 34, 10, 45,
  118, 32, 45, 32, 45, 108, 91, 93, 10, 116, 105, 109, 101, 61, 48, 10,
  40, 48, 59, 54, 52, 94, 48, 59, 51, 50, 94, 49, 50, 56, 59, 48,
  41, 32, 45, 114, 32, 50, 53, 54, 44, 49, 50, 56, 44, 49, 44, 51,
  44, 51, 10, 91, 45, 49, 93, 10, 45, 119, 91, 45, 49, 93, 32, 123,
  49, 46, 53, 42, 119, 125, 44, 123, 49, 46, 53, 42, 104, 125, 44, 48,
  44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 70, 105, 114, 101, 119, 111,
  114, 107, 115, 34, 10, 45, 100, 111, 10, 116, 105, 109, 101, 61, 123, 36,
  116, 105, 109, 101, 45, 49, 125, 10, 45, 105, 102, 32, 123, 64, 35, 61,
  61, 50, 92, 32, 124, 124, 92, 32, 36, 116, 105, 109, 101, 60, 48, 125,
  10, 45, 105, 91, 48, 93, 32, 40, 123, 63, 40, 119, 41, 125, 44, 92,
  10, 123, 104, 125, 44, 92, 10, 123, 63, 40, 45, 51, 44, 51, 41, 125,
  44, 92, 10, 123, 63, 40, 50, 41, 45, 53, 125, 44, 92, 10, 123, 51,
  48, 43, 63, 40, 50, 48, 41, 125, 44, 92, 10, 49, 46, 53, 44, 92,
  10, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 41, 10, 116, 105,
  109, 101, 61, 123, 63, 40, 52, 48, 41, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 42, 91, 45, 49, 93, 32, 48, 46, 57, 57, 10, 45, 106,
  91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 44,
  48, 44, 48, 46, 50, 10, 105, 61, 48, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 64, 35, 45, 50, 125, 10, 116, 111, 95, 98, 101, 95, 114,
  101, 109, 111, 118, 101, 100, 61, 48, 10, 114, 97, 100, 105, 117, 115, 61,
  123, 105, 102, 40, 64, 123, 36, 105, 44, 52, 125, 62, 48, 44, 64, 123,
  36, 105, 44, 53, 125, 47, 51, 44, 64, 123, 36, 105, 44, 53, 125, 42,
  40, 49, 43, 50, 42, 40, 64, 123, 36, 105, 44, 52, 125, 43, 50, 41,
  47, 49, 50, 48, 41, 41, 125, 10, 45, 101, 108, 108, 105, 112, 115, 101,
  91, 45, 49, 93, 32, 64, 123, 36, 105, 44, 48, 125, 44, 64, 123, 36,
  105, 44, 49, 125, 44, 64, 123, 36, 105, 44, 53, 125, 44, 123, 109, 97,
  120, 40, 48, 46, 53, 44, 36, 114, 97, 100, 105, 117, 115, 41, 125, 44,
  123, 97, 116, 97, 110, 50, 40, 64, 123, 36, 105, 44, 51, 125, 44, 64,
  123, 36, 105, 44, 50, 125, 41, 42, 49, 56, 48, 47, 112, 105, 125, 44,
  48, 46, 54, 44, 64, 123, 36, 105, 44, 54, 45, 56, 125, 10, 40, 64,
  123, 36, 105, 44, 50, 125, 44, 64, 123, 36, 105, 44, 51, 125, 44, 48,
  44, 48, 46, 48, 57, 44, 45, 49, 44, 48, 44, 48, 44, 48, 44, 48,
  41, 32, 45, 43, 91, 36, 105, 44, 45, 49, 93, 10, 45, 105, 102, 32,
  123, 64, 123, 36, 105, 44, 48, 125, 60, 48, 92, 32, 124, 124, 92, 32,
  64, 123, 36, 105, 44, 48, 125, 62, 61, 119, 92, 32, 124, 124, 92, 32,
  64, 123, 36, 105, 44, 49, 125, 62, 61, 104, 92, 32, 124, 124, 92, 32,
  36, 114, 97, 100, 105, 117, 115, 60, 48, 125, 32, 116, 111, 95, 98, 101,
  95, 114, 101, 109, 111, 118, 101, 100, 61, 49, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 64, 123, 36, 105, 44, 52, 125, 60, 48,
  92, 32, 38, 38, 92, 32, 64, 123, 36, 105, 44, 52, 125, 62, 61, 45,
  49, 125, 10, 99, 111, 108, 111, 114, 61, 123, 109, 105, 110, 40, 50, 53,
  53, 44, 56, 48, 43, 63, 40, 50, 48, 48, 41, 41, 125, 44, 123, 109,
  105, 110, 40, 50, 53, 53, 44, 56, 48, 43, 63, 40, 50, 48, 48, 41,
  41, 125, 44, 123, 109, 105, 110, 40, 50, 53, 53, 44, 56, 48, 43, 63,
  40, 50, 48, 48, 41, 41, 125, 10, 114, 97, 100, 105, 117, 115, 61, 123,
  63, 40, 49, 48, 41, 125, 10, 78, 61, 123, 53, 43, 63, 40, 49, 48,
  41, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 78, 10, 97, 110,
  103, 108, 101, 61, 123, 36, 62, 42, 50, 42, 112, 105, 47, 36, 78, 125,
  10, 45, 105, 91, 45, 51, 93, 32, 40, 64, 123, 36, 105, 44, 48, 44,
  49, 125, 44, 123, 50, 42, 99, 111, 115, 40, 36, 97, 110, 103, 108, 101,
  41, 43, 64, 123, 36, 105, 44, 50, 125, 47, 49, 46, 53, 125, 44, 123,
  50, 42, 115, 105, 110, 40, 36, 97, 110, 103, 108, 101, 41, 43, 64, 123,
  36, 105, 44, 51, 125, 47, 49, 46, 53, 125, 44, 45, 50, 44, 36, 114,
  97, 100, 105, 117, 115, 44, 36, 99, 111, 108, 111, 114, 41, 10, 45, 100,
  111, 110, 101, 10, 116, 111, 95, 98, 101, 95, 114, 101, 109, 111, 118, 101,
  100, 61, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36,
  116, 111, 95, 98, 101, 95, 114, 101, 109, 111, 118, 101, 100, 32, 45, 114,
  109, 91, 36, 105, 93, 32, 45, 101, 108, 115, 101, 32, 105, 61, 123, 36,
  105, 43, 49, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110,
  101, 10, 45, 119, 91, 45, 49, 93, 32, 45, 119, 97, 105, 116, 32, 50,
  48, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76,
  69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 68, 125, 125, 32, 45, 119,
  91, 93, 32, 123, 51, 42, 119, 125, 44, 123, 51, 42, 104, 125, 32, 45,
  101, 108, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69,
  70, 84, 125, 38, 38, 64, 123, 33, 44, 67, 125, 125, 32, 45, 119, 91,
  93, 32, 123, 49, 46, 53, 42, 119, 125, 44, 123, 49, 46, 53, 42, 104,
  125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32,
  123, 64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83,
  67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125,
  10, 45, 101, 110, 100, 108, 32, 45, 107, 91, 45, 49, 93, 32, 45, 119,
  91, 93, 32, 48, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 120, 95, 102, 105, 115, 104, 101, 121, 101, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 76, 97, 117, 110, 99, 104, 32, 116, 104, 101, 32, 102,
  105, 115, 104, 45, 101, 121, 101, 32, 101, 102, 102, 101, 99, 116, 32, 100,
  101, 109, 111, 46, 10, 120, 95, 102, 105, 115, 104, 101, 121, 101, 32, 58,
  10, 45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45,
  32, 70, 105, 115, 104, 45, 101, 121, 101, 32, 101, 102, 102, 101, 99, 116,
  32, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45,
  45, 32, 77, 111, 117, 115, 101, 32, 112, 111, 105, 110, 116, 101, 114, 32,
  109, 111, 118, 101, 115, 32, 102, 105, 115, 104, 45, 101, 121, 101, 32, 99,
  101, 110, 116, 101, 114, 46, 92, 110, 10, 45, 45, 45, 45, 32, 77, 111,
  117, 115, 101, 32, 98, 117, 116, 116, 111, 110, 115, 32, 115, 101, 116, 32,
  102, 105, 115, 104, 45, 101, 121, 101, 32, 115, 105, 122, 101, 46, 92, 110,
  10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76,
  43, 68, 39, 32, 116, 111, 32, 100, 111, 117, 98, 108, 101, 32, 119, 105,
  110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45,
  45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76, 43, 67, 39, 32,
  116, 111, 32, 114, 101, 115, 101, 116, 32, 119, 105, 110, 100, 111, 119, 32,
  115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121,
  115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81, 39, 32, 116,
  111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110,
  10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45,
  10, 45, 105, 102, 32, 123, 64, 35, 62, 48, 125, 32, 45, 97, 32, 120,
  32, 45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 114, 50, 100, 121, 32,
  50, 50, 48, 32, 45, 101, 108, 115, 101, 10, 49, 50, 48, 44, 57, 48,
  44, 49, 44, 51, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 32, 45, 112, 108, 97, 115, 109, 97, 91, 45, 49, 93,
  32, 48, 46, 51, 44, 51, 32, 45, 110, 32, 48, 44, 50, 53, 53, 10,
  45, 116, 32, 34, 32, 32, 71, 39, 77, 73, 67, 92, 110, 70, 73, 83,
  72, 45, 69, 89, 69, 92, 110, 32, 69, 70, 70, 69, 67, 84, 34, 44,
  49, 53, 44, 49, 51, 44, 50, 52, 44, 49, 44, 50, 53, 53, 32, 45,
  115, 99, 97, 108, 101, 50, 120, 32, 45, 98, 32, 53, 32, 45, 115, 104,
  97, 114, 112, 101, 110, 32, 49, 48, 48, 48, 10, 45, 102, 32, 105, 43,
  49, 53, 48, 45, 52, 42, 97, 98, 115, 40, 121, 45, 104, 47, 50, 41,
  32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 102,
  114, 97, 109, 101, 95, 102, 117, 122, 122, 121, 91, 45, 49, 93, 32, 49,
  53, 44, 49, 48, 44, 49, 53, 44, 49, 46, 53, 44, 48, 32, 45, 116,
  111, 95, 114, 103, 98, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 116, 111, 114, 117, 115, 51, 100, 32, 50, 48, 44, 54, 32, 45,
  99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 123, 63, 40, 51, 48, 44,
  50, 53, 53, 41, 125, 44, 123, 63, 40, 51, 48, 44, 50, 53, 53, 41,
  125, 44, 123, 63, 40, 51, 48, 44, 50, 53, 53, 41, 125, 32, 45, 45,
  114, 51, 100, 91, 45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 57, 48,
  10, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 123, 63, 40, 51,
  48, 44, 50, 53, 53, 41, 125, 44, 123, 63, 40, 51, 48, 44, 50, 53,
  53, 41, 125, 44, 123, 63, 40, 51, 48, 44, 50, 53, 53, 41, 125, 32,
  45, 43, 51, 100, 91, 45, 49, 93, 32, 49, 53, 32, 45, 43, 51, 100,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 100, 98, 51, 100, 32, 48, 32,
  45, 99, 51, 100, 91, 45, 49, 93, 10, 82, 61, 51, 48, 10, 45, 119,
  91, 45, 50, 93, 32, 123, 49, 46, 53, 42, 64, 123, 45, 50, 44, 119,
  125, 125, 44, 123, 49, 46, 53, 42, 64, 123, 45, 50, 44, 104, 125, 125,
  44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 70, 105, 115, 104,
  45, 101, 121, 101, 32, 101, 102, 102, 101, 99, 116, 34, 10, 45, 100, 111,
  10, 45, 119, 97, 105, 116, 32, 52, 48, 10, 45, 105, 102, 32, 123, 64,
  123, 33, 44, 98, 125, 61, 61, 49, 125, 32, 82, 61, 123, 109, 105, 110,
  40, 56, 48, 44, 36, 82, 43, 56, 41, 125, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 98, 125, 61, 61, 50,
  125, 32, 82, 61, 123, 109, 97, 120, 40, 51, 44, 36, 82, 45, 56, 41,
  125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 111, 98, 106, 101, 99,
  116, 51, 100, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 123, 53, 48,
  43, 51, 48, 42, 99, 111, 115, 40, 64, 124, 42, 50, 46, 53, 41, 125,
  37, 44, 123, 53, 48, 43, 51, 48, 42, 115, 105, 110, 40, 64, 124, 42,
  49, 46, 54, 41, 125, 37, 44, 123, 53, 48, 43, 51, 51, 48, 42, 115,
  105, 110, 40, 64, 124, 42, 50, 46, 54, 41, 125, 44, 48, 46, 55, 44,
  51, 44, 48, 44, 48, 32, 45, 114, 51, 100, 91, 45, 50, 93, 32, 49,
  44, 48, 46, 50, 44, 48, 46, 54, 44, 51, 10, 45, 105, 102, 32, 123,
  64, 123, 33, 44, 120, 125, 62, 61, 48, 125, 10, 45, 102, 105, 115, 104,
  101, 121, 101, 91, 45, 49, 93, 32, 123, 64, 123, 33, 44, 120, 125, 42,
  49, 48, 48, 47, 64, 123, 33, 44, 119, 125, 125, 44, 123, 64, 123, 33,
  44, 121, 125, 42, 49, 48, 48, 47, 64, 123, 33, 44, 104, 125, 125, 44,
  36, 82, 10, 45, 101, 110, 100, 105, 102, 10, 45, 119, 91, 45, 49, 93,
  10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69,
  70, 84, 125, 38, 38, 64, 123, 33, 44, 68, 125, 125, 32, 45, 119, 91,
  93, 32, 123, 51, 42, 119, 125, 44, 123, 51, 42, 104, 125, 32, 45, 101,
  108, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70,
  84, 125, 38, 38, 64, 123, 33, 44, 67, 125, 125, 32, 45, 119, 91, 93,
  32, 123, 49, 46, 53, 42, 119, 125, 44, 123, 49, 46, 53, 42, 104, 125,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 105, 102, 32, 123, 64, 33, 61, 61, 48, 34, 32, 124, 124, 32, 34,
  64, 123, 33, 44, 69, 83, 67, 125, 34, 32, 124, 124, 32, 34, 64, 123,
  33, 44, 81, 125, 125, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 119, 32, 48, 32, 45, 118, 32, 43, 32, 45, 114, 101, 116, 117,
  114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 119, 104, 105, 108, 101,
  32, 49, 10, 35, 64, 103, 109, 105, 99, 32, 120, 95, 102, 111, 117, 114,
  105, 101, 114, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 76, 97, 117,
  110, 99, 104, 32, 116, 104, 101, 32, 102, 111, 117, 114, 105, 101, 114, 32,
  102, 105, 108, 116, 101, 114, 105, 110, 103, 32, 100, 101, 109, 111, 46, 10,
  120, 95, 102, 111, 117, 114, 105, 101, 114, 32, 58, 10, 45, 101, 91, 93,
  32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 70, 111, 117, 114,
  105, 101, 114, 45, 102, 105, 108, 116, 101, 114, 105, 110, 103, 32, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10,
  45, 45, 45, 45, 32, 77, 111, 117, 115, 101, 32, 98, 117, 116, 116, 111,
  110, 115, 32, 111, 110, 32, 116, 104, 101, 32, 114, 105, 103, 104, 116, 32,
  105, 109, 97, 103, 101, 32, 116, 111, 32, 115, 101, 116, 32, 109, 105, 110,
  47, 109, 97, 120, 32, 102, 114, 101, 113, 117, 101, 110, 99, 105, 101, 115,
  46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67,
  84, 82, 76, 43, 68, 39, 32, 116, 111, 32, 105, 110, 99, 114, 101, 97,
  115, 101, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92,
  110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82,
  76, 43, 67, 39, 32, 116, 111, 32, 100, 101, 99, 114, 101, 97, 115, 101,
  32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10,
  45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76, 43,
  82, 39, 32, 116, 111, 32, 114, 101, 115, 101, 116, 32, 119, 105, 110, 100,
  111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32,
  75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81,
  39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45,
  45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32,
  123, 33, 64, 35, 125, 32, 45, 116, 101, 115, 116, 105, 109, 97, 103, 101,
  50, 100, 32, 50, 53, 54, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  110, 101, 101, 100, 95, 117, 112, 100, 97, 116, 101, 61, 49, 10, 102, 114,
  101, 113, 109, 105, 110, 61, 48, 10, 102, 114, 101, 113, 109, 97, 120, 61,
  49, 48, 48, 10, 45, 105, 102, 32, 123, 119, 62, 51, 42, 64, 123, 33,
  44, 117, 125, 47, 53, 125, 32, 45, 114, 50, 100, 120, 91, 45, 49, 93,
  32, 123, 51, 42, 64, 123, 33, 44, 117, 125, 47, 49, 48, 125, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 104, 62, 51, 42, 64,
  123, 33, 44, 118, 125, 47, 53, 125, 32, 45, 114, 50, 100, 121, 91, 45,
  49, 93, 32, 123, 51, 42, 64, 123, 33, 44, 118, 125, 47, 53, 125, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 45, 102, 102, 116, 91, 45, 49, 93,
  32, 45, 110, 109, 91, 45, 50, 93, 32, 114, 101, 97, 108, 32, 45, 110,
  109, 91, 45, 49, 93, 32, 105, 109, 97, 103, 10, 45, 45, 115, 113, 114,
  91, 114, 101, 97, 108, 44, 105, 109, 97, 103, 93, 32, 45, 43, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 115, 113, 114, 116, 91, 45, 49, 93, 32,
  45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 108, 111, 103, 91, 45, 49,
  93, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45,
  115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48,
  37, 44, 48, 44, 48, 44, 50, 32, 45, 116, 111, 95, 99, 111, 108, 111,
  114, 109, 111, 100, 101, 91, 45, 49, 93, 32, 64, 123, 45, 50, 44, 115,
  125, 10, 45, 110, 109, 91, 45, 49, 93, 32, 108, 111, 103, 109, 97, 103,
  10, 45, 119, 91, 48, 44, 45, 49, 93, 32, 45, 49, 44, 45, 49, 44,
  48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 70, 111, 117, 114, 105,
  101, 114, 32, 102, 105, 108, 116, 101, 114, 105, 110, 103, 34, 10, 45, 105,
  102, 32, 123, 33, 110, 97, 114, 103, 40, 36, 102, 105, 114, 115, 116, 95,
  116, 105, 109, 101, 41, 125, 32, 45, 45, 108, 91, 45, 49, 93, 32, 45,
  114, 50, 100, 121, 32, 49, 50, 56, 32, 45, 102, 114, 97, 109, 101, 32,
  49, 44, 49, 44, 48, 10, 45, 97, 108, 101, 114, 116, 32, 34, 91, 71,
  39, 77, 73, 67, 32, 70, 111, 117, 114, 105, 101, 114, 32, 102, 105, 108,
  116, 101, 114, 105, 110, 103, 93, 34, 44, 92, 10, 34, 84, 104, 101, 32,
  71, 39, 77, 73, 67, 32, 70, 111, 117, 114, 105, 101, 114, 32, 102, 105,
  108, 116, 101, 114, 105, 110, 103, 32, 100, 101, 109, 111, 32, 105, 108, 108,
  117, 115, 116, 114, 97, 116, 101, 115, 32, 116, 104, 101, 32, 101, 102, 102,
  101, 99, 116, 92, 110, 34, 92, 10, 34, 111, 102, 32, 98, 97, 110, 100,
  112, 97, 115, 115, 32, 102, 114, 101, 113, 117, 101, 110, 99, 121, 32, 102,
  105, 108, 116, 101, 114, 105, 110, 103, 32, 111, 110, 32, 97, 110, 32, 105,
  109, 97, 103, 101, 46, 32, 85, 115, 101, 32, 121, 111, 117, 114, 32, 109,
  111, 117, 115, 101, 92, 110, 34, 92, 10, 34, 98, 117, 116, 116, 111, 110,
  115, 32, 116, 111, 32, 115, 101, 108, 101, 99, 116, 32, 108, 111, 119, 32,
  97, 110, 100, 32, 104, 105, 103, 104, 32, 98, 111, 117, 110, 100, 115, 32,
  102, 111, 114, 32, 116, 104, 101, 32, 102, 114, 101, 113, 117, 101, 110, 99,
  105, 101, 115, 92, 110, 34, 92, 10, 34, 100, 105, 115, 112, 108, 97, 121,
  101, 100, 32, 111, 110, 32, 116, 104, 101, 32, 70, 111, 117, 114, 105, 101,
  114, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 97, 116, 105, 111, 110,
  32, 111, 102, 32, 116, 104, 101, 32, 105, 109, 97, 103, 101, 92, 110, 34,
  92, 10, 34, 40, 114, 105, 103, 104, 116, 32, 105, 109, 97, 103, 101, 41,
  46, 34, 44, 92, 10, 34, 83, 116, 97, 114, 116, 32, 100, 101, 109, 111,
  34, 10, 45, 114, 109, 32, 45, 101, 110, 100, 108, 32, 102, 105, 114, 115,
  116, 95, 116, 105, 109, 101, 61, 48, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 100, 111, 10, 45, 105, 102, 32, 36, 110, 101, 101, 100, 95, 117, 112,
  100, 97, 116, 101, 10, 45, 105, 91, 109, 97, 115, 107, 93, 32, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 10, 114, 61, 123, 115, 113, 114, 116, 40,
  119, 94, 50, 43, 104, 94, 50, 41, 42, 36, 102, 114, 101, 113, 109, 97,
  120, 47, 50, 48, 48, 125, 32, 45, 101, 108, 108, 105, 112, 115, 101, 91,
  109, 97, 115, 107, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 36, 114,
  44, 36, 114, 44, 48, 44, 49, 44, 49, 10, 114, 61, 123, 109, 97, 120,
  40, 48, 44, 115, 113, 114, 116, 40, 119, 94, 50, 43, 104, 94, 50, 41,
  42, 36, 102, 114, 101, 113, 109, 105, 110, 47, 50, 48, 48, 45, 49, 41,
  125, 32, 45, 105, 102, 32, 36, 114, 32, 45, 101, 108, 108, 105, 112, 115,
  101, 91, 109, 97, 115, 107, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44,
  36, 114, 44, 36, 114, 44, 48, 44, 49, 44, 48, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 45, 42, 91, 108, 111, 103, 109, 97, 103, 93, 32, 91,
  109, 97, 115, 107, 93, 32, 45, 43, 91, 45, 49, 93, 32, 91, 109, 97,
  115, 107, 93, 32, 45, 47, 91, 45, 49, 93, 32, 50, 32, 45, 110, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 115, 104, 105, 102, 116,
  91, 109, 97, 115, 107, 93, 32, 45, 53, 48, 37, 44, 45, 53, 48, 37,
  44, 48, 44, 48, 44, 50, 10, 45, 45, 42, 91, 114, 101, 97, 108, 44,
  105, 109, 97, 103, 93, 32, 91, 109, 97, 115, 107, 93, 10, 45, 114, 109,
  91, 45, 52, 93, 10, 45, 105, 102, 102, 116, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 10, 45, 114, 118, 91, 45, 50, 44, 45, 49,
  93, 10, 45, 105, 102, 32, 64, 33, 32, 45, 114, 91, 45, 50, 44, 45,
  49, 93, 32, 123, 64, 123, 33, 44, 119, 125, 47, 50, 125, 44, 64, 123,
  33, 44, 104, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 91, 45,
  49, 93, 32, 34, 70, 114, 101, 113, 46, 32, 77, 105, 110, 47, 77, 97,
  120, 32, 61, 32, 34, 123, 105, 110, 116, 40, 36, 102, 114, 101, 113, 109,
  105, 110, 41, 125, 34, 37, 32, 47, 32, 34, 123, 105, 110, 116, 40, 36,
  102, 114, 101, 113, 109, 97, 120, 41, 125, 34, 37, 34, 44, 53, 44, 53,
  44, 49, 51, 44, 49, 44, 50, 53, 53, 10, 45, 119, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 110,
  101, 101, 100, 95, 117, 112, 100, 97, 116, 101, 61, 48, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 119, 97, 105, 116, 10, 45, 105, 102, 32, 123, 64,
  123, 33, 44, 98, 125, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 120,
  125, 62, 61, 64, 123, 33, 44, 119, 125, 47, 50, 125, 10, 114, 61, 123,
  50, 48, 48, 42, 115, 113, 114, 116, 40, 40, 64, 123, 33, 44, 120, 125,
  45, 51, 42, 64, 123, 33, 44, 119, 125, 47, 52, 41, 94, 50, 43, 40,
  64, 123, 33, 44, 121, 125, 45, 64, 123, 33, 44, 104, 125, 47, 50, 41,
  94, 50, 41, 47, 92, 10, 115, 113, 114, 116, 40, 40, 64, 123, 33, 44,
  119, 125, 47, 50, 41, 94, 50, 43, 64, 123, 33, 44, 104, 125, 94, 50,
  41, 125, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 98, 125, 38, 49,
  125, 32, 102, 114, 101, 113, 109, 97, 120, 61, 36, 114, 10, 45, 101, 108,
  115, 101, 32, 102, 114, 101, 113, 109, 105, 110, 61, 123, 109, 97, 120, 40,
  48, 44, 36, 114, 45, 51, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 102, 114, 101, 113, 109, 105, 110, 62, 61, 36,
  102, 114, 101, 113, 109, 97, 120, 125, 32, 102, 114, 101, 113, 109, 105, 110,
  61, 36, 102, 114, 101, 113, 109, 97, 120, 32, 45, 101, 110, 100, 105, 102,
  10, 110, 101, 101, 100, 95, 117, 112, 100, 97, 116, 101, 61, 49, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 64, 123, 33, 44, 114, 125,
  32, 110, 101, 101, 100, 95, 117, 112, 100, 97, 116, 101, 61, 49, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 40, 64, 123, 33, 44,
  67, 84, 82, 76, 76, 69, 70, 84, 125, 34, 32, 124, 124, 32, 34, 64,
  123, 33, 44, 67, 84, 82, 76, 82, 73, 71, 72, 84, 125, 41, 34, 32,
  38, 38, 32, 34, 64, 123, 33, 44, 68, 125, 125, 32, 45, 119, 91, 93,
  32, 123, 64, 123, 33, 44, 119, 125, 42, 49, 46, 53, 125, 44, 123, 64,
  123, 33, 44, 104, 125, 42, 49, 46, 53, 125, 32, 110, 101, 101, 100, 95,
  117, 112, 100, 97, 116, 101, 61, 49, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 40, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69,
  70, 84, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 44, 67, 84, 82,
  76, 82, 73, 71, 72, 84, 125, 41, 34, 32, 38, 38, 32, 34, 64, 123,
  33, 44, 67, 125, 125, 32, 45, 119, 91, 93, 32, 123, 64, 123, 33, 44,
  119, 125, 47, 49, 46, 53, 125, 44, 123, 64, 123, 33, 44, 104, 125, 47,
  49, 46, 53, 125, 32, 110, 101, 101, 100, 95, 117, 112, 100, 97, 116, 101,
  61, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 40,
  64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 34, 32, 124,
  124, 32, 34, 64, 123, 33, 44, 67, 84, 82, 76, 82, 73, 71, 72, 84,
  125, 41, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 82, 125, 125, 32,
  45, 119, 91, 93, 32, 123, 50, 42, 64, 123, 48, 44, 119, 125, 125, 44,
  64, 123, 48, 44, 104, 125, 32, 110, 101, 101, 100, 95, 117, 112, 100, 97,
  116, 101, 61, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 119, 104, 105,
  108, 101, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33,
  44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44,
  81, 125, 125, 10, 45, 114, 109, 91, 45, 51, 45, 45, 49, 93, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 119, 32, 48, 32,
  45, 114, 109, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  120, 95, 104, 105, 115, 116, 111, 103, 114, 97, 109, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 76, 97, 117, 110, 99, 104, 32, 116, 104, 101, 32,
  104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 100, 101, 109, 111, 46, 10,
  120, 95, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 58, 10, 45, 101,
  91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 72, 105,
  115, 116, 111, 103, 114, 97, 109, 32, 100, 101, 109, 111, 32, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45,
  45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32, 77, 111, 117, 115, 101,
  32, 116, 111, 32, 115, 101, 116, 32, 112, 97, 114, 97, 109, 101, 116, 101,
  114, 115, 46, 92, 110, 10, 45, 45, 45, 45, 32, 82, 105, 103, 104, 116,
  32, 98, 117, 116, 116, 111, 110, 32, 111, 114, 32, 107, 101, 121, 32, 39,
  83, 80, 65, 67, 69, 39, 32, 116, 111, 32, 114, 101, 115, 101, 116, 46,
  92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 69, 83,
  67, 39, 32, 111, 114, 32, 39, 81, 39, 32, 116, 111, 32, 101, 120, 105,
  116, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 34, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 123, 33, 64, 35,
  125, 32, 45, 116, 101, 115, 116, 105, 109, 97, 103, 101, 50, 100, 32, 51,
  48, 48, 44, 51, 48, 48, 32, 45, 101, 108, 115, 101, 32, 45, 107, 91,
  48, 93, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 114, 50, 100, 121,
  32, 51, 48, 48, 44, 50, 32, 45, 105, 102, 32, 123, 119, 62, 56, 48,
  48, 125, 32, 45, 114, 32, 56, 48, 48, 44, 49, 48, 48, 37, 44, 49,
  44, 51, 44, 50, 32, 45, 101, 110, 100, 105, 102, 32, 45, 110, 32, 48,
  44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 102, 114,
  97, 109, 101, 91, 45, 49, 93, 32, 49, 44, 49, 44, 48, 10, 51, 48,
  48, 44, 123, 104, 125, 44, 49, 44, 51, 44, 50, 50, 48, 10, 45, 116,
  91, 45, 49, 93, 32, 34, 71, 97, 109, 109, 97, 32, 58, 34, 44, 53,
  44, 48, 44, 49, 54, 44, 49, 44, 48, 10, 45, 116, 91, 45, 49, 93,
  32, 34, 67, 111, 110, 116, 114, 97, 115, 116, 32, 58, 34, 44, 53, 44,
  53, 48, 44, 49, 54, 44, 49, 44, 48, 10, 45, 116, 91, 45, 49, 93,
  32, 34, 66, 114, 105, 103, 104, 116, 110, 101, 115, 115, 32, 58, 34, 44,
  53, 44, 49, 48, 48, 44, 49, 54, 44, 49, 44, 48, 10, 45, 116, 91,
  45, 49, 93, 32, 34, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  58, 34, 44, 53, 44, 49, 53, 48, 44, 49, 54, 44, 49, 44, 48, 10,
  45, 116, 91, 45, 49, 93, 32, 34, 83, 104, 97, 114, 112, 110, 101, 115,
  115, 32, 58, 34, 44, 53, 44, 50, 48, 48, 44, 49, 54, 44, 49, 44,
  48, 10, 45, 116, 91, 45, 49, 93, 32, 34, 67, 108, 117, 115, 116, 101,
  114, 115, 32, 58, 34, 44, 53, 44, 50, 53, 48, 44, 49, 54, 44, 49,
  44, 48, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 10, 123,
  119, 125, 44, 50, 48, 48, 44, 49, 44, 51, 44, 50, 53, 53, 10, 45,
  103, 114, 105, 100, 91, 45, 49, 93, 32, 49, 48, 37, 44, 49, 48, 37,
  44, 48, 44, 48, 44, 48, 46, 51, 44, 48, 120, 67, 67, 67, 67, 67,
  67, 67, 67, 44, 48, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101,
  91, 45, 49, 93, 32, 48, 44, 48, 44, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44,
  48, 10, 45, 97, 120, 101, 115, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 44, 49, 44, 48, 44, 49, 51, 44, 49, 44, 48, 10, 45, 102, 114,
  97, 109, 101, 91, 45, 50, 44, 45, 49, 93, 32, 53, 44, 53, 44, 50,
  50, 48, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 10, 99,
  108, 117, 115, 116, 101, 114, 115, 61, 54, 52, 32, 115, 104, 97, 114, 112,
  110, 101, 115, 115, 61, 48, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 61, 48, 32, 99, 111, 110, 116, 114, 97, 115, 116, 61, 49, 32, 98,
  114, 105, 103, 104, 116, 110, 101, 115, 115, 61, 48, 32, 103, 97, 109, 109,
  97, 61, 49, 10, 45, 100, 111, 10, 91, 48, 93, 10, 105, 97, 61, 123,
  105, 97, 125, 10, 45, 105, 102, 32, 36, 103, 97, 109, 109, 97, 32, 45,
  47, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 94, 91, 45, 49, 93,
  32, 123, 49, 47, 36, 103, 97, 109, 109, 97, 125, 32, 45, 42, 91, 45,
  49, 93, 32, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45,
  91, 45, 49, 93, 32, 36, 105, 97, 32, 45, 42, 91, 45, 49, 93, 32,
  36, 99, 111, 110, 116, 114, 97, 115, 116, 32, 45, 43, 91, 45, 49, 93,
  32, 36, 98, 114, 105, 103, 104, 116, 110, 101, 115, 115, 32, 45, 43, 91,
  45, 49, 93, 32, 36, 105, 97, 10, 45, 98, 91, 45, 49, 93, 32, 36,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 10, 45, 115, 104, 97, 114,
  112, 101, 110, 91, 45, 49, 93, 32, 36, 115, 104, 97, 114, 112, 110, 101,
  115, 115, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10,
  45, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 54, 44, 54,
  10, 115, 120, 61, 123, 64, 123, 48, 44, 119, 125, 43, 49, 50, 125, 10,
  45, 95, 120, 95, 104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 49,
  93, 32, 123, 36, 103, 97, 109, 109, 97, 42, 49, 48, 48, 47, 52, 125,
  32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 115, 120,
  44, 50, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 95, 120, 95,
  104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 49, 93, 32, 123, 36,
  99, 111, 110, 116, 114, 97, 115, 116, 42, 49, 48, 48, 47, 52, 125, 32,
  45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 115, 120, 44,
  55, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 95, 120, 95, 104,
  105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 49, 93, 32, 123, 40, 36,
  98, 114, 105, 103, 104, 116, 110, 101, 115, 115, 43, 49, 50, 56, 41, 42,
  49, 48, 48, 47, 50, 53, 54, 125, 32, 45, 106, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 36, 115, 120, 44, 49, 50, 53, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 95, 120, 95, 104, 105, 115, 116, 111, 103, 114,
  97, 109, 91, 45, 49, 93, 32, 123, 36, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 42, 49, 48, 48, 47, 49, 48, 125, 32, 45, 106, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 44, 36, 115, 120, 44, 49, 55, 53, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 95, 120, 95, 104, 105, 115, 116,
  111, 103, 114, 97, 109, 91, 45, 49, 93, 32, 123, 36, 115, 104, 97, 114,
  112, 110, 101, 115, 115, 42, 49, 48, 48, 47, 50, 48, 48, 48, 125, 32,
  45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 115, 120, 44,
  50, 50, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 95, 120, 95,
  104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 49, 93, 32, 123, 36,
  99, 108, 117, 115, 116, 101, 114, 115, 42, 49, 48, 48, 47, 50, 53, 54,
  125, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 115,
  120, 44, 50, 55, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 45,
  115, 91, 45, 50, 93, 32, 99, 32, 45, 104, 105, 115, 116, 111, 103, 114,
  97, 109, 91, 45, 51, 45, 45, 49, 93, 32, 36, 99, 108, 117, 115, 116,
  101, 114, 115, 44, 48, 44, 50, 53, 53, 32, 45, 47, 91, 45, 51, 45,
  45, 49, 93, 32, 123, 51, 42, 64, 123, 48, 44, 119, 104, 125, 47, 36,
  99, 108, 117, 115, 116, 101, 114, 115, 125, 32, 45, 114, 109, 91, 45, 53,
  93, 10, 45, 45, 122, 91, 45, 52, 93, 32, 53, 44, 51, 49, 55, 44,
  123, 64, 123, 45, 52, 44, 119, 125, 45, 53, 125, 44, 123, 64, 123, 45,
  52, 44, 104, 125, 45, 54, 125, 10, 45, 103, 114, 97, 112, 104, 91, 45,
  49, 93, 32, 91, 45, 52, 93, 44, 51, 44, 48, 44, 49, 44, 48, 44,
  48, 46, 50, 44, 50, 53, 53, 44, 48, 44, 48, 10, 45, 103, 114, 97,
  112, 104, 91, 45, 49, 93, 32, 91, 45, 51, 93, 44, 51, 44, 48, 44,
  49, 44, 48, 44, 48, 46, 50, 44, 48, 44, 50, 53, 53, 44, 48, 10,
  45, 103, 114, 97, 112, 104, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44,
  51, 44, 48, 44, 49, 44, 48, 44, 48, 46, 50, 44, 48, 44, 48, 44,
  50, 53, 53, 10, 45, 114, 109, 91, 45, 52, 45, 45, 50, 93, 10, 45,
  106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 53, 44, 51, 49, 55,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 119, 91, 45, 49, 93, 32,
  123, 119, 125, 44, 123, 104, 125, 44, 48, 44, 34, 91, 71, 39, 77, 73,
  67, 93, 32, 72, 105, 115, 116, 111, 103, 114, 97, 109, 32, 100, 101, 109,
  111, 34, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 119, 97, 105, 116,
  10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 98, 125, 38, 49, 92, 32,
  38, 38, 92, 32, 64, 123, 33, 44, 120, 125, 62, 61, 64, 123, 48, 44,
  119, 125, 45, 49, 48, 125, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44,
  121, 125, 62, 61, 50, 53, 92, 32, 38, 38, 92, 32, 64, 123, 33, 44,
  121, 125, 60, 61, 52, 50, 125, 10, 103, 97, 109, 109, 97, 61, 123, 109,
  97, 120, 40, 48, 44, 109, 105, 110, 40, 52, 44, 40, 64, 123, 33, 44,
  120, 125, 45, 36, 115, 120, 41, 42, 52, 47, 50, 56, 48, 41, 41, 125,
  10, 45, 101, 108, 105, 102, 32, 123, 64, 123, 33, 44, 121, 125, 62, 61,
  55, 53, 92, 32, 38, 38, 92, 32, 64, 123, 33, 44, 121, 125, 60, 61,
  57, 50, 125, 10, 99, 111, 110, 116, 114, 97, 115, 116, 61, 123, 109, 97,
  120, 40, 48, 44, 109, 105, 110, 40, 52, 44, 40, 64, 123, 33, 44, 120,
  125, 45, 36, 115, 120, 41, 42, 52, 47, 50, 56, 48, 41, 41, 125, 10,
  45, 101, 108, 105, 102, 32, 123, 64, 123, 33, 44, 121, 125, 62, 61, 49,
  50, 53, 92, 32, 38, 38, 92, 32, 64, 123, 33, 44, 121, 125, 60, 61,
  49, 52, 50, 125, 10, 98, 114, 105, 103, 104, 116, 110, 101, 115, 115, 61,
  123, 109, 97, 120, 40, 45, 49, 50, 56, 44, 109, 105, 110, 40, 49, 50,
  56, 44, 40, 64, 123, 33, 44, 120, 125, 45, 36, 115, 120, 41, 42, 50,
  53, 54, 47, 50, 56, 48, 45, 49, 50, 56, 41, 41, 125, 10, 45, 101,
  108, 105, 102, 32, 123, 64, 123, 33, 44, 121, 125, 62, 61, 49, 55, 53,
  92, 32, 38, 38, 92, 32, 64, 123, 33, 44, 121, 125, 60, 61, 49, 57,
  50, 125, 10, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 123, 109,
  97, 120, 40, 48, 44, 109, 105, 110, 40, 49, 48, 44, 40, 64, 123, 33,
  44, 120, 125, 45, 36, 115, 120, 41, 42, 49, 48, 47, 50, 56, 48, 41,
  41, 125, 10, 45, 101, 108, 105, 102, 32, 123, 64, 123, 33, 44, 121, 125,
  62, 61, 50, 50, 53, 92, 32, 38, 38, 92, 32, 64, 123, 33, 44, 121,
  125, 60, 61, 50, 52, 50, 125, 10, 115, 104, 97, 114, 112, 110, 101, 115,
  115, 61, 123, 109, 97, 120, 40, 48, 44, 109, 105, 110, 40, 50, 48, 48,
  48, 44, 40, 64, 123, 33, 44, 120, 125, 45, 36, 115, 120, 41, 42, 50,
  48, 48, 48, 47, 50, 56, 48, 41, 41, 125, 10, 45, 101, 108, 105, 102,
  32, 123, 64, 123, 33, 44, 121, 125, 62, 61, 50, 55, 53, 92, 32, 38,
  38, 92, 32, 64, 123, 33, 44, 121, 125, 60, 61, 50, 57, 50, 125, 10,
  99, 108, 117, 115, 116, 101, 114, 115, 61, 123, 109, 97, 120, 40, 50, 44,
  109, 105, 110, 40, 50, 53, 54, 44, 40, 64, 123, 33, 44, 120, 125, 45,
  36, 115, 120, 41, 42, 50, 53, 54, 47, 50, 56, 48, 41, 41, 125, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 64, 123, 33, 44, 98, 125, 38, 50, 92, 32, 124, 124, 92,
  32, 64, 123, 33, 44, 83, 80, 65, 67, 69, 125, 125, 32, 99, 108, 117,
  115, 116, 101, 114, 115, 61, 54, 52, 32, 115, 104, 97, 114, 112, 110, 101,
  115, 115, 61, 48, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61,
  48, 32, 99, 111, 110, 116, 114, 97, 115, 116, 61, 49, 32, 98, 114, 105,
  103, 104, 116, 110, 101, 115, 115, 61, 48, 32, 103, 97, 109, 109, 97, 61,
  49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32,
  123, 64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83,
  67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125,
  10, 45, 119, 32, 48, 32, 45, 114, 109, 32, 45, 118, 32, 43, 10, 95,
  120, 95, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 58, 10, 118, 97,
  108, 61, 123, 109, 97, 120, 40, 48, 44, 109, 105, 110, 40, 49, 48, 48,
  44, 36, 49, 41, 41, 125, 10, 50, 56, 48, 44, 50, 44, 49, 44, 51,
  44, 50, 53, 53, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 48,
  44, 48, 44, 36, 118, 97, 108, 37, 44, 48, 44, 49, 44, 48, 44, 50,
  53, 53, 44, 48, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 48,
  44, 49, 44, 36, 118, 97, 108, 37, 44, 49, 44, 49, 44, 50, 52, 48,
  44, 50, 53, 53, 44, 54, 50, 32, 45, 114, 91, 45, 49, 93, 32, 49,
  48, 48, 37, 44, 49, 54, 44, 49, 44, 51, 44, 51, 10, 48, 32, 45,
  116, 91, 45, 49, 93, 32, 123, 114, 111, 117, 110, 100, 40, 36, 118, 97,
  108, 41, 125, 37, 44, 48, 44, 48, 44, 50, 48, 44, 49, 44, 49, 32,
  45, 45, 42, 91, 45, 49, 93, 32, 45, 50, 53, 53, 32, 45, 43, 91,
  45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 91, 45, 49, 93, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 51, 10, 45, 106, 91,
  45, 51, 93, 32, 91, 45, 49, 93, 44, 123, 40, 50, 56, 48, 45, 119,
  41, 47, 50, 125, 44, 123, 40, 49, 54, 45, 104, 41, 47, 50, 125, 44,
  48, 44, 48, 44, 49, 44, 91, 45, 50, 93, 32, 45, 114, 109, 91, 45,
  50, 44, 45, 49, 93, 10, 45, 114, 91, 45, 49, 93, 32, 123, 119, 43,
  50, 125, 44, 123, 104, 43, 50, 125, 44, 49, 44, 51, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 10, 35, 64, 103, 109, 105, 99, 32,
  120, 95, 104, 111, 117, 103, 104, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 76, 97, 117, 110, 99, 104, 32, 116, 104, 101, 32, 104, 111, 117, 103,
  104, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32, 100, 101, 109, 111,
  46, 10, 120, 95, 104, 111, 117, 103, 104, 32, 58, 10, 45, 101, 91, 93,
  32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 72, 111, 117, 103,
  104, 45, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45,
  45, 45, 45, 32, 77, 111, 117, 115, 101, 32, 98, 117, 116, 116, 111, 110,
  115, 32, 111, 110, 32, 116, 104, 101, 32, 118, 111, 116, 101, 32, 105, 109,
  97, 103, 101, 32, 116, 111, 32, 100, 114, 97, 119, 32, 99, 111, 114, 114,
  101, 115, 112, 111, 110, 100, 105, 110, 103, 32, 108, 105, 110, 101, 46, 92,
  110, 10, 45, 45, 45, 45, 32, 77, 111, 117, 115, 101, 32, 98, 117, 116,
  116, 111, 110, 115, 32, 111, 110, 32, 116, 104, 101, 32, 105, 109, 97, 103,
  101, 32, 116, 111, 32, 118, 111, 116, 101, 32, 102, 111, 114, 32, 97, 108,
  108, 32, 108, 105, 110, 101, 115, 32, 99, 114, 111, 115, 115, 105, 110, 103,
  46, 92, 110, 10, 45, 45, 45, 45, 32, 116, 104, 101, 32, 99, 108, 105,
  99, 107, 101, 100, 32, 112, 111, 105, 110, 116, 46, 92, 110, 10, 45, 45,
  45, 45, 32, 75, 101, 121, 32, 39, 83, 80, 65, 67, 69, 39, 32, 116,
  111, 32, 114, 101, 115, 101, 116, 32, 116, 104, 101, 32, 104, 111, 117, 103,
  104, 32, 119, 105, 110, 100, 111, 119, 46, 92, 110, 10, 45, 45, 45, 45,
  32, 75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39,
  81, 39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45,
  45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 10, 45, 105, 102,
  32, 123, 33, 64, 35, 125, 32, 45, 116, 101, 115, 116, 105, 109, 97, 103,
  101, 50, 100, 32, 52, 48, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  110, 32, 48, 44, 50, 53, 53, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 114, 91, 45, 49, 93,
  32, 64, 123, 45, 102, 105, 116, 115, 99, 114, 101, 101, 110, 92, 32, 123,
  119, 125, 44, 123, 104, 125, 125, 44, 49, 44, 49, 48, 48, 37, 44, 51,
  10, 114, 104, 111, 109, 97, 120, 61, 123, 115, 113, 114, 116, 40, 119, 94,
  50, 43, 104, 94, 50, 41, 47, 50, 125, 10, 45, 45, 98, 91, 45, 49,
  93, 32, 49, 46, 53, 32, 45, 104, 111, 117, 103, 104, 91, 45, 49, 93,
  32, 53, 49, 50, 44, 52, 48, 48, 32, 45, 98, 91, 45, 49, 93, 32,
  48, 46, 53, 32, 45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 108, 111,
  103, 91, 45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 10, 45, 119, 91, 45, 50, 93, 32, 45, 49, 44, 45, 49, 44,
  48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 73, 109, 97, 103, 101,
  34, 32, 45, 119, 49, 91, 45, 49, 93, 32, 45, 49, 44, 45, 49, 44,
  48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 72, 111, 117, 103, 104,
  32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 34, 10, 45, 105, 102, 32,
  123, 33, 110, 97, 114, 103, 40, 36, 102, 105, 114, 115, 116, 95, 116, 105,
  109, 101, 41, 125, 32, 45, 45, 108, 91, 48, 93, 32, 45, 114, 50, 100,
  121, 32, 49, 50, 56, 32, 45, 102, 114, 97, 109, 101, 32, 49, 44, 49,
  44, 48, 10, 45, 97, 108, 101, 114, 116, 32, 34, 91, 71, 39, 77, 73,
  67, 32, 72, 111, 117, 103, 104, 32, 84, 114, 97, 110, 115, 102, 111, 114,
  109, 93, 34, 44, 92, 10, 34, 84, 104, 101, 32, 71, 39, 77, 73, 67,
  32, 72, 111, 117, 103, 104, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109,
  32, 100, 101, 109, 111, 32, 105, 108, 108, 117, 115, 116, 114, 97, 116, 101,
  115, 32, 116, 104, 101, 32, 97, 112, 112, 108, 105, 99, 97, 116, 105, 111,
  110, 92, 110, 34, 92, 10, 34, 111, 102, 32, 116, 104, 101, 32, 72, 111,
  117, 103, 104, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32, 116, 111,
  32, 100, 101, 116, 101, 99, 116, 32, 108, 105, 110, 101, 115, 32, 105, 110,
  32, 97, 110, 32, 105, 109, 97, 103, 101, 46, 32, 85, 115, 101, 32, 121,
  111, 117, 114, 92, 110, 34, 92, 10, 34, 109, 111, 117, 115, 101, 32, 98,
  117, 116, 116, 111, 110, 115, 32, 116, 111, 32, 101, 120, 112, 108, 111, 114,
  101, 32, 116, 104, 101, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32,
  105, 109, 97, 103, 101, 32, 97, 110, 100, 32, 115, 101, 101, 32, 104, 111,
  119, 92, 110, 34, 92, 10, 34, 108, 105, 110, 101, 115, 32, 105, 110, 32,
  105, 109, 97, 103, 101, 115, 32, 97, 114, 101, 32, 114, 101, 112, 114, 101,
  115, 101, 110, 116, 101, 100, 32, 98, 121, 32, 112, 111, 105, 110, 116, 115,
  32, 105, 110, 32, 116, 104, 101, 32, 116, 114, 97, 110, 115, 102, 111, 114,
  109, 46, 34, 44, 92, 10, 34, 83, 116, 97, 114, 116, 32, 100, 101, 109,
  111, 34, 10, 45, 114, 109, 32, 45, 101, 110, 100, 108, 32, 102, 105, 114,
  115, 116, 95, 116, 105, 109, 101, 61, 48, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 100, 111, 10, 45, 119, 97, 105, 116, 10, 45, 105, 102, 32, 64,
  123, 33, 44, 98, 125, 10, 120, 48, 61, 123, 64, 123, 33, 44, 120, 125,
  45, 64, 123, 33, 44, 119, 125, 47, 50, 125, 10, 121, 48, 61, 123, 64,
  123, 33, 44, 121, 125, 45, 64, 123, 33, 44, 104, 125, 47, 50, 125, 10,
  114, 104, 111, 48, 61, 123, 115, 113, 114, 116, 40, 40, 36, 120, 48, 41,
  94, 50, 43, 40, 36, 121, 48, 41, 94, 50, 41, 125, 10, 116, 104, 101,
  116, 97, 48, 61, 123, 97, 116, 97, 110, 50, 40, 36, 121, 48, 44, 36,
  120, 48, 41, 125, 10, 40, 48, 44, 123, 50, 42, 112, 105, 125, 41, 32,
  40, 36, 116, 104, 101, 116, 97, 48, 44, 123, 36, 116, 104, 101, 116, 97,
  48, 45, 50, 42, 112, 105, 125, 41, 10, 45, 114, 91, 45, 50, 44, 45,
  49, 93, 32, 64, 123, 45, 51, 44, 119, 125, 44, 49, 44, 49, 44, 49,
  44, 51, 10, 45, 99, 111, 115, 91, 45, 49, 93, 32, 45, 42, 91, 45,
  49, 93, 32, 36, 114, 104, 111, 48, 32, 45, 45, 108, 116, 91, 45, 49,
  93, 32, 48, 32, 45, 97, 98, 115, 91, 45, 50, 93, 10, 45, 42, 91,
  45, 49, 93, 32, 123, 112, 105, 125, 32, 45, 43, 91, 45, 51, 44, 45,
  49, 93, 32, 45, 37, 91, 45, 50, 93, 32, 123, 50, 42, 112, 105, 125,
  10, 45, 42, 91, 45, 50, 93, 32, 123, 48, 46, 53, 42, 64, 123, 45,
  51, 44, 119, 125, 47, 112, 105, 125, 32, 45, 42, 91, 45, 49, 93, 32,
  123, 64, 123, 45, 51, 44, 104, 125, 47, 36, 114, 104, 111, 109, 97, 120,
  125, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 123, 119, 125, 32, 45, 112, 111, 105, 110, 116,
  91, 45, 50, 93, 32, 64, 123, 45, 49, 44, 40, 36, 62, 44, 48, 41,
  125, 44, 64, 123, 45, 49, 44, 40, 36, 62, 44, 49, 41, 125, 44, 48,
  44, 48, 46, 51, 44, 50, 53, 53, 32, 45, 100, 111, 110, 101, 10, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 119, 49, 91, 45, 49, 93, 10, 45,
  101, 108, 105, 102, 32, 123, 64, 123, 33, 49, 44, 120, 125, 62, 61, 48,
  34, 32, 38, 38, 32, 34, 64, 123, 33, 49, 44, 98, 125, 125, 10, 116,
  104, 101, 116, 97, 61, 123, 64, 123, 33, 49, 44, 120, 125, 42, 50, 42,
  112, 105, 47, 64, 123, 33, 49, 44, 119, 125, 125, 10, 114, 104, 111, 61,
  123, 64, 123, 33, 49, 44, 121, 125, 42, 36, 114, 104, 111, 109, 97, 120,
  47, 64, 123, 33, 49, 44, 104, 125, 125, 10, 120, 61, 123, 64, 123, 45,
  50, 44, 119, 125, 47, 50, 43, 36, 114, 104, 111, 42, 99, 111, 115, 40,
  36, 116, 104, 101, 116, 97, 41, 125, 10, 121, 61, 123, 64, 123, 45, 50,
  44, 104, 125, 47, 50, 43, 36, 114, 104, 111, 42, 115, 105, 110, 40, 36,
  116, 104, 101, 116, 97, 41, 125, 10, 120, 48, 61, 123, 36, 120, 43, 49,
  48, 48, 48, 42, 115, 105, 110, 40, 36, 116, 104, 101, 116, 97, 41, 125,
  10, 121, 48, 61, 123, 36, 121, 45, 49, 48, 48, 48, 42, 99, 111, 115,
  40, 36, 116, 104, 101, 116, 97, 41, 125, 10, 120, 49, 61, 123, 36, 120,
  45, 49, 48, 48, 48, 42, 115, 105, 110, 40, 36, 116, 104, 101, 116, 97,
  41, 125, 10, 121, 49, 61, 123, 36, 121, 43, 49, 48, 48, 48, 42, 99,
  111, 115, 40, 36, 116, 104, 101, 116, 97, 41, 125, 10, 91, 45, 50, 93,
  10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 120, 48, 44, 36,
  121, 48, 44, 36, 120, 49, 44, 36, 121, 49, 44, 49, 44, 48, 120, 48,
  70, 48, 70, 48, 70, 48, 70, 44, 50, 53, 53, 10, 45, 108, 105, 110,
  101, 91, 45, 49, 93, 32, 123, 36, 120, 48, 43, 49, 125, 44, 36, 121,
  48, 44, 36, 120, 49, 44, 36, 121, 49, 44, 49, 44, 48, 120, 48, 70,
  48, 70, 48, 70, 48, 70, 44, 50, 53, 53, 10, 45, 108, 105, 110, 101,
  91, 45, 49, 93, 32, 36, 120, 48, 44, 123, 36, 121, 48, 43, 49, 125,
  44, 36, 120, 49, 44, 36, 121, 49, 44, 49, 44, 48, 120, 48, 70, 48,
  70, 48, 70, 48, 70, 44, 50, 53, 53, 10, 45, 108, 105, 110, 101, 91,
  45, 49, 93, 32, 36, 120, 48, 44, 36, 121, 48, 44, 36, 120, 49, 44,
  36, 121, 49, 44, 49, 44, 48, 120, 70, 48, 70, 48, 70, 48, 70, 48,
  44, 48, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 123, 36, 120,
  48, 43, 49, 125, 44, 36, 121, 48, 44, 36, 120, 49, 44, 36, 121, 49,
  44, 49, 44, 48, 120, 70, 48, 70, 48, 70, 48, 70, 48, 44, 48, 10,
  45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 120, 48, 44, 123, 36,
  121, 48, 43, 49, 125, 44, 36, 120, 49, 44, 36, 121, 49, 44, 49, 44,
  48, 120, 70, 48, 70, 48, 70, 48, 70, 48, 44, 48, 10, 45, 119, 91,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 105,
  102, 32, 123, 64, 123, 33, 44, 83, 80, 65, 67, 69, 125, 34, 32, 124,
  124, 32, 34, 64, 123, 33, 49, 44, 83, 80, 65, 67, 69, 125, 125, 10,
  45, 114, 109, 91, 45, 49, 93, 32, 45, 45, 98, 91, 45, 49, 93, 32,
  49, 46, 53, 32, 45, 104, 111, 117, 103, 104, 91, 45, 49, 93, 32, 53,
  49, 50, 44, 52, 48, 48, 32, 45, 98, 91, 45, 49, 93, 32, 48, 46,
  53, 32, 45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 108, 111, 103, 91,
  45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  10, 45, 119, 49, 91, 45, 49, 93, 32, 45, 49, 44, 45, 49, 44, 48,
  44, 34, 72, 111, 117, 103, 104, 32, 84, 114, 97, 110, 115, 102, 111, 114,
  109, 34, 10, 45, 101, 108, 105, 102, 32, 64, 123, 33, 44, 114, 125, 32,
  45, 119, 91, 45, 50, 93, 10, 45, 101, 108, 105, 102, 32, 64, 123, 33,
  49, 44, 114, 125, 32, 45, 119, 49, 91, 45, 49, 93, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34, 32,
  38, 38, 32, 34, 64, 123, 33, 49, 125, 34, 32, 38, 38, 32, 34, 33,
  64, 123, 33, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64,
  123, 33, 44, 81, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 49,
  44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 49,
  44, 81, 125, 125, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 110,
  100, 108, 10, 45, 105, 102, 32, 123, 33, 64, 33, 34, 32, 124, 124, 32,
  34, 33, 64, 123, 33, 49, 125, 125, 32, 45, 98, 114, 101, 97, 107, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 119, 48, 32, 48, 10, 45, 100, 111,
  110, 101, 32, 45, 114, 109, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109,
  105, 99, 32, 120, 95, 106, 97, 119, 98, 114, 101, 97, 107, 101, 114, 32,
  58, 32, 48, 60, 95, 119, 105, 100, 116, 104, 60, 50, 48, 44, 48, 60,
  95, 104, 101, 105, 103, 104, 116, 60, 50, 48, 44, 48, 60, 95, 98, 97,
  108, 108, 115, 60, 61, 56, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  76, 97, 117, 110, 99, 104, 32, 116, 104, 101, 32, 74, 97, 119, 98, 114,
  101, 97, 107, 101, 114, 32, 103, 97, 109, 101, 46, 10, 120, 95, 106, 97,
  119, 98, 114, 101, 97, 107, 101, 114, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 34, 36, 123, 49, 61, 49, 50, 125, 62, 48, 32, 38, 38, 32,
  36, 49, 60, 50, 48, 32, 38, 38, 32, 36, 123, 50, 61, 49, 51, 125,
  62, 48, 32, 38, 38, 32, 36, 50, 60, 50, 48, 32, 38, 38, 32, 36,
  123, 51, 61, 53, 125, 62, 48, 32, 38, 38, 32, 36, 51, 60, 61, 56,
  34, 10, 45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45,
  45, 32, 74, 97, 119, 98, 114, 101, 97, 107, 101, 114, 32, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45,
  92, 110, 10, 45, 45, 45, 45, 32, 84, 104, 101, 32, 103, 111, 97, 108,
  32, 111, 102, 32, 116, 104, 101, 32, 103, 97, 109, 101, 32, 105, 115, 32,
  116, 111, 32, 114, 101, 109, 111, 118, 101, 32, 116, 104, 101, 32, 109, 97,
  120, 105, 109, 117, 109, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 92,
  110, 10, 45, 45, 45, 45, 32, 98, 97, 108, 108, 115, 32, 111, 110, 32,
  116, 104, 101, 32, 98, 111, 97, 114, 100, 44, 32, 115, 105, 109, 112, 108,
  121, 32, 98, 121, 32, 99, 108, 105, 99, 107, 105, 110, 103, 32, 111, 110,
  32, 116, 104, 101, 109, 46, 32, 66, 117, 116, 32, 97, 92, 110, 10, 45,
  45, 45, 45, 32, 99, 111, 108, 111, 114, 101, 100, 32, 98, 97, 108, 108,
  32, 99, 97, 110, 32, 100, 105, 115, 97, 112, 112, 101, 97, 114, 32, 111,
  110, 108, 121, 32, 105, 102, 32, 105, 116, 32, 105, 115, 32, 103, 114, 111,
  117, 112, 101, 100, 32, 119, 105, 116, 104, 32, 97, 116, 92, 110, 10, 45,
  45, 45, 45, 32, 108, 101, 97, 115, 116, 32, 111, 110, 101, 32, 98, 97,
  108, 108, 32, 111, 102, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 99,
  111, 108, 111, 114, 46, 32, 84, 104, 101, 32, 115, 99, 111, 114, 101, 32,
  105, 115, 32, 104, 105, 103, 104, 101, 114, 32, 105, 102, 92, 110, 10, 45,
  45, 45, 45, 32, 121, 111, 117, 32, 100, 101, 115, 116, 114, 111, 121, 32,
  108, 97, 114, 103, 101, 114, 32, 115, 101, 116, 115, 32, 111, 102, 32, 99,
  111, 110, 110, 101, 99, 116, 101, 100, 32, 99, 111, 108, 111, 114, 101, 100,
  32, 98, 97, 108, 108, 115, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110,
  10, 45, 45, 45, 45, 32, 76, 101, 102, 116, 32, 109, 111, 117, 115, 101,
  32, 98, 117, 116, 116, 111, 110, 32, 116, 111, 32, 115, 101, 108, 101, 99,
  116, 47, 100, 101, 115, 116, 114, 111, 121, 32, 98, 97, 108, 108, 115, 32,
  111, 110, 32, 98, 111, 97, 114, 100, 46, 92, 110, 10, 45, 45, 45, 45,
  32, 75, 101, 121, 32, 39, 66, 65, 67, 75, 83, 80, 65, 67, 69, 39,
  32, 111, 114, 32, 39, 83, 80, 65, 67, 69, 39, 32, 116, 111, 32, 117,
  110, 100, 111, 32, 116, 104, 101, 32, 108, 97, 115, 116, 32, 109, 111, 118,
  101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 32, 39, 83,
  39, 32, 116, 111, 32, 115, 97, 118, 101, 32, 115, 110, 97, 112, 115, 104,
  111, 116, 32, 111, 102, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110,
  116, 32, 118, 105, 101, 119, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75,
  101, 121, 115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81, 39,
  32, 116, 111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45, 45,
  92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 34, 10, 45, 118, 32, 45, 10, 45, 105, 91, 98, 111, 97, 114, 100,
  93, 32, 36, 49, 44, 36, 50, 32, 45, 114, 97, 110, 100, 91, 98, 111,
  97, 114, 100, 93, 32, 49, 44, 36, 51, 32, 45, 114, 111, 117, 110, 100,
  91, 98, 111, 97, 114, 100, 93, 32, 49, 10, 45, 105, 91, 117, 110, 100,
  111, 93, 32, 91, 45, 49, 93, 10, 45, 105, 91, 98, 97, 108, 108, 115,
  93, 32, 51, 50, 44, 51, 50, 44, 49, 44, 52, 32, 45, 95, 120, 95,
  106, 97, 119, 98, 114, 101, 97, 107, 101, 114, 95, 98, 97, 108, 108, 91,
  45, 49, 93, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49,
  93, 32, 48, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 91, 45,
  49, 93, 32, 49, 44, 48, 32, 45, 42, 91, 45, 49, 93, 32, 49, 46,
  53, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45,
  114, 91, 45, 49, 93, 32, 123, 64, 123, 98, 111, 97, 114, 100, 44, 119,
  125, 42, 119, 125, 44, 123, 64, 123, 98, 111, 97, 114, 100, 44, 104, 125,
  42, 104, 125, 44, 49, 44, 49, 44, 48, 44, 50, 32, 45, 47, 91, 45,
  49, 93, 32, 50, 53, 53, 10, 45, 105, 91, 98, 97, 99, 107, 93, 32,
  123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 51, 32, 45, 108, 91, 45,
  49, 93, 10, 45, 114, 97, 110, 100, 32, 48, 44, 50, 53, 53, 32, 45,
  98, 108, 117, 114, 95, 120, 121, 32, 54, 44, 50, 48, 32, 45, 101, 113,
  117, 97, 108, 105, 122, 101, 32, 49, 48, 48, 44, 48, 44, 50, 53, 53,
  32, 45, 98, 108, 117, 114, 95, 120, 121, 32, 50, 44, 52, 10, 45, 115,
  104, 32, 48, 44, 48, 32, 45, 115, 104, 91, 45, 50, 93, 32, 49, 44,
  49, 32, 45, 115, 104, 91, 45, 51, 93, 32, 50, 44, 50, 32, 45, 47,
  91, 45, 51, 93, 32, 52, 32, 45, 47, 91, 45, 50, 93, 32, 56, 32,
  45, 47, 91, 45, 49, 93, 32, 50, 32, 45, 114, 109, 91, 45, 51, 45,
  45, 49, 93, 10, 45, 101, 110, 100, 108, 10, 45, 105, 91, 118, 105, 115,
  117, 93, 32, 91, 98, 97, 99, 107, 93, 10, 115, 99, 111, 114, 101, 61,
  48, 10, 117, 110, 100, 111, 115, 99, 111, 114, 101, 61, 48, 10, 114, 101,
  110, 100, 101, 114, 95, 98, 111, 97, 114, 100, 61, 49, 10, 115, 104, 97,
  112, 101, 115, 99, 111, 114, 101, 121, 61, 48, 10, 115, 104, 97, 112, 101,
  115, 99, 111, 114, 101, 61, 48, 10, 45, 100, 111, 10, 45, 105, 102, 32,
  36, 114, 101, 110, 100, 101, 114, 95, 98, 111, 97, 114, 100, 10, 45, 45,
  97, 98, 115, 91, 98, 111, 97, 114, 100, 93, 32, 45, 45, 91, 45, 49,
  93, 32, 49, 32, 45, 42, 91, 45, 49, 93, 32, 123, 51, 54, 48, 47,
  36, 51, 125, 32, 45, 45, 103, 101, 91, 98, 111, 97, 114, 100, 93, 32,
  48, 32, 45, 42, 91, 45, 49, 93, 32, 48, 46, 57, 32, 45, 114, 91,
  45, 50, 44, 45, 49, 93, 32, 91, 98, 97, 108, 108, 115, 93, 32, 91,
  98, 97, 108, 108, 115, 93, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93,
  32, 99, 32, 45, 104, 115, 118, 50, 114, 103, 98, 91, 45, 49, 93, 10,
  45, 45, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101,
  108, 115, 91, 45, 49, 93, 32, 43, 32, 45, 103, 116, 91, 45, 49, 93,
  32, 48, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51,
  10, 45, 106, 91, 118, 105, 115, 117, 93, 32, 91, 98, 97, 99, 107, 93,
  32, 45, 106, 91, 118, 105, 115, 117, 93, 32, 91, 45, 50, 93, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 32, 45, 114,
  109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 105, 102, 32, 123, 33, 36,
  115, 104, 97, 112, 101, 115, 99, 111, 114, 101, 121, 125, 32, 45, 119, 91,
  118, 105, 115, 117, 93, 32, 64, 123, 98, 97, 99, 107, 44, 119, 125, 44,
  64, 123, 98, 97, 99, 107, 44, 104, 125, 44, 48, 44, 34, 91, 71, 39,
  77, 73, 67, 93, 32, 74, 97, 119, 98, 114, 101, 97, 107, 101, 114, 32,
  40, 115, 99, 111, 114, 101, 32, 58, 32, 34, 36, 115, 99, 111, 114, 101,
  34, 41, 34, 32, 45, 101, 110, 100, 105, 102, 10, 114, 101, 110, 100, 101,
  114, 95, 98, 111, 97, 114, 100, 61, 48, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 36, 115, 104, 97, 112, 101, 115, 99, 111, 114, 101,
  121, 10, 45, 45, 116, 91, 118, 105, 115, 117, 93, 32, 34, 43, 34, 36,
  115, 104, 97, 112, 101, 115, 99, 111, 114, 101, 44, 64, 123, 33, 44, 120,
  125, 44, 123, 64, 123, 33, 44, 121, 125, 45, 54, 52, 43, 36, 115, 104,
  97, 112, 101, 115, 99, 111, 114, 101, 121, 125, 44, 51, 50, 44, 123, 40,
  36, 115, 104, 97, 112, 101, 115, 99, 111, 114, 101, 121, 45, 49, 41, 47,
  51, 49, 125, 44, 50, 53, 53, 10, 115, 104, 97, 112, 101, 115, 99, 111,
  114, 101, 121, 61, 123, 109, 97, 120, 40, 48, 44, 36, 115, 104, 97, 112,
  101, 115, 99, 111, 114, 101, 121, 45, 49, 41, 125, 10, 45, 119, 91, 45,
  49, 93, 32, 64, 123, 98, 97, 99, 107, 44, 119, 125, 44, 64, 123, 98,
  97, 99, 107, 44, 104, 125, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67,
  93, 32, 74, 97, 119, 98, 114, 101, 97, 107, 101, 114, 32, 40, 115, 99,
  111, 114, 101, 32, 58, 32, 34, 36, 115, 99, 111, 114, 101, 34, 41, 34,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 119, 97, 105, 116, 32, 50,
  53, 10, 45, 101, 108, 115, 101, 32, 45, 119, 97, 105, 116, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 45, 102, 91, 98, 111, 97, 114, 100, 93, 32,
  34, 105, 102, 40, 105, 44, 106, 40, 45, 49, 41, 61, 61, 105, 32, 124,
  124, 32, 106, 40, 49, 41, 61, 61, 105, 32, 124, 124, 32, 106, 40, 48,
  44, 49, 41, 61, 61, 105, 32, 124, 124, 32, 106, 40, 48, 44, 45, 49,
  41, 61, 61, 105, 44, 48, 41, 34, 10, 45, 105, 102, 32, 123, 33, 64,
  123, 45, 49, 44, 43, 125, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 98, 114, 101, 97, 107, 32, 45, 101, 110, 100, 105, 102, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 105, 102, 32, 64, 123, 33, 44, 114, 125,
  32, 114, 101, 110, 100, 101, 114, 95, 98, 111, 97, 114, 100, 61, 49, 10,
  45, 101, 108, 105, 102, 32, 64, 123, 33, 44, 83, 125, 32, 45, 111, 91,
  118, 105, 115, 117, 93, 32, 103, 109, 105, 99, 95, 106, 97, 119, 98, 114,
  101, 97, 107, 101, 114, 46, 112, 110, 103, 10, 45, 101, 108, 105, 102, 32,
  123, 64, 123, 33, 44, 66, 65, 67, 75, 83, 80, 65, 67, 69, 125, 34,
  32, 124, 124, 32, 34, 64, 123, 33, 44, 83, 80, 65, 67, 69, 125, 125,
  10, 45, 97, 98, 115, 91, 117, 110, 100, 111, 93, 32, 45, 106, 91, 98,
  111, 97, 114, 100, 93, 32, 91, 117, 110, 100, 111, 93, 10, 115, 99, 111,
  114, 101, 61, 36, 117, 110, 100, 111, 115, 99, 111, 114, 101, 10, 114, 101,
  110, 100, 101, 114, 95, 98, 111, 97, 114, 100, 61, 49, 10, 45, 101, 108,
  105, 102, 32, 123, 64, 123, 33, 44, 120, 125, 34, 62, 61, 48, 32, 38,
  38, 32, 34, 64, 123, 33, 44, 98, 125, 125, 10, 45, 119, 97, 105, 116,
  32, 45, 49, 10, 120, 61, 123, 34, 105, 110, 116, 40, 34, 64, 123, 33,
  44, 120, 125, 34, 42, 34, 64, 123, 98, 111, 97, 114, 100, 44, 119, 125,
  34, 47, 34, 64, 123, 33, 44, 119, 125, 34, 41, 34, 125, 10, 121, 61,
  123, 34, 105, 110, 116, 40, 34, 64, 123, 33, 44, 121, 125, 34, 42, 34,
  64, 123, 98, 111, 97, 114, 100, 44, 104, 125, 34, 47, 34, 64, 123, 33,
  44, 104, 125, 34, 41, 34, 125, 10, 45, 105, 102, 32, 123, 64, 123, 98,
  111, 97, 114, 100, 44, 40, 36, 120, 44, 36, 121, 41, 125, 62, 48, 125,
  10, 45, 97, 98, 115, 91, 98, 111, 97, 114, 100, 93, 32, 45, 102, 108,
  111, 111, 100, 91, 98, 111, 97, 114, 100, 93, 32, 36, 120, 44, 36, 121,
  44, 48, 44, 48, 44, 48, 44, 49, 44, 45, 64, 123, 98, 111, 97, 114,
  100, 44, 40, 36, 120, 44, 36, 121, 41, 125, 10, 45, 45, 103, 101, 91,
  98, 111, 97, 114, 100, 93, 32, 48, 32, 45, 45, 91, 45, 49, 93, 32,
  49, 10, 115, 104, 97, 112, 101, 115, 99, 111, 114, 101, 61, 123, 40, 64,
  123, 45, 49, 44, 43, 125, 43, 49, 41, 94, 50, 125, 32, 115, 104, 97,
  112, 101, 115, 99, 111, 114, 101, 121, 61, 123, 105, 102, 40, 36, 115, 104,
  97, 112, 101, 115, 99, 111, 114, 101, 44, 51, 50, 44, 48, 41, 125, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 105, 102, 32, 64, 123,
  98, 111, 97, 114, 100, 44, 40, 36, 120, 44, 36, 121, 41, 125, 10, 45,
  45, 102, 108, 111, 111, 100, 91, 98, 111, 97, 114, 100, 93, 32, 36, 120,
  44, 36, 121, 44, 48, 44, 48, 44, 48, 44, 49, 44, 45, 49, 32, 45,
  61, 61, 91, 45, 49, 93, 32, 45, 49, 10, 45, 105, 102, 32, 123, 64,
  123, 45, 49, 44, 43, 125, 62, 49, 125, 10, 45, 106, 91, 117, 110, 100,
  111, 93, 32, 91, 98, 111, 97, 114, 100, 93, 10, 117, 110, 100, 111, 115,
  99, 111, 114, 101, 61, 36, 115, 99, 111, 114, 101, 10, 45, 102, 108, 111,
  111, 100, 91, 98, 111, 97, 114, 100, 93, 32, 36, 120, 44, 36, 121, 44,
  48, 44, 48, 44, 48, 44, 49, 44, 48, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 123, 98, 111, 97, 114, 100, 44, 119, 125, 10, 45, 45, 99,
  111, 108, 117, 109, 110, 115, 91, 98, 111, 97, 114, 100, 93, 32, 36, 62,
  32, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 121, 10, 104,
  61, 64, 123, 98, 111, 97, 114, 100, 44, 104, 125, 32, 45, 108, 91, 45,
  49, 93, 32, 45, 115, 32, 45, 44, 48, 32, 45, 97, 32, 121, 32, 45,
  105, 102, 32, 64, 35, 32, 45, 114, 32, 49, 44, 36, 104, 44, 49, 44,
  49, 44, 48, 32, 45, 109, 105, 114, 114, 111, 114, 32, 121, 32, 45, 101,
  108, 115, 101, 32, 45, 105, 32, 49, 44, 36, 104, 32, 45, 101, 110, 100,
  105, 102, 32, 45, 101, 110, 100, 108, 10, 45, 106, 91, 98, 111, 97, 114,
  100, 93, 32, 91, 45, 49, 93, 44, 36, 62, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 100, 111, 110, 101, 10, 45, 114, 111, 119, 115, 91, 98,
  111, 97, 114, 100, 93, 32, 45, 49, 44, 49, 48, 48, 37, 32, 45, 102,
  91, 98, 111, 97, 114, 100, 93, 32, 34, 105, 102, 40, 121, 61, 61, 48,
  44, 105, 102, 40, 105, 40, 120, 44, 104, 45, 49, 41, 44, 120, 44, 119,
  41, 44, 105, 41, 34, 32, 45, 115, 111, 114, 116, 91, 98, 111, 97, 114,
  100, 93, 32, 43, 44, 120, 32, 45, 114, 111, 119, 115, 91, 98, 111, 97,
  114, 100, 93, 32, 49, 44, 49, 48, 48, 37, 10, 115, 99, 111, 114, 101,
  61, 123, 36, 115, 99, 111, 114, 101, 43, 105, 110, 116, 40, 40, 64, 123,
  45, 49, 44, 43, 125, 45, 49, 41, 94, 50, 41, 125, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 115,
  101, 32, 45, 97, 98, 115, 91, 98, 111, 97, 114, 100, 93, 10, 45, 101,
  110, 100, 105, 102, 10, 114, 101, 110, 100, 101, 114, 95, 98, 111, 97, 114,
  100, 61, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 119, 104, 105, 108,
  101, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44,
  81, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67,
  125, 125, 10, 45, 105, 102, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34,
  33, 64, 123, 33, 44, 69, 83, 67, 125, 125, 10, 45, 119, 91, 93, 32,
  64, 123, 118, 105, 115, 117, 44, 119, 125, 44, 64, 123, 118, 105, 115, 117,
  44, 104, 125, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 74,
  97, 119, 98, 114, 101, 97, 107, 101, 114, 32, 40, 102, 105, 110, 97, 108,
  32, 115, 99, 111, 114, 101, 32, 58, 32, 34, 36, 115, 99, 111, 114, 101,
  34, 41, 34, 10, 45, 105, 91, 103, 97, 109, 101, 111, 118, 101, 114, 93,
  32, 50, 51, 48, 44, 56, 53, 32, 45, 116, 91, 45, 49, 93, 32, 34,
  71, 97, 109, 101, 32, 79, 118, 101, 114, 33, 34, 44, 51, 44, 48, 44,
  53, 55, 44, 49, 44, 49, 32, 45, 116, 91, 45, 49, 93, 32, 34, 83,
  99, 111, 114, 101, 32, 58, 32, 34, 36, 115, 99, 111, 114, 101, 44, 50,
  52, 44, 53, 52, 44, 51, 50, 44, 49, 44, 49, 10, 45, 45, 100, 105,
  108, 97, 116, 101, 91, 45, 49, 93, 32, 53, 32, 45, 110, 109, 91, 45,
  49, 93, 32, 34, 109, 103, 97, 109, 101, 111, 118, 101, 114, 34, 32, 45,
  42, 91, 45, 50, 93, 32, 50, 53, 53, 32, 45, 114, 91, 45, 50, 93,
  32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 51, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 50, 53, 10, 45, 45, 114, 91, 103, 97,
  109, 101, 111, 118, 101, 114, 44, 109, 103, 97, 109, 101, 111, 118, 101, 114,
  93, 32, 123, 52, 48, 48, 45, 49, 50, 42, 40, 36, 62, 43, 49, 41,
  125, 37, 44, 123, 52, 48, 48, 45, 49, 50, 42, 40, 36, 62, 43, 49,
  41, 125, 37, 10, 45, 45, 106, 91, 118, 105, 115, 117, 93, 32, 91, 45,
  50, 93, 44, 123, 40, 64, 123, 118, 105, 115, 117, 44, 119, 125, 45, 119,
  41, 47, 50, 125, 44, 123, 40, 64, 123, 118, 105, 115, 117, 44, 104, 125,
  45, 104, 41, 47, 50, 125, 44, 48, 44, 48, 44, 123, 36, 62, 47, 50,
  53, 125, 44, 91, 45, 49, 93, 10, 45, 119, 91, 45, 49, 93, 32, 45,
  114, 109, 91, 45, 51, 45, 45, 49, 93, 32, 45, 119, 97, 105, 116, 32,
  50, 53, 10, 45, 100, 111, 110, 101, 10, 45, 100, 111, 10, 45, 119, 97,
  105, 116, 32, 45, 105, 102, 32, 64, 123, 33, 44, 114, 125, 32, 45, 119,
  91, 93, 32, 64, 123, 33, 44, 119, 125, 44, 64, 123, 33, 44, 104, 125,
  32, 45, 119, 97, 105, 116, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34, 32, 38, 38, 32,
  34, 33, 64, 123, 33, 44, 81, 125, 34, 32, 38, 38, 32, 34, 33, 64,
  123, 33, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123,
  33, 44, 98, 125, 125, 10, 45, 114, 109, 91, 103, 97, 109, 101, 111, 118,
  101, 114, 44, 109, 103, 97, 109, 101, 111, 118, 101, 114, 93, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 109, 91, 98, 111, 97, 114, 100, 44, 117,
  110, 100, 111, 44, 98, 97, 108, 108, 115, 44, 98, 97, 99, 107, 44, 118,
  105, 115, 117, 93, 10, 45, 119, 32, 48, 32, 45, 118, 32, 43, 10, 95,
  120, 95, 106, 97, 119, 98, 114, 101, 97, 107, 101, 114, 95, 98, 97, 108,
  108, 32, 58, 10, 109, 119, 104, 61, 123, 109, 105, 110, 40, 119, 44, 104,
  41, 125, 10, 45, 115, 104, 32, 51, 44, 51, 32, 45, 102, 91, 45, 49,
  93, 32, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 108,
  105, 112, 115, 101, 32, 123, 48, 46, 53, 42, 36, 109, 119, 104, 125, 44,
  123, 48, 46, 53, 42, 36, 109, 119, 104, 125, 44, 123, 48, 46, 53, 42,
  36, 109, 119, 104, 45, 52, 125, 44, 123, 48, 46, 53, 42, 36, 109, 119,
  104, 45, 52, 125, 44, 48, 44, 49, 44, 50, 52, 48, 44, 50, 52, 48,
  44, 50, 52, 48, 44, 49, 10, 45, 115, 104, 32, 48, 44, 50, 32, 45,
  42, 91, 45, 49, 93, 32, 39, 40, 36, 109, 119, 104, 43, 121, 45, 120,
  41, 47, 40, 50, 42, 119, 41, 39, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 101, 108, 108, 105, 112, 115, 101, 32, 123, 36, 109, 119, 104, 42,
  48, 46, 55, 125, 44, 123, 36, 109, 119, 104, 42, 48, 46, 51, 125, 44,
  123, 109, 105, 110, 40, 51, 48, 44, 36, 109, 119, 104, 42, 36, 109, 119,
  104, 47, 53, 49, 50, 41, 125, 44, 123, 109, 105, 110, 40, 51, 48, 44,
  36, 109, 119, 104, 42, 36, 109, 119, 104, 47, 53, 49, 50, 41, 125, 44,
  48, 44, 123, 109, 105, 110, 40, 36, 109, 119, 104, 47, 54, 52, 44, 49,
  41, 125, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 49,
  10, 45, 115, 104, 32, 48, 44, 50, 32, 45, 98, 91, 45, 49, 93, 32,
  123, 48, 46, 48, 50, 42, 36, 109, 119, 104, 125, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 115, 104, 32, 51, 44, 51, 32, 45, 42, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 32, 45, 100, 105, 108, 97, 116, 101, 91,
  45, 49, 93, 32, 51, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115,
  104, 32, 48, 44, 50, 32, 45, 43, 91, 45, 49, 93, 32, 39, 105, 102,
  40, 105, 38, 38, 40, 33, 106, 40, 45, 49, 41, 124, 124, 33, 106, 40,
  49, 41, 124, 124, 33, 106, 40, 48, 44, 45, 49, 41, 124, 124, 33, 106,
  40, 48, 44, 49, 41, 41, 44, 50, 52, 48, 47, 54, 44, 48, 41, 39,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 35, 64, 103, 109, 105, 99, 32,
  120, 95, 108, 105, 102, 101, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  76, 97, 117, 110, 99, 104, 32, 116, 104, 101, 32, 103, 97, 109, 101, 32,
  111, 102, 32, 108, 105, 102, 101, 46, 10, 120, 95, 108, 105, 102, 101, 32,
  58, 10, 45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45,
  45, 32, 84, 104, 101, 32, 103, 97, 109, 101, 32, 111, 102, 32, 108, 105,
  102, 101, 32, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45,
  92, 110, 10, 45, 45, 45, 45, 32, 84, 104, 101, 32, 103, 111, 97, 108,
  32, 105, 115, 32, 116, 111, 32, 99, 114, 101, 97, 116, 101, 32, 116, 104,
  101, 32, 98, 105, 103, 103, 101, 115, 116, 32, 112, 111, 115, 115, 105, 98,
  108, 101, 32, 98, 105, 111, 108, 111, 103, 105, 99, 97, 108, 92, 110, 10,
  45, 45, 45, 45, 32, 115, 121, 115, 116, 101, 109, 46, 32, 89, 111, 117,
  32, 115, 116, 97, 114, 116, 32, 119, 105, 116, 104, 32, 97, 32, 115, 116,
  111, 99, 107, 32, 111, 102, 32, 99, 101, 108, 108, 115, 32, 119, 104, 105,
  99, 104, 32, 121, 111, 117, 32, 99, 97, 110, 92, 110, 10, 45, 45, 45,
  45, 32, 115, 112, 114, 101, 97, 100, 32, 111, 118, 101, 114, 32, 116, 104,
  101, 32, 98, 111, 97, 114, 100, 46, 32, 70, 111, 114, 32, 101, 97, 99,
  104, 32, 110, 101, 119, 32, 99, 101, 108, 108, 115, 32, 99, 114, 101, 97,
  116, 101, 100, 92, 110, 10, 45, 45, 45, 45, 32, 115, 105, 109, 117, 108,
  116, 97, 110, 101, 111, 117, 115, 108, 121, 32, 97, 110, 100, 32, 115, 112,
  111, 110, 116, 97, 110, 101, 111, 117, 115, 108, 121, 32, 98, 121, 32, 121,
  111, 117, 114, 32, 115, 121, 115, 116, 101, 109, 44, 32, 121, 111, 117, 92,
  110, 10, 45, 45, 45, 45, 32, 103, 97, 105, 110, 32, 109, 111, 114, 101,
  32, 110, 101, 119, 32, 99, 101, 108, 108, 115, 32, 116, 111, 32, 115, 99,
  97, 116, 116, 101, 114, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10,
  45, 45, 45, 45, 32, 76, 101, 102, 116, 32, 109, 111, 117, 115, 101, 32,
  98, 117, 116, 116, 111, 110, 32, 116, 111, 32, 115, 99, 97, 116, 116, 101,
  114, 32, 99, 101, 108, 108, 115, 32, 105, 110, 32, 115, 116, 111, 99, 107,
  46, 92, 110, 10, 45, 45, 45, 45, 32, 82, 105, 103, 104, 116, 32, 109,
  111, 117, 115, 101, 32, 98, 117, 116, 116, 111, 110, 32, 116, 111, 32, 114,
  101, 115, 101, 116, 32, 103, 97, 109, 101, 46, 92, 110, 10, 45, 45, 45,
  45, 32, 75, 101, 121, 32, 39, 83, 39, 32, 116, 111, 32, 115, 97, 118,
  101, 32, 115, 110, 97, 112, 115, 104, 111, 116, 32, 111, 102, 32, 116, 104,
  101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 118, 105, 101, 119, 46, 92,
  110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 69, 83, 67,
  39, 32, 111, 114, 32, 39, 81, 39, 32, 116, 111, 32, 101, 120, 105, 116,
  46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 10,
  45, 105, 91, 48, 93, 32, 57, 48, 44, 57, 48, 44, 49, 44, 49, 44,
  48, 10, 45, 105, 91, 49, 93, 32, 91, 48, 93, 32, 45, 102, 91, 49,
  93, 32, 48, 10, 45, 105, 91, 50, 93, 32, 52, 48, 48, 44, 52, 48,
  48, 44, 49, 44, 51, 10, 45, 105, 91, 51, 93, 32, 49, 10, 105, 116,
  101, 114, 97, 116, 105, 111, 110, 61, 48, 10, 115, 99, 111, 114, 101, 61,
  48, 10, 98, 101, 115, 116, 115, 99, 111, 114, 101, 61, 48, 10, 115, 116,
  111, 99, 107, 61, 53, 48, 48, 10, 45, 119, 91, 48, 93, 32, 52, 48,
  48, 44, 52, 48, 48, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93,
  32, 84, 104, 101, 32, 103, 97, 109, 101, 32, 111, 102, 32, 108, 105, 102,
  101, 34, 10, 45, 99, 117, 114, 115, 111, 114, 91, 48, 93, 32, 48, 10,
  45, 100, 111, 10, 40, 49, 44, 49, 44, 49, 59, 49, 44, 48, 44, 49,
  59, 49, 44, 49, 44, 49, 41, 32, 45, 45, 99, 111, 114, 114, 101, 108,
  97, 116, 101, 91, 48, 93, 32, 91, 45, 49, 93, 44, 48, 32, 45, 114,
  109, 91, 45, 50, 93, 10, 45, 45, 116, 50, 91, 45, 49, 93, 32, 50,
  44, 50, 32, 45, 97, 110, 100, 91, 45, 49, 93, 32, 91, 48, 93, 32,
  45, 116, 50, 91, 45, 50, 93, 32, 51, 44, 51, 32, 45, 111, 114, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 114, 118, 91, 48, 44, 45, 49, 93,
  10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 120, 125, 62, 48, 34, 32,
  38, 38, 32, 34, 64, 123, 33, 44, 98, 125, 61, 61, 49, 34, 32, 38,
  38, 32, 34, 36, 115, 116, 111, 99, 107, 62, 48, 125, 10, 110, 98, 61,
  123, 63, 42, 55, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 110,
  98, 10, 120, 61, 123, 64, 123, 33, 44, 120, 125, 47, 64, 123, 33, 44,
  119, 125, 42, 64, 123, 48, 44, 119, 125, 43, 63, 40, 45, 52, 44, 52,
  41, 125, 10, 121, 61, 123, 64, 123, 33, 44, 121, 125, 47, 64, 123, 33,
  44, 104, 125, 42, 64, 123, 48, 44, 104, 125, 43, 63, 40, 45, 51, 44,
  51, 41, 125, 10, 45, 61, 91, 48, 93, 32, 49, 44, 36, 120, 44, 36,
  121, 10, 45, 61, 91, 49, 93, 32, 36, 105, 116, 101, 114, 97, 116, 105,
  111, 110, 44, 36, 120, 44, 36, 121, 10, 45, 112, 111, 105, 110, 116, 91,
  50, 93, 32, 123, 36, 120, 42, 64, 123, 50, 44, 119, 125, 47, 64, 123,
  48, 44, 119, 125, 125, 44, 123, 36, 121, 42, 64, 123, 50, 44, 104, 125,
  47, 64, 123, 48, 44, 104, 125, 125, 44, 48, 44, 48, 46, 56, 44, 50,
  53, 53, 10, 45, 100, 111, 110, 101, 10, 115, 116, 111, 99, 107, 61, 123,
  114, 111, 117, 110, 100, 40, 109, 97, 120, 40, 48, 44, 36, 115, 116, 111,
  99, 107, 45, 36, 110, 98, 41, 41, 125, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 45, 91, 45, 49, 93, 32, 91, 48, 93, 32, 45, 42, 91, 45,
  49, 93, 32, 45, 49, 10, 115, 116, 111, 99, 107, 61, 123, 36, 115, 116,
  111, 99, 107, 45, 50, 42, 40, 109, 105, 110, 40, 48, 44, 105, 110, 116,
  40, 64, 123, 45, 49, 44, 43, 125, 47, 49, 54, 42, 36, 115, 99, 111,
  114, 101, 47, 49, 53, 48, 41, 41, 41, 125, 10, 45, 43, 91, 49, 93,
  32, 91, 48, 93, 10, 45, 109, 105, 110, 91, 45, 49, 93, 32, 48, 32,
  45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 42, 91, 49, 44, 45, 49,
  93, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 98, 125, 61, 61, 50,
  125, 10, 45, 102, 91, 48, 45, 50, 93, 32, 48, 32, 105, 116, 101, 114,
  97, 116, 105, 111, 110, 61, 48, 32, 115, 99, 111, 114, 101, 61, 48, 32,
  98, 101, 115, 116, 115, 99, 111, 114, 101, 61, 48, 32, 115, 116, 111, 99,
  107, 61, 53, 48, 48, 32, 45, 114, 109, 91, 51, 93, 32, 45, 105, 91,
  51, 93, 32, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 64, 123, 51, 44, 119, 125, 61, 61, 49, 125, 10, 45, 114, 109, 91,
  51, 93, 32, 45, 105, 91, 51, 93, 32, 123, 63, 40, 51, 44, 49, 50,
  41, 125, 44, 49, 44, 49, 44, 51, 44, 63, 40, 49, 48, 48, 44, 50,
  53, 53, 41, 10, 45, 114, 91, 51, 93, 32, 123, 63, 40, 49, 48, 48,
  44, 51, 48, 48, 41, 125, 37, 44, 49, 44, 49, 44, 51, 44, 52, 10,
  45, 112, 111, 105, 110, 116, 91, 51, 93, 32, 48, 44, 48, 44, 48, 44,
  49, 44, 48, 10, 45, 114, 91, 51, 93, 32, 123, 63, 40, 49, 48, 48,
  44, 54, 48, 48, 41, 125, 37, 44, 49, 44, 49, 44, 51, 44, 53, 32,
  45, 99, 91, 51, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 45, 114, 91, 49, 93, 32, 64, 123, 50, 44, 119, 125,
  44, 64, 123, 50, 44, 104, 125, 32, 45, 97, 110, 100, 91, 45, 49, 93,
  32, 55, 32, 45, 98, 91, 45, 49, 93, 32, 123, 49, 43, 36, 115, 99,
  111, 114, 101, 42, 48, 46, 48, 53, 125, 10, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 64, 123, 51, 44, 119, 125, 32, 45, 109, 97, 112, 91, 45,
  49, 93, 32, 91, 51, 93, 32, 45, 42, 91, 45, 49, 93, 32, 48, 46,
  49, 32, 45, 43, 91, 50, 44, 45, 49, 93, 32, 45, 47, 91, 50, 93,
  32, 49, 46, 49, 10, 91, 50, 93, 32, 45, 105, 102, 32, 123, 64, 123,
  33, 44, 120, 125, 62, 48, 125, 10, 111, 112, 97, 99, 61, 123, 48, 46,
  55, 42, 109, 105, 110, 40, 49, 44, 36, 115, 116, 111, 99, 107, 47, 53,
  48, 48, 41, 125, 32, 114, 61, 123, 109, 105, 110, 40, 53, 48, 48, 44,
  36, 115, 116, 111, 99, 107, 41, 42, 99, 111, 115, 40, 36, 105, 116, 101,
  114, 97, 116, 105, 111, 110, 41, 47, 49, 48, 48, 125, 10, 45, 101, 108,
  108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 64, 123, 33, 44, 120, 125,
  44, 64, 123, 33, 44, 121, 125, 44, 123, 49, 53, 43, 36, 114, 125, 44,
  123, 49, 53, 43, 36, 114, 125, 44, 48, 44, 36, 111, 112, 97, 99, 44,
  48, 44, 49, 57, 54, 44, 48, 10, 45, 101, 108, 108, 105, 112, 115, 101,
  91, 45, 49, 93, 32, 64, 123, 33, 44, 120, 125, 44, 64, 123, 33, 44,
  121, 125, 44, 123, 49, 48, 43, 36, 114, 125, 44, 123, 49, 48, 43, 36,
  114, 125, 44, 48, 44, 36, 111, 112, 97, 99, 44, 51, 50, 44, 54, 52,
  44, 49, 54, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93,
  32, 64, 123, 33, 44, 120, 125, 44, 64, 123, 33, 44, 121, 125, 44, 123,
  53, 43, 36, 114, 125, 44, 123, 53, 43, 36, 114, 125, 44, 48, 44, 36,
  111, 112, 97, 99, 44, 50, 53, 53, 44, 50, 51, 48, 44, 48, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 116, 91, 45, 49, 93, 32, 34, 76, 105,
  118, 105, 110, 103, 32, 99, 101, 108, 108, 115, 32, 58, 32, 34, 36, 115,
  99, 111, 114, 101, 34, 92, 110, 34, 92, 10, 34, 83, 116, 111, 99, 107,
  32, 58, 32, 34, 36, 115, 116, 111, 99, 107, 34, 92, 110, 34, 92, 10,
  34, 83, 99, 111, 114, 101, 32, 58, 32, 34, 36, 98, 101, 115, 116, 115,
  99, 111, 114, 101, 44, 53, 44, 51, 44, 50, 50, 44, 48, 46, 55, 44,
  50, 53, 53, 10, 45, 119, 91, 45, 49, 93, 32, 64, 123, 33, 44, 119,
  125, 44, 64, 123, 33, 44, 104, 125, 10, 45, 105, 102, 32, 64, 123, 33,
  44, 83, 125, 32, 45, 111, 91, 45, 49, 93, 32, 103, 109, 105, 99, 95,
  108, 105, 102, 101, 46, 112, 110, 103, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 33, 40, 36,
  105, 116, 101, 114, 97, 116, 105, 111, 110, 37, 49, 48, 41, 125, 32, 115,
  99, 111, 114, 101, 61, 64, 123, 48, 44, 43, 125, 32, 98, 101, 115, 116,
  115, 99, 111, 114, 101, 61, 123, 109, 97, 120, 40, 36, 115, 99, 111, 114,
  101, 44, 36, 98, 101, 115, 116, 115, 99, 111, 114, 101, 41, 125, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 119, 97, 105, 116, 32, 54, 48, 10, 105,
  116, 101, 114, 97, 116, 105, 111, 110, 61, 123, 36, 105, 116, 101, 114, 97,
  116, 105, 111, 110, 43, 49, 125, 10, 45, 119, 104, 105, 108, 101, 32, 123,
  64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67,
  125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125, 10,
  45, 114, 109, 91, 48, 45, 51, 93, 32, 45, 119, 32, 48, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 120, 95, 108, 105, 103, 104,
  116, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 76, 97, 117, 110, 99,
  104, 32, 116, 104, 101, 32, 108, 105, 103, 104, 116, 32, 101, 102, 102, 101,
  99, 116, 32, 100, 101, 109, 111, 46, 10, 120, 95, 108, 105, 103, 104, 116,
  32, 58, 10, 45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45,
  45, 45, 32, 76, 105, 103, 104, 116, 32, 101, 102, 102, 101, 99, 116, 32,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10,
  45, 45, 45, 45, 32, 77, 111, 118, 101, 32, 108, 105, 103, 104, 116, 32,
  112, 111, 115, 105, 116, 105, 111, 110, 32, 119, 105, 116, 104, 32, 109, 111,
  117, 115, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 77, 111, 117, 115,
  101, 32, 98, 117, 116, 116, 111, 110, 115, 32, 102, 97, 100, 101, 32, 108,
  105, 103, 104, 116, 32, 105, 110, 47, 111, 117, 116, 46, 92, 110, 10, 45,
  45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76, 43, 68,
  39, 32, 116, 111, 32, 100, 111, 117, 98, 108, 101, 32, 119, 105, 110, 100,
  111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32,
  75, 101, 121, 115, 32, 39, 67, 84, 82, 76, 43, 67, 39, 32, 116, 111,
  32, 114, 101, 115, 101, 116, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105,
  122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32,
  39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81, 39, 32, 116, 111, 32,
  101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 10, 48,
  32, 45, 116, 91, 45, 49, 93, 32, 34, 32, 32, 32, 32, 71, 39, 77,
  73, 67, 92, 110, 76, 105, 103, 104, 116, 32, 101, 102, 102, 101, 99, 116,
  34, 44, 48, 44, 48, 44, 53, 55, 44, 49, 44, 50, 53, 53, 32, 45,
  101, 120, 112, 97, 110, 100, 95, 120, 121, 91, 45, 49, 93, 32, 49, 53,
  44, 48, 32, 45, 98, 91, 45, 49, 93, 32, 51, 10, 91, 45, 49, 93,
  32, 45, 110, 91, 45, 50, 93, 32, 48, 44, 49, 32, 45, 114, 91, 45,
  50, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 51,
  10, 45, 115, 104, 91, 45, 50, 93, 32, 48, 44, 48, 32, 45, 42, 91,
  45, 49, 93, 32, 49, 50, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 115, 104, 91, 45, 50, 93, 32, 49, 44, 49, 32, 45, 42, 91, 45,
  49, 93, 32, 55, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115,
  104, 91, 45, 50, 93, 32, 48, 44, 53, 48, 37, 44, 48, 44, 50, 32,
  45, 42, 91, 45, 49, 93, 32, 49, 50, 48, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 50, 53, 37, 44, 50, 53, 37, 44, 49, 44, 49, 32, 45,
  114, 97, 110, 100, 91, 45, 49, 93, 32, 45, 50, 48, 44, 50, 48, 32,
  45, 115, 109, 111, 111, 116, 104, 91, 45, 49, 93, 32, 49, 48, 44, 48,
  44, 49, 44, 49, 44, 52, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 44, 51, 32, 45, 98, 91, 45, 49, 93, 32, 51, 32, 45, 110,
  91, 45, 49, 93, 32, 45, 54, 48, 44, 54, 48, 10, 45, 43, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 103, 91, 45, 49, 93, 32, 120, 121, 32,
  45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 110, 91, 45,
  49, 93, 32, 45, 49, 53, 48, 44, 49, 53, 48, 10, 45, 119, 91, 93,
  32, 123, 49, 46, 53, 42, 64, 123, 45, 50, 44, 119, 125, 125, 44, 123,
  49, 46, 53, 42, 64, 123, 45, 50, 44, 104, 125, 125, 44, 48, 44, 34,
  91, 71, 39, 77, 73, 67, 93, 32, 76, 105, 103, 104, 116, 32, 101, 102,
  102, 101, 99, 116, 34, 10, 45, 99, 117, 114, 115, 111, 114, 91, 48, 93,
  32, 48, 10, 108, 105, 103, 104, 116, 61, 55, 48, 10, 53, 49, 50, 44,
  53, 49, 50, 32, 45, 103, 97, 117, 115, 115, 105, 97, 110, 91, 45, 49,
  93, 32, 36, 108, 105, 103, 104, 116, 32, 45, 110, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 10, 116, 61, 48, 10, 45, 100, 111, 10, 45, 105,
  102, 32, 123, 64, 123, 33, 44, 120, 125, 62, 61, 48, 125, 10, 88, 61,
  123, 114, 111, 117, 110, 100, 40, 40, 119, 45, 64, 123, 33, 44, 120, 125,
  41, 47, 50, 41, 125, 10, 89, 61, 123, 114, 111, 117, 110, 100, 40, 40,
  104, 45, 64, 123, 33, 44, 121, 125, 41, 47, 50, 41, 125, 10, 45, 101,
  108, 115, 101, 10, 88, 61, 123, 114, 111, 117, 110, 100, 40, 40, 119, 45,
  64, 123, 45, 50, 44, 119, 125, 42, 40, 49, 43, 99, 111, 115, 40, 50,
  42, 36, 116, 41, 41, 41, 47, 50, 41, 125, 10, 89, 61, 123, 114, 111,
  117, 110, 100, 40, 40, 104, 45, 64, 123, 45, 50, 44, 104, 125, 42, 40,
  49, 43, 115, 105, 110, 40, 50, 46, 53, 42, 36, 116, 41, 41, 41, 47,
  50, 41, 125, 10, 116, 61, 123, 36, 116, 43, 48, 46, 48, 50, 125, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44,
  98, 125, 38, 49, 125, 32, 108, 105, 103, 104, 116, 61, 123, 109, 105, 110,
  40, 50, 48, 48, 44, 36, 108, 105, 103, 104, 116, 43, 49, 48, 41, 125,
  32, 45, 103, 97, 117, 115, 115, 105, 97, 110, 91, 45, 49, 93, 32, 36,
  108, 105, 103, 104, 116, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64,
  123, 33, 44, 98, 125, 38, 50, 125, 32, 108, 105, 103, 104, 116, 61, 123,
  109, 97, 120, 40, 49, 48, 44, 36, 108, 105, 103, 104, 116, 45, 49, 48,
  41, 125, 32, 45, 103, 97, 117, 115, 115, 105, 97, 110, 91, 45, 49, 93,
  32, 36, 108, 105, 103, 104, 116, 32, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 122, 91,
  45, 49, 93, 32, 36, 88, 44, 36, 89, 44, 123, 36, 88, 43, 64, 123,
  45, 50, 44, 119, 125, 45, 49, 125, 44, 123, 36, 89, 43, 64, 123, 45,
  50, 44, 104, 125, 45, 49, 125, 10, 45, 119, 97, 114, 112, 91, 45, 49,
  93, 32, 91, 45, 51, 93, 44, 49, 44, 48, 44, 49, 10, 45, 114, 91,
  45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44,
  51, 32, 45, 43, 91, 45, 49, 93, 32, 91, 45, 52, 93, 32, 45, 99,
  91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 119, 91, 45, 49,
  93, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76,
  69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 68, 125, 125, 32, 45, 119,
  91, 93, 32, 123, 51, 42, 119, 125, 44, 123, 51, 42, 104, 125, 10, 45,
  101, 108, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69,
  70, 84, 125, 38, 38, 64, 123, 33, 44, 67, 125, 125, 32, 45, 119, 91,
  93, 32, 123, 49, 46, 53, 42, 119, 125, 44, 123, 49, 46, 53, 42, 104,
  125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 105, 102, 32, 123, 64, 123, 33, 44, 120, 125, 62, 61, 48, 34,
  32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 98, 125, 125, 32, 45, 119,
  97, 105, 116, 32, 45, 101, 108, 115, 101, 32, 45, 119, 97, 105, 116, 32,
  50, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 119, 104, 105, 108, 101,
  32, 123, 64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69,
  83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125,
  125, 10, 45, 119, 91, 93, 32, 48, 32, 45, 114, 109, 91, 45, 51, 45,
  45, 49, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  120, 95, 109, 97, 110, 100, 101, 108, 98, 114, 111, 116, 32, 58, 32, 95,
  106, 117, 108, 105, 97, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 44,
  95, 99, 48, 114, 44, 95, 99, 48, 105, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 76, 97, 117, 110, 99, 104, 32, 77, 97, 110, 100, 101, 108,
  98, 114, 111, 116, 47, 74, 117, 108, 105, 97, 32, 101, 120, 112, 108, 111,
  114, 101, 114, 46, 10, 120, 95, 109, 97, 110, 100, 101, 108, 98, 114, 111,
  116, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 125,
  44, 36, 123, 50, 61, 48, 46, 51, 49, 55, 125, 44, 36, 123, 51, 61,
  48, 46, 48, 51, 125, 10, 45, 101, 91, 93, 32, 34, 92, 110, 10, 45,
  45, 45, 45, 45, 45, 32, 77, 97, 110, 100, 101, 108, 98, 114, 111, 116,
  47, 74, 117, 108, 105, 97, 32, 101, 120, 112, 108, 111, 114, 101, 114, 32,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32,
  83, 101, 108, 101, 99, 116, 32, 122, 111, 111, 109, 105, 110, 103, 32, 114,
  101, 103, 105, 111, 110, 32, 119, 105, 116, 104, 32, 109, 111, 117, 115, 101,
  46, 92, 110, 10, 45, 45, 45, 45, 32, 67, 108, 105, 99, 107, 32, 111,
  110, 99, 101, 32, 116, 111, 32, 114, 101, 115, 101, 116, 32, 122, 111, 111,
  109, 32, 102, 97, 99, 116, 111, 114, 46, 92, 110, 10, 45, 45, 45, 45,
  32, 75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39,
  81, 39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45,
  45, 45, 32, 75, 101, 121, 32, 39, 67, 39, 32, 116, 111, 32, 112, 114,
  105, 110, 116, 32, 99, 117, 114, 114, 101, 110, 116, 32, 102, 114, 97, 99,
  116, 97, 108, 32, 99, 111, 111, 114, 100, 105, 110, 97, 116, 101, 115, 46,
  92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 34, 10, 45, 118,
  32, 45, 10, 45, 114, 109, 32, 45, 119, 32, 53, 49, 50, 44, 53, 49,
  50, 44, 48, 32, 45, 95, 120, 95, 109, 97, 110, 100, 101, 108, 98, 114,
  111, 116, 95, 99, 111, 111, 114, 100, 115, 32, 36, 49, 32, 45, 95, 120,
  95, 109, 97, 110, 100, 101, 108, 98, 114, 111, 116, 95, 112, 97, 108, 101,
  116, 116, 101, 10, 45, 100, 111, 10, 115, 105, 122, 61, 123, 109, 105, 110,
  40, 64, 123, 33, 44, 119, 125, 44, 64, 123, 33, 44, 104, 125, 41, 125,
  10, 36, 115, 105, 122, 44, 36, 115, 105, 122, 32, 45, 109, 97, 110, 100,
  101, 108, 98, 114, 111, 116, 91, 45, 49, 93, 32, 64, 48, 44, 50, 53,
  54, 44, 36, 49, 44, 123, 105, 102, 40, 36, 49, 44, 36, 50, 44, 48,
  41, 125, 44, 123, 105, 102, 40, 36, 49, 44, 36, 51, 44, 48, 41, 125,
  32, 45, 109, 97, 112, 91, 45, 49, 93, 32, 91, 49, 93, 10, 45, 105,
  102, 32, 36, 49, 32, 45, 119, 91, 45, 49, 93, 32, 36, 115, 105, 122,
  44, 36, 115, 105, 122, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93,
  32, 74, 117, 108, 105, 97, 32, 115, 101, 116, 32, 99, 61, 40, 34, 64,
  123, 48, 44, 48, 125, 34, 44, 34, 64, 123, 48, 44, 49, 125, 34, 41,
  45, 40, 34, 64, 123, 48, 44, 50, 125, 34, 44, 34, 64, 123, 48, 44,
  51, 125, 34, 41, 44, 32, 99, 48, 61, 40, 36, 50, 44, 36, 51, 41,
  34, 10, 45, 101, 108, 115, 101, 32, 45, 119, 91, 45, 49, 93, 32, 36,
  115, 105, 122, 44, 36, 115, 105, 122, 44, 48, 44, 34, 91, 71, 39, 77,
  73, 67, 93, 32, 77, 97, 110, 100, 101, 108, 98, 114, 111, 116, 32, 115,
  101, 116, 32, 99, 61, 40, 34, 64, 123, 48, 44, 48, 125, 34, 44, 34,
  64, 123, 48, 44, 49, 125, 34, 41, 45, 40, 34, 64, 123, 48, 44, 50,
  125, 34, 44, 34, 64, 123, 48, 44, 51, 125, 34, 41, 34, 32, 45, 101,
  110, 100, 105, 102, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125,
  32, 45, 115, 101, 108, 101, 99, 116, 91, 45, 49, 93, 32, 50, 10, 45,
  105, 102, 32, 123, 64, 123, 45, 49, 44, 48, 125, 62, 48, 125, 10, 77,
  61, 123, 109, 97, 120, 40, 64, 123, 45, 49, 44, 51, 125, 45, 64, 123,
  45, 49, 44, 48, 125, 44, 64, 123, 45, 49, 44, 52, 125, 45, 64, 123,
  45, 49, 44, 49, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 77, 60,
  53, 125, 32, 45, 95, 120, 95, 109, 97, 110, 100, 101, 108, 98, 114, 111,
  116, 95, 99, 111, 111, 114, 100, 115, 32, 36, 49, 32, 45, 114, 109, 91,
  49, 93, 32, 45, 95, 120, 95, 109, 97, 110, 100, 101, 108, 98, 114, 111,
  116, 95, 112, 97, 108, 101, 116, 116, 101, 32, 45, 109, 118, 91, 45, 49,
  93, 32, 49, 10, 45, 101, 108, 115, 101, 32, 40, 123, 64, 123, 48, 44,
  48, 125, 43, 64, 123, 45, 49, 44, 48, 125, 42, 40, 64, 123, 48, 44,
  50, 125, 45, 64, 123, 48, 44, 48, 125, 41, 47, 36, 119, 125, 59, 92,
  10, 123, 64, 123, 48, 44, 49, 125, 43, 64, 123, 45, 49, 44, 49, 125,
  42, 40, 64, 123, 48, 44, 51, 125, 45, 64, 123, 48, 44, 49, 125, 41,
  47, 36, 104, 125, 59, 92, 10, 123, 64, 123, 48, 44, 48, 125, 43, 40,
  64, 123, 45, 49, 44, 48, 125, 43, 36, 77, 41, 42, 40, 64, 123, 48,
  44, 50, 125, 45, 64, 123, 48, 44, 48, 125, 41, 47, 36, 119, 125, 59,
  92, 10, 123, 64, 123, 48, 44, 49, 125, 43, 40, 64, 123, 45, 49, 44,
  49, 125, 43, 36, 77, 41, 42, 40, 64, 123, 48, 44, 51, 125, 45, 64,
  123, 48, 44, 49, 125, 41, 47, 36, 104, 125, 41, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 114, 109, 91, 48, 93, 32, 45, 109, 118, 91, 45, 49,
  93, 32, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 67, 125, 125, 10,
  45, 105, 102, 32, 36, 49, 32, 45, 118, 32, 43, 32, 45, 101, 91, 48,
  45, 45, 52, 93, 32, 34, 74, 117, 108, 105, 97, 32, 115, 101, 116, 44,
  32, 97, 116, 32, 99, 32, 61, 32, 40, 34, 64, 123, 48, 44, 48, 45,
  49, 125, 34, 41, 45, 40, 34, 64, 123, 48, 44, 50, 45, 51, 125, 34,
  41, 44, 32, 119, 105, 116, 104, 32, 99, 48, 32, 61, 32, 40, 36, 50,
  44, 36, 51, 41, 46, 34, 32, 45, 118, 32, 45, 10, 45, 101, 108, 115,
  101, 32, 45, 118, 32, 43, 32, 45, 101, 91, 48, 45, 45, 52, 93, 32,
  34, 77, 97, 110, 100, 101, 108, 98, 114, 111, 116, 32, 115, 101, 116, 44,
  32, 97, 116, 32, 99, 32, 61, 32, 40, 34, 64, 123, 48, 44, 48, 45,
  49, 125, 34, 41, 45, 40, 34, 64, 123, 48, 44, 50, 45, 51, 125, 34,
  41, 46, 34, 32, 45, 118, 32, 45, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 33, 64, 33, 34,
  32, 124, 124, 32, 34, 64, 123, 33, 44, 69, 83, 67, 125, 34, 32, 124,
  124, 32, 34, 64, 123, 33, 44, 81, 125, 125, 32, 45, 114, 109, 32, 45,
  119, 32, 48, 32, 45, 118, 32, 43, 32, 45, 114, 101, 116, 117, 114, 110,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 119, 97, 105, 116, 32, 45, 49,
  10, 45, 119, 104, 105, 108, 101, 32, 49, 10, 95, 120, 95, 109, 97, 110,
  100, 101, 108, 98, 114, 111, 116, 95, 99, 111, 111, 114, 100, 115, 32, 58,
  10, 45, 105, 102, 32, 36, 49, 32, 40, 45, 50, 59, 45, 50, 59, 50,
  59, 50, 41, 32, 45, 101, 108, 115, 101, 32, 40, 45, 50, 46, 49, 59,
  45, 49, 46, 53, 59, 49, 46, 50, 59, 49, 46, 53, 41, 32, 45, 101,
  110, 100, 105, 102, 10, 95, 120, 95, 109, 97, 110, 100, 101, 108, 98, 114,
  111, 116, 95, 112, 97, 108, 101, 116, 116, 101, 32, 58, 10, 54, 44, 49,
  44, 49, 44, 51, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 50,
  48, 44, 50, 53, 53, 32, 45, 114, 91, 45, 49, 93, 32, 51, 50, 44,
  49, 44, 49, 44, 51, 44, 51, 32, 45, 114, 91, 45, 49, 93, 32, 49,
  48, 50, 52, 44, 49, 44, 49, 44, 51, 44, 48, 44, 50, 32, 45, 61,
  91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 44, 48, 32, 45,
  61, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 44, 49, 32,
  45, 61, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 44, 50,
  10, 35, 64, 103, 109, 105, 99, 32, 120, 95, 109, 101, 116, 97, 98, 97,
  108, 108, 115, 51, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 76,
  97, 117, 110, 99, 104, 32, 116, 104, 101, 32, 51, 100, 32, 109, 101, 116,
  97, 98, 97, 108, 108, 115, 32, 100, 101, 109, 111, 46, 10, 120, 95, 109,
  101, 116, 97, 98, 97, 108, 108, 115, 51, 100, 32, 58, 10, 45, 101, 91,
  93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 51, 100, 32,
  109, 101, 116, 97, 98, 97, 108, 108, 115, 32, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32,
  77, 111, 117, 115, 101, 32, 98, 117, 116, 116, 111, 110, 32, 111, 114, 32,
  39, 83, 80, 65, 67, 69, 39, 32, 107, 101, 121, 32, 116, 111, 32, 115,
  119, 105, 116, 99, 104, 32, 114, 101, 110, 100, 101, 114, 105, 110, 103, 32,
  109, 111, 100, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121,
  115, 32, 39, 67, 84, 82, 76, 43, 68, 39, 32, 116, 111, 32, 100, 111,
  117, 98, 108, 101, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101,
  46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67,
  84, 82, 76, 43, 67, 39, 32, 116, 111, 32, 114, 101, 115, 101, 116, 32,
  119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45,
  45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32, 111,
  114, 32, 39, 81, 39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92, 110,
  10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 34, 10, 45, 118, 32, 45, 32, 45, 108, 91, 93, 10, 49,
  48, 48, 44, 49, 48, 48, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49,
  93, 32, 49, 48, 48, 44, 49, 32, 45, 112, 108, 97, 115, 109, 97, 91,
  45, 49, 93, 32, 49, 44, 48, 44, 49, 48, 32, 45, 114, 91, 45, 49,
  93, 32, 53, 49, 50, 44, 51, 50, 48, 44, 49, 44, 51, 32, 45, 110,
  91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 98, 91, 45, 49, 93, 32,
  52, 44, 48, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  10, 45, 109, 105, 120, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45,
  49, 93, 32, 40, 48, 46, 55, 44, 48, 44, 48, 59, 48, 44, 48, 46,
  57, 44, 48, 59, 48, 44, 48, 44, 49, 46, 50, 41, 32, 45, 99, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 108, 51, 100, 10, 48,
  10, 50, 52, 44, 50, 52, 44, 50, 52, 44, 49, 44, 39, 88, 61, 120,
  45, 119, 47, 50, 59, 89, 61, 121, 45, 104, 47, 50, 59, 90, 61, 122,
  45, 100, 47, 50, 59, 101, 120, 112, 40, 45, 40, 88, 42, 88, 43, 89,
  42, 89, 43, 90, 42, 90, 41, 47, 49, 48, 48, 41, 39, 10, 55, 50,
  44, 55, 50, 44, 55, 50, 32, 77, 61, 56, 32, 109, 111, 100, 101, 61,
  53, 10, 115, 48, 61, 68, 111, 116, 115, 32, 115, 49, 61, 87, 105, 114,
  101, 102, 114, 97, 109, 101, 32, 115, 50, 61, 70, 108, 97, 116, 32, 115,
  51, 61, 70, 108, 97, 116, 45, 115, 104, 97, 100, 101, 100, 32, 115, 52,
  61, 71, 111, 117, 114, 97, 117, 100, 45, 115, 104, 97, 100, 101, 100, 32,
  115, 53, 61, 80, 104, 111, 110, 103, 45, 115, 104, 97, 100, 101, 100, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 36, 77, 32, 102, 120, 36, 62, 61,
  123, 103, 42, 49, 46, 53, 125, 32, 102, 121, 36, 62, 61, 123, 103, 42,
  49, 46, 53, 125, 32, 102, 122, 36, 62, 61, 123, 103, 42, 49, 46, 53,
  125, 32, 45, 100, 111, 110, 101, 10, 45, 119, 91, 48, 93, 32, 45, 49,
  44, 45, 49, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 51,
  100, 32, 109, 101, 116, 97, 98, 97, 108, 108, 115, 34, 10, 45, 100, 111,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 77, 10, 120, 36, 62, 61,
  123, 119, 47, 50, 43, 48, 46, 53, 42, 40, 119, 45, 64, 123, 50, 44,
  119, 125, 45, 52, 41, 42, 99, 111, 115, 40, 36, 123, 102, 120, 36, 62,
  125, 42, 64, 124, 41, 125, 10, 121, 36, 62, 61, 123, 104, 47, 50, 43,
  48, 46, 53, 42, 40, 104, 45, 64, 123, 50, 44, 104, 125, 45, 52, 41,
  42, 115, 105, 110, 40, 36, 123, 102, 121, 36, 62, 125, 42, 64, 124, 41,
  125, 10, 122, 36, 62, 61, 123, 100, 47, 50, 43, 48, 46, 53, 42, 40,
  100, 45, 64, 123, 50, 44, 100, 125, 45, 52, 41, 42, 115, 105, 110, 40,
  36, 123, 102, 122, 36, 62, 125, 42, 64, 124, 41, 125, 10, 45, 100, 111,
  110, 101, 10, 45, 102, 91, 51, 93, 32, 48, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 36, 77, 32, 45, 106, 91, 51, 93, 32, 91, 50, 93, 44,
  123, 36, 123, 120, 36, 62, 125, 45, 64, 123, 50, 44, 119, 47, 50, 125,
  125, 44, 123, 36, 123, 121, 36, 62, 125, 45, 64, 123, 50, 44, 104, 47,
  50, 125, 125, 44, 123, 36, 123, 122, 36, 62, 125, 45, 64, 123, 50, 44,
  100, 47, 50, 125, 125, 44, 48, 44, 45, 49, 32, 45, 100, 111, 110, 101,
  10, 45, 45, 114, 91, 51, 93, 32, 50, 52, 44, 50, 52, 44, 50, 52,
  44, 49, 44, 50, 32, 45, 105, 115, 111, 115, 117, 114, 102, 97, 99, 101,
  51, 100, 91, 45, 49, 93, 32, 48, 46, 52, 32, 45, 45, 51, 100, 91,
  45, 49, 93, 32, 49, 50, 44, 49, 50, 44, 49, 50, 32, 45, 42, 51,
  100, 91, 45, 49, 93, 32, 49, 51, 32, 45, 114, 118, 51, 100, 91, 45,
  49, 93, 10, 45, 114, 51, 100, 91, 45, 49, 93, 32, 49, 44, 50, 44,
  49, 44, 123, 49, 48, 48, 42, 64, 124, 125, 10, 78, 61, 123, 105, 91,
  55, 93, 125, 32, 40, 50, 53, 53, 44, 50, 53, 53, 44, 49, 53, 48,
  59, 50, 48, 48, 44, 57, 54, 44, 49, 54, 52, 59, 53, 48, 44, 49,
  53, 48, 44, 50, 51, 48, 41, 32, 45, 114, 91, 45, 49, 93, 32, 51,
  44, 36, 78, 44, 49, 44, 49, 44, 51, 32, 45, 121, 91, 45, 49, 93,
  32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 123,
  64, 123, 45, 50, 44, 104, 125, 45, 52, 42, 36, 78, 125, 10, 45, 105,
  102, 32, 123, 33, 36, 109, 111, 100, 101, 125, 32, 45, 99, 105, 114, 99,
  108, 101, 115, 51, 100, 91, 45, 50, 93, 32, 52, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 33, 64, 123, 49, 44, 119, 125, 125,
  10, 48, 32, 45, 116, 101, 120, 116, 91, 45, 49, 93, 32, 36, 123, 115,
  36, 109, 111, 100, 101, 125, 44, 53, 44, 53, 44, 50, 52, 44, 48, 46,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 98,
  91, 45, 49, 93, 32, 48, 46, 55, 32, 45, 110, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 10, 45, 45, 100, 105, 108, 97, 116, 101, 91, 45,
  49, 93, 32, 51, 32, 45, 45, 106, 91, 48, 93, 32, 91, 45, 50, 93,
  44, 53, 44, 51, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 44,
  50, 53, 53, 32, 45, 109, 118, 91, 45, 49, 93, 32, 49, 32, 45, 114,
  109, 91, 50, 44, 45, 50, 44, 45, 49, 93, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 49, 93, 32,
  91, 45, 50, 93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 49,
  44, 123, 105, 102, 40, 33, 36, 109, 111, 100, 101, 44, 51, 44, 36, 109,
  111, 100, 101, 41, 125, 44, 48, 44, 48, 44, 51, 48, 48, 44, 48, 44,
  48, 44, 45, 53, 48, 48, 44, 48, 46, 49, 44, 49, 46, 53, 10, 45,
  119, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 67,
  84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 68, 125,
  125, 32, 45, 119, 91, 93, 32, 123, 50, 42, 119, 125, 44, 123, 50, 42,
  104, 125, 32, 45, 101, 108, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84,
  82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 67, 125, 125,
  32, 45, 119, 91, 93, 32, 123, 119, 125, 44, 123, 104, 125, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 51, 45, 45, 49, 93, 32,
  45, 119, 97, 105, 116, 32, 50, 48, 10, 45, 105, 102, 32, 123, 64, 123,
  33, 44, 98, 125, 124, 124, 64, 123, 33, 44, 83, 80, 65, 67, 69, 125,
  125, 32, 109, 111, 100, 101, 61, 123, 40, 36, 109, 111, 100, 101, 43, 105,
  102, 40, 64, 123, 33, 44, 98, 125, 38, 50, 44, 45, 49, 44, 49, 41,
  41, 37, 54, 125, 32, 45, 119, 97, 105, 116, 32, 45, 49, 32, 45, 114,
  109, 91, 49, 93, 32, 45, 105, 91, 49, 93, 32, 48, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34, 32,
  38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67, 125, 34, 32, 38,
  38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125, 10, 45, 114, 109, 32,
  45, 119, 32, 48, 32, 45, 101, 110, 100, 108, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 120, 95, 109, 105, 110, 101, 115, 119, 101,
  101, 112, 101, 114, 32, 58, 32, 56, 60, 61, 95, 119, 105, 100, 116, 104,
  61, 60, 50, 48, 44, 56, 60, 61, 95, 104, 101, 105, 103, 104, 116, 60,
  61, 50, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 76, 97, 117,
  110, 99, 104, 32, 116, 104, 101, 32, 77, 105, 110, 101, 115, 119, 101, 101,
  112, 101, 114, 32, 103, 97, 109, 101, 46, 10, 120, 95, 109, 105, 110, 101,
  115, 119, 101, 101, 112, 101, 114, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 34, 36, 123, 49, 61, 50, 48, 125, 62, 61, 56, 32, 38, 38, 32,
  36, 49, 60, 61, 51, 48, 32, 38, 38, 32, 36, 123, 50, 61, 36, 49,
  125, 62, 61, 56, 32, 38, 38, 32, 36, 50, 60, 61, 51, 48, 34, 10,
  45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32,
  77, 105, 110, 101, 115, 119, 101, 101, 112, 101, 114, 32, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110,
  10, 45, 45, 45, 45, 32, 84, 104, 101, 32, 103, 111, 97, 108, 32, 105,
  115, 32, 116, 111, 32, 99, 108, 101, 97, 114, 32, 116, 104, 101, 32, 109,
  105, 110, 101, 102, 105, 101, 108, 100, 32, 119, 105, 116, 104, 111, 117, 116,
  32, 100, 101, 116, 111, 110, 97, 116, 105, 110, 103, 32, 97, 92, 110, 10,
  45, 45, 45, 45, 32, 109, 105, 110, 101, 46, 92, 110, 10, 45, 45, 45,
  45, 92, 110, 10, 45, 45, 45, 45, 32, 76, 101, 102, 116, 32, 109, 111,
  117, 115, 101, 32, 98, 117, 116, 116, 111, 110, 32, 116, 111, 32, 116, 114,
  121, 32, 99, 108, 101, 97, 114, 105, 110, 103, 32, 111, 110, 101, 32, 115,
  113, 117, 97, 114, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 82, 105,
  103, 104, 116, 32, 109, 111, 117, 115, 101, 32, 98, 117, 116, 116, 111, 110,
  32, 116, 111, 32, 102, 108, 97, 103, 32, 111, 114, 32, 117, 110, 102, 108,
  97, 103, 32, 97, 32, 115, 113, 117, 97, 114, 101, 46, 92, 110, 10, 45,
  45, 45, 45, 32, 77, 105, 100, 100, 108, 101, 32, 109, 111, 117, 115, 101,
  32, 98, 117, 116, 116, 111, 110, 32, 116, 111, 32, 114, 101, 115, 101, 116,
  32, 109, 105, 110, 101, 32, 102, 105, 101, 108, 100, 46, 92, 110, 10, 45,
  45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32, 111,
  114, 32, 39, 81, 39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92, 110,
  10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 92, 110, 34, 10, 45, 118, 32, 45, 10, 36,
  49, 44, 36, 50, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32,
  51, 48, 44, 50, 32, 110, 98, 95, 109, 105, 110, 101, 115, 61, 64, 123,
  45, 49, 44, 43, 125, 32, 40, 49, 44, 49, 44, 49, 59, 49, 44, 48,
  44, 49, 59, 49, 44, 49, 44, 49, 41, 32, 45, 45, 99, 111, 110, 118,
  111, 108, 118, 101, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 32,
  45, 114, 109, 91, 45, 50, 93, 32, 45, 43, 91, 45, 49, 93, 32, 49,
  32, 45, 61, 61, 91, 45, 50, 93, 32, 48, 32, 45, 42, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 110, 109, 91, 45, 49, 93, 32, 102, 105, 101,
  108, 100, 10, 45, 100, 111, 32, 120, 61, 123, 114, 111, 117, 110, 100, 40,
  63, 40, 119, 45, 49, 41, 41, 125, 32, 121, 61, 123, 114, 111, 117, 110,
  100, 40, 63, 40, 104, 45, 49, 41, 41, 125, 32, 45, 119, 104, 105, 108,
  101, 32, 123, 105, 40, 36, 120, 44, 36, 121, 41, 33, 61, 49, 125, 10,
  45, 45, 102, 91, 102, 105, 101, 108, 100, 93, 32, 49, 49, 32, 45, 61,
  91, 45, 49, 93, 32, 49, 50, 44, 36, 120, 44, 36, 121, 32, 45, 110,
  109, 91, 45, 49, 93, 32, 98, 111, 97, 114, 100, 10, 50, 52, 44, 50,
  52, 44, 49, 44, 51, 44, 50, 48, 48, 32, 45, 102, 99, 91, 45, 49,
  93, 32, 50, 53, 53, 44, 49, 56, 48, 44, 49, 51, 48, 10, 45, 101,
  108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 49, 50, 44, 49, 50,
  44, 52, 44, 52, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 54,
  44, 49, 50, 44, 49, 56, 44, 49, 50, 32, 45, 108, 105, 110, 101, 91,
  45, 49, 93, 32, 49, 50, 44, 54, 44, 49, 50, 44, 49, 56, 32, 45,
  108, 105, 110, 101, 91, 45, 49, 93, 32, 49, 51, 44, 49, 48, 44, 49,
  52, 44, 49, 48, 44, 49, 44, 50, 53, 53, 32, 45, 108, 105, 110, 101,
  91, 45, 49, 93, 32, 49, 51, 44, 49, 49, 44, 49, 52, 44, 49, 49,
  44, 49, 44, 50, 53, 53, 10, 45, 122, 91, 45, 49, 93, 32, 49, 44,
  49, 44, 123, 119, 45, 50, 125, 44, 123, 104, 45, 50, 125, 32, 45, 102,
  114, 97, 109, 101, 91, 45, 49, 93, 32, 49, 44, 49, 44, 48, 10, 45,
  45, 102, 99, 91, 45, 49, 93, 32, 50, 51, 48, 44, 50, 53, 48, 44,
  50, 53, 53, 10, 45, 45, 116, 91, 45, 49, 93, 32, 34, 49, 34, 44,
  49, 48, 44, 53, 44, 49, 51, 44, 49, 44, 48, 44, 49, 57, 54, 44,
  48, 32, 45, 45, 116, 91, 45, 50, 93, 32, 34, 50, 34, 44, 57, 44,
  53, 44, 49, 51, 44, 49, 44, 48, 44, 49, 50, 56, 44, 48, 32, 45,
  45, 116, 91, 45, 51, 93, 32, 34, 51, 34, 44, 57, 44, 53, 44, 49,
  51, 44, 49, 44, 48, 44, 48, 44, 50, 53, 53, 10, 45, 45, 116, 91,
  45, 52, 93, 32, 34, 52, 34, 44, 57, 44, 53, 44, 49, 51, 44, 49,
  44, 50, 53, 53, 44, 48, 44, 48, 32, 45, 45, 116, 91, 45, 53, 93,
  32, 34, 53, 34, 44, 57, 44, 53, 44, 49, 51, 44, 49, 44, 50, 48,
  48, 44, 48, 44, 48, 32, 45, 45, 116, 91, 45, 54, 93, 32, 34, 54,
  34, 44, 57, 44, 53, 44, 49, 51, 44, 49, 44, 49, 53, 48, 44, 48,
  44, 48, 10, 45, 45, 116, 91, 45, 55, 93, 32, 34, 55, 34, 44, 57,
  44, 53, 44, 49, 51, 44, 49, 44, 49, 50, 56, 44, 48, 44, 48, 32,
  45, 45, 116, 91, 45, 56, 93, 32, 34, 56, 34, 44, 57, 44, 53, 44,
  49, 51, 44, 49, 44, 54, 52, 44, 48, 44, 48, 32, 45, 101, 114, 111,
  100, 101, 91, 45, 56, 45, 45, 49, 93, 32, 50, 10, 45, 45, 102, 91,
  45, 49, 93, 32, 39, 105, 102, 40, 120, 60, 61, 49, 124, 124, 121, 60,
  61, 49, 124, 124, 120, 62, 61, 119, 45, 50, 124, 124, 121, 62, 61, 104,
  45, 50, 44, 105, 102, 40, 120, 60, 121, 44, 49, 50, 56, 44, 50, 53,
  53, 41, 44, 49, 54, 48, 43, 50, 42, 40, 121, 43, 120, 41, 41, 39,
  10, 45, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 52,
  44, 49, 51, 44, 49, 53, 44, 49, 49, 44, 49, 53, 44, 54, 44, 49,
  56, 44, 49, 55, 44, 49, 56, 44, 49, 44, 48, 32, 45, 108, 105, 110,
  101, 91, 45, 49, 93, 32, 49, 50, 44, 49, 53, 44, 49, 50, 44, 54,
  44, 49, 44, 50, 53, 53, 44, 48, 44, 48, 32, 45, 112, 111, 108, 121,
  103, 111, 110, 91, 45, 49, 93, 32, 51, 44, 49, 50, 44, 54, 44, 54,
  44, 57, 44, 49, 50, 44, 49, 50, 44, 49, 44, 50, 50, 48, 44, 48,
  44, 48, 10, 45, 114, 118, 91, 45, 50, 44, 45, 49, 93, 10, 91, 45,
  49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 51,
  32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 54, 44, 49, 52, 44,
  49, 48, 44, 49, 56, 44, 49, 44, 48, 44, 50, 48, 48, 44, 48, 32,
  45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 49, 48, 44, 49, 56, 44,
  49, 54, 44, 54, 44, 49, 44, 48, 44, 50, 48, 48, 44, 48, 32, 45,
  100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 50, 10, 45, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 49, 32, 45, 110,
  91, 45, 49, 93, 32, 48, 44, 48, 46, 55, 32, 45, 100, 105, 108, 97,
  116, 101, 91, 45, 49, 93, 32, 51, 32, 45, 106, 91, 45, 51, 93, 32,
  91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45,
  97, 91, 45, 49, 51, 45, 45, 49, 93, 32, 120, 32, 45, 110, 109, 91,
  45, 49, 93, 32, 115, 112, 114, 105, 116, 101, 115, 10, 40, 48, 44, 50,
  51, 59, 48, 44, 50, 51, 94, 48, 44, 48, 59, 50, 51, 44, 50, 51,
  41, 32, 45, 114, 91, 45, 49, 93, 32, 50, 52, 44, 50, 52, 44, 49,
  44, 50, 44, 51, 32, 45, 114, 91, 45, 49, 93, 32, 123, 64, 123, 98,
  111, 97, 114, 100, 44, 119, 125, 42, 50, 52, 125, 44, 123, 64, 123, 98,
  111, 97, 114, 100, 44, 104, 125, 42, 50, 52, 125, 44, 49, 44, 50, 44,
  48, 44, 50, 32, 45, 110, 109, 91, 45, 49, 93, 32, 111, 102, 102, 115,
  101, 116, 115, 10, 91, 45, 49, 93, 44, 91, 45, 49, 93, 44, 49, 44,
  51, 44, 50, 53, 53, 32, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93,
  32, 49, 44, 49, 44, 48, 32, 45, 102, 114, 97, 109, 101, 91, 45, 49,
  93, 32, 50, 51, 44, 50, 51, 44, 50, 53, 53, 10, 48, 32, 45, 116,
  91, 45, 49, 93, 32, 34, 78, 117, 109, 98, 101, 114, 32, 111, 102, 32,
  109, 105, 110, 101, 115, 32, 58, 32, 34, 36, 110, 98, 95, 109, 105, 110,
  101, 115, 44, 48, 44, 48, 44, 49, 56, 44, 49, 44, 49, 48, 48, 44,
  50, 48, 48, 44, 50, 53, 53, 32, 45, 110, 101, 103, 97, 116, 105, 118,
  101, 91, 45, 49, 93, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 123, 40, 64, 123, 45, 50, 44, 119, 125, 45, 119, 41, 47, 50,
  125, 44, 123, 64, 123, 45, 50, 44, 104, 125, 45, 104, 45, 50, 125, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 110, 109, 91, 45, 49, 93, 32,
  99, 97, 110, 118, 97, 115, 10, 102, 97, 105, 108, 101, 100, 61, 48, 32,
  115, 117, 99, 99, 101, 101, 100, 101, 100, 61, 48, 32, 110, 98, 95, 102,
  108, 97, 103, 115, 61, 48, 32, 115, 116, 97, 114, 116, 101, 100, 61, 48,
  10, 45, 100, 111, 10, 45, 45, 42, 91, 98, 111, 97, 114, 100, 93, 32,
  50, 52, 32, 45, 114, 91, 45, 49, 93, 32, 91, 111, 102, 102, 115, 101,
  116, 115, 93, 44, 91, 111, 102, 102, 115, 101, 116, 115, 93, 32, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 44, 49, 32,
  45, 43, 91, 45, 49, 93, 32, 91, 111, 102, 102, 115, 101, 116, 115, 93,
  32, 45, 45, 119, 97, 114, 112, 91, 115, 112, 114, 105, 116, 101, 115, 93,
  32, 91, 45, 49, 93, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 50,
  93, 10, 45, 106, 91, 99, 97, 110, 118, 97, 115, 93, 32, 91, 45, 49,
  93, 44, 50, 52, 44, 50, 52, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 119, 97, 105, 116, 32, 45, 49, 10, 45, 105, 102, 32, 36, 102, 97,
  105, 108, 101, 100, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 71,
  97, 109, 101, 92, 110, 79, 118, 101, 114, 33, 34, 44, 51, 44, 51, 44,
  51, 56, 44, 49, 44, 50, 53, 53, 32, 45, 114, 91, 45, 49, 93, 32,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 52, 32, 45, 115,
  104, 91, 45, 49, 93, 32, 51, 44, 51, 32, 45, 100, 105, 108, 97, 116,
  101, 91, 45, 49, 93, 32, 53, 32, 45, 47, 91, 45, 49, 93, 32, 50,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 100, 114, 111, 112, 95, 115,
  104, 97, 100, 111, 119, 91, 45, 49, 93, 32, 53, 44, 53, 44, 49, 32,
  45, 98, 108, 101, 110, 100, 91, 99, 97, 110, 118, 97, 115, 44, 45, 49,
  93, 32, 97, 108, 112, 104, 97, 10, 48, 32, 45, 116, 91, 45, 49, 93,
  32, 34, 66, 111, 111, 109, 33, 32, 89, 111, 117, 32, 102, 97, 105, 108,
  101, 100, 33, 34, 44, 48, 44, 48, 44, 49, 56, 44, 49, 44, 49, 48,
  48, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 114, 91, 45, 49, 93,
  32, 64, 123, 99, 97, 110, 118, 97, 115, 44, 119, 125, 44, 49, 48, 48,
  37, 44, 49, 44, 51, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46,
  53, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32,
  45, 106, 91, 99, 97, 110, 118, 97, 115, 93, 32, 91, 45, 49, 93, 44,
  48, 44, 51, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 100, 111, 32,
  45, 119, 91, 99, 97, 110, 118, 97, 115, 93, 32, 123, 119, 125, 44, 123,
  104, 125, 32, 45, 119, 97, 105, 116, 32, 45, 119, 104, 105, 108, 101, 32,
  123, 64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83,
  67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125,
  10, 45, 101, 108, 105, 102, 32, 36, 115, 117, 99, 99, 101, 101, 100, 101,
  100, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 83, 117, 99, 99,
  101, 115, 115, 33, 34, 44, 51, 44, 51, 44, 51, 56, 44, 49, 44, 50,
  53, 53, 32, 45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 49, 44, 52, 32, 45, 115, 104, 91, 45, 49, 93, 32,
  51, 44, 51, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32,
  53, 32, 45, 47, 91, 45, 49, 93, 32, 50, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119, 91,
  45, 49, 93, 32, 53, 44, 53, 44, 49, 32, 45, 98, 108, 101, 110, 100,
  91, 99, 97, 110, 118, 97, 115, 44, 45, 49, 93, 32, 97, 108, 112, 104,
  97, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 67, 111, 110, 103,
  114, 97, 116, 117, 108, 97, 116, 105, 111, 110, 115, 33, 32, 40, 34, 123,
  114, 111, 117, 110, 100, 40, 64, 124, 45, 36, 116, 105, 99, 41, 125, 34,
  32, 115, 41, 34, 44, 48, 44, 48, 44, 49, 56, 44, 49, 44, 50, 53,
  53, 44, 49, 48, 48, 44, 50, 53, 53, 32, 45, 114, 91, 45, 49, 93,
  32, 64, 123, 99, 97, 110, 118, 97, 115, 44, 119, 125, 44, 49, 48, 48,
  37, 44, 49, 44, 51, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46,
  53, 10, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32,
  45, 106, 91, 99, 97, 110, 118, 97, 115, 93, 32, 91, 45, 49, 93, 44,
  48, 44, 51, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 100, 111, 32,
  45, 119, 91, 99, 97, 110, 118, 97, 115, 93, 32, 123, 119, 125, 44, 123,
  104, 125, 32, 45, 119, 97, 105, 116, 32, 45, 119, 104, 105, 108, 101, 32,
  123, 64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83,
  67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125,
  10, 45, 101, 108, 115, 101, 10, 45, 45, 61, 61, 91, 98, 111, 97, 114,
  100, 93, 32, 49, 48, 32, 110, 98, 95, 102, 108, 97, 103, 115, 61, 64,
  123, 45, 49, 44, 43, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  100, 111, 10, 45, 105, 102, 32, 123, 33, 36, 115, 116, 97, 114, 116, 101,
  100, 125, 32, 116, 105, 99, 61, 64, 124, 32, 45, 101, 110, 100, 105, 102,
  10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 69, 108, 97, 112, 115,
  101, 100, 32, 116, 105, 109, 101, 32, 58, 32, 34, 123, 114, 111, 117, 110,
  100, 40, 64, 124, 45, 36, 116, 105, 99, 41, 125, 34, 32, 115, 32, 47,
  32, 70, 108, 97, 103, 115, 32, 58, 32, 34, 36, 110, 98, 95, 102, 108,
  97, 103, 115, 44, 48, 44, 48, 44, 49, 56, 44, 49, 44, 50, 53, 53,
  44, 50, 48, 48, 44, 48, 32, 45, 114, 91, 45, 49, 93, 32, 64, 123,
  99, 97, 110, 118, 97, 115, 44, 119, 125, 44, 49, 48, 48, 37, 44, 49,
  44, 51, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45,
  110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32, 45, 106, 91,
  99, 97, 110, 118, 97, 115, 93, 32, 91, 45, 49, 93, 44, 48, 44, 51,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 119, 97, 105, 116, 32, 53,
  48, 10, 120, 61, 123, 105, 110, 116, 40, 40, 64, 123, 33, 44, 120, 125,
  45, 50, 52, 41, 47, 50, 52, 41, 125, 32, 121, 61, 123, 105, 110, 116,
  40, 40, 64, 123, 33, 44, 121, 125, 45, 50, 52, 41, 47, 50, 52, 41,
  125, 32, 98, 61, 64, 123, 33, 44, 98, 125, 10, 45, 119, 91, 99, 97,
  110, 118, 97, 115, 93, 32, 123, 119, 125, 44, 123, 104, 125, 44, 48, 44,
  34, 91, 71, 39, 77, 73, 67, 93, 32, 77, 105, 110, 101, 115, 119, 101,
  101, 112, 101, 114, 34, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 33,
  34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67, 125, 34,
  32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 34, 32, 38, 38,
  32, 34, 33, 36, 98, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 120, 62, 61, 48, 92, 32, 38, 38, 92, 32, 36, 121,
  62, 61, 48, 92, 32, 38, 38, 92, 32, 36, 120, 60, 64, 123, 98, 111,
  97, 114, 100, 44, 119, 125, 92, 32, 38, 38, 92, 32, 36, 121, 60, 64,
  123, 98, 111, 97, 114, 100, 44, 104, 125, 125, 10, 45, 105, 102, 32, 123,
  36, 98, 38, 49, 125, 10, 115, 116, 97, 114, 116, 101, 100, 61, 49, 32,
  118, 97, 108, 61, 64, 123, 102, 105, 101, 108, 100, 44, 40, 36, 120, 44,
  36, 121, 41, 125, 10, 45, 105, 102, 32, 123, 36, 118, 97, 108, 61, 61,
  48, 125, 32, 45, 45, 61, 61, 91, 102, 105, 101, 108, 100, 93, 32, 48,
  32, 45, 106, 91, 98, 111, 97, 114, 100, 93, 32, 91, 102, 105, 101, 108,
  100, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49,
  93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 102, 97, 105, 108, 101, 100,
  61, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 118, 97, 108, 61, 61,
  49, 125, 32, 45, 45, 102, 108, 111, 111, 100, 91, 102, 105, 101, 108, 100,
  93, 32, 36, 120, 44, 36, 121, 44, 48, 44, 48, 44, 49, 44, 49, 44,
  45, 49, 32, 45, 61, 61, 91, 45, 49, 93, 32, 45, 49, 32, 45, 100,
  105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51, 32, 45, 106, 91, 98,
  111, 97, 114, 100, 93, 32, 91, 102, 105, 101, 108, 100, 93, 44, 48, 44,
  48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 101, 108, 115, 101, 32, 45, 61, 91, 98, 111,
  97, 114, 100, 93, 32, 36, 118, 97, 108, 44, 36, 120, 44, 36, 121, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 105, 102, 32, 123, 110, 61,
  64, 123, 98, 111, 97, 114, 100, 44, 40, 36, 120, 44, 36, 121, 41, 125,
  59, 36, 98, 38, 50, 34, 32, 38, 38, 32, 34, 110, 62, 61, 49, 48,
  34, 32, 38, 38, 32, 34, 110, 60, 61, 49, 49, 125, 10, 45, 61, 91,
  98, 111, 97, 114, 100, 93, 32, 123, 105, 102, 40, 64, 123, 98, 111, 97,
  114, 100, 44, 40, 36, 120, 44, 36, 121, 41, 125, 61, 61, 49, 49, 44,
  49, 48, 44, 49, 49, 41, 125, 44, 36, 120, 44, 36, 121, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 98, 38, 52, 125, 32, 45, 102, 91, 98, 111,
  97, 114, 100, 93, 32, 49, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 110, 98, 95, 109,
  105, 110, 101, 115, 61, 61, 36, 110, 98, 95, 102, 108, 97, 103, 115, 92,
  32, 38, 38, 92, 32, 64, 123, 98, 111, 97, 114, 100, 44, 77, 125, 33,
  61, 49, 49, 125, 32, 115, 117, 99, 99, 101, 101, 100, 101, 100, 61, 49,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123,
  64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67,
  125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125, 10,
  45, 119, 32, 48, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 120, 95, 109, 105, 110, 105, 109, 97, 108, 95, 112, 97, 116, 104, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 76, 97, 117, 110, 99, 104, 32,
  116, 104, 101, 32, 109, 105, 110, 105, 109, 97, 108, 32, 112, 97, 116, 104,
  32, 100, 101, 109, 111, 46, 10, 120, 95, 109, 105, 110, 105, 109, 97, 108,
  95, 112, 97, 116, 104, 32, 58, 10, 45, 101, 91, 93, 32, 34, 92, 110,
  10, 45, 45, 45, 45, 45, 45, 32, 77, 105, 110, 105, 109, 97, 108, 32,
  112, 97, 116, 104, 32, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92,
  110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32, 67, 108,
  105, 99, 107, 32, 111, 110, 32, 116, 119, 111, 32, 112, 111, 105, 110, 116,
  115, 32, 116, 111, 32, 99, 111, 109, 112, 117, 116, 101, 32, 97, 110, 100,
  32, 100, 105, 115, 112, 108, 97, 121, 32, 116, 104, 101, 32, 109, 105, 110,
  105, 109, 97, 108, 92, 110, 10, 45, 45, 45, 45, 32, 112, 97, 116, 104,
  32, 98, 101, 116, 119, 101, 101, 110, 32, 116, 104, 111, 115, 101, 32, 112,
  111, 105, 110, 116, 115, 46, 32, 84, 104, 101, 32, 101, 110, 100, 105, 110,
  103, 32, 112, 111, 105, 110, 116, 32, 105, 115, 32, 116, 104, 101, 110, 92,
  110, 10, 45, 45, 45, 45, 32, 99, 104, 111, 115, 101, 110, 32, 97, 115,
  32, 116, 104, 101, 32, 110, 101, 120, 116, 32, 115, 116, 97, 114, 116, 105,
  110, 103, 32, 112, 111, 105, 110, 116, 32, 102, 111, 114, 32, 97, 110, 111,
  116, 104, 101, 114, 32, 112, 97, 116, 104, 46, 92, 110, 10, 45, 45, 45,
  45, 32, 75, 101, 121, 32, 39, 83, 39, 32, 116, 111, 32, 115, 97, 118,
  101, 32, 115, 110, 97, 112, 115, 104, 111, 116, 32, 111, 102, 32, 116, 104,
  101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 118, 105, 101, 119, 46, 92,
  110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 69, 83, 67,
  39, 32, 111, 114, 32, 39, 81, 39, 32, 116, 111, 32, 101, 120, 105, 116,
  46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 10,
  45, 105, 102, 32, 123, 33, 64, 35, 125, 32, 45, 116, 101, 115, 116, 105,
  109, 97, 103, 101, 50, 100, 32, 52, 48, 48, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 110, 32, 48, 44, 50, 48, 48, 32, 45, 114, 111, 117, 110,
  100, 32, 49, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 119, 91, 48, 93, 32, 45, 49, 44, 45,
  49, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 83, 101, 108,
  101, 99, 116, 32, 115, 116, 97, 114, 116, 105, 110, 103, 32, 112, 111, 105,
  110, 116, 32, 80, 48, 34, 10, 45, 105, 102, 32, 123, 33, 110, 97, 114,
  103, 40, 36, 102, 105, 114, 115, 116, 95, 116, 105, 109, 101, 41, 125, 32,
  45, 45, 108, 91, 48, 93, 32, 45, 114, 50, 100, 121, 32, 49, 50, 56,
  32, 45, 102, 114, 97, 109, 101, 32, 49, 44, 49, 44, 48, 10, 45, 97,
  108, 101, 114, 116, 32, 34, 91, 71, 39, 77, 73, 67, 32, 77, 105, 110,
  105, 109, 97, 108, 32, 112, 97, 116, 104, 93, 34, 44, 92, 10, 34, 84,
  104, 101, 32, 71, 39, 77, 73, 67, 32, 109, 105, 110, 105, 109, 97, 108,
  32, 112, 97, 116, 104, 32, 100, 101, 109, 111, 32, 105, 108, 108, 117, 115,
  116, 114, 97, 116, 101, 115, 32, 104, 111, 119, 32, 109, 105, 110, 105, 109,
  97, 108, 32, 112, 97, 116, 104, 115, 92, 110, 34, 92, 10, 34, 99, 97,
  110, 32, 98, 101, 32, 99, 111, 109, 112, 117, 116, 101, 100, 32, 105, 110,
  32, 105, 109, 97, 103, 101, 115, 32, 116, 111, 32, 100, 101, 116, 101, 99,
  116, 32, 97, 110, 100, 32, 116, 114, 97, 99, 107, 32, 101, 100, 103, 101,
  32, 112, 111, 105, 110, 116, 115, 46, 92, 110, 34, 92, 10, 34, 85, 115,
  101, 32, 121, 111, 117, 114, 32, 109, 111, 117, 115, 101, 32, 116, 111, 32,
  115, 101, 108, 101, 99, 116, 32, 100, 101, 115, 105, 114, 101, 100, 32, 115,
  116, 97, 114, 116, 105, 110, 103, 32, 97, 110, 100, 32, 101, 110, 100, 105,
  110, 103, 32, 112, 111, 105, 110, 116, 115, 44, 92, 110, 34, 92, 10, 34,
  97, 110, 100, 32, 115, 101, 101, 32, 119, 104, 97, 116, 32, 105, 115, 32,
  116, 104, 101, 32, 109, 105, 110, 105, 109, 97, 108, 32, 112, 97, 116, 104,
  32, 99, 111, 109, 112, 117, 116, 101, 100, 32, 98, 101, 116, 119, 101, 101,
  110, 32, 116, 104, 101, 115, 101, 32, 112, 111, 105, 110, 116, 115, 46, 34,
  44, 92, 10, 34, 83, 116, 97, 114, 116, 32, 100, 101, 109, 111, 34, 10,
  45, 114, 109, 32, 45, 101, 110, 100, 108, 32, 102, 105, 114, 115, 116, 95,
  116, 105, 109, 101, 61, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45,
  103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 32, 45, 98,
  91, 45, 49, 93, 32, 49, 32, 45, 102, 91, 45, 49, 93, 32, 101, 120,
  112, 40, 45, 105, 47, 49, 48, 41, 10, 45, 116, 111, 95, 114, 103, 98,
  91, 48, 93, 32, 45, 45, 115, 101, 108, 101, 99, 116, 91, 48, 93, 32,
  48, 32, 80, 48, 61, 64, 45, 49, 10, 45, 101, 108, 108, 105, 112, 115,
  101, 91, 48, 93, 32, 64, 123, 45, 49, 44, 48, 44, 49, 125, 44, 51,
  44, 51, 44, 48, 44, 49, 44, 50, 53, 53, 44, 48, 44, 50, 53, 53,
  10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 48, 93, 32, 64, 123, 45,
  49, 44, 48, 44, 49, 125, 44, 51, 44, 51, 44, 48, 44, 49, 44, 48,
  120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 105,
  102, 32, 123, 109, 105, 110, 40, 36, 80, 48, 41, 62, 61, 48, 125, 10,
  112, 61, 49, 10, 45, 100, 111, 10, 45, 119, 91, 48, 93, 32, 45, 49,
  44, 45, 49, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 83,
  101, 108, 101, 99, 116, 32, 101, 110, 100, 105, 110, 103, 32, 112, 111, 105,
  110, 116, 32, 80, 34, 36, 112, 10, 45, 45, 115, 101, 108, 101, 99, 116,
  91, 48, 93, 32, 48, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 83,
  125, 125, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 45, 116, 101, 120,
  116, 95, 111, 117, 116, 108, 105, 110, 101, 91, 48, 93, 32, 34, 83, 97,
  118, 105, 110, 103, 32, 115, 110, 97, 112, 115, 104, 111, 116, 46, 46, 46,
  34, 44, 53, 44, 53, 44, 49, 51, 44, 49, 44, 49, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 119, 91, 45, 49, 93, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 111, 91, 48, 93, 32, 103, 109,
  105, 99, 95, 109, 105, 110, 105, 109, 97, 108, 95, 112, 97, 116, 104, 46,
  112, 110, 103, 10, 45, 119, 97, 105, 116, 32, 45, 49, 10, 45, 101, 108,
  115, 101, 10, 80, 49, 61, 64, 45, 49, 10, 45, 101, 108, 108, 105, 112,
  115, 101, 91, 48, 93, 32, 64, 123, 45, 49, 44, 48, 44, 49, 125, 44,
  51, 44, 51, 44, 48, 44, 49, 44, 50, 53, 53, 44, 48, 44, 50, 53,
  53, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 48, 93, 32, 64, 123,
  45, 49, 44, 48, 44, 49, 125, 44, 51, 44, 51, 44, 48, 44, 49, 44,
  48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 50, 53, 53, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  105, 102, 32, 123, 109, 105, 110, 40, 36, 80, 49, 41, 62, 61, 48, 125,
  10, 45, 45, 116, 101, 120, 116, 95, 111, 117, 116, 108, 105, 110, 101, 91,
  48, 93, 32, 34, 80, 114, 111, 99, 101, 115, 115, 105, 110, 103, 46, 46,
  46, 34, 44, 53, 44, 53, 44, 49, 51, 44, 49, 44, 49, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 119, 91, 45, 49, 93,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 45, 109, 105, 110, 105, 109,
  97, 108, 95, 112, 97, 116, 104, 91, 49, 93, 32, 36, 80, 48, 44, 36,
  80, 49, 44, 49, 10, 45, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100,
  91, 45, 49, 93, 32, 48, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53,
  53, 32, 45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 44, 91, 48, 93, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 48, 46, 53, 32, 45, 114, 91, 45, 49, 93, 32, 91, 48,
  93, 44, 48, 32, 45, 111, 114, 91, 48, 44, 45, 49, 93, 10, 80, 48,
  61, 36, 80, 49, 32, 112, 61, 123, 36, 112, 43, 49, 125, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 119, 104, 105,
  108, 101, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33,
  44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44,
  81, 125, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 49,
  93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 119,
  32, 48, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 120,
  95, 112, 97, 99, 109, 97, 110, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 76, 97, 117, 110, 99, 104, 32, 112, 97, 99, 109, 97, 110, 32, 103,
  97, 109, 101, 46, 10, 120, 95, 112, 97, 99, 109, 97, 110, 32, 58, 10,
  45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32,
  80, 97, 99, 109, 97, 110, 32, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10,
  45, 45, 45, 45, 32, 84, 104, 105, 115, 32, 105, 115, 32, 97, 32, 71,
  39, 77, 73, 67, 32, 105, 109, 112, 108, 101, 109, 101, 110, 116, 97, 116,
  105, 111, 110, 32, 111, 102, 32, 116, 104, 101, 32, 112, 97, 99, 109, 97,
  110, 32, 103, 97, 109, 101, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110,
  10, 45, 45, 45, 45, 32, 77, 111, 118, 101, 32, 116, 104, 101, 32, 112,
  97, 99, 109, 97, 110, 32, 116, 111, 32, 101, 97, 116, 32, 97, 108, 108,
  32, 112, 97, 99, 100, 111, 116, 115, 32, 111, 110, 32, 116, 104, 101, 32,
  100, 105, 102, 102, 101, 114, 101, 110, 116, 32, 108, 101, 118, 101, 108, 115,
  46, 92, 110, 10, 45, 45, 45, 45, 32, 69, 97, 116, 105, 110, 103, 32,
  97, 32, 112, 97, 99, 103, 117, 109, 32, 109, 97, 107, 101, 115, 32, 112,
  97, 99, 109, 97, 110, 32, 105, 110, 118, 105, 110, 99, 105, 98, 108, 101,
  32, 102, 111, 114, 32, 49, 48, 32, 115, 101, 99, 111, 110, 100, 115, 44,
  92, 110, 10, 45, 45, 45, 45, 32, 119, 104, 105, 99, 104, 32, 109, 101,
  97, 110, 32, 112, 97, 99, 109, 97, 110, 32, 99, 97, 110, 32, 101, 97,
  116, 32, 103, 104, 111, 115, 116, 115, 32, 100, 117, 114, 105, 110, 103, 32,
  116, 104, 105, 115, 32, 116, 105, 109, 101, 46, 92, 110, 10, 45, 45, 45,
  45, 32, 69, 97, 116, 105, 110, 103, 32, 97, 32, 103, 104, 111, 115, 116,
  32, 101, 97, 114, 110, 115, 32, 49, 48, 48, 32, 112, 116, 115, 46, 92,
  110, 10, 45, 45, 45, 45, 32, 69, 97, 116, 105, 110, 103, 32, 97, 32,
  99, 104, 101, 114, 114, 121, 32, 101, 97, 114, 110, 115, 32, 49, 48, 32,
  112, 116, 115, 46, 92, 110, 10, 45, 45, 45, 45, 32, 69, 97, 116, 105,
  110, 103, 32, 97, 32, 115, 116, 114, 97, 119, 98, 101, 114, 114, 121, 32,
  101, 97, 114, 110, 115, 32, 49, 48, 48, 32, 112, 116, 115, 46, 92, 110,
  10, 45, 45, 45, 45, 32, 69, 97, 116, 105, 110, 103, 32, 97, 110, 32,
  111, 114, 97, 110, 103, 101, 32, 101, 97, 114, 110, 115, 32, 49, 48, 48,
  48, 32, 112, 116, 115, 46, 92, 110, 10, 45, 45, 45, 45, 32, 69, 97,
  116, 105, 110, 103, 32, 97, 32, 98, 97, 110, 97, 110, 97, 32, 101, 97,
  114, 110, 115, 32, 53, 48, 48, 48, 32, 112, 116, 115, 46, 92, 110, 10,
  45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32, 65, 114, 114, 111,
  119, 32, 107, 101, 121, 115, 32, 116, 111, 32, 99, 111, 110, 116, 114, 111,
  108, 32, 112, 97, 99, 109, 97, 110, 46, 92, 110, 10, 45, 45, 45, 45,
  32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76, 43, 68, 39, 32, 116,
  111, 32, 100, 111, 117, 98, 108, 101, 32, 119, 105, 110, 100, 111, 119, 32,
  115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121,
  115, 32, 39, 67, 84, 82, 76, 43, 67, 39, 32, 116, 111, 32, 114, 101,
  115, 101, 116, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46,
  92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 69, 83,
  67, 39, 32, 111, 114, 32, 39, 81, 39, 32, 116, 111, 32, 101, 120, 105,
  116, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 109, 10, 45, 109, 32, 34, 95, 112, 97, 99, 109, 97, 110,
  95, 103, 104, 111, 115, 116, 95, 98, 97, 115, 101, 95, 103, 102, 120, 32,
  58, 32, 51, 49, 44, 49, 57, 32, 45, 99, 105, 114, 99, 108, 101, 91,
  45, 49, 93, 32, 49, 53, 44, 49, 53, 44, 49, 53, 44, 49, 44, 49,
  32, 51, 49, 44, 49, 50, 44, 49, 44, 49, 44, 39, 121, 60, 52, 43,
  56, 42, 97, 98, 115, 40, 99, 111, 115, 40, 120, 42, 48, 46, 51, 43,
  48, 46, 50, 53, 42, 112, 105, 42, 36, 34, 34, 49, 41, 41, 39, 32,
  45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 34, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 52, 10, 45, 95, 112, 97, 99, 109, 97, 110, 95,
  103, 104, 111, 115, 116, 95, 115, 116, 97, 110, 100, 97, 114, 100, 95, 103,
  102, 120, 32, 50, 53, 53, 44, 48, 44, 48, 44, 36, 62, 32, 45, 110,
  109, 91, 45, 49, 93, 32, 103, 104, 111, 115, 116, 48, 95, 36, 62, 10,
  45, 95, 112, 97, 99, 109, 97, 110, 95, 103, 104, 111, 115, 116, 95, 115,
  116, 97, 110, 100, 97, 114, 100, 95, 103, 102, 120, 32, 48, 44, 50, 53,
  53, 44, 50, 50, 50, 44, 36, 62, 32, 45, 110, 109, 91, 45, 49, 93,
  32, 103, 104, 111, 115, 116, 49, 95, 36, 62, 10, 45, 95, 112, 97, 99,
  109, 97, 110, 95, 103, 104, 111, 115, 116, 95, 115, 116, 97, 110, 100, 97,
  114, 100, 95, 103, 102, 120, 32, 50, 53, 53, 44, 49, 56, 52, 44, 50,
  50, 50, 44, 36, 62, 32, 45, 110, 109, 91, 45, 49, 93, 32, 103, 104,
  111, 115, 116, 50, 95, 36, 62, 10, 45, 95, 112, 97, 99, 109, 97, 110,
  95, 103, 104, 111, 115, 116, 95, 115, 116, 97, 110, 100, 97, 114, 100, 95,
  103, 102, 120, 32, 50, 53, 53, 44, 49, 56, 52, 44, 55, 49, 44, 36,
  62, 32, 45, 110, 109, 91, 45, 49, 93, 32, 103, 104, 111, 115, 116, 51,
  95, 36, 62, 10, 45, 95, 112, 97, 99, 109, 97, 110, 95, 103, 104, 111,
  115, 116, 95, 97, 102, 114, 97, 105, 100, 95, 103, 102, 120, 32, 36, 62,
  32, 45, 110, 109, 91, 45, 49, 93, 32, 103, 104, 111, 115, 116, 97, 95,
  36, 62, 10, 45, 95, 112, 97, 99, 109, 97, 110, 95, 103, 104, 111, 115,
  116, 95, 98, 97, 115, 101, 95, 103, 102, 120, 32, 36, 62, 32, 45, 114,
  91, 45, 49, 93, 32, 49, 54, 44, 49, 54, 44, 49, 44, 49, 44, 50,
  32, 45, 110, 109, 91, 45, 49, 93, 32, 103, 104, 111, 115, 116, 109, 95,
  36, 62, 10, 45, 95, 112, 97, 99, 109, 97, 110, 95, 103, 104, 111, 115,
  116, 95, 115, 116, 97, 110, 100, 97, 114, 100, 95, 103, 102, 120, 32, 48,
  44, 48, 44, 48, 44, 36, 62, 32, 45, 110, 109, 91, 45, 49, 93, 32,
  103, 104, 111, 115, 116, 100, 95, 36, 62, 10, 45, 95, 112, 97, 99, 109,
  97, 110, 95, 112, 97, 99, 109, 97, 110, 95, 103, 102, 120, 32, 36, 62,
  32, 45, 110, 109, 91, 45, 50, 93, 32, 112, 97, 99, 109, 97, 110, 95,
  36, 62, 32, 45, 110, 109, 91, 45, 49, 93, 32, 112, 97, 99, 109, 97,
  110, 109, 95, 36, 62, 10, 45, 100, 111, 110, 101, 10, 45, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 103, 104, 111, 115, 116, 100, 95, 48, 93,
  32, 48, 32, 45, 33, 61, 91, 45, 49, 93, 32, 48, 32, 45, 110, 109,
  91, 45, 49, 93, 32, 103, 104, 111, 115, 116, 100, 109, 10, 45, 95, 112,
  97, 99, 109, 97, 110, 95, 99, 104, 101, 114, 114, 121, 95, 103, 102, 120,
  32, 45, 110, 109, 91, 45, 49, 93, 32, 102, 114, 117, 105, 116, 48, 32,
  45, 95, 112, 97, 99, 109, 97, 110, 95, 115, 116, 114, 97, 119, 98, 101,
  114, 114, 121, 95, 103, 102, 120, 32, 45, 110, 109, 91, 45, 49, 93, 32,
  102, 114, 117, 105, 116, 49, 10, 45, 95, 112, 97, 99, 109, 97, 110, 95,
  111, 114, 97, 110, 103, 101, 95, 103, 102, 120, 32, 45, 110, 109, 91, 45,
  49, 93, 32, 102, 114, 117, 105, 116, 50, 32, 45, 95, 112, 97, 99, 109,
  97, 110, 95, 98, 97, 110, 97, 110, 97, 95, 103, 102, 120, 32, 45, 110,
  109, 91, 45, 49, 93, 32, 102, 114, 117, 105, 116, 51, 10, 50, 48, 44,
  50, 44, 49, 44, 51, 44, 50, 48, 48, 32, 45, 110, 109, 91, 45, 49,
  93, 32, 103, 97, 116, 101, 10, 115, 99, 111, 114, 101, 48, 61, 34, 49,
  48, 34, 32, 115, 99, 111, 114, 101, 49, 61, 34, 49, 48, 48, 34, 32,
  115, 99, 111, 114, 101, 50, 61, 34, 49, 48, 48, 48, 34, 32, 115, 99,
  111, 114, 101, 51, 61, 34, 53, 48, 48, 48, 34, 32, 115, 99, 111, 114,
  101, 52, 61, 34, 65, 114, 103, 104, 33, 34, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 53, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 36, 123,
  115, 99, 111, 114, 101, 36, 62, 125, 44, 48, 44, 48, 44, 49, 51, 44,
  49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 97,
  117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 48, 32, 45, 101,
  120, 112, 97, 110, 100, 95, 120, 121, 91, 45, 49, 93, 32, 49, 44, 48,
  32, 45, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51, 10,
  45, 110, 109, 91, 45, 49, 93, 32, 115, 99, 111, 114, 101, 109, 36, 62,
  32, 45, 110, 109, 91, 45, 50, 93, 32, 115, 99, 111, 114, 101, 36, 62,
  10, 45, 100, 111, 110, 101, 10, 116, 105, 109, 101, 52, 61, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 32, 116, 105, 109, 101, 51, 61, 50,
  53, 53, 44, 50, 53, 53, 44, 51, 50, 32, 116, 105, 109, 101, 50, 61,
  50, 53, 53, 44, 49, 50, 56, 44, 51, 50, 32, 116, 105, 109, 101, 49,
  61, 50, 53, 53, 44, 51, 50, 44, 51, 50, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 49, 49, 32, 48, 32, 45, 116, 91, 45, 49, 93, 32, 36,
  60, 34, 32, 115, 34, 44, 48, 44, 48, 44, 50, 51, 44, 49, 44, 36,
  123, 116, 105, 109, 101, 123, 109, 105, 110, 40, 52, 44, 114, 111, 117, 110,
  100, 40, 40, 36, 60, 43, 49, 41, 47, 50, 41, 41, 125, 125, 32, 45,
  110, 109, 91, 45, 49, 93, 32, 116, 105, 109, 101, 36, 60, 32, 45, 100,
  111, 110, 101, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 71, 101,
  116, 32, 82, 101, 97, 100, 121, 33, 34, 44, 48, 44, 48, 44, 51, 50,
  44, 49, 44, 50, 53, 53, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112,
  91, 45, 49, 93, 32, 48, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120,
  121, 91, 45, 49, 93, 32, 52, 44, 48, 32, 45, 45, 100, 105, 108, 97,
  116, 101, 91, 45, 49, 93, 32, 56, 32, 45, 114, 91, 45, 50, 93, 32,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 51, 10, 45, 110,
  109, 91, 45, 50, 93, 32, 103, 101, 116, 95, 114, 101, 97, 100, 121, 32,
  45, 110, 109, 91, 45, 49, 93, 32, 103, 101, 116, 95, 114, 101, 97, 100,
  121, 109, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 71, 97, 109,
  101, 92, 110, 79, 118, 101, 114, 33, 34, 44, 48, 44, 48, 44, 53, 55,
  44, 49, 44, 50, 53, 53, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112,
  91, 45, 49, 93, 32, 48, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120,
  121, 91, 45, 49, 93, 32, 52, 44, 48, 32, 45, 45, 100, 105, 108, 97,
  116, 101, 91, 45, 49, 93, 32, 56, 32, 45, 114, 91, 45, 50, 93, 32,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 51, 10, 45, 110,
  109, 91, 45, 50, 93, 32, 103, 97, 109, 101, 95, 111, 118, 101, 114, 32,
  45, 110, 109, 91, 45, 49, 93, 32, 103, 97, 109, 101, 95, 111, 118, 101,
  114, 109, 10, 115, 99, 111, 114, 101, 61, 48, 32, 108, 101, 118, 101, 108,
  61, 45, 49, 32, 108, 105, 118, 101, 115, 61, 51, 32, 105, 115, 95, 113,
  117, 105, 116, 61, 48, 10, 45, 100, 111, 10, 45, 105, 102, 32, 123, 36,
  108, 101, 118, 101, 108, 60, 48, 125, 10, 95, 114, 108, 101, 118, 101, 108,
  61, 51, 51, 32, 95, 103, 108, 101, 118, 101, 108, 61, 51, 51, 32, 95,
  98, 108, 101, 118, 101, 108, 61, 50, 53, 53, 10, 45, 95, 112, 97, 99,
  109, 97, 110, 95, 109, 97, 112, 95, 108, 101, 118, 101, 108, 123, 40, 40,
  45, 36, 108, 101, 118, 101, 108, 45, 49, 41, 37, 54, 41, 43, 49, 125,
  32, 109, 119, 61, 123, 119, 125, 32, 109, 104, 61, 123, 104, 125, 32, 109,
  119, 50, 61, 123, 105, 110, 116, 40, 119, 47, 50, 41, 125, 32, 109, 104,
  50, 61, 123, 105, 110, 116, 40, 104, 47, 50, 41, 125, 10, 45, 105, 102,
  32, 123, 36, 108, 101, 118, 101, 108, 60, 45, 54, 125, 32, 45, 114, 101,
  112, 108, 97, 99, 101, 91, 45, 49, 93, 32, 51, 44, 50, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 110, 109, 91, 45, 49, 93, 32, 109, 97, 112,
  48, 32, 45, 105, 91, 109, 97, 112, 93, 32, 91, 45, 49, 93, 10, 45,
  45, 115, 104, 105, 102, 116, 91, 109, 97, 112, 93, 32, 45, 49, 44, 48,
  32, 45, 45, 115, 104, 105, 102, 116, 91, 109, 97, 112, 93, 32, 48, 44,
  45, 49, 32, 45, 45, 115, 104, 105, 102, 116, 91, 109, 97, 112, 93, 32,
  49, 44, 48, 32, 45, 45, 115, 104, 105, 102, 116, 91, 109, 97, 112, 93,
  32, 48, 44, 49, 32, 45, 97, 91, 45, 52, 45, 45, 49, 93, 32, 122,
  32, 45, 33, 61, 91, 45, 49, 93, 32, 49, 32, 45, 110, 109, 91, 45,
  49, 93, 32, 99, 97, 110, 95, 103, 111, 10, 45, 45, 61, 61, 91, 109,
  97, 112, 93, 32, 49, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32,
  45, 61, 91, 45, 49, 93, 32, 49, 44, 36, 109, 119, 50, 44, 36, 109,
  104, 50, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93,
  32, 49, 44, 91, 45, 50, 93, 44, 51, 32, 45, 114, 109, 91, 45, 50,
  93, 10, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102, 40, 105, 61, 61,
  50, 44, 48, 44, 105, 102, 40, 105, 61, 61, 56, 44, 49, 44, 105, 102,
  40, 105, 61, 61, 49, 44, 50, 44, 105, 102, 40, 105, 61, 61, 52, 44,
  51, 44, 105, 41, 41, 41, 41, 39, 32, 45, 110, 109, 91, 45, 49, 93,
  32, 112, 97, 116, 104, 10, 45, 45, 61, 61, 91, 109, 97, 112, 93, 32,
  50, 32, 112, 97, 99, 100, 111, 116, 115, 61, 64, 123, 45, 49, 44, 43,
  125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 108, 101, 118, 101, 108, 61,
  123, 45, 36, 108, 101, 118, 101, 108, 125, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 102, 91, 109, 97, 112, 93, 32, 39, 105, 102, 40, 105, 62, 61,
  52, 44, 48, 44, 105, 41, 39, 32, 45, 45, 61, 61, 91, 109, 97, 112,
  93, 32, 49, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 91, 45,
  49, 93, 32, 49, 44, 48, 32, 45, 114, 91, 45, 49, 93, 32, 49, 54,
  48, 48, 37, 44, 49, 54, 48, 48, 37, 32, 45, 101, 114, 111, 100, 101,
  91, 45, 49, 93, 32, 57, 32, 45, 98, 91, 45, 49, 93, 32, 50, 10,
  45, 103, 91, 45, 49, 93, 32, 120, 121, 32, 45, 97, 98, 115, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 103, 101, 91, 45, 49, 93, 32, 56, 48, 37, 32, 45, 98, 91, 45,
  49, 93, 32, 50, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 49, 32,
  45, 115, 104, 114, 105, 110, 107, 95, 120, 121, 91, 45, 49, 93, 32, 49,
  54, 10, 45, 45, 42, 91, 45, 49, 93, 32, 36, 95, 103, 108, 101, 118,
  101, 108, 32, 45, 45, 42, 91, 45, 50, 93, 32, 36, 95, 98, 108, 101,
  118, 101, 108, 32, 45, 42, 91, 45, 51, 93, 32, 36, 95, 114, 108, 101,
  118, 101, 108, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 99, 10,
  49, 54, 44, 49, 54, 44, 49, 44, 49, 44, 39, 120, 39, 32, 45, 45,
  45, 91, 109, 97, 112, 93, 32, 49, 32, 45, 109, 97, 120, 91, 45, 49,
  93, 32, 48, 32, 45, 42, 91, 45, 49, 93, 32, 49, 54, 32, 45, 114,
  91, 45, 49, 93, 32, 49, 54, 48, 48, 37, 44, 49, 54, 48, 48, 37,
  10, 49, 54, 44, 49, 54, 44, 49, 44, 49, 44, 39, 121, 39, 32, 45,
  114, 91, 45, 51, 44, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44,
  50, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 97, 91, 45,
  50, 44, 45, 49, 93, 32, 99, 10, 49, 54, 44, 49, 54, 44, 49, 44,
  51, 32, 45, 95, 112, 97, 99, 109, 97, 110, 95, 112, 97, 99, 100, 111,
  116, 115, 95, 103, 102, 120, 32, 45, 95, 112, 97, 99, 109, 97, 110, 95,
  112, 97, 99, 103, 117, 109, 95, 103, 102, 120, 32, 45, 97, 91, 45, 51,
  45, 45, 49, 93, 32, 121, 10, 45, 119, 97, 114, 112, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 50,
  93, 32, 45, 111, 114, 91, 45, 50, 44, 45, 49, 93, 32, 45, 114, 91,
  45, 49, 93, 32, 49, 48, 48, 37, 44, 123, 104, 43, 50, 52, 125, 44,
  49, 44, 51, 44, 48, 44, 48, 44, 48, 44, 49, 10, 45, 116, 91, 45,
  49, 93, 32, 34, 76, 105, 118, 101, 115, 32, 58, 34, 44, 49, 48, 44,
  48, 44, 50, 51, 44, 49, 44, 50, 53, 53, 32, 45, 116, 91, 45, 49,
  93, 32, 34, 83, 99, 111, 114, 101, 32, 58, 34, 44, 123, 119, 45, 49,
  52, 48, 125, 44, 48, 44, 50, 51, 44, 49, 44, 50, 53, 53, 10, 45,
  105, 102, 32, 36, 108, 105, 118, 101, 115, 32, 45, 45, 114, 91, 112, 97,
  99, 109, 97, 110, 95, 50, 93, 32, 49, 50, 44, 49, 50, 44, 49, 44,
  52, 44, 50, 32, 45, 114, 91, 45, 49, 93, 32, 123, 49, 48, 48, 42,
  36, 108, 105, 118, 101, 115, 125, 37, 44, 49, 48, 48, 37, 44, 49, 44,
  52, 44, 48, 44, 50, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 57, 48, 44, 55, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 110, 109, 91, 45, 49, 93, 32, 118, 105,
  115, 117, 10, 45, 119, 91, 118, 105, 115, 117, 93, 32, 45, 49, 44, 45,
  49, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 80, 97, 99,
  109, 97, 110, 34, 32, 45, 99, 117, 114, 115, 111, 114, 91, 48, 93, 32,
  48, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 76, 101, 118, 101,
  108, 32, 34, 36, 108, 101, 118, 101, 108, 44, 48, 44, 48, 44, 53, 55,
  44, 49, 44, 49, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45,
  49, 93, 32, 48, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 91,
  45, 49, 93, 32, 52, 44, 48, 32, 40, 48, 44, 50, 53, 53, 94, 48,
  44, 50, 53, 53, 94, 48, 44, 48, 41, 32, 45, 45, 109, 97, 112, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 93,
  32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 50, 93, 32, 56, 10, 45,
  110, 109, 91, 45, 49, 93, 32, 108, 101, 118, 101, 108, 95, 78, 32, 45,
  110, 109, 91, 45, 50, 93, 32, 108, 101, 118, 101, 108, 109, 95, 78, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 52, 32, 120, 103, 36, 62, 61, 123,
  49, 54, 42, 36, 109, 119, 50, 125, 32, 121, 103, 36, 62, 61, 123, 49,
  54, 42, 36, 109, 104, 50, 43, 52, 42, 36, 62, 125, 32, 100, 103, 36,
  62, 61, 51, 32, 109, 103, 36, 62, 61, 48, 32, 45, 100, 111, 110, 101,
  10, 120, 112, 61, 123, 49, 54, 42, 49, 48, 125, 32, 121, 112, 61, 123,
  49, 54, 42, 50, 49, 125, 32, 100, 112, 61, 45, 49, 32, 112, 97, 99,
  103, 117, 109, 95, 116, 105, 109, 101, 114, 61, 45, 49, 32, 102, 114, 117,
  105, 116, 95, 116, 105, 109, 101, 114, 61, 64, 124, 32, 100, 121, 105, 110,
  103, 95, 112, 97, 99, 109, 97, 110, 61, 48, 32, 105, 115, 95, 103, 101,
  116, 95, 114, 101, 97, 100, 121, 61, 49, 10, 120, 115, 99, 111, 114, 101,
  61, 48, 32, 121, 115, 99, 111, 114, 101, 61, 48, 32, 110, 115, 99, 111,
  114, 101, 61, 48, 32, 111, 115, 99, 111, 114, 101, 61, 48, 10, 45, 100,
  111, 10, 116, 61, 123, 105, 110, 116, 40, 54, 42, 64, 124, 41, 37, 52,
  125, 32, 108, 101, 102, 116, 61, 123, 105, 102, 40, 36, 112, 97, 99, 103,
  117, 109, 95, 116, 105, 109, 101, 114, 62, 61, 48, 44, 49, 48, 45, 64,
  124, 43, 36, 112, 97, 99, 103, 117, 109, 95, 116, 105, 109, 101, 114, 44,
  45, 49, 41, 125, 10, 91, 118, 105, 115, 117, 93, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 52, 10, 109, 103, 61, 36, 123, 109, 103, 36, 62, 125,
  32, 120, 103, 61, 36, 123, 120, 103, 36, 62, 125, 32, 121, 103, 61, 123,
  36, 123, 121, 103, 36, 62, 125, 43, 50, 52, 125, 10, 45, 105, 102, 32,
  123, 36, 109, 103, 61, 61, 48, 125, 32, 45, 106, 91, 45, 49, 93, 32,
  91, 103, 104, 111, 115, 116, 36, 62, 95, 36, 116, 93, 44, 36, 120, 103,
  44, 36, 121, 103, 44, 48, 44, 48, 44, 49, 44, 91, 103, 104, 111, 115,
  116, 109, 95, 36, 116, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 109,
  103, 61, 61, 49, 125, 32, 116, 50, 61, 123, 105, 102, 40, 36, 108, 101,
  102, 116, 62, 55, 44, 36, 116, 44, 105, 102, 40, 36, 108, 101, 102, 116,
  62, 51, 44, 105, 110, 116, 40, 49, 50, 42, 64, 124, 41, 37, 52, 44,
  105, 110, 116, 40, 50, 52, 42, 64, 124, 41, 37, 52, 41, 41, 125, 32,
  45, 106, 91, 45, 49, 93, 32, 91, 103, 104, 111, 115, 116, 97, 95, 36,
  116, 50, 93, 44, 36, 120, 103, 44, 36, 121, 103, 44, 48, 44, 48, 44,
  49, 44, 91, 103, 104, 111, 115, 116, 109, 95, 36, 116, 93, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 109, 103, 61, 61, 50, 125, 32, 45, 106, 91,
  45, 49, 93, 32, 91, 103, 104, 111, 115, 116, 100, 95, 36, 116, 93, 44,
  36, 120, 103, 44, 36, 121, 103, 44, 48, 44, 48, 44, 48, 46, 56, 44,
  91, 103, 104, 111, 115, 116, 100, 109, 93, 10, 45, 101, 108, 115, 101, 32,
  45, 106, 91, 45, 49, 93, 32, 91, 103, 104, 111, 115, 116, 36, 62, 95,
  36, 116, 93, 44, 36, 120, 103, 44, 36, 121, 103, 44, 48, 44, 48, 44,
  123, 36, 109, 103, 45, 50, 125, 44, 91, 103, 104, 111, 115, 116, 109, 95,
  36, 116, 93, 32, 45, 106, 91, 45, 49, 93, 32, 91, 103, 104, 111, 115,
  116, 100, 95, 36, 116, 93, 44, 36, 120, 103, 44, 36, 121, 103, 44, 48,
  44, 48, 44, 49, 44, 91, 103, 104, 111, 115, 116, 100, 109, 93, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32,
  36, 100, 121, 105, 110, 103, 95, 112, 97, 99, 109, 97, 110, 10, 45, 95,
  112, 97, 99, 109, 97, 110, 95, 112, 97, 99, 109, 97, 110, 95, 103, 102,
  120, 32, 123, 36, 100, 121, 105, 110, 103, 95, 112, 97, 99, 109, 97, 110,
  47, 50, 125, 32, 45, 114, 111, 116, 97, 116, 101, 91, 45, 50, 44, 45,
  49, 93, 32, 123, 57, 48, 42, 40, 97, 98, 115, 40, 36, 100, 112, 41,
  45, 49, 41, 125, 32, 45, 106, 91, 45, 51, 93, 32, 91, 45, 50, 93,
  44, 36, 120, 112, 44, 123, 50, 52, 43, 36, 121, 112, 125, 44, 48, 44,
  48, 44, 49, 44, 91, 45, 49, 93, 44, 50, 53, 53, 32, 45, 114, 109,
  91, 45, 50, 44, 45, 49, 93, 10, 100, 121, 105, 110, 103, 95, 112, 97,
  99, 109, 97, 110, 61, 123, 36, 100, 121, 105, 110, 103, 95, 112, 97, 99,
  109, 97, 110, 43, 49, 125, 10, 45, 105, 102, 32, 123, 36, 100, 121, 105,
  110, 103, 95, 112, 97, 99, 109, 97, 110, 62, 54, 52, 125, 10, 45, 105,
  102, 32, 123, 36, 108, 105, 118, 101, 115, 33, 61, 49, 125, 32, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 98, 114, 101, 97, 107, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 106, 91, 45, 49, 93, 32, 91, 103, 97, 109, 101,
  95, 111, 118, 101, 114, 93, 44, 123, 40, 119, 45, 64, 123, 103, 97, 109,
  101, 95, 111, 118, 101, 114, 44, 119, 125, 41, 47, 50, 125, 44, 123, 49,
  50, 43, 40, 104, 45, 64, 123, 103, 97, 109, 101, 95, 111, 118, 101, 114,
  44, 104, 125, 41, 47, 50, 125, 44, 48, 44, 48, 44, 123, 109, 105, 110,
  40, 49, 44, 40, 36, 100, 121, 105, 110, 103, 95, 112, 97, 99, 109, 97,
  110, 45, 54, 52, 41, 47, 53, 48, 41, 125, 44, 91, 103, 97, 109, 101,
  95, 111, 118, 101, 114, 109, 93, 44, 50, 53, 53, 10, 45, 114, 101, 99,
  116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 57, 48, 44, 55, 44,
  49, 48, 49, 44, 49, 56, 44, 49, 44, 48, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 108, 115, 101, 10, 45, 45, 114, 111, 116, 97, 116, 101,
  91, 112, 97, 99, 109, 97, 110, 95, 36, 116, 44, 112, 97, 99, 109, 97,
  110, 109, 95, 36, 116, 93, 32, 123, 57, 48, 42, 40, 97, 98, 115, 40,
  36, 100, 112, 41, 45, 49, 41, 125, 32, 45, 106, 91, 45, 51, 93, 32,
  91, 45, 50, 93, 44, 36, 120, 112, 44, 123, 50, 52, 43, 36, 121, 112,
  125, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 44, 50, 53, 53,
  32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 105, 102, 32,
  123, 36, 108, 101, 102, 116, 62, 61, 48, 34, 32, 38, 38, 32, 34, 40,
  36, 108, 101, 102, 116, 62, 61, 53, 34, 32, 124, 124, 32, 34, 36, 116,
  60, 61, 50, 41, 125, 32, 45, 106, 91, 45, 49, 93, 32, 91, 116, 105,
  109, 101, 123, 114, 111, 117, 110, 100, 40, 36, 108, 101, 102, 116, 41, 125,
  93, 44, 123, 40, 119, 45, 64, 123, 116, 105, 109, 101, 48, 44, 119, 125,
  41, 47, 50, 125, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 116, 91, 45, 49, 93, 32, 36, 115, 99, 111,
  114, 101, 44, 123, 119, 45, 54, 53, 125, 44, 49, 44, 50, 50, 44, 49,
  44, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36, 105, 115, 95, 103, 101,
  116, 95, 114, 101, 97, 100, 121, 125, 10, 45, 106, 91, 45, 49, 93, 32,
  91, 108, 101, 118, 101, 108, 95, 78, 93, 44, 123, 40, 119, 45, 64, 123,
  108, 101, 118, 101, 108, 95, 78, 44, 119, 125, 41, 47, 50, 125, 44, 123,
  49, 50, 43, 40, 104, 45, 49, 46, 53, 42, 64, 123, 108, 101, 118, 101,
  108, 95, 78, 44, 104, 125, 41, 47, 50, 125, 44, 48, 44, 48, 44, 49,
  44, 91, 108, 101, 118, 101, 108, 109, 95, 78, 93, 10, 45, 105, 102, 32,
  123, 105, 110, 116, 40, 64, 124, 42, 52, 41, 37, 50, 125, 32, 45, 106,
  91, 45, 49, 93, 32, 91, 103, 101, 116, 95, 114, 101, 97, 100, 121, 93,
  44, 123, 40, 119, 45, 64, 123, 103, 101, 116, 95, 114, 101, 97, 100, 121,
  44, 119, 125, 41, 47, 50, 125, 44, 123, 50, 52, 43, 40, 104, 43, 64,
  123, 103, 101, 116, 95, 114, 101, 97, 100, 121, 44, 104, 125, 41, 47, 50,
  125, 44, 48, 44, 48, 44, 49, 44, 91, 103, 101, 116, 95, 114, 101, 97,
  100, 121, 109, 93, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 111, 115, 99,
  111, 114, 101, 62, 48, 125, 32, 45, 106, 91, 45, 49, 93, 32, 91, 115,
  99, 111, 114, 101, 36, 110, 115, 99, 111, 114, 101, 93, 44, 36, 120, 115,
  99, 111, 114, 101, 44, 36, 121, 115, 99, 111, 114, 101, 44, 48, 44, 48,
  44, 36, 111, 115, 99, 111, 114, 101, 44, 91, 115, 99, 111, 114, 101, 109,
  36, 110, 115, 99, 111, 114, 101, 93, 44, 50, 53, 53, 32, 111, 115, 99,
  111, 114, 101, 61, 123, 36, 111, 115, 99, 111, 114, 101, 45, 48, 46, 48,
  52, 125, 32, 121, 115, 99, 111, 114, 101, 61, 123, 36, 121, 115, 99, 111,
  114, 101, 45, 49, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 106, 91,
  45, 49, 93, 32, 91, 103, 97, 116, 101, 93, 44, 49, 53, 56, 44, 50,
  50, 51, 44, 48, 44, 48, 44, 48, 46, 54, 10, 45, 119, 91, 45, 49,
  93, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76,
  69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 68, 125, 125, 32, 45, 119,
  91, 93, 32, 123, 50, 42, 119, 125, 44, 123, 50, 42, 104, 125, 32, 45,
  101, 108, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69,
  70, 84, 125, 38, 38, 64, 123, 33, 44, 67, 125, 125, 32, 45, 119, 91,
  93, 32, 123, 119, 125, 44, 123, 104, 125, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 52, 10, 120, 103, 61, 36, 123, 120, 103, 36, 62, 125, 32, 121, 103,
  61, 36, 123, 121, 103, 36, 62, 125, 32, 100, 103, 61, 36, 123, 100, 103,
  36, 62, 125, 32, 109, 103, 61, 36, 123, 109, 103, 36, 62, 125, 10, 45,
  105, 102, 32, 123, 109, 97, 120, 40, 97, 98, 115, 40, 36, 120, 103, 45,
  36, 120, 112, 41, 44, 97, 98, 115, 40, 36, 121, 103, 45, 36, 121, 112,
  41, 41, 60, 61, 56, 125, 10, 45, 105, 102, 32, 123, 36, 109, 103, 61,
  61, 48, 34, 32, 38, 38, 32, 34, 33, 36, 100, 121, 105, 110, 103, 95,
  112, 97, 99, 109, 97, 110, 125, 32, 100, 121, 105, 110, 103, 95, 112, 97,
  99, 109, 97, 110, 61, 49, 10, 120, 115, 99, 111, 114, 101, 61, 36, 120,
  112, 32, 121, 115, 99, 111, 114, 101, 61, 123, 36, 121, 112, 43, 49, 50,
  125, 32, 111, 115, 99, 111, 114, 101, 61, 49, 32, 110, 115, 99, 111, 114,
  101, 61, 52, 10, 45, 101, 108, 105, 102, 32, 123, 36, 109, 103, 61, 61,
  49, 125, 32, 109, 103, 61, 50, 32, 109, 103, 36, 62, 61, 36, 109, 103,
  32, 115, 99, 111, 114, 101, 61, 123, 36, 115, 99, 111, 114, 101, 43, 49,
  48, 48, 125, 10, 120, 115, 99, 111, 114, 101, 61, 36, 120, 112, 32, 121,
  115, 99, 111, 114, 101, 61, 123, 36, 121, 112, 43, 49, 50, 125, 32, 111,
  115, 99, 111, 114, 101, 61, 49, 32, 110, 115, 99, 111, 114, 101, 61, 49,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 109, 103, 62, 61, 50, 34, 32, 38, 38, 32, 34,
  40, 36, 120, 103, 62, 62, 52, 41, 61, 61, 36, 109, 119, 50, 34, 32,
  38, 38, 32, 34, 40, 36, 121, 103, 62, 62, 52, 41, 61, 61, 36, 109,
  104, 50, 125, 10, 109, 103, 61, 123, 36, 109, 103, 43, 48, 46, 48, 49,
  125, 10, 45, 105, 102, 32, 123, 36, 109, 103, 62, 61, 51, 125, 32, 109,
  103, 61, 48, 32, 120, 103, 61, 123, 36, 120, 103, 38, 45, 50, 125, 32,
  121, 103, 61, 123, 36, 121, 103, 38, 45, 50, 125, 32, 45, 101, 110, 100,
  105, 102, 10, 109, 103, 36, 62, 61, 36, 109, 103, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 33, 40, 36, 120, 103, 38, 49, 53,
  41, 34, 32, 38, 38, 32, 34, 33, 40, 36, 121, 103, 38, 49, 53, 41,
  125, 10, 40, 123, 63, 125, 44, 123, 63, 125, 44, 123, 63, 125, 44, 123,
  63, 125, 59, 48, 44, 49, 44, 50, 44, 51, 41, 10, 45, 105, 102, 32,
  123, 36, 109, 103, 60, 50, 125, 10, 45, 61, 91, 45, 49, 93, 32, 123,
  63, 40, 48, 46, 54, 44, 49, 41, 125, 44, 123, 105, 102, 40, 36, 109,
  103, 61, 61, 48, 44, 100, 88, 48, 61, 36, 120, 112, 45, 36, 120, 103,
  59, 100, 89, 48, 61, 36, 121, 112, 45, 36, 121, 103, 59, 105, 102, 40,
  97, 98, 115, 40, 100, 88, 48, 41, 62, 97, 98, 115, 40, 100, 89, 48,
  41, 44, 105, 102, 40, 100, 88, 48, 62, 48, 44, 48, 44, 50, 41, 44,
  105, 102, 40, 100, 89, 48, 62, 48, 44, 49, 44, 51, 41, 41, 44, 92,
  10, 100, 88, 49, 61, 36, 120, 112, 45, 36, 120, 103, 59, 100, 89, 49,
  61, 36, 121, 112, 45, 36, 121, 103, 59, 105, 102, 40, 97, 98, 115, 40,
  100, 88, 49, 41, 60, 97, 98, 115, 40, 100, 89, 49, 41, 44, 105, 102,
  40, 100, 88, 49, 62, 48, 44, 50, 44, 48, 41, 44, 105, 102, 40, 100,
  89, 49, 62, 48, 44, 51, 44, 49, 41, 41, 41, 125, 10, 45, 61, 91,
  45, 49, 93, 32, 48, 44, 123, 40, 36, 100, 103, 43, 50, 41, 37, 52,
  125, 10, 45, 105, 102, 32, 36, 105, 115, 95, 103, 101, 116, 95, 114, 101,
  97, 100, 121, 32, 45, 61, 91, 45, 49, 93, 32, 48, 46, 56, 44, 64,
  123, 112, 97, 116, 104, 44, 40, 123, 36, 120, 103, 62, 62, 52, 125, 44,
  123, 36, 121, 103, 62, 62, 52, 125, 41, 125, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 108, 115, 101, 32, 45, 61, 91, 45, 49, 93, 32, 49,
  44, 64, 123, 112, 97, 116, 104, 44, 40, 123, 36, 120, 103, 62, 62, 52,
  125, 44, 123, 36, 121, 103, 62, 62, 52, 125, 41, 125, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 115, 111, 114, 116, 91, 45, 49, 93, 32, 45, 44,
  120, 32, 45, 114, 101, 112, 101, 97, 116, 32, 52, 32, 100, 61, 123, 105,
  40, 36, 62, 44, 49, 41, 125, 32, 45, 105, 102, 32, 64, 123, 99, 97,
  110, 95, 103, 111, 44, 40, 123, 36, 120, 103, 62, 62, 52, 125, 44, 123,
  36, 121, 103, 62, 62, 52, 125, 44, 36, 100, 41, 125, 32, 100, 103, 61,
  36, 100, 32, 45, 98, 114, 101, 97, 107, 32, 45, 101, 110, 100, 105, 102,
  32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 45, 49, 93, 10, 100,
  103, 36, 62, 61, 36, 100, 10, 45, 101, 110, 100, 105, 102, 10, 117, 61,
  123, 68, 61, 36, 123, 100, 103, 36, 62, 125, 59, 40, 68, 61, 61, 48,
  41, 45, 40, 68, 61, 61, 50, 41, 125, 10, 118, 61, 123, 68, 61, 36,
  123, 100, 103, 36, 62, 125, 59, 40, 68, 61, 61, 49, 41, 45, 40, 68,
  61, 61, 51, 41, 125, 10, 120, 103, 36, 62, 61, 123, 40, 36, 120, 103,
  43, 36, 117, 42, 40, 49, 43, 40, 36, 109, 103, 61, 61, 48, 41, 41,
  41, 37, 40, 49, 54, 42, 36, 109, 119, 41, 125, 10, 121, 103, 36, 62,
  61, 123, 40, 36, 121, 103, 43, 36, 118, 42, 40, 49, 43, 40, 36, 109,
  103, 61, 61, 48, 41, 41, 41, 37, 40, 49, 54, 42, 36, 109, 104, 41,
  125, 10, 45, 100, 111, 110, 101, 10, 45, 119, 97, 105, 116, 32, 50, 50,
  10, 45, 105, 102, 32, 123, 33, 36, 100, 121, 105, 110, 103, 95, 112, 97,
  99, 109, 97, 110, 125, 10, 100, 61, 123, 105, 102, 40, 64, 123, 33, 44,
  65, 82, 82, 79, 87, 82, 73, 71, 72, 84, 125, 44, 49, 44, 105, 102,
  40, 64, 123, 33, 44, 65, 82, 82, 79, 87, 68, 79, 87, 78, 125, 44,
  50, 44, 105, 102, 40, 64, 123, 33, 44, 65, 82, 82, 79, 87, 76, 69,
  70, 84, 125, 44, 51, 44, 105, 102, 40, 64, 123, 33, 44, 65, 82, 82,
  79, 87, 85, 80, 125, 44, 52, 44, 36, 100, 112, 41, 41, 41, 41, 125,
  10, 45, 105, 102, 32, 123, 33, 40, 36, 120, 112, 38, 49, 53, 41, 34,
  32, 38, 38, 32, 34, 33, 40, 36, 121, 112, 38, 49, 53, 41, 125, 10,
  105, 61, 64, 123, 109, 97, 112, 44, 40, 123, 36, 120, 112, 62, 62, 52,
  125, 44, 123, 36, 121, 112, 62, 62, 52, 125, 41, 125, 10, 45, 105, 102,
  32, 123, 36, 105, 61, 61, 50, 125, 32, 115, 99, 111, 114, 101, 61, 123,
  36, 115, 99, 111, 114, 101, 43, 49, 48, 125, 32, 112, 97, 99, 100, 111,
  116, 115, 61, 123, 36, 112, 97, 99, 100, 111, 116, 115, 45, 49, 125, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 105, 61, 61, 51, 125, 32, 112, 97,
  99, 103, 117, 109, 95, 116, 105, 109, 101, 114, 61, 64, 124, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 52, 32, 45, 105, 102, 32, 123, 33, 36, 123,
  109, 103, 36, 62, 125, 125, 32, 109, 103, 36, 62, 61, 49, 32, 100, 103,
  36, 62, 61, 123, 40, 36, 123, 100, 103, 36, 62, 125, 43, 50, 41, 37,
  52, 125, 32, 45, 101, 110, 100, 105, 102, 32, 45, 100, 111, 110, 101, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 105, 62, 61, 52, 125, 32, 115, 99,
  111, 114, 101, 61, 123, 36, 115, 99, 111, 114, 101, 43, 36, 123, 115, 99,
  111, 114, 101, 123, 36, 105, 45, 52, 125, 125, 125, 32, 120, 115, 99, 111,
  114, 101, 61, 36, 120, 112, 32, 121, 115, 99, 111, 114, 101, 61, 123, 36,
  121, 112, 43, 49, 50, 125, 32, 111, 115, 99, 111, 114, 101, 61, 49, 32,
  110, 115, 99, 111, 114, 101, 61, 123, 36, 105, 45, 52, 125, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 61, 91, 109, 97, 112, 93, 32, 48, 44, 123,
  36, 120, 112, 62, 62, 52, 125, 44, 123, 36, 121, 112, 62, 62, 52, 125,
  10, 49, 54, 44, 49, 54, 44, 49, 44, 51, 32, 45, 106, 91, 118, 105,
  115, 117, 93, 32, 91, 45, 49, 93, 44, 36, 120, 112, 44, 123, 50, 52,
  43, 36, 121, 112, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 100, 61,
  123, 105, 102, 40, 64, 123, 99, 97, 110, 95, 103, 111, 44, 40, 123, 36,
  120, 112, 62, 62, 52, 125, 44, 123, 36, 121, 112, 62, 62, 52, 125, 44,
  123, 97, 98, 115, 40, 36, 100, 41, 45, 49, 125, 41, 125, 44, 36, 100,
  44, 36, 100, 112, 41, 125, 10, 100, 61, 123, 105, 102, 40, 64, 123, 99,
  97, 110, 95, 103, 111, 44, 40, 123, 36, 120, 112, 62, 62, 52, 125, 44,
  123, 36, 121, 112, 62, 62, 52, 125, 44, 123, 97, 98, 115, 40, 36, 100,
  41, 45, 49, 125, 41, 125, 44, 36, 100, 44, 45, 97, 98, 115, 40, 36,
  100, 112, 41, 41, 125, 10, 100, 112, 61, 36, 100, 10, 45, 101, 108, 115,
  101, 32, 100, 112, 61, 123, 105, 102, 40, 97, 98, 115, 40, 36, 100, 45,
  36, 100, 112, 41, 61, 61, 50, 44, 36, 100, 44, 36, 100, 112, 41, 125,
  10, 45, 101, 110, 100, 105, 102, 10, 105, 115, 95, 103, 101, 116, 95, 114,
  101, 97, 100, 121, 61, 123, 105, 102, 40, 36, 100, 112, 62, 48, 44, 48,
  44, 36, 105, 115, 95, 103, 101, 116, 95, 114, 101, 97, 100, 121, 41, 125,
  10, 117, 61, 123, 40, 36, 100, 112, 61, 61, 49, 41, 45, 40, 36, 100,
  112, 61, 61, 51, 41, 125, 10, 118, 61, 123, 40, 36, 100, 112, 61, 61,
  50, 41, 45, 40, 36, 100, 112, 61, 61, 52, 41, 125, 10, 120, 112, 61,
  123, 40, 36, 120, 112, 43, 50, 42, 36, 117, 41, 37, 40, 49, 54, 42,
  36, 109, 119, 41, 125, 10, 121, 112, 61, 123, 40, 36, 121, 112, 43, 50,
  42, 36, 118, 41, 37, 40, 49, 54, 42, 36, 109, 104, 41, 125, 10, 45,
  105, 102, 32, 123, 36, 112, 97, 99, 103, 117, 109, 95, 116, 105, 109, 101,
  114, 62, 61, 48, 34, 32, 38, 38, 32, 34, 64, 124, 62, 36, 112, 97,
  99, 103, 117, 109, 95, 116, 105, 109, 101, 114, 43, 49, 48, 125, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 52, 32, 120, 103, 36, 62, 61, 123, 36,
  123, 120, 103, 36, 62, 125, 38, 45, 50, 125, 32, 121, 103, 36, 62, 61,
  123, 36, 123, 121, 103, 36, 62, 125, 38, 45, 50, 125, 32, 109, 103, 36,
  62, 61, 123, 105, 102, 40, 36, 123, 109, 103, 36, 62, 125, 61, 61, 49,
  44, 48, 44, 36, 123, 109, 103, 36, 62, 125, 41, 125, 32, 45, 100, 111,
  110, 101, 10, 112, 97, 99, 103, 117, 109, 95, 116, 105, 109, 101, 114, 61,
  45, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 33,
  36, 105, 115, 95, 103, 101, 116, 95, 114, 101, 97, 100, 121, 34, 32, 38,
  38, 32, 34, 40, 64, 124, 45, 36, 102, 114, 117, 105, 116, 95, 116, 105,
  109, 101, 114, 41, 62, 61, 49, 48, 125, 10, 120, 61, 123, 114, 111, 117,
  110, 100, 40, 63, 40, 48, 44, 64, 123, 109, 97, 112, 48, 44, 119, 125,
  41, 41, 125, 10, 121, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 64, 123, 109, 97, 112, 48, 44, 104, 125, 41, 41, 125, 10, 45, 105,
  102, 32, 123, 33, 64, 123, 109, 97, 112, 44, 40, 36, 120, 44, 36, 121,
  41, 125, 34, 32, 38, 38, 32, 34, 64, 123, 109, 97, 112, 48, 44, 40,
  36, 120, 44, 36, 121, 41, 125, 61, 61, 50, 125, 10, 110, 61, 123, 109,
  105, 110, 40, 51, 44, 105, 110, 116, 40, 97, 98, 115, 40, 103, 42, 49,
  46, 55, 41, 41, 41, 125, 32, 45, 61, 91, 109, 97, 112, 93, 32, 123,
  52, 43, 36, 110, 125, 44, 36, 120, 44, 36, 121, 32, 45, 106, 91, 118,
  105, 115, 117, 93, 32, 91, 102, 114, 117, 105, 116, 36, 110, 93, 44, 123,
  49, 54, 42, 36, 120, 125, 44, 123, 49, 54, 42, 36, 121, 43, 50, 52,
  125, 32, 102, 114, 117, 105, 116, 95, 116, 105, 109, 101, 114, 61, 64, 124,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 33, 64, 33, 34, 32,
  124, 124, 32, 34, 64, 123, 33, 44, 81, 125, 34, 32, 124, 124, 32, 34,
  64, 123, 33, 44, 69, 83, 67, 125, 125, 32, 105, 115, 95, 113, 117, 105,
  116, 61, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 119, 104, 105, 108,
  101, 32, 123, 33, 36, 105, 115, 95, 113, 117, 105, 116, 34, 32, 38, 38,
  32, 34, 36, 112, 97, 99, 100, 111, 116, 115, 125, 10, 45, 105, 102, 32,
  36, 105, 115, 95, 113, 117, 105, 116, 32, 45, 98, 114, 101, 97, 107, 10,
  45, 101, 108, 105, 102, 32, 36, 112, 97, 99, 100, 111, 116, 115, 10, 108,
  105, 118, 101, 115, 61, 123, 36, 108, 105, 118, 101, 115, 45, 49, 125, 10,
  45, 101, 108, 115, 101, 10, 108, 101, 118, 101, 108, 61, 123, 45, 36, 108,
  101, 118, 101, 108, 45, 49, 125, 32, 45, 119, 97, 105, 116, 91, 48, 93,
  32, 45, 49, 10, 45, 114, 109, 91, 109, 97, 112, 48, 44, 109, 97, 112,
  44, 99, 97, 110, 95, 103, 111, 44, 112, 97, 116, 104, 93, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 109, 91, 118, 105, 115, 117, 44, 108, 101,
  118, 101, 108, 95, 78, 44, 108, 101, 118, 101, 108, 109, 95, 78, 93, 10,
  45, 119, 104, 105, 108, 101, 32, 36, 108, 105, 118, 101, 115, 10, 45, 114,
  109, 32, 45, 119, 32, 48, 32, 45, 118, 32, 43, 10, 95, 112, 97, 99,
  109, 97, 110, 95, 103, 104, 111, 115, 116, 95, 115, 116, 97, 110, 100, 97,
  114, 100, 95, 103, 102, 120, 32, 58, 10, 45, 95, 112, 97, 99, 109, 97,
  110, 95, 103, 104, 111, 115, 116, 95, 98, 97, 115, 101, 95, 103, 102, 120,
  32, 36, 52, 32, 40, 48, 44, 36, 49, 94, 48, 44, 36, 50, 94, 48,
  44, 36, 51, 41, 32, 45, 109, 97, 112, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 108, 105,
  112, 115, 101, 91, 45, 49, 93, 32, 49, 48, 44, 49, 49, 44, 51, 44,
  52, 44, 48, 44, 49, 44, 50, 53, 53, 32, 45, 101, 108, 108, 105, 112,
  115, 101, 91, 45, 49, 93, 32, 50, 48, 44, 49, 49, 44, 51, 44, 52,
  44, 48, 44, 49, 44, 50, 53, 53, 10, 45, 114, 91, 45, 49, 93, 32,
  49, 54, 44, 49, 54, 44, 49, 44, 51, 44, 50, 32, 45, 112, 111, 105,
  110, 116, 91, 45, 49, 93, 32, 53, 44, 123, 55, 45, 40, 36, 52, 62,
  61, 50, 41, 125, 44, 48, 44, 49, 44, 49, 32, 45, 112, 111, 105, 110,
  116, 91, 45, 49, 93, 32, 49, 48, 44, 123, 55, 45, 40, 36, 52, 62,
  61, 50, 41, 125, 44, 48, 44, 49, 44, 49, 10, 95, 112, 97, 99, 109,
  97, 110, 95, 103, 104, 111, 115, 116, 95, 97, 102, 114, 97, 105, 100, 95,
  103, 102, 120, 32, 58, 10, 45, 95, 112, 97, 99, 109, 97, 110, 95, 103,
  104, 111, 115, 116, 95, 98, 97, 115, 101, 95, 103, 102, 120, 32, 36, 49,
  10, 45, 105, 102, 32, 123, 36, 49, 60, 50, 125, 32, 99, 111, 108, 61,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 40, 48, 44, 48,
  94, 48, 44, 48, 94, 48, 44, 50, 48, 56, 41, 32, 45, 101, 108, 115,
  101, 32, 99, 111, 108, 61, 50, 53, 53, 44, 48, 44, 48, 32, 40, 48,
  44, 50, 52, 56, 94, 48, 44, 50, 52, 56, 94, 48, 44, 50, 52, 56,
  41, 32, 45, 101, 110, 100, 105, 102, 10, 45, 109, 97, 112, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  114, 91, 45, 49, 93, 32, 49, 54, 44, 49, 54, 44, 49, 44, 51, 44,
  50, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 52, 44, 52, 44,
  54, 44, 54, 44, 49, 44, 36, 99, 111, 108, 44, 50, 53, 53, 32, 45,
  108, 105, 110, 101, 91, 45, 49, 93, 32, 52, 44, 54, 44, 54, 44, 52,
  44, 49, 44, 36, 99, 111, 108, 44, 50, 53, 53, 10, 45, 108, 105, 110,
  101, 91, 45, 49, 93, 32, 57, 44, 52, 44, 49, 49, 44, 54, 44, 49,
  44, 36, 99, 111, 108, 44, 50, 53, 53, 32, 45, 108, 105, 110, 101, 91,
  45, 49, 93, 32, 57, 44, 54, 44, 49, 49, 44, 52, 44, 49, 44, 36,
  99, 111, 108, 44, 50, 53, 53, 10, 45, 102, 91, 45, 49, 93, 32, 39,
  105, 102, 40, 121, 62, 61, 57, 38, 38, 121, 60, 61, 49, 48, 38, 38,
  120, 62, 61, 50, 38, 38, 120, 60, 61, 49, 51, 38, 38, 40, 40, 105,
  110, 116, 40, 40, 120, 43, 49, 41, 47, 50, 41, 43, 121, 41, 37, 50,
  41, 44, 97, 114, 103, 40, 99, 43, 49, 44, 36, 99, 111, 108, 41, 44,
  105, 41, 39, 10, 95, 112, 97, 99, 109, 97, 110, 95, 112, 97, 99, 109,
  97, 110, 95, 103, 102, 120, 32, 58, 10, 51, 50, 44, 51, 50, 44, 49,
  44, 49, 44, 39, 88, 61, 120, 45, 49, 53, 59, 89, 61, 121, 45, 49,
  53, 59, 65, 61, 97, 116, 97, 110, 50, 40, 89, 44, 88, 41, 59, 82,
  61, 115, 113, 114, 116, 40, 88, 94, 50, 43, 89, 94, 50, 41, 59, 82,
  60, 49, 53, 46, 53, 38, 38, 97, 98, 115, 40, 65, 41, 62, 48, 46,
  56, 42, 48, 46, 51, 51, 42, 36, 49, 39, 10, 40, 48, 44, 50, 53,
  53, 94, 48, 44, 50, 53, 53, 94, 48, 44, 48, 94, 48, 44, 50, 53,
  53, 41, 32, 45, 109, 97, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 114, 91, 45, 49, 93, 32,
  49, 54, 44, 49, 54, 44, 49, 44, 52, 44, 50, 32, 45, 115, 91, 45,
  49, 93, 32, 99, 44, 45, 51, 10, 95, 112, 97, 99, 109, 97, 110, 95,
  112, 97, 99, 100, 111, 116, 115, 95, 103, 102, 120, 32, 58, 10, 40, 50,
  53, 53, 94, 49, 56, 52, 94, 49, 53, 49, 41, 32, 45, 114, 91, 45,
  49, 93, 32, 52, 44, 52, 44, 49, 44, 51, 32, 45, 114, 91, 45, 49,
  93, 32, 49, 54, 44, 49, 54, 44, 49, 44, 51, 44, 48, 44, 48, 44,
  48, 46, 53, 44, 48, 46, 53, 10, 95, 112, 97, 99, 109, 97, 110, 95,
  112, 97, 99, 103, 117, 109, 95, 103, 102, 120, 32, 58, 10, 49, 54, 44,
  49, 54, 44, 49, 44, 51, 32, 45, 99, 105, 114, 99, 108, 101, 91, 45,
  49, 93, 32, 55, 44, 55, 44, 55, 44, 49, 44, 50, 53, 53, 44, 49,
  50, 56, 44, 54, 52, 10, 95, 112, 97, 99, 109, 97, 110, 95, 99, 104,
  101, 114, 114, 121, 95, 103, 102, 120, 32, 58, 10, 40, 49, 50, 44, 49,
  50, 44, 49, 44, 49, 44, 48, 44, 45, 49, 48, 44, 45, 50, 44, 49,
  44, 45, 56, 44, 45, 52, 44, 49, 44, 45, 54, 44, 45, 50, 44, 49,
  44, 48, 44, 49, 44, 45, 55, 44, 48, 44, 49, 44, 45, 51, 44, 48,
  44, 49, 44, 45, 51, 44, 45, 52, 44, 50, 44, 45, 51, 44, 48, 44,
  49, 44, 45, 51, 44, 45, 54, 44, 50, 44, 48, 44, 49, 44, 45, 52,
  44, 45, 53, 44, 50, 44, 48, 44, 45, 52, 44, 50, 44, 45, 50, 44,
  92, 10, 48, 44, 50, 44, 51, 44, 45, 50, 44, 50, 44, 48, 44, 45,
  54, 44, 50, 44, 48, 44, 45, 50, 44, 50, 44, 51, 44, 50, 44, 48,
  44, 45, 54, 44, 50, 44, 45, 50, 44, 45, 51, 44, 50, 44, 48, 44,
  50, 44, 51, 44, 45, 52, 44, 50, 44, 45, 54, 44, 45, 50, 44, 50,
  44, 51, 44, 45, 51, 44, 50, 44, 45, 55, 44, 45, 52, 44, 50, 44,
  45, 50, 44, 48, 41, 10, 45, 117, 110, 99, 111, 109, 112, 114, 101, 115,
  115, 95, 114, 108, 101, 91, 45, 49, 93, 32, 40, 48, 44, 48, 44, 50,
  53, 53, 44, 50, 53, 53, 94, 48, 44, 49, 55, 51, 44, 48, 44, 50,
  53, 53, 94, 48, 44, 48, 44, 48, 44, 50, 53, 53, 41, 32, 45, 109,
  97, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 114, 50, 100, 121, 91, 45, 49, 93, 32, 49, 52,
  32, 45, 114, 91, 45, 49, 93, 32, 49, 54, 44, 49, 54, 44, 49, 44,
  51, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 95, 112,
  97, 99, 109, 97, 110, 95, 115, 116, 114, 97, 119, 98, 101, 114, 114, 121,
  95, 103, 102, 120, 32, 58, 10, 40, 49, 49, 44, 49, 50, 44, 49, 44,
  49, 44, 48, 44, 45, 53, 44, 48, 44, 51, 44, 45, 55, 44, 45, 51,
  44, 49, 44, 51, 44, 45, 51, 44, 49, 44, 45, 51, 44, 45, 50, 44,
  50, 44, 45, 53, 44, 49, 44, 45, 50, 44, 50, 44, 48, 44, 45, 52,
  44, 50, 44, 45, 51, 44, 49, 44, 45, 50, 44, 50, 44, 51, 44, 45,
  50, 44, 50, 44, 51, 44, 45, 53, 44, 50, 44, 51, 44, 45, 54, 44,
  50, 44, 51, 44, 92, 10, 50, 44, 51, 44, 45, 49, 51, 44, 50, 44,
  51, 44, 45, 50, 44, 50, 44, 48, 44, 50, 44, 51, 44, 45, 50, 44,
  50, 44, 51, 44, 45, 52, 44, 50, 44, 45, 50, 44, 45, 57, 44, 50,
  44, 45, 51, 44, 45, 50, 44, 50, 44, 51, 44, 45, 50, 44, 50, 44,
  51, 44, 45, 54, 44, 45, 53, 44, 50, 44, 45, 56, 44, 48, 44, 50,
  44, 45, 53, 44, 48, 41, 10, 45, 117, 110, 99, 111, 109, 112, 114, 101,
  115, 115, 95, 114, 108, 101, 91, 45, 49, 93, 32, 40, 48, 44, 48, 44,
  50, 53, 53, 44, 50, 53, 53, 94, 48, 44, 49, 55, 51, 44, 48, 44,
  50, 53, 53, 94, 48, 44, 48, 44, 48, 44, 50, 53, 53, 41, 32, 45,
  109, 97, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 114, 50, 100, 121, 91, 45, 49, 93, 32, 49,
  52, 32, 45, 114, 91, 45, 49, 93, 32, 49, 54, 44, 49, 54, 44, 49,
  44, 51, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 95,
  112, 97, 99, 109, 97, 110, 95, 111, 114, 97, 110, 103, 101, 95, 103, 102,
  120, 32, 58, 10, 40, 49, 50, 44, 49, 51, 44, 49, 44, 49, 44, 48,
  44, 45, 53, 44, 48, 44, 49, 44, 48, 44, 45, 50, 44, 49, 44, 45,
  56, 44, 45, 54, 44, 49, 44, 45, 54, 44, 48, 44, 49, 44, 51, 44,
  45, 51, 44, 49, 44, 45, 52, 44, 45, 51, 44, 50, 44, 49, 44, 45,
  52, 44, 50, 44, 45, 51, 44, 45, 49, 48, 44, 50, 44, 48, 44, 45,
  54, 48, 44, 50, 44, 48, 44, 45, 49, 48, 44, 50, 44, 45, 50, 44,
  45, 49, 48, 44, 50, 44, 45, 52, 44, 45, 54, 44, 50, 44, 45, 51,
  44, 48, 41, 10, 45, 117, 110, 99, 111, 109, 112, 114, 101, 115, 115, 95,
  114, 108, 101, 91, 45, 49, 93, 32, 40, 48, 44, 48, 44, 50, 53, 53,
  44, 50, 53, 53, 94, 48, 44, 49, 55, 51, 44, 49, 55, 51, 44, 50,
  53, 53, 94, 48, 44, 48, 44, 48, 44, 50, 53, 53, 41, 32, 45, 109,
  97, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 114, 50, 100, 121, 91, 45, 49, 93, 32, 49, 52,
  32, 45, 114, 91, 45, 49, 93, 32, 49, 54, 44, 49, 54, 44, 49, 44,
  51, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 95, 112,
  97, 99, 109, 97, 110, 95, 98, 97, 110, 97, 110, 97, 95, 103, 102, 120,
  32, 58, 10, 40, 57, 44, 49, 50, 44, 49, 44, 49, 44, 48, 44, 45,
  55, 44, 48, 44, 49, 44, 45, 55, 44, 45, 50, 44, 49, 44, 45, 55,
  44, 45, 51, 44, 49, 44, 45, 53, 44, 48, 44, 49, 44, 48, 44, 45,
  50, 44, 49, 44, 45, 53, 44, 48, 44, 49, 44, 48, 44, 45, 50, 44,
  49, 44, 45, 52, 44, 48, 44, 49, 44, 48, 44, 45, 51, 44, 49, 44,
  45, 52, 44, 48, 44, 49, 44, 48, 44, 45, 51, 44, 92, 10, 49, 44,
  45, 51, 44, 48, 44, 49, 44, 48, 44, 49, 44, 50, 44, 49, 44, 45,
  51, 44, 48, 44, 49, 44, 48, 44, 49, 44, 50, 44, 45, 50, 44, 49,
  44, 45, 50, 44, 48, 44, 49, 44, 48, 44, 49, 44, 50, 44, 45, 50,
  44, 49, 44, 45, 50, 44, 45, 54, 44, 49, 44, 45, 51, 44, 45, 52,
  44, 49, 44, 45, 53, 44, 48, 41, 10, 45, 117, 110, 99, 111, 109, 112,
  114, 101, 115, 115, 95, 114, 108, 101, 91, 45, 49, 93, 32, 40, 48, 44,
  50, 53, 53, 44, 50, 53, 53, 94, 48, 44, 49, 55, 51, 44, 50, 53,
  53, 94, 48, 44, 48, 44, 50, 53, 53, 41, 32, 45, 109, 97, 112, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 114, 50, 100, 121, 91, 45, 49, 93, 32, 49, 52, 32, 45, 114,
  91, 45, 49, 93, 32, 49, 54, 44, 49, 54, 44, 49, 44, 51, 44, 48,
  44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 95, 112, 97, 99, 109,
  97, 110, 95, 109, 97, 112, 95, 108, 101, 118, 101, 108, 49, 32, 58, 10,
  40, 49, 49, 44, 50, 56, 44, 49, 44, 49, 44, 48, 44, 45, 49, 50,
  44, 49, 44, 45, 53, 44, 50, 44, 49, 44, 45, 52, 44, 50, 44, 49,
  44, 51, 44, 45, 51, 44, 49, 44, 50, 44, 49, 44, 50, 44, 45, 52,
  44, 49, 44, 50, 44, 45, 51, 44, 49, 44, 50, 44, 49, 44, 50, 44,
  45, 52, 44, 49, 44, 45, 49, 48, 44, 50, 44, 45, 51, 44, 49, 44,
  50, 44, 49, 44, 50, 44, 45, 51, 44, 49, 44, 50, 44, 49, 44, 45,
  50, 44, 48, 44, 49, 44, 50, 44, 49, 44, 50, 44, 45, 51, 44, 49,
  44, 50, 44, 45, 52, 44, 49, 44, 92, 10, 50, 44, 49, 44, 50, 44,
  45, 51, 44, 49, 44, 50, 44, 49, 44, 45, 51, 44, 48, 44, 50, 44,
  49, 44, 45, 53, 44, 50, 44, 45, 52, 44, 49, 44, 50, 44, 45, 51,
  44, 49, 44, 48, 44, 45, 51, 44, 49, 44, 45, 50, 44, 48, 44, 49,
  44, 50, 44, 45, 51, 44, 49, 44, 48, 44, 45, 51, 44, 49, 44, 45,
  50, 44, 48, 44, 49, 44, 50, 44, 45, 57, 44, 48, 44, 49, 44, 50,
  44, 45, 51, 44, 49, 44, 48, 44, 45, 50, 44, 49, 44, 45, 51, 44,
  48, 44, 49, 44, 50, 44, 49, 44, 45, 51, 44, 48, 44, 49, 44, 45,
  52, 44, 92, 10, 48, 44, 49, 44, 50, 44, 49, 44, 48, 44, 49, 44,
  48, 44, 49, 44, 45, 50, 44, 45, 51, 44, 49, 44, 50, 44, 49, 44,
  48, 44, 49, 44, 48, 44, 45, 51, 44, 49, 44, 45, 51, 44, 48, 44,
  50, 44, 45, 50, 44, 48, 44, 49, 44, 45, 52, 44, 45, 51, 44, 49,
  44, 50, 44, 45, 53, 44, 49, 44, 48, 44, 49, 44, 45, 50, 44, 48,
  44, 49, 44, 45, 53, 44, 50, 44, 45, 50, 44, 48, 44, 49, 44, 45,
  50, 44, 48, 44, 49, 44, 50, 44, 45, 51, 44, 49, 44, 50, 44, 45,
  54, 44, 49, 44, 50, 44, 45, 51, 44, 49, 44, 50, 44, 92, 10, 45,
  52, 44, 49, 44, 45, 57, 44, 50, 44, 48, 44, 49, 44, 50, 44, 45,
  51, 44, 49, 44, 50, 44, 45, 51, 44, 49, 44, 50, 44, 45, 50, 44,
  49, 44, 50, 44, 45, 51, 44, 49, 44, 50, 44, 49, 44, 45, 51, 44,
  50, 44, 45, 50, 44, 49, 44, 51, 44, 45, 51, 44, 49, 44, 50, 44,
  49, 44, 50, 44, 45, 52, 44, 49, 44, 50, 44, 45, 51, 44, 49, 44,
  50, 44, 49, 44, 50, 44, 45, 52, 44, 49, 44, 45, 49, 48, 44, 50,
  44, 45, 49, 49, 44, 49, 41, 10, 45, 117, 110, 99, 111, 109, 112, 114,
  101, 115, 115, 95, 114, 108, 101, 91, 45, 49, 93, 32, 45, 45, 109, 105,
  114, 114, 111, 114, 91, 45, 49, 93, 32, 120, 32, 45, 99, 114, 111, 112,
  91, 45, 49, 93, 32, 49, 44, 49, 48, 48, 37, 32, 45, 97, 91, 45,
  50, 44, 45, 49, 93, 32, 120, 10, 95, 114, 108, 101, 118, 101, 108, 61,
  51, 51, 32, 95, 103, 108, 101, 118, 101, 108, 61, 51, 51, 32, 95, 98,
  108, 101, 118, 101, 108, 61, 50, 53, 53, 10, 95, 112, 97, 99, 109, 97,
  110, 95, 109, 97, 112, 95, 108, 101, 118, 101, 108, 50, 32, 58, 10, 40,
  49, 49, 44, 50, 56, 44, 49, 44, 49, 44, 48, 44, 45, 49, 50, 44,
  49, 44, 45, 49, 48, 44, 50, 44, 49, 44, 51, 44, 49, 44, 50, 44,
  45, 51, 44, 49, 44, 50, 44, 45, 52, 44, 49, 44, 50, 44, 49, 44,
  50, 44, 45, 51, 44, 49, 44, 50, 44, 49, 44, 45, 50, 44, 50, 44,
  49, 44, 50, 44, 49, 44, 45, 53, 44, 50, 44, 49, 44, 50, 44, 45,
  50, 44, 49, 44, 50, 44, 45, 51, 44, 49, 44, 50, 44, 49, 44, 50,
  44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 51, 44, 49,
  44, 50, 44, 49, 44, 50, 44, 49, 44, 92, 10, 50, 44, 45, 50, 44,
  49, 44, 45, 53, 44, 50, 44, 49, 44, 45, 51, 44, 50, 44, 45, 52,
  44, 49, 44, 50, 44, 45, 53, 44, 49, 44, 48, 44, 49, 44, 45, 50,
  44, 48, 44, 49, 44, 50, 44, 45, 53, 44, 49, 44, 48, 44, 49, 44,
  45, 50, 44, 48, 44, 49, 44, 50, 44, 45, 53, 44, 49, 44, 48, 44,
  49, 44, 45, 50, 44, 48, 44, 49, 44, 45, 51, 44, 50, 44, 49, 44,
  45, 52, 44, 45, 51, 44, 49, 44, 48, 44, 49, 44, 50, 44, 49, 44,
  48, 44, 45, 50, 44, 49, 44, 45, 53, 44, 48, 44, 49, 44, 50, 44,
  49, 44, 48, 44, 49, 44, 92, 10, 45, 50, 44, 45, 53, 44, 49, 44,
  50, 44, 45, 50, 44, 48, 44, 49, 44, 45, 50, 44, 45, 53, 44, 49,
  44, 50, 44, 49, 44, 48, 44, 45, 51, 44, 49, 44, 45, 52, 44, 48,
  44, 49, 44, 50, 44, 49, 44, 45, 52, 44, 45, 51, 44, 49, 44, 45,
  51, 44, 50, 44, 45, 51, 44, 49, 44, 48, 44, 49, 44, 45, 50, 44,
  48, 44, 49, 44, 50, 44, 49, 44, 45, 51, 44, 50, 44, 45, 50, 44,
  48, 44, 49, 44, 45, 50, 44, 48, 44, 49, 44, 50, 44, 45, 51, 44,
  49, 44, 50, 44, 49, 44, 48, 44, 45, 52, 44, 49, 44, 50, 44, 45,
  51, 44, 49, 44, 92, 10, 50, 44, 49, 44, 48, 44, 45, 50, 44, 49,
  44, 45, 55, 44, 50, 44, 49, 44, 45, 50, 44, 48, 44, 49, 44, 50,
  44, 45, 51, 44, 49, 44, 50, 44, 49, 44, 50, 44, 45, 52, 44, 49,
  44, 50, 44, 49, 44, 45, 51, 44, 50, 44, 49, 44, 45, 52, 44, 50,
  44, 49, 44, 51, 44, 49, 44, 50, 44, 45, 53, 44, 49, 44, 50, 44,
  45, 50, 44, 49, 44, 50, 44, 49, 44, 50, 44, 45, 53, 44, 49, 44,
  50, 44, 45, 50, 44, 49, 44, 45, 57, 44, 50, 44, 45, 49, 50, 44,
  49, 41, 10, 45, 117, 110, 99, 111, 109, 112, 114, 101, 115, 115, 95, 114,
  108, 101, 91, 45, 49, 93, 32, 45, 45, 109, 105, 114, 114, 111, 114, 91,
  45, 49, 93, 32, 120, 32, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32,
  49, 44, 49, 48, 48, 37, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93,
  32, 120, 10, 95, 114, 108, 101, 118, 101, 108, 61, 50, 48, 48, 32, 95,
  103, 108, 101, 118, 101, 108, 61, 51, 51, 32, 95, 98, 108, 101, 118, 101,
  108, 61, 51, 51, 10, 95, 112, 97, 99, 109, 97, 110, 95, 109, 97, 112,
  95, 108, 101, 118, 101, 108, 51, 32, 58, 10, 40, 49, 49, 44, 50, 56,
  44, 49, 44, 49, 44, 48, 44, 45, 49, 49, 44, 49, 44, 45, 54, 44,
  48, 44, 49, 44, 45, 52, 44, 50, 44, 45, 53, 44, 49, 44, 48, 44,
  49, 44, 50, 44, 45, 56, 44, 49, 44, 48, 44, 49, 44, 50, 44, 45,
  52, 44, 49, 44, 51, 44, 45, 56, 44, 50, 44, 45, 50, 44, 49, 44,
  50, 44, 45, 53, 44, 49, 44, 50, 44, 49, 44, 50, 44, 45, 50, 44,
  49, 44, 50, 44, 45, 53, 44, 49, 44, 50, 44, 49, 44, 50, 44, 45,
  50, 44, 49, 44, 50, 44, 49, 44, 45, 53, 44, 50, 44, 49, 44, 50,
  44, 45, 50, 44, 49, 44, 50, 44, 92, 10, 49, 44, 50, 44, 45, 51,
  44, 49, 44, 48, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 45, 53,
  44, 50, 44, 49, 44, 48, 44, 49, 44, 45, 50, 44, 50, 44, 45, 53,
  44, 49, 44, 50, 44, 49, 44, 48, 44, 45, 52, 44, 49, 44, 45, 53,
  44, 50, 44, 49, 44, 45, 52, 44, 48, 44, 49, 44, 50, 44, 45, 51,
  44, 49, 44, 50, 44, 49, 44, 48, 44, 45, 50, 44, 49, 44, 48, 44,
  49, 44, 50, 44, 45, 51, 44, 49, 44, 50, 44, 49, 44, 48, 44, 49,
  44, 45, 50, 44, 48, 44, 49, 44, 45, 51, 44, 50, 44, 49, 44, 50,
  44, 45, 50, 44, 48, 44, 49, 44, 92, 10, 45, 50, 44, 45, 51, 44,
  49, 44, 50, 44, 49, 44, 50, 44, 49, 44, 48, 44, 45, 51, 44, 49,
  44, 45, 50, 44, 48, 44, 49, 44, 50, 44, 49, 44, 50, 44, 49, 44,
  45, 54, 44, 48, 44, 49, 44, 50, 44, 49, 44, 50, 44, 45, 50, 44,
  49, 44, 48, 44, 45, 50, 44, 49, 44, 45, 50, 44, 48, 44, 49, 44,
  50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 48, 44, 45, 50, 44,
  49, 44, 45, 50, 44, 48, 44, 49, 44, 45, 54, 44, 50, 44, 45, 53,
  44, 49, 44, 50, 44, 45, 52, 44, 49, 44, 50, 44, 45, 50, 44, 49,
  44, 45, 51, 44, 45, 51, 44, 50, 44, 92, 10, 49, 44, 45, 51, 44,
  50, 44, 48, 44, 45, 51, 44, 49, 44, 50, 44, 49, 44, 50, 44, 49,
  44, 50, 44, 45, 52, 44, 49, 44, 51, 44, 45, 50, 44, 50, 44, 49,
  44, 45, 53, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 51, 44,
  49, 44, 50, 44, 45, 51, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44,
  50, 44, 45, 51, 44, 49, 44, 50, 44, 45, 51, 44, 49, 44, 50, 44,
  45, 50, 44, 49, 44, 45, 49, 48, 44, 50, 44, 45, 49, 49, 44, 49,
  41, 10, 45, 117, 110, 99, 111, 109, 112, 114, 101, 115, 115, 95, 114, 108,
  101, 91, 45, 49, 93, 32, 45, 45, 109, 105, 114, 114, 111, 114, 91, 45,
  49, 93, 32, 120, 32, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 49,
  44, 49, 48, 48, 37, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32,
  120, 10, 95, 114, 108, 101, 118, 101, 108, 61, 51, 51, 32, 95, 103, 108,
  101, 118, 101, 108, 61, 50, 48, 48, 32, 95, 98, 108, 101, 118, 101, 108,
  61, 50, 53, 53, 10, 95, 112, 97, 99, 109, 97, 110, 95, 109, 97, 112,
  95, 108, 101, 118, 101, 108, 52, 32, 58, 10, 40, 49, 49, 44, 50, 56,
  44, 49, 44, 49, 44, 48, 44, 45, 57, 44, 49, 44, 45, 50, 44, 48,
  44, 49, 44, 45, 55, 44, 50, 44, 49, 44, 45, 50, 44, 48, 44, 49,
  44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50,
  44, 49, 44, 45, 50, 44, 48, 44, 49, 44, 50, 44, 45, 50, 44, 49,
  44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 49, 44, 45, 50, 44, 48,
  44, 49, 44, 45, 51, 44, 50, 44, 51, 44, 45, 51, 44, 50, 44, 45,
  52, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 50, 44,
  49, 44, 45, 52, 44, 50, 44, 49, 44, 50, 44, 92, 10, 45, 50, 44,
  49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44,
  50, 44, 49, 44, 45, 55, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44,
  49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44,
  45, 52, 44, 50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44,
  45, 50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 49, 44,
  45, 55, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 51, 44, 49,
  44, 45, 49, 48, 44, 48, 44, 49, 44, 45, 53, 44, 45, 50, 44, 49,
  44, 48, 44, 45, 51, 44, 49, 44, 45, 53, 44, 48, 44, 49, 44, 92,
  10, 45, 49, 48, 44, 48, 44, 49, 44, 45, 50, 44, 45, 51, 44, 49,
  44, 45, 53, 44, 45, 54, 44, 49, 44, 45, 56, 44, 48, 44, 49, 44,
  50, 44, 45, 57, 44, 48, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44,
  50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44,
  49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44,
  50, 44, 45, 50, 44, 49, 44, 50, 44, 49, 44, 45, 49, 48, 44, 50,
  44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 50, 44, 49,
  44, 50, 44, 45, 51, 44, 48, 44, 49, 44, 50, 44, 45, 50, 44, 49,
  44, 50, 44, 92, 10, 45, 50, 44, 49, 44, 50, 44, 48, 44, 45, 51,
  44, 49, 44, 45, 51, 44, 50, 44, 51, 44, 45, 52, 44, 50, 44, 49,
  44, 48, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 50,
  44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 48, 44, 49, 44, 50, 44,
  45, 50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 49, 44,
  45, 50, 44, 48, 44, 49, 44, 45, 55, 44, 50, 44, 49, 44, 45, 50,
  44, 45, 57, 44, 49, 44, 45, 50, 44, 48, 41, 10, 45, 117, 110, 99,
  111, 109, 112, 114, 101, 115, 115, 95, 114, 108, 101, 91, 45, 49, 93, 32,
  45, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 120, 32, 45,
  99, 114, 111, 112, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48, 37, 32,
  45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 10, 95, 114, 108, 101,
  118, 101, 108, 61, 50, 48, 48, 32, 95, 103, 108, 101, 118, 101, 108, 61,
  50, 48, 48, 32, 95, 98, 108, 101, 118, 101, 108, 61, 51, 51, 10, 95,
  112, 97, 99, 109, 97, 110, 95, 109, 97, 112, 95, 108, 101, 118, 101, 108,
  53, 32, 58, 10, 40, 49, 49, 44, 50, 56, 44, 49, 44, 49, 44, 48,
  44, 45, 49, 50, 44, 49, 44, 45, 55, 44, 50, 44, 49, 44, 45, 50,
  44, 50, 44, 49, 44, 51, 44, 45, 53, 44, 49, 44, 50, 44, 49, 44,
  50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 53, 44, 49, 44, 50, 44,
  49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 49, 44, 45, 55, 44,
  50, 44, 45, 50, 44, 49, 44, 45, 51, 44, 50, 44, 49, 44, 50, 44,
  45, 51, 44, 49, 44, 50, 44, 45, 52, 44, 49, 44, 50, 44, 49, 44,
  50, 44, 49, 44, 48, 44, 49, 44, 50, 44, 45, 52, 44, 49, 44, 50,
  44, 49, 44, 50, 44, 92, 10, 45, 51, 44, 49, 44, 50, 44, 49, 44,
  45, 52, 44, 48, 44, 49, 44, 45, 54, 44, 50, 44, 49, 44, 50, 44,
  49, 44, 48, 44, 45, 51, 44, 49, 44, 48, 44, 45, 52, 44, 49, 44,
  50, 44, 49, 44, 48, 44, 45, 51, 44, 49, 44, 48, 44, 45, 52, 44,
  49, 44, 50, 44, 49, 44, 45, 56, 44, 48, 44, 49, 44, 50, 44, 45,
  51, 44, 49, 44, 48, 44, 49, 44, 48, 44, 45, 50, 44, 49, 44, 48,
  44, 49, 44, 50, 44, 45, 51, 44, 49, 44, 48, 44, 49, 44, 48, 44,
  49, 44, 45, 50, 44, 48, 44, 49, 44, 50, 44, 45, 52, 44, 48, 44,
  49, 44, 48, 44, 49, 44, 45, 50, 44, 92, 10, 48, 44, 49, 44, 50,
  44, 49, 44, 48, 44, 45, 51, 44, 49, 44, 48, 44, 45, 52, 44, 49,
  44, 50, 44, 49, 44, 45, 56, 44, 48, 44, 49, 44, 50, 44, 45, 51,
  44, 49, 44, 48, 44, 45, 51, 44, 49, 44, 48, 44, 45, 50, 44, 49,
  44, 45, 53, 44, 50, 44, 49, 44, 45, 51, 44, 50, 44, 45, 52, 44,
  49, 44, 50, 44, 49, 44, 50, 44, 49, 44, 50, 44, 45, 54, 44, 49,
  44, 50, 44, 49, 44, 50, 44, 49, 44, 50, 44, 45, 52, 44, 49, 44,
  51, 44, 45, 50, 44, 50, 44, 49, 44, 45, 53, 44, 50, 44, 48, 44,
  49, 44, 50, 44, 45, 51, 44, 49, 44, 50, 44, 45, 51, 44, 92, 10,
  49, 44, 50, 44, 45, 50, 44, 49, 44, 45, 53, 44, 50, 44, 49, 44,
  45, 51, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 51, 44, 49,
  44, 50, 44, 49, 44, 50, 44, 45, 52, 44, 49, 44, 50, 44, 45, 51,
  44, 49, 44, 50, 44, 49, 44, 50, 44, 45, 52, 44, 49, 44, 45, 53,
  44, 50, 44, 49, 44, 45, 52, 44, 50, 44, 45, 49, 49, 44, 49, 41,
  10, 45, 117, 110, 99, 111, 109, 112, 114, 101, 115, 115, 95, 114, 108, 101,
  91, 45, 49, 93, 32, 45, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49,
  93, 32, 120, 32, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 49, 44,
  49, 48, 48, 37, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120,
  10, 95, 114, 108, 101, 118, 101, 108, 61, 50, 48, 48, 32, 95, 103, 108,
  101, 118, 101, 108, 61, 50, 53, 53, 32, 95, 98, 108, 101, 118, 101, 108,
  61, 51, 51, 10, 95, 112, 97, 99, 109, 97, 110, 95, 109, 97, 112, 95,
  108, 101, 118, 101, 108, 54, 32, 58, 10, 40, 49, 49, 44, 50, 56, 44,
  49, 44, 49, 44, 48, 44, 45, 49, 50, 44, 49, 44, 45, 49, 48, 44,
  50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 55, 44,
  49, 44, 51, 44, 45, 57, 44, 50, 44, 45, 53, 44, 49, 44, 50, 44,
  45, 54, 44, 49, 44, 45, 49, 48, 44, 50, 44, 49, 44, 50, 44, 45,
  52, 44, 49, 44, 48, 44, 45, 53, 44, 49, 44, 50, 44, 49, 44, 45,
  56, 44, 48, 44, 49, 44, 50, 44, 49, 44, 48, 44, 45, 51, 44, 49,
  44, 48, 44, 45, 51, 44, 49, 44, 48, 44, 50, 44, 49, 44, 48, 44,
  49, 44, 45, 54, 44, 50, 44, 49, 44, 50, 44, 92, 10, 45, 50, 44,
  48, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 48, 44, 45, 51, 44,
  49, 44, 50, 44, 49, 44, 45, 50, 44, 48, 44, 50, 44, 49, 44, 45,
  52, 44, 48, 44, 49, 44, 50, 44, 49, 44, 48, 44, 49, 44, 50, 44,
  45, 50, 44, 45, 50, 44, 49, 44, 48, 44, 49, 44, 50, 44, 49, 44,
  48, 44, 49, 44, 50, 44, 49, 44, 48, 44, 49, 44, 45, 50, 44, 48,
  44, 49, 44, 50, 44, 49, 44, 48, 44, 49, 44, 50, 44, 49, 44, 48,
  44, 49, 44, 45, 50, 44, 48, 44, 49, 44, 50, 44, 49, 44, 48, 44,
  49, 44, 50, 44, 45, 50, 44, 45, 52, 44, 49, 44, 50, 44, 92, 10,
  49, 44, 45, 50, 44, 48, 44, 50, 44, 49, 44, 45, 52, 44, 48, 44,
  49, 44, 50, 44, 45, 50, 44, 48, 44, 49, 44, 50, 44, 45, 50, 44,
  49, 44, 48, 44, 45, 50, 44, 49, 44, 48, 44, 50, 44, 49, 44, 48,
  44, 49, 44, 45, 54, 44, 50, 44, 49, 44, 50, 44, 49, 44, 48, 44,
  45, 51, 44, 49, 44, 48, 44, 45, 52, 44, 49, 44, 50, 44, 49, 44,
  45, 56, 44, 48, 44, 49, 44, 50, 44, 45, 52, 44, 49, 44, 48, 44,
  45, 51, 44, 49, 44, 48, 44, 49, 44, 45, 49, 48, 44, 50, 44, 45,
  53, 44, 49, 44, 50, 44, 45, 54, 44, 49, 44, 51, 44, 45, 57, 44,
  92, 10, 50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45,
  55, 44, 49, 44, 45, 49, 48, 44, 50, 44, 45, 49, 49, 44, 49, 41,
  10, 45, 117, 110, 99, 111, 109, 112, 114, 101, 115, 115, 95, 114, 108, 101,
  91, 45, 49, 93, 32, 45, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49,
  93, 32, 120, 32, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 49, 44,
  49, 48, 48, 37, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120,
  10, 95, 114, 108, 101, 118, 101, 108, 61, 50, 53, 53, 32, 95, 103, 108,
  101, 118, 101, 108, 61, 49, 51, 48, 32, 95, 98, 108, 101, 118, 101, 108,
  61, 50, 51, 51, 10, 35, 64, 103, 109, 105, 99, 32, 120, 95, 112, 97,
  105, 110, 116, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 76, 97, 117,
  110, 99, 104, 32, 116, 104, 101, 32, 105, 110, 116, 101, 114, 97, 99, 116,
  105, 118, 101, 32, 112, 97, 105, 110, 116, 101, 114, 46, 10, 120, 95, 112,
  97, 105, 110, 116, 32, 58, 10, 45, 101, 91, 93, 32, 34, 92, 110, 10,
  45, 45, 45, 45, 45, 45, 32, 73, 110, 116, 101, 114, 97, 99, 116, 105,
  118, 101, 32, 112, 97, 105, 110, 116, 101, 114, 32, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45,
  32, 85, 115, 101, 32, 109, 111, 117, 115, 101, 32, 116, 111, 32, 115, 101,
  108, 101, 99, 116, 32, 99, 111, 108, 111, 114, 32, 97, 110, 100, 32, 98,
  114, 117, 115, 104, 46, 92, 110, 10, 45, 45, 45, 45, 32, 76, 101, 102,
  116, 32, 98, 117, 116, 116, 111, 110, 32, 100, 114, 97, 119, 115, 32, 97,
  32, 99, 111, 108, 111, 114, 101, 100, 32, 115, 116, 114, 111, 107, 101, 46,
  92, 110, 10, 45, 45, 45, 45, 32, 82, 105, 103, 104, 116, 32, 98, 117,
  116, 116, 111, 110, 32, 102, 105, 108, 108, 115, 32, 97, 32, 99, 111, 108,
  111, 114, 101, 100, 32, 114, 101, 103, 105, 111, 110, 46, 92, 110, 10, 45,
  45, 45, 45, 32, 65, 114, 114, 111, 119, 32, 107, 101, 121, 115, 32, 111,
  114, 32, 83, 80, 65, 67, 69, 32, 97, 110, 100, 32, 66, 65, 67, 75,
  83, 80, 65, 67, 69, 32, 116, 111, 32, 115, 119, 97, 112, 92, 110, 10,
  45, 45, 45, 45, 32, 98, 101, 116, 119, 101, 101, 110, 32, 97, 118, 97,
  105, 108, 97, 98, 108, 101, 32, 105, 109, 97, 103, 101, 115, 46, 92, 110,
  10, 45, 45, 45, 45, 32, 75, 101, 121, 32, 39, 83, 39, 32, 116, 111,
  32, 115, 97, 118, 101, 32, 115, 110, 97, 112, 115, 104, 111, 116, 32, 111,
  102, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 118, 105,
  101, 119, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32,
  39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81, 39, 32, 116, 111, 32,
  101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 34, 10, 45, 118, 32, 45, 32, 45, 116, 111, 95, 114, 103, 98, 10,
  45, 105, 102, 32, 123, 33, 64, 35, 125, 32, 45, 105, 91, 48, 93, 32,
  53, 49, 50, 44, 53, 49, 50, 44, 49, 44, 51, 44, 50, 53, 53, 32,
  45, 110, 109, 91, 48, 93, 32, 34, 91, 78, 101, 119, 32, 105, 109, 97,
  103, 101, 93, 34, 32, 45, 101, 110, 100, 105, 102, 10, 99, 111, 108, 111,
  114, 61, 48, 44, 48, 44, 48, 10, 115, 97, 116, 117, 114, 97, 116, 105,
  111, 110, 61, 49, 10, 98, 114, 117, 115, 104, 115, 105, 122, 101, 61, 51,
  10, 98, 114, 117, 115, 104, 111, 112, 97, 99, 105, 116, 121, 61, 48, 10,
  98, 114, 117, 115, 104, 97, 110, 103, 108, 101, 61, 57, 48, 10, 98, 114,
  117, 115, 104, 116, 104, 105, 99, 107, 110, 101, 115, 115, 61, 49, 10, 105,
  109, 97, 103, 101, 61, 48, 10, 114, 101, 102, 114, 101, 115, 104, 95, 112,
  97, 108, 101, 116, 116, 101, 61, 49, 10, 114, 101, 102, 114, 101, 115, 104,
  95, 105, 109, 97, 103, 101, 61, 49, 10, 114, 101, 102, 114, 101, 115, 104,
  95, 98, 114, 117, 115, 104, 61, 49, 10, 111, 120, 49, 61, 45, 49, 10,
  111, 121, 49, 61, 45, 49, 10, 49, 32, 49, 10, 45, 100, 111, 10, 45,
  105, 102, 32, 36, 114, 101, 102, 114, 101, 115, 104, 95, 112, 97, 108, 101,
  116, 116, 101, 10, 45, 114, 109, 91, 45, 50, 93, 32, 40, 48, 44, 51,
  53, 57, 59, 48, 44, 51, 53, 57, 94, 36, 115, 97, 116, 117, 114, 97,
  116, 105, 111, 110, 44, 36, 115, 97, 116, 117, 114, 97, 116, 105, 111, 110,
  59, 36, 115, 97, 116, 117, 114, 97, 116, 105, 111, 110, 44, 36, 115, 97,
  116, 117, 114, 97, 116, 105, 111, 110, 94, 49, 44, 49, 59, 48, 44, 48,
  41, 32, 45, 114, 91, 45, 49, 93, 32, 50, 53, 54, 44, 54, 52, 44,
  49, 44, 51, 44, 51, 32, 45, 104, 115, 118, 50, 114, 103, 98, 91, 45,
  49, 93, 10, 40, 50, 53, 53, 59, 48, 41, 32, 45, 114, 91, 45, 49,
  93, 32, 49, 54, 44, 64, 123, 45, 50, 44, 104, 125, 44, 49, 44, 51,
  44, 51, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 48, 44, 48,
  44, 48, 44, 49, 48, 48, 37, 44, 49, 44, 48, 32, 45, 97, 91, 45,
  50, 44, 45, 49, 93, 32, 120, 10, 123, 119, 125, 44, 49, 54, 44, 49,
  44, 51, 32, 45, 116, 91, 45, 49, 93, 32, 34, 83, 101, 108, 101, 99,
  116, 101, 100, 32, 99, 111, 108, 111, 114, 34, 44, 52, 44, 50, 44, 49,
  51, 44, 49, 44, 50, 53, 53, 10, 45, 114, 101, 99, 116, 97, 110, 103,
  108, 101, 91, 45, 49, 93, 32, 56, 48, 44, 51, 44, 49, 48, 48, 44,
  49, 51, 44, 49, 44, 36, 99, 111, 108, 111, 114, 10, 45, 114, 101, 99,
  116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 56, 48, 44, 51, 44,
  49, 48, 48, 44, 49, 51, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70,
  70, 70, 70, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10,
  45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 32, 45, 119, 50, 91,
  45, 49, 93, 32, 123, 119, 125, 44, 123, 104, 125, 44, 48, 44, 34, 80,
  97, 108, 101, 116, 116, 101, 34, 32, 45, 109, 118, 91, 45, 49, 93, 32,
  45, 50, 10, 114, 101, 102, 114, 101, 115, 104, 95, 112, 97, 108, 101, 116,
  116, 101, 61, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  36, 114, 101, 102, 114, 101, 115, 104, 95, 98, 114, 117, 115, 104, 10, 45,
  114, 109, 91, 45, 49, 93, 32, 40, 51, 50, 44, 54, 52, 59, 54, 52,
  44, 51, 50, 41, 32, 45, 114, 91, 45, 49, 93, 32, 49, 54, 44, 49,
  54, 44, 49, 44, 51, 44, 49, 32, 45, 114, 91, 45, 49, 93, 32, 123,
  56, 42, 52, 56, 125, 44, 123, 52, 42, 52, 56, 125, 44, 49, 44, 51,
  44, 48, 44, 50, 10, 45, 114, 101, 112, 101, 97, 116, 32, 52, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 56, 10, 45, 101, 108, 108, 105, 112, 115,
  101, 91, 45, 49, 93, 32, 123, 52, 56, 42, 36, 62, 43, 50, 52, 125,
  44, 123, 52, 56, 42, 64, 123, 62, 44, 45, 50, 125, 43, 50, 52, 125,
  44, 123, 50, 42, 36, 62, 43, 49, 125, 44, 123, 40, 50, 42, 36, 62,
  43, 49, 41, 42, 36, 98, 114, 117, 115, 104, 116, 104, 105, 99, 107, 110,
  101, 115, 115, 125, 44, 36, 98, 114, 117, 115, 104, 97, 110, 103, 108, 101,
  44, 123, 49, 45, 64, 123, 62, 44, 45, 50, 125, 47, 52, 125, 44, 50,
  53, 53, 10, 45, 100, 111, 110, 101, 32, 45, 100, 111, 110, 101, 10, 45,
  114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 123, 36,
  98, 114, 117, 115, 104, 115, 105, 122, 101, 42, 52, 56, 125, 44, 123, 36,
  98, 114, 117, 115, 104, 111, 112, 97, 99, 105, 116, 121, 42, 52, 56, 125,
  44, 92, 10, 123, 36, 98, 114, 117, 115, 104, 115, 105, 122, 101, 42, 52,
  56, 43, 52, 55, 125, 44, 123, 36, 98, 114, 117, 115, 104, 111, 112, 97,
  99, 105, 116, 121, 42, 52, 56, 43, 52, 55, 125, 44, 92, 10, 49, 44,
  48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 50, 53, 53, 44, 49,
  50, 56, 44, 49, 50, 56, 10, 123, 119, 125, 44, 49, 54, 44, 49, 44,
  51, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 48, 44, 53, 48,
  37, 44, 49, 48, 48, 37, 44, 53, 48, 37, 44, 49, 44, 48, 120, 53,
  53, 53, 53, 53, 53, 53, 53, 44, 49, 50, 56, 44, 54, 52, 44, 49,
  50, 56, 10, 98, 120, 61, 123, 36, 98, 114, 117, 115, 104, 97, 110, 103,
  108, 101, 42, 119, 47, 49, 56, 48, 125, 10, 45, 114, 101, 99, 116, 97,
  110, 103, 108, 101, 91, 45, 49, 93, 32, 123, 36, 98, 120, 45, 49, 54,
  125, 44, 50, 48, 37, 44, 123, 36, 98, 120, 43, 49, 54, 125, 44, 56,
  48, 37, 44, 49, 44, 49, 50, 56, 10, 45, 108, 105, 110, 101, 91, 45,
  49, 93, 32, 123, 36, 98, 120, 45, 49, 54, 125, 44, 50, 48, 37, 44,
  123, 36, 98, 120, 43, 49, 54, 125, 44, 50, 48, 37, 44, 49, 44, 50,
  53, 53, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 123, 36, 98,
  120, 43, 49, 54, 125, 44, 50, 48, 37, 44, 123, 36, 98, 120, 43, 49,
  54, 125, 44, 56, 48, 37, 44, 49, 44, 50, 53, 53, 10, 45, 108, 105,
  110, 101, 91, 45, 49, 93, 32, 123, 36, 98, 120, 45, 49, 54, 125, 44,
  56, 48, 37, 44, 123, 36, 98, 120, 43, 49, 54, 125, 44, 56, 48, 37,
  44, 49, 44, 54, 52, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32,
  123, 36, 98, 120, 45, 49, 54, 125, 44, 50, 48, 37, 44, 123, 36, 98,
  120, 45, 49, 54, 125, 44, 56, 48, 37, 44, 49, 44, 54, 52, 10, 45,
  97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 10, 49, 54, 44, 123, 104,
  45, 49, 54, 125, 44, 49, 44, 51, 32, 45, 108, 105, 110, 101, 91, 45,
  49, 93, 32, 53, 48, 37, 44, 48, 44, 53, 48, 37, 44, 49, 48, 48,
  37, 44, 49, 44, 48, 120, 53, 53, 53, 53, 53, 53, 53, 53, 44, 49,
  50, 56, 44, 54, 52, 44, 49, 50, 56, 10, 98, 121, 61, 123, 36, 98,
  114, 117, 115, 104, 116, 104, 105, 99, 107, 110, 101, 115, 115, 42, 40, 104,
  45, 49, 54, 41, 125, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101,
  91, 45, 49, 93, 32, 50, 48, 37, 44, 123, 36, 98, 121, 45, 49, 54,
  125, 44, 56, 48, 37, 44, 123, 36, 98, 121, 43, 49, 54, 125, 44, 49,
  44, 49, 50, 56, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 50,
  48, 37, 44, 123, 36, 98, 121, 45, 49, 54, 125, 44, 56, 48, 37, 44,
  123, 36, 98, 121, 45, 49, 54, 125, 44, 49, 44, 50, 53, 53, 32, 45,
  108, 105, 110, 101, 91, 45, 49, 93, 32, 56, 48, 37, 44, 123, 36, 98,
  121, 45, 49, 54, 125, 44, 56, 48, 37, 44, 123, 36, 98, 121, 43, 49,
  54, 125, 44, 49, 44, 50, 53, 53, 10, 45, 108, 105, 110, 101, 91, 45,
  49, 93, 32, 50, 48, 37, 44, 123, 36, 98, 121, 45, 49, 54, 125, 44,
  50, 48, 37, 44, 123, 36, 98, 121, 43, 49, 54, 125, 44, 49, 44, 54,
  52, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 50, 48, 37, 44,
  123, 36, 98, 121, 43, 49, 54, 125, 44, 56, 48, 37, 44, 123, 36, 98,
  121, 43, 49, 54, 125, 44, 49, 44, 54, 52, 10, 45, 97, 91, 45, 50,
  44, 45, 49, 93, 32, 120, 10, 45, 119, 51, 91, 45, 49, 93, 32, 123,
  119, 125, 44, 123, 104, 125, 44, 48, 44, 34, 66, 114, 117, 115, 104, 34,
  10, 114, 101, 102, 114, 101, 115, 104, 95, 98, 114, 117, 115, 104, 61, 48,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 114, 101, 102,
  114, 101, 115, 104, 95, 105, 109, 97, 103, 101, 10, 45, 119, 49, 91, 36,
  105, 109, 97, 103, 101, 93, 32, 64, 123, 36, 105, 109, 97, 103, 101, 44,
  119, 125, 44, 64, 123, 36, 105, 109, 97, 103, 101, 44, 104, 125, 44, 48,
  44, 34, 73, 109, 97, 103, 101, 32, 34, 35, 36, 105, 109, 97, 103, 101,
  34, 32, 58, 32, 34, 64, 123, 36, 105, 109, 97, 103, 101, 44, 98, 125,
  46, 64, 123, 36, 105, 109, 97, 103, 101, 44, 120, 125, 10, 114, 101, 102,
  114, 101, 115, 104, 95, 105, 109, 97, 103, 101, 61, 48, 10, 45, 101, 110,
  100, 105, 102, 10, 120, 49, 61, 64, 123, 33, 49, 44, 120, 125, 32, 121,
  49, 61, 64, 123, 33, 49, 44, 121, 125, 10, 120, 50, 61, 64, 123, 33,
  50, 44, 120, 125, 32, 121, 50, 61, 64, 123, 33, 50, 44, 121, 125, 10,
  120, 51, 61, 64, 123, 33, 51, 44, 120, 125, 32, 121, 51, 61, 64, 123,
  33, 51, 44, 121, 125, 10, 45, 105, 102, 32, 123, 36, 120, 49, 62, 61,
  48, 125, 10, 45, 105, 102, 32, 123, 64, 123, 33, 49, 44, 98, 125, 38,
  49, 125, 10, 111, 120, 49, 61, 123, 105, 102, 40, 36, 111, 120, 49, 60,
  48, 44, 36, 120, 49, 44, 36, 111, 120, 49, 41, 125, 10, 111, 121, 49,
  61, 123, 105, 102, 40, 36, 111, 121, 49, 60, 48, 44, 36, 121, 49, 44,
  36, 111, 121, 49, 41, 125, 10, 100, 101, 108, 116, 97, 61, 123, 109, 97,
  120, 40, 97, 98, 115, 40, 36, 120, 49, 45, 36, 111, 120, 49, 41, 44,
  97, 98, 115, 40, 36, 121, 49, 45, 36, 111, 121, 49, 41, 41, 125, 10,
  114, 49, 61, 123, 50, 42, 36, 98, 114, 117, 115, 104, 115, 105, 122, 101,
  43, 49, 125, 10, 114, 50, 61, 123, 36, 114, 49, 42, 36, 98, 114, 117,
  115, 104, 116, 104, 105, 99, 107, 110, 101, 115, 115, 125, 10, 100, 120, 61,
  123, 50, 42, 40, 36, 120, 49, 45, 36, 111, 120, 49, 41, 47, 109, 97,
  120, 40, 49, 44, 36, 100, 101, 108, 116, 97, 41, 125, 10, 100, 121, 61,
  123, 50, 42, 40, 36, 121, 49, 45, 36, 111, 121, 49, 41, 47, 109, 97,
  120, 40, 49, 44, 36, 100, 101, 108, 116, 97, 41, 125, 10, 111, 61, 123,
  49, 45, 40, 36, 98, 114, 117, 115, 104, 111, 112, 97, 99, 105, 116, 121,
  47, 52, 41, 94, 48, 46, 48, 52, 125, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 109, 97, 120, 40, 49, 44, 40, 36, 100, 101, 108, 116, 97,
  43, 49, 41, 47, 50, 41, 125, 10, 45, 101, 108, 108, 105, 112, 115, 101,
  91, 36, 105, 109, 97, 103, 101, 93, 32, 123, 36, 111, 120, 49, 43, 36,
  62, 42, 36, 100, 120, 125, 44, 123, 36, 111, 121, 49, 43, 36, 62, 42,
  36, 100, 121, 125, 44, 36, 114, 49, 44, 36, 114, 50, 44, 36, 98, 114,
  117, 115, 104, 97, 110, 103, 108, 101, 44, 36, 111, 44, 36, 99, 111, 108,
  111, 114, 10, 45, 100, 111, 110, 101, 10, 111, 120, 49, 61, 36, 120, 49,
  32, 111, 121, 49, 61, 36, 121, 49, 10, 114, 101, 102, 114, 101, 115, 104,
  95, 105, 109, 97, 103, 101, 61, 49, 10, 45, 101, 108, 115, 101, 10, 111,
  120, 49, 61, 45, 49, 32, 111, 121, 49, 61, 45, 49, 10, 45, 105, 102,
  32, 123, 64, 123, 33, 49, 44, 98, 125, 38, 50, 125, 10, 45, 102, 108,
  111, 111, 100, 91, 36, 105, 109, 97, 103, 101, 93, 32, 36, 120, 49, 44,
  36, 121, 49, 44, 48, 44, 49, 48, 44, 48, 44, 49, 44, 36, 99, 111,
  108, 111, 114, 10, 114, 101, 102, 114, 101, 115, 104, 95, 105, 109, 97, 103,
  101, 61, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64, 123,
  33, 49, 44, 65, 82, 82, 79, 87, 82, 73, 71, 72, 84, 125, 34, 32,
  124, 124, 32, 34, 64, 123, 33, 50, 44, 65, 82, 82, 79, 87, 82, 73,
  71, 72, 84, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 51, 44, 65,
  82, 82, 79, 87, 82, 73, 71, 72, 84, 125, 34, 32, 124, 124, 32, 34,
  92, 10, 64, 123, 33, 49, 44, 65, 82, 82, 79, 87, 85, 80, 125, 34,
  32, 124, 124, 32, 34, 64, 123, 33, 50, 44, 65, 82, 82, 79, 87, 85,
  80, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 51, 44, 65, 82, 82,
  79, 87, 85, 80, 125, 34, 32, 124, 124, 32, 34, 92, 10, 64, 123, 33,
  49, 44, 83, 80, 65, 67, 69, 125, 34, 32, 124, 124, 32, 34, 64, 123,
  33, 50, 44, 83, 80, 65, 67, 69, 125, 34, 32, 124, 124, 32, 34, 64,
  123, 33, 51, 44, 83, 80, 65, 67, 69, 125, 125, 10, 105, 109, 97, 103,
  101, 61, 123, 40, 36, 105, 109, 97, 103, 101, 43, 49, 41, 37, 40, 64,
  35, 45, 50, 41, 125, 32, 114, 101, 102, 114, 101, 115, 104, 95, 105, 109,
  97, 103, 101, 61, 49, 10, 45, 101, 108, 105, 102, 32, 123, 64, 123, 33,
  49, 44, 65, 82, 82, 79, 87, 76, 69, 70, 84, 125, 34, 32, 124, 124,
  32, 34, 64, 123, 33, 50, 44, 65, 82, 82, 79, 87, 76, 69, 70, 84,
  125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 51, 44, 65, 82, 82, 79,
  87, 76, 69, 70, 84, 125, 34, 32, 124, 124, 32, 34, 92, 10, 64, 123,
  33, 49, 44, 65, 82, 82, 79, 87, 68, 79, 87, 78, 125, 34, 32, 124,
  124, 32, 34, 64, 123, 33, 50, 44, 65, 82, 82, 79, 87, 68, 79, 87,
  78, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 51, 44, 65, 82, 82,
  79, 87, 68, 79, 87, 78, 125, 34, 32, 124, 124, 32, 34, 92, 10, 64,
  123, 33, 49, 44, 66, 65, 67, 75, 83, 80, 65, 67, 69, 125, 34, 32,
  124, 124, 32, 34, 64, 123, 33, 50, 44, 66, 65, 67, 75, 83, 80, 65,
  67, 69, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 51, 44, 66, 65,
  67, 75, 83, 80, 65, 67, 69, 125, 125, 10, 105, 109, 97, 103, 101, 61,
  123, 40, 36, 105, 109, 97, 103, 101, 45, 49, 41, 37, 40, 64, 35, 45,
  50, 41, 125, 32, 114, 101, 102, 114, 101, 115, 104, 95, 105, 109, 97, 103,
  101, 61, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 64,
  123, 33, 49, 44, 83, 125, 32, 45, 111, 91, 36, 105, 109, 97, 103, 101,
  93, 32, 103, 109, 105, 99, 95, 112, 97, 105, 110, 116, 46, 112, 110, 103,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64, 123, 33,
  50, 44, 98, 125, 34, 32, 38, 38, 32, 34, 36, 120, 50, 62, 61, 48,
  34, 32, 38, 38, 32, 34, 36, 121, 50, 60, 54, 52, 125, 10, 45, 105,
  102, 32, 123, 36, 120, 50, 62, 61, 50, 53, 54, 125, 32, 115, 97, 116,
  117, 114, 97, 116, 105, 111, 110, 61, 123, 49, 45, 36, 121, 50, 47, 54,
  51, 125, 10, 45, 101, 108, 105, 102, 32, 123, 36, 120, 50, 62, 61, 48,
  125, 32, 99, 111, 108, 111, 114, 61, 64, 123, 45, 50, 44, 40, 36, 120,
  50, 44, 36, 121, 50, 44, 48, 44, 48, 41, 125, 44, 64, 123, 45, 50,
  44, 40, 36, 120, 50, 44, 36, 121, 50, 44, 48, 44, 49, 41, 125, 44,
  64, 123, 45, 50, 44, 40, 36, 120, 50, 44, 36, 121, 50, 44, 48, 44,
  50, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10, 114, 101, 102, 114, 101,
  115, 104, 95, 112, 97, 108, 101, 116, 116, 101, 61, 49, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 64, 123, 33, 51, 44, 98, 125,
  34, 32, 38, 38, 32, 34, 36, 120, 51, 62, 61, 48, 125, 10, 45, 105,
  102, 32, 123, 36, 120, 51, 60, 51, 56, 52, 34, 32, 38, 38, 32, 34,
  36, 121, 51, 62, 61, 49, 57, 50, 125, 32, 98, 114, 117, 115, 104, 97,
  110, 103, 108, 101, 61, 123, 36, 120, 51, 42, 49, 56, 48, 47, 40, 119,
  45, 49, 54, 41, 125, 10, 45, 101, 108, 105, 102, 32, 123, 36, 120, 51,
  62, 61, 51, 56, 52, 34, 32, 38, 38, 32, 34, 36, 121, 51, 60, 49,
  57, 50, 125, 32, 98, 114, 117, 115, 104, 116, 104, 105, 99, 107, 110, 101,
  115, 115, 61, 123, 36, 121, 51, 47, 40, 104, 45, 49, 54, 41, 125, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 120, 51, 60, 51, 56, 52, 34, 32,
  38, 38, 32, 34, 36, 121, 51, 60, 49, 57, 50, 125, 32, 98, 114, 117,
  115, 104, 115, 105, 122, 101, 61, 123, 105, 110, 116, 40, 36, 120, 51, 42,
  56, 47, 40, 119, 45, 49, 54, 41, 41, 125, 32, 98, 114, 117, 115, 104,
  111, 112, 97, 99, 105, 116, 121, 61, 123, 105, 110, 116, 40, 36, 121, 51,
  42, 52, 47, 40, 104, 45, 49, 54, 41, 41, 125, 10, 45, 101, 110, 100,
  105, 102, 10, 114, 101, 102, 114, 101, 115, 104, 95, 98, 114, 117, 115, 104,
  61, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 119, 97, 105, 116, 10,
  45, 119, 104, 105, 108, 101, 32, 123, 64, 123, 33, 49, 125, 34, 32, 38,
  38, 32, 34, 33, 64, 123, 33, 49, 44, 81, 125, 34, 32, 38, 38, 32,
  34, 33, 64, 123, 33, 49, 44, 69, 83, 67, 125, 125, 10, 45, 119, 49,
  91, 93, 32, 48, 32, 45, 119, 50, 91, 93, 32, 48, 32, 45, 119, 51,
  91, 93, 32, 48, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 120, 95, 112, 108,
  97, 115, 109, 97, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 76, 97,
  117, 110, 99, 104, 32, 116, 104, 101, 32, 112, 108, 97, 115, 109, 97, 32,
  101, 102, 102, 101, 99, 116, 32, 100, 101, 109, 111, 46, 10, 120, 95, 112,
  108, 97, 115, 109, 97, 32, 58, 10, 45, 101, 91, 93, 32, 34, 92, 110,
  10, 45, 45, 45, 45, 45, 45, 32, 80, 108, 97, 115, 109, 97, 32, 101,
  102, 102, 101, 99, 116, 32, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45,
  45, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67,
  84, 82, 76, 43, 68, 39, 32, 116, 111, 32, 100, 111, 117, 98, 108, 101,
  32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10,
  45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76, 43,
  67, 39, 32, 116, 111, 32, 114, 101, 115, 101, 116, 32, 119, 105, 110, 100,
  111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32,
  75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81,
  39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45,
  45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 34, 10, 45,
  118, 32, 45, 32, 45, 108, 91, 93, 10, 78, 61, 56, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 36, 78, 10, 50, 53, 54, 44, 49, 53, 48, 44,
  49, 44, 51, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 32, 45, 112, 108, 97, 115, 109, 97, 91, 45, 49, 93, 32,
  49, 44, 48, 44, 55, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 10, 97, 109, 112, 61, 123, 63, 40, 45, 52, 48, 44, 52, 48,
  41, 125, 32, 102, 114, 101, 113, 61, 123, 114, 111, 117, 110, 100, 40, 63,
  40, 50, 44, 54, 41, 41, 125, 32, 100, 105, 114, 36, 62, 61, 123, 105,
  102, 40, 63, 60, 48, 46, 53, 44, 45, 49, 44, 49, 41, 42, 114, 111,
  117, 110, 100, 40, 63, 40, 49, 44, 50, 41, 41, 125, 10, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 39, 36, 97, 109, 112,
  42, 99, 111, 115, 40, 121, 42, 50, 42, 112, 105, 42, 36, 102, 114, 101,
  113, 47, 104, 41, 39, 10, 45, 100, 111, 110, 101, 10, 123, 119, 43, 50,
  125, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 39, 120, 39, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 39, 89, 61,
  40, 121, 45, 54, 48, 43, 53, 42, 99, 111, 115, 40, 120, 47, 51, 48,
  41, 43, 49, 48, 42, 115, 105, 110, 40, 120, 47, 49, 53, 41, 41, 59,
  105, 102, 40, 89, 60, 48, 124, 124, 89, 62, 61, 51, 50, 44, 45, 49,
  44, 89, 41, 39, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99,
  10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 42, 42, 32, 87, 101,
  108, 99, 111, 109, 101, 32, 116, 111, 32, 71, 39, 77, 73, 67, 44, 32,
  97, 32, 112, 111, 119, 101, 114, 102, 117, 108, 32, 105, 109, 97, 103, 101,
  32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 102, 114, 97, 109,
  101, 119, 111, 114, 107, 32, 42, 42, 34, 44, 48, 44, 48, 44, 51, 50,
  44, 49, 44, 50, 53, 53, 10, 45, 98, 91, 45, 49, 93, 32, 48, 46,
  54, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 77,
  61, 123, 119, 125, 10, 45, 119, 91, 93, 32, 123, 49, 46, 53, 42, 64,
  123, 48, 44, 119, 125, 125, 44, 123, 49, 46, 53, 42, 64, 123, 48, 44,
  104, 125, 125, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 80,
  108, 97, 115, 109, 97, 32, 101, 102, 102, 101, 99, 116, 34, 10, 116, 61,
  48, 32, 116, 116, 61, 123, 45, 49, 46, 53, 42, 64, 123, 48, 44, 119,
  125, 125, 10, 45, 100, 111, 10, 116, 105, 99, 61, 64, 124, 10, 97, 61,
  123, 105, 110, 116, 40, 36, 116, 41, 125, 32, 32, 32, 97, 50, 61, 123,
  50, 42, 36, 97, 125, 32, 97, 50, 49, 61, 123, 36, 97, 50, 43, 49,
  125, 10, 98, 61, 123, 40, 36, 97, 43, 49, 41, 37, 36, 78, 125, 32,
  98, 50, 61, 123, 50, 42, 36, 98, 125, 32, 98, 50, 49, 61, 123, 36,
  98, 50, 43, 49, 125, 10, 45, 45, 119, 97, 114, 112, 91, 36, 97, 50,
  93, 32, 91, 36, 97, 50, 49, 93, 44, 49, 44, 48, 44, 50, 10, 45,
  45, 119, 97, 114, 112, 91, 36, 98, 50, 93, 32, 91, 36, 98, 50, 49,
  93, 44, 49, 44, 48, 44, 50, 10, 45, 106, 91, 45, 50, 93, 32, 91,
  45, 49, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 123, 36, 116, 45,
  36, 97, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 105,
  102, 116, 91, 36, 97, 50, 49, 93, 32, 48, 44, 36, 123, 100, 105, 114,
  36, 97, 125, 44, 48, 44, 48, 44, 50, 10, 45, 115, 104, 105, 102, 116,
  91, 36, 98, 50, 49, 93, 32, 48, 44, 36, 123, 100, 105, 114, 36, 98,
  125, 44, 48, 44, 48, 44, 50, 10, 45, 105, 102, 32, 123, 105, 110, 116,
  40, 36, 116, 43, 48, 46, 48, 48, 53, 41, 62, 105, 110, 116, 40, 36,
  116, 41, 125, 32, 100, 105, 114, 36, 97, 61, 123, 105, 102, 40, 63, 60,
  48, 46, 53, 44, 45, 49, 44, 49, 41, 42, 114, 111, 117, 110, 100, 40,
  63, 40, 49, 44, 51, 41, 41, 125, 32, 45, 101, 110, 100, 105, 102, 10,
  116, 61, 123, 40, 36, 116, 43, 40, 64, 124, 45, 36, 116, 105, 99, 41,
  41, 37, 36, 78, 125, 10, 45, 45, 122, 91, 45, 50, 93, 32, 36, 116,
  116, 44, 123, 36, 116, 116, 43, 119, 45, 49, 43, 50, 125, 10, 45, 119,
  97, 114, 112, 91, 45, 49, 93, 32, 91, 45, 52, 93, 44, 48, 44, 48,
  44, 48, 10, 45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 49, 44, 51, 10, 45, 45, 42, 91, 45, 49, 93, 32,
  45, 49, 32, 45, 43, 91, 45, 49, 93, 32, 50, 53, 53, 10, 45, 106,
  91, 45, 51, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 44, 48, 44,
  48, 44, 49, 44, 91, 45, 50, 93, 44, 50, 53, 53, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  44, 45, 50, 44, 45, 50, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49,
  93, 44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 116, 116,
  61, 123, 36, 116, 116, 43, 40, 64, 124, 45, 36, 116, 105, 99, 41, 42,
  50, 53, 48, 125, 10, 45, 105, 102, 32, 123, 36, 116, 116, 62, 61, 36,
  77, 125, 32, 116, 116, 61, 123, 45, 49, 46, 53, 42, 64, 123, 48, 44,
  119, 125, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 119, 91, 45, 49,
  93, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76,
  69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 68, 125, 125, 32, 45, 119,
  91, 93, 32, 123, 51, 42, 119, 125, 44, 123, 51, 42, 104, 125, 32, 45,
  101, 108, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69,
  70, 84, 125, 38, 38, 64, 123, 33, 44, 67, 125, 125, 32, 45, 119, 91,
  93, 32, 123, 49, 46, 53, 42, 119, 125, 44, 123, 49, 46, 53, 42, 104,
  125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 119, 97, 105, 116, 32, 50, 48, 10, 45, 119, 104, 105, 108, 101,
  32, 123, 64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69,
  83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125,
  125, 10, 45, 114, 109, 91, 123, 45, 50, 42, 36, 78, 45, 50, 125, 45,
  45, 49, 93, 32, 45, 119, 91, 93, 32, 48, 32, 45, 101, 110, 100, 108,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 120, 95, 113,
  117, 97, 110, 116, 105, 122, 101, 95, 114, 103, 98, 32, 58, 32, 95, 110,
  98, 99, 111, 108, 111, 114, 115, 62, 61, 50, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 76, 97, 117, 110, 99, 104, 32, 116, 104, 101, 32, 82,
  71, 66, 32, 99, 111, 108, 111, 114, 32, 113, 117, 97, 110, 116, 105, 122,
  97, 116, 105, 111, 110, 32, 100, 101, 109, 111, 46, 10, 120, 95, 113, 117,
  97, 110, 116, 105, 122, 101, 95, 114, 103, 98, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 49,
  54, 125, 41, 32, 38, 38, 32, 36, 49, 62, 49, 34, 10, 45, 101, 91,
  93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 82, 71, 66,
  32, 81, 117, 97, 110, 116, 105, 122, 97, 116, 105, 111, 110, 32, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45,
  45, 45, 32, 84, 104, 105, 115, 32, 100, 101, 109, 111, 32, 115, 104, 111,
  119, 115, 32, 104, 111, 119, 32, 82, 71, 66, 32, 99, 111, 108, 111, 114,
  115, 32, 99, 97, 110, 32, 98, 101, 32, 113, 117, 97, 110, 116, 105, 102,
  105, 101, 100, 32, 117, 115, 105, 110, 103, 92, 110, 10, 45, 45, 45, 45,
  32, 116, 104, 101, 32, 107, 45, 109, 101, 97, 110, 115, 32, 97, 108, 103,
  111, 114, 105, 116, 104, 109, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110,
  10, 45, 45, 45, 45, 32, 76, 101, 102, 116, 32, 109, 111, 117, 115, 101,
  32, 98, 117, 116, 116, 111, 110, 32, 111, 110, 32, 51, 100, 32, 118, 105,
  101, 119, 32, 114, 111, 116, 97, 116, 101, 115, 32, 116, 104, 101, 32, 99,
  111, 108, 111, 114, 32, 99, 117, 98, 101, 46, 92, 110, 10, 45, 45, 45,
  45, 32, 82, 105, 103, 104, 116, 32, 109, 111, 117, 115, 101, 32, 98, 117,
  116, 116, 111, 110, 32, 111, 110, 32, 51, 100, 32, 118, 105, 101, 119, 32,
  116, 111, 103, 103, 108, 101, 115, 32, 99, 111, 108, 111, 114, 115, 47, 99,
  108, 117, 115, 116, 101, 114, 115, 32, 109, 111, 100, 101, 46, 92, 110, 10,
  45, 45, 45, 45, 32, 76, 101, 102, 116, 32, 109, 111, 117, 115, 101, 32,
  98, 117, 116, 116, 111, 110, 32, 111, 110, 32, 105, 109, 97, 103, 101, 32,
  116, 111, 103, 103, 108, 101, 115, 32, 100, 105, 116, 104, 101, 114, 105, 110,
  103, 32, 109, 111, 100, 101, 44, 92, 110, 10, 45, 45, 45, 45, 32, 76,
  101, 102, 116, 32, 109, 111, 117, 115, 101, 32, 98, 117, 116, 116, 111, 110,
  32, 111, 110, 32, 99, 111, 108, 111, 114, 109, 97, 112, 32, 97, 100, 100,
  115, 32, 97, 32, 114, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111, 114,
  46, 92, 110, 10, 45, 45, 45, 45, 32, 82, 105, 103, 104, 116, 32, 109,
  111, 117, 115, 101, 32, 98, 117, 116, 116, 111, 110, 32, 111, 110, 32, 99,
  111, 108, 111, 114, 109, 97, 112, 32, 114, 101, 109, 111, 118, 101, 115, 32,
  97, 32, 99, 111, 108, 111, 114, 46, 92, 110, 10, 45, 45, 45, 45, 32,
  75, 101, 121, 32, 39, 82, 39, 32, 105, 110, 105, 116, 32, 99, 111, 108,
  111, 114, 109, 97, 112, 32, 119, 105, 116, 104, 32, 114, 97, 110, 100, 111,
  109, 32, 118, 97, 108, 117, 101, 115, 46, 92, 110, 10, 45, 45, 45, 45,
  32, 75, 101, 121, 32, 39, 85, 39, 32, 105, 110, 105, 116, 32, 99, 111,
  108, 111, 114, 109, 97, 112, 32, 119, 105, 116, 104, 32, 117, 110, 105, 102,
  111, 114, 109, 32, 115, 97, 109, 112, 108, 105, 110, 103, 46, 92, 110, 10,
  45, 45, 45, 45, 32, 75, 101, 121, 32, 39, 77, 39, 32, 105, 110, 105,
  116, 32, 99, 111, 108, 111, 114, 109, 97, 112, 32, 119, 105, 116, 104, 32,
  109, 101, 100, 105, 97, 110, 45, 99, 117, 116, 32, 97, 108, 103, 111, 114,
  105, 116, 104, 109, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121,
  32, 39, 83, 80, 65, 67, 69, 39, 32, 100, 111, 101, 115, 32, 97, 32,
  115, 105, 110, 103, 108, 101, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110,
  32, 111, 102, 32, 107, 45, 109, 101, 97, 110, 115, 32, 97, 110, 100, 32,
  112, 97, 117, 115, 101, 115, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75,
  101, 121, 32, 39, 69, 78, 84, 69, 82, 39, 32, 114, 117, 110, 115, 32,
  107, 45, 109, 101, 97, 110, 115, 32, 97, 108, 103, 111, 114, 105, 116, 104,
  109, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39,
  67, 84, 82, 76, 43, 68, 39, 32, 116, 111, 32, 100, 111, 117, 98, 108,
  101, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110,
  10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76,
  43, 67, 39, 32, 116, 111, 32, 114, 101, 115, 101, 116, 32, 119, 105, 110,
  100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45, 45,
  32, 75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39,
  81, 39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45,
  45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 34, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 123, 33,
  64, 35, 125, 32, 45, 116, 101, 115, 116, 105, 109, 97, 103, 101, 50, 100,
  32, 51, 48, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 107, 91, 48,
  93, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 105, 102, 32, 123, 104,
  62, 51, 48, 48, 125, 32, 45, 114, 50, 100, 121, 32, 51, 48, 48, 32,
  45, 114, 111, 117, 110, 100, 32, 49, 32, 45, 101, 110, 100, 105, 102, 32,
  45, 110, 109, 91, 45, 49, 93, 32, 105, 109, 103, 10, 45, 45, 114, 32,
  123, 119, 42, 104, 125, 44, 49, 44, 49, 44, 51, 44, 45, 49, 32, 45,
  114, 91, 45, 49, 93, 32, 123, 109, 105, 110, 40, 119, 44, 56, 49, 57,
  50, 41, 125, 44, 49, 44, 49, 44, 51, 32, 45, 110, 109, 91, 45, 49,
  93, 32, 99, 111, 108, 111, 114, 115, 10, 36, 49, 44, 49, 44, 49, 44,
  51, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 49, 32, 45,
  110, 109, 91, 45, 49, 93, 32, 99, 101, 110, 116, 114, 111, 105, 100, 115,
  10, 45, 95, 120, 95, 113, 117, 97, 110, 116, 105, 122, 101, 95, 114, 103,
  98, 95, 51, 100, 32, 40, 49, 44, 48, 44, 48, 44, 48, 59, 48, 44,
  49, 44, 48, 44, 48, 59, 48, 44, 48, 44, 49, 44, 48, 41, 32, 45,
  110, 109, 91, 45, 49, 93, 32, 112, 111, 115, 101, 51, 100, 10, 45, 95,
  120, 95, 113, 117, 97, 110, 116, 105, 122, 101, 95, 114, 103, 98, 95, 116,
  101, 120, 116, 32, 34, 67, 111, 108, 111, 114, 115, 34, 44, 99, 108, 117,
  115, 116, 101, 114, 105, 110, 103, 48, 10, 45, 95, 120, 95, 113, 117, 97,
  110, 116, 105, 122, 101, 95, 114, 103, 98, 95, 116, 101, 120, 116, 32, 34,
  67, 108, 117, 115, 116, 101, 114, 115, 34, 44, 99, 108, 117, 115, 116, 101,
  114, 105, 110, 103, 49, 10, 45, 95, 120, 95, 113, 117, 97, 110, 116, 105,
  122, 101, 95, 114, 103, 98, 95, 116, 101, 120, 116, 32, 34, 68, 105, 116,
  104, 101, 114, 105, 110, 103, 58, 32, 111, 102, 102, 34, 44, 100, 105, 116,
  104, 101, 114, 105, 110, 103, 48, 10, 45, 95, 120, 95, 113, 117, 97, 110,
  116, 105, 122, 101, 95, 114, 103, 98, 95, 116, 101, 120, 116, 32, 34, 68,
  105, 116, 104, 101, 114, 105, 110, 103, 58, 32, 111, 110, 34, 44, 100, 105,
  116, 104, 101, 114, 105, 110, 103, 49, 10, 45, 105, 102, 32, 123, 64, 123,
  105, 109, 103, 44, 104, 125, 60, 51, 48, 48, 125, 32, 45, 45, 114, 50,
  100, 121, 91, 105, 109, 103, 93, 32, 51, 48, 48, 44, 49, 32, 45, 101,
  108, 115, 101, 32, 91, 105, 109, 103, 93, 32, 45, 101, 110, 100, 105, 102,
  10, 123, 119, 43, 51, 49, 53, 125, 44, 51, 54, 53, 44, 49, 44, 51,
  44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 114, 101,
  99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 52, 44, 52, 44,
  51, 48, 53, 44, 51, 48, 53, 44, 49, 44, 48, 120, 70, 70, 70, 70,
  70, 70, 70, 70, 44, 48, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108,
  101, 91, 45, 49, 93, 32, 51, 48, 57, 44, 52, 44, 123, 119, 45, 53,
  125, 44, 51, 48, 53, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70,
  70, 70, 44, 48, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91,
  45, 49, 93, 32, 52, 44, 51, 48, 57, 44, 123, 119, 45, 53, 125, 44,
  51, 54, 48, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70,
  44, 48, 10, 91, 45, 49, 93, 44, 91, 45, 49, 93, 10, 45, 114, 101,
  99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 51, 49, 48, 44,
  53, 44, 123, 119, 45, 54, 125, 44, 51, 48, 53, 44, 49, 44, 49, 10,
  45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 53,
  44, 51, 49, 48, 44, 123, 119, 45, 54, 125, 44, 51, 54, 48, 44, 49,
  44, 50, 10, 51, 48, 48, 44, 51, 48, 48, 44, 49, 44, 49, 44, 39,
  40, 121, 60, 60, 49, 49, 41, 43, 40, 120, 60, 60, 50, 41, 43, 51,
  39, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 53, 44,
  53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 97, 91, 45, 50, 44,
  45, 49, 93, 32, 99, 32, 32, 45, 110, 109, 91, 45, 49, 93, 32, 118,
  105, 115, 117, 10, 100, 105, 116, 104, 101, 114, 105, 110, 103, 61, 48, 32,
  99, 108, 117, 115, 116, 101, 114, 105, 110, 103, 61, 48, 32, 112, 97, 117,
  115, 101, 61, 49, 32, 115, 48, 61, 111, 102, 102, 32, 115, 49, 61, 111,
  110, 10, 45, 114, 101, 112, 101, 97, 116, 32, 49, 101, 49, 48, 10, 45,
  105, 102, 32, 123, 33, 110, 97, 114, 103, 40, 36, 118, 105, 115, 117, 95,
  51, 100, 41, 125, 10, 45, 45, 45, 91, 99, 101, 110, 116, 114, 111, 105,
  100, 115, 93, 32, 50, 32, 45, 45, 43, 91, 99, 101, 110, 116, 114, 111,
  105, 100, 115, 93, 32, 50, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93,
  32, 120, 32, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 49, 93, 32,
  99, 120, 121, 122, 32, 45, 121, 91, 45, 49, 93, 32, 45, 45, 91, 45,
  49, 93, 32, 49, 50, 56, 10, 45, 106, 91, 111, 98, 106, 51, 100, 93,
  32, 91, 45, 49, 93, 44, 48, 44, 56, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 91, 111, 98, 106, 51, 100, 93, 10, 45, 105, 102, 32, 36, 99,
  108, 117, 115, 116, 101, 114, 105, 110, 103, 10, 45, 105, 102, 32, 123, 64,
  123, 99, 111, 108, 111, 114, 115, 44, 77, 125, 60, 50, 53, 54, 125, 32,
  45, 45, 105, 110, 100, 101, 120, 91, 99, 111, 108, 111, 114, 115, 93, 32,
  91, 99, 101, 110, 116, 114, 111, 105, 100, 115, 93, 32, 45, 42, 91, 45,
  49, 93, 32, 50, 53, 54, 32, 45, 43, 91, 99, 111, 108, 111, 114, 115,
  44, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 99, 111, 108, 111, 114, 115, 93, 32, 48,
  32, 45, 62, 62, 91, 45, 49, 93, 32, 56, 32, 45, 109, 97, 112, 91,
  45, 49, 93, 32, 50, 32, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45,
  49, 93, 32, 99, 120, 121, 122, 32, 45, 121, 91, 45, 49, 93, 32, 45,
  106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 123, 64, 123,
  45, 50, 44, 104, 125, 45, 36, 95, 78, 45, 104, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 97, 112, 112,
  108, 121, 95, 112, 111, 115, 101, 51, 100, 91, 45, 49, 93, 32, 64, 112,
  111, 115, 101, 51, 100, 32, 51, 48, 48, 44, 51, 48, 48, 44, 49, 44,
  51, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32,
  91, 45, 50, 93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 49, 48, 48,
  44, 49, 44, 50, 44, 48, 44, 48, 44, 51, 48, 48, 32, 45, 114, 109,
  91, 45, 50, 93, 10, 45, 106, 91, 45, 49, 93, 32, 91, 99, 108, 117,
  115, 116, 101, 114, 105, 110, 103, 36, 99, 108, 117, 115, 116, 101, 114, 105,
  110, 103, 93, 44, 50, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 109,
  99, 108, 117, 115, 116, 101, 114, 105, 110, 103, 36, 99, 108, 117, 115, 116,
  101, 114, 105, 110, 103, 93, 44, 50, 53, 53, 10, 45, 110, 109, 91, 45,
  49, 93, 32, 118, 105, 115, 117, 95, 51, 100, 32, 45, 106, 91, 118, 105,
  115, 117, 93, 32, 91, 118, 105, 115, 117, 95, 51, 100, 93, 44, 53, 44,
  53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 33, 110,
  97, 114, 103, 40, 36, 118, 105, 115, 117, 95, 105, 109, 103, 41, 125, 10,
  45, 45, 105, 110, 100, 101, 120, 91, 105, 109, 103, 93, 32, 91, 99, 101,
  110, 116, 114, 111, 105, 100, 115, 93, 44, 123, 48, 46, 55, 42, 36, 100,
  105, 116, 104, 101, 114, 105, 110, 103, 125, 44, 49, 32, 45, 105, 102, 32,
  123, 104, 60, 51, 48, 48, 125, 32, 45, 114, 50, 100, 121, 91, 45, 49,
  93, 32, 51, 48, 48, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  106, 91, 45, 49, 93, 32, 91, 100, 105, 116, 104, 101, 114, 105, 110, 103,
  36, 100, 105, 116, 104, 101, 114, 105, 110, 103, 93, 44, 50, 44, 48, 44,
  48, 44, 48, 44, 49, 44, 91, 109, 100, 105, 116, 104, 101, 114, 105, 110,
  103, 36, 100, 105, 116, 104, 101, 114, 105, 110, 103, 93, 44, 50, 53, 53,
  10, 45, 110, 109, 91, 45, 49, 93, 32, 118, 105, 115, 117, 95, 105, 109,
  103, 32, 45, 106, 91, 118, 105, 115, 117, 93, 32, 91, 118, 105, 115, 117,
  95, 105, 109, 103, 93, 44, 51, 49, 48, 44, 53, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 33, 110, 97, 114, 103, 40, 36, 118,
  105, 115, 117, 95, 99, 101, 110, 116, 114, 111, 105, 100, 115, 41, 125, 10,
  45, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 99, 101, 110, 116,
  114, 111, 105, 100, 115, 93, 32, 45, 97, 91, 45, 49, 93, 32, 91, 99,
  101, 110, 116, 114, 111, 105, 100, 115, 93, 44, 121, 32, 45, 115, 111, 114,
  116, 91, 45, 49, 93, 32, 43, 44, 120, 32, 45, 114, 111, 119, 115, 91,
  45, 49, 93, 32, 49, 32, 45, 114, 91, 45, 49, 93, 32, 123, 64, 123,
  118, 105, 115, 117, 44, 119, 125, 45, 49, 48, 125, 44, 53, 48, 44, 49,
  44, 51, 10, 48, 32, 45, 116, 101, 120, 116, 91, 45, 49, 93, 32, 34,
  67, 111, 108, 111, 114, 115, 58, 32, 34, 64, 123, 99, 101, 110, 116, 114,
  111, 105, 100, 115, 44, 119, 125, 44, 50, 44, 48, 44, 49, 51, 44, 49,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 45, 100,
  105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51, 32, 45, 106, 91, 45,
  51, 93, 32, 91, 45, 50, 93, 44, 50, 44, 50, 44, 48, 44, 48, 44,
  49, 44, 91, 45, 49, 93, 44, 50, 53, 53, 10, 45, 114, 109, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 110, 109, 91, 45, 49, 93, 32, 118, 105,
  115, 117, 95, 99, 101, 110, 116, 114, 111, 105, 100, 115, 32, 45, 106, 91,
  118, 105, 115, 117, 93, 32, 91, 118, 105, 115, 117, 95, 99, 101, 110, 116,
  114, 111, 105, 100, 115, 93, 44, 53, 44, 51, 49, 48, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 108, 91, 118, 105, 115, 117, 93, 10, 45, 119, 32,
  45, 49, 44, 45, 49, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93,
  32, 82, 71, 66, 32, 113, 117, 97, 110, 116, 105, 122, 97, 116, 105, 111,
  110, 34, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76,
  76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 68, 125, 125, 32, 45,
  119, 91, 93, 32, 123, 50, 42, 119, 125, 44, 123, 50, 42, 104, 125, 32,
  45, 101, 108, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76,
  69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 67, 125, 125, 32, 45, 119,
  91, 93, 32, 123, 119, 125, 44, 123, 104, 125, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 108, 10, 120, 61, 123, 105, 110, 116, 40, 64,
  123, 33, 44, 120, 125, 42, 64, 123, 118, 105, 115, 117, 44, 119, 125, 47,
  64, 123, 33, 44, 119, 125, 41, 125, 10, 121, 61, 123, 105, 110, 116, 40,
  64, 123, 33, 44, 121, 125, 42, 64, 123, 118, 105, 115, 117, 44, 104, 125,
  47, 64, 123, 33, 44, 104, 125, 41, 125, 10, 98, 61, 64, 123, 33, 44,
  98, 125, 10, 105, 61, 64, 123, 118, 105, 115, 117, 44, 40, 36, 120, 44,
  36, 121, 44, 48, 44, 51, 41, 125, 10, 45, 105, 102, 32, 123, 36, 98,
  38, 49, 34, 32, 38, 38, 32, 34, 36, 105, 61, 61, 49, 125, 10, 100,
  105, 116, 104, 101, 114, 105, 110, 103, 61, 123, 33, 36, 100, 105, 116, 104,
  101, 114, 105, 110, 103, 125, 32, 45, 114, 109, 91, 118, 105, 115, 117, 95,
  105, 109, 103, 93, 32, 45, 119, 97, 105, 116, 32, 45, 49, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 98, 38, 49, 34, 32, 38, 38, 32, 34, 36,
  105, 61, 61, 50, 125, 10, 40, 64, 123, 45, 82, 71, 66, 125, 41, 32,
  45, 121, 91, 45, 49, 93, 32, 99, 32, 45, 97, 91, 99, 101, 110, 116,
  114, 111, 105, 100, 115, 44, 45, 49, 93, 32, 120, 32, 32, 45, 95, 120,
  95, 113, 117, 97, 110, 116, 105, 122, 101, 95, 114, 103, 98, 95, 51, 100,
  32, 45, 114, 109, 91, 118, 105, 115, 117, 95, 51, 100, 44, 118, 105, 115,
  117, 95, 105, 109, 103, 44, 118, 105, 115, 117, 95, 99, 101, 110, 116, 114,
  111, 105, 100, 115, 93, 32, 45, 97, 110, 100, 91, 99, 111, 108, 111, 114,
  115, 93, 32, 50, 53, 53, 32, 112, 97, 117, 115, 101, 61, 49, 32, 45,
  119, 97, 105, 116, 32, 49, 48, 48, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 98, 38, 50, 34, 32, 38, 38, 32, 34, 36, 105, 61, 61, 50, 34,
  32, 38, 38, 32, 34, 64, 123, 99, 101, 110, 116, 114, 111, 105, 100, 115,
  44, 119, 125, 62, 50, 125, 10, 45, 114, 91, 99, 101, 110, 116, 114, 111,
  105, 100, 115, 93, 32, 123, 64, 123, 99, 101, 110, 116, 114, 111, 105, 100,
  115, 44, 119, 125, 45, 49, 125, 32, 45, 95, 120, 95, 113, 117, 97, 110,
  116, 105, 122, 101, 95, 114, 103, 98, 95, 51, 100, 32, 45, 114, 109, 91,
  118, 105, 115, 117, 95, 51, 100, 44, 118, 105, 115, 117, 95, 105, 109, 103,
  44, 118, 105, 115, 117, 95, 99, 101, 110, 116, 114, 111, 105, 100, 115, 93,
  32, 45, 97, 110, 100, 91, 99, 111, 108, 111, 114, 115, 93, 32, 50, 53,
  53, 32, 112, 97, 117, 115, 101, 61, 49, 32, 45, 119, 97, 105, 116, 32,
  49, 48, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 98, 38, 50, 34,
  32, 38, 38, 32, 34, 36, 105, 62, 61, 51, 125, 10, 99, 108, 117, 115,
  116, 101, 114, 105, 110, 103, 61, 123, 33, 36, 99, 108, 117, 115, 116, 101,
  114, 105, 110, 103, 125, 32, 45, 114, 109, 91, 118, 105, 115, 117, 95, 51,
  100, 93, 32, 45, 119, 97, 105, 116, 32, 45, 49, 10, 45, 101, 108, 105,
  102, 32, 64, 123, 33, 44, 77, 125, 10, 45, 45, 97, 110, 100, 91, 99,
  111, 108, 111, 114, 115, 93, 32, 50, 53, 53, 32, 45, 99, 111, 108, 111,
  114, 109, 97, 112, 91, 45, 49, 93, 32, 64, 123, 99, 101, 110, 116, 114,
  111, 105, 100, 115, 44, 119, 125, 44, 48, 44, 48, 32, 45, 114, 109, 91,
  99, 101, 110, 116, 114, 111, 105, 100, 115, 93, 32, 45, 110, 109, 91, 45,
  49, 93, 32, 99, 101, 110, 116, 114, 111, 105, 100, 115, 10, 45, 95, 120,
  95, 113, 117, 97, 110, 116, 105, 122, 101, 95, 114, 103, 98, 95, 51, 100,
  32, 45, 114, 109, 91, 118, 105, 115, 117, 95, 51, 100, 44, 118, 105, 115,
  117, 95, 105, 109, 103, 44, 118, 105, 115, 117, 95, 99, 101, 110, 116, 114,
  111, 105, 100, 115, 93, 32, 45, 97, 110, 100, 91, 99, 111, 108, 111, 114,
  115, 93, 32, 50, 53, 53, 32, 112, 97, 117, 115, 101, 61, 49, 32, 45,
  119, 97, 105, 116, 32, 45, 49, 10, 45, 101, 108, 105, 102, 32, 64, 123,
  33, 44, 82, 125, 10, 45, 114, 97, 110, 100, 91, 99, 101, 110, 116, 114,
  111, 105, 100, 115, 93, 32, 48, 44, 50, 53, 53, 32, 45, 114, 111, 117,
  110, 100, 91, 99, 101, 110, 116, 114, 111, 105, 100, 115, 93, 32, 49, 10,
  45, 95, 120, 95, 113, 117, 97, 110, 116, 105, 122, 101, 95, 114, 103, 98,
  95, 51, 100, 32, 45, 114, 109, 91, 118, 105, 115, 117, 95, 51, 100, 44,
  118, 105, 115, 117, 95, 105, 109, 103, 44, 118, 105, 115, 117, 95, 99, 101,
  110, 116, 114, 111, 105, 100, 115, 93, 32, 45, 97, 110, 100, 91, 99, 111,
  108, 111, 114, 115, 93, 32, 50, 53, 53, 32, 112, 97, 117, 115, 101, 61,
  49, 32, 45, 119, 97, 105, 116, 32, 45, 49, 10, 45, 101, 108, 105, 102,
  32, 64, 123, 33, 44, 85, 125, 10, 45, 117, 110, 105, 102, 111, 114, 109,
  95, 100, 105, 115, 116, 114, 105, 98, 117, 116, 105, 111, 110, 32, 64, 123,
  99, 101, 110, 116, 114, 111, 105, 100, 115, 44, 119, 125, 44, 51, 32, 45,
  42, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 109, 91, 99, 101,
  110, 116, 114, 111, 105, 100, 115, 93, 32, 45, 110, 109, 91, 45, 49, 93,
  32, 99, 101, 110, 116, 114, 111, 105, 100, 115, 10, 45, 95, 120, 95, 113,
  117, 97, 110, 116, 105, 122, 101, 95, 114, 103, 98, 95, 51, 100, 32, 45,
  114, 109, 91, 118, 105, 115, 117, 95, 51, 100, 44, 118, 105, 115, 117, 95,
  105, 109, 103, 44, 118, 105, 115, 117, 95, 99, 101, 110, 116, 114, 111, 105,
  100, 115, 93, 32, 45, 97, 110, 100, 91, 99, 111, 108, 111, 114, 115, 93,
  32, 50, 53, 53, 32, 112, 97, 117, 115, 101, 61, 49, 32, 45, 119, 97,
  105, 116, 32, 45, 49, 10, 45, 101, 108, 105, 102, 32, 64, 123, 33, 44,
  69, 78, 84, 69, 82, 125, 10, 112, 97, 117, 115, 101, 61, 48, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 98, 38, 49, 34, 32, 38, 38, 32, 34,
  36, 105, 62, 61, 51, 125, 10, 99, 111, 111, 114, 100, 115, 61, 123, 64,
  123, 118, 105, 115, 117, 44, 40, 36, 120, 44, 36, 121, 44, 48, 44, 51,
  41, 125, 45, 51, 125, 32, 117, 49, 61, 123, 40, 40, 36, 99, 111, 111,
  114, 100, 115, 62, 62, 50, 41, 38, 53, 49, 49, 41, 45, 49, 53, 48,
  125, 32, 118, 49, 61, 123, 40, 36, 99, 111, 111, 114, 100, 115, 62, 62,
  49, 49, 41, 45, 49, 53, 48, 125, 10, 45, 105, 102, 32, 123, 33, 110,
  97, 114, 103, 40, 36, 117, 48, 41, 125, 32, 117, 48, 61, 36, 117, 49,
  32, 118, 48, 61, 36, 118, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 117, 48, 33, 61, 36, 117, 49, 34, 32, 38, 38,
  32, 34, 36, 118, 48, 33, 61, 36, 118, 49, 125, 10, 110, 48, 61, 123,
  115, 113, 114, 116, 40, 40, 36, 117, 48, 41, 94, 50, 43, 40, 36, 118,
  48, 41, 94, 50, 41, 125, 10, 110, 117, 48, 61, 123, 105, 102, 40, 36,
  110, 48, 62, 49, 51, 53, 44, 36, 117, 48, 42, 49, 51, 53, 47, 36,
  110, 48, 44, 36, 117, 48, 41, 125, 32, 110, 118, 48, 61, 123, 105, 102,
  40, 36, 110, 48, 62, 49, 51, 53, 44, 36, 118, 48, 42, 49, 51, 53,
  47, 36, 110, 48, 44, 36, 118, 48, 41, 125, 32, 110, 119, 48, 61, 123,
  115, 113, 114, 116, 40, 109, 97, 120, 40, 48, 44, 49, 56, 50, 50, 53,
  45, 40, 36, 110, 117, 48, 41, 94, 50, 45, 40, 36, 110, 118, 48, 41,
  94, 50, 41, 41, 125, 10, 110, 49, 61, 123, 115, 113, 114, 116, 40, 40,
  36, 117, 49, 41, 94, 50, 43, 40, 36, 118, 49, 41, 94, 50, 41, 125,
  10, 110, 117, 49, 61, 123, 105, 102, 40, 36, 110, 49, 62, 49, 51, 53,
  44, 36, 117, 49, 42, 49, 51, 53, 47, 36, 110, 49, 44, 36, 117, 49,
  41, 125, 32, 110, 118, 49, 61, 123, 105, 102, 40, 36, 110, 49, 62, 49,
  51, 53, 44, 36, 118, 49, 42, 49, 51, 53, 47, 36, 110, 49, 44, 36,
  118, 49, 41, 125, 32, 110, 119, 49, 61, 123, 115, 113, 114, 116, 40, 109,
  97, 120, 40, 48, 44, 49, 56, 50, 50, 53, 45, 40, 36, 110, 117, 49,
  41, 94, 50, 45, 40, 36, 110, 118, 49, 41, 94, 50, 41, 41, 125, 10,
  117, 61, 123, 36, 110, 118, 48, 42, 36, 110, 119, 49, 45, 36, 110, 119,
  48, 42, 36, 110, 118, 49, 125, 32, 118, 61, 123, 36, 110, 119, 48, 42,
  36, 110, 117, 49, 45, 36, 110, 117, 48, 42, 36, 110, 119, 49, 125, 32,
  119, 61, 123, 36, 110, 118, 48, 42, 36, 110, 117, 49, 45, 36, 110, 117,
  48, 42, 36, 110, 118, 49, 125, 32, 110, 61, 123, 115, 113, 114, 116, 40,
  40, 36, 117, 41, 94, 50, 43, 40, 36, 118, 41, 94, 50, 43, 40, 36,
  119, 41, 94, 50, 41, 125, 10, 45, 114, 111, 116, 97, 116, 105, 111, 110,
  51, 100, 91, 93, 32, 36, 117, 44, 36, 118, 44, 36, 119, 44, 123, 97,
  115, 105, 110, 40, 36, 110, 47, 49, 56, 50, 50, 53, 41, 42, 49, 56,
  48, 47, 112, 105, 125, 32, 45, 109, 118, 91, 112, 111, 115, 101, 51, 100,
  93, 32, 64, 35, 32, 45, 42, 42, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 110, 109, 91, 45, 49, 93, 32, 112, 111, 115, 101, 51, 100, 10, 117,
  48, 61, 36, 117, 49, 32, 118, 48, 61, 36, 118, 49, 32, 45, 114, 109,
  91, 118, 105, 115, 117, 95, 51, 100, 93, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 108, 105, 102, 32, 123, 33, 40, 36, 98, 38, 49, 41, 125,
  32, 117, 48, 61, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 33, 36, 112, 97, 117, 115, 101, 34, 32, 124, 124, 32, 34, 64, 123,
  33, 44, 83, 80, 65, 67, 69, 125, 125, 10, 112, 97, 117, 115, 101, 61,
  64, 123, 33, 44, 83, 80, 65, 67, 69, 125, 10, 45, 97, 110, 100, 91,
  99, 111, 108, 111, 114, 115, 93, 32, 50, 53, 53, 32, 45, 45, 105, 110,
  100, 101, 120, 91, 99, 111, 108, 111, 114, 115, 93, 32, 91, 99, 101, 110,
  116, 114, 111, 105, 100, 115, 93, 32, 45, 42, 91, 45, 49, 93, 32, 50,
  53, 54, 32, 45, 43, 91, 99, 111, 108, 111, 114, 115, 44, 45, 49, 93,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 123, 99, 111, 108, 111, 114,
  115, 44, 115, 125, 10, 45, 115, 104, 91, 99, 111, 108, 111, 114, 115, 93,
  32, 36, 62, 44, 36, 62, 32, 45, 45, 104, 105, 115, 116, 111, 103, 114,
  97, 109, 91, 45, 49, 93, 32, 123, 64, 123, 99, 101, 110, 116, 114, 111,
  105, 100, 115, 44, 119, 125, 42, 50, 53, 54, 125, 44, 48, 44, 123, 64,
  123, 99, 101, 110, 116, 114, 111, 105, 100, 115, 44, 119, 125, 42, 50, 53,
  54, 45, 49, 125, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 105, 91,
  45, 50, 93, 32, 50, 53, 54, 44, 49, 44, 49, 44, 49, 44, 39, 120,
  39, 32, 45, 114, 91, 45, 50, 93, 32, 123, 119, 125, 44, 49, 44, 49,
  44, 49, 44, 48, 44, 50, 32, 45, 42, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 32, 45, 114, 91, 45, 50, 44, 45, 49, 93, 32, 64, 123, 99,
  101, 110, 116, 114, 111, 105, 100, 115, 44, 119, 125, 44, 49, 44, 49, 44,
  49, 44, 50, 32, 45, 109, 97, 120, 91, 45, 49, 93, 32, 48, 46, 48,
  49, 32, 45, 47, 91, 45, 50, 44, 45, 49, 93, 10, 45, 100, 111, 110,
  101, 32, 45, 97, 91, 45, 64, 123, 99, 111, 108, 111, 114, 115, 44, 115,
  125, 45, 45, 49, 93, 32, 99, 10, 45, 114, 109, 91, 99, 101, 110, 116,
  114, 111, 105, 100, 115, 93, 32, 45, 110, 109, 91, 45, 49, 93, 32, 99,
  101, 110, 116, 114, 111, 105, 100, 115, 10, 45, 45, 62, 62, 91, 99, 111,
  108, 111, 114, 115, 93, 32, 56, 32, 45, 99, 104, 97, 110, 110, 101, 108,
  115, 91, 45, 49, 93, 32, 48, 32, 45, 104, 105, 115, 116, 111, 103, 114,
  97, 109, 91, 45, 49, 93, 32, 64, 123, 99, 101, 110, 116, 114, 111, 105,
  100, 115, 44, 119, 125, 44, 48, 44, 123, 64, 123, 99, 101, 110, 116, 114,
  111, 105, 100, 115, 44, 119, 125, 45, 49, 125, 10, 99, 109, 97, 120, 61,
  64, 123, 45, 49, 44, 120, 77, 125, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 123, 119, 125, 32, 45, 105, 102, 32, 123, 33, 105, 40, 36, 62, 41,
  125, 32, 45, 112, 111, 105, 110, 116, 91, 99, 101, 110, 116, 114, 111, 105,
  100, 115, 93, 32, 36, 62, 44, 48, 44, 48, 44, 49, 44, 64, 123, 45,
  97, 116, 91, 99, 101, 110, 116, 114, 111, 105, 100, 115, 93, 92, 32, 36,
  99, 109, 97, 120, 125, 32, 45, 112, 111, 105, 110, 116, 91, 99, 101, 110,
  116, 114, 111, 105, 100, 115, 93, 32, 36, 62, 44, 48, 44, 48, 44, 45,
  48, 46, 48, 48, 49, 44, 64, 123, 45, 82, 71, 66, 125, 32, 45, 101,
  110, 100, 105, 102, 32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 45,
  49, 93, 32, 45, 99, 91, 99, 101, 110, 116, 114, 111, 105, 100, 115, 93,
  32, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 36, 118, 105, 115, 117,
  95, 51, 100, 32, 45, 114, 109, 91, 118, 105, 115, 117, 95, 51, 100, 93,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 118, 105, 115,
  117, 95, 105, 109, 103, 32, 45, 114, 109, 91, 118, 105, 115, 117, 95, 105,
  109, 103, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36,
  118, 105, 115, 117, 95, 99, 101, 110, 116, 114, 111, 105, 100, 115, 32, 45,
  114, 109, 91, 118, 105, 115, 117, 95, 99, 101, 110, 116, 114, 111, 105, 100,
  115, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 119, 97, 105, 116, 32,
  50, 48, 10, 45, 101, 108, 115, 101, 32, 45, 105, 102, 32, 36, 118, 105,
  115, 117, 95, 105, 109, 103, 32, 45, 119, 97, 105, 116, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  33, 64, 33, 34, 32, 124, 124, 32, 34, 64, 123, 33, 44, 81, 125, 34,
  32, 124, 124, 32, 34, 64, 123, 33, 44, 69, 83, 67, 125, 125, 32, 45,
  98, 114, 101, 97, 107, 32, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111,
  110, 101, 10, 45, 114, 109, 32, 45, 119, 32, 48, 32, 45, 118, 32, 43,
  10, 95, 120, 95, 113, 117, 97, 110, 116, 105, 122, 101, 95, 114, 103, 98,
  95, 51, 100, 32, 58, 10, 45, 105, 102, 32, 36, 111, 98, 106, 51, 100,
  32, 45, 114, 109, 91, 111, 98, 106, 51, 100, 93, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 45, 100, 105, 115, 116, 114, 105, 98, 117, 116, 105, 111,
  110, 51, 100, 91, 99, 101, 110, 116, 114, 111, 105, 100, 115, 93, 32, 45,
  99, 105, 114, 99, 108, 101, 115, 51, 100, 91, 45, 49, 93, 32, 53, 32,
  45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 50, 53, 53, 10, 45,
  99, 111, 108, 111, 114, 99, 117, 98, 101, 51, 100, 32, 45, 112, 51, 100,
  91, 45, 49, 93, 32, 49, 10, 45, 45, 97, 110, 100, 91, 99, 111, 108,
  111, 114, 115, 93, 32, 50, 53, 53, 32, 45, 100, 105, 115, 116, 114, 105,
  98, 117, 116, 105, 111, 110, 51, 100, 91, 45, 49, 93, 32, 45, 111, 51,
  100, 91, 45, 49, 93, 32, 48, 46, 56, 32, 45, 43, 51, 100, 91, 45,
  51, 45, 45, 49, 93, 10, 45, 45, 51, 100, 91, 45, 49, 93, 32, 49,
  50, 56, 44, 49, 50, 56, 44, 49, 50, 56, 32, 45, 110, 109, 91, 45,
  49, 93, 32, 111, 98, 106, 51, 100, 32, 95, 78, 61, 123, 105, 91, 55,
  93, 125, 10, 95, 120, 95, 113, 117, 97, 110, 116, 105, 122, 101, 95, 114,
  103, 98, 95, 116, 101, 120, 116, 32, 58, 10, 48, 32, 45, 116, 101, 120,
  116, 91, 45, 49, 93, 32, 34, 36, 49, 34, 44, 48, 44, 48, 44, 49,
  51, 44, 49, 44, 50, 53, 53, 32, 45, 114, 91, 45, 49, 93, 32, 123,
  119, 43, 50, 125, 44, 49, 53, 44, 49, 44, 49, 44, 48, 44, 48, 44,
  48, 46, 53, 44, 48, 46, 53, 32, 45, 45, 100, 105, 108, 97, 116, 101,
  91, 45, 49, 93, 32, 51, 32, 45, 116, 111, 95, 114, 103, 98, 91, 45,
  50, 93, 10, 45, 110, 109, 91, 45, 50, 93, 32, 36, 50, 32, 45, 110,
  109, 91, 45, 49, 93, 32, 109, 36, 50, 10, 35, 64, 103, 109, 105, 99,
  32, 120, 95, 114, 101, 102, 108, 101, 99, 116, 105, 111, 110, 51, 100, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 76, 97, 117, 110, 99, 104, 32,
  116, 104, 101, 32, 51, 100, 32, 114, 101, 102, 108, 101, 99, 116, 105, 111,
  110, 32, 100, 101, 109, 111, 46, 10, 120, 95, 114, 101, 102, 108, 101, 99,
  116, 105, 111, 110, 51, 100, 32, 58, 10, 45, 101, 91, 93, 32, 34, 92,
  110, 10, 45, 45, 45, 45, 45, 45, 32, 51, 100, 32, 114, 101, 102, 108,
  101, 99, 116, 105, 111, 110, 32, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45,
  45, 45, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39,
  67, 84, 82, 76, 43, 68, 39, 32, 116, 111, 32, 100, 111, 117, 98, 108,
  101, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110,
  10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76,
  43, 67, 39, 32, 116, 111, 32, 114, 101, 115, 101, 116, 32, 119, 105, 110,
  100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45, 45,
  32, 75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39,
  81, 39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45,
  45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 34, 10,
  45, 118, 32, 45, 10, 49, 50, 56, 44, 50, 53, 54, 44, 49, 44, 51,
  32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  32, 45, 112, 108, 97, 115, 109, 97, 91, 45, 49, 93, 32, 49, 44, 49,
  48, 48, 32, 45, 98, 108, 117, 114, 95, 120, 121, 91, 45, 49, 93, 32,
  51, 48, 44, 50, 10, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 48,
  32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 57, 48, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 115, 104, 91, 45, 49, 93, 32, 49, 44, 49,
  32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 54, 48, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 115, 104, 91, 45, 49, 93, 32, 50, 44, 50,
  32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 49, 56, 48, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 45, 109, 105, 114, 114, 111, 114, 91, 45,
  49, 93, 32, 120, 32, 91, 45, 50, 44, 45, 49, 93, 32, 45, 97, 91,
  45, 52, 45, 45, 49, 93, 32, 120, 10, 45, 45, 108, 117, 109, 105, 110,
  97, 110, 99, 101, 91, 45, 49, 93, 32, 45, 109, 105, 114, 114, 111, 114,
  91, 45, 49, 93, 32, 120, 32, 45, 98, 91, 45, 49, 93, 32, 50, 32,
  45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 116, 111,
  114, 117, 115, 51, 100, 32, 51, 48, 44, 49, 48, 32, 45, 99, 111, 108,
  51, 100, 91, 45, 49, 93, 32, 50, 53, 53, 44, 50, 48, 48, 44, 48,
  10, 45, 115, 112, 104, 101, 114, 105, 99, 97, 108, 51, 100, 32, 52, 55,
  44, 51, 52, 44, 34, 56, 48, 43, 50, 48, 42, 97, 98, 115, 40, 99,
  111, 115, 40, 50, 42, 116, 104, 101, 116, 97, 41, 41, 34, 32, 45, 115,
  51, 100, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45,
  105, 91, 45, 50, 93, 32, 51, 44, 123, 104, 125, 44, 49, 44, 49, 44,
  49, 53, 48, 44, 50, 50, 48, 44, 50, 53, 53, 44, 50, 48, 48, 44,
  50, 53, 53, 44, 50, 53, 53, 32, 45, 121, 91, 45, 50, 93, 32, 45,
  97, 91, 45, 54, 45, 45, 49, 93, 32, 121, 10, 45, 115, 112, 104, 101,
  114, 105, 99, 97, 108, 51, 100, 32, 52, 55, 44, 51, 52, 44, 34, 49,
  48, 48, 42, 97, 98, 115, 40, 49, 43, 48, 46, 54, 42, 99, 111, 115,
  40, 51, 42, 112, 104, 105, 41, 42, 115, 105, 110, 40, 52, 42, 116, 104,
  101, 116, 97, 41, 41, 34, 10, 45, 114, 51, 100, 91, 45, 50, 44, 45,
  49, 93, 32, 48, 44, 49, 44, 48, 44, 57, 48, 32, 45, 100, 98, 51,
  100, 32, 48, 10, 120, 98, 61, 48, 32, 120, 108, 61, 48, 32, 97, 110,
  105, 109, 61, 48, 10, 45, 119, 91, 93, 32, 50, 53, 54, 44, 50, 53,
  54, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 51, 100, 32,
  114, 101, 102, 108, 101, 99, 116, 105, 111, 110, 34, 10, 45, 100, 111, 10,
  116, 105, 99, 61, 64, 124, 10, 45, 45, 114, 111, 119, 115, 91, 45, 49,
  93, 32, 56, 44, 123, 56, 43, 51, 42, 105, 91, 54, 93, 45, 49, 125,
  32, 45, 45, 106, 91, 45, 51, 93, 32, 91, 45, 49, 93, 44, 48, 44,
  56, 44, 48, 44, 48, 44, 123, 105, 102, 40, 36, 97, 110, 105, 109, 60,
  50, 53, 48, 44, 48, 44, 48, 46, 53, 45, 48, 46, 53, 42, 99, 111,
  115, 40, 40, 36, 97, 110, 105, 109, 45, 50, 53, 48, 41, 47, 49, 48,
  48, 41, 41, 125, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 45, 122,
  91, 45, 54, 93, 32, 36, 120, 98, 44, 48, 44, 123, 36, 120, 98, 43,
  50, 53, 53, 125, 44, 50, 53, 53, 32, 45, 111, 98, 106, 101, 99, 116,
  51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 55, 53, 37, 44,
  53, 48, 37, 44, 48, 44, 49, 44, 51, 44, 48, 44, 48, 10, 45, 45,
  122, 91, 45, 54, 93, 32, 36, 120, 108, 44, 48, 44, 123, 36, 120, 108,
  43, 50, 53, 53, 125, 44, 50, 53, 53, 10, 120, 102, 61, 123, 109, 105,
  110, 40, 51, 48, 44, 36, 97, 110, 105, 109, 45, 55, 48, 41, 43, 50,
  48, 42, 99, 111, 115, 40, 49, 46, 56, 42, 64, 124, 41, 125, 10, 121,
  102, 61, 123, 53, 48, 43, 50, 48, 42, 115, 105, 110, 40, 50, 46, 55,
  42, 64, 124, 41, 125, 10, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91,
  45, 49, 93, 32, 91, 45, 54, 93, 44, 123, 50, 48, 43, 36, 120, 102,
  125, 37, 44, 36, 121, 102, 37, 44, 48, 44, 49, 44, 52, 44, 48, 44,
  48, 10, 45, 108, 51, 100, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45,
  49, 93, 32, 91, 45, 50, 93, 44, 55, 53, 37, 44, 53, 48, 37, 44,
  48, 44, 49, 44, 53, 44, 48, 44, 48, 32, 45, 106, 91, 45, 50, 93,
  32, 91, 45, 49, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 46,
  54, 32, 45, 114, 109, 91, 45, 51, 44, 45, 49, 93, 10, 45, 111, 98,
  106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 52, 93, 44,
  36, 120, 102, 37, 44, 36, 121, 102, 37, 44, 48, 44, 49, 44, 52, 44,
  48, 44, 48, 10, 45, 119, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123,
  64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64,
  123, 33, 44, 68, 125, 125, 32, 45, 119, 91, 93, 32, 123, 50, 42, 119,
  125, 44, 123, 50, 42, 104, 125, 32, 45, 101, 108, 105, 102, 32, 123, 64,
  123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123,
  33, 44, 67, 125, 125, 32, 45, 119, 91, 93, 32, 123, 119, 125, 44, 123,
  104, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 49,
  93, 10, 120, 98, 61, 123, 40, 36, 120, 98, 43, 54, 41, 38, 50, 53,
  53, 125, 10, 120, 108, 61, 123, 40, 36, 120, 108, 45, 54, 41, 38, 50,
  53, 53, 125, 10, 97, 110, 105, 109, 61, 123, 36, 97, 110, 105, 109, 43,
  49, 125, 10, 45, 114, 51, 100, 91, 45, 50, 44, 45, 49, 93, 32, 123,
  115, 105, 110, 40, 48, 46, 53, 42, 64, 124, 41, 125, 44, 123, 99, 111,
  115, 40, 64, 124, 41, 125, 44, 49, 44, 123, 40, 64, 124, 45, 36, 116,
  105, 99, 41, 42, 51, 51, 125, 10, 45, 114, 51, 100, 91, 45, 51, 93,
  32, 45, 49, 44, 48, 46, 51, 44, 48, 46, 56, 44, 123, 40, 64, 124,
  45, 36, 116, 105, 99, 41, 42, 49, 48, 48, 125, 10, 45, 119, 97, 105,
  116, 32, 50, 48, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34,
  32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67, 125, 34, 32,
  38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125, 10, 45, 114, 109,
  91, 45, 53, 45, 45, 49, 93, 32, 45, 119, 91, 93, 32, 48, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 120, 95, 114, 117, 98,
  98, 101, 114, 51, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 76,
  97, 117, 110, 99, 104, 32, 116, 104, 101, 32, 51, 100, 32, 114, 117, 98,
  98, 101, 114, 32, 111, 98, 106, 101, 99, 116, 32, 100, 101, 109, 111, 46,
  10, 120, 95, 114, 117, 98, 98, 101, 114, 51, 100, 32, 58, 10, 45, 101,
  91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 51, 100,
  32, 114, 117, 98, 98, 101, 114, 32, 111, 98, 106, 101, 99, 116, 32, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32, 75,
  101, 121, 115, 32, 39, 67, 84, 82, 76, 43, 68, 39, 32, 116, 111, 32,
  100, 111, 117, 98, 108, 101, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105,
  122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32,
  39, 67, 84, 82, 76, 43, 67, 39, 32, 116, 111, 32, 114, 101, 115, 101,
  116, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110,
  10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 69, 83, 67, 39,
  32, 111, 114, 32, 39, 81, 39, 32, 116, 111, 32, 101, 120, 105, 116, 46,
  92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 34, 10, 45, 118, 32, 45, 32, 45, 114, 109, 10, 45, 115,
  112, 104, 101, 114, 101, 51, 100, 32, 49, 53, 48, 44, 48, 32, 45, 116,
  111, 114, 117, 115, 51, 100, 32, 55, 48, 44, 49, 53, 32, 45, 99, 121,
  108, 105, 110, 100, 101, 114, 51, 100, 32, 50, 48, 44, 52, 48, 10, 45,
  99, 111, 108, 51, 100, 91, 45, 51, 93, 32, 50, 48, 48, 44, 50, 48,
  48, 44, 50, 48, 48, 44, 48, 46, 51, 32, 45, 99, 111, 108, 51, 100,
  91, 45, 50, 93, 32, 49, 50, 56, 44, 50, 48, 48, 44, 55, 54, 32,
  45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 50, 48, 48, 44, 49,
  50, 56, 44, 55, 54, 10, 45, 99, 51, 100, 91, 45, 51, 45, 45, 49,
  93, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 49, 44, 48, 44, 48,
  44, 55, 48, 32, 45, 43, 51, 100, 91, 45, 51, 45, 45, 49, 93, 32,
  45, 43, 51, 100, 91, 45, 49, 93, 32, 49, 48, 44, 45, 56, 44, 50,
  48, 10, 50, 53, 54, 44, 50, 53, 54, 44, 54, 52, 44, 51, 10, 123,
  119, 125, 44, 123, 104, 125, 44, 49, 44, 51, 44, 39, 105, 102, 40, 99,
  61, 61, 48, 44, 120, 44, 105, 102, 40, 99, 61, 61, 49, 44, 121, 44,
  121, 42, 64, 123, 49, 44, 100, 125, 47, 104, 41, 41, 39, 10, 123, 119,
  125, 44, 123, 104, 125, 44, 49, 44, 51, 10, 45, 119, 91, 93, 32, 123,
  119, 125, 44, 123, 104, 125, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67,
  93, 32, 51, 100, 32, 114, 117, 98, 98, 101, 114, 32, 111, 98, 106, 101,
  99, 116, 34, 10, 102, 114, 97, 109, 101, 61, 48, 10, 45, 100, 111, 10,
  123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 51, 32, 45, 102, 99, 91,
  45, 49, 93, 32, 49, 54, 44, 51, 50, 44, 51, 50, 32, 45, 111, 98,
  106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 48, 93, 44, 53,
  48, 37, 44, 53, 48, 37, 44, 48, 44, 49, 44, 51, 44, 48, 44, 48,
  32, 45, 106, 91, 49, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 44,
  36, 102, 114, 97, 109, 101, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  114, 51, 100, 91, 48, 93, 32, 48, 46, 49, 44, 49, 44, 48, 46, 54,
  44, 123, 51, 42, 99, 111, 115, 40, 64, 124, 42, 49, 46, 50, 53, 41,
  125, 32, 45, 114, 51, 100, 91, 48, 93, 32, 49, 44, 48, 46, 50, 44,
  48, 46, 54, 44, 45, 49, 10, 45, 45, 119, 97, 114, 112, 91, 49, 93,
  32, 91, 50, 93, 44, 48, 44, 48, 32, 45, 42, 91, 51, 93, 32, 48,
  46, 56, 32, 45, 42, 91, 45, 49, 93, 32, 48, 46, 50, 32, 45, 43,
  91, 51, 44, 45, 49, 93, 10, 45, 119, 91, 45, 49, 93, 10, 45, 105,
  102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125,
  38, 38, 64, 123, 33, 44, 68, 125, 125, 32, 45, 119, 91, 93, 32, 123,
  50, 42, 119, 125, 44, 123, 50, 42, 104, 125, 32, 45, 101, 108, 105, 102,
  32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38,
  38, 64, 123, 33, 44, 67, 125, 125, 32, 45, 119, 91, 93, 32, 123, 119,
  125, 44, 123, 104, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 119, 97,
  105, 116, 32, 50, 48, 10, 45, 115, 104, 91, 50, 93, 32, 50, 44, 50,
  32, 45, 45, 91, 45, 49, 93, 32, 49, 32, 45, 97, 110, 100, 91, 45,
  49, 93, 32, 123, 64, 123, 49, 44, 100, 125, 45, 49, 125, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 102, 114, 97, 109, 101, 61, 123, 40, 36, 102,
  114, 97, 109, 101, 45, 49, 41, 37, 64, 123, 49, 44, 100, 125, 125, 10,
  45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34,
  33, 64, 123, 33, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33,
  64, 123, 33, 44, 81, 125, 125, 10, 45, 114, 109, 32, 45, 119, 32, 48,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 120, 95, 115,
  104, 97, 100, 101, 98, 111, 98, 115, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 76, 97, 117, 110, 99, 104, 32, 116, 104, 101, 32, 115, 104, 97,
  100, 101, 32, 98, 111, 98, 115, 32, 100, 101, 109, 111, 46, 10, 120, 95,
  115, 104, 97, 100, 101, 98, 111, 98, 115, 32, 58, 10, 45, 101, 91, 93,
  32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 83, 104, 97, 100,
  101, 32, 98, 111, 98, 115, 32, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10,
  45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32,
  111, 114, 32, 39, 81, 39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92,
  110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 109, 32, 116, 61, 49, 48, 48, 32, 45, 119, 32, 53, 49,
  50, 44, 53, 49, 50, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93,
  32, 83, 104, 97, 100, 101, 32, 98, 111, 98, 115, 34, 10, 45, 100, 111,
  10, 116, 61, 123, 36, 116, 43, 48, 46, 48, 49, 53, 125, 10, 45, 105,
  102, 32, 123, 36, 116, 62, 52, 42, 112, 105, 34, 32, 124, 124, 32, 34,
  64, 123, 33, 44, 98, 125, 125, 10, 114, 120, 61, 123, 63, 40, 45, 49,
  44, 49, 41, 125, 32, 114, 121, 61, 123, 63, 40, 45, 49, 44, 49, 41,
  125, 32, 114, 122, 61, 123, 63, 40, 45, 49, 44, 49, 41, 125, 32, 114,
  116, 61, 123, 63, 40, 45, 49, 44, 49, 41, 125, 32, 114, 99, 120, 61,
  123, 63, 40, 45, 48, 46, 54, 42, 48, 46, 54, 41, 125, 32, 116, 61,
  48, 10, 78, 61, 123, 50, 48, 43, 114, 111, 117, 110, 100, 40, 63, 40,
  56, 48, 41, 41, 125, 32, 82, 61, 123, 40, 50, 43, 114, 111, 117, 110,
  100, 40, 63, 40, 52, 48, 41, 41, 41, 42, 109, 105, 110, 40, 64, 123,
  33, 44, 119, 125, 44, 64, 123, 33, 44, 104, 125, 41, 47, 51, 48, 48,
  125, 10, 45, 105, 102, 32, 36, 111, 98, 106, 51, 100, 32, 45, 114, 109,
  91, 99, 111, 108, 111, 114, 109, 97, 112, 44, 105, 109, 103, 44, 111, 98,
  106, 51, 100, 93, 32, 45, 101, 110, 100, 105, 102, 10, 123, 52, 43, 114,
  111, 117, 110, 100, 40, 63, 40, 49, 50, 41, 41, 125, 44, 49, 44, 49,
  44, 51, 32, 45, 110, 111, 105, 115, 101, 91, 48, 93, 32, 50, 53, 53,
  44, 50, 32, 45, 114, 91, 48, 93, 32, 50, 53, 54, 44, 49, 44, 49,
  44, 51, 44, 51, 32, 45, 42, 91, 48, 93, 32, 50, 53, 53, 32, 45,
  115, 104, 105, 102, 116, 91, 48, 93, 32, 49, 32, 45, 110, 109, 91, 45,
  49, 93, 32, 99, 111, 108, 111, 114, 109, 97, 112, 10, 40, 54, 55, 46,
  53, 59, 55, 51, 46, 53, 59, 49, 48, 57, 46, 53, 59, 49, 48, 51,
  46, 53, 59, 53, 49, 46, 53, 59, 49, 48, 48, 46, 53, 59, 123, 50,
  42, 36, 78, 125, 59, 36, 78, 41, 32, 51, 44, 123, 50, 42, 36, 78,
  125, 44, 49, 44, 49, 44, 48, 10, 49, 44, 36, 78, 44, 49, 44, 49,
  44, 53, 32, 50, 44, 36, 78, 44, 49, 44, 49, 44, 39, 121, 43, 120,
  42, 36, 78, 39, 32, 45, 97, 91, 45, 50, 45, 45, 49, 93, 32, 120,
  32, 45, 122, 91, 45, 49, 93, 32, 48, 44, 53, 10, 52, 44, 36, 78,
  44, 49, 44, 49, 44, 49, 32, 45, 121, 91, 45, 51, 45, 45, 49, 93,
  32, 45, 97, 91, 45, 52, 45, 45, 49, 93, 32, 121, 32, 45, 110, 109,
  91, 45, 49, 93, 32, 111, 98, 106, 51, 100, 10, 64, 123, 33, 44, 119,
  125, 44, 64, 123, 33, 44, 104, 125, 32, 45, 110, 109, 91, 45, 49, 93,
  32, 105, 109, 103, 10, 45, 119, 97, 105, 116, 32, 45, 49, 10, 45, 101,
  110, 100, 105, 102, 10, 114, 61, 123, 36, 114, 121, 43, 36, 114, 120, 42,
  99, 111, 115, 40, 54, 42, 36, 114, 122, 42, 36, 116, 41, 43, 40, 49,
  45, 36, 114, 120, 41, 42, 115, 105, 110, 40, 54, 42, 36, 114, 116, 42,
  36, 116, 41, 125, 10, 40, 48, 59, 123, 51, 48, 42, 36, 114, 121, 42,
  40, 36, 78, 45, 49, 41, 125, 41, 32, 40, 36, 116, 59, 123, 50, 42,
  112, 105, 42, 40, 36, 78, 45, 49, 41, 47, 36, 78, 43, 36, 116, 125,
  41, 32, 45, 114, 91, 45, 50, 44, 45, 49, 93, 32, 49, 44, 36, 78,
  44, 49, 44, 49, 44, 51, 10, 45, 43, 91, 45, 50, 93, 32, 123, 51,
  54, 48, 42, 115, 105, 110, 40, 36, 114, 122, 42, 36, 116, 41, 125, 32,
  45, 42, 91, 45, 50, 93, 32, 123, 112, 105, 47, 49, 56, 48, 125, 10,
  45, 45, 115, 105, 110, 91, 45, 50, 44, 45, 49, 93, 32, 45, 99, 111,
  115, 91, 45, 52, 44, 45, 51, 93, 32, 45, 42, 91, 45, 52, 44, 45,
  50, 93, 32, 36, 114, 32, 45, 42, 91, 45, 51, 44, 45, 49, 93, 32,
  36, 114, 99, 120, 32, 45, 43, 91, 45, 52, 44, 45, 51, 93, 32, 45,
  43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 42, 91, 45, 50, 93, 32,
  123, 64, 123, 33, 44, 119, 125, 47, 50, 125, 32, 45, 42, 91, 45, 49,
  93, 32, 123, 64, 123, 33, 44, 104, 125, 47, 50, 125, 32, 45, 97, 91,
  45, 50, 44, 45, 49, 93, 32, 120, 10, 45, 45, 43, 91, 45, 49, 93,
  32, 36, 82, 32, 45, 45, 91, 45, 50, 93, 32, 36, 82, 32, 45, 97,
  91, 45, 50, 44, 45, 49, 93, 32, 121, 32, 45, 122, 91, 45, 49, 93,
  32, 48, 44, 50, 32, 45, 121, 91, 45, 49, 93, 32, 45, 106, 91, 111,
  98, 106, 51, 100, 93, 32, 91, 45, 49, 93, 44, 48, 44, 56, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 111, 98, 106, 101, 99, 116, 51, 100,
  91, 105, 109, 103, 93, 32, 91, 111, 98, 106, 51, 100, 93, 44, 53, 48,
  37, 44, 53, 48, 37, 44, 48, 44, 45, 49, 44, 50, 44, 48, 44, 48,
  10, 45, 97, 110, 100, 91, 105, 109, 103, 93, 32, 50, 53, 53, 32, 45,
  45, 109, 97, 112, 91, 105, 109, 103, 93, 32, 91, 99, 111, 108, 111, 114,
  109, 97, 112, 93, 32, 45, 119, 91, 45, 49, 93, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 119, 97, 105, 116, 32, 50, 48, 10, 45, 119, 104,
  105, 108, 101, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123,
  33, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33,
  44, 81, 125, 125, 10, 45, 114, 109, 32, 45, 119, 32, 48, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 120, 95, 115, 112, 108, 105,
  110, 101, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 76, 97, 117, 110,
  99, 104, 32, 115, 112, 108, 105, 110, 101, 32, 99, 117, 114, 118, 101, 32,
  101, 100, 105, 116, 111, 114, 46, 10, 120, 95, 115, 112, 108, 105, 110, 101,
  32, 58, 10, 45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45,
  45, 45, 32, 83, 112, 108, 105, 110, 101, 32, 99, 117, 114, 118, 101, 32,
  101, 100, 105, 116, 111, 114, 32, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32,
  77, 111, 117, 115, 101, 32, 116, 111, 32, 105, 110, 115, 101, 114, 116, 47,
  109, 111, 118, 101, 47, 100, 101, 108, 101, 116, 101, 32, 112, 111, 105, 110,
  116, 115, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 32, 39,
  82, 39, 32, 116, 111, 32, 114, 101, 115, 101, 116, 32, 116, 104, 101, 32,
  99, 117, 114, 118, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101,
  121, 32, 39, 83, 80, 65, 67, 69, 39, 32, 116, 111, 32, 115, 104, 111,
  119, 115, 47, 104, 105, 100, 101, 32, 115, 112, 108, 105, 110, 101, 32, 99,
  117, 114, 118, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121,
  32, 39, 80, 39, 32, 116, 111, 32, 115, 104, 111, 119, 115, 47, 104, 105,
  100, 101, 32, 99, 111, 110, 116, 114, 111, 108, 32, 112, 111, 105, 110, 116,
  115, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 32, 39, 69,
  78, 84, 69, 82, 39, 32, 116, 111, 32, 115, 104, 111, 119, 115, 47, 104,
  105, 100, 101, 32, 99, 111, 110, 116, 114, 111, 108, 32, 112, 111, 108, 121,
  103, 111, 110, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 32,
  39, 84, 39, 32, 116, 111, 32, 115, 104, 111, 119, 115, 47, 104, 105, 100,
  101, 32, 112, 111, 105, 110, 116, 32, 116, 97, 110, 103, 101, 110, 116, 115,
  46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 32, 39, 73, 39,
  32, 116, 111, 32, 115, 104, 111, 119, 115, 47, 104, 105, 100, 101, 32, 112,
  111, 105, 110, 116, 32, 105, 110, 100, 105, 99, 101, 115, 46, 92, 110, 10,
  45, 45, 45, 45, 32, 75, 101, 121, 32, 39, 67, 39, 32, 116, 111, 32,
  115, 104, 111, 119, 115, 47, 104, 105, 100, 101, 32, 112, 111, 105, 110, 116,
  32, 99, 111, 111, 114, 100, 105, 110, 97, 116, 101, 115, 46, 92, 110, 10,
  45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 43, 39, 32, 97, 110,
  100, 32, 39, 45, 39, 32, 116, 111, 32, 105, 110, 99, 114, 101, 97, 115,
  101, 47, 100, 101, 99, 114, 101, 97, 115, 101, 32, 114, 111, 117, 110, 100,
  110, 101, 115, 115, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121,
  115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81, 39, 32, 116,
  111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110,
  10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 10, 45, 105, 102,
  32, 64, 35, 32, 45, 97, 32, 120, 32, 45, 110, 32, 48, 44, 50, 53,
  53, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 101, 108, 115, 101, 32,
  40, 48, 59, 48, 94, 48, 59, 49, 50, 56, 94, 48, 59, 48, 41, 32,
  45, 114, 91, 45, 49, 93, 32, 53, 49, 50, 44, 53, 49, 50, 44, 49,
  44, 51, 44, 51, 32, 45, 110, 97, 109, 101, 91, 45, 49, 93, 32, 34,
  91, 71, 39, 77, 73, 67, 93, 32, 83, 112, 108, 105, 110, 101, 32, 69,
  100, 105, 116, 111, 114, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 119,
  91, 48, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104,
  125, 44, 48, 44, 48, 44, 45, 49, 44, 45, 49, 44, 64, 123, 45, 49,
  44, 110, 125, 32, 45, 114, 91, 48, 93, 32, 64, 123, 33, 44, 119, 125,
  44, 64, 123, 33, 44, 104, 125, 44, 49, 44, 51, 44, 49, 10, 45, 105,
  91, 49, 93, 32, 49, 10, 114, 111, 117, 110, 100, 110, 101, 115, 115, 61,
  48, 46, 53, 10, 118, 105, 115, 117, 102, 108, 97, 103, 115, 61, 50, 51,
  10, 110, 101, 97, 114, 101, 115, 116, 61, 45, 49, 10, 97, 99, 116, 105,
  118, 101, 61, 45, 49, 10, 45, 100, 111, 10, 45, 105, 102, 32, 123, 64,
  123, 49, 44, 35, 125, 61, 61, 49, 125, 10, 45, 114, 109, 91, 49, 93,
  32, 114, 111, 117, 110, 100, 110, 101, 115, 115, 61, 48, 46, 53, 32, 110,
  101, 97, 114, 101, 115, 116, 61, 45, 49, 32, 97, 99, 116, 105, 118, 101,
  61, 45, 49, 10, 45, 105, 91, 49, 93, 32, 40, 123, 48, 46, 50, 42,
  119, 125, 44, 123, 48, 46, 50, 42, 104, 125, 59, 92, 10, 123, 48, 46,
  50, 42, 119, 125, 44, 123, 48, 46, 56, 42, 104, 125, 59, 92, 10, 123,
  48, 46, 56, 42, 119, 125, 44, 123, 48, 46, 56, 42, 104, 125, 59, 92,
  10, 123, 48, 46, 56, 42, 119, 125, 44, 123, 48, 46, 50, 42, 104, 125,
  41, 10, 45, 101, 110, 100, 105, 102, 10, 91, 49, 93, 32, 40, 123, 64,
  123, 33, 44, 119, 125, 47, 64, 123, 48, 44, 119, 125, 125, 44, 123, 64,
  123, 33, 44, 104, 125, 47, 64, 123, 48, 44, 104, 125, 125, 41, 32, 45,
  42, 91, 45, 50, 44, 45, 49, 93, 10, 45, 45, 115, 104, 105, 102, 116,
  91, 50, 93, 32, 48, 44, 45, 49, 44, 48, 44, 48, 44, 50, 32, 45,
  45, 115, 104, 105, 102, 116, 91, 50, 93, 32, 48, 44, 49, 44, 48, 44,
  48, 44, 50, 32, 45, 45, 91, 45, 50, 44, 45, 49, 93, 32, 45, 42,
  91, 45, 49, 93, 32, 36, 114, 111, 117, 110, 100, 110, 101, 115, 115, 10,
  45, 45, 115, 91, 45, 49, 93, 32, 120, 32, 45, 115, 113, 114, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 115, 113, 114, 116, 91, 45, 49, 93, 32, 45, 114, 91, 45, 49, 93,
  32, 50, 32, 45, 45, 47, 91, 45, 50, 44, 45, 49, 93, 32, 45, 114,
  109, 91, 45, 50, 93, 10, 45, 45, 114, 91, 48, 93, 32, 64, 123, 33,
  44, 119, 125, 44, 64, 123, 33, 44, 104, 125, 44, 49, 44, 51, 10, 45,
  105, 102, 32, 123, 36, 118, 105, 115, 117, 102, 108, 97, 103, 115, 38, 52,
  125, 32, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 64,
  123, 50, 44, 104, 125, 44, 64, 50, 44, 48, 46, 51, 44, 49, 50, 56,
  44, 50, 48, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 123, 49, 44, 104, 125, 10, 45,
  108, 105, 110, 101, 91, 45, 49, 93, 32, 64, 123, 50, 44, 48, 45, 51,
  125, 44, 48, 46, 51, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 10,
  45, 105, 102, 32, 123, 36, 118, 105, 115, 117, 102, 108, 97, 103, 115, 38,
  49, 125, 32, 45, 115, 112, 108, 105, 110, 101, 91, 45, 49, 93, 32, 64,
  123, 50, 44, 48, 45, 49, 125, 44, 64, 123, 51, 44, 48, 45, 49, 125,
  44, 64, 123, 50, 44, 50, 45, 51, 125, 44, 64, 123, 51, 44, 50, 45,
  51, 125, 44, 51, 50, 44, 49, 44, 50, 53, 53, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 118, 105, 115, 117, 102, 108, 97,
  103, 115, 38, 56, 125, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32,
  123, 64, 123, 50, 44, 48, 125, 45, 64, 123, 52, 44, 48, 125, 42, 50,
  48, 125, 44, 123, 64, 123, 50, 44, 49, 125, 45, 64, 123, 52, 44, 49,
  125, 42, 50, 48, 125, 44, 123, 64, 123, 50, 44, 48, 125, 43, 64, 123,
  52, 44, 48, 125, 42, 50, 48, 125, 44, 123, 64, 123, 50, 44, 49, 125,
  43, 64, 123, 52, 44, 49, 125, 42, 50, 48, 125, 44, 49, 44, 48, 44,
  50, 53, 53, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 118, 105, 115, 117, 102, 108, 97, 103, 115, 38, 49, 54, 125,
  32, 45, 116, 91, 45, 49, 93, 32, 36, 62, 44, 123, 64, 123, 50, 44,
  48, 125, 45, 51, 125, 44, 123, 64, 123, 50, 44, 49, 125, 45, 49, 56,
  125, 44, 49, 51, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 118, 105,
  115, 117, 102, 108, 97, 103, 115, 38, 51, 50, 125, 32, 45, 116, 91, 45,
  49, 93, 32, 34, 40, 34, 123, 114, 111, 117, 110, 100, 40, 64, 123, 49,
  44, 48, 125, 41, 125, 34, 44, 34, 123, 114, 111, 117, 110, 100, 40, 64,
  123, 49, 44, 49, 125, 41, 125, 34, 41, 34, 44, 123, 64, 123, 50, 44,
  48, 125, 45, 49, 54, 125, 44, 123, 64, 123, 50, 44, 49, 125, 43, 49,
  48, 125, 44, 49, 51, 44, 49, 44, 49, 48, 48, 44, 50, 48, 48, 44,
  50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 115, 104, 105, 102,
  116, 91, 49, 45, 52, 93, 32, 48, 44, 45, 49, 44, 48, 44, 48, 44,
  50, 10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 118, 105,
  115, 117, 102, 108, 97, 103, 115, 34, 38, 50, 34, 125, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 123, 49, 44, 104, 125, 10, 45, 101, 108, 108,
  105, 112, 115, 101, 91, 45, 49, 93, 32, 64, 123, 50, 44, 48, 45, 49,
  125, 44, 52, 44, 52, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 32,
  45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 64, 123, 50,
  44, 48, 45, 49, 125, 44, 50, 44, 50, 44, 48, 44, 49, 44, 50, 53,
  53, 44, 49, 48, 48, 44, 49, 53, 53, 32, 45, 115, 104, 105, 102, 116,
  91, 50, 93, 32, 48, 44, 49, 44, 48, 44, 48, 44, 50, 10, 45, 100,
  111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 119, 91, 45, 49,
  93, 32, 45, 114, 109, 91, 51, 44, 52, 44, 45, 49, 93, 32, 45, 119,
  97, 105, 116, 10, 45, 105, 102, 32, 64, 123, 33, 44, 83, 80, 65, 67,
  69, 125, 32, 118, 105, 115, 117, 102, 108, 97, 103, 115, 61, 123, 36, 118,
  105, 115, 117, 102, 108, 97, 103, 115, 43, 105, 102, 40, 36, 118, 105, 115,
  117, 102, 108, 97, 103, 115, 38, 49, 44, 45, 49, 44, 49, 41, 125, 32,
  45, 119, 97, 105, 116, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 64, 123, 33, 44, 80, 125, 32, 118, 105, 115, 117, 102,
  108, 97, 103, 115, 61, 123, 36, 118, 105, 115, 117, 102, 108, 97, 103, 115,
  43, 105, 102, 40, 36, 118, 105, 115, 117, 102, 108, 97, 103, 115, 38, 50,
  44, 45, 50, 44, 50, 41, 125, 32, 45, 119, 97, 105, 116, 32, 45, 49,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 64, 123, 33, 44,
  69, 78, 84, 69, 82, 125, 32, 118, 105, 115, 117, 102, 108, 97, 103, 115,
  61, 123, 36, 118, 105, 115, 117, 102, 108, 97, 103, 115, 43, 105, 102, 40,
  36, 118, 105, 115, 117, 102, 108, 97, 103, 115, 38, 52, 44, 45, 52, 44,
  52, 41, 125, 32, 45, 119, 97, 105, 116, 32, 45, 49, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 64, 123, 33, 44, 84, 125, 32, 118,
  105, 115, 117, 102, 108, 97, 103, 115, 61, 123, 36, 118, 105, 115, 117, 102,
  108, 97, 103, 115, 43, 105, 102, 40, 36, 118, 105, 115, 117, 102, 108, 97,
  103, 115, 38, 56, 44, 45, 56, 44, 56, 41, 125, 32, 45, 119, 97, 105,
  116, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  64, 123, 33, 44, 73, 125, 32, 118, 105, 115, 117, 102, 108, 97, 103, 115,
  61, 123, 36, 118, 105, 115, 117, 102, 108, 97, 103, 115, 43, 105, 102, 40,
  36, 118, 105, 115, 117, 102, 108, 97, 103, 115, 38, 49, 54, 44, 45, 49,
  54, 44, 49, 54, 41, 125, 32, 45, 119, 97, 105, 116, 32, 45, 49, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44,
  67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 67, 84, 82,
  76, 76, 69, 70, 84, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33,
  44, 67, 84, 82, 76, 82, 73, 71, 72, 84, 125, 125, 32, 118, 105, 115,
  117, 102, 108, 97, 103, 115, 61, 123, 36, 118, 105, 115, 117, 102, 108, 97,
  103, 115, 43, 105, 102, 40, 36, 118, 105, 115, 117, 102, 108, 97, 103, 115,
  38, 51, 50, 44, 45, 51, 50, 44, 51, 50, 41, 125, 32, 45, 119, 97,
  105, 116, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 64, 123, 33, 44, 80, 65, 68, 65, 68, 68, 125, 34, 32, 38,
  38, 32, 34, 36, 114, 111, 117, 110, 100, 110, 101, 115, 115, 60, 49, 125,
  32, 114, 111, 117, 110, 100, 110, 101, 115, 115, 61, 123, 36, 114, 111, 117,
  110, 100, 110, 101, 115, 115, 42, 49, 46, 49, 125, 32, 45, 119, 97, 105,
  116, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 64, 123, 33, 44, 80, 65, 68, 83, 85, 66, 125, 34, 32, 38, 38,
  32, 34, 36, 114, 111, 117, 110, 100, 110, 101, 115, 115, 62, 48, 46, 49,
  125, 32, 114, 111, 117, 110, 100, 110, 101, 115, 115, 61, 123, 36, 114, 111,
  117, 110, 100, 110, 101, 115, 115, 42, 48, 46, 57, 125, 32, 45, 119, 97,
  105, 116, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 64, 123, 33, 44, 82, 125, 34, 32, 38, 38, 32, 34, 33, 64,
  123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 34, 32, 38, 38,
  32, 34, 33, 64, 123, 33, 44, 67, 84, 82, 76, 82, 73, 71, 72, 84,
  125, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 105, 91, 49, 93,
  32, 49, 32, 45, 119, 97, 105, 116, 32, 45, 49, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 40, 64, 123, 33, 44, 67, 84, 82,
  76, 76, 69, 70, 84, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 44,
  67, 84, 82, 76, 82, 73, 71, 72, 84, 125, 41, 34, 32, 38, 38, 32,
  34, 64, 123, 33, 44, 68, 125, 125, 32, 45, 119, 91, 93, 32, 123, 64,
  123, 33, 44, 119, 125, 42, 49, 46, 53, 125, 44, 123, 64, 123, 33, 44,
  104, 125, 42, 49, 46, 53, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 40, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70,
  84, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 44, 67, 84, 82, 76,
  82, 73, 71, 72, 84, 125, 41, 34, 32, 38, 38, 32, 34, 64, 123, 33,
  44, 67, 125, 125, 32, 45, 119, 91, 93, 32, 123, 64, 123, 33, 44, 119,
  125, 47, 49, 46, 53, 125, 44, 123, 64, 123, 33, 44, 104, 125, 47, 49,
  46, 53, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  40, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 34, 32,
  124, 124, 32, 34, 64, 123, 33, 44, 67, 84, 82, 76, 82, 73, 71, 72,
  84, 125, 41, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 82, 125, 125,
  32, 45, 119, 91, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48,
  44, 104, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 64,
  123, 33, 44, 114, 125, 32, 45, 119, 91, 93, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 98, 125, 61, 61, 48,
  125, 32, 97, 99, 116, 105, 118, 101, 61, 45, 49, 10, 45, 101, 108, 105,
  102, 32, 123, 64, 123, 33, 44, 120, 125, 62, 61, 48, 34, 32, 38, 38,
  32, 34, 64, 123, 33, 44, 98, 125, 34, 32, 38, 38, 32, 34, 36, 97,
  99, 116, 105, 118, 101, 61, 61, 45, 49, 125, 10, 91, 50, 93, 32, 40,
  64, 123, 33, 44, 120, 125, 44, 64, 123, 33, 44, 121, 125, 41, 32, 45,
  45, 91, 45, 50, 44, 45, 49, 93, 32, 45, 115, 113, 114, 91, 45, 49,
  93, 32, 45, 115, 91, 45, 49, 93, 32, 120, 32, 45, 43, 91, 45, 50,
  44, 45, 49, 93, 10, 40, 64, 123, 45, 49, 44, 99, 125, 41, 32, 110,
  101, 97, 114, 101, 115, 116, 61, 64, 123, 45, 49, 44, 49, 125, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 64, 123, 45, 49,
  44, 109, 125, 60, 54, 52, 125, 32, 97, 99, 116, 105, 118, 101, 61, 36,
  110, 101, 97, 114, 101, 115, 116, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114,
  109, 91, 50, 93, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 98, 125,
  38, 49, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 120, 125, 62, 61,
  48, 34, 32, 38, 38, 32, 34, 36, 97, 99, 116, 105, 118, 101, 33, 61,
  45, 49, 125, 10, 45, 61, 91, 49, 93, 32, 123, 64, 123, 33, 44, 120,
  125, 42, 64, 123, 48, 44, 119, 125, 47, 64, 123, 33, 44, 119, 125, 125,
  44, 48, 44, 36, 97, 99, 116, 105, 118, 101, 10, 45, 61, 91, 49, 93,
  32, 123, 64, 123, 33, 44, 121, 125, 42, 64, 123, 48, 44, 104, 125, 47,
  64, 123, 33, 44, 104, 125, 125, 44, 49, 44, 36, 97, 99, 116, 105, 118,
  101, 10, 45, 101, 108, 105, 102, 32, 123, 64, 123, 33, 44, 98, 125, 38,
  50, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 120, 125, 62, 61, 48,
  34, 32, 38, 38, 32, 34, 64, 123, 49, 44, 104, 125, 62, 51, 125, 10,
  45, 108, 91, 49, 93, 32, 45, 115, 32, 121, 32, 45, 114, 109, 91, 36,
  110, 101, 97, 114, 101, 115, 116, 93, 32, 45, 97, 32, 121, 32, 45, 101,
  110, 100, 108, 32, 45, 119, 97, 105, 116, 32, 45, 49, 10, 45, 101, 108,
  105, 102, 32, 123, 64, 123, 33, 44, 98, 125, 38, 49, 34, 32, 38, 38,
  32, 34, 64, 123, 33, 44, 120, 125, 62, 61, 48, 125, 10, 120, 121, 61,
  40, 123, 64, 123, 33, 44, 120, 125, 42, 64, 123, 48, 44, 119, 125, 47,
  64, 123, 33, 44, 119, 125, 125, 44, 123, 64, 123, 33, 44, 121, 125, 42,
  64, 123, 48, 44, 104, 125, 47, 64, 123, 33, 44, 104, 125, 125, 41, 10,
  45, 45, 115, 104, 105, 102, 116, 91, 49, 93, 32, 48, 44, 45, 49, 44,
  48, 44, 48, 44, 50, 32, 45, 43, 91, 45, 49, 93, 32, 91, 49, 93,
  32, 45, 47, 91, 45, 49, 93, 32, 50, 10, 36, 120, 121, 32, 45, 45,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 115, 113, 114, 91, 45, 49, 93,
  32, 45, 115, 91, 45, 49, 93, 32, 120, 32, 45, 43, 91, 45, 50, 44,
  45, 49, 93, 10, 40, 64, 123, 45, 49, 44, 99, 125, 41, 32, 110, 115,
  61, 64, 123, 45, 49, 44, 49, 125, 32, 45, 114, 109, 91, 45, 50, 44,
  45, 49, 93, 10, 45, 108, 91, 49, 93, 32, 45, 115, 32, 121, 32, 45,
  105, 91, 123, 36, 110, 115, 43, 49, 125, 93, 32, 36, 120, 121, 32, 45,
  97, 32, 121, 32, 45, 101, 110, 100, 108, 10, 97, 99, 116, 105, 118, 101,
  61, 123, 36, 110, 115, 43, 49, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34,
  33, 64, 123, 33, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33,
  64, 123, 33, 44, 81, 125, 125, 10, 45, 45, 115, 104, 105, 102, 116, 91,
  49, 93, 32, 48, 44, 45, 49, 44, 48, 44, 48, 44, 50, 32, 45, 45,
  115, 104, 105, 102, 116, 91, 49, 93, 32, 48, 44, 49, 44, 48, 44, 48,
  44, 50, 32, 45, 45, 91, 45, 50, 44, 45, 49, 93, 32, 45, 42, 91,
  45, 49, 93, 32, 36, 114, 111, 117, 110, 100, 110, 101, 115, 115, 10, 91,
  48, 93, 44, 91, 48, 93, 44, 49, 44, 49, 44, 50, 32, 45, 114, 109,
  91, 48, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 123, 49, 44,
  104, 125, 32, 45, 115, 112, 108, 105, 110, 101, 91, 45, 49, 93, 32, 64,
  123, 48, 44, 48, 45, 49, 125, 44, 64, 123, 49, 44, 48, 45, 49, 125,
  44, 64, 123, 48, 44, 50, 45, 51, 125, 44, 64, 123, 49, 44, 50, 45,
  51, 125, 44, 49, 50, 56, 44, 49, 44, 49, 32, 45, 115, 104, 105, 102,
  116, 91, 48, 93, 32, 48, 44, 45, 49, 44, 48, 44, 48, 44, 50, 32,
  45, 115, 104, 105, 102, 116, 91, 49, 93, 32, 48, 44, 45, 49, 44, 48,
  44, 48, 44, 50, 32, 45, 100, 111, 110, 101, 10, 45, 102, 108, 111, 111,
  100, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44,
  49, 44, 48, 10, 45, 114, 109, 91, 48, 44, 49, 93, 32, 45, 119, 32,
  48, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 120, 95,
  116, 101, 116, 114, 105, 115, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  76, 97, 117, 110, 99, 104, 32, 116, 101, 116, 114, 105, 115, 32, 103, 97,
  109, 101, 46, 10, 120, 95, 116, 101, 116, 114, 105, 115, 32, 58, 10, 45,
  101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 84,
  101, 116, 114, 105, 115, 32, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45,
  32, 84, 104, 105, 115, 32, 105, 115, 32, 97, 32, 71, 39, 77, 73, 67,
  32, 105, 109, 112, 108, 101, 109, 101, 110, 116, 97, 116, 105, 111, 110, 32,
  111, 102, 32, 116, 104, 101, 32, 84, 101, 116, 114, 105, 115, 32, 103, 97,
  109, 101, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45,
  45, 32, 65, 114, 114, 111, 119, 32, 107, 101, 121, 115, 32, 116, 111, 32,
  109, 111, 118, 101, 47, 114, 111, 116, 97, 116, 101, 32, 116, 104, 101, 32,
  116, 114, 105, 111, 109, 105, 110, 111, 115, 46, 92, 110, 10, 45, 45, 45,
  45, 32, 75, 101, 121, 32, 39, 83, 80, 65, 67, 69, 39, 32, 116, 111,
  32, 109, 97, 107, 101, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110,
  116, 32, 116, 114, 105, 111, 109, 105, 110, 111, 32, 102, 97, 108, 108, 105,
  110, 103, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32,
  39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81, 39, 32, 116, 111, 32,
  101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 109, 10, 45, 105, 91, 109, 48, 93, 32, 52,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 10, 45,
  105, 91, 109, 52, 93, 32, 51, 44, 50, 44, 49, 44, 49, 44, 49, 44,
  48, 44, 48, 44, 49, 44, 49, 44, 49, 10, 45, 105, 91, 109, 56, 93,
  32, 51, 44, 50, 44, 49, 44, 49, 44, 48, 44, 48, 44, 49, 44, 49,
  44, 49, 44, 49, 10, 45, 105, 91, 109, 49, 50, 93, 32, 50, 44, 50,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 10, 45, 105, 91,
  109, 49, 54, 93, 32, 51, 44, 50, 44, 49, 44, 49, 44, 48, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 48, 10, 45, 105, 91, 109, 50, 48, 93,
  32, 51, 44, 50, 44, 49, 44, 49, 44, 48, 44, 49, 44, 48, 44, 49,
  44, 49, 44, 49, 10, 45, 105, 91, 109, 50, 52, 93, 32, 51, 44, 50,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 48, 44, 48, 44, 49, 44, 49,
  10, 45, 105, 102, 32, 123, 63, 60, 48, 46, 50, 53, 125, 10, 45, 105,
  91, 109, 50, 56, 93, 32, 50, 44, 49, 44, 49, 44, 49, 44, 49, 44,
  49, 10, 45, 105, 91, 109, 51, 50, 93, 32, 50, 44, 50, 44, 49, 44,
  49, 44, 49, 44, 49, 44, 48, 44, 49, 10, 45, 105, 91, 109, 51, 54,
  93, 32, 51, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 10,
  45, 105, 91, 109, 52, 48, 93, 32, 49, 44, 49, 44, 49, 44, 49, 44,
  49, 10, 45, 105, 91, 109, 52, 52, 93, 32, 51, 44, 50, 44, 49, 44,
  49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 48, 44, 49, 10, 45, 105,
  91, 109, 52, 56, 93, 32, 51, 44, 51, 44, 49, 44, 49, 44, 49, 44,
  49, 44, 49, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49, 44, 49, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 105, 61, 123, 52, 42, 36, 62, 125, 32, 45, 108, 91, 109, 36,
  105, 93, 32, 45, 114, 101, 112, 101, 97, 116, 32, 51, 32, 45, 45, 114,
  111, 116, 97, 116, 101, 91, 48, 93, 32, 123, 57, 48, 42, 40, 36, 62,
  43, 49, 41, 125, 32, 45, 110, 109, 91, 45, 49, 93, 32, 109, 123, 36,
  105, 43, 36, 62, 43, 49, 125, 32, 45, 100, 111, 110, 101, 32, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 78, 61, 64, 35, 10, 45,
  105, 91, 99, 111, 108, 111, 114, 115, 93, 32, 51, 44, 36, 78, 44, 49,
  44, 49, 44, 39, 63, 40, 49, 54, 44, 50, 50, 52, 41, 39, 32, 45,
  114, 91, 45, 49, 93, 32, 51, 44, 52, 48, 48, 37, 32, 45, 105, 91,
  109, 97, 115, 107, 93, 32, 40, 48, 44, 45, 49, 44, 48, 59, 49, 44,
  48, 44, 45, 49, 59, 48, 44, 49, 44, 48, 41, 32, 45, 42, 91, 45,
  49, 93, 32, 49, 50, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36,
  78, 10, 45, 45, 114, 91, 109, 36, 62, 93, 32, 53, 48, 48, 37, 44,
  53, 48, 48, 37, 44, 49, 44, 51, 32, 45, 45, 99, 111, 114, 114, 101,
  108, 97, 116, 101, 91, 45, 49, 93, 32, 91, 109, 97, 115, 107, 93, 44,
  48, 32, 45, 114, 91, 45, 49, 93, 32, 50, 48, 48, 37, 44, 50, 48,
  48, 37, 44, 49, 44, 49, 44, 51, 32, 45, 114, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  99, 91, 45, 49, 93, 32, 51, 48, 37, 44, 49, 48, 48, 37, 10, 45,
  45, 114, 91, 109, 36, 62, 93, 32, 91, 45, 49, 93, 44, 91, 45, 49,
  93, 44, 49, 44, 51, 32, 45, 45, 114, 101, 112, 108, 97, 99, 101, 95,
  99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 49, 44,
  49, 44, 49, 44, 64, 123, 99, 111, 108, 111, 114, 115, 44, 123, 51, 42,
  36, 62, 125, 45, 123, 51, 42, 36, 62, 43, 50, 125, 125, 32, 45, 114,
  118, 91, 45, 51, 44, 45, 49, 93, 32, 45, 43, 91, 45, 51, 44, 45,
  49, 93, 32, 45, 99, 91, 45, 50, 93, 32, 48, 44, 50, 53, 53, 10,
  45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 32,
  45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 97, 91, 45, 50,
  44, 45, 49, 93, 32, 99, 32, 45, 110, 109, 91, 45, 49, 93, 32, 115,
  36, 62, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 99, 111, 108,
  111, 114, 115, 44, 109, 97, 115, 107, 93, 10, 102, 97, 99, 116, 61, 123,
  64, 123, 115, 48, 44, 119, 125, 47, 64, 123, 109, 48, 44, 119, 125, 125,
  10, 87, 61, 49, 50, 32, 72, 61, 50, 48, 10, 45, 105, 91, 98, 111,
  97, 114, 100, 93, 32, 36, 87, 44, 36, 72, 32, 45, 105, 91, 99, 117,
  114, 114, 95, 98, 111, 97, 114, 100, 93, 32, 91, 98, 111, 97, 114, 100,
  93, 10, 45, 105, 91, 114, 101, 110, 100, 101, 114, 93, 32, 123, 36, 102,
  97, 99, 116, 42, 36, 87, 125, 44, 123, 36, 102, 97, 99, 116, 42, 36,
  72, 125, 44, 49, 44, 51, 32, 45, 105, 91, 99, 117, 114, 114, 95, 114,
  101, 110, 100, 101, 114, 93, 32, 91, 114, 101, 110, 100, 101, 114, 93, 32,
  45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48,
  32, 45, 110, 109, 91, 45, 49, 93, 32, 99, 117, 114, 114, 95, 114, 101,
  110, 100, 101, 114, 95, 109, 97, 115, 107, 10, 45, 45, 114, 111, 119, 115,
  91, 114, 101, 110, 100, 101, 114, 93, 32, 48, 44, 53, 48, 37, 32, 45,
  112, 108, 97, 115, 109, 97, 91, 45, 49, 93, 32, 49, 44, 50, 32, 45,
  110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 50, 48, 32, 45, 98, 108,
  117, 114, 95, 121, 91, 45, 49, 93, 32, 52, 48, 37, 44, 49, 32, 45,
  45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 121, 32, 45, 97,
  91, 45, 50, 44, 45, 49, 93, 32, 121, 32, 45, 114, 91, 45, 49, 93,
  32, 91, 114, 101, 110, 100, 101, 114, 93, 10, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 54, 52, 32, 45, 98, 108, 117, 114, 95, 120, 91, 45, 49,
  93, 32, 49, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 110,
  111, 105, 115, 101, 91, 45, 49, 93, 32, 48, 46, 53, 44, 50, 32, 45,
  98, 91, 45, 49, 93, 32, 49, 32, 45, 42, 91, 45, 49, 93, 32, 51,
  48, 48, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 99, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 110, 109, 91, 45, 49,
  93, 32, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 10, 116, 105, 109,
  101, 61, 64, 124, 32, 115, 99, 111, 114, 101, 61, 48, 32, 102, 97, 108,
  108, 95, 109, 111, 100, 101, 61, 48, 32, 103, 97, 109, 101, 111, 118, 101,
  114, 61, 48, 32, 110, 61, 45, 49, 32, 110, 110, 61, 123, 114, 111, 117,
  110, 100, 40, 63, 40, 48, 44, 36, 78, 45, 49, 41, 41, 125, 10, 45,
  100, 111, 10, 45, 119, 97, 105, 116, 32, 123, 105, 102, 40, 36, 102, 97,
  108, 108, 95, 109, 111, 100, 101, 44, 45, 49, 44, 45, 50, 48, 41, 125,
  10, 45, 105, 102, 32, 36, 103, 97, 109, 101, 111, 118, 101, 114, 10, 45,
  45, 106, 91, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 93, 32, 91,
  99, 117, 114, 114, 95, 114, 101, 110, 100, 101, 114, 93, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 48, 46, 55, 44, 91, 99, 117, 114, 114, 95, 114,
  101, 110, 100, 101, 114, 95, 109, 97, 115, 107, 93, 44, 50, 53, 53, 10,
  45, 116, 101, 120, 116, 95, 111, 117, 116, 108, 105, 110, 101, 91, 45, 49,
  93, 32, 34, 71, 97, 109, 101, 92, 110, 79, 118, 101, 114, 33, 34, 44,
  51, 48, 44, 51, 48, 37, 44, 51, 50, 44, 50, 44, 49, 44, 50, 53,
  53, 32, 45, 119, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 99, 111, 110, 116, 105, 110, 117, 101, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 110, 60, 48, 125, 10, 45, 108, 91,
  98, 111, 97, 114, 100, 93, 32, 45, 115, 32, 121, 32, 105, 61, 45, 49,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 105, 102, 32,
  64, 123, 36, 60, 44, 109, 125, 32, 105, 61, 36, 60, 44, 36, 105, 32,
  45, 101, 110, 100, 105, 102, 32, 45, 100, 111, 110, 101, 10, 48, 32, 45,
  114, 109, 91, 36, 105, 93, 32, 45, 97, 32, 121, 32, 115, 99, 111, 114,
  101, 61, 123, 36, 115, 99, 111, 114, 101, 43, 50, 94, 40, 110, 97, 114,
  103, 40, 36, 105, 41, 45, 49, 41, 45, 49, 125, 32, 45, 114, 32, 36,
  87, 44, 36, 72, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 44, 49,
  32, 45, 110, 109, 32, 98, 111, 97, 114, 100, 32, 45, 101, 110, 100, 108,
  10, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40, 36, 105, 41, 62, 49,
  125, 32, 45, 108, 91, 114, 101, 110, 100, 101, 114, 93, 32, 45, 115, 32,
  121, 44, 36, 72, 32, 48, 32, 45, 114, 109, 91, 36, 105, 93, 32, 45,
  97, 32, 121, 32, 45, 114, 32, 123, 36, 102, 97, 99, 116, 42, 36, 87,
  125, 44, 123, 36, 102, 97, 99, 116, 42, 36, 72, 125, 44, 49, 44, 51,
  44, 48, 44, 48, 44, 48, 44, 49, 32, 45, 110, 109, 32, 114, 101, 110,
  100, 101, 114, 32, 45, 101, 110, 100, 108, 32, 45, 101, 110, 100, 105, 102,
  10, 110, 61, 36, 110, 110, 32, 110, 110, 61, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 48, 44, 36, 78, 45, 49, 41, 41, 125, 32, 120, 61, 123,
  36, 87, 47, 50, 125, 32, 121, 61, 48, 32, 100, 111, 95, 114, 101, 110,
  100, 101, 114, 61, 49, 32, 102, 97, 108, 108, 95, 109, 111, 100, 101, 61,
  48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 100, 111,
  95, 114, 101, 110, 100, 101, 114, 10, 45, 114, 109, 91, 99, 117, 114, 114,
  95, 98, 111, 97, 114, 100, 44, 99, 117, 114, 114, 95, 114, 101, 110, 100,
  101, 114, 44, 99, 117, 114, 114, 95, 114, 101, 110, 100, 101, 114, 95, 109,
  97, 115, 107, 93, 10, 45, 105, 91, 99, 117, 114, 114, 95, 98, 111, 97,
  114, 100, 93, 32, 91, 98, 111, 97, 114, 100, 93, 32, 45, 106, 91, 99,
  117, 114, 114, 95, 98, 111, 97, 114, 100, 93, 32, 91, 109, 36, 110, 93,
  44, 123, 36, 120, 45, 105, 110, 116, 40, 64, 123, 109, 36, 110, 44, 119,
  125, 47, 50, 41, 125, 44, 36, 121, 44, 48, 44, 48, 44, 49, 44, 91,
  109, 36, 110, 93, 10, 45, 105, 91, 99, 117, 114, 114, 95, 114, 101, 110,
  100, 101, 114, 93, 32, 91, 114, 101, 110, 100, 101, 114, 93, 32, 45, 115,
  104, 91, 115, 36, 110, 93, 32, 51, 44, 51, 32, 45, 106, 91, 99, 117,
  114, 114, 95, 114, 101, 110, 100, 101, 114, 93, 32, 91, 115, 36, 110, 93,
  44, 123, 36, 102, 97, 99, 116, 42, 40, 36, 120, 45, 105, 110, 116, 40,
  64, 123, 109, 36, 110, 44, 119, 125, 47, 50, 41, 41, 125, 44, 123, 36,
  102, 97, 99, 116, 42, 36, 121, 125, 44, 48, 44, 48, 44, 49, 44, 91,
  45, 49, 93, 44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 45, 42, 91, 99, 117, 114, 114, 95, 98, 111, 97, 114, 100, 93, 32,
  50, 53, 53, 32, 45, 114, 91, 45, 49, 93, 32, 91, 99, 117, 114, 114,
  95, 114, 101, 110, 100, 101, 114, 93, 44, 91, 99, 117, 114, 114, 95, 114,
  101, 110, 100, 101, 114, 93, 32, 45, 110, 109, 91, 45, 49, 93, 32, 99,
  117, 114, 114, 95, 114, 101, 110, 100, 101, 114, 95, 109, 97, 115, 107, 10,
  48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 83, 99, 111, 114, 101, 32,
  58, 32, 34, 36, 115, 99, 111, 114, 101, 34, 32, 32, 32, 32, 78, 101,
  120, 116, 32, 58, 34, 44, 52, 44, 48, 44, 51, 50, 44, 49, 44, 49,
  54, 52, 32, 45, 114, 91, 45, 49, 93, 32, 52, 48, 37, 44, 52, 48,
  37, 44, 49, 44, 51, 44, 50, 32, 45, 45, 110, 101, 113, 91, 45, 49,
  93, 32, 48, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 10, 45,
  106, 91, 99, 117, 114, 114, 95, 114, 101, 110, 100, 101, 114, 93, 32, 91,
  45, 50, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45,
  49, 93, 44, 50, 53, 53, 32, 45, 106, 91, 99, 117, 114, 114, 95, 114,
  101, 110, 100, 101, 114, 95, 109, 97, 115, 107, 93, 32, 91, 45, 49, 93,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 44,
  50, 53, 53, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45,
  45, 42, 91, 109, 36, 110, 110, 93, 32, 49, 57, 54, 32, 45, 114, 91,
  45, 49, 93, 32, 51, 48, 48, 37, 44, 51, 48, 48, 37, 44, 49, 44,
  51, 32, 45, 106, 91, 99, 117, 114, 114, 95, 114, 101, 110, 100, 101, 114,
  44, 99, 117, 114, 114, 95, 114, 101, 110, 100, 101, 114, 95, 109, 97, 115,
  107, 93, 32, 91, 45, 49, 93, 44, 123, 64, 123, 99, 117, 114, 114, 95,
  114, 101, 110, 100, 101, 114, 44, 119, 125, 45, 119, 45, 52, 125, 44, 51,
  44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 44, 49, 57, 54, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 100, 111, 95, 114, 101, 110, 100, 101,
  114, 61, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 45, 115, 104, 105,
  102, 116, 91, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 93, 32, 48,
  44, 123, 45, 49, 51, 42, 64, 124, 42, 49, 46, 48, 52, 94, 36, 115,
  99, 111, 114, 101, 125, 44, 48, 44, 48, 44, 50, 10, 45, 106, 91, 45,
  49, 93, 32, 91, 99, 117, 114, 114, 95, 114, 101, 110, 100, 101, 114, 93,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 99, 117, 114, 114,
  95, 114, 101, 110, 100, 101, 114, 95, 109, 97, 115, 107, 93, 44, 50, 53,
  53, 10, 45, 119, 91, 45, 49, 93, 32, 123, 50, 42, 119, 125, 44, 123,
  50, 42, 104, 125, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32,
  84, 101, 116, 114, 105, 115, 34, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 99, 117, 114, 115, 111, 114, 91, 48, 93, 32, 48, 10, 45, 105, 102,
  32, 64, 123, 33, 44, 83, 80, 65, 67, 69, 125, 32, 102, 97, 108, 108,
  95, 109, 111, 100, 101, 61, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 64, 123, 33, 44, 65, 82, 82, 79, 87, 85, 80, 125,
  34, 32, 124, 124, 32, 34, 64, 123, 33, 44, 65, 82, 82, 79, 87, 76,
  69, 70, 84, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 44, 65, 82,
  82, 79, 87, 82, 73, 71, 72, 84, 125, 125, 10, 97, 110, 61, 123, 105,
  102, 40, 64, 123, 33, 44, 65, 82, 82, 79, 87, 85, 80, 125, 44, 110,
  61, 36, 110, 43, 49, 59, 105, 102, 40, 110, 37, 52, 44, 110, 44, 110,
  45, 52, 41, 44, 36, 110, 41, 125, 10, 110, 120, 61, 123, 119, 50, 61,
  105, 110, 116, 40, 64, 123, 109, 36, 97, 110, 44, 119, 125, 47, 50, 41,
  59, 109, 97, 120, 40, 119, 50, 44, 109, 105, 110, 40, 36, 120, 45, 64,
  123, 33, 44, 65, 82, 82, 79, 87, 76, 69, 70, 84, 125, 43, 64, 123,
  33, 44, 65, 82, 82, 79, 87, 82, 73, 71, 72, 84, 125, 44, 36, 87,
  45, 40, 64, 123, 109, 36, 97, 110, 44, 119, 125, 37, 50, 41, 45, 119,
  50, 41, 41, 125, 10, 45, 45, 106, 91, 98, 111, 97, 114, 100, 93, 32,
  91, 109, 36, 97, 110, 93, 44, 123, 36, 110, 120, 45, 105, 110, 116, 40,
  64, 123, 109, 36, 97, 110, 44, 119, 125, 47, 50, 41, 125, 44, 36, 121,
  44, 48, 44, 48, 44, 45, 49, 44, 91, 109, 36, 97, 110, 93, 10, 45,
  105, 102, 32, 123, 64, 123, 45, 49, 44, 77, 125, 61, 61, 49, 125, 32,
  120, 61, 36, 110, 120, 32, 110, 61, 36, 97, 110, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 114, 109, 91, 45, 49, 93, 10, 100, 111, 95, 114, 101,
  110, 100, 101, 114, 61, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 64, 123, 33, 44, 65, 82, 82, 79, 87, 68, 79, 87, 78,
  125, 34, 32, 124, 124, 32, 34, 64, 124, 45, 36, 116, 105, 109, 101, 62,
  48, 46, 57, 94, 105, 110, 116, 40, 36, 115, 99, 111, 114, 101, 47, 50,
  41, 34, 32, 124, 124, 32, 34, 36, 102, 97, 108, 108, 95, 109, 111, 100,
  101, 125, 10, 121, 61, 123, 36, 121, 43, 49, 125, 10, 45, 45, 106, 91,
  98, 111, 97, 114, 100, 93, 32, 91, 109, 36, 110, 93, 44, 123, 36, 120,
  45, 105, 110, 116, 40, 64, 123, 109, 36, 110, 44, 119, 125, 47, 50, 41,
  125, 44, 36, 121, 44, 48, 44, 48, 44, 45, 49, 44, 91, 109, 36, 110,
  93, 10, 45, 105, 102, 32, 123, 64, 123, 45, 49, 44, 77, 125, 62, 49,
  34, 32, 124, 124, 32, 34, 36, 121, 43, 64, 123, 109, 36, 110, 44, 104,
  125, 62, 36, 72, 125, 10, 45, 105, 102, 32, 123, 36, 121, 60, 61, 49,
  125, 32, 103, 97, 109, 101, 111, 118, 101, 114, 61, 49, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 106, 91, 98, 111, 97, 114, 100, 93, 32, 91, 99,
  117, 114, 114, 95, 98, 111, 97, 114, 100, 93, 32, 45, 106, 91, 114, 101,
  110, 100, 101, 114, 93, 32, 91, 99, 117, 114, 114, 95, 114, 101, 110, 100,
  101, 114, 93, 32, 110, 61, 45, 49, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 114, 109, 91, 45, 49, 93, 10, 116, 105, 109, 101, 61, 64, 124, 32,
  100, 111, 95, 114, 101, 110, 100, 101, 114, 61, 49, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34, 32, 38,
  38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67, 125, 34, 32, 38, 38,
  32, 34, 33, 64, 123, 33, 44, 81, 125, 125, 10, 45, 114, 109, 32, 45,
  119, 32, 48, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  120, 95, 116, 105, 99, 116, 97, 99, 116, 111, 101, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 76, 97, 117, 110, 99, 104, 32, 116, 105, 99, 45,
  116, 97, 99, 45, 116, 111, 101, 32, 103, 97, 109, 101, 46, 10, 120, 95,
  116, 105, 99, 116, 97, 99, 116, 111, 101, 32, 58, 10, 45, 101, 91, 93,
  32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 84, 105, 99, 45,
  84, 97, 99, 45, 84, 111, 101, 32, 103, 97, 109, 101, 32, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110,
  10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32, 85, 115, 101,
  32, 109, 111, 117, 115, 101, 32, 116, 111, 32, 115, 101, 108, 101, 99, 116,
  32, 112, 111, 115, 105, 116, 105, 111, 110, 115, 32, 111, 102, 32, 116, 104,
  101, 92, 110, 10, 45, 45, 45, 45, 32, 115, 121, 109, 98, 111, 108, 115,
  46, 32, 67, 108, 111, 115, 101, 32, 119, 105, 110, 100, 111, 119, 32, 116,
  111, 32, 101, 120, 105, 116, 32, 103, 97, 109, 101, 46, 92, 110, 10, 45,
  45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 34,
  10, 45, 118, 32, 45, 10, 109, 101, 115, 115, 97, 103, 101, 61, 48, 10,
  99, 111, 117, 110, 116, 101, 114, 61, 48, 10, 112, 108, 97, 121, 101, 114,
  61, 48, 10, 115, 116, 97, 116, 101, 61, 48, 10, 116, 109, 112, 51, 61,
  48, 10, 116, 109, 112, 50, 61, 48, 10, 116, 109, 112, 49, 61, 48, 10,
  45, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116, 111, 101, 50, 10, 45,
  119, 91, 45, 49, 93, 32, 45, 49, 44, 45, 49, 44, 48, 44, 34, 32,
  34, 10, 45, 100, 111, 10, 45, 105, 102, 32, 36, 112, 108, 97, 121, 101,
  114, 32, 109, 101, 115, 115, 97, 103, 101, 61, 34, 84, 105, 99, 45, 84,
  97, 99, 45, 84, 111, 101, 32, 40, 79, 32, 116, 111, 32, 112, 108, 97,
  121, 41, 34, 10, 45, 101, 108, 115, 101, 32, 109, 101, 115, 115, 97, 103,
  101, 61, 34, 84, 105, 99, 45, 84, 97, 99, 45, 84, 111, 101, 32, 40,
  88, 32, 116, 111, 32, 112, 108, 97, 121, 41, 34, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 100, 111, 10, 45, 119, 91, 93, 32, 123, 119, 125, 44,
  123, 104, 125, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 34,
  36, 109, 101, 115, 115, 97, 103, 101, 32, 45, 119, 97, 105, 116, 10, 45,
  105, 102, 32, 123, 33, 64, 33, 125, 32, 45, 119, 91, 93, 32, 48, 32,
  45, 114, 109, 32, 45, 118, 32, 43, 32, 45, 114, 101, 116, 117, 114, 110,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64, 123, 33,
  44, 98, 125, 38, 49, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 120,
  125, 62, 50, 48, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 121, 125,
  62, 50, 48, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 120, 125, 60,
  52, 48, 48, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 121, 125, 60,
  52, 48, 48, 125, 10, 116, 109, 112, 51, 61, 123, 105, 110, 116, 40, 40,
  64, 123, 33, 44, 120, 125, 45, 49, 53, 41, 47, 49, 51, 48, 41, 125,
  10, 116, 109, 112, 50, 61, 123, 105, 110, 116, 40, 40, 64, 123, 33, 44,
  121, 125, 45, 49, 53, 41, 47, 49, 51, 48, 41, 125, 10, 116, 109, 112,
  49, 61, 123, 52, 94, 40, 36, 116, 109, 112, 50, 42, 51, 43, 36, 116,
  109, 112, 51, 41, 125, 10, 45, 105, 102, 32, 123, 105, 110, 116, 40, 36,
  115, 116, 97, 116, 101, 47, 36, 116, 109, 112, 49, 41, 37, 52, 125, 32,
  116, 109, 112, 49, 61, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 108, 115, 101, 32, 116, 109, 112, 49, 61, 45, 49, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123, 36, 116, 109, 112,
  49, 60, 48, 125, 10, 45, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116,
  111, 101, 123, 36, 112, 108, 97, 121, 101, 114, 37, 50, 125, 10, 45, 106,
  91, 45, 51, 93, 32, 91, 45, 50, 93, 44, 123, 34, 49, 51, 48, 42,
  34, 36, 116, 109, 112, 51, 34, 32, 43, 32, 49, 53, 43, 63, 40, 45,
  53, 44, 53, 41, 34, 125, 44, 92, 10, 123, 34, 49, 51, 48, 42, 34,
  36, 116, 109, 112, 50, 34, 32, 43, 32, 49, 53, 43, 63, 40, 45, 53,
  44, 53, 41, 34, 125, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93,
  10, 45, 114, 109, 91, 45, 50, 45, 45, 49, 93, 10, 45, 119, 91, 45,
  49, 93, 10, 115, 116, 97, 116, 101, 61, 123, 36, 115, 116, 97, 116, 101,
  43, 40, 49, 43, 36, 112, 108, 97, 121, 101, 114, 41, 42, 36, 116, 109,
  112, 49, 125, 10, 40, 50, 49, 44, 49, 51, 52, 52, 44, 56, 54, 48,
  49, 54, 44, 52, 49, 54, 49, 44, 49, 54, 54, 52, 52, 44, 54, 54,
  53, 55, 54, 44, 54, 53, 55, 57, 51, 44, 52, 51, 54, 56, 59, 92,
  10, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 50, 44, 48, 44, 48,
  59, 92, 10, 48, 44, 49, 44, 50, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 48, 59, 92, 10, 51, 44, 51, 44, 51, 44, 52, 44, 52, 44, 52,
  44, 53, 44, 54, 41, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 119,
  125, 10, 116, 109, 112, 49, 61, 64, 123, 45, 49, 44, 36, 62, 125, 10,
  45, 105, 102, 32, 123, 40, 36, 115, 116, 97, 116, 101, 38, 36, 116, 109,
  112, 49, 41, 61, 61, 36, 116, 109, 112, 49, 124, 124, 40, 36, 115, 116,
  97, 116, 101, 38, 40, 50, 42, 36, 116, 109, 112, 49, 41, 41, 61, 61,
  50, 42, 36, 116, 109, 112, 49, 125, 10, 45, 95, 120, 95, 116, 105, 99,
  116, 97, 99, 116, 111, 101, 64, 123, 45, 49, 44, 40, 36, 62, 44, 51,
  41, 125, 10, 45, 106, 91, 45, 52, 93, 32, 91, 45, 50, 93, 44, 123,
  49, 51, 48, 42, 64, 123, 45, 51, 44, 40, 36, 62, 44, 49, 41, 125,
  43, 63, 40, 45, 53, 44, 53, 41, 125, 44, 92, 10, 123, 49, 51, 48,
  42, 64, 123, 45, 51, 44, 40, 36, 62, 44, 50, 41, 125, 43, 63, 40,
  45, 53, 44, 53, 41, 125, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49,
  93, 32, 45, 114, 109, 91, 45, 50, 45, 45, 49, 93, 10, 45, 105, 102,
  32, 123, 40, 36, 115, 116, 97, 116, 101, 38, 36, 116, 109, 112, 49, 41,
  61, 61, 36, 116, 109, 112, 49, 125, 32, 45, 119, 91, 45, 50, 93, 32,
  45, 49, 44, 45, 49, 44, 48, 44, 34, 84, 105, 99, 45, 84, 97, 99,
  45, 84, 111, 101, 32, 40, 88, 32, 119, 111, 110, 33, 41, 34, 10, 45,
  101, 108, 115, 101, 32, 45, 119, 91, 45, 50, 93, 32, 45, 49, 44, 45,
  49, 44, 48, 44, 34, 84, 105, 99, 45, 84, 97, 99, 45, 84, 111, 101,
  32, 40, 79, 32, 119, 111, 110, 33, 41, 34, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 100, 111, 32, 45, 119, 97, 105, 116, 32, 45, 119, 91, 93,
  32, 64, 123, 33, 44, 119, 125, 44, 64, 123, 33, 44, 104, 125, 32, 45,
  119, 104, 105, 108, 101, 32, 64, 33, 10, 45, 114, 109, 32, 45, 119, 91,
  93, 32, 48, 32, 45, 118, 32, 43, 32, 45, 114, 101, 116, 117, 114, 110,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 114,
  109, 91, 45, 49, 93, 10, 112, 108, 97, 121, 101, 114, 61, 123, 40, 36,
  112, 108, 97, 121, 101, 114, 43, 49, 41, 37, 50, 125, 10, 99, 111, 117,
  110, 116, 101, 114, 61, 123, 36, 99, 111, 117, 110, 116, 101, 114, 43, 49,
  125, 10, 45, 119, 104, 105, 108, 101, 32, 123, 36, 99, 111, 117, 110, 116,
  101, 114, 60, 57, 125, 10, 45, 119, 91, 93, 32, 45, 49, 44, 45, 49,
  44, 48, 44, 48, 44, 34, 84, 105, 99, 45, 84, 97, 99, 45, 84, 111,
  101, 32, 40, 84, 105, 101, 100, 32, 103, 97, 109, 101, 33, 41, 34, 10,
  45, 100, 111, 32, 45, 119, 97, 105, 116, 32, 45, 119, 91, 93, 32, 64,
  123, 33, 44, 119, 125, 44, 64, 123, 33, 44, 104, 125, 32, 45, 119, 104,
  105, 108, 101, 32, 64, 33, 10, 45, 119, 91, 93, 32, 48, 32, 45, 114,
  109, 32, 45, 118, 32, 43, 10, 95, 120, 95, 116, 105, 99, 116, 97, 99,
  116, 111, 101, 32, 58, 10, 45, 115, 112, 114, 101, 97, 100, 91, 45, 49,
  93, 32, 52, 32, 45, 98, 91, 45, 49, 93, 32, 54, 32, 45, 115, 104,
  97, 114, 112, 101, 110, 91, 45, 49, 93, 32, 48, 46, 56, 32, 45, 110,
  91, 45, 49, 93, 32, 48, 44, 49, 10, 95, 95, 120, 95, 116, 105, 99,
  116, 97, 99, 116, 111, 101, 32, 58, 10, 45, 45, 102, 91, 45, 49, 93,
  32, 49, 45, 105, 32, 45, 45, 110, 91, 45, 50, 93, 32, 36, 50, 44,
  50, 53, 53, 32, 45, 45, 110, 91, 45, 51, 93, 32, 36, 51, 44, 50,
  53, 53, 32, 45, 110, 91, 45, 52, 93, 32, 36, 49, 44, 50, 53, 53,
  32, 45, 97, 91, 45, 52, 44, 45, 50, 44, 45, 49, 93, 32, 99, 10,
  95, 120, 95, 116, 105, 99, 116, 97, 99, 116, 111, 101, 48, 32, 58, 10,
  49, 50, 56, 44, 49, 50, 56, 44, 49, 44, 49, 44, 49, 32, 45, 108,
  105, 110, 101, 91, 45, 49, 93, 32, 49, 53, 37, 44, 49, 53, 37, 44,
  56, 53, 37, 44, 56, 53, 37, 44, 49, 44, 48, 32, 45, 108, 105, 110,
  101, 91, 45, 49, 93, 32, 49, 53, 37, 44, 56, 53, 37, 44, 56, 53,
  37, 44, 49, 53, 37, 44, 49, 44, 48, 32, 45, 101, 114, 111, 100, 101,
  91, 45, 49, 93, 32, 49, 50, 32, 45, 95, 120, 95, 116, 105, 99, 116,
  97, 99, 116, 111, 101, 32, 45, 100, 101, 102, 111, 114, 109, 91, 45, 49,
  93, 32, 52, 32, 45, 95, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116,
  111, 101, 32, 52, 48, 44, 52, 48, 44, 49, 54, 48, 10, 95, 120, 95,
  116, 105, 99, 116, 97, 99, 116, 111, 101, 49, 32, 58, 10, 49, 50, 56,
  44, 49, 50, 56, 44, 49, 44, 49, 44, 49, 32, 45, 101, 108, 108, 105,
  112, 115, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44,
  50, 50, 37, 44, 50, 50, 37, 44, 48, 44, 49, 44, 48, 32, 45, 101,
  108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53,
  48, 37, 44, 49, 53, 37, 44, 49, 53, 37, 44, 48, 44, 49, 44, 49,
  32, 45, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116, 111, 101, 32, 45,
  100, 101, 102, 111, 114, 109, 91, 45, 49, 93, 32, 52, 32, 45, 95, 95,
  120, 95, 116, 105, 99, 116, 97, 99, 116, 111, 101, 32, 49, 54, 48, 44,
  52, 48, 44, 49, 54, 48, 10, 95, 120, 95, 116, 105, 99, 116, 97, 99,
  116, 111, 101, 50, 32, 58, 10, 51, 57, 49, 44, 51, 57, 49, 44, 49,
  44, 49, 44, 34, 33, 40, 120, 37, 49, 51, 48, 41, 32, 124, 124, 32,
  33, 40, 121, 37, 49, 51, 48, 41, 34, 32, 45, 114, 91, 45, 49, 93,
  32, 52, 50, 49, 44, 52, 50, 49, 44, 49, 44, 49, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 100, 105, 108, 97, 116, 101,
  91, 45, 49, 93, 32, 51, 32, 45, 95, 120, 95, 116, 105, 99, 116, 97,
  99, 116, 111, 101, 32, 45, 102, 91, 45, 49, 93, 32, 49, 45, 105, 10,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 110, 111, 105, 115, 101,
  91, 45, 49, 93, 32, 49, 48, 32, 45, 98, 91, 45, 49, 93, 32, 56,
  44, 48, 32, 45, 115, 104, 97, 114, 112, 101, 110, 91, 45, 49, 93, 32,
  49, 46, 53, 32, 45, 110, 91, 45, 49, 93, 32, 50, 50, 48, 44, 50,
  53, 53, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 116, 111,
  95, 114, 103, 98, 91, 45, 49, 93, 10, 95, 120, 95, 116, 105, 99, 116,
  97, 99, 116, 111, 101, 51, 32, 58, 10, 52, 50, 49, 44, 49, 51, 48,
  44, 49, 44, 49, 44, 49, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93,
  32, 49, 48, 37, 44, 54, 48, 37, 44, 57, 48, 37, 44, 54, 48, 37,
  44, 49, 44, 48, 32, 45, 101, 114, 111, 100, 101, 91, 45, 49, 93, 32,
  54, 32, 45, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116, 111, 101, 32,
  45, 114, 111, 116, 97, 116, 101, 91, 45, 49, 93, 32, 123, 63, 40, 45,
  54, 44, 54, 41, 125, 44, 49, 44, 49, 44, 53, 48, 37, 44, 53, 48,
  37, 32, 45, 95, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116, 111, 101,
  32, 49, 56, 48, 44, 49, 48, 44, 49, 48, 10, 95, 120, 95, 116, 105,
  99, 116, 97, 99, 116, 111, 101, 52, 32, 58, 10, 45, 95, 120, 95, 116,
  105, 99, 116, 97, 99, 116, 111, 101, 51, 32, 45, 116, 114, 97, 110, 115,
  112, 111, 115, 101, 91, 45, 50, 45, 45, 49, 93, 10, 95, 120, 95, 116,
  105, 99, 116, 97, 99, 116, 111, 101, 53, 32, 58, 10, 52, 50, 49, 44,
  52, 50, 49, 44, 49, 44, 49, 44, 49, 32, 45, 108, 105, 110, 101, 91,
  45, 49, 93, 32, 49, 48, 37, 44, 49, 48, 37, 44, 57, 48, 37, 44,
  57, 48, 37, 44, 49, 44, 48, 32, 45, 101, 114, 111, 100, 101, 91, 45,
  49, 93, 32, 54, 32, 45, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116,
  111, 101, 32, 45, 95, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116, 111,
  101, 32, 49, 56, 48, 44, 49, 48, 44, 49, 48, 10, 95, 120, 95, 116,
  105, 99, 116, 97, 99, 116, 111, 101, 54, 32, 58, 10, 52, 50, 49, 44,
  52, 50, 49, 44, 49, 44, 49, 44, 49, 32, 45, 108, 105, 110, 101, 91,
  45, 49, 93, 32, 49, 48, 37, 44, 57, 48, 37, 44, 57, 48, 37, 44,
  49, 48, 37, 44, 49, 44, 48, 32, 45, 101, 114, 111, 100, 101, 91, 45,
  49, 93, 32, 54, 32, 45, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116,
  111, 101, 32, 45, 95, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116, 111,
  101, 32, 49, 56, 48, 44, 49, 48, 44, 49, 48, 10, 35, 64, 103, 109,
  105, 99, 32, 120, 95, 119, 97, 118, 101, 115, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 76, 97, 117, 110, 99, 104, 32, 116, 104, 101, 32, 105,
  109, 97, 103, 101, 32, 119, 97, 118, 101, 115, 32, 100, 101, 109, 111, 46,
  10, 120, 95, 119, 97, 118, 101, 115, 32, 58, 10, 45, 101, 91, 93, 32,
  34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 73, 109, 97, 103, 101,
  32, 119, 97, 118, 101, 115, 32, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110, 10,
  45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32, 76, 101, 102, 116,
  32, 109, 111, 117, 115, 101, 32, 98, 117, 116, 116, 111, 110, 32, 116, 111,
  32, 100, 114, 111, 112, 32, 98, 97, 108, 108, 115, 46, 92, 110, 10, 45,
  45, 45, 45, 32, 82, 105, 103, 104, 116, 32, 109, 111, 117, 115, 101, 32,
  98, 117, 116, 116, 111, 110, 32, 116, 111, 32, 114, 111, 116, 97, 116, 101,
  32, 118, 105, 101, 119, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101,
  121, 115, 32, 39, 67, 84, 82, 76, 43, 68, 39, 32, 116, 111, 32, 100,
  111, 117, 98, 108, 101, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122,
  101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39,
  67, 84, 82, 76, 43, 67, 39, 32, 116, 111, 32, 114, 101, 115, 101, 116,
  32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10,
  45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32,
  111, 114, 32, 39, 81, 39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92,
  110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 34, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 123, 33, 64,
  35, 125, 32, 45, 108, 91, 93, 10, 50, 48, 48, 44, 50, 48, 48, 32,
  120, 61, 123, 45, 49, 46, 48, 54, 45, 63, 42, 48, 46, 49, 125, 32,
  121, 61, 123, 45, 48, 46, 50, 54, 45, 63, 42, 48, 46, 49, 125, 10,
  45, 109, 97, 110, 100, 101, 108, 98, 114, 111, 116, 32, 36, 120, 44, 36,
  121, 44, 123, 36, 120, 43, 48, 46, 49, 125, 44, 123, 36, 121, 43, 48,
  46, 49, 125, 44, 50, 53, 54, 10, 49, 54, 44, 49, 44, 49, 44, 51,
  44, 63, 32, 45, 114, 91, 45, 49, 93, 32, 50, 53, 54, 44, 49, 44,
  49, 44, 51, 44, 51, 32, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93,
  32, 49, 10, 45, 109, 97, 112, 91, 48, 93, 32, 91, 45, 49, 93, 32,
  45, 114, 109, 91, 45, 49, 93, 32, 45, 114, 50, 100, 120, 32, 49, 48,
  48, 10, 45, 45, 109, 105, 114, 114, 111, 114, 32, 121, 32, 45, 45, 109,
  105, 114, 114, 111, 114, 32, 120, 32, 45, 43, 32, 45, 110, 32, 48, 44,
  50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 101, 108, 115, 101, 32,
  45, 107, 91, 48, 93, 32, 45, 114, 91, 48, 93, 32, 49, 48, 48, 44,
  49, 48, 48, 44, 49, 44, 51, 44, 50, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 91, 48, 93, 32, 40, 50, 48, 59, 56, 48, 59, 48, 94,
  50, 48, 59, 56, 48, 59, 48, 94, 50, 48, 59, 56, 48, 59, 48, 41,
  32, 45, 114, 91, 48, 93, 32, 52, 48, 48, 44, 51, 48, 48, 44, 49,
  44, 51, 44, 51, 32, 45, 119, 97, 116, 101, 114, 91, 48, 93, 32, 49,
  48, 48, 44, 50, 10, 45, 119, 91, 48, 93, 32, 64, 123, 48, 44, 119,
  125, 44, 64, 123, 48, 44, 104, 125, 44, 48, 44, 34, 91, 71, 39, 77,
  73, 67, 93, 32, 73, 109, 97, 103, 101, 32, 119, 97, 118, 101, 115, 34,
  10, 119, 61, 123, 119, 125, 32, 45, 101, 108, 101, 118, 97, 116, 105, 111,
  110, 51, 100, 91, 45, 49, 93, 32, 48, 32, 45, 114, 118, 51, 100, 91,
  45, 49, 93, 10, 45, 115, 104, 91, 45, 49, 93, 32, 56, 44, 123, 55,
  43, 51, 42, 105, 91, 54, 93, 125, 44, 48, 44, 48, 32, 45, 114, 91,
  45, 49, 93, 32, 51, 44, 123, 104, 47, 51, 125, 44, 49, 44, 49, 44,
  45, 49, 10, 40, 48, 44, 49, 44, 48, 59, 49, 44, 48, 44, 49, 59,
  48, 44, 49, 44, 48, 41, 32, 45, 47, 91, 45, 49, 93, 32, 50, 10,
  45, 98, 97, 108, 108, 91, 93, 32, 50, 48, 44, 50, 48, 48, 44, 50,
  53, 53, 44, 49, 50, 56, 44, 49, 44, 48, 46, 55, 44, 51, 46, 53,
  10, 48, 32, 36, 119, 44, 36, 119, 32, 91, 45, 49, 93, 10, 45, 108,
  51, 100, 32, 123, 36, 119, 47, 50, 125, 44, 45, 50, 48, 48, 44, 45,
  49, 48, 48, 48, 32, 45, 115, 108, 51, 100, 32, 48, 46, 52, 32, 45,
  115, 115, 51, 100, 32, 48, 46, 56, 32, 45, 102, 51, 100, 32, 53, 48,
  48, 32, 116, 105, 109, 101, 48, 61, 64, 124, 10, 45, 100, 111, 10, 45,
  45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 45, 49, 93, 32, 91, 51,
  93, 44, 49, 32, 45, 45, 91, 45, 49, 93, 32, 91, 45, 51, 93, 32,
  45, 114, 109, 91, 45, 51, 93, 32, 45, 98, 91, 45, 49, 93, 32, 48,
  46, 56, 32, 45, 45, 91, 45, 49, 93, 32, 123, 105, 97, 125, 10, 45,
  114, 91, 45, 49, 93, 32, 49, 44, 123, 36, 119, 42, 36, 119, 125, 44,
  49, 44, 49, 44, 45, 49, 32, 45, 106, 91, 50, 93, 32, 91, 45, 49,
  93, 44, 50, 44, 48, 32, 45, 114, 91, 45, 49, 93, 32, 36, 119, 44,
  36, 119, 44, 49, 44, 49, 44, 45, 49, 10, 91, 49, 93, 10, 45, 105,
  102, 32, 64, 123, 53, 44, 104, 125, 32, 45, 45, 108, 91, 53, 93, 32,
  45, 114, 111, 119, 115, 32, 48, 44, 50, 10, 110, 98, 61, 123, 119, 125,
  10, 45, 105, 91, 48, 93, 32, 40, 123, 39, 67, 73, 109, 103, 51, 100,
  39, 125, 41, 32, 45, 105, 91, 49, 93, 32, 40, 36, 110, 98, 44, 36,
  110, 98, 41, 32, 45, 116, 114, 97, 110, 115, 112, 111, 115, 101, 91, 50,
  93, 10, 40, 49, 44, 48, 59, 49, 44, 123, 36, 110, 98, 45, 49, 125,
  41, 32, 45, 114, 91, 45, 49, 93, 32, 50, 44, 36, 110, 98, 44, 49,
  44, 49, 44, 51, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 10,
  49, 44, 123, 52, 42, 36, 110, 98, 125, 44, 49, 44, 49, 44, 49, 32,
  45, 121, 32, 45, 97, 32, 121, 10, 45, 101, 110, 100, 108, 32, 91, 52,
  93, 32, 45, 115, 112, 114, 105, 116, 101, 115, 51, 100, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 43, 51, 100, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 45, 51, 100, 91, 45, 49, 93, 32,
  123, 36, 119, 47, 50, 125, 44, 123, 36, 119, 47, 50, 125, 32, 45, 42,
  51, 100, 91, 45, 49, 93, 32, 64, 123, 48, 44, 48, 46, 57, 42, 109,
  97, 120, 40, 119, 44, 104, 41, 47, 36, 119, 125, 10, 45, 114, 51, 100,
  91, 45, 49, 93, 32, 48, 44, 48, 44, 49, 44, 123, 105, 102, 40, 64,
  123, 33, 44, 98, 125, 38, 50, 44, 45, 64, 123, 33, 44, 120, 125, 42,
  51, 54, 48, 47, 64, 123, 33, 44, 119, 125, 44, 64, 124, 42, 51, 48,
  41, 125, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 49, 44, 48, 44,
  48, 44, 45, 49, 50, 48, 10, 45, 45, 111, 98, 106, 101, 99, 116, 51,
  100, 91, 48, 93, 32, 91, 45, 49, 93, 44, 53, 48, 37, 44, 54, 53,
  37, 44, 51, 48, 44, 49, 44, 51, 44, 48, 44, 48, 32, 45, 119, 91,
  45, 49, 93, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82,
  76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 68, 125, 125, 32,
  45, 119, 91, 93, 32, 123, 50, 42, 119, 125, 44, 123, 50, 42, 104, 125,
  32, 45, 101, 108, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76,
  76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 67, 125, 125, 32, 45,
  119, 91, 93, 32, 123, 119, 125, 44, 123, 104, 125, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 32, 45, 119,
  97, 105, 116, 32, 50, 48, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44,
  98, 125, 38, 49, 124, 124, 40, 64, 124, 45, 36, 116, 105, 109, 101, 48,
  41, 62, 49, 125, 32, 40, 123, 63, 42, 36, 119, 125, 59, 123, 63, 42,
  36, 119, 125, 59, 55, 48, 59, 48, 41, 32, 45, 97, 91, 53, 44, 45,
  49, 93, 32, 120, 32, 116, 105, 109, 101, 48, 61, 123, 64, 124, 45, 63,
  125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 64, 123, 53,
  44, 104, 125, 32, 45, 108, 91, 53, 44, 45, 49, 93, 10, 45, 115, 104,
  91, 48, 93, 32, 50, 44, 50, 44, 48, 44, 48, 32, 45, 115, 104, 91,
  48, 93, 32, 51, 44, 51, 44, 48, 44, 48, 32, 45, 45, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 32, 45, 43, 91, 45, 49, 93, 32, 48, 46,
  50, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 115, 91,
  48, 93, 32, 120, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35,
  45, 49, 125, 32, 99, 111, 111, 114, 100, 115, 61, 64, 123, 36, 60, 44,
  48, 45, 49, 125, 32, 45, 105, 102, 32, 123, 64, 123, 36, 60, 44, 50,
  125, 60, 105, 40, 36, 99, 111, 111, 114, 100, 115, 41, 125, 32, 45, 61,
  91, 45, 49, 93, 32, 123, 56, 48, 43, 64, 123, 45, 49, 44, 40, 36,
  99, 111, 111, 114, 100, 115, 41, 125, 125, 44, 36, 99, 111, 111, 114, 100,
  115, 32, 45, 114, 109, 91, 36, 60, 93, 32, 45, 101, 110, 100, 105, 102,
  32, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 64, 35, 61, 61,
  49, 125, 32, 45, 105, 91, 48, 93, 32, 48, 32, 45, 101, 108, 115, 101,
  32, 45, 97, 91, 48, 45, 45, 50, 93, 32, 120, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 108, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34,
  33, 64, 123, 33, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33,
  64, 123, 33, 44, 81, 125, 125, 10, 45, 114, 109, 32, 45, 119, 32, 48,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 120, 95, 119,
  104, 105, 114, 108, 32, 58, 32, 95, 111, 112, 97, 99, 105, 116, 121, 62,
  61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 76, 97, 117, 110,
  99, 104, 32, 116, 104, 101, 32, 102, 114, 97, 99, 116, 97, 108, 32, 119,
  104, 105, 114, 108, 115, 32, 100, 101, 109, 111, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108,
  117, 101, 115, 58, 32, 39, 111, 112, 97, 99, 105, 116, 121, 61, 48, 46,
  50, 39, 46, 10, 120, 95, 119, 104, 105, 114, 108, 32, 58, 32, 45, 99,
  104, 101, 99, 107, 32, 36, 123, 49, 61, 48, 46, 50, 125, 62, 61, 48,
  10, 45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45,
  32, 70, 114, 97, 99, 116, 97, 108, 32, 119, 104, 105, 114, 108, 115, 32,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45,
  45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32,
  39, 67, 84, 82, 76, 43, 68, 39, 32, 116, 111, 32, 100, 111, 117, 98,
  108, 101, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92,
  110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82,
  76, 43, 67, 39, 32, 116, 111, 32, 114, 101, 115, 101, 116, 32, 119, 105,
  110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45,
  45, 32, 75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32,
  39, 81, 39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45,
  45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 10, 53,
  44, 53, 44, 49, 44, 51, 32, 50, 53, 54, 44, 50, 53, 54, 44, 49,
  44, 51, 32, 91, 45, 49, 93, 32, 45, 119, 91, 45, 49, 93, 32, 51,
  56, 52, 44, 51, 56, 52, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67,
  93, 32, 70, 114, 97, 99, 116, 97, 108, 32, 119, 104, 105, 114, 108, 115,
  34, 10, 116, 97, 110, 103, 108, 101, 61, 48, 32, 116, 122, 111, 111, 109,
  61, 48, 32, 120, 99, 61, 123, 40, 119, 45, 64, 123, 45, 51, 44, 119,
  125, 41, 47, 50, 125, 32, 121, 99, 61, 123, 40, 104, 45, 64, 123, 45,
  51, 44, 104, 125, 41, 47, 50, 125, 10, 45, 100, 111, 10, 45, 114, 97,
  110, 100, 91, 45, 51, 93, 32, 48, 44, 50, 53, 53, 32, 45, 106, 91,
  45, 50, 93, 32, 91, 45, 51, 93, 44, 36, 120, 99, 44, 36, 121, 99,
  44, 48, 44, 48, 10, 45, 114, 111, 116, 97, 116, 101, 91, 45, 50, 93,
  32, 123, 56, 42, 115, 105, 110, 40, 36, 116, 97, 110, 103, 108, 101, 41,
  125, 44, 48, 44, 48, 44, 123, 119, 47, 50, 43, 63, 40, 45, 50, 44,
  50, 41, 125, 44, 123, 104, 47, 50, 125, 44, 123, 49, 46, 48, 51, 43,
  48, 46, 48, 50, 42, 115, 105, 110, 40, 36, 116, 122, 111, 111, 109, 41,
  125, 10, 116, 97, 110, 103, 108, 101, 61, 123, 36, 116, 97, 110, 103, 108,
  101, 43, 48, 46, 48, 48, 49, 125, 32, 116, 122, 111, 111, 109, 61, 123,
  36, 116, 122, 111, 111, 109, 43, 48, 46, 48, 50, 125, 10, 45, 106, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 36, 49, 32, 45, 119, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123,
  64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64,
  123, 33, 44, 68, 125, 125, 32, 45, 119, 91, 93, 32, 123, 51, 42, 119,
  125, 44, 123, 51, 42, 104, 125, 32, 45, 101, 108, 105, 102, 32, 123, 64,
  123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123,
  33, 44, 67, 125, 125, 32, 45, 119, 91, 93, 32, 123, 49, 46, 53, 42,
  119, 125, 44, 123, 49, 46, 53, 42, 104, 125, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 119, 97, 105, 116, 32, 50, 48, 10, 45, 119, 104, 105, 108,
  101, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44,
  69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81,
  125, 125, 10, 45, 114, 109, 91, 45, 51, 44, 45, 50, 93, 32, 45, 119,
  91, 93, 32, 48, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 58, 32, 80, 73, 78, 75, 45, 108, 105, 98, 114, 97, 114, 121,
  32, 111, 112, 101, 114, 97, 116, 111, 114, 115, 10, 95, 119, 114, 98, 121,
  116, 101, 112, 110, 107, 32, 58, 10, 45, 111, 117, 116, 112, 117, 116, 95,
  112, 105, 110, 107, 51, 100, 32, 36, 123, 49, 125, 46, 112, 110, 107, 10,
  95, 120, 112, 105, 110, 107, 32, 58, 10, 102, 105, 108, 101, 110, 97, 109,
  101, 61, 64, 123, 45, 102, 105, 108, 101, 95, 114, 97, 110, 100, 125, 10,
  112, 114, 101, 102, 105, 120, 61, 112, 105, 110, 107, 46, 10, 45, 105, 102,
  32, 123, 33, 64, 123, 45, 105, 115, 95, 119, 105, 110, 100, 111, 119, 115,
  125, 125, 10, 45, 120, 32, 34, 119, 104, 105, 99, 104, 32, 34, 36, 123,
  112, 114, 101, 102, 105, 120, 125, 36, 123, 49, 125, 34, 32, 62, 47, 100,
  101, 118, 47, 110, 117, 108, 108, 32, 50, 62, 38, 49, 34, 10, 45, 105,
  102, 32, 123, 64, 123, 125, 33, 61, 48, 125, 32, 112, 114, 101, 102, 105,
  120, 61, 34, 34, 32, 45, 120, 32, 34, 119, 104, 105, 99, 104, 32, 34,
  36, 49, 34, 32, 62, 47, 100, 101, 118, 47, 110, 117, 108, 108, 32, 50,
  62, 38, 49, 34, 10, 9, 32, 32, 45, 105, 102, 32, 123, 64, 123, 125,
  33, 61, 48, 125, 32, 45, 101, 114, 114, 111, 114, 32, 34, 101, 120, 101,
  99, 117, 116, 97, 98, 108, 101, 32, 40, 112, 105, 110, 107, 46, 41, 34,
  36, 49, 34, 32, 110, 111, 116, 32, 102, 111, 117, 110, 100, 32, 105, 110,
  32, 80, 65, 84, 72, 44, 32, 115, 116, 97, 116, 117, 115, 32, 61, 32,
  34, 64, 123, 125, 34, 33, 33, 32, 82, 101, 116, 117, 114, 110, 105, 110,
  103, 33, 33, 92, 110, 34, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45,
  101, 110, 100, 105, 102, 10, 9, 45, 101, 110, 100, 105, 102, 10, 45, 111,
  117, 116, 112, 117, 116, 95, 112, 105, 110, 107, 51, 100, 32, 36, 123, 102,
  105, 108, 101, 110, 97, 109, 101, 125, 46, 112, 110, 107, 32, 45, 120, 32,
  36, 123, 112, 114, 101, 102, 105, 120, 125, 36, 123, 49, 125, 34, 32, 34,
  36, 123, 102, 105, 108, 101, 110, 97, 109, 101, 125, 34, 46, 112, 110, 107,
  32, 36, 50, 32, 34, 36, 123, 102, 105, 108, 101, 110, 97, 109, 101, 125,
  34, 95, 111, 46, 112, 110, 107, 32, 62, 47, 100, 101, 118, 47, 110, 117,
  108, 108, 32, 50, 62, 38, 49, 34, 10, 45, 101, 108, 115, 101, 10, 45,
  111, 117, 116, 112, 117, 116, 95, 112, 105, 110, 107, 51, 100, 32, 36, 123,
  102, 105, 108, 101, 110, 97, 109, 101, 125, 46, 112, 110, 107, 32, 45, 120,
  32, 36, 49, 34, 32, 34, 36, 123, 102, 105, 108, 101, 110, 97, 109, 101,
  125, 34, 46, 112, 110, 107, 32, 36, 50, 32, 34, 36, 123, 102, 105, 108,
  101, 110, 97, 109, 101, 125, 34, 95, 111, 46, 112, 110, 107, 34, 10, 45,
  101, 110, 100, 105, 102, 10, 115, 116, 97, 116, 117, 115, 61, 64, 123, 125,
  10, 45, 102, 105, 108, 101, 95, 114, 109, 32, 36, 123, 102, 105, 108, 101,
  110, 97, 109, 101, 125, 46, 112, 110, 107, 10, 45, 105, 102, 32, 123, 36,
  115, 116, 97, 116, 117, 115, 33, 61, 48, 92, 32, 38, 38, 92, 32, 123,
  36, 49, 39, 33, 61, 39, 115, 101, 117, 105, 108, 97, 117, 116, 111, 125,
  32, 45, 101, 114, 114, 111, 114, 32, 34, 101, 120, 101, 99, 32, 83, 116,
  97, 116, 117, 115, 32, 105, 115, 32, 34, 36, 123, 115, 116, 97, 116, 117,
  115, 125, 34, 46, 34, 32, 45, 114, 101, 116, 117, 114, 110, 10, 45, 101,
  108, 105, 102, 32, 36, 123, 102, 105, 108, 101, 110, 97, 109, 101, 125, 95,
  111, 46, 112, 110, 107, 32, 45, 105, 32, 36, 123, 102, 105, 108, 101, 110,
  97, 109, 101, 125, 95, 111, 46, 112, 110, 107, 32, 45, 102, 105, 108, 101,
  95, 114, 109, 32, 36, 123, 102, 105, 108, 101, 110, 97, 109, 101, 125, 95,
  111, 46, 112, 110, 107, 32, 45, 107, 91, 45, 49, 93, 10, 45, 101, 108,
  115, 101, 32, 45, 101, 114, 114, 111, 114, 32, 34, 101, 120, 101, 99, 32,
  69, 114, 114, 111, 114, 33, 33, 34, 32, 45, 101, 110, 100, 105, 102, 10,
  95, 120, 112, 105, 110, 107, 115, 32, 58, 10, 115, 61, 64, 123, 45, 49,
  44, 115, 125, 32, 45, 105, 102, 32, 123, 36, 115, 62, 49, 125, 32, 45,
  115, 91, 45, 49, 93, 32, 99, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 64, 123, 62,
  44, 45, 49, 125, 93, 32, 32, 45, 95, 120, 112, 105, 110, 107, 32, 36,
  49, 44, 34, 36, 50, 34, 32, 45, 107, 91, 45, 49, 93, 32, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36,
  115, 62, 49, 125, 32, 45, 97, 91, 45, 36, 115, 45, 45, 49, 93, 32,
  99, 32, 45, 101, 110, 100, 105, 102, 10, 95, 120, 102, 114, 97, 109, 101,
  32, 58, 10, 45, 108, 105, 110, 101, 32, 48, 37, 44, 48, 37, 44, 49,
  48, 48, 37, 44, 48, 37, 32, 45, 108, 105, 110, 101, 32, 48, 37, 44,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45,
  108, 105, 110, 101, 32, 48, 37, 44, 48, 37, 44, 48, 37, 44, 49, 48,
  48, 37, 32, 45, 108, 105, 110, 101, 32, 49, 48, 48, 37, 44, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 10, 35, 64, 103, 109, 105,
  99, 32, 111, 117, 116, 112, 117, 116, 95, 112, 105, 110, 107, 51, 100, 32,
  58, 32, 102, 105, 108, 101, 110, 97, 109, 101, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 83, 97, 118, 101, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 32, 97, 115, 32, 80, 53, 45, 99,
  111, 100, 101, 100, 32, 80, 80, 77, 32, 102, 105, 108, 101, 115, 32, 40,
  80, 73, 78, 75, 32, 101, 120, 116, 101, 110, 115, 105, 111, 110, 32, 102,
  111, 114, 32, 51, 100, 32, 118, 111, 108, 117, 109, 101, 116, 114, 105, 99,
  32, 105, 109, 97, 103, 101, 115, 41, 46, 10, 111, 117, 116, 112, 117, 116,
  95, 112, 105, 110, 107, 51, 100, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 79, 117, 116, 112, 117, 116, 32, 105, 109, 97, 103, 101, 36,
  63, 32, 97, 115, 32, 102, 105, 108, 101, 32, 39, 36, 49, 39, 32, 40,
  105, 110, 32, 51, 100, 32, 112, 105, 110, 107, 32, 101, 120, 116, 101, 110,
  115, 105, 111, 110, 32, 111, 102, 32, 80, 53, 45, 99, 111, 100, 101, 100,
  32, 80, 80, 77, 32, 102, 111, 114, 109, 97, 116, 41, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 105, 102, 32, 123, 64, 35, 61, 61, 49, 125, 32,
  102, 105, 108, 101, 110, 97, 109, 101, 48, 61, 34, 36, 49, 34, 10, 45,
  101, 108, 115, 101, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  102, 105, 108, 101, 110, 97, 109, 101, 36, 62, 61, 64, 123, 45, 102, 105,
  108, 101, 110, 97, 109, 101, 92, 32, 34, 92, 34, 36, 49, 92, 34, 34,
  44, 36, 62, 125, 32, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 105, 102, 32, 123, 100, 61, 61, 49, 125, 32, 45,
  111, 91, 45, 49, 93, 32, 112, 112, 109, 58, 36, 123, 102, 105, 108, 101,
  110, 97, 109, 101, 36, 62, 125, 10, 45, 101, 108, 115, 101, 10, 40, 123,
  39, 80, 53, 92, 110, 123, 119, 125, 92, 32, 123, 104, 125, 92, 32, 123,
  100, 125, 92, 110, 50, 53, 53, 92, 110, 39, 125, 41, 10, 45, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 91, 45, 50, 93, 32, 48, 32, 45, 121,
  91, 45, 49, 93, 32, 120, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93,
  32, 120, 10, 45, 111, 91, 45, 49, 93, 32, 114, 97, 119, 58, 36, 123,
  102, 105, 108, 101, 110, 97, 109, 101, 36, 62, 125, 44, 117, 99, 104, 97,
  114, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 112, 105, 110, 107, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 80, 105, 110, 107, 32, 119, 114, 97, 112,
  112, 101, 114, 32, 110, 97, 109, 101, 44, 112, 49, 44, 32, 46, 46, 32,
  44, 112, 110, 32, 40, 114, 101, 113, 117, 105, 114, 101, 115, 32, 116, 104,
  101, 32, 80, 73, 78, 75, 32, 108, 105, 98, 114, 97, 114, 121, 32, 116,
  111, 32, 98, 101, 32, 105, 110, 115, 116, 97, 108, 108, 101, 100, 41, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 104, 116, 116, 112, 58,
  47, 47, 112, 105, 110, 107, 104, 113, 46, 99, 111, 109, 47, 41, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 112, 114, 101, 112, 97, 114, 101, 115,
  32, 105, 110, 112, 117, 116, 44, 32, 99, 97, 108, 108, 115, 32, 101, 120,
  116, 101, 114, 110, 97, 108, 32, 34, 110, 97, 109, 101, 32, 105, 110, 112,
  117, 116, 32, 112, 49, 32, 46, 46, 46, 32, 112, 110, 32, 111, 117, 116,
  112, 117, 116, 34, 32, 97, 110, 100, 32, 114, 101, 97, 100, 115, 32, 111,
  117, 116, 112, 117, 116, 32, 40, 47, 116, 109, 112, 41, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112,
  103, 32, 45, 45, 112, 105, 110, 107, 32, 97, 115, 102, 114, 44, 53, 32,
  45, 112, 105, 110, 107, 91, 48, 93, 32, 97, 115, 102, 44, 53, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 45, 98, 108, 117, 114, 32, 50, 32, 45, 112, 105,
  110, 107, 32, 109, 97, 120, 105, 109, 97, 44, 52, 10, 112, 105, 110, 107,
  32, 58, 32, 45, 118, 32, 45, 10, 45, 105, 102, 32, 123, 36, 35, 62,
  49, 125, 32, 40, 123, 34, 39, 36, 123, 50, 45, 45, 49, 125, 39, 34,
  125, 41, 32, 45, 114, 101, 112, 108, 97, 99, 101, 91, 45, 49, 93, 32,
  123, 39, 44, 39, 125, 44, 123, 34, 39, 32, 39, 34, 125, 32, 112, 61,
  64, 123, 45, 49, 44, 116, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 101, 108, 115, 101, 32, 112, 61, 34, 32, 34, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 118, 32, 43, 32, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 67, 97, 108, 108, 32, 112, 105, 110, 107, 32, 112, 97, 99, 107, 97,
  103, 101, 32, 119, 105, 116, 104, 32, 99, 109, 100, 58, 32, 92, 34, 36,
  49, 36, 63, 32, 34, 36, 112, 34, 36, 63, 92, 34, 46, 34, 32, 45,
  118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 64, 123, 62, 44, 45, 49, 125, 93, 32, 45, 95, 120, 112, 105,
  110, 107, 115, 32, 36, 49, 44, 36, 112, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 112, 105, 110, 107, 95, 103, 114, 97, 121, 115, 107, 101, 108, 32,
  58, 32, 95, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 61,
  123, 32, 52, 32, 124, 32, 56, 32, 124, 32, 54, 32, 124, 32, 50, 54,
  32, 125, 44, 32, 95, 108, 97, 109, 98, 100, 97, 61, 48, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 40, 104, 116, 116, 112, 58, 47, 47, 112,
  105, 110, 107, 104, 113, 46, 99, 111, 109, 47, 103, 114, 97, 121, 115, 107,
  101, 108, 95, 56, 99, 46, 104, 116, 109, 108, 41, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 71, 114, 97, 121, 115, 99, 97, 108, 101, 32, 104,
  111, 109, 111, 116, 111, 112, 105, 99, 32, 115, 107, 101, 108, 101, 116, 111,
  110, 32, 40, 114, 101, 113, 117, 105, 114, 101, 115, 32, 116, 104, 101, 32,
  80, 73, 78, 75, 32, 108, 105, 98, 114, 97, 114, 121, 32, 116, 111, 32,
  98, 101, 32, 105, 110, 115, 116, 97, 108, 108, 101, 100, 41, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32,
  118, 97, 108, 117, 101, 115, 58, 32, 39, 99, 111, 110, 110, 101, 99, 116,
  105, 118, 105, 116, 121, 61, 52, 39, 32, 97, 110, 100, 32, 39, 108, 97,
  109, 98, 100, 97, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45,
  112, 105, 110, 107, 95, 103, 114, 97, 121, 115, 107, 101, 108, 32, 44, 32,
  45, 45, 112, 105, 110, 107, 95, 103, 114, 97, 121, 115, 107, 101, 108, 91,
  48, 93, 32, 44, 49, 48, 32, 45, 45, 112, 105, 110, 107, 95, 103, 114,
  97, 121, 115, 107, 101, 108, 91, 48, 93, 32, 44, 49, 48, 48, 32, 45,
  97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 32, 50, 10, 112,
  105, 110, 107, 95, 103, 114, 97, 121, 115, 107, 101, 108, 32, 58, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 49, 61, 52, 125, 44, 36, 123, 50, 61,
  48, 125, 10, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 52,
  125, 61, 61, 52, 32, 124, 124, 32, 36, 49, 61, 61, 56, 32, 124, 124,
  32, 36, 49, 61, 61, 54, 32, 124, 124, 32, 36, 49, 61, 61, 50, 54,
  34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  64, 123, 62, 44, 45, 49, 125, 93, 32, 45, 95, 120, 112, 105, 110, 107,
  115, 32, 34, 103, 114, 97, 121, 115, 107, 101, 108, 34, 44, 34, 110, 117,
  108, 108, 32, 36, 49, 32, 36, 50, 34, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 35, 64, 103, 109, 105, 99, 32, 112, 105, 110,
  107, 95, 104, 101, 105, 103, 104, 116, 109, 97, 120, 105, 109, 97, 32, 58,
  32, 95, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 61, 123,
  32, 52, 32, 124, 32, 56, 32, 124, 32, 54, 32, 124, 32, 50, 54, 32,
  125, 44, 95, 104, 101, 105, 103, 104, 116, 61, 49, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 40, 104, 116, 116, 112, 58, 47, 47, 112, 105, 110,
  107, 104, 113, 46, 99, 111, 109, 47, 104, 101, 105, 103, 104, 116, 109, 97,
  120, 105, 109, 97, 95, 56, 99, 46, 104, 116, 109, 108, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 72, 101, 105, 103, 104, 116, 109, 97, 120,
  105, 109, 97, 32, 102, 105, 108, 116, 101, 114, 105, 110, 103, 32, 40, 114,
  101, 113, 117, 105, 114, 101, 115, 32, 116, 104, 101, 32, 80, 73, 78, 75,
  32, 108, 105, 98, 114, 97, 114, 121, 32, 116, 111, 32, 98, 101, 32, 105,
  110, 115, 116, 97, 108, 108, 101, 100, 41, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117,
  101, 115, 58, 32, 39, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116,
  121, 61, 52, 39, 32, 97, 110, 100, 32, 39, 104, 101, 105, 103, 104, 116,
  61, 49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32,
  105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 98, 108, 117, 114,
  32, 50, 32, 45, 45, 112, 105, 110, 107, 95, 104, 101, 105, 103, 104, 116,
  109, 105, 110, 105, 109, 97, 32, 44, 49, 53, 32, 45, 45, 112, 105, 110,
  107, 95, 104, 101, 105, 103, 104, 116, 109, 97, 120, 105, 109, 97, 91, 48,
  44, 49, 93, 32, 44, 49, 53, 32, 45, 45, 91, 45, 51, 44, 45, 49,
  93, 32, 45, 45, 91, 45, 51, 44, 45, 49, 93, 32, 45, 107, 101, 101,
  112, 91, 45, 49, 44, 45, 50, 93, 10, 112, 105, 110, 107, 95, 104, 101,
  105, 103, 104, 116, 109, 97, 120, 105, 109, 97, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 36, 123, 49, 61, 52, 125, 61, 61, 52, 32, 124,
  124, 32, 36, 49, 61, 61, 56, 32, 124, 124, 32, 36, 49, 61, 61, 54,
  32, 124, 124, 32, 36, 49, 61, 61, 50, 54, 34, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 50, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 70, 105, 108, 116, 101, 114, 32, 98, 121, 32, 104, 101, 105, 103,
  104, 116, 109, 97, 120, 105, 109, 97, 32, 101, 120, 101, 99, 32, 119, 105,
  116, 104, 32, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 32,
  36, 49, 32, 104, 101, 105, 103, 104, 116, 32, 36, 50, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 64, 123, 62, 44, 45, 49, 125, 93, 10, 115, 61, 64, 123, 45,
  49, 44, 115, 125, 32, 45, 105, 102, 32, 123, 36, 115, 62, 49, 125, 32,
  45, 115, 91, 45, 49, 93, 32, 99, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 64, 123,
  62, 44, 45, 49, 125, 93, 32, 45, 95, 120, 112, 105, 110, 107, 32, 34,
  104, 101, 105, 103, 104, 116, 109, 97, 120, 105, 109, 97, 34, 44, 34, 36,
  49, 32, 36, 50, 34, 32, 45, 107, 91, 45, 49, 93, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 115,
  62, 49, 125, 32, 45, 97, 91, 45, 36, 115, 45, 45, 49, 93, 32, 99,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  112, 105, 110, 107, 95, 104, 101, 105, 103, 104, 116, 109, 105, 110, 105, 109,
  97, 32, 58, 32, 95, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116,
  121, 61, 123, 32, 52, 32, 124, 32, 56, 32, 124, 32, 54, 32, 124, 32,
  50, 54, 32, 125, 44, 95, 104, 101, 105, 103, 104, 116, 61, 49, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 40, 104, 116, 116, 112, 58, 47, 47,
  112, 105, 110, 107, 104, 113, 46, 99, 111, 109, 47, 104, 101, 105, 103, 104,
  116, 109, 105, 110, 105, 109, 97, 95, 56, 99, 46, 104, 116, 109, 108, 41,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 72, 101, 105, 103, 104, 116,
  109, 105, 110, 105, 109, 97, 32, 102, 105, 108, 116, 101, 114, 105, 110, 103,
  32, 40, 114, 101, 113, 117, 105, 114, 101, 115, 32, 116, 104, 101, 32, 80,
  73, 78, 75, 32, 108, 105, 98, 114, 97, 114, 121, 32, 116, 111, 32, 98,
  101, 32, 105, 110, 115, 116, 97, 108, 108, 101, 100, 41, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 115, 58, 32, 39, 99, 111, 110, 110, 101, 99, 116, 105,
  118, 105, 116, 121, 61, 52, 39, 32, 97, 110, 100, 32, 39, 104, 101, 105,
  103, 104, 116, 61, 49, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 98,
  108, 117, 114, 32, 50, 32, 45, 45, 112, 105, 110, 107, 95, 104, 101, 105,
  103, 104, 116, 109, 105, 110, 105, 109, 97, 32, 44, 49, 53, 32, 45, 45,
  112, 105, 110, 107, 95, 104, 101, 105, 103, 104, 116, 109, 97, 120, 105, 109,
  97, 91, 48, 44, 49, 93, 32, 44, 49, 53, 32, 45, 45, 91, 45, 51,
  44, 45, 49, 93, 32, 45, 45, 91, 45, 51, 44, 45, 49, 93, 32, 45,
  107, 101, 101, 112, 91, 45, 49, 44, 45, 50, 93, 10, 112, 105, 110, 107,
  95, 104, 101, 105, 103, 104, 116, 109, 105, 110, 105, 109, 97, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 52, 125, 61, 61,
  52, 32, 124, 124, 32, 36, 49, 61, 61, 56, 32, 124, 124, 32, 36, 49,
  61, 61, 54, 32, 124, 124, 32, 36, 49, 61, 61, 50, 54, 34, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 50, 61, 49, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 102, 105, 108, 116, 101,
  114, 32, 98, 121, 32, 104, 101, 105, 103, 104, 116, 109, 105, 110, 105, 109,
  97, 32, 101, 120, 101, 99, 32, 119, 105, 116, 104, 32, 99, 111, 110, 110,
  101, 99, 116, 105, 118, 105, 116, 121, 32, 36, 49, 32, 104, 101, 105, 103,
  104, 116, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 64, 123, 62, 44, 45,
  49, 125, 93, 10, 115, 61, 64, 123, 45, 49, 44, 115, 125, 32, 45, 105,
  102, 32, 123, 36, 115, 62, 49, 125, 32, 45, 115, 91, 45, 49, 93, 32,
  99, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 64, 123, 62, 44, 45, 49, 125, 93, 32,
  45, 95, 120, 112, 105, 110, 107, 32, 34, 104, 101, 105, 103, 104, 116, 109,
  105, 110, 105, 109, 97, 34, 44, 34, 36, 49, 32, 36, 50, 34, 32, 45,
  107, 91, 45, 49, 93, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 45, 105, 102, 32, 123, 36, 115, 62, 49, 125, 32, 45, 97, 91,
  45, 36, 115, 45, 45, 49, 93, 32, 99, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 112, 105, 110, 107, 95, 104, 116,
  107, 101, 114, 110, 32, 58, 32, 95, 99, 111, 110, 110, 101, 99, 116, 105,
  118, 105, 116, 121, 61, 123, 32, 52, 32, 124, 32, 56, 32, 124, 32, 54,
  32, 124, 32, 50, 54, 32, 125, 44, 32, 95, 116, 121, 112, 101, 61, 123,
  34, 34, 124, 117, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40,
  104, 116, 116, 112, 58, 47, 47, 112, 105, 110, 107, 104, 113, 46, 99, 111,
  109, 47, 104, 116, 107, 101, 114, 110, 95, 56, 99, 46, 104, 116, 109, 108,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 104, 116, 116, 112,
  58, 47, 47, 112, 105, 110, 107, 104, 113, 46, 99, 111, 109, 47, 104, 116,
  107, 101, 114, 110, 117, 95, 56, 99, 46, 104, 116, 109, 108, 41, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 71, 114, 97, 121, 115, 99, 97, 108,
  101, 32, 117, 108, 116, 105, 109, 97, 116, 101, 32, 104, 111, 109, 111, 116,
  111, 112, 105, 99, 32, 116, 104, 105, 110, 110, 105, 110, 103, 47, 116, 104,
  105, 99, 107, 101, 110, 105, 110, 103, 32, 119, 105, 116, 104, 111, 117, 116,
  32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 32, 40, 114, 101, 113, 117,
  105, 114, 101, 115, 32, 116, 104, 101, 32, 80, 73, 78, 75, 32, 108, 105,
  98, 114, 97, 114, 121, 32, 116, 111, 32, 98, 101, 32, 105, 110, 115, 116,
  97, 108, 108, 101, 100, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58,
  32, 39, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 61, 52,
  39, 32, 97, 110, 100, 32, 39, 116, 121, 112, 101, 61, 34, 34, 39, 46,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103,
  101, 46, 106, 112, 103, 32, 45, 45, 112, 105, 110, 107, 95, 104, 116, 107,
  101, 114, 110, 32, 44, 117, 32, 45, 45, 112, 105, 110, 107, 95, 104, 116,
  107, 101, 114, 110, 91, 48, 93, 32, 44, 32, 45, 45, 45, 91, 45, 49,
  44, 45, 50, 93, 32, 45, 114, 101, 109, 111, 118, 101, 91, 48, 93, 10,
  112, 105, 110, 107, 95, 104, 116, 107, 101, 114, 110, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 49, 61, 52, 125, 44, 36, 123, 50, 61, 34,
  34, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 64, 123, 62, 44, 45, 49, 125, 93, 32, 45, 95, 120, 112, 105, 110,
  107, 115, 32, 104, 116, 107, 101, 114, 110, 36, 50, 44, 34, 110, 117, 108,
  108, 32, 36, 49, 34, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 35, 64, 103, 109, 105, 99, 32, 112, 105, 110, 107, 95, 108, 118,
  107, 101, 114, 110, 32, 58, 32, 95, 99, 111, 110, 110, 101, 99, 116, 105,
  118, 105, 116, 121, 61, 123, 32, 52, 32, 124, 32, 56, 32, 124, 32, 54,
  32, 124, 32, 50, 54, 32, 125, 44, 32, 95, 116, 121, 112, 101, 61, 123,
  34, 34, 124, 117, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40,
  104, 116, 116, 112, 58, 47, 47, 112, 105, 110, 107, 104, 113, 46, 99, 111,
  109, 47, 108, 118, 107, 101, 114, 110, 95, 56, 99, 46, 104, 116, 109, 108,
  41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 104, 116, 116, 112,
  58, 47, 47, 112, 105, 110, 107, 104, 113, 46, 99, 111, 109, 47, 108, 118,
  107, 101, 114, 110, 117, 95, 56, 99, 46, 104, 116, 109, 108, 41, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 71, 114, 97, 121, 115, 99, 97, 108,
  101, 32, 117, 108, 116, 105, 109, 97, 116, 101, 32, 108, 101, 118, 101, 108,
  105, 110, 103, 32, 116, 104, 105, 110, 110, 105, 110, 103, 47, 116, 104, 105,
  99, 107, 101, 110, 105, 110, 103, 32, 119, 105, 116, 104, 111, 117, 116, 32,
  99, 111, 110, 100, 105, 116, 105, 111, 110, 32, 40, 114, 101, 113, 117, 105,
  114, 101, 115, 32, 116, 104, 101, 32, 80, 73, 78, 75, 32, 108, 105, 98,
  114, 97, 114, 121, 32, 116, 111, 32, 98, 101, 32, 105, 110, 115, 116, 97,
  108, 108, 101, 100, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 61, 52, 39,
  32, 97, 110, 100, 32, 39, 116, 121, 112, 101, 61, 34, 34, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 112, 105, 110, 107, 95, 108, 118, 107, 101, 114,
  110, 32, 44, 117, 10, 112, 105, 110, 107, 95, 108, 118, 107, 101, 114, 110,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 52, 125, 44,
  36, 123, 50, 61, 34, 34, 125, 10, 45, 99, 104, 101, 99, 107, 32, 34,
  36, 123, 49, 61, 52, 125, 61, 61, 52, 32, 124, 124, 32, 36, 49, 61,
  61, 56, 32, 124, 124, 32, 36, 49, 61, 61, 54, 32, 124, 124, 32, 36,
  49, 61, 61, 50, 54, 34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 64, 123, 62, 44, 45, 49, 125, 93, 32, 45, 95,
  120, 112, 105, 110, 107, 115, 32, 108, 118, 107, 101, 114, 110, 36, 123, 50,
  125, 44, 34, 110, 117, 108, 108, 32, 36, 49, 34, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 109, 105, 99, 32, 112,
  105, 110, 107, 95, 114, 101, 103, 95, 109, 105, 110, 105, 109, 97, 32, 58,
  32, 95, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 61, 123,
  32, 52, 32, 124, 32, 56, 32, 124, 32, 54, 32, 124, 32, 50, 54, 32,
  125, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 104, 116, 116, 112,
  58, 47, 47, 112, 105, 110, 107, 104, 113, 46, 99, 111, 109, 47, 109, 105,
  110, 105, 109, 97, 95, 56, 99, 46, 104, 116, 109, 108, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 82, 101, 103, 105, 111, 110, 97, 108, 32,
  109, 105, 110, 105, 109, 97, 32, 40, 114, 101, 113, 117, 105, 114, 101, 115,
  32, 116, 104, 101, 32, 80, 73, 78, 75, 32, 108, 105, 98, 114, 97, 114,
  121, 32, 116, 111, 32, 98, 101, 32, 105, 110, 115, 116, 97, 108, 108, 101,
  100, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102,
  97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 99, 111,
  110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 61, 52, 39, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46,
  106, 112, 103, 32, 45, 45, 98, 108, 117, 114, 32, 50, 32, 45, 112, 105,
  110, 107, 95, 114, 101, 103, 95, 109, 105, 110, 105, 109, 97, 32, 44, 10,
  112, 105, 110, 107, 95, 114, 101, 103, 95, 109, 105, 110, 105, 109, 97, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 52, 125,
  61, 61, 52, 32, 124, 124, 32, 36, 49, 61, 61, 56, 32, 124, 124, 32,
  36, 49, 61, 61, 54, 32, 124, 124, 32, 36, 49, 61, 61, 50, 54, 34,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116,
  101, 32, 114, 101, 103, 105, 111, 110, 97, 108, 32, 109, 105, 110, 105, 109,
  97, 32, 101, 120, 101, 99, 32, 119, 105, 116, 104, 32, 99, 111, 110, 110,
  101, 99, 116, 105, 118, 105, 116, 121, 32, 36, 49, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 64, 123, 62, 44, 45, 49, 125, 93, 10, 115, 61, 64, 123, 45, 49,
  44, 115, 125, 32, 45, 105, 102, 32, 123, 36, 115, 62, 49, 125, 32, 45,
  115, 91, 45, 49, 93, 32, 99, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 64, 123, 62,
  44, 45, 49, 125, 93, 32, 32, 45, 95, 120, 112, 105, 110, 107, 32, 34,
  109, 105, 110, 105, 109, 97, 34, 44, 34, 36, 49, 34, 32, 45, 107, 91,
  45, 49, 93, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  45, 105, 102, 32, 123, 36, 115, 62, 49, 125, 32, 45, 97, 91, 45, 36,
  115, 45, 45, 49, 93, 32, 99, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 112, 105, 110, 107, 95, 115, 107, 101, 108,
  99, 117, 114, 118, 32, 58, 32, 95, 112, 114, 105, 111, 61, 123, 48, 124,
  49, 124, 50, 124, 51, 124, 52, 124, 56, 124, 54, 124, 50, 54, 125, 44,
  95, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 61, 123, 32,
  52, 32, 124, 32, 56, 32, 124, 32, 54, 32, 124, 32, 50, 54, 32, 125,
  44, 95, 105, 110, 104, 105, 98, 105, 116, 61, 123, 34, 34, 125, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 40, 104, 116, 116, 112, 58, 47, 47,
  112, 105, 110, 107, 104, 113, 46, 99, 111, 109, 47, 115, 107, 101, 108, 99,
  117, 114, 118, 95, 56, 99, 46, 104, 116, 109, 108, 41, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 67, 117, 114, 118, 105, 108, 105, 110, 101, 97,
  114, 32, 98, 105, 110, 97, 114, 121, 32, 115, 107, 101, 108, 101, 116, 111,
  110, 32, 103, 117, 105, 100, 101, 100, 32, 98, 121, 32, 97, 32, 112, 114,
  105, 111, 114, 105, 116, 121, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32,
  111, 114, 32, 105, 109, 97, 103, 101, 32, 40, 114, 101, 113, 117, 105, 114,
  101, 115, 32, 116, 104, 101, 32, 80, 73, 78, 75, 32, 108, 105, 98, 114,
  97, 114, 121, 32, 116, 111, 32, 98, 101, 32, 105, 110, 115, 116, 97, 108,
  108, 101, 100, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68,
  101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39,
  112, 114, 105, 111, 61, 48, 39, 44, 32, 39, 99, 111, 110, 110, 101, 99,
  116, 105, 118, 105, 116, 121, 61, 52, 39, 32, 97, 110, 100, 32, 39, 105,
  110, 104, 105, 98, 105, 116, 61, 34, 34, 39, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 53, 48, 37, 32,
  123, 119, 125, 44, 123, 104, 125, 32, 45, 102, 105, 108, 108, 91, 45, 49,
  93, 32, 39, 105, 102, 40, 120, 62, 119, 47, 50, 44, 50, 53, 53, 44,
  48, 41, 39, 32, 116, 112, 61, 64, 123, 45, 112, 97, 116, 104, 95, 116,
  109, 112, 125, 32, 45, 111, 117, 116, 112, 117, 116, 91, 45, 49, 93, 32,
  36, 123, 116, 112, 125, 47, 105, 110, 104, 105, 98, 105, 116, 46, 112, 103,
  109, 32, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 93, 32, 45, 45,
  112, 105, 110, 107, 95, 115, 107, 101, 108, 99, 117, 114, 118, 91, 48, 93,
  32, 44, 32, 45, 45, 112, 105, 110, 107, 95, 115, 107, 101, 108, 99, 117,
  114, 118, 91, 48, 93, 32, 44, 44, 36, 123, 116, 112, 125, 47, 105, 110,
  104, 105, 98, 105, 116, 46, 112, 103, 109, 32, 45, 101, 120, 101, 99, 32,
  34, 114, 109, 32, 34, 36, 123, 116, 112, 125, 34, 47, 105, 110, 104, 105,
  98, 105, 116, 46, 112, 103, 109, 34, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 32, 53, 48, 37, 32, 45, 45, 112,
  105, 110, 107, 95, 115, 107, 101, 108, 99, 117, 114, 118, 32, 44, 32, 45,
  45, 112, 105, 110, 107, 95, 115, 107, 101, 108, 99, 117, 114, 118, 91, 45,
  50, 93, 32, 44, 56, 10, 112, 105, 110, 107, 95, 115, 107, 101, 108, 99,
  117, 114, 118, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  48, 125, 44, 36, 123, 50, 61, 52, 125, 44, 36, 123, 51, 61, 34, 34,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 117, 114, 118, 105,
  108, 105, 110, 101, 97, 114, 32, 98, 105, 110, 97, 114, 121, 32, 115, 107,
  101, 108, 101, 116, 111, 110, 32, 103, 117, 105, 100, 101, 100, 32, 98, 121,
  32, 97, 32, 112, 114, 105, 111, 114, 105, 116, 121, 32, 102, 117, 110, 99,
  116, 105, 111, 110, 32, 111, 114, 32, 105, 109, 97, 103, 101, 32, 102, 114,
  111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 112, 114, 105, 111,
  61, 36, 49, 44, 32, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116,
  121, 61, 36, 50, 44, 32, 105, 110, 104, 105, 98, 105, 116, 61, 36, 51,
  46, 34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 64, 123, 62, 44, 45, 49, 125, 93, 32, 45, 95, 120, 112, 105, 110,
  107, 115, 32, 34, 115, 107, 101, 108, 99, 117, 114, 118, 34, 44, 34, 36,
  49, 32, 36, 50, 32, 36, 51, 34, 32, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 35, 64, 103, 109, 105, 99, 32, 112, 105, 110, 107,
  95, 115, 107, 101, 108, 101, 110, 100, 32, 58, 32, 95, 99, 111, 110, 110,
  101, 99, 116, 105, 118, 105, 116, 121, 61, 123, 32, 52, 32, 124, 32, 56,
  32, 124, 32, 54, 32, 124, 32, 50, 54, 32, 125, 44, 95, 110, 61, 48,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40, 104, 116, 116, 112, 58,
  47, 47, 112, 105, 110, 107, 104, 113, 46, 99, 111, 109, 47, 115, 107, 101,
  108, 101, 110, 100, 95, 56, 99, 46, 104, 116, 109, 108, 41, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 72, 111, 109, 111, 116, 111, 112, 105, 99,
  32, 115, 107, 101, 108, 101, 116, 111, 110, 32, 111, 102, 32, 97, 32, 50,
  100, 32, 111, 114, 32, 51, 100, 32, 98, 105, 110, 97, 114, 121, 32, 105,
  109, 97, 103, 101, 32, 119, 105, 116, 104, 32, 100, 121, 110, 97, 109, 105,
  99, 32, 100, 101, 116, 101, 99, 116, 105, 111, 110, 32, 111, 102, 32, 101,
  110, 100, 32, 112, 111, 105, 110, 116, 115, 32, 40, 114, 101, 113, 117, 105,
  114, 101, 115, 32, 116, 104, 101, 32, 80, 73, 78, 75, 32, 108, 105, 98,
  114, 97, 114, 121, 32, 116, 111, 32, 98, 101, 32, 105, 110, 115, 116, 97,
  108, 108, 101, 100, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32,
  39, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 61, 52, 39,
  32, 97, 110, 100, 32, 39, 110, 61, 48, 39, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 53, 48, 37, 32,
  45, 45, 112, 105, 110, 107, 95, 115, 107, 101, 108, 101, 110, 100, 32, 44,
  32, 45, 45, 112, 105, 110, 107, 95, 115, 107, 101, 108, 101, 110, 100, 91,
  45, 50, 93, 32, 44, 45, 49, 10, 112, 105, 110, 107, 95, 115, 107, 101,
  108, 101, 110, 100, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49,
  61, 52, 125, 44, 36, 123, 50, 61, 48, 125, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 64, 123, 62, 44, 45, 49, 125,
  93, 32, 45, 95, 120, 112, 105, 110, 107, 115, 32, 34, 115, 107, 101, 108,
  101, 110, 100, 34, 44, 34, 36, 49, 32, 36, 50, 34, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 109, 105, 99, 32,
  112, 105, 110, 107, 95, 115, 107, 101, 108, 101, 116, 111, 110, 32, 58, 32,
  95, 112, 114, 105, 111, 61, 123, 48, 124, 49, 124, 50, 124, 51, 124, 52,
  124, 56, 124, 54, 124, 50, 54, 125, 44, 95, 99, 111, 110, 110, 101, 99,
  116, 105, 118, 105, 116, 121, 61, 123, 32, 52, 32, 124, 32, 56, 32, 124,
  32, 54, 32, 124, 32, 50, 54, 32, 125, 44, 95, 105, 110, 104, 105, 98,
  105, 116, 61, 123, 34, 34, 125, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 40, 104, 116, 116, 112, 58, 47, 47, 112, 105, 110, 107, 104, 113, 46,
  99, 111, 109, 47, 115, 107, 101, 108, 101, 116, 111, 110, 95, 56, 99, 46,
  104, 116, 109, 108, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 85,
  108, 116, 105, 109, 97, 116, 101, 32, 98, 105, 110, 97, 114, 121, 32, 115,
  107, 101, 108, 101, 116, 111, 110, 32, 103, 117, 105, 100, 101, 100, 32, 98,
  121, 32, 97, 32, 112, 114, 105, 111, 114, 105, 116, 121, 32, 105, 109, 97,
  103, 101, 32, 40, 114, 101, 113, 117, 105, 114, 101, 115, 32, 116, 104, 101,
  32, 80, 73, 78, 75, 32, 108, 105, 98, 114, 97, 114, 121, 32, 116, 111,
  32, 98, 101, 32, 105, 110, 115, 116, 97, 108, 108, 101, 100, 41, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116,
  32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 112, 114, 105, 111, 61, 48,
  39, 44, 32, 39, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121,
  61, 52, 39, 32, 97, 110, 100, 32, 39, 105, 110, 104, 105, 98, 105, 116,
  61, 34, 34, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 36,
  32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 116, 104, 114, 101,
  115, 104, 111, 108, 100, 32, 53, 48, 37, 32, 45, 45, 112, 105, 110, 107,
  95, 115, 107, 101, 108, 101, 116, 111, 110, 91, 45, 49, 93, 32, 44, 10,
  112, 105, 110, 107, 95, 115, 107, 101, 108, 101, 116, 111, 110, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 125, 44, 36, 123, 50,
  61, 52, 125, 44, 36, 123, 51, 61, 34, 34, 125, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 64, 123, 62, 44, 45, 49,
  125, 93, 32, 45, 95, 120, 112, 105, 110, 107, 115, 32, 34, 115, 107, 101,
  108, 101, 116, 111, 110, 34, 44, 34, 36, 49, 32, 36, 50, 32, 36, 51,
  34, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64,
  103, 109, 105, 99, 32, 112, 105, 110, 107, 95, 115, 107, 101, 108, 112, 97,
  114, 32, 58, 32, 95, 97, 108, 103, 111, 114, 105, 116, 104, 109, 61, 123,
  48, 46, 46, 50, 57, 125, 44, 95, 110, 115, 116, 101, 112, 115, 61, 95,
  49, 44, 95, 105, 110, 104, 105, 98, 105, 116, 61, 34, 34, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 40, 104, 116, 116, 112, 58, 47, 47, 112,
  105, 110, 107, 104, 113, 46, 99, 111, 109, 47, 115, 107, 101, 108, 112, 97,
  114, 95, 56, 99, 46, 104, 116, 109, 108, 41, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 80, 97, 114, 97, 108, 108, 101, 108, 32, 98, 105, 110,
  97, 114, 121, 32, 115, 107, 101, 108, 101, 116, 111, 110, 32, 40, 114, 101,
  113, 117, 105, 114, 101, 115, 32, 116, 104, 101, 32, 80, 73, 78, 75, 32,
  108, 105, 98, 114, 97, 114, 121, 32, 116, 111, 32, 98, 101, 32, 105, 110,
  115, 116, 97, 108, 108, 101, 100, 41, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101,
  115, 58, 32, 39, 97, 108, 103, 111, 114, 105, 116, 104, 109, 61, 52, 39,
  44, 32, 39, 110, 115, 116, 101, 112, 115, 61, 45, 49, 39, 32, 97, 110,
  100, 32, 39, 105, 110, 104, 105, 98, 105, 116, 61, 34, 34, 39, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101,
  46, 106, 112, 103, 32, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32,
  53, 48, 37, 32, 45, 45, 112, 105, 110, 107, 95, 115, 107, 101, 108, 112,
  97, 114, 91, 45, 49, 93, 32, 48, 32, 45, 45, 112, 105, 110, 107, 95,
  115, 107, 101, 108, 112, 97, 114, 91, 45, 49, 93, 32, 50, 10, 112, 105,
  110, 107, 95, 115, 107, 101, 108, 112, 97, 114, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 49, 61, 52, 125, 44, 36, 123, 50, 61, 45, 49,
  125, 44, 36, 123, 51, 61, 34, 34, 125, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 64, 123, 62, 44, 45, 49, 125, 93,
  32, 45, 95, 120, 102, 114, 97, 109, 101, 32, 45, 95, 120, 112, 105, 110,
  107, 115, 32, 34, 115, 107, 101, 108, 112, 97, 114, 34, 44, 34, 36, 49,
  32, 36, 50, 32, 36, 51, 34, 32, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 35, 64, 103, 109, 105, 99, 32, 112, 105, 110, 107, 95,
  119, 115, 104, 101, 100, 32, 58, 32, 95, 99, 111, 110, 110, 101, 99, 116,
  105, 118, 105, 116, 121, 61, 123, 32, 52, 32, 124, 32, 56, 32, 124, 32,
  54, 32, 124, 32, 50, 54, 32, 125, 44, 95, 105, 110, 118, 101, 114, 115,
  101, 61, 123, 32, 48, 32, 124, 32, 49, 32, 125, 44, 95, 104, 101, 105,
  103, 104, 116, 61, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 40,
  104, 116, 116, 112, 58, 47, 47, 112, 105, 110, 107, 104, 113, 46, 99, 111,
  109, 47, 119, 115, 104, 101, 100, 116, 111, 112, 111, 95, 56, 99, 46, 104,
  116, 109, 108, 41, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 87, 97,
  116, 101, 114, 115, 104, 101, 100, 32, 40, 114, 101, 113, 117, 105, 114, 101,
  115, 32, 116, 104, 101, 32, 80, 73, 78, 75, 32, 108, 105, 98, 114, 97,
  114, 121, 32, 116, 111, 32, 98, 101, 32, 105, 110, 115, 116, 97, 108, 108,
  101, 100, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 101,
  102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58, 32, 39, 99,
  111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 61, 52, 39, 44, 32,
  39, 105, 110, 118, 101, 114, 115, 101, 61, 48, 39, 32, 97, 110, 100, 32,
  39, 104, 101, 105, 103, 104, 116, 61, 48, 39, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103,
  32, 45, 45, 112, 105, 110, 107, 95, 119, 115, 104, 101, 100, 32, 44, 49,
  44, 53, 32, 45, 112, 105, 110, 107, 95, 119, 115, 104, 101, 100, 91, 48,
  93, 32, 44, 44, 53, 10, 112, 105, 110, 107, 95, 119, 115, 104, 101, 100,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 52,
  125, 61, 61, 52, 32, 124, 124, 32, 36, 49, 61, 61, 56, 32, 124, 124,
  32, 36, 49, 61, 61, 54, 32, 124, 124, 32, 36, 49, 61, 61, 50, 54,
  34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 48, 125, 44, 36,
  123, 51, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67,
  111, 109, 112, 117, 116, 101, 32, 119, 115, 104, 101, 100, 116, 111, 112, 111,
  32, 101, 120, 101, 99, 32, 119, 105, 116, 104, 32, 99, 111, 110, 110, 101,
  99, 116, 105, 118, 105, 116, 121, 32, 36, 49, 32, 105, 110, 118, 101, 114,
  115, 105, 111, 110, 32, 36, 50, 32, 104, 101, 105, 103, 104, 116, 32, 36,
  51, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 64, 123, 62, 44, 45, 49, 125, 93, 10,
  115, 61, 64, 123, 45, 49, 44, 115, 125, 32, 45, 105, 102, 32, 123, 36,
  115, 62, 49, 125, 32, 45, 115, 91, 45, 49, 93, 32, 99, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 100, 61, 61, 49, 125, 10,
  45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 52, 125, 61, 61,
  52, 32, 124, 124, 32, 36, 49, 61, 61, 56, 34, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 64, 123, 62, 44, 45, 49,
  125, 93, 10, 45, 105, 102, 32, 123, 36, 50, 33, 61, 48, 125, 32, 45,
  110, 101, 103, 97, 116, 105, 118, 101, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 102, 32, 109, 97, 120, 40, 109, 105, 110, 40, 105, 44, 50, 53, 53,
  41, 44, 48, 41, 10, 45, 105, 102, 32, 123, 36, 51, 62, 61, 48, 125,
  32, 45, 112, 105, 110, 107, 32, 104, 101, 105, 103, 104, 116, 109, 105, 110,
  105, 109, 97, 44, 36, 49, 44, 36, 51, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 112, 105, 110, 107, 32, 119, 115, 104, 101, 100, 116, 111, 112, 111,
  44, 36, 49, 10, 45, 105, 102, 32, 123, 36, 50, 33, 61, 48, 125, 32,
  45, 110, 101, 103, 97, 116, 105, 118, 101, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108,
  115, 101, 10, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 61, 61, 54,
  32, 124, 124, 32, 36, 49, 61, 61, 50, 54, 34, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 64, 123, 62, 44, 45, 49,
  125, 93, 10, 45, 105, 102, 32, 123, 36, 50, 33, 61, 48, 125, 32, 45,
  110, 101, 103, 97, 116, 105, 118, 101, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 102, 32, 109, 97, 120, 40, 109, 105, 110, 40, 105, 44, 50, 53, 53,
  41, 44, 48, 41, 10, 45, 105, 102, 32, 123, 36, 51, 62, 61, 48, 125,
  10, 45, 112, 105, 110, 107, 32, 104, 101, 105, 103, 104, 116, 109, 105, 110,
  105, 109, 97, 44, 36, 49, 44, 36, 51, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 112, 105, 110, 107, 32, 119, 115, 104, 101, 100, 116, 111, 112, 111,
  44, 36, 49, 10, 45, 105, 102, 32, 123, 36, 50, 33, 61, 48, 125, 32,
  45, 110, 101, 103, 97, 116, 105, 118, 101, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 115, 62, 49, 125, 32, 45,
  97, 91, 45, 36, 115, 45, 45, 49, 93, 32, 99, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 58, 58, 32, 67, 111,
  110, 118, 101, 110, 105, 101, 110, 99, 101, 32, 102, 117, 110, 99, 116, 105,
  111, 110, 115, 10, 35, 64, 103, 109, 105, 99, 32, 97, 108, 101, 114, 116,
  32, 58, 32, 95, 116, 105, 116, 108, 101, 44, 95, 109, 101, 115, 115, 97,
  103, 101, 44, 95, 108, 97, 98, 101, 108, 95, 98, 117, 116, 116, 111, 110,
  49, 44, 95, 108, 97, 98, 101, 108, 95, 98, 117, 116, 116, 111, 110, 50,
  44, 46, 46, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 68, 105,
  115, 112, 108, 97, 121, 32, 97, 110, 32, 97, 108, 101, 114, 116, 32, 98,
  111, 120, 32, 97, 110, 100, 32, 119, 97, 105, 116, 32, 102, 111, 114, 32,
  117, 115, 101, 114, 39, 115, 32, 99, 104, 111, 105, 99, 101, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 73, 102, 32, 97, 32, 115, 105, 110,
  103, 108, 101, 32, 105, 109, 97, 103, 101, 32, 105, 115, 32, 105, 110, 32,
  116, 104, 101, 32, 115, 101, 108, 101, 99, 116, 105, 111, 110, 44, 32, 105,
  116, 32, 105, 115, 32, 117, 115, 101, 100, 32, 97, 115, 32, 97, 110, 32,
  105, 99, 111, 110, 32, 102, 111, 114, 32, 116, 104, 101, 32, 97, 108, 101,
  114, 116, 32, 98, 111, 120, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 58,
  32, 39, 116, 105, 116, 108, 101, 61, 91, 71, 39, 77, 73, 67, 32, 65,
  108, 101, 114, 116, 93, 39, 32, 97, 110, 100, 32, 39, 109, 101, 115, 115,
  97, 103, 101, 61, 84, 104, 105, 115, 32, 105, 115, 32, 97, 110, 32, 97,
  108, 101, 114, 116, 32, 98, 111, 120, 46, 39, 46, 10, 97, 108, 101, 114,
  116, 32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36, 123, 49, 61, 91,
  71, 39, 77, 73, 67, 32, 65, 108, 101, 114, 116, 93, 125, 44, 36, 123,
  50, 61, 84, 104, 105, 115, 32, 105, 115, 32, 97, 110, 32, 97, 108, 101,
  114, 116, 32, 98, 111, 120, 46, 125, 44, 36, 123, 51, 61, 79, 75, 125,
  34, 10, 45, 105, 102, 32, 123, 64, 35, 61, 61, 49, 125, 10, 45, 101,
  91, 48, 45, 45, 51, 93, 32, 34, 68, 105, 115, 112, 108, 97, 121, 32,
  97, 108, 101, 114, 116, 32, 98, 111, 120, 44, 32, 119, 105, 116, 104, 32,
  105, 109, 97, 103, 101, 36, 63, 44, 32, 116, 105, 116, 108, 101, 32, 39,
  36, 49, 39, 44, 32, 109, 101, 115, 115, 97, 103, 101, 32, 39, 36, 50,
  39, 32, 97, 110, 100, 32, 98, 117, 116, 116, 111, 110, 115, 32, 39, 36,
  123, 51, 45, 45, 49, 125, 39, 46, 34, 10, 45, 101, 108, 115, 101, 10,
  45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 68, 105, 115, 112, 108, 97,
  121, 32, 97, 108, 101, 114, 116, 32, 98, 111, 120, 44, 32, 119, 105, 116,
  104, 32, 116, 105, 116, 108, 101, 32, 39, 36, 49, 39, 44, 32, 109, 101,
  115, 115, 97, 103, 101, 32, 39, 36, 50, 39, 32, 97, 110, 100, 32, 98,
  117, 116, 116, 111, 110, 115, 32, 39, 36, 123, 51, 45, 45, 49, 125, 39,
  46, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 10, 45,
  105, 102, 32, 123, 64, 35, 61, 61, 49, 125, 32, 108, 111, 103, 111, 61,
  32, 45, 101, 108, 115, 101, 32, 108, 111, 103, 111, 61, 91, 93, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 45, 108, 36, 108, 111, 103, 111, 10, 45,
  105, 102, 32, 123, 64, 35, 61, 61, 49, 125, 32, 45, 116, 111, 95, 114,
  103, 98, 10, 45, 101, 108, 115, 101, 10, 54, 52, 44, 54, 52, 32, 45,
  112, 111, 108, 121, 103, 111, 110, 32, 51, 44, 53, 48, 37, 44, 49, 48,
  37, 44, 49, 48, 37, 44, 57, 48, 37, 44, 57, 48, 37, 44, 57, 48,
  37, 44, 49, 44, 49, 32, 45, 98, 32, 51, 32, 45, 103, 101, 32, 53,
  48, 37, 10, 45, 45, 101, 114, 111, 100, 101, 91, 45, 49, 93, 32, 53,
  32, 45, 45, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 61, 61,
  91, 45, 49, 93, 32, 48, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91,
  45, 49, 93, 32, 52, 44, 52, 55, 37, 44, 52, 51, 37, 44, 53, 51,
  37, 44, 52, 51, 37, 44, 53, 51, 37, 44, 54, 54, 37, 44, 52, 55,
  37, 44, 54, 54, 37, 44, 49, 44, 48, 32, 45, 99, 105, 114, 99, 108,
  101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 55, 54, 37, 44, 50, 44,
  49, 44, 48, 10, 45, 45, 42, 91, 48, 93, 32, 50, 53, 53, 32, 91,
  45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 97,
  91, 45, 51, 45, 45, 49, 93, 32, 99, 32, 45, 45, 91, 45, 49, 93,
  32, 39, 51, 42, 40, 121, 45, 104, 47, 50, 41, 39, 10, 45, 42, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 114, 109, 91, 45, 50, 93,
  32, 45, 42, 91, 48, 93, 32, 50, 53, 53, 32, 45, 114, 118, 32, 45,
  97, 32, 99, 10, 45, 100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119,
  32, 51, 44, 51, 44, 49, 32, 45, 105, 91, 48, 93, 32, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 49, 44, 51, 44, 50, 48, 48, 32, 45,
  98, 108, 101, 110, 100, 32, 97, 108, 112, 104, 97, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 45, 49, 44,
  50, 10, 36, 61, 97, 114, 103, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 36, 35, 45, 50, 125, 32, 108, 97, 98, 101, 108, 61, 36, 123, 97,
  114, 103, 123, 36, 62, 43, 51, 125, 125, 32, 48, 32, 45, 116, 101, 120,
  116, 91, 45, 49, 93, 32, 36, 108, 97, 98, 101, 108, 44, 48, 44, 48,
  44, 49, 52, 44, 49, 44, 45, 50, 48, 48, 32, 45, 100, 111, 110, 101,
  10, 45, 114, 91, 94, 48, 93, 32, 123, 109, 105, 110, 40, 49, 50, 56,
  44, 109, 97, 120, 40, 54, 52, 44, 64, 123, 45, 109, 97, 120, 95, 119,
  91, 94, 48, 93, 125, 43, 49, 50, 41, 41, 125, 44, 123, 109, 105, 110,
  40, 52, 56, 44, 109, 97, 120, 40, 50, 52, 44, 64, 123, 45, 109, 97,
  120, 95, 104, 91, 94, 48, 93, 125, 43, 49, 50, 41, 41, 125, 44, 49,
  44, 49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45,
  43, 91, 94, 48, 93, 32, 50, 48, 48, 32, 45, 116, 111, 95, 114, 103,
  98, 91, 94, 48, 93, 10, 45, 109, 118, 91, 48, 93, 32, 64, 35, 10,
  91, 48, 93, 44, 91, 48, 93, 44, 49, 44, 49, 44, 39, 40, 121, 45,
  104, 47, 50, 41, 39, 32, 45, 42, 91, 45, 49, 93, 32, 45, 50, 32,
  45, 99, 91, 45, 49, 93, 32, 45, 51, 48, 44, 51, 48, 32, 45, 43,
  91, 48, 45, 45, 51, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 99, 91, 94, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125,
  32, 45, 108, 91, 36, 60, 93, 10, 45, 45, 114, 101, 99, 116, 97, 110,
  103, 108, 101, 32, 48, 44, 48, 44, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48,
  10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32,
  49, 44, 49, 44, 123, 119, 45, 50, 125, 44, 123, 104, 45, 50, 125, 44,
  49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 10, 45,
  108, 105, 110, 101, 91, 45, 49, 93, 32, 50, 44, 123, 104, 45, 51, 125,
  44, 123, 119, 45, 51, 125, 44, 123, 104, 45, 51, 125, 44, 49, 44, 49,
  53, 48, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 123, 119, 45,
  51, 125, 44, 123, 104, 45, 51, 125, 44, 123, 119, 45, 51, 125, 44, 50,
  44, 49, 44, 49, 53, 48, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93,
  32, 49, 44, 49, 44, 123, 119, 45, 51, 125, 44, 49, 44, 49, 44, 50,
  53, 53, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 49, 44, 49,
  44, 49, 44, 123, 104, 45, 51, 125, 44, 49, 44, 50, 53, 53, 10, 45,
  114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 52, 44,
  52, 44, 123, 119, 45, 53, 125, 44, 123, 104, 45, 53, 125, 44, 49, 44,
  48, 120, 65, 65, 65, 65, 65, 65, 65, 65, 44, 48, 10, 45, 45, 115,
  104, 105, 102, 116, 91, 45, 50, 93, 32, 49, 44, 49, 44, 48, 44, 48,
  44, 50, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49,
  93, 32, 48, 44, 48, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 10, 45,
  114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 49, 44,
  49, 44, 123, 119, 45, 50, 125, 44, 123, 104, 45, 50, 125, 44, 49, 44,
  48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 49, 53, 48, 10, 45,
  114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 52, 44,
  52, 44, 123, 119, 45, 53, 125, 44, 123, 104, 45, 53, 125, 44, 49, 44,
  48, 120, 65, 65, 65, 65, 65, 65, 65, 65, 44, 48, 10, 45, 114, 101,
  99, 116, 97, 110, 103, 108, 101, 91, 45, 51, 93, 32, 48, 44, 48, 44,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 48, 120, 70, 70,
  70, 70, 70, 70, 70, 70, 44, 48, 10, 45, 108, 105, 110, 101, 91, 45,
  51, 93, 32, 49, 44, 123, 104, 45, 50, 125, 44, 123, 119, 45, 50, 125,
  44, 123, 104, 45, 50, 125, 44, 49, 44, 49, 53, 48, 32, 45, 108, 105,
  110, 101, 91, 45, 51, 93, 32, 123, 119, 45, 50, 125, 44, 123, 104, 45,
  50, 125, 44, 123, 119, 45, 50, 125, 44, 49, 44, 49, 44, 49, 53, 48,
  10, 45, 108, 105, 110, 101, 91, 45, 51, 93, 32, 48, 44, 48, 44, 123,
  119, 45, 50, 125, 44, 48, 44, 49, 44, 50, 53, 53, 32, 45, 108, 105,
  110, 101, 91, 45, 51, 93, 32, 48, 44, 48, 44, 48, 44, 123, 104, 45,
  50, 125, 44, 49, 44, 50, 53, 53, 10, 45, 105, 91, 48, 93, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 61, 91, 48, 93, 32, 49,
  44, 48, 44, 48, 10, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 45, 45, 108, 10, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 48, 44, 51, 32, 45, 115, 104, 32, 49, 44, 49, 48,
  48, 37, 32, 45, 45, 91, 53, 48, 37, 45, 45, 49, 93, 32, 50, 48,
  48, 32, 45, 114, 109, 91, 53, 48, 37, 45, 45, 49, 93, 32, 45, 102,
  114, 97, 109, 101, 32, 56, 44, 56, 44, 48, 10, 45, 105, 102, 32, 123,
  64, 35, 60, 54, 125, 32, 45, 97, 91, 94, 45, 49, 93, 32, 120, 32,
  45, 101, 108, 115, 101, 32, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105,
  108, 101, 115, 91, 94, 45, 49, 93, 32, 44, 32, 45, 101, 110, 100, 105,
  102, 10, 48, 32, 45, 116, 101, 120, 116, 91, 45, 49, 93, 32, 34, 36,
  50, 34, 44, 48, 44, 48, 44, 49, 52, 44, 49, 44, 48, 44, 45, 50,
  48, 48, 44, 45, 50, 48, 48, 44, 45, 50, 48, 48, 32, 45, 114, 91,
  45, 49, 93, 32, 123, 119, 43, 49, 54, 125, 44, 123, 104, 43, 56, 125,
  44, 49, 44, 52, 44, 48, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93,
  32, 120, 44, 48, 46, 53, 32, 45, 114, 118, 32, 45, 97, 32, 121, 44,
  48, 46, 53, 10, 45, 115, 104, 32, 49, 44, 49, 48, 48, 37, 32, 45,
  43, 91, 45, 49, 93, 32, 50, 48, 48, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 32, 48, 44, 48,
  44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 48, 120, 70,
  70, 70, 70, 70, 70, 70, 70, 44, 48, 10, 45, 108, 105, 110, 101, 32,
  48, 44, 48, 44, 123, 119, 45, 50, 125, 44, 48, 44, 49, 44, 48, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 108, 105, 110,
  101, 32, 48, 44, 48, 44, 48, 44, 123, 104, 45, 50, 125, 44, 49, 44,
  48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 101,
  110, 100, 108, 10, 45, 114, 109, 91, 45, 50, 93, 10, 45, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 10, 40, 48, 44,
  123, 119, 45, 49, 125, 41, 32, 40, 48, 59, 64, 123, 45, 50, 44, 104,
  45, 49, 125, 41, 32, 45, 114, 91, 45, 50, 44, 45, 49, 93, 32, 91,
  45, 51, 93, 44, 51, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32,
  99, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 45, 114, 118,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 42, 91, 45, 50, 44, 45, 49,
  93, 10, 45, 100, 105, 115, 99, 97, 114, 100, 91, 45, 49, 93, 32, 48,
  32, 45, 114, 91, 45, 49, 93, 32, 123, 104, 47, 50, 125, 44, 50, 44,
  49, 44, 49, 44, 45, 49, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115,
  91, 45, 50, 93, 32, 49, 44, 51, 32, 45, 114, 118, 91, 45, 50, 44,
  45, 49, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 123, 45, 51, 44, 119, 125, 32, 120, 48,
  61, 64, 123, 45, 51, 44, 40, 36, 62, 44, 48, 41, 125, 32, 121, 48,
  61, 64, 123, 45, 51, 44, 40, 36, 62, 44, 49, 41, 125, 32, 45, 114,
  101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 36, 120, 48,
  44, 36, 121, 48, 44, 123, 36, 120, 48, 43, 64, 123, 48, 44, 119, 125,
  45, 49, 125, 44, 123, 36, 121, 48, 43, 64, 123, 48, 44, 104, 125, 45,
  49, 125, 44, 49, 44, 123, 49, 43, 36, 62, 125, 32, 45, 100, 111, 110,
  101, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 57, 32, 45, 105, 102, 32, 123, 33, 64, 123,
  33, 36, 62, 125, 125, 32, 100, 105, 115, 112, 61, 36, 62, 32, 45, 98,
  114, 101, 97, 107, 32, 45, 101, 110, 100, 105, 102, 32, 45, 100, 111, 110,
  101, 10, 45, 105, 102, 32, 123, 33, 110, 97, 114, 103, 40, 36, 100, 105,
  115, 112, 41, 125, 32, 45, 101, 114, 114, 111, 114, 91, 48, 45, 45, 52,
  93, 32, 34, 67, 97, 110, 110, 111, 116, 32, 111, 112, 101, 110, 32, 100,
  105, 115, 112, 108, 97, 121, 32, 119, 105, 110, 100, 111, 119, 32, 102, 111,
  114, 32, 97, 108, 101, 114, 116, 32, 98, 111, 120, 46, 34, 32, 45, 101,
  110, 100, 105, 102, 10, 115, 101, 108, 101, 99, 116, 101, 100, 61, 123, 105,
  102, 40, 36, 35, 61, 61, 51, 44, 48, 44, 45, 49, 41, 125, 32, 99,
  108, 105, 99, 107, 101, 100, 61, 45, 49, 10, 45, 100, 111, 10, 45, 45,
  99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 44, 50,
  10, 45, 105, 102, 32, 123, 36, 99, 108, 105, 99, 107, 101, 100, 62, 61,
  48, 125, 10, 120, 48, 61, 64, 123, 45, 51, 44, 40, 36, 99, 108, 105,
  99, 107, 101, 100, 44, 48, 41, 125, 32, 121, 48, 61, 64, 123, 45, 51,
  44, 40, 36, 99, 108, 105, 99, 107, 101, 100, 44, 49, 41, 125, 10, 45,
  115, 104, 91, 36, 99, 108, 105, 99, 107, 101, 100, 93, 32, 55, 44, 57,
  10, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 120, 48,
  44, 36, 121, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 115, 101, 108, 101, 99, 116, 101, 100, 62, 61, 48,
  125, 10, 120, 48, 61, 64, 123, 45, 51, 44, 40, 36, 115, 101, 108, 101,
  99, 116, 101, 100, 44, 48, 41, 125, 32, 121, 48, 61, 64, 123, 45, 51,
  44, 40, 36, 115, 101, 108, 101, 99, 116, 101, 100, 44, 49, 41, 125, 10,
  45, 115, 104, 91, 36, 115, 101, 108, 101, 99, 116, 101, 100, 93, 32, 52,
  44, 54, 10, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36,
  120, 48, 44, 36, 121, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 119, 36, 100, 105, 115, 112, 91, 45, 49,
  93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48, 44, 34, 36,
  49, 34, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 119, 97, 105, 116,
  10, 120, 109, 61, 64, 123, 33, 36, 100, 105, 115, 112, 44, 120, 125, 32,
  121, 109, 61, 64, 123, 33, 36, 100, 105, 115, 112, 44, 121, 125, 32, 98,
  109, 61, 123, 64, 123, 33, 36, 100, 105, 115, 112, 44, 98, 125, 38, 49,
  125, 32, 118, 97, 108, 61, 123, 105, 40, 36, 120, 109, 44, 36, 121, 109,
  44, 48, 44, 51, 41, 125, 10, 45, 105, 102, 32, 123, 36, 98, 109, 34,
  32, 38, 38, 32, 34, 36, 118, 97, 108, 125, 32, 99, 108, 105, 99, 107,
  101, 100, 61, 123, 36, 118, 97, 108, 45, 49, 125, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 98, 109, 34, 32, 38, 38, 32, 34, 33, 36, 118, 97,
  108, 34, 32, 38, 38, 32, 34, 36, 99, 108, 105, 99, 107, 101, 100, 62,
  61, 48, 125, 32, 115, 101, 108, 101, 99, 116, 101, 100, 61, 36, 99, 108,
  105, 99, 107, 101, 100, 32, 99, 108, 105, 99, 107, 101, 100, 61, 45, 49,
  10, 45, 101, 108, 105, 102, 32, 123, 33, 36, 98, 109, 34, 32, 38, 38,
  32, 34, 36, 99, 108, 105, 99, 107, 101, 100, 62, 61, 48, 34, 32, 38,
  38, 32, 34, 36, 99, 108, 105, 99, 107, 101, 100, 61, 61, 36, 118, 97,
  108, 45, 49, 125, 32, 45, 98, 114, 101, 97, 107, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 64, 123, 33, 36, 100, 105, 115, 112, 44,
  65, 82, 82, 79, 87, 82, 73, 71, 72, 84, 125, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 61, 123, 40, 36, 115, 101, 108, 101, 99, 116, 101, 100,
  43, 49, 41, 37, 64, 123, 45, 50, 44, 119, 125, 125, 32, 45, 119, 97,
  105, 116, 32, 45, 49, 10, 45, 101, 108, 105, 102, 32, 64, 123, 33, 36,
  100, 105, 115, 112, 44, 65, 82, 82, 79, 87, 76, 69, 70, 84, 125, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 61, 123, 40, 36, 115, 101, 108, 101,
  99, 116, 101, 100, 45, 49, 41, 37, 64, 123, 45, 50, 44, 119, 125, 43,
  40, 36, 115, 101, 108, 101, 99, 116, 101, 100, 61, 61, 45, 49, 41, 125,
  32, 45, 119, 97, 105, 116, 32, 45, 49, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 115, 101, 108, 101, 99, 116, 101, 100, 62, 61, 48, 34, 32, 38,
  38, 32, 34, 64, 123, 33, 36, 100, 105, 115, 112, 44, 69, 78, 84, 69,
  82, 125, 125, 32, 99, 108, 105, 99, 107, 101, 100, 61, 36, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 45, 98, 114, 101, 97, 107, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 123, 33, 36,
  100, 105, 115, 112, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 36,
  100, 105, 115, 112, 44, 69, 83, 67, 125, 125, 10, 45, 119, 36, 100, 105,
  115, 112, 32, 48, 32, 45, 114, 109, 32, 45, 117, 32, 36, 99, 108, 105,
  99, 107, 101, 100, 10, 45, 101, 110, 100, 108, 10, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 97, 114, 103, 32, 58, 32, 110, 44, 95,
  97, 114, 103, 49, 44, 46, 46, 46, 44, 95, 97, 114, 103, 78, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116, 117, 114, 110, 32, 116,
  104, 101, 32, 110, 45, 116, 104, 32, 97, 114, 103, 117, 109, 101, 110, 116,
  32, 111, 102, 32, 116, 104, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101,
  100, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 108, 105, 115, 116, 46,
  10, 97, 114, 103, 32, 58, 10, 45, 118, 32, 45, 32, 36, 61, 97, 114,
  103, 32, 45, 117, 32, 36, 123, 97, 114, 103, 123, 49, 43, 40, 36, 49,
  41, 125, 125, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  97, 116, 32, 58, 32, 95, 120, 44, 95, 121, 44, 95, 122, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 82, 101, 116, 117, 114, 110, 32, 97, 32,
  115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 118, 101, 99, 116, 111, 114,
  45, 118, 97, 108, 117, 101, 100, 32, 112, 111, 105, 110, 116, 32, 40, 120,
  44, 121, 44, 122, 41, 32, 102, 114, 111, 109, 32, 116, 104, 101, 32, 108,
  97, 116, 101, 115, 116, 32, 111, 102, 32, 116, 104, 101, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 97, 116,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 125, 44,
  36, 123, 50, 61, 48, 125, 44, 36, 123, 51, 61, 48, 125, 10, 45, 118,
  32, 45, 32, 45, 45, 122, 91, 45, 49, 93, 32, 36, 123, 49, 45, 51,
  125, 44, 36, 123, 49, 45, 51, 125, 32, 45, 117, 32, 64, 45, 49, 32,
  45, 114, 109, 91, 45, 49, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 97, 117, 116, 111, 99, 114, 111, 112, 95, 99, 111, 111,
  114, 100, 115, 32, 58, 32, 118, 97, 108, 117, 101, 49, 44, 118, 97, 108,
  117, 101, 50, 44, 46, 46, 46, 32, 124, 32, 97, 117, 116, 111, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116, 117, 114, 110, 32, 99,
  111, 111, 114, 100, 105, 110, 97, 116, 101, 115, 32, 40, 120, 48, 44, 121,
  48, 44, 122, 48, 44, 120, 49, 44, 121, 49, 44, 122, 49, 41, 32, 111,
  102, 32, 116, 104, 101, 32, 97, 117, 116, 111, 99, 114, 111, 112, 32, 116,
  104, 97, 116, 32, 99, 111, 117, 108, 100, 32, 98, 101, 32, 112, 101, 114,
  102, 111, 114, 109, 101, 100, 32, 111, 110, 32, 116, 104, 101, 32, 108, 97,
  116, 101, 115, 116, 32, 111, 102, 32, 116, 104, 101, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 58, 32, 39, 97, 117, 116, 111, 39, 10, 97, 117, 116, 111,
  99, 114, 111, 112, 95, 99, 111, 111, 114, 100, 115, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 49, 61, 97, 117, 116, 111, 125, 10, 45, 118,
  32, 45, 10, 105, 115, 95, 97, 117, 116, 111, 61, 123, 36, 49, 39, 61,
  61, 39, 97, 117, 116, 111, 125, 10, 119, 61, 123, 119, 125, 32, 104, 61,
  123, 104, 125, 32, 100, 61, 123, 100, 125, 10, 118, 97, 108, 117, 101, 61,
  123, 105, 40, 119, 45, 49, 44, 104, 45, 49, 44, 100, 45, 49, 41, 125,
  32, 45, 45, 61, 91, 45, 49, 93, 32, 123, 49, 43, 36, 118, 97, 108,
  117, 101, 125, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 32, 45, 95, 97, 117, 116, 111, 99, 114, 111, 112, 36, 105, 115,
  95, 97, 117, 116, 111, 91, 45, 49, 93, 32, 36, 123, 49, 45, 45, 49,
  125, 32, 45, 61, 91, 45, 49, 93, 32, 36, 118, 97, 108, 117, 101, 44,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 10, 120,
  48, 61, 123, 36, 119, 45, 119, 125, 32, 121, 48, 61, 123, 36, 104, 45,
  104, 125, 32, 122, 48, 61, 123, 36, 100, 45, 100, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 45, 95, 97, 117, 116, 111, 99, 114, 111, 112,
  36, 105, 115, 95, 97, 117, 116, 111, 91, 45, 49, 93, 32, 36, 123, 49,
  45, 45, 49, 125, 10, 120, 49, 61, 123, 36, 120, 48, 43, 119, 45, 49,
  125, 32, 121, 49, 61, 123, 36, 121, 48, 43, 104, 45, 49, 125, 32, 122,
  49, 61, 123, 36, 122, 48, 43, 100, 45, 49, 125, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 117, 32, 36, 120, 48, 44, 36, 121, 48, 44, 36,
  122, 48, 44, 36, 120, 49, 44, 36, 121, 49, 44, 36, 122, 49, 10, 45,
  118, 32, 43, 10, 95, 97, 117, 116, 111, 99, 114, 111, 112, 48, 32, 58,
  32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 36, 42, 10, 95, 97,
  117, 116, 111, 99, 114, 111, 112, 49, 32, 58, 32, 45, 115, 107, 105, 112,
  32, 36, 42, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 10, 35, 64,
  103, 109, 105, 99, 32, 97, 118, 101, 114, 97, 103, 101, 95, 99, 111, 108,
  111, 114, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116, 117,
  114, 110, 32, 116, 104, 101, 32, 97, 118, 101, 114, 97, 103, 101, 32, 99,
  111, 108, 111, 114, 32, 111, 102, 32, 116, 104, 101, 32, 108, 97, 116, 101,
  115, 116, 32, 111, 102, 32, 116, 104, 101, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 97, 118, 101, 114, 97,
  103, 101, 95, 99, 111, 108, 111, 114, 32, 58, 10, 45, 118, 32, 45, 10,
  114, 101, 115, 61, 34, 34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  115, 45, 49, 125, 32, 45, 115, 104, 91, 45, 49, 93, 32, 123, 49, 43,
  36, 62, 125, 44, 123, 49, 43, 36, 62, 125, 32, 114, 101, 115, 61, 36,
  114, 101, 115, 44, 123, 105, 97, 125, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 100, 111, 110, 101, 10, 45, 115, 104, 91, 45, 49, 93, 32, 48,
  44, 48, 32, 45, 117, 32, 123, 105, 97, 125, 36, 114, 101, 115, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 118, 32, 43, 10, 35, 64, 103, 109,
  105, 99, 32, 98, 97, 115, 101, 110, 97, 109, 101, 32, 58, 32, 102, 105,
  108, 101, 95, 112, 97, 116, 104, 44, 95, 118, 97, 114, 105, 97, 98, 108,
  101, 95, 110, 97, 109, 101, 95, 102, 111, 114, 95, 102, 111, 108, 100, 101,
  114, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116, 117, 114,
  110, 32, 116, 104, 101, 32, 98, 97, 115, 101, 110, 97, 109, 101, 32, 111,
  102, 32, 97, 32, 102, 105, 108, 101, 32, 112, 97, 116, 104, 44, 32, 97,
  110, 100, 32, 111, 112, 116, 46, 32, 105, 116, 115, 32, 102, 111, 108, 100,
  101, 114, 32, 108, 111, 99, 97, 116, 105, 111, 110, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 87, 104, 101, 110, 32, 115, 112, 101, 99, 105,
  102, 105, 101, 100, 32, 39, 118, 97, 114, 105, 97, 98, 108, 101, 95, 110,
  97, 109, 101, 95, 102, 111, 114, 95, 102, 111, 108, 100, 101, 114, 39, 32,
  109, 117, 115, 116, 32, 115, 116, 97, 114, 116, 115, 32, 98, 121, 32, 97,
  110, 32, 117, 110, 100, 101, 114, 115, 99, 111, 114, 101, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 40, 103, 108, 111, 98, 97, 108, 32, 118, 97,
  114, 105, 97, 98, 108, 101, 32, 97, 99, 99, 101, 115, 115, 105, 98, 108,
  101, 32, 102, 114, 111, 109, 32, 99, 97, 108, 108, 105, 110, 103, 32, 102,
  117, 110, 99, 116, 105, 111, 110, 41, 46, 10, 98, 97, 115, 101, 110, 97,
  109, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 117,
  110, 117, 115, 101, 100, 125, 10, 45, 118, 32, 45, 10, 45, 108, 91, 93,
  32, 40, 123, 34, 39, 36, 49, 39, 34, 125, 41, 32, 45, 114, 101, 112,
  108, 97, 99, 101, 32, 57, 50, 44, 52, 55, 32, 45, 115, 32, 43, 44,
  52, 55, 10, 45, 105, 102, 32, 123, 105, 61, 61, 52, 55, 125, 32, 45,
  97, 32, 121, 32, 36, 50, 61, 64, 123, 45, 49, 44, 116, 125, 32, 45,
  117, 32, 34, 34, 10, 45, 101, 108, 105, 102, 32, 123, 64, 35, 61, 61,
  49, 125, 32, 45, 117, 32, 64, 123, 45, 49, 44, 116, 125, 32, 36, 50,
  61, 34, 34, 10, 45, 101, 108, 115, 101, 32, 45, 97, 91, 94, 45, 49,
  93, 32, 121, 32, 45, 117, 32, 64, 123, 45, 49, 44, 116, 125, 32, 36,
  50, 61, 64, 123, 45, 50, 44, 116, 125, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 114, 109, 32, 45, 101, 110, 100, 108, 10, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 98, 105, 110, 32, 58, 32, 98, 105, 110,
  97, 114, 121, 95, 105, 110, 116, 49, 44, 46, 46, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 80, 114, 105, 110, 116, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 98, 105, 110, 97, 114, 121, 32, 105, 110, 116,
  101, 103, 101, 114, 115, 32, 105, 110, 116, 111, 32, 116, 104, 101, 105, 114,
  32, 111, 99, 116, 97, 108, 44, 32, 100, 101, 99, 105, 109, 97, 108, 44,
  32, 104, 101, 120, 97, 100, 101, 99, 105, 109, 97, 108, 32, 97, 110, 100,
  32, 115, 116, 114, 105, 110, 103, 32, 114, 101, 112, 114, 101, 115, 101, 110,
  116, 97, 116, 105, 111, 110, 115, 46, 10, 98, 105, 110, 32, 58, 10, 45,
  118, 32, 45, 32, 100, 101, 99, 61, 64, 123, 45, 98, 105, 110, 50, 100,
  101, 99, 92, 32, 36, 123, 94, 48, 125, 125, 32, 45, 118, 32, 43, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116,
  32, 98, 105, 110, 97, 114, 121, 32, 105, 110, 116, 101, 103, 101, 114, 34,
  64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 40, 36, 35, 62, 49, 41,
  44, 34, 34, 44, 115, 125, 34, 32, 39, 36, 123, 94, 48, 125, 39, 32,
  116, 111, 32, 111, 99, 116, 97, 108, 32, 39, 34, 64, 123, 45, 100, 101,
  99, 50, 111, 99, 116, 92, 32, 36, 100, 101, 99, 125, 34, 39, 44, 10,
  100, 101, 99, 105, 109, 97, 108, 32, 39, 34, 36, 100, 101, 99, 34, 39,
  44, 32, 104, 101, 120, 97, 100, 101, 99, 105, 109, 97, 108, 32, 39, 34,
  64, 123, 45, 100, 101, 99, 50, 104, 101, 120, 92, 32, 36, 100, 101, 99,
  125, 34, 39, 32, 97, 110, 100, 32, 115, 116, 114, 105, 110, 103, 32, 39,
  34, 64, 123, 45, 100, 101, 99, 50, 115, 116, 114, 92, 32, 36, 100, 101,
  99, 125, 34, 39, 46, 34, 10, 35, 64, 103, 109, 105, 99, 32, 98, 105,
  110, 50, 100, 101, 99, 32, 58, 32, 98, 105, 110, 97, 114, 121, 95, 105,
  110, 116, 49, 44, 46, 46, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 112, 101, 99, 105, 102, 105,
  101, 100, 32, 98, 105, 110, 97, 114, 121, 32, 105, 110, 116, 101, 103, 101,
  114, 115, 32, 105, 110, 116, 111, 32, 116, 104, 101, 105, 114, 32, 100, 101,
  99, 105, 109, 97, 108, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 97,
  116, 105, 111, 110, 115, 46, 10, 98, 105, 110, 50, 100, 101, 99, 32, 58,
  10, 45, 118, 32, 45, 32, 114, 101, 115, 61, 64, 123, 45, 95, 36, 48,
  92, 32, 36, 49, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36,
  35, 45, 49, 125, 32, 114, 101, 115, 61, 36, 114, 101, 115, 44, 64, 123,
  45, 95, 36, 48, 92, 32, 64, 123, 45, 97, 114, 103, 92, 32, 36, 62,
  43, 50, 44, 36, 123, 94, 48, 125, 125, 125, 32, 45, 100, 111, 110, 101,
  32, 45, 117, 32, 36, 114, 101, 115, 32, 45, 118, 32, 43, 10, 95, 98,
  105, 110, 50, 100, 101, 99, 32, 58, 10, 40, 123, 39, 64, 123, 45, 115,
  116, 114, 117, 110, 99, 97, 115, 101, 92, 32, 36, 49, 125, 39, 125, 41,
  10, 105, 115, 95, 110, 101, 103, 97, 116, 105, 118, 101, 61, 48, 10, 45,
  105, 102, 32, 123, 64, 123, 45, 49, 44, 48, 125, 61, 61, 52, 53, 125,
  32, 45, 122, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48, 37, 32, 105,
  115, 95, 110, 101, 103, 97, 116, 105, 118, 101, 61, 49, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 102, 91, 45, 49, 93, 32, 34, 105, 102, 40, 105,
  62, 61, 52, 56, 32, 38, 38, 32, 105, 60, 61, 52, 57, 44, 40, 105,
  45, 52, 56, 41, 42, 50, 94, 40, 119, 45, 49, 45, 120, 41, 44, 110,
  97, 110, 41, 34, 10, 45, 117, 32, 123, 105, 102, 40, 36, 105, 115, 95,
  110, 101, 103, 97, 116, 105, 118, 101, 44, 45, 49, 44, 49, 41, 42, 64,
  123, 45, 49, 44, 43, 125, 125, 10, 45, 114, 109, 91, 45, 49, 93, 10,
  99, 111, 109, 112, 114, 101, 115, 115, 95, 103, 109, 105, 99, 32, 58, 10,
  45, 101, 91, 93, 32, 34, 34, 32, 45, 118, 32, 45, 10, 104, 101, 97,
  100, 95, 115, 116, 100, 61, 123, 39, 34, 35, 64, 103, 109, 105, 99, 34,
  39, 125, 10, 45, 115, 32, 45, 44, 49, 48, 32, 78, 61, 64, 35, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 105, 102, 32, 123,
  33, 40, 36, 62, 37, 49, 48, 48, 41, 125, 32, 45, 118, 32, 43, 32,
  45, 101, 91, 93, 32, 34, 92, 114, 32, 32, 80, 114, 111, 99, 101, 115,
  115, 32, 58, 32, 34, 123, 114, 111, 117, 110, 100, 40, 36, 62, 47, 36,
  78, 42, 49, 48, 48, 41, 125, 37, 32, 45, 118, 32, 45, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 105, 61, 61, 123, 39, 35,
  39, 125, 125, 10, 104, 101, 97, 100, 61, 64, 123, 45, 49, 44, 48, 45,
  123, 109, 105, 110, 40, 53, 44, 104, 45, 49, 41, 125, 125, 10, 45, 105,
  102, 32, 123, 123, 36, 104, 101, 97, 100, 39, 33, 61, 39, 36, 104, 101,
  97, 100, 95, 115, 116, 100, 125, 34, 32, 124, 124, 32, 34, 40, 105, 91,
  54, 93, 33, 61, 123, 39, 34, 32, 34, 39, 125, 34, 32, 38, 38, 32,
  34, 105, 91, 54, 93, 33, 61, 123, 39, 58, 39, 125, 41, 125, 32, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 99, 111, 110, 116, 105, 110, 117, 101,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101, 10, 45, 108,
  91, 45, 49, 93, 32, 45, 115, 112, 108, 105, 116, 32, 43, 44, 51, 50,
  44, 51, 53, 32, 45, 105, 102, 32, 123, 64, 35, 62, 50, 125, 32, 45,
  107, 91, 48, 93, 32, 45, 101, 110, 100, 105, 102, 32, 45, 97, 32, 121,
  32, 45, 101, 110, 100, 108, 10, 45, 97, 117, 116, 111, 99, 114, 111, 112,
  91, 45, 49, 93, 32, 51, 50, 32, 45, 105, 102, 32, 123, 33, 119, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 99, 111, 110, 116, 105, 110,
  117, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101,
  10, 45, 105, 91, 49, 45, 45, 50, 93, 32, 40, 49, 48, 41, 32, 45,
  97, 32, 121, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92,
  114, 32, 80, 114, 111, 99, 101, 115, 115, 32, 58, 32, 49, 48, 48, 37,
  34, 10, 99, 111, 109, 112, 114, 101, 115, 115, 95, 103, 109, 105, 99, 95,
  103, 105, 109, 112, 32, 58, 10, 45, 101, 91, 93, 32, 34, 34, 32, 45,
  118, 32, 45, 10, 104, 101, 97, 100, 95, 115, 116, 100, 61, 123, 39, 34,
  35, 64, 103, 105, 109, 112, 34, 39, 125, 10, 45, 115, 32, 45, 44, 49,
  48, 32, 78, 61, 64, 35, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 10, 45, 105, 102, 32, 123, 33, 40, 36, 62, 37, 49, 48, 48, 41,
  125, 32, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 114, 32,
  32, 80, 114, 111, 99, 101, 115, 115, 32, 58, 32, 34, 123, 114, 111, 117,
  110, 100, 40, 36, 62, 47, 36, 78, 42, 49, 48, 48, 41, 125, 37, 32,
  45, 118, 32, 45, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 105, 61, 61, 123, 39, 35, 39, 125, 125, 10, 104, 101, 97, 100, 61,
  64, 123, 45, 49, 44, 48, 45, 123, 109, 105, 110, 40, 53, 44, 104, 45,
  49, 41, 125, 125, 10, 45, 105, 102, 32, 123, 36, 104, 101, 97, 100, 39,
  33, 61, 39, 36, 104, 101, 97, 100, 95, 115, 116, 100, 125, 32, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 99, 111, 110, 116, 105, 110, 117, 101, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101, 10, 45, 108, 91,
  45, 49, 93, 32, 45, 115, 112, 108, 105, 116, 32, 43, 44, 51, 50, 44,
  51, 53, 32, 45, 105, 102, 32, 123, 64, 35, 62, 50, 125, 32, 45, 107,
  91, 48, 93, 32, 45, 101, 110, 100, 105, 102, 32, 45, 97, 32, 121, 32,
  45, 101, 110, 100, 108, 10, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91,
  45, 49, 93, 32, 51, 50, 32, 45, 105, 102, 32, 123, 33, 119, 125, 32,
  45, 114, 109, 91, 45, 49, 93, 32, 45, 99, 111, 110, 116, 105, 110, 117,
  101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10,
  45, 105, 91, 49, 45, 45, 50, 93, 32, 40, 49, 48, 41, 32, 45, 97,
  32, 121, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 114,
  32, 80, 114, 111, 99, 101, 115, 115, 32, 58, 32, 49, 48, 48, 37, 34,
  10, 35, 64, 103, 109, 105, 99, 32, 100, 101, 99, 32, 58, 32, 100, 101,
  99, 105, 109, 97, 108, 95, 105, 110, 116, 49, 44, 46, 46, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 80, 114, 105, 110, 116, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 100, 101, 99, 105, 109, 97, 108, 32,
  105, 110, 116, 101, 103, 101, 114, 115, 32, 105, 110, 116, 111, 32, 116, 104,
  101, 105, 114, 32, 98, 105, 110, 97, 114, 121, 44, 32, 111, 99, 116, 97,
  108, 44, 32, 104, 101, 120, 97, 100, 101, 99, 105, 109, 97, 108, 32, 97,
  110, 100, 32, 115, 116, 114, 105, 110, 103, 32, 114, 101, 112, 114, 101, 115,
  101, 110, 116, 97, 116, 105, 111, 110, 115, 46, 10, 100, 101, 99, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114,
  116, 32, 100, 101, 99, 105, 109, 97, 108, 32, 105, 110, 116, 101, 103, 101,
  114, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 40, 36, 35, 62,
  49, 41, 44, 34, 34, 44, 115, 125, 34, 32, 39, 36, 123, 94, 48, 125,
  39, 32, 116, 111, 32, 98, 105, 110, 97, 114, 121, 32, 39, 34, 64, 123,
  45, 100, 101, 99, 50, 98, 105, 110, 92, 32, 36, 123, 94, 48, 125, 125,
  34, 39, 44, 10, 111, 99, 116, 97, 108, 32, 39, 34, 64, 123, 45, 100,
  101, 99, 50, 111, 99, 116, 92, 32, 36, 123, 94, 48, 125, 125, 34, 39,
  44, 32, 104, 101, 120, 97, 100, 101, 99, 105, 109, 97, 108, 32, 39, 34,
  64, 123, 45, 100, 101, 99, 50, 104, 101, 120, 92, 32, 36, 123, 94, 48,
  125, 125, 34, 39, 32, 97, 110, 100, 32, 115, 116, 114, 105, 110, 103, 32,
  39, 34, 64, 123, 45, 100, 101, 99, 50, 115, 116, 114, 92, 32, 36, 123,
  94, 48, 125, 125, 34, 39, 46, 34, 10, 35, 64, 103, 109, 105, 99, 32,
  100, 101, 99, 50, 115, 116, 114, 32, 58, 32, 100, 101, 99, 105, 109, 97,
  108, 95, 105, 110, 116, 49, 44, 46, 46, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 112, 101, 99,
  105, 102, 105, 97, 108, 32, 100, 101, 99, 105, 109, 97, 108, 32, 105, 110,
  116, 101, 103, 101, 114, 115, 32, 105, 110, 116, 111, 32, 105, 116, 115, 32,
  115, 116, 114, 105, 110, 103, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116,
  97, 116, 105, 111, 110, 46, 10, 100, 101, 99, 50, 115, 116, 114, 32, 58,
  10, 45, 118, 32, 45, 32, 45, 117, 32, 123, 96, 36, 123, 94, 48, 125,
  96, 125, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 100,
  101, 99, 50, 98, 105, 110, 32, 58, 32, 100, 101, 99, 105, 109, 97, 108,
  95, 105, 110, 116, 49, 44, 46, 46, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 112, 101, 99, 105,
  102, 105, 101, 100, 32, 100, 101, 99, 105, 109, 97, 108, 32, 105, 110, 116,
  101, 103, 101, 114, 115, 32, 105, 110, 116, 111, 32, 116, 104, 101, 105, 114,
  32, 98, 105, 110, 97, 114, 121, 32, 114, 101, 112, 114, 101, 115, 101, 110,
  116, 97, 116, 105, 111, 110, 115, 46, 10, 100, 101, 99, 50, 98, 105, 110,
  32, 58, 10, 45, 118, 32, 45, 32, 114, 101, 115, 61, 64, 123, 45, 95,
  36, 48, 92, 32, 36, 49, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 36, 35, 45, 49, 125, 32, 114, 101, 115, 61, 36, 114, 101, 115, 44,
  64, 123, 45, 95, 36, 48, 92, 32, 64, 123, 45, 97, 114, 103, 92, 32,
  36, 62, 43, 50, 44, 36, 123, 94, 48, 125, 125, 125, 32, 45, 100, 111,
  110, 101, 32, 45, 117, 32, 36, 114, 101, 115, 32, 45, 118, 32, 43, 10,
  95, 100, 101, 99, 50, 98, 105, 110, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 105, 115, 105, 110, 116, 40, 36, 49, 41, 10, 114, 101, 115, 61,
  34, 34, 32, 114, 61, 123, 97, 98, 115, 40, 36, 49, 41, 125, 10, 45,
  100, 111, 32, 114, 101, 115, 61, 123, 36, 114, 37, 50, 125, 36, 114, 101,
  115, 32, 114, 61, 123, 105, 110, 116, 40, 36, 114, 47, 50, 41, 125, 32,
  45, 119, 104, 105, 108, 101, 32, 36, 114, 10, 45, 117, 32, 64, 123, 45,
  97, 114, 103, 92, 32, 49, 43, 40, 36, 49, 62, 61, 48, 41, 44, 45,
  44, 34, 34, 125, 36, 114, 101, 115, 10, 35, 64, 103, 109, 105, 99, 32,
  100, 101, 99, 50, 104, 101, 120, 32, 58, 32, 100, 101, 99, 105, 109, 97,
  108, 95, 105, 110, 116, 49, 44, 46, 46, 46, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 112, 101, 99,
  105, 102, 105, 101, 100, 32, 100, 101, 99, 105, 109, 97, 108, 32, 105, 110,
  116, 101, 103, 101, 114, 115, 32, 105, 110, 116, 111, 32, 116, 104, 101, 105,
  114, 32, 104, 101, 120, 97, 100, 101, 99, 105, 109, 97, 108, 32, 114, 101,
  112, 114, 101, 115, 101, 110, 116, 97, 116, 105, 111, 110, 115, 46, 10, 100,
  101, 99, 50, 104, 101, 120, 32, 58, 10, 45, 118, 32, 45, 32, 114, 101,
  115, 61, 64, 123, 45, 95, 36, 48, 92, 32, 36, 49, 125, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 123, 36, 35, 45, 49, 125, 32, 114, 101, 115,
  61, 36, 114, 101, 115, 44, 64, 123, 45, 95, 36, 48, 92, 32, 64, 123,
  45, 97, 114, 103, 92, 32, 36, 62, 43, 50, 44, 36, 123, 94, 48, 125,
  125, 125, 32, 45, 100, 111, 110, 101, 32, 45, 117, 32, 36, 114, 101, 115,
  32, 45, 118, 32, 43, 10, 95, 100, 101, 99, 50, 104, 101, 120, 32, 58,
  32, 45, 99, 104, 101, 99, 107, 32, 105, 115, 105, 110, 116, 40, 36, 49,
  41, 10, 114, 101, 115, 61, 34, 34, 32, 114, 61, 123, 97, 98, 115, 40,
  36, 49, 41, 125, 10, 45, 100, 111, 32, 114, 101, 115, 61, 64, 123, 45,
  95, 100, 101, 99, 50, 104, 101, 120, 95, 123, 36, 114, 37, 49, 54, 125,
  125, 36, 114, 101, 115, 32, 114, 61, 123, 105, 110, 116, 40, 36, 114, 47,
  49, 54, 41, 125, 32, 45, 119, 104, 105, 108, 101, 32, 36, 114, 10, 45,
  117, 32, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 40, 36, 49, 62,
  61, 48, 41, 44, 45, 44, 34, 34, 125, 36, 114, 101, 115, 10, 95, 100,
  101, 99, 50, 104, 101, 120, 95, 48, 32, 58, 32, 45, 117, 32, 48, 10,
  95, 100, 101, 99, 50, 104, 101, 120, 95, 49, 32, 58, 32, 45, 117, 32,
  49, 10, 95, 100, 101, 99, 50, 104, 101, 120, 95, 50, 32, 58, 32, 45,
  117, 32, 50, 10, 95, 100, 101, 99, 50, 104, 101, 120, 95, 51, 32, 58,
  32, 45, 117, 32, 51, 10, 95, 100, 101, 99, 50, 104, 101, 120, 95, 52,
  32, 58, 32, 45, 117, 32, 52, 10, 95, 100, 101, 99, 50, 104, 101, 120,
  95, 53, 32, 58, 32, 45, 117, 32, 53, 10, 95, 100, 101, 99, 50, 104,
  101, 120, 95, 54, 32, 58, 32, 45, 117, 32, 54, 10, 95, 100, 101, 99,
  50, 104, 101, 120, 95, 55, 32, 58, 32, 45, 117, 32, 55, 10, 95, 100,
  101, 99, 50, 104, 101, 120, 95, 56, 32, 58, 32, 45, 117, 32, 56, 10,
  95, 100, 101, 99, 50, 104, 101, 120, 95, 57, 32, 58, 32, 45, 117, 32,
  57, 10, 95, 100, 101, 99, 50, 104, 101, 120, 95, 49, 48, 32, 58, 32,
  45, 117, 32, 97, 10, 95, 100, 101, 99, 50, 104, 101, 120, 95, 49, 49,
  32, 58, 32, 45, 117, 32, 98, 10, 95, 100, 101, 99, 50, 104, 101, 120,
  95, 49, 50, 32, 58, 32, 45, 117, 32, 99, 10, 95, 100, 101, 99, 50,
  104, 101, 120, 95, 49, 51, 32, 58, 32, 45, 117, 32, 100, 10, 95, 100,
  101, 99, 50, 104, 101, 120, 95, 49, 52, 32, 58, 32, 45, 117, 32, 101,
  10, 95, 100, 101, 99, 50, 104, 101, 120, 95, 49, 53, 32, 58, 32, 45,
  117, 32, 102, 10, 35, 64, 103, 109, 105, 99, 32, 100, 101, 99, 50, 111,
  99, 116, 32, 58, 32, 100, 101, 99, 105, 109, 97, 108, 95, 105, 110, 116,
  49, 44, 46, 46, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67,
  111, 110, 118, 101, 114, 116, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100,
  32, 100, 101, 99, 105, 109, 97, 108, 32, 105, 110, 116, 101, 103, 101, 114,
  115, 32, 105, 110, 116, 111, 32, 116, 104, 101, 105, 114, 32, 111, 99, 116,
  97, 108, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 97, 116, 105, 111,
  110, 115, 46, 10, 100, 101, 99, 50, 111, 99, 116, 32, 58, 10, 45, 118,
  32, 45, 32, 114, 101, 115, 61, 64, 123, 45, 95, 36, 48, 92, 32, 36,
  49, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 35, 45, 49,
  125, 32, 114, 101, 115, 61, 36, 114, 101, 115, 44, 64, 123, 45, 95, 36,
  48, 92, 32, 64, 123, 45, 97, 114, 103, 92, 32, 36, 62, 43, 50, 44,
  36, 123, 94, 48, 125, 125, 125, 32, 45, 100, 111, 110, 101, 32, 45, 117,
  32, 36, 114, 101, 115, 32, 45, 118, 32, 43, 10, 95, 100, 101, 99, 50,
  111, 99, 116, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 105, 115, 105,
  110, 116, 40, 36, 49, 41, 10, 114, 101, 115, 61, 34, 34, 32, 114, 61,
  123, 97, 98, 115, 40, 36, 49, 41, 125, 10, 45, 100, 111, 32, 114, 101,
  115, 61, 123, 36, 114, 37, 56, 125, 36, 114, 101, 115, 32, 114, 61, 123,
  105, 110, 116, 40, 36, 114, 47, 56, 41, 125, 32, 45, 119, 104, 105, 108,
  101, 32, 36, 114, 10, 45, 117, 32, 64, 123, 45, 97, 114, 103, 92, 32,
  49, 43, 40, 36, 49, 62, 61, 48, 41, 44, 45, 44, 34, 34, 125, 36,
  114, 101, 115, 10, 35, 64, 103, 109, 105, 99, 32, 102, 97, 99, 116, 32,
  58, 32, 118, 97, 108, 117, 101, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 82, 101, 116, 117, 114, 110, 32, 116, 104, 101, 32, 102, 97, 99, 116,
  111, 114, 105, 97, 108, 32, 111, 102, 32, 116, 104, 101, 32, 115, 112, 101,
  99, 105, 102, 105, 101, 100, 32, 118, 97, 108, 117, 101, 46, 10, 102, 97,
  99, 116, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 105, 115, 105, 110,
  116, 40, 36, 49, 41, 10, 45, 118, 32, 45, 32, 114, 101, 115, 61, 49,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 32, 114, 101, 115, 61,
  123, 36, 114, 101, 115, 42, 40, 36, 62, 43, 49, 41, 125, 32, 45, 100,
  111, 110, 101, 32, 45, 117, 32, 36, 114, 101, 115, 32, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 102, 105, 108, 101, 95, 109, 118, 32,
  58, 32, 102, 105, 108, 101, 110, 97, 109, 101, 95, 115, 114, 99, 44, 102,
  105, 108, 101, 110, 97, 109, 101, 95, 100, 101, 115, 116, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 82, 101, 110, 97, 109, 101, 32, 111, 114, 32,
  109, 111, 118, 101, 32, 97, 32, 102, 105, 108, 101, 32, 102, 114, 111, 109,
  32, 97, 32, 108, 111, 99, 97, 116, 105, 111, 110, 32, 36, 49, 32, 116,
  111, 32, 97, 110, 111, 116, 104, 101, 114, 32, 108, 111, 99, 97, 116, 105,
  111, 110, 32, 36, 50, 46, 10, 102, 105, 108, 101, 95, 109, 118, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 77, 111, 118, 101, 32, 102,
  105, 108, 101, 32, 39, 36, 49, 39, 32, 116, 111, 32, 108, 111, 99, 97,
  116, 105, 111, 110, 32, 39, 36, 50, 39, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 105, 102, 32, 64, 123, 45, 105, 115, 95, 119, 105, 110, 100, 111,
  119, 115, 125, 32, 45, 120, 32, 34, 109, 111, 118, 101, 32, 34, 36, 49,
  34, 32, 34, 36, 50, 32, 45, 101, 108, 115, 101, 32, 45, 120, 32, 34,
  109, 118, 32, 34, 36, 49, 34, 32, 34, 36, 50, 32, 45, 101, 110, 100,
  105, 102, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 102,
  105, 108, 101, 95, 114, 97, 110, 100, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 82, 101, 116, 117, 114, 110, 32, 97, 32, 114, 97, 110, 100, 111,
  109, 32, 102, 105, 108, 101, 110, 97, 109, 101, 32, 102, 111, 114, 32, 115,
  116, 111, 114, 105, 110, 103, 32, 116, 101, 109, 112, 111, 114, 97, 114, 121,
  32, 100, 97, 116, 97, 46, 10, 102, 105, 108, 101, 95, 114, 97, 110, 100,
  32, 58, 10, 45, 118, 32, 45, 10, 45, 100, 111, 32, 102, 105, 108, 101,
  110, 97, 109, 101, 61, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109, 112,
  125, 64, 123, 45, 102, 105, 108, 101, 95, 115, 108, 97, 115, 104, 125, 103,
  109, 105, 99, 64, 37, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44,
  57, 41, 41, 125, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 57,
  41, 41, 125, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 57, 41,
  41, 125, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 57, 41, 41,
  125, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 57, 41, 41, 125,
  123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 57, 41, 41, 125, 10,
  45, 119, 104, 105, 108, 101, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101,
  10, 45, 117, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 10, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 102, 105, 108, 101, 95, 114,
  109, 32, 58, 32, 102, 105, 108, 101, 110, 97, 109, 101, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 108, 101, 116, 101, 32, 97, 32, 102,
  105, 108, 101, 46, 10, 102, 105, 108, 101, 95, 114, 109, 32, 58, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 109, 111, 118, 101, 32, 102,
  105, 108, 101, 32, 39, 36, 49, 39, 46, 34, 10, 45, 118, 32, 45, 10,
  45, 105, 102, 32, 64, 123, 45, 105, 115, 95, 119, 105, 110, 100, 111, 119,
  115, 125, 10, 49, 32, 45, 110, 109, 91, 45, 49, 93, 32, 34, 36, 49,
  34, 32, 100, 105, 114, 61, 64, 123, 45, 49, 44, 102, 125, 32, 98, 97,
  115, 101, 61, 64, 123, 45, 49, 44, 98, 125, 32, 101, 120, 116, 61, 64,
  123, 45, 49, 44, 120, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 99,
  111, 109, 61, 34, 34, 10, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40,
  36, 100, 105, 114, 41, 125, 32, 99, 111, 109, 61, 34, 99, 100, 32, 92,
  34, 34, 36, 100, 105, 114, 34, 92, 92, 92, 34, 32, 38, 38, 32, 34,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 110, 97, 114,
  103, 40, 36, 101, 120, 116, 41, 125, 32, 99, 111, 109, 61, 36, 123, 99,
  111, 109, 125, 34, 100, 101, 108, 32, 92, 34, 34, 36, 98, 97, 115, 101,
  46, 36, 101, 120, 116, 34, 92, 34, 34, 32, 45, 101, 108, 115, 101, 32,
  99, 111, 109, 61, 36, 123, 99, 111, 109, 125, 34, 100, 101, 108, 32, 92,
  34, 34, 36, 98, 97, 115, 101, 34, 92, 34, 34, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 120, 32, 36, 99, 111, 109, 10, 45, 101, 108, 115, 101,
  10, 45, 120, 32, 34, 114, 109, 32, 45, 102, 32, 92, 34, 36, 49, 92,
  34, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 102, 105, 108, 101, 95, 115, 108, 97, 115, 104,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116, 117, 114, 110,
  32, 39, 47, 39, 32, 111, 114, 32, 39, 92, 39, 32, 97, 115, 32, 97,
  32, 112, 97, 116, 104, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 32,
  102, 111, 114, 32, 102, 105, 108, 101, 110, 97, 109, 101, 115, 46, 10, 102,
  105, 108, 101, 95, 115, 108, 97, 115, 104, 32, 58, 10, 45, 118, 32, 45,
  32, 45, 105, 102, 32, 64, 123, 45, 105, 115, 95, 119, 105, 110, 100, 111,
  119, 115, 125, 32, 45, 117, 32, 34, 92, 92, 34, 32, 45, 101, 108, 115,
  101, 32, 45, 117, 32, 34, 47, 34, 32, 45, 101, 110, 100, 105, 102, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 102, 105, 108, 101,
  110, 97, 109, 101, 32, 58, 32, 102, 105, 108, 101, 110, 97, 109, 101, 44,
  95, 110, 117, 109, 98, 101, 114, 49, 44, 95, 110, 117, 109, 98, 101, 114,
  50, 44, 46, 46, 46, 44, 95, 110, 117, 109, 98, 101, 114, 78, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116, 117, 114, 110, 32, 97,
  32, 102, 105, 108, 101, 110, 97, 109, 101, 32, 110, 117, 109, 98, 101, 114,
  101, 100, 32, 119, 105, 116, 104, 32, 115, 112, 101, 99, 105, 102, 105, 101,
  100, 32, 105, 110, 100, 105, 99, 101, 115, 46, 10, 102, 105, 108, 101, 110,
  97, 109, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36, 123, 49,
  61, 100, 101, 102, 97, 117, 108, 116, 125, 34, 10, 45, 118, 32, 45, 10,
  45, 105, 102, 32, 123, 36, 35, 61, 61, 49, 125, 32, 45, 117, 32, 34,
  36, 49, 34, 10, 45, 101, 108, 115, 101, 10, 40, 36, 123, 50, 45, 45,
  49, 125, 41, 32, 45, 110, 97, 109, 101, 91, 45, 49, 93, 32, 34, 36,
  49, 34, 32, 45, 117, 32, 64, 123, 45, 49, 44, 102, 125, 64, 123, 45,
  49, 44, 98, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 119, 125,
  10, 45, 117, 32, 64, 123, 125, 95, 123, 105, 110, 116, 40, 105, 47, 49,
  48, 48, 48, 48, 48, 41, 37, 49, 48, 125, 123, 105, 110, 116, 40, 105,
  47, 49, 48, 48, 48, 48, 41, 37, 49, 48, 125, 123, 105, 110, 116, 40,
  105, 47, 49, 48, 48, 48, 41, 37, 49, 48, 125, 123, 105, 110, 116, 40,
  105, 47, 49, 48, 48, 41, 37, 49, 48, 125, 123, 105, 110, 116, 40, 105,
  47, 49, 48, 41, 37, 49, 48, 125, 123, 105, 37, 49, 48, 125, 10, 45,
  115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 45, 49, 10, 45, 100, 111,
  110, 101, 10, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40, 123, 39, 64,
  123, 45, 49, 44, 120, 125, 39, 125, 41, 125, 32, 45, 117, 32, 64, 123,
  125, 46, 64, 123, 45, 49, 44, 120, 125, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 102, 105, 116, 114,
  97, 116, 105, 111, 95, 119, 104, 32, 58, 32, 109, 105, 110, 95, 119, 105,
  100, 116, 104, 44, 109, 105, 110, 95, 104, 101, 105, 103, 104, 116, 44, 114,
  97, 116, 105, 111, 95, 119, 104, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 82, 101, 116, 117, 114, 110, 32, 97, 32, 50, 100, 32, 115, 105, 122,
  101, 32, 39, 119, 105, 100, 116, 104, 44, 104, 101, 105, 103, 104, 116, 39,
  32, 119, 104, 105, 99, 104, 32, 105, 115, 32, 98, 105, 103, 103, 101, 114,
  32, 116, 104, 97, 110, 32, 39, 109, 105, 110, 95, 119, 105, 100, 116, 104,
  44, 109, 105, 110, 95, 104, 101, 105, 103, 104, 116, 39, 32, 97, 110, 100,
  32, 104, 97, 115, 32, 116, 104, 101, 32, 115, 112, 101, 99, 105, 102, 105,
  101, 100, 32, 119, 47, 104, 32, 114, 97, 116, 105, 111, 46, 10, 102, 105,
  116, 114, 97, 116, 105, 111, 95, 119, 104, 32, 58, 10, 45, 118, 32, 45,
  32, 45, 105, 102, 32, 123, 36, 51, 42, 36, 50, 62, 36, 49, 125, 32,
  45, 117, 32, 123, 105, 110, 116, 40, 36, 51, 42, 36, 50, 41, 125, 44,
  36, 50, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 36, 49, 44, 123,
  105, 110, 116, 40, 36, 49, 47, 36, 51, 41, 125, 32, 45, 101, 110, 100,
  105, 102, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 102,
  105, 116, 115, 99, 114, 101, 101, 110, 32, 58, 32, 119, 105, 100, 116, 104,
  44, 104, 101, 105, 103, 104, 116, 44, 95, 100, 101, 112, 116, 104, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116, 117, 114, 110, 32, 116,
  104, 101, 32, 39, 105, 100, 101, 97, 108, 39, 32, 115, 105, 122, 101, 32,
  87, 120, 72, 32, 102, 111, 114, 32, 97, 32, 119, 105, 110, 100, 111, 119,
  32, 105, 110, 116, 101, 110, 100, 101, 100, 32, 116, 111, 32, 100, 105, 115,
  112, 108, 97, 121, 32, 97, 110, 32, 105, 109, 97, 103, 101, 32, 111, 102,
  32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 115, 105, 122, 101, 32,
  111, 110, 32, 115, 99, 114, 101, 101, 110, 46, 10, 102, 105, 116, 115, 99,
  114, 101, 101, 110, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36,
  49, 62, 48, 32, 38, 38, 32, 36, 50, 62, 48, 32, 38, 38, 32, 36,
  123, 51, 61, 49, 125, 62, 48, 34, 10, 45, 118, 32, 45, 10, 119, 61,
  123, 105, 102, 40, 36, 51, 62, 49, 44, 36, 49, 43, 36, 51, 44, 36,
  49, 41, 125, 10, 104, 61, 123, 105, 102, 40, 36, 51, 62, 49, 44, 36,
  50, 43, 36, 51, 44, 36, 50, 41, 125, 10, 77, 119, 61, 123, 105, 110,
  116, 40, 48, 46, 56, 53, 42, 64, 123, 33, 44, 117, 125, 41, 125, 10,
  77, 104, 61, 123, 105, 110, 116, 40, 48, 46, 56, 53, 42, 64, 123, 33,
  44, 118, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 119, 60, 49, 50,
  56, 125, 32, 104, 61, 123, 105, 110, 116, 40, 36, 104, 42, 49, 50, 56,
  47, 36, 119, 41, 125, 32, 119, 61, 49, 50, 56, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 104, 60, 49, 50, 56, 125, 32,
  119, 61, 123, 105, 110, 116, 40, 36, 119, 42, 49, 50, 56, 47, 36, 104,
  41, 125, 32, 104, 61, 49, 50, 56, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 119, 62, 36, 77, 119, 125, 32, 104, 61, 123,
  109, 97, 120, 40, 49, 44, 105, 110, 116, 40, 36, 104, 42, 36, 77, 119,
  47, 36, 119, 41, 41, 125, 32, 119, 61, 36, 77, 119, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 104, 62, 36, 77, 104, 125,
  32, 119, 61, 123, 109, 97, 120, 40, 49, 44, 105, 110, 116, 40, 36, 119,
  42, 36, 77, 104, 47, 36, 104, 41, 41, 125, 32, 104, 61, 36, 77, 119,
  32, 45, 101, 110, 100, 105, 102, 10, 119, 61, 123, 109, 97, 120, 40, 36,
  119, 44, 49, 50, 56, 41, 125, 10, 104, 61, 123, 109, 97, 120, 40, 36,
  104, 44, 49, 50, 56, 41, 125, 10, 45, 117, 32, 36, 119, 44, 36, 104,
  10, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 103, 99, 100,
  32, 58, 32, 97, 44, 98, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  82, 101, 116, 117, 114, 110, 32, 116, 104, 101, 32, 71, 67, 68, 32, 40,
  103, 114, 101, 97, 116, 101, 115, 116, 32, 99, 111, 109, 109, 111, 110, 32,
  100, 105, 118, 105, 115, 111, 114, 41, 32, 98, 101, 116, 119, 101, 101, 110,
  32, 97, 32, 97, 110, 100, 32, 98, 46, 10, 103, 99, 100, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 49,
  41, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 50, 41, 32, 38,
  38, 32, 36, 49, 42, 36, 50, 33, 61, 48, 34, 10, 45, 118, 32, 45,
  32, 45, 95, 103, 99, 100, 32, 123, 109, 97, 120, 40, 97, 98, 115, 40,
  36, 49, 41, 44, 97, 98, 115, 40, 36, 50, 41, 41, 125, 44, 123, 109,
  105, 110, 40, 97, 98, 115, 40, 36, 49, 41, 44, 97, 98, 115, 40, 36,
  50, 41, 41, 125, 32, 45, 118, 32, 43, 10, 95, 103, 99, 100, 32, 58,
  10, 114, 61, 123, 36, 49, 37, 36, 50, 125, 32, 45, 105, 102, 32, 36,
  114, 32, 45, 117, 32, 64, 123, 45, 95, 103, 99, 100, 92, 32, 36, 50,
  44, 36, 114, 125, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 36, 50,
  32, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103, 109, 105, 99, 32, 104,
  101, 120, 32, 58, 32, 104, 101, 120, 97, 100, 101, 99, 105, 109, 97, 108,
  95, 105, 110, 116, 49, 44, 46, 46, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 80, 114, 105, 110, 116, 32, 115, 112, 101, 99, 105, 102, 105,
  101, 100, 32, 104, 101, 120, 97, 100, 101, 99, 105, 109, 97, 108, 32, 105,
  110, 116, 101, 103, 101, 114, 115, 32, 105, 110, 116, 111, 32, 116, 104, 101,
  105, 114, 32, 98, 105, 110, 97, 114, 121, 44, 32, 111, 99, 116, 97, 108,
  44, 32, 100, 101, 99, 105, 109, 97, 108, 32, 97, 110, 100, 32, 115, 116,
  114, 105, 110, 103, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 97, 116,
  105, 111, 110, 115, 46, 10, 104, 101, 120, 32, 58, 10, 45, 118, 32, 45,
  32, 100, 101, 99, 61, 64, 123, 45, 104, 101, 120, 50, 100, 101, 99, 92,
  32, 36, 123, 94, 48, 125, 125, 32, 45, 118, 32, 43, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 104, 101,
  120, 97, 100, 101, 99, 105, 109, 97, 108, 32, 105, 110, 116, 101, 103, 101,
  114, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 40, 36, 35, 62,
  49, 41, 44, 115, 44, 34, 34, 125, 34, 32, 39, 36, 123, 94, 48, 125,
  39, 32, 116, 111, 32, 98, 105, 110, 97, 114, 121, 32, 39, 34, 64, 123,
  45, 100, 101, 99, 50, 98, 105, 110, 92, 32, 36, 100, 101, 99, 125, 34,
  39, 44, 10, 111, 99, 116, 97, 108, 32, 39, 34, 64, 123, 45, 100, 101,
  99, 50, 111, 99, 116, 92, 32, 36, 100, 101, 99, 125, 34, 39, 44, 32,
  100, 101, 99, 105, 109, 97, 108, 32, 39, 34, 36, 100, 101, 99, 34, 39,
  32, 97, 110, 100, 32, 115, 116, 114, 105, 110, 103, 32, 39, 34, 64, 123,
  45, 100, 101, 99, 50, 115, 116, 114, 92, 32, 36, 100, 101, 99, 125, 34,
  39, 46, 34, 10, 35, 64, 103, 109, 105, 99, 32, 104, 101, 120, 50, 100,
  101, 99, 32, 58, 32, 104, 101, 120, 97, 100, 101, 99, 105, 109, 97, 108,
  95, 105, 110, 116, 49, 44, 46, 46, 46, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 112, 101, 99, 105,
  102, 105, 101, 100, 32, 104, 101, 120, 97, 100, 101, 99, 105, 109, 97, 108,
  32, 105, 110, 116, 101, 103, 101, 114, 115, 32, 105, 110, 116, 111, 32, 116,
  104, 101, 105, 114, 32, 100, 101, 99, 105, 109, 97, 108, 32, 114, 101, 112,
  114, 101, 115, 101, 110, 116, 97, 116, 105, 111, 110, 115, 46, 10, 104, 101,
  120, 50, 100, 101, 99, 32, 58, 10, 45, 118, 32, 45, 32, 114, 101, 115,
  61, 64, 123, 45, 95, 36, 48, 92, 32, 36, 49, 125, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 36, 35, 45, 49, 125, 32, 114, 101, 115, 61,
  36, 114, 101, 115, 44, 64, 123, 45, 95, 36, 48, 92, 32, 64, 123, 45,
  97, 114, 103, 92, 32, 36, 62, 43, 50, 44, 36, 123, 94, 48, 125, 125,
  125, 32, 45, 100, 111, 110, 101, 32, 45, 117, 32, 36, 114, 101, 115, 32,
  45, 118, 32, 43, 10, 95, 104, 101, 120, 50, 100, 101, 99, 32, 58, 10,
  40, 123, 39, 64, 123, 45, 115, 116, 114, 117, 110, 99, 97, 115, 101, 92,
  32, 36, 49, 125, 39, 125, 41, 10, 105, 115, 95, 110, 101, 103, 97, 116,
  105, 118, 101, 61, 48, 10, 45, 105, 102, 32, 123, 64, 123, 45, 49, 44,
  48, 125, 61, 61, 52, 53, 125, 32, 45, 122, 91, 45, 49, 93, 32, 49,
  44, 49, 48, 48, 37, 32, 105, 115, 95, 110, 101, 103, 97, 116, 105, 118,
  101, 61, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 102, 91, 45, 49,
  93, 32, 34, 105, 102, 40, 105, 62, 61, 52, 56, 32, 38, 38, 32, 105,
  60, 61, 53, 55, 44, 105, 45, 52, 56, 44, 105, 102, 40, 105, 62, 61,
  57, 55, 32, 38, 38, 32, 105, 60, 61, 49, 48, 50, 44, 105, 45, 56,
  55, 44, 110, 97, 110, 41, 41, 42, 49, 54, 94, 40, 119, 45, 49, 45,
  120, 41, 34, 10, 45, 117, 32, 123, 105, 102, 40, 36, 105, 115, 95, 110,
  101, 103, 97, 116, 105, 118, 101, 44, 45, 49, 44, 49, 41, 42, 64, 123,
  45, 49, 44, 43, 125, 125, 10, 45, 114, 109, 91, 45, 49, 93, 10, 35,
  64, 103, 109, 105, 99, 32, 104, 101, 120, 50, 115, 116, 114, 32, 58, 32,
  104, 101, 120, 97, 100, 101, 99, 105, 109, 97, 108, 95, 115, 116, 114, 105,
  110, 103, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118,
  101, 114, 116, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 104, 101,
  120, 97, 100, 101, 99, 105, 109, 97, 108, 32, 115, 116, 114, 105, 110, 103,
  32, 105, 110, 116, 111, 32, 97, 32, 115, 116, 114, 105, 110, 103, 46, 10,
  104, 101, 120, 50, 115, 116, 114, 32, 58, 32, 45, 115, 107, 105, 112, 32,
  36, 123, 49, 61, 34, 34, 125, 10, 45, 118, 32, 45, 10, 45, 105, 102,
  32, 123, 33, 110, 97, 114, 103, 40, 34, 36, 49, 34, 41, 125, 32, 45,
  114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 40, 123,
  39, 36, 42, 39, 125, 41, 10, 45, 105, 102, 32, 123, 119, 60, 50, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 117, 32, 34, 34, 32, 45,
  114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114,
  91, 45, 49, 93, 32, 50, 44, 123, 119, 47, 50, 125, 44, 49, 44, 49,
  44, 45, 49, 32, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102, 40, 105,
  62, 61, 57, 55, 44, 105, 45, 56, 55, 44, 105, 45, 52, 56, 41, 39,
  32, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102, 40, 120, 61, 61, 48,
  44, 105, 42, 49, 54, 43, 105, 40, 120, 43, 49, 41, 44, 48, 41, 39,
  32, 45, 99, 111, 108, 117, 109, 110, 115, 91, 45, 49, 93, 32, 48, 10,
  45, 117, 32, 64, 123, 45, 49, 44, 116, 125, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 105,
  109, 103, 50, 115, 116, 114, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  82, 101, 116, 117, 114, 110, 32, 116, 104, 101, 32, 99, 111, 110, 116, 101,
  110, 116, 32, 111, 102, 32, 116, 104, 101, 32, 108, 97, 116, 101, 115, 116,
  32, 111, 102, 32, 116, 104, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 32, 97, 115, 32, 97, 32, 115, 112, 101, 99,
  105, 97, 108, 32, 71, 39, 77, 73, 67, 32, 105, 110, 112, 117, 116, 32,
  115, 116, 114, 105, 110, 103, 46, 10, 105, 109, 103, 50, 115, 116, 114, 32,
  58, 10, 45, 118, 32, 45, 10, 45, 117, 32, 34, 40, 34, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 123, 115, 125, 32, 99, 61, 36, 62, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 100, 125, 32, 122, 61, 36, 62, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 104, 125, 32, 121, 61, 36, 62,
  10, 45, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 48, 44, 36, 121,
  44, 36, 122, 44, 36, 99, 44, 49, 48, 48, 37, 44, 36, 121, 44, 36,
  122, 44, 36, 99, 10, 45, 117, 32, 64, 123, 125, 64, 45, 49, 10, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 121, 33, 61,
  104, 45, 49, 125, 32, 45, 117, 32, 64, 123, 125, 59, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 32, 64, 123, 125, 10, 45, 100, 111, 110, 101,
  10, 45, 105, 102, 32, 123, 36, 122, 33, 61, 100, 45, 49, 125, 32, 45,
  117, 32, 64, 123, 125, 47, 32, 45, 101, 110, 100, 105, 102, 10, 45, 100,
  111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 99, 33, 61, 115, 45, 49,
  125, 32, 45, 117, 32, 64, 123, 125, 94, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 100, 111, 110, 101, 10, 45, 117, 32, 64, 123, 125, 34, 41, 34,
  10, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 105, 109, 103,
  50, 116, 101, 120, 116, 32, 58, 32, 95, 108, 105, 110, 101, 95, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 82, 101, 116, 117, 114, 110, 32, 116, 101, 120, 116, 32, 99, 111, 110,
  116, 97, 105, 110, 101, 100, 32, 105, 110, 32, 97, 32, 109, 117, 108, 116,
  105, 45, 108, 105, 110, 101, 32, 105, 109, 97, 103, 101, 46, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118,
  97, 108, 117, 101, 58, 32, 39, 108, 105, 110, 101, 95, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 61, 32, 39, 46, 10, 105, 109, 103, 50, 116, 101,
  120, 116, 32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36, 123, 49, 61,
  32, 125, 34, 10, 45, 118, 32, 45, 32, 45, 45, 108, 32, 45, 115, 32,
  121, 32, 45, 115, 32, 45, 44, 48, 32, 45, 121, 32, 120, 32, 45, 105,
  102, 32, 123, 64, 35, 62, 49, 125, 32, 45, 105, 91, 49, 45, 45, 50,
  93, 32, 40, 123, 39, 34, 36, 49, 34, 39, 125, 41, 32, 45, 101, 110,
  100, 105, 102, 32, 45, 97, 32, 120, 32, 45, 117, 32, 64, 123, 48, 44,
  116, 125, 32, 45, 114, 109, 32, 45, 101, 110, 100, 108, 32, 45, 118, 32,
  43, 10, 35, 64, 103, 109, 105, 99, 32, 105, 109, 103, 56, 50, 104, 101,
  120, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101,
  114, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 56, 98, 105, 116,
  115, 45, 118, 97, 108, 117, 101, 100, 32, 118, 101, 99, 116, 111, 114, 115,
  32, 105, 110, 116, 111, 32, 116, 104, 101, 105, 114, 32, 104, 101, 120, 97,
  100, 101, 99, 105, 109, 97, 108, 32, 114, 101, 112, 114, 101, 115, 101, 110,
  116, 97, 116, 105, 111, 110, 115, 32, 40, 97, 115, 99, 105, 105, 45, 101,
  110, 99, 111, 100, 101, 100, 41, 46, 10, 105, 109, 103, 56, 50, 104, 101,
  120, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110,
  118, 101, 114, 116, 32, 56, 98, 105, 116, 115, 45, 118, 97, 108, 117, 101,
  100, 32, 118, 101, 99, 116, 111, 114, 36, 63, 32, 105, 110, 116, 111, 32,
  104, 101, 120, 97, 100, 101, 99, 105, 109, 97, 108, 32, 114, 101, 112, 114,
  101, 115, 101, 110, 116, 97, 116, 105, 111, 110, 115, 32, 40, 97, 115, 99,
  105, 105, 45, 101, 110, 99, 111, 100, 101, 100, 41, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 109, 111, 100, 32, 50, 53, 54, 32, 45, 121, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 45, 102, 91, 36, 62,
  93, 32, 39, 118, 61, 105, 110, 116, 40, 105, 41, 38, 49, 53, 59, 118,
  43, 105, 102, 40, 118, 60, 49, 48, 44, 52, 56, 44, 56, 55, 41, 39,
  10, 45, 102, 91, 36, 62, 93, 32, 39, 118, 61, 105, 110, 116, 40, 105,
  41, 62, 62, 52, 59, 118, 43, 105, 102, 40, 118, 60, 49, 48, 44, 52,
  56, 44, 56, 55, 41, 39, 10, 45, 97, 91, 36, 62, 44, 45, 49, 93,
  32, 120, 10, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 104, 101, 120, 50, 105, 109, 103, 56, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 104, 101, 120, 97, 100, 101, 99, 105,
  109, 97, 108, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 97, 116, 105,
  111, 110, 115, 32, 40, 97, 115, 99, 105, 105, 45, 101, 110, 99, 111, 100,
  101, 100, 41, 32, 105, 110, 116, 111, 32, 56, 98, 105, 116, 115, 45, 118,
  97, 108, 117, 101, 100, 32, 118, 101, 99, 116, 111, 114, 115, 46, 10, 104,
  101, 120, 50, 105, 109, 103, 56, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 104, 101, 120, 97, 100,
  101, 99, 105, 109, 97, 108, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116,
  97, 116, 105, 111, 110, 36, 63, 32, 40, 97, 115, 99, 105, 105, 45, 101,
  110, 99, 111, 100, 101, 100, 41, 32, 105, 110, 116, 111, 32, 56, 98, 105,
  116, 115, 45, 118, 97, 108, 117, 101, 100, 32, 118, 101, 99, 116, 111, 114,
  115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 10, 45, 115, 91, 45, 49, 93, 32, 120, 44, 50, 32, 45,
  102, 91, 45, 50, 44, 45, 49, 93, 32, 39, 105, 102, 40, 105, 62, 61,
  57, 55, 44, 105, 45, 56, 55, 44, 105, 45, 52, 56, 41, 39, 32, 45,
  42, 91, 45, 50, 93, 32, 49, 54, 32, 45, 43, 91, 45, 50, 44, 45,
  49, 93, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 105,
  115, 95, 51, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101,
  116, 117, 114, 110, 32, 49, 32, 105, 102, 32, 97, 108, 108, 32, 111, 102,
  32, 116, 104, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 32, 97, 114, 101, 32, 51, 100, 32, 111, 98, 106, 101, 99,
  116, 115, 44, 32, 48, 32, 111, 116, 104, 101, 114, 119, 105, 115, 101, 46,
  10, 105, 115, 95, 51, 100, 32, 58, 10, 45, 118, 32, 45, 32, 45, 117,
  32, 49, 32, 45, 108, 32, 45, 99, 104, 101, 99, 107, 51, 100, 32, 49,
  32, 45, 111, 110, 102, 97, 105, 108, 32, 45, 117, 32, 48, 32, 45, 101,
  110, 100, 108, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 32, 58, 32, 115, 116, 114,
  105, 110, 103, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116,
  117, 114, 110, 32, 49, 32, 105, 102, 32, 115, 112, 101, 99, 105, 102, 105,
  101, 100, 32, 115, 116, 114, 105, 110, 103, 32, 101, 110, 100, 115, 32, 119,
  105, 116, 104, 32, 97, 32, 39, 37, 39, 44, 32, 48, 32, 111, 116, 104,
  101, 114, 119, 105, 115, 101, 46, 10, 105, 115, 95, 112, 101, 114, 99, 101,
  110, 116, 32, 58, 10, 45, 118, 32, 45, 32, 45, 117, 32, 123, 97, 114,
  103, 40, 45, 49, 44, 123, 39, 34, 36, 49, 34, 39, 125, 41, 61, 61,
  51, 55, 125, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  105, 115, 95, 119, 105, 110, 100, 111, 119, 115, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 82, 101, 116, 117, 114, 110, 32, 49, 32, 105, 102, 32,
  99, 117, 114, 114, 101, 110, 116, 32, 99, 111, 109, 112, 117, 116, 101, 114,
  32, 79, 83, 32, 105, 115, 32, 87, 105, 110, 100, 111, 119, 115, 44, 32,
  48, 32, 111, 116, 104, 101, 114, 119, 105, 115, 101, 46, 10, 105, 115, 95,
  119, 105, 110, 100, 111, 119, 115, 32, 58, 10, 45, 118, 32, 45, 32, 45,
  117, 32, 123, 110, 97, 114, 103, 40, 36, 79, 83, 41, 61, 61, 49, 34,
  32, 38, 38, 32, 34, 110, 97, 114, 103, 40, 36, 87, 73, 78, 68, 73,
  82, 41, 61, 61, 49, 125, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109,
  105, 99, 32, 109, 97, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  82, 101, 116, 117, 114, 110, 32, 116, 104, 101, 32, 77, 65, 68, 32, 40,
  77, 97, 120, 105, 109, 117, 109, 32, 65, 98, 115, 111, 108, 117, 116, 101,
  32, 68, 101, 118, 105, 97, 116, 105, 111, 110, 41, 32, 111, 102, 32, 116,
  104, 101, 32, 108, 97, 115, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 84, 104, 101, 32, 77, 65, 68, 32, 105, 115, 32, 100, 101, 102, 105,
  110, 101, 100, 32, 97, 115, 32, 77, 65, 68, 32, 61, 32, 109, 101, 100,
  95, 105, 124, 120, 95, 105, 45, 109, 101, 100, 95, 106, 40, 120, 95, 106,
  41, 124, 10, 109, 97, 100, 32, 58, 10, 45, 118, 32, 45, 32, 45, 45,
  45, 91, 45, 49, 93, 32, 64, 123, 45, 109, 101, 100, 91, 45, 49, 93,
  125, 32, 45, 97, 98, 115, 91, 45, 49, 93, 32, 45, 109, 101, 100, 91,
  45, 49, 93, 32, 45, 117, 32, 123, 49, 46, 52, 56, 50, 54, 42, 64,
  123, 125, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 109, 97, 120, 95, 119, 10, 35, 64,
  103, 109, 105, 99, 32, 58, 32, 82, 101, 116, 117, 114, 110, 32, 116, 104,
  101, 32, 109, 97, 120, 105, 109, 97, 108, 32, 119, 105, 100, 116, 104, 32,
  98, 101, 116, 119, 101, 101, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 46, 10, 109, 97, 120, 95, 119, 32, 58,
  10, 45, 118, 32, 45, 32, 45, 117, 32, 123, 97, 114, 103, 40, 49, 44,
  64, 123, 45, 95, 109, 97, 120, 95, 119, 104, 100, 115, 92, 32, 52, 125,
  41, 125, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 109,
  97, 120, 95, 104, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101,
  116, 117, 114, 110, 32, 116, 104, 101, 32, 109, 97, 120, 105, 109, 97, 108,
  32, 104, 101, 105, 103, 104, 116, 32, 98, 101, 116, 119, 101, 101, 110, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 109, 97, 120, 95, 104, 32, 58, 10, 45, 118, 32, 45, 32, 45, 117,
  32, 123, 97, 114, 103, 40, 50, 44, 64, 123, 45, 95, 109, 97, 120, 95,
  119, 104, 100, 115, 92, 32, 52, 125, 41, 125, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 109, 97, 120, 95, 100, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 82, 101, 116, 117, 114, 110, 32, 116, 104, 101,
  32, 109, 97, 120, 105, 109, 97, 108, 32, 100, 101, 112, 116, 104, 32, 98,
  101, 116, 119, 101, 101, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 46, 10, 109, 97, 120, 95, 100, 32, 58, 10,
  45, 118, 32, 45, 32, 45, 117, 32, 123, 97, 114, 103, 40, 51, 44, 64,
  123, 45, 95, 109, 97, 120, 95, 119, 104, 100, 115, 92, 32, 52, 125, 41,
  125, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 109, 97,
  120, 95, 115, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116,
  117, 114, 110, 32, 116, 104, 101, 32, 109, 97, 120, 105, 109, 97, 108, 32,
  115, 112, 101, 99, 116, 114, 117, 109, 32, 98, 101, 116, 119, 101, 101, 110,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 109, 97, 120, 95, 115, 32, 58, 10, 45, 118, 32, 45, 32, 45,
  117, 32, 123, 97, 114, 103, 40, 52, 44, 64, 123, 45, 95, 109, 97, 120,
  95, 119, 104, 100, 115, 92, 32, 52, 125, 41, 125, 32, 45, 118, 32, 43,
  10, 35, 64, 103, 109, 105, 99, 32, 109, 97, 120, 95, 119, 104, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116, 117, 114, 110, 32, 116,
  104, 101, 32, 109, 97, 120, 105, 109, 97, 108, 32, 119, 120, 104, 32, 115,
  105, 122, 101, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  105, 109, 97, 103, 101, 115, 46, 10, 109, 97, 120, 95, 119, 104, 32, 58,
  10, 45, 118, 32, 45, 32, 45, 95, 109, 97, 120, 95, 119, 104, 100, 115,
  32, 50, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 109,
  97, 120, 95, 119, 104, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  82, 101, 116, 117, 114, 110, 32, 116, 104, 101, 32, 109, 97, 120, 105, 109,
  97, 108, 32, 119, 120, 104, 120, 100, 32, 115, 105, 122, 101, 32, 111, 102,
  32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115,
  46, 10, 109, 97, 120, 95, 119, 104, 100, 32, 58, 10, 45, 118, 32, 45,
  32, 45, 95, 109, 97, 120, 95, 119, 104, 100, 115, 32, 51, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 109, 97, 120, 95, 119, 104,
  100, 115, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116, 117,
  114, 110, 32, 116, 104, 101, 32, 109, 97, 120, 105, 109, 97, 108, 32, 119,
  120, 104, 120, 100, 120, 115, 32, 115, 105, 122, 101, 32, 111, 102, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  109, 97, 120, 95, 119, 104, 100, 115, 32, 58, 10, 45, 118, 32, 45, 32,
  45, 95, 109, 97, 120, 95, 119, 104, 100, 115, 32, 52, 32, 45, 118, 32,
  43, 10, 95, 109, 97, 120, 95, 119, 104, 100, 115, 32, 58, 10, 119, 61,
  48, 32, 104, 61, 48, 32, 100, 61, 48, 32, 115, 61, 48, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 10, 119, 61, 123, 109, 97, 120, 40,
  36, 119, 44, 119, 41, 125, 10, 104, 61, 123, 109, 97, 120, 40, 36, 104,
  44, 104, 41, 125, 10, 100, 61, 123, 109, 97, 120, 40, 36, 100, 44, 100,
  41, 125, 10, 115, 61, 123, 109, 97, 120, 40, 36, 115, 44, 115, 41, 125,
  10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101,
  10, 45, 105, 102, 32, 123, 36, 49, 62, 61, 52, 125, 32, 45, 117, 32,
  36, 119, 44, 36, 104, 44, 36, 100, 44, 36, 115, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 61, 61, 51, 125, 32, 45, 117, 32, 36, 119, 44,
  36, 104, 44, 36, 100, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61,
  61, 50, 125, 32, 45, 117, 32, 36, 119, 44, 36, 104, 10, 45, 101, 108,
  115, 101, 32, 45, 117, 32, 36, 119, 10, 45, 101, 110, 100, 105, 102, 10,
  35, 64, 103, 109, 105, 99, 32, 109, 101, 100, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 82, 101, 116, 117, 114, 110, 32, 116, 104, 101, 32, 109,
  101, 100, 105, 97, 110, 32, 118, 97, 108, 117, 101, 32, 111, 102, 32, 116,
  104, 101, 32, 108, 97, 115, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 46, 10, 109, 101, 100, 32, 58, 10, 45, 118,
  32, 45, 32, 45, 45, 115, 111, 114, 116, 91, 45, 49, 93, 32, 45, 117,
  32, 64, 123, 45, 49, 44, 123, 119, 42, 104, 42, 100, 42, 115, 47, 50,
  125, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 99, 111, 108, 111, 114, 95, 109, 101, 100,
  10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116, 117, 114, 110,
  32, 116, 104, 101, 32, 109, 101, 100, 105, 97, 110, 32, 99, 111, 108, 111,
  114, 32, 118, 97, 108, 117, 101, 32, 111, 102, 32, 116, 104, 101, 32, 108,
  97, 115, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 46, 10, 99, 111, 108, 111, 114, 95, 109, 101, 100, 32, 58, 10,
  45, 118, 32, 45, 32, 45, 117, 32, 34, 34, 32, 115, 61, 34, 34, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 115, 125, 32, 45, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 36, 62, 32, 45, 117,
  32, 64, 123, 125, 36, 115, 64, 123, 45, 109, 101, 100, 91, 45, 49, 93,
  125, 32, 115, 61, 44, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32,
  109, 105, 110, 95, 119, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82,
  101, 116, 117, 114, 110, 32, 116, 104, 101, 32, 109, 105, 110, 105, 109, 97,
  108, 32, 119, 105, 100, 116, 104, 32, 98, 101, 116, 119, 101, 101, 110, 32,
  115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 109, 105, 110, 95, 119, 32, 58, 10, 45, 118, 32, 45, 32, 45, 117,
  32, 123, 97, 114, 103, 40, 49, 44, 64, 123, 45, 95, 109, 105, 110, 95,
  119, 104, 100, 115, 92, 32, 52, 125, 41, 125, 32, 45, 118, 32, 43, 10,
  35, 64, 103, 109, 105, 99, 32, 109, 105, 110, 95, 104, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 82, 101, 116, 117, 114, 110, 32, 116, 104, 101,
  32, 109, 105, 110, 105, 109, 97, 108, 32, 104, 101, 105, 103, 104, 116, 32,
  98, 101, 116, 119, 101, 101, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 115, 46, 10, 109, 105, 110, 95, 104, 32, 58,
  10, 45, 118, 32, 45, 32, 45, 117, 32, 123, 97, 114, 103, 40, 50, 44,
  64, 123, 45, 95, 109, 105, 110, 95, 119, 104, 100, 115, 92, 32, 52, 125,
  41, 125, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 109,
  105, 110, 95, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101,
  116, 117, 114, 110, 32, 116, 104, 101, 32, 109, 105, 110, 105, 109, 97, 108,
  32, 100, 101, 112, 116, 104, 32, 98, 101, 116, 119, 101, 101, 110, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  109, 105, 110, 95, 100, 32, 58, 10, 45, 118, 32, 45, 32, 45, 117, 32,
  123, 97, 114, 103, 40, 51, 44, 64, 123, 45, 95, 109, 105, 110, 95, 119,
  104, 100, 115, 92, 32, 52, 125, 41, 125, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 109, 105, 110, 95, 115, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 82, 101, 116, 117, 114, 110, 32, 116, 104, 101, 32,
  109, 105, 110, 105, 109, 97, 108, 32, 115, 32, 115, 105, 122, 101, 32, 111,
  102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 109, 105, 110, 95, 115, 32, 58, 10, 45, 118, 32, 45, 32,
  45, 95, 109, 105, 110, 95, 115, 32, 64, 123, 45, 95, 109, 105, 110, 95,
  119, 104, 100, 115, 92, 32, 52, 125, 32, 45, 118, 32, 43, 10, 95, 109,
  105, 110, 95, 115, 32, 58, 10, 45, 117, 32, 36, 52, 10, 35, 64, 103,
  109, 105, 99, 32, 109, 105, 110, 95, 119, 104, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 82, 101, 116, 117, 114, 110, 32, 116, 104, 101, 32, 109,
  105, 110, 105, 109, 97, 108, 32, 119, 120, 104, 32, 115, 105, 122, 101, 32,
  111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103,
  101, 115, 46, 10, 109, 105, 110, 95, 119, 104, 32, 58, 10, 45, 118, 32,
  45, 32, 45, 95, 109, 105, 110, 95, 119, 104, 100, 115, 32, 50, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 109, 105, 110, 95, 119,
  104, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116, 117,
  114, 110, 32, 116, 104, 101, 32, 109, 105, 110, 105, 109, 97, 108, 32, 119,
  120, 104, 120, 100, 32, 115, 105, 122, 101, 32, 111, 102, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 109, 105,
  110, 95, 119, 104, 100, 32, 58, 10, 45, 118, 32, 45, 32, 45, 95, 109,
  105, 110, 95, 119, 104, 100, 115, 32, 51, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 109, 105, 110, 95, 119, 104, 100, 115, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116, 117, 114, 110, 32, 116,
  104, 101, 32, 109, 105, 110, 105, 109, 97, 108, 32, 119, 120, 104, 120, 100,
  120, 115, 32, 115, 105, 122, 101, 32, 111, 102, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 115, 46, 10, 109, 105, 110, 95,
  119, 104, 100, 115, 32, 58, 10, 45, 118, 32, 45, 32, 45, 95, 109, 105,
  110, 95, 119, 104, 100, 115, 32, 52, 32, 45, 118, 32, 43, 10, 95, 109,
  105, 110, 95, 119, 104, 100, 115, 32, 58, 10, 119, 61, 123, 119, 125, 32,
  104, 61, 123, 104, 125, 32, 100, 61, 123, 100, 125, 32, 115, 61, 123, 115,
  125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 119, 61, 123,
  109, 105, 110, 40, 36, 119, 44, 119, 41, 125, 10, 104, 61, 123, 109, 105,
  110, 40, 36, 104, 44, 104, 41, 125, 10, 100, 61, 123, 109, 105, 110, 40,
  36, 100, 44, 100, 41, 125, 10, 115, 61, 123, 109, 105, 110, 40, 36, 115,
  44, 115, 41, 125, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45,
  100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 49, 62, 61, 52, 125,
  32, 45, 117, 32, 36, 119, 44, 36, 104, 44, 36, 100, 44, 36, 115, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 51, 125, 32, 45, 117,
  32, 36, 119, 44, 36, 104, 44, 36, 100, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 49, 61, 61, 50, 125, 32, 45, 117, 32, 36, 119, 44, 36, 104,
  10, 45, 101, 108, 115, 101, 32, 45, 117, 32, 36, 119, 10, 45, 101, 110,
  100, 105, 102, 10, 35, 64, 103, 109, 105, 99, 32, 110, 111, 114, 109, 97,
  108, 105, 122, 101, 95, 102, 105, 108, 101, 110, 97, 109, 101, 32, 58, 32,
  102, 105, 108, 101, 110, 97, 109, 101, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 82, 101, 116, 117, 114, 110, 32, 97, 32, 34, 110, 111, 114, 109,
  97, 108, 105, 122, 101, 100, 34, 32, 118, 101, 114, 115, 105, 111, 110, 32,
  111, 102, 32, 116, 104, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100,
  32, 102, 105, 108, 101, 110, 97, 109, 101, 44, 32, 119, 105, 116, 104, 111,
  117, 116, 32, 115, 112, 97, 99, 101, 115, 32, 97, 110, 100, 32, 99, 97,
  112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 115, 46, 10, 110,
  111, 114, 109, 97, 108, 105, 122, 101, 95, 102, 105, 108, 101, 110, 97, 109,
  101, 32, 58, 10, 45, 118, 32, 45, 32, 40, 123, 39, 34, 36, 49, 34,
  39, 125, 41, 32, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102, 40, 105,
  62, 61, 54, 53, 38, 38, 105, 60, 61, 57, 48, 44, 105, 43, 51, 50,
  44, 105, 102, 40, 105, 61, 61, 51, 50, 44, 57, 53, 44, 105, 41, 41,
  39, 32, 45, 117, 32, 64, 123, 45, 49, 44, 116, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 111, 99, 116, 32, 58, 32, 111, 99, 116, 97, 108, 95, 105, 110, 116,
  49, 44, 46, 46, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 80,
  114, 105, 110, 116, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 111,
  99, 116, 97, 108, 32, 105, 110, 116, 101, 103, 101, 114, 115, 32, 105, 110,
  116, 111, 32, 116, 104, 101, 105, 114, 32, 98, 105, 110, 97, 114, 121, 44,
  32, 100, 101, 99, 105, 109, 97, 108, 44, 32, 104, 101, 120, 97, 100, 101,
  99, 105, 109, 97, 108, 32, 97, 110, 100, 32, 115, 116, 114, 105, 110, 103,
  32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 97, 116, 105, 111, 110, 115,
  46, 10, 111, 99, 116, 32, 58, 10, 45, 118, 32, 45, 32, 100, 101, 99,
  61, 64, 123, 45, 111, 99, 116, 50, 100, 101, 99, 92, 32, 36, 123, 94,
  48, 125, 125, 32, 45, 118, 32, 43, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 111, 99, 116, 97, 108, 32,
  105, 110, 116, 101, 103, 101, 114, 34, 64, 123, 45, 97, 114, 103, 92, 32,
  49, 43, 40, 36, 35, 62, 49, 41, 44, 34, 34, 44, 115, 125, 34, 32,
  39, 36, 123, 94, 48, 125, 39, 32, 116, 111, 32, 98, 105, 110, 97, 114,
  121, 32, 39, 34, 64, 123, 45, 100, 101, 99, 50, 98, 105, 110, 92, 32,
  36, 100, 101, 99, 125, 34, 39, 44, 32, 100, 101, 99, 105, 109, 97, 108,
  32, 39, 34, 36, 100, 101, 99, 34, 39, 44, 10, 104, 101, 120, 97, 100,
  101, 99, 105, 109, 97, 108, 32, 39, 34, 64, 123, 45, 100, 101, 99, 50,
  104, 101, 120, 92, 32, 36, 100, 101, 99, 125, 34, 39, 32, 97, 110, 100,
  32, 115, 116, 114, 105, 110, 103, 32, 39, 34, 64, 123, 45, 100, 101, 99,
  50, 115, 116, 114, 92, 32, 36, 100, 101, 99, 125, 34, 39, 46, 34, 10,
  35, 64, 103, 109, 105, 99, 32, 111, 99, 116, 50, 100, 101, 99, 32, 58,
  32, 111, 99, 116, 97, 108, 95, 105, 110, 116, 49, 44, 46, 46, 46, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 67, 111, 110, 118, 101, 114, 116,
  32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 111, 99, 116, 97, 108,
  32, 105, 110, 116, 101, 103, 101, 114, 115, 32, 105, 110, 116, 111, 32, 116,
  104, 101, 105, 114, 32, 100, 101, 99, 105, 109, 97, 108, 32, 114, 101, 112,
  114, 101, 115, 101, 110, 116, 97, 116, 105, 111, 110, 115, 46, 10, 111, 99,
  116, 50, 100, 101, 99, 32, 58, 10, 45, 118, 32, 45, 32, 114, 101, 115,
  61, 64, 123, 45, 95, 36, 48, 92, 32, 36, 49, 125, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 36, 35, 45, 49, 125, 32, 114, 101, 115, 61,
  36, 114, 101, 115, 44, 64, 123, 45, 95, 36, 48, 92, 32, 64, 123, 45,
  97, 114, 103, 92, 32, 36, 62, 43, 50, 44, 36, 123, 94, 48, 125, 125,
  125, 32, 45, 100, 111, 110, 101, 32, 45, 117, 32, 36, 114, 101, 115, 32,
  45, 118, 32, 43, 10, 95, 111, 99, 116, 50, 100, 101, 99, 32, 58, 10,
  40, 123, 39, 64, 123, 45, 115, 116, 114, 117, 110, 99, 97, 115, 101, 92,
  32, 36, 49, 125, 39, 125, 41, 10, 105, 115, 95, 110, 101, 103, 97, 116,
  105, 118, 101, 61, 48, 10, 45, 105, 102, 32, 123, 64, 123, 45, 49, 44,
  48, 125, 61, 61, 52, 53, 125, 32, 45, 122, 91, 45, 49, 93, 32, 49,
  44, 49, 48, 48, 37, 32, 105, 115, 95, 110, 101, 103, 97, 116, 105, 118,
  101, 61, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 102, 91, 45, 49,
  93, 32, 34, 105, 102, 40, 105, 62, 61, 52, 56, 32, 38, 38, 32, 105,
  60, 61, 53, 53, 44, 40, 105, 45, 52, 56, 41, 42, 56, 94, 40, 119,
  45, 49, 45, 120, 41, 44, 110, 97, 110, 41, 34, 10, 45, 117, 32, 123,
  105, 102, 40, 36, 105, 115, 95, 110, 101, 103, 97, 116, 105, 118, 101, 44,
  45, 49, 44, 49, 41, 42, 64, 123, 45, 49, 44, 43, 125, 125, 10, 45,
  114, 109, 91, 45, 49, 93, 10, 35, 64, 103, 109, 105, 99, 32, 112, 97,
  100, 105, 110, 116, 32, 58, 32, 110, 117, 109, 98, 101, 114, 44, 95, 115,
  105, 122, 101, 62, 48, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82,
  101, 116, 117, 114, 110, 32, 97, 32, 105, 110, 116, 101, 103, 101, 114, 32,
  119, 105, 116, 104, 32, 39, 115, 105, 122, 101, 39, 32, 100, 105, 103, 105,
  116, 115, 32, 40, 101, 118, 101, 110, 116, 117, 97, 108, 108, 121, 32, 108,
  101, 102, 116, 45, 112, 97, 100, 100, 101, 100, 32, 119, 105, 116, 104, 32,
  39, 48, 39, 41, 46, 10, 112, 97, 100, 105, 110, 116, 32, 58, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 50, 61, 52, 125, 10, 45, 118, 32, 45,
  32, 45, 117, 32, 34, 34, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36,
  50, 32, 45, 117, 32, 64, 123, 125, 123, 105, 110, 116, 40, 36, 49, 47,
  49, 48, 94, 36, 60, 41, 37, 49, 48, 125, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 112, 97, 116,
  104, 95, 103, 105, 109, 112, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  82, 101, 116, 117, 114, 110, 32, 97, 32, 112, 97, 116, 104, 32, 116, 111,
  32, 115, 116, 111, 114, 101, 32, 71, 73, 77, 80, 32, 99, 111, 110, 102,
  105, 103, 117, 114, 97, 116, 105, 111, 110, 32, 102, 105, 108, 101, 115, 32,
  102, 111, 114, 32, 111, 110, 101, 32, 117, 115, 101, 114, 32, 40, 119, 104,
  111, 115, 101, 32, 118, 97, 108, 117, 101, 32, 105, 115, 32, 79, 68, 45,
  100, 101, 112, 101, 110, 100, 101, 110, 116, 41, 46, 10, 112, 97, 116, 104,
  95, 103, 105, 109, 112, 32, 58, 10, 45, 105, 102, 32, 123, 110, 97, 114,
  103, 40, 123, 39, 36, 123, 71, 73, 77, 80, 50, 95, 68, 73, 82, 69,
  67, 84, 79, 82, 89, 125, 39, 125, 41, 125, 32, 45, 117, 32, 36, 123,
  71, 73, 77, 80, 50, 95, 68, 73, 82, 69, 67, 84, 79, 82, 89, 125,
  32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 110, 97, 114, 103, 40, 123, 39, 36, 123, 85, 83,
  69, 82, 80, 82, 79, 70, 73, 76, 69, 125, 39, 125, 41, 125, 32, 45,
  117, 32, 36, 123, 85, 83, 69, 82, 80, 82, 79, 70, 73, 76, 69, 125,
  10, 45, 101, 108, 105, 102, 32, 123, 110, 97, 114, 103, 40, 123, 39, 36,
  123, 72, 79, 77, 69, 125, 39, 125, 41, 125, 32, 45, 117, 32, 36, 123,
  72, 79, 77, 69, 125, 10, 45, 101, 108, 115, 101, 32, 45, 117, 32, 34,
  34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 64, 123, 125,
  47, 46, 103, 105, 109, 112, 45, 50, 46, 56, 47, 112, 108, 117, 103, 105,
  110, 114, 99, 32, 45, 117, 32, 64, 123, 125, 47, 46, 103, 105, 109, 112,
  45, 50, 46, 56, 10, 45, 101, 108, 105, 102, 32, 64, 123, 125, 47, 46,
  103, 105, 109, 112, 45, 50, 46, 54, 47, 112, 108, 117, 103, 105, 110, 114,
  99, 32, 45, 117, 32, 64, 123, 125, 47, 46, 103, 105, 109, 112, 45, 50,
  46, 54, 10, 45, 101, 108, 115, 101, 32, 45, 117, 32, 64, 123, 45, 112,
  97, 116, 104, 95, 116, 109, 112, 125, 10, 45, 101, 110, 100, 105, 102, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 112, 97, 116, 104,
  95, 116, 109, 112, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101,
  116, 117, 114, 110, 32, 97, 32, 112, 97, 116, 104, 32, 116, 111, 32, 115,
  116, 111, 114, 101, 32, 116, 101, 109, 112, 111, 114, 97, 114, 121, 32, 102,
  105, 108, 101, 115, 32, 40, 119, 104, 111, 115, 101, 32, 118, 97, 108, 117,
  101, 32, 105, 115, 32, 79, 83, 45, 100, 101, 112, 101, 110, 100, 101, 110,
  116, 41, 46, 10, 112, 97, 116, 104, 95, 116, 109, 112, 32, 58, 10, 45,
  118, 32, 45, 32, 45, 117, 32, 34, 34, 10, 45, 105, 102, 32, 123, 110,
  97, 114, 103, 40, 123, 39, 36, 123, 84, 77, 80, 125, 39, 125, 41, 125,
  32, 45, 117, 32, 36, 123, 84, 77, 80, 125, 10, 45, 101, 108, 105, 102,
  32, 123, 110, 97, 114, 103, 40, 123, 39, 36, 123, 84, 69, 77, 80, 125,
  39, 125, 41, 125, 32, 45, 117, 32, 36, 123, 84, 69, 77, 80, 125, 10,
  45, 101, 108, 105, 102, 32, 123, 110, 97, 114, 103, 40, 123, 39, 36, 123,
  84, 77, 80, 68, 73, 82, 125, 39, 125, 41, 125, 32, 45, 117, 32, 36,
  123, 84, 77, 80, 68, 73, 82, 125, 10, 45, 101, 108, 105, 102, 32, 123,
  110, 97, 114, 103, 40, 123, 39, 36, 123, 72, 79, 77, 69, 125, 39, 125,
  41, 125, 32, 45, 117, 32, 34, 47, 116, 109, 112, 34, 10, 45, 101, 108,
  115, 101, 32, 45, 117, 32, 34, 34, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 112, 97, 116, 104,
  95, 117, 115, 101, 114, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82,
  101, 116, 117, 114, 110, 32, 97, 32, 112, 97, 116, 104, 32, 116, 111, 32,
  115, 116, 111, 114, 101, 32, 112, 101, 114, 115, 105, 115, 116, 101, 110, 116,
  32, 99, 111, 110, 102, 105, 103, 117, 114, 97, 116, 105, 111, 110, 32, 102,
  105, 108, 101, 115, 32, 102, 111, 114, 32, 111, 110, 101, 32, 117, 115, 101,
  114, 32, 40, 119, 104, 111, 115, 101, 32, 118, 97, 108, 117, 101, 32, 105,
  115, 32, 79, 83, 45, 100, 101, 112, 101, 110, 100, 101, 110, 116, 41, 46,
  10, 112, 97, 116, 104, 95, 117, 115, 101, 114, 32, 58, 10, 45, 118, 32,
  45, 32, 45, 117, 32, 34, 34, 10, 45, 105, 102, 32, 123, 110, 97, 114,
  103, 40, 123, 39, 36, 123, 65, 80, 80, 68, 65, 84, 65, 125, 39, 125,
  41, 125, 32, 45, 117, 32, 36, 123, 65, 80, 80, 68, 65, 84, 65, 125,
  10, 45, 101, 108, 105, 102, 32, 123, 110, 97, 114, 103, 40, 123, 39, 36,
  123, 72, 79, 77, 69, 125, 39, 125, 41, 125, 32, 45, 117, 32, 36, 123,
  72, 79, 77, 69, 125, 10, 45, 101, 108, 115, 101, 32, 45, 117, 32, 34,
  34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 35, 64,
  103, 109, 105, 99, 32, 113, 117, 111, 116, 101, 32, 58, 32, 115, 116, 114,
  105, 110, 103, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116,
  117, 114, 110, 32, 97, 32, 34, 113, 117, 111, 116, 105, 102, 105, 101, 100,
  34, 32, 118, 101, 114, 115, 105, 111, 110, 32, 111, 102, 32, 116, 104, 101,
  32, 115, 116, 114, 105, 110, 103, 46, 10, 113, 117, 111, 116, 101, 32, 58,
  10, 45, 118, 32, 45, 32, 45, 117, 32, 34, 36, 42, 34, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 114, 101, 103, 105, 111, 110,
  95, 102, 101, 97, 116, 117, 114, 101, 32, 58, 32, 114, 101, 103, 105, 111,
  110, 95, 108, 97, 98, 101, 108, 44, 102, 101, 97, 116, 117, 114, 101, 44,
  95, 100, 101, 102, 97, 117, 108, 116, 95, 118, 97, 108, 117, 101, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116, 117, 114, 110, 32, 102,
  101, 97, 116, 117, 114, 101, 32, 102, 111, 114, 32, 97, 32, 115, 112, 101,
  99, 105, 102, 105, 101, 100, 32, 114, 101, 103, 105, 111, 110, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 84, 104, 105, 115, 32, 102, 117, 110,
  99, 116, 105, 111, 110, 32, 114, 101, 113, 117, 105, 114, 101, 115, 32, 116,
  119, 111, 32, 105, 109, 97, 103, 101, 115, 32, 91, 105, 109, 103, 44, 114,
  101, 103, 105, 111, 110, 95, 108, 97, 98, 101, 108, 93, 32, 105, 110, 32,
  116, 104, 101, 32, 115, 101, 108, 101, 99, 116, 105, 111, 110, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 65, 114, 103, 117, 109, 101, 110, 116,
  32, 39, 102, 101, 97, 116, 117, 114, 101, 39, 32, 105, 115, 32, 97, 32,
  115, 116, 114, 105, 110, 103, 32, 116, 104, 97, 116, 32, 99, 111, 114, 114,
  101, 115, 112, 111, 110, 100, 115, 32, 116, 111, 32, 116, 104, 101, 32, 119,
  97, 121, 32, 116, 104, 101, 32, 102, 101, 97, 116, 117, 114, 101, 32, 119,
  111, 117, 108, 100, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 98, 101,
  32, 97, 115, 107, 101, 100, 32, 102, 111, 114, 32, 116, 104, 101, 32, 101,
  110, 116, 105, 114, 101, 32, 105, 109, 97, 103, 101, 46, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 58, 32, 39, 100, 101, 102, 97, 117, 108, 116, 95, 118, 97,
  108, 117, 101, 61, 48, 39, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 45, 108,
  117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 113, 117, 97, 110, 116, 105,
  122, 101, 91, 45, 49, 93, 32, 50, 32, 45, 108, 97, 98, 101, 108, 91,
  45, 49, 93, 32, 48, 44, 49, 32, 109, 101, 97, 110, 61, 64, 123, 34,
  45, 114, 101, 103, 105, 111, 110, 95, 102, 101, 97, 116, 117, 114, 101, 91,
  48, 44, 49, 93, 32, 49, 48, 44, 92, 34, 123, 105, 97, 125, 92, 34,
  34, 125, 32, 115, 117, 109, 61, 64, 123, 34, 45, 114, 101, 103, 105, 111,
  110, 95, 102, 101, 97, 116, 117, 114, 101, 91, 48, 44, 49, 93, 32, 49,
  48, 44, 92, 34, 64, 123, 45, 49, 44, 43, 125, 92, 34, 34, 125, 10,
  114, 101, 103, 105, 111, 110, 95, 102, 101, 97, 116, 117, 114, 101, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 34, 36, 123, 51, 61, 48, 125, 34, 10,
  45, 118, 32, 45, 10, 115, 61, 64, 123, 45, 50, 44, 115, 125, 32, 45,
  45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 32,
  45, 61, 61, 91, 45, 49, 93, 32, 36, 49, 32, 45, 94, 91, 45, 49,
  93, 32, 45, 49, 32, 45, 45, 91, 45, 49, 93, 32, 49, 32, 45, 114,
  91, 45, 49, 93, 32, 91, 45, 51, 93, 32, 45, 43, 91, 45, 49, 93,
  32, 91, 45, 51, 93, 10, 45, 108, 91, 45, 49, 93, 10, 45, 115, 91,
  45, 49, 93, 32, 45, 44, 105, 110, 102, 32, 45, 97, 32, 121, 10, 45,
  105, 102, 32, 64, 35, 32, 45, 114, 91, 45, 49, 93, 32, 49, 44, 123,
  104, 47, 36, 115, 125, 44, 49, 44, 36, 115, 44, 45, 49, 32, 45, 117,
  32, 36, 50, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 115,
  101, 32, 45, 117, 32, 36, 51, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 108, 10, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99,
  32, 114, 101, 115, 101, 116, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32,
  82, 101, 115, 101, 116, 32, 103, 108, 111, 98, 97, 108, 32, 112, 97, 114,
  97, 109, 101, 116, 101, 114, 115, 32, 111, 102, 32, 116, 104, 101, 32, 105,
  110, 116, 101, 114, 112, 114, 101, 116, 101, 114, 32, 101, 110, 118, 105, 114,
  111, 110, 109, 101, 110, 116, 46, 10, 114, 101, 115, 101, 116, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 115, 101, 116, 32, 103,
  108, 111, 98, 97, 108, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115,
  32, 111, 102, 32, 116, 104, 101, 32, 105, 110, 116, 101, 114, 112, 114, 101,
  116, 101, 114, 32, 101, 110, 118, 105, 114, 111, 110, 109, 101, 110, 116, 46,
  34, 10, 45, 118, 32, 45, 49, 32, 45, 100, 98, 51, 100, 32, 45, 98,
  51, 100, 32, 45, 109, 51, 100, 32, 45, 109, 100, 51, 100, 32, 45, 102,
  51, 100, 32, 45, 108, 51, 100, 32, 45, 115, 108, 51, 100, 32, 45, 115,
  115, 51, 100, 32, 45, 118, 10, 35, 64, 103, 109, 105, 99, 32, 82, 71,
  66, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116, 117, 114,
  110, 32, 97, 32, 114, 97, 110, 100, 111, 109, 32, 105, 110, 116, 45, 118,
  97, 108, 117, 101, 100, 32, 82, 71, 66, 32, 99, 111, 108, 111, 114, 46,
  10, 82, 71, 66, 32, 58, 10, 45, 118, 32, 45, 32, 45, 117, 32, 123,
  114, 111, 117, 110, 100, 40, 63, 40, 50, 53, 53, 41, 41, 125, 44, 123,
  114, 111, 117, 110, 100, 40, 63, 40, 50, 53, 53, 41, 41, 125, 44, 123,
  114, 111, 117, 110, 100, 40, 63, 40, 50, 53, 53, 41, 41, 125, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 82, 71, 66, 65, 10,
  35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116, 117, 114, 110, 32,
  97, 32, 114, 97, 110, 100, 111, 109, 32, 105, 110, 116, 45, 118, 97, 108,
  117, 101, 100, 32, 82, 71, 66, 65, 32, 99, 111, 108, 111, 114, 46, 10,
  82, 71, 66, 65, 32, 58, 10, 45, 118, 32, 45, 32, 45, 117, 32, 123,
  114, 111, 117, 110, 100, 40, 63, 40, 50, 53, 53, 41, 41, 125, 44, 123,
  114, 111, 117, 110, 100, 40, 63, 40, 50, 53, 53, 41, 41, 125, 44, 123,
  114, 111, 117, 110, 100, 40, 63, 40, 50, 53, 53, 41, 41, 125, 44, 123,
  114, 111, 117, 110, 100, 40, 63, 40, 50, 53, 53, 41, 41, 125, 32, 45,
  118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 116, 114, 32, 58,
  32, 115, 116, 114, 105, 110, 103, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 80, 114, 105, 110, 116, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100,
  32, 115, 116, 114, 105, 110, 103, 32, 105, 110, 116, 111, 32, 105, 116, 115,
  32, 98, 105, 110, 97, 114, 121, 44, 32, 111, 99, 116, 97, 108, 44, 32,
  100, 101, 99, 105, 109, 97, 108, 32, 97, 110, 100, 32, 104, 101, 120, 97,
  100, 101, 99, 105, 109, 97, 108, 32, 114, 101, 112, 114, 101, 115, 101, 110,
  116, 97, 116, 105, 111, 110, 115, 46, 10, 115, 116, 114, 32, 58, 32, 45,
  115, 107, 105, 112, 32, 36, 49, 10, 45, 118, 32, 45, 32, 100, 101, 99,
  61, 123, 39, 36, 42, 39, 125, 32, 45, 118, 32, 43, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 115, 116,
  114, 105, 110, 103, 32, 39, 36, 42, 39, 32, 116, 111, 32, 98, 105, 110,
  97, 114, 121, 32, 39, 34, 64, 123, 45, 100, 101, 99, 50, 98, 105, 110,
  92, 32, 36, 100, 101, 99, 125, 34, 39, 44, 32, 111, 99, 116, 97, 108,
  32, 39, 34, 64, 123, 45, 100, 101, 99, 50, 111, 99, 116, 92, 32, 36,
  100, 101, 99, 125, 34, 39, 44, 32, 100, 101, 99, 105, 109, 97, 108, 32,
  39, 34, 36, 100, 101, 99, 34, 39, 32, 97, 110, 100, 10, 104, 101, 120,
  97, 100, 101, 99, 105, 109, 97, 108, 32, 39, 34, 64, 123, 45, 100, 101,
  99, 50, 104, 101, 120, 92, 32, 36, 100, 101, 99, 125, 34, 39, 46, 34,
  10, 35, 64, 103, 109, 105, 99, 32, 115, 116, 114, 50, 104, 101, 120, 32,
  58, 32, 115, 116, 114, 105, 110, 103, 10, 35, 64, 103, 109, 105, 99, 32,
  58, 32, 67, 111, 110, 118, 101, 114, 116, 32, 115, 112, 101, 99, 105, 102,
  105, 101, 100, 32, 115, 116, 114, 105, 110, 103, 32, 105, 110, 116, 111, 32,
  97, 32, 115, 101, 113, 117, 101, 110, 99, 101, 32, 111, 102, 32, 104, 101,
  120, 97, 100, 101, 99, 105, 109, 97, 108, 32, 118, 97, 108, 117, 101, 115,
  46, 10, 115, 116, 114, 50, 104, 101, 120, 32, 58, 10, 45, 118, 32, 45,
  32, 40, 123, 39, 34, 36, 42, 34, 39, 125, 41, 32, 45, 114, 111, 119,
  115, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 102, 91, 45, 49, 93,
  32, 39, 105, 102, 40, 121, 61, 61, 48, 44, 105, 110, 116, 40, 105, 47,
  49, 54, 41, 44, 105, 40, 120, 44, 121, 45, 49, 41, 37, 49, 54, 41,
  39, 32, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102, 40, 105, 60, 61,
  57, 44, 52, 56, 43, 105, 44, 56, 55, 43, 105, 41, 39, 32, 45, 116,
  114, 97, 110, 115, 112, 111, 115, 101, 91, 45, 49, 93, 32, 45, 117, 32,
  64, 123, 45, 49, 44, 116, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 116, 114, 101,
  115, 99, 32, 58, 32, 118, 97, 108, 49, 44, 46, 46, 46, 44, 118, 97,
  108, 78, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116, 117,
  114, 110, 32, 101, 115, 99, 97, 112, 101, 100, 32, 115, 116, 114, 105, 110,
  103, 32, 102, 114, 111, 109, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100,
  32, 97, 115, 99, 105, 105, 32, 99, 111, 100, 101, 115, 46, 10, 115, 116,
  114, 101, 115, 99, 32, 58, 10, 45, 118, 32, 45, 32, 40, 36, 42, 41,
  32, 45, 99, 91, 45, 49, 93, 32, 51, 50, 44, 50, 53, 53, 32, 45,
  121, 91, 45, 49, 93, 32, 91, 45, 49, 93, 10, 45, 102, 91, 45, 50,
  93, 32, 39, 105, 102, 40, 105, 61, 61, 51, 50, 124, 124, 105, 61, 61,
  51, 52, 124, 124, 105, 61, 61, 51, 54, 124, 124, 105, 61, 61, 52, 52,
  124, 124, 105, 61, 61, 54, 52, 124, 124, 105, 61, 61, 57, 50, 124, 124,
  105, 61, 61, 49, 50, 51, 124, 124, 105, 61, 61, 49, 50, 53, 44, 57,
  50, 44, 45, 49, 41, 39, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93,
  32, 120, 10, 45, 100, 105, 115, 99, 97, 114, 100, 91, 45, 49, 93, 32,
  45, 49, 32, 45, 117, 32, 64, 123, 45, 49, 44, 116, 125, 32, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 115, 116, 114, 99, 97, 116, 32, 58, 32, 115, 116, 114, 105, 110,
  103, 49, 44, 115, 116, 114, 105, 110, 103, 50, 44, 46, 46, 46, 10, 35,
  64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116, 117, 114, 110, 32, 116,
  104, 101, 32, 99, 111, 110, 99, 97, 116, 101, 110, 97, 116, 105, 111, 110,
  32, 111, 102, 32, 97, 108, 108, 32, 115, 116, 114, 105, 110, 103, 115, 32,
  112, 97, 115, 115, 101, 100, 32, 97, 115, 32, 97, 114, 103, 117, 109, 101,
  110, 116, 115, 46, 10, 115, 116, 114, 99, 97, 116, 32, 58, 10, 45, 118,
  32, 45, 32, 36, 61, 115, 32, 114, 101, 115, 61, 34, 36, 49, 34, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 35, 45, 49, 125, 32, 114,
  101, 115, 61, 36, 114, 101, 115, 36, 123, 115, 123, 36, 62, 43, 50, 125,
  125, 32, 45, 100, 111, 110, 101, 10, 45, 117, 32, 36, 114, 101, 115, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 116, 114, 99,
  109, 112, 32, 58, 32, 115, 116, 114, 105, 110, 103, 49, 44, 115, 116, 114,
  105, 110, 103, 50, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101,
  116, 117, 114, 110, 32, 49, 32, 105, 102, 32, 116, 104, 101, 32, 116, 119,
  111, 32, 115, 116, 114, 105, 110, 103, 115, 32, 97, 114, 101, 32, 101, 113,
  117, 97, 108, 44, 32, 48, 32, 111, 116, 104, 101, 114, 119, 105, 115, 101,
  46, 10, 115, 116, 114, 99, 109, 112, 32, 58, 10, 45, 118, 32, 45, 32,
  40, 48, 44, 123, 39, 34, 36, 49, 34, 39, 125, 41, 32, 40, 123, 119,
  125, 44, 123, 39, 34, 36, 50, 34, 39, 125, 41, 32, 45, 61, 91, 45,
  50, 93, 32, 123, 119, 125, 32, 45, 45, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 97, 98, 115, 91, 45, 49, 93, 32, 45, 117, 32, 123, 33, 64,
  123, 45, 49, 44, 43, 125, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 116, 114, 108,
  101, 110, 32, 58, 32, 115, 116, 114, 105, 110, 103, 49, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 82, 101, 116, 117, 114, 110, 32, 116, 104, 101,
  32, 108, 101, 110, 103, 116, 104, 32, 111, 102, 32, 115, 112, 101, 99, 105,
  102, 105, 101, 100, 32, 115, 116, 114, 105, 110, 103, 32, 97, 114, 103, 117,
  109, 101, 110, 116, 46, 10, 115, 116, 114, 108, 101, 110, 32, 58, 10, 45,
  118, 32, 45, 32, 40, 123, 39, 34, 36, 49, 34, 39, 125, 41, 32, 45,
  117, 32, 123, 119, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 118,
  32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 116, 114, 114, 101, 112,
  108, 97, 99, 101, 32, 58, 32, 115, 116, 114, 105, 110, 103, 44, 115, 101,
  97, 114, 99, 104, 44, 114, 101, 112, 108, 97, 99, 101, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 83, 101, 97, 114, 99, 104, 32, 97, 110, 100,
  32, 114, 101, 112, 108, 97, 99, 101, 32, 115, 117, 98, 115, 116, 114, 105,
  110, 103, 115, 32, 105, 110, 32, 97, 110, 32, 105, 110, 112, 117, 116, 32,
  115, 116, 114, 105, 110, 103, 46, 10, 115, 116, 114, 114, 101, 112, 108, 97,
  99, 101, 32, 58, 10, 45, 118, 32, 45, 10, 108, 115, 61, 64, 123, 45,
  115, 116, 114, 108, 101, 110, 92, 32, 34, 36, 50, 34, 125, 10, 108, 114,
  61, 123, 64, 123, 45, 115, 116, 114, 108, 101, 110, 92, 32, 34, 36, 51,
  34, 125, 45, 49, 125, 10, 45, 108, 91, 93, 32, 40, 123, 39, 34, 36,
  49, 34, 39, 125, 41, 32, 45, 115, 32, 43, 44, 123, 39, 34, 36, 50,
  34, 39, 125, 32, 45, 115, 32, 121, 44, 45, 36, 108, 115, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 105, 102, 32, 123, 64, 123,
  36, 62, 44, 116, 125, 39, 61, 61, 39, 34, 36, 50, 34, 125, 32, 45,
  114, 111, 119, 115, 91, 36, 62, 93, 32, 48, 44, 36, 108, 114, 32, 45,
  102, 91, 36, 62, 93, 32, 123, 39, 34, 36, 51, 34, 39, 125, 32, 45,
  101, 110, 100, 105, 102, 32, 45, 100, 111, 110, 101, 10, 45, 97, 32, 121,
  32, 45, 117, 32, 64, 123, 45, 49, 44, 116, 125, 32, 45, 114, 109, 32,
  45, 101, 110, 100, 108, 10, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105,
  99, 32, 115, 116, 114, 117, 110, 99, 97, 115, 101, 32, 58, 32, 115, 116,
  114, 105, 110, 103, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101,
  116, 117, 114, 110, 32, 97, 32, 108, 111, 119, 101, 114, 45, 99, 97, 115,
  101, 32, 118, 101, 114, 115, 105, 111, 110, 32, 111, 102, 32, 116, 104, 101,
  32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 115, 116, 114, 105, 110,
  103, 46, 10, 115, 116, 114, 117, 110, 99, 97, 115, 101, 32, 58, 10, 45,
  118, 32, 45, 32, 40, 123, 39, 34, 36, 42, 34, 39, 125, 41, 32, 45,
  43, 91, 45, 49, 93, 32, 39, 105, 102, 40, 105, 62, 61, 54, 53, 38,
  38, 105, 60, 61, 57, 48, 44, 51, 50, 44, 48, 41, 39, 32, 45, 117,
  32, 64, 123, 45, 49, 44, 116, 125, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 115, 116, 114,
  118, 101, 114, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 82, 101, 116,
  117, 114, 110, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32,
  118, 101, 114, 115, 105, 111, 110, 32, 110, 117, 109, 98, 101, 114, 32, 111,
  102, 32, 116, 104, 101, 32, 71, 39, 77, 73, 67, 32, 105, 110, 116, 101,
  114, 112, 114, 101, 116, 101, 114, 44, 32, 97, 115, 32, 97, 32, 115, 116,
  114, 105, 110, 103, 46, 10, 115, 116, 114, 118, 101, 114, 32, 58, 10, 45,
  118, 32, 45, 32, 40, 123, 39, 64, 46, 39, 125, 41, 32, 45, 114, 91,
  45, 49, 93, 32, 55, 32, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102,
  40, 120, 37, 50, 44, 123, 39, 46, 39, 125, 44, 105, 41, 39, 32, 45,
  117, 32, 64, 123, 45, 49, 44, 116, 125, 32, 45, 114, 109, 91, 45, 49,
  93, 32, 45, 118, 32, 43, 10, 35, 64, 103, 109, 105, 99, 32, 116, 105,
  99, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 73, 110, 105, 116, 105,
  97, 108, 105, 122, 101, 32, 116, 105, 99, 45, 116, 111, 99, 32, 116, 105,
  109, 101, 114, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58, 32, 85, 115,
  101, 32, 105, 116, 32, 105, 110, 32, 99, 111, 110, 106, 117, 110, 99, 116,
  105, 111, 110, 32, 119, 105, 116, 104, 32, 39, 45, 116, 111, 99, 39, 46,
  10, 116, 105, 99, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  73, 110, 105, 116, 105, 97, 108, 105, 122, 101, 32, 116, 105, 109, 101, 114,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 105, 102, 32, 123, 33, 110, 97,
  114, 103, 40, 36, 95, 95, 116, 105, 99, 112, 111, 115, 41, 125, 32, 95,
  95, 116, 105, 99, 112, 111, 115, 61, 48, 32, 45, 101, 110, 100, 105, 102,
  32, 95, 95, 116, 105, 99, 36, 95, 95, 116, 105, 99, 112, 111, 115, 61,
  64, 124, 32, 95, 95, 116, 105, 99, 112, 111, 115, 61, 123, 36, 95, 95,
  116, 105, 99, 112, 111, 115, 43, 49, 125, 32, 45, 118, 32, 43, 10, 35,
  64, 103, 109, 105, 99, 32, 116, 111, 99, 10, 35, 64, 103, 109, 105, 99,
  32, 58, 32, 68, 105, 115, 112, 108, 97, 121, 32, 101, 108, 97, 112, 115,
  101, 100, 32, 116, 105, 109, 101, 32, 111, 102, 32, 116, 104, 101, 32, 116,
  105, 99, 45, 116, 111, 99, 32, 116, 105, 109, 101, 114, 32, 115, 105, 110,
  99, 101, 32, 116, 104, 101, 32, 108, 97, 115, 116, 32, 99, 97, 108, 108,
  32, 116, 111, 32, 39, 45, 116, 105, 99, 39, 46, 10, 35, 64, 103, 109,
  105, 99, 32, 58, 32, 85, 115, 101, 32, 105, 116, 32, 105, 110, 32, 99,
  111, 110, 106, 117, 110, 99, 116, 105, 111, 110, 32, 119, 105, 116, 104, 32,
  39, 45, 116, 105, 99, 39, 46, 10, 116, 111, 99, 32, 58, 10, 45, 118,
  32, 45, 32, 95, 95, 116, 105, 99, 112, 111, 115, 61, 123, 36, 95, 95,
  116, 105, 99, 112, 111, 115, 45, 49, 125, 32, 45, 118, 32, 43, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 69, 108, 97, 112, 115, 101, 100, 32,
  116, 105, 109, 101, 32, 58, 32, 34, 123, 95, 64, 124, 45, 36, 123, 95,
  95, 116, 105, 99, 36, 95, 95, 116, 105, 99, 112, 111, 115, 125, 125, 34,
  32, 115, 34, 46, 10, 35, 64, 103, 109, 105, 99, 32, 118, 97, 114, 105,
  97, 110, 99, 101, 95, 110, 111, 105, 115, 101, 10, 35, 64, 103, 109, 105,
  99, 32, 58, 32, 82, 101, 116, 117, 114, 110, 32, 116, 104, 101, 32, 101,
  115, 116, 105, 109, 97, 116, 101, 100, 32, 110, 111, 105, 115, 101, 32, 118,
  97, 114, 105, 97, 110, 99, 101, 32, 111, 102, 32, 116, 104, 101, 32, 108,
  97, 115, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 46, 10, 118, 97, 114, 105, 97, 110, 99, 101, 95, 110, 111, 105,
  115, 101, 32, 58, 10, 45, 118, 32, 45, 32, 45, 45, 108, 97, 112, 108,
  97, 99, 105, 97, 110, 91, 45, 49, 93, 32, 45, 117, 32, 123, 64, 123,
  45, 109, 97, 100, 91, 45, 49, 93, 125, 47, 115, 113, 114, 116, 40, 105,
  102, 40, 100, 61, 61, 49, 44, 50, 48, 44, 52, 50, 41, 41, 125, 32,
  45, 114, 109, 91, 45, 49, 93, 32, 45, 118, 32, 43, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 58, 32, 79, 116, 104, 101, 114, 115, 10, 35, 64,
  103, 109, 105, 99, 32, 103, 112, 116, 32, 58, 32, 95, 115, 99, 111, 114,
  101, 102, 105, 108, 101, 44, 95, 110, 117, 109, 98, 101, 114, 95, 111, 102,
  95, 115, 101, 115, 115, 105, 111, 110, 115, 62, 61, 48, 10, 35, 64, 103,
  109, 105, 99, 32, 58, 32, 71, 101, 110, 101, 114, 97, 116, 101, 32, 115,
  99, 111, 114, 101, 32, 98, 111, 97, 114, 100, 32, 102, 111, 114, 32, 116,
  104, 101, 32, 71, 80, 84, 32, 99, 104, 97, 109, 112, 105, 111, 110, 115,
  104, 105, 112, 32, 40, 71, 82, 69, 89, 67, 32, 80, 111, 107, 101, 114,
  32, 84, 111, 117, 114, 41, 46, 10, 35, 64, 103, 109, 105, 99, 32, 58,
  32, 36, 32, 45, 103, 112, 116, 32, 44, 10, 103, 112, 116, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 34, 36, 123, 49, 61, 104, 116, 116, 112, 115,
  58, 47, 47, 116, 115, 99, 104, 117, 109, 112, 101, 114, 108, 101, 46, 117,
  115, 101, 114, 115, 46, 103, 114, 101, 121, 99, 46, 102, 114, 47, 103, 112,
  116, 46, 114, 97, 119, 125, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  50, 61, 48, 125, 44, 36, 123, 51, 61, 48, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 71, 101, 110, 101, 114, 97, 116, 101, 32, 115, 99,
  111, 114, 101, 32, 98, 111, 97, 114, 100, 32, 102, 111, 114, 32, 71, 80,
  84, 45, 108, 105, 107, 101, 32, 99, 104, 97, 109, 112, 105, 111, 110, 115,
  104, 105, 112, 32, 40, 71, 82, 69, 89, 67, 32, 80, 111, 107, 101, 114,
  32, 84, 111, 117, 114, 41, 44, 32, 102, 114, 111, 109, 32, 102, 105, 108,
  101, 32, 39, 36, 49, 39, 46, 34, 10, 45, 118, 32, 45, 10, 45, 114,
  109, 32, 45, 105, 32, 114, 97, 119, 58, 36, 49, 44, 117, 99, 104, 97,
  114, 32, 45, 115, 91, 45, 49, 93, 32, 45, 44, 49, 48, 32, 45, 116,
  114, 97, 110, 115, 112, 111, 115, 101, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 105, 102, 32, 123, 105, 61, 61, 123, 39, 35, 39,
  125, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 108, 115, 101,
  32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 101, 110, 100, 105,
  102, 32, 45, 100, 111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 32, 45, 44, 123,
  39, 92, 32, 39, 125, 10, 45, 105, 102, 32, 64, 35, 10, 45, 105, 102,
  32, 123, 64, 35, 33, 61, 52, 125, 32, 45, 101, 114, 114, 111, 114, 91,
  48, 45, 45, 52, 93, 32, 34, 73, 110, 118, 97, 108, 105, 100, 32, 115,
  99, 111, 114, 101, 32, 102, 105, 108, 101, 32, 40, 108, 105, 110, 101, 32,
  34, 123, 36, 62, 43, 49, 125, 34, 32, 100, 101, 102, 105, 110, 101, 115,
  32, 34, 64, 35, 34, 32, 105, 116, 101, 109, 115, 32, 105, 110, 115, 116,
  101, 97, 100, 32, 111, 102, 32, 52, 41, 46, 34, 32, 45, 101, 110, 100,
  105, 102, 10, 112, 108, 97, 121, 101, 114, 36, 62, 95, 110, 97, 109, 101,
  61, 64, 123, 48, 44, 116, 125, 10, 112, 108, 97, 121, 101, 114, 36, 62,
  95, 117, 114, 108, 61, 64, 123, 49, 44, 116, 125, 10, 112, 108, 97, 121,
  101, 114, 36, 62, 95, 102, 105, 108, 101, 61, 64, 123, 50, 44, 116, 125,
  10, 40, 64, 123, 51, 44, 116, 125, 41, 32, 45, 114, 109, 91, 48, 45,
  51, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 45, 43, 32, 49, 32, 45, 97, 32, 121, 44,
  49, 32, 45, 45, 32, 49, 10, 45, 105, 102, 32, 123, 36, 50, 62, 48,
  125, 32, 45, 122, 91, 45, 49, 93, 32, 123, 109, 97, 120, 40, 48, 44,
  119, 45, 36, 50, 41, 125, 44, 49, 48, 48, 37, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 50, 60, 48, 125, 32, 45, 122, 91, 45, 49, 93, 32,
  123, 119, 45, 49, 45, 40, 40, 119, 45, 49, 41, 37, 45, 36, 50, 41,
  125, 44, 49, 48, 48, 37, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 36, 50, 32, 45, 115, 32, 121, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 105, 102, 32, 123, 64, 123, 36, 60, 44, 77,
  125, 60, 48, 125, 10, 105, 61, 36, 60, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 64, 35, 45, 36, 105, 125, 10, 112, 108, 97, 121, 101, 114,
  123, 36, 105, 43, 36, 62, 125, 95, 110, 97, 109, 101, 61, 36, 123, 112,
  108, 97, 121, 101, 114, 123, 36, 105, 43, 36, 62, 43, 49, 125, 95, 110,
  97, 109, 101, 125, 10, 112, 108, 97, 121, 101, 114, 123, 36, 105, 43, 36,
  62, 125, 95, 117, 114, 108, 61, 36, 123, 112, 108, 97, 121, 101, 114, 123,
  36, 105, 43, 36, 62, 43, 49, 125, 95, 117, 114, 108, 125, 10, 112, 108,
  97, 121, 101, 114, 123, 36, 105, 43, 36, 62, 125, 95, 102, 105, 108, 101,
  61, 36, 123, 112, 108, 97, 121, 101, 114, 123, 36, 105, 43, 36, 62, 43,
  49, 125, 95, 102, 105, 108, 101, 125, 10, 45, 100, 111, 110, 101, 10, 45,
  114, 109, 91, 36, 60, 93, 32, 45, 101, 110, 100, 105, 102, 32, 45, 100,
  111, 110, 101, 32, 45, 97, 32, 121, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 110, 109, 91, 45, 49, 93, 32, 115, 99, 111, 114, 101, 115, 10, 114,
  111, 119, 95, 104, 101, 105, 103, 104, 116, 61, 123, 105, 102, 40, 36, 50,
  44, 50, 52, 44, 52, 56, 41, 125, 10, 45, 45, 108, 91, 115, 99, 111,
  114, 101, 115, 93, 32, 45, 115, 32, 121, 32, 45, 109, 97, 120, 32, 45,
  101, 110, 100, 108, 32, 45, 45, 61, 61, 91, 115, 99, 111, 114, 101, 115,
  44, 45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 110, 109,
  91, 45, 49, 93, 32, 119, 105, 110, 110, 101, 114, 115, 10, 45, 45, 108,
  91, 115, 99, 111, 114, 101, 115, 93, 32, 45, 114, 101, 112, 108, 97, 99,
  101, 91, 45, 49, 93, 32, 45, 49, 44, 49, 101, 56, 32, 45, 115, 32,
  121, 32, 45, 109, 105, 110, 32, 45, 101, 110, 100, 108, 32, 45, 45, 61,
  61, 91, 115, 99, 111, 114, 101, 115, 44, 45, 49, 93, 32, 45, 114, 109,
  91, 45, 50, 93, 10, 45, 110, 109, 91, 45, 49, 93, 32, 108, 111, 115,
  101, 114, 115, 10, 45, 45, 108, 91, 119, 105, 110, 110, 101, 114, 115, 93,
  32, 45, 115, 32, 121, 32, 45, 43, 32, 45, 101, 110, 100, 108, 10, 45,
  110, 109, 91, 45, 49, 93, 32, 110, 98, 95, 119, 105, 110, 110, 101, 114,
  115, 10, 45, 45, 108, 91, 108, 111, 115, 101, 114, 115, 93, 32, 45, 115,
  32, 121, 32, 45, 43, 32, 45, 101, 110, 100, 108, 10, 45, 110, 109, 91,
  45, 49, 93, 32, 110, 98, 95, 108, 111, 115, 101, 114, 115, 10, 45, 45,
  108, 91, 115, 99, 111, 114, 101, 115, 93, 32, 45, 115, 32, 120, 32, 45,
  114, 32, 50, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 48, 32, 45,
  102, 32, 39, 105, 102, 40, 120, 44, 121, 44, 105, 41, 39, 32, 45, 115,
  111, 114, 116, 32, 45, 44, 121, 10, 45, 114, 32, 51, 44, 49, 48, 48,
  37, 44, 49, 44, 49, 44, 48, 44, 48, 44, 49, 44, 48, 32, 45, 102,
  32, 39, 105, 102, 40, 120, 44, 105, 44, 121, 43, 49, 41, 39, 10, 45,
  102, 32, 39, 62, 105, 102, 40, 120, 44, 105, 44, 105, 102, 40, 105, 40,
  49, 44, 121, 41, 61, 61, 105, 40, 49, 44, 121, 45, 49, 41, 44, 105,
  40, 48, 44, 121, 45, 49, 41, 44, 105, 41, 41, 39, 10, 45, 109, 105,
  114, 114, 111, 114, 32, 120, 32, 45, 115, 111, 114, 116, 32, 43, 44, 121,
  32, 45, 122, 32, 49, 44, 50, 32, 45, 102, 32, 39, 105, 102, 40, 105,
  40, 48, 44, 121, 41, 61, 61, 45, 49, 44, 45, 49, 44, 105, 41, 39,
  10, 45, 122, 32, 49, 44, 49, 32, 45, 97, 32, 120, 32, 45, 101, 110,
  100, 108, 10, 45, 110, 109, 91, 45, 49, 93, 32, 114, 97, 110, 107, 115,
  10, 45, 114, 111, 117, 110, 100, 91, 115, 99, 111, 114, 101, 115, 93, 10,
  45, 45, 108, 91, 115, 99, 111, 114, 101, 115, 93, 32, 45, 115, 32, 120,
  32, 45, 100, 105, 115, 99, 97, 114, 100, 32, 45, 49, 32, 45, 102, 32,
  104, 32, 45, 114, 111, 119, 115, 32, 48, 32, 45, 97, 32, 120, 32, 45,
  101, 110, 100, 108, 10, 45, 110, 109, 91, 45, 49, 93, 32, 110, 98, 95,
  112, 108, 97, 121, 101, 114, 115, 10, 45, 45, 108, 91, 115, 99, 111, 114,
  101, 115, 93, 32, 45, 115, 32, 121, 32, 45, 109, 97, 120, 32, 45, 101,
  110, 100, 108, 10, 45, 110, 109, 91, 45, 49, 93, 32, 109, 97, 120, 95,
  115, 99, 111, 114, 101, 115, 10, 45, 45, 108, 91, 115, 99, 111, 114, 101,
  115, 93, 32, 45, 114, 101, 112, 108, 97, 99, 101, 91, 45, 49, 93, 32,
  45, 49, 44, 49, 101, 56, 32, 45, 115, 32, 121, 32, 45, 109, 105, 110,
  32, 45, 101, 110, 100, 108, 10, 45, 110, 109, 91, 45, 49, 93, 32, 109,
  105, 110, 95, 115, 99, 111, 114, 101, 115, 10, 45, 45, 108, 91, 115, 99,
  111, 114, 101, 115, 93, 32, 45, 103, 101, 32, 48, 32, 45, 115, 32, 120,
  32, 45, 43, 32, 45, 101, 110, 100, 108, 10, 45, 110, 109, 91, 45, 49,
  93, 32, 110, 98, 95, 103, 97, 109, 101, 115, 10, 45, 45, 108, 91, 115,
  99, 111, 114, 101, 115, 93, 32, 45, 110, 101, 113, 32, 45, 49, 32, 45,
  115, 32, 121, 32, 45, 42, 32, 39, 119, 45, 120, 39, 32, 45, 102, 32,
  120, 77, 32, 45, 97, 32, 121, 32, 45, 122, 32, 48, 44, 48, 32, 45,
  101, 110, 100, 108, 10, 45, 110, 109, 91, 45, 49, 93, 32, 102, 105, 114,
  115, 116, 95, 103, 97, 109, 101, 10, 45, 45, 108, 116, 91, 115, 99, 111,
  114, 101, 115, 93, 32, 48, 10, 45, 45, 108, 91, 45, 49, 93, 32, 45,
  115, 32, 120, 32, 45, 43, 32, 45, 101, 110, 100, 108, 32, 45, 45, 91,
  45, 49, 93, 32, 91, 102, 105, 114, 115, 116, 95, 103, 97, 109, 101, 93,
  10, 45, 108, 91, 45, 50, 93, 32, 45, 102, 32, 39, 105, 102, 40, 105,
  44, 105, 44, 45, 120, 41, 39, 32, 45, 115, 32, 121, 32, 45, 108, 97,
  98, 101, 108, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 110,
  61, 123, 64, 123, 36, 62, 44, 77, 125, 125, 32, 45, 105, 102, 32, 36,
  110, 32, 45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 36, 62, 93,
  32, 36, 110, 44, 49, 44, 36, 110, 32, 45, 101, 108, 115, 101, 32, 45,
  102, 91, 36, 62, 93, 32, 48, 32, 45, 101, 110, 100, 105, 102, 32, 45,
  100, 111, 110, 101, 10, 45, 114, 32, 49, 44, 49, 44, 49, 44, 49, 44,
  50, 32, 45, 97, 32, 121, 32, 45, 45, 32, 49, 32, 45, 109, 97, 120,
  32, 48, 32, 45, 114, 111, 117, 110, 100, 32, 45, 101, 110, 100, 108, 32,
  45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 114, 111, 117, 110, 100,
  91, 45, 49, 93, 10, 45, 110, 109, 91, 45, 49, 93, 32, 97, 98, 115,
  95, 109, 97, 108, 117, 115, 10, 45, 45, 108, 91, 115, 99, 111, 114, 101,
  115, 93, 32, 45, 102, 32, 39, 105, 102, 40, 105, 61, 61, 45, 49, 44,
  48, 44, 105, 45, 49, 48, 48, 41, 39, 32, 45, 115, 32, 120, 32, 45,
  43, 32, 45, 101, 110, 100, 108, 10, 45, 105, 102, 32, 36, 51, 32, 45,
  97, 98, 115, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  45, 91, 45, 49, 93, 32, 91, 97, 98, 115, 95, 109, 97, 108, 117, 115,
  93, 10, 45, 45, 102, 91, 45, 49, 93, 32, 121, 32, 45, 97, 91, 45,
  50, 44, 45, 49, 93, 32, 120, 32, 45, 115, 111, 114, 116, 91, 45, 49,
  93, 32, 45, 44, 121, 10, 49, 44, 49, 48, 48, 37, 44, 49, 44, 49,
  44, 39, 121, 43, 49, 39, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93,
  32, 120, 32, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 120,
  10, 45, 102, 91, 45, 49, 93, 32, 39, 62, 105, 102, 40, 120, 44, 105,
  44, 105, 102, 40, 105, 40, 50, 44, 121, 41, 61, 61, 105, 40, 50, 44,
  121, 45, 49, 41, 44, 105, 40, 48, 44, 121, 45, 49, 41, 44, 105, 41,
  41, 39, 10, 45, 110, 109, 91, 45, 49, 93, 32, 114, 97, 110, 107, 10,
  45, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 45, 49, 44, 48,
  44, 48, 44, 48, 44, 50, 32, 45, 115, 111, 114, 116, 91, 45, 49, 93,
  32, 43, 44, 121, 32, 45, 99, 111, 108, 117, 109, 110, 115, 91, 45, 49,
  93, 32, 49, 44, 49, 48, 48, 37, 10, 45, 110, 109, 91, 45, 49, 93,
  32, 115, 99, 111, 114, 101, 10, 115, 117, 109, 95, 115, 99, 111, 114, 101,
  61, 64, 123, 115, 99, 111, 114, 101, 44, 43, 125, 10, 45, 45, 108, 91,
  115, 99, 111, 114, 101, 115, 93, 32, 45, 115, 32, 120, 32, 45, 109, 97,
  120, 32, 45, 45, 32, 49, 48, 48, 32, 45, 101, 110, 100, 108, 10, 45,
  45, 102, 91, 45, 49, 93, 32, 121, 32, 45, 97, 91, 45, 50, 44, 45,
  49, 93, 32, 120, 32, 45, 115, 111, 114, 116, 91, 45, 49, 93, 32, 45,
  44, 121, 10, 49, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 39, 121,
  43, 49, 39, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32,
  45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 120, 10, 45, 102,
  91, 45, 49, 93, 32, 39, 62, 105, 102, 40, 120, 44, 105, 44, 105, 102,
  40, 105, 40, 50, 44, 121, 41, 61, 61, 105, 40, 50, 44, 121, 45, 49,
  41, 44, 105, 40, 48, 44, 121, 45, 49, 41, 44, 105, 41, 41, 39, 10,
  45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 45, 49, 44, 48, 44,
  48, 44, 48, 44, 50, 32, 45, 115, 111, 114, 116, 91, 45, 49, 93, 32,
  43, 44, 121, 32, 45, 99, 111, 108, 117, 109, 110, 115, 91, 45, 49, 93,
  32, 49, 44, 49, 48, 48, 37, 10, 45, 110, 109, 91, 45, 49, 93, 32,
  98, 101, 115, 116, 95, 115, 99, 111, 114, 101, 10, 45, 45, 108, 91, 115,
  99, 111, 114, 101, 115, 93, 32, 45, 99, 111, 108, 117, 109, 110, 115, 32,
  48, 44, 123, 119, 45, 50, 125, 32, 45, 102, 32, 39, 105, 102, 40, 105,
  61, 61, 45, 49, 44, 48, 44, 105, 45, 49, 48, 48, 41, 39, 32, 45,
  115, 32, 120, 32, 45, 43, 32, 45, 101, 110, 100, 108, 32, 45, 45, 91,
  45, 49, 93, 32, 91, 97, 98, 115, 95, 109, 97, 108, 117, 115, 93, 10,
  45, 105, 102, 32, 36, 51, 32, 45, 97, 98, 115, 91, 45, 49, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 45, 102, 91, 45, 49, 93, 32, 121,
  32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 115, 111,
  114, 116, 91, 45, 49, 93, 32, 45, 44, 121, 10, 49, 44, 49, 48, 48,
  37, 44, 49, 44, 49, 44, 39, 121, 43, 49, 39, 32, 45, 97, 91, 45,
  50, 44, 45, 49, 93, 32, 120, 32, 45, 109, 105, 114, 114, 111, 114, 91,
  45, 49, 93, 32, 120, 10, 45, 102, 91, 45, 49, 93, 32, 39, 62, 105,
  102, 40, 120, 44, 105, 44, 105, 102, 40, 105, 40, 50, 44, 121, 41, 61,
  61, 105, 40, 50, 44, 121, 45, 49, 41, 44, 105, 40, 48, 44, 121, 45,
  49, 41, 44, 105, 41, 41, 39, 10, 45, 115, 104, 105, 102, 116, 91, 45,
  49, 93, 32, 45, 49, 44, 48, 44, 48, 44, 48, 44, 50, 32, 45, 115,
  111, 114, 116, 91, 45, 49, 93, 32, 43, 44, 121, 32, 45, 99, 111, 108,
  117, 109, 110, 115, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48, 37, 10,
  45, 110, 109, 91, 45, 49, 93, 32, 112, 114, 101, 118, 105, 111, 117, 115,
  95, 115, 99, 111, 114, 101, 10, 45, 45, 108, 91, 115, 99, 111, 114, 101,
  115, 93, 32, 45, 102, 32, 39, 105, 102, 40, 105, 61, 61, 45, 49, 44,
  48, 44, 105, 45, 49, 48, 48, 41, 39, 32, 45, 115, 32, 120, 32, 45,
  43, 32, 45, 101, 110, 100, 108, 10, 45, 110, 109, 91, 45, 49, 93, 32,
  99, 104, 105, 112, 115, 10, 115, 117, 109, 95, 99, 104, 105, 112, 115, 61,
  64, 123, 99, 104, 105, 112, 115, 44, 43, 125, 10, 45, 118, 32, 43, 10,
  45, 101, 32, 34, 83, 117, 109, 32, 111, 102, 32, 99, 104, 105, 112, 115,
  32, 58, 32, 34, 36, 115, 117, 109, 95, 99, 104, 105, 112, 115, 10, 45,
  101, 32, 34, 83, 117, 109, 32, 111, 102, 32, 115, 99, 111, 114, 101, 115,
  32, 58, 32, 34, 36, 115, 117, 109, 95, 115, 99, 111, 114, 101, 10, 45,
  118, 32, 45, 10, 45, 45, 45, 91, 112, 114, 101, 118, 105, 111, 117, 115,
  95, 115, 99, 111, 114, 101, 44, 115, 99, 111, 114, 101, 93, 32, 45, 99,
  111, 108, 117, 109, 110, 115, 91, 45, 49, 93, 32, 49, 10, 45, 110, 109,
  91, 45, 49, 93, 32, 116, 114, 101, 110, 100, 10, 45, 45, 108, 91, 115,
  99, 111, 114, 101, 115, 93, 32, 45, 115, 32, 121, 32, 45, 100, 105, 115,
  99, 97, 114, 100, 32, 45, 49, 32, 45, 117, 110, 114, 111, 108, 108, 32,
  120, 32, 45, 45, 32, 49, 48, 48, 32, 45, 99, 117, 109, 117, 108, 32,
  45, 102, 32, 105, 77, 32, 45, 97, 32, 121, 32, 45, 122, 32, 48, 44,
  48, 32, 45, 101, 110, 100, 108, 10, 45, 45, 102, 91, 45, 49, 93, 32,
  121, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 115,
  111, 114, 116, 91, 45, 49, 93, 32, 45, 44, 121, 10, 49, 44, 49, 48,
  48, 37, 44, 49, 44, 49, 44, 39, 121, 43, 49, 39, 32, 45, 97, 91,
  45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 109, 105, 114, 114, 111, 114,
  91, 45, 49, 93, 32, 120, 10, 45, 102, 91, 45, 49, 93, 32, 39, 62,
  105, 102, 40, 120, 44, 105, 44, 105, 102, 40, 105, 40, 50, 44, 121, 41,
  61, 61, 105, 40, 50, 44, 121, 45, 49, 41, 44, 105, 40, 48, 44, 121,
  45, 49, 41, 44, 105, 41, 41, 39, 10, 45, 115, 104, 105, 102, 116, 91,
  45, 49, 93, 32, 45, 49, 44, 48, 44, 48, 44, 48, 44, 50, 32, 45,
  115, 111, 114, 116, 91, 45, 49, 93, 32, 43, 44, 121, 32, 45, 99, 111,
  108, 117, 109, 110, 115, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48, 37,
  10, 45, 110, 109, 91, 45, 49, 93, 32, 104, 105, 103, 104, 101, 115, 116,
  95, 99, 104, 105, 112, 115, 10, 45, 45, 108, 91, 115, 99, 111, 114, 101,
  115, 93, 32, 45, 115, 32, 121, 32, 45, 100, 105, 115, 99, 97, 114, 100,
  32, 45, 49, 32, 45, 117, 110, 114, 111, 108, 108, 32, 120, 32, 45, 45,
  32, 49, 48, 48, 32, 45, 99, 117, 109, 117, 108, 32, 45, 102, 32, 105,
  109, 32, 45, 97, 32, 121, 32, 45, 122, 32, 48, 44, 48, 32, 45, 101,
  110, 100, 108, 10, 45, 45, 102, 91, 45, 49, 93, 32, 121, 32, 45, 97,
  91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 115, 111, 114, 116, 91,
  45, 49, 93, 32, 45, 44, 121, 10, 49, 44, 49, 48, 48, 37, 44, 49,
  44, 49, 44, 39, 121, 43, 49, 39, 32, 45, 97, 91, 45, 50, 44, 45,
  49, 93, 32, 120, 32, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93,
  32, 120, 10, 45, 102, 91, 45, 49, 93, 32, 39, 62, 105, 102, 40, 120,
  44, 105, 44, 105, 102, 40, 105, 40, 50, 44, 121, 41, 61, 61, 105, 40,
  50, 44, 121, 45, 49, 41, 44, 105, 40, 48, 44, 121, 45, 49, 41, 44,
  105, 41, 41, 39, 10, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32,
  45, 49, 44, 48, 44, 48, 44, 48, 44, 50, 32, 45, 115, 111, 114, 116,
  91, 45, 49, 93, 32, 43, 44, 121, 32, 45, 99, 111, 108, 117, 109, 110,
  115, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48, 37, 10, 45, 110, 109,
  91, 45, 49, 93, 32, 108, 111, 119, 101, 115, 116, 95, 99, 104, 105, 112,
  115, 10, 45, 45, 45, 91, 115, 99, 111, 114, 101, 115, 93, 32, 91, 109,
  105, 110, 95, 115, 99, 111, 114, 101, 115, 93, 32, 91, 109, 97, 120, 95,
  115, 99, 111, 114, 101, 115, 93, 32, 45, 45, 91, 45, 49, 93, 32, 91,
  109, 105, 110, 95, 115, 99, 111, 114, 101, 115, 93, 32, 45, 47, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 49, 48, 48,
  10, 45, 108, 91, 45, 49, 93, 32, 45, 102, 32, 39, 105, 102, 40, 105,
  60, 48, 44, 45, 49, 44, 105, 41, 39, 32, 45, 115, 32, 121, 32, 45,
  100, 105, 115, 99, 97, 114, 100, 32, 45, 49, 32, 45, 102, 32, 39, 105,
  102, 40, 105, 97, 60, 48, 44, 48, 44, 105, 97, 41, 39, 32, 45, 114,
  111, 119, 115, 32, 48, 32, 45, 97, 32, 121, 32, 45, 114, 111, 117, 110,
  100, 32, 49, 32, 45, 101, 110, 100, 108, 10, 45, 45, 102, 91, 45, 49,
  93, 32, 121, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32,
  45, 115, 111, 114, 116, 91, 45, 49, 93, 32, 45, 44, 121, 10, 49, 44,
  49, 48, 48, 37, 44, 49, 44, 49, 44, 121, 43, 49, 32, 45, 97, 91,
  45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 109, 105, 114, 114, 111, 114,
  91, 45, 49, 93, 32, 120, 10, 45, 102, 91, 45, 49, 93, 32, 39, 62,
  105, 102, 40, 120, 44, 105, 44, 105, 102, 40, 105, 40, 50, 44, 121, 41,
  61, 61, 105, 40, 50, 44, 121, 45, 49, 41, 44, 105, 40, 48, 44, 121,
  45, 49, 41, 44, 105, 41, 41, 39, 10, 45, 115, 104, 105, 102, 116, 91,
  45, 49, 93, 32, 45, 49, 44, 48, 44, 48, 44, 48, 44, 50, 32, 45,
  115, 111, 114, 116, 91, 45, 49, 93, 32, 43, 44, 121, 32, 45, 99, 111,
  108, 117, 109, 110, 115, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48, 37,
  10, 45, 110, 109, 91, 45, 49, 93, 32, 112, 101, 114, 102, 111, 114, 109,
  97, 110, 99, 101, 10, 45, 45, 108, 91, 115, 99, 111, 114, 101, 115, 93,
  32, 45, 115, 32, 121, 32, 45, 100, 105, 115, 99, 97, 114, 100, 32, 45,
  49, 32, 45, 45, 32, 49, 48, 48, 32, 45, 114, 32, 49, 44, 49, 44,
  49, 44, 49, 44, 50, 32, 45, 97, 32, 121, 32, 45, 101, 110, 100, 108,
  10, 45, 45, 102, 91, 45, 49, 93, 32, 121, 32, 45, 97, 91, 45, 50,
  44, 45, 49, 93, 32, 120, 32, 45, 115, 111, 114, 116, 91, 45, 49, 93,
  32, 45, 44, 121, 10, 49, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44,
  121, 43, 49, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32,
  45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 120, 10, 45, 102,
  91, 45, 49, 93, 32, 39, 62, 105, 102, 40, 120, 44, 105, 44, 105, 102,
  40, 105, 40, 50, 44, 121, 41, 61, 61, 105, 40, 50, 44, 121, 45, 49,
  41, 44, 105, 40, 48, 44, 121, 45, 49, 41, 44, 105, 41, 41, 39, 10,
  45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 45, 49, 44, 48, 44,
  48, 44, 48, 44, 50, 32, 45, 115, 111, 114, 116, 91, 45, 49, 93, 32,
  43, 44, 121, 32, 45, 99, 111, 108, 117, 109, 110, 115, 91, 45, 49, 93,
  32, 49, 44, 49, 48, 48, 37, 10, 45, 110, 109, 91, 45, 49, 93, 32,
  97, 118, 101, 114, 97, 103, 101, 10, 45, 45, 33, 61, 91, 115, 99, 111,
  114, 101, 115, 93, 32, 45, 49, 10, 45, 45, 42, 91, 108, 111, 115, 101,
  114, 115, 44, 110, 98, 95, 112, 108, 97, 121, 101, 114, 115, 93, 32, 45,
  47, 91, 45, 49, 93, 32, 91, 110, 98, 95, 108, 111, 115, 101, 114, 115,
  93, 10, 45, 45, 91, 45, 50, 44, 45, 49, 93, 32, 45, 108, 91, 45,
  49, 93, 32, 45, 115, 32, 120, 32, 45, 43, 32, 45, 101, 110, 100, 108,
  32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 45, 42, 91, 45,
  49, 93, 32, 48, 46, 52, 10, 45, 45, 102, 91, 45, 49, 93, 32, 121,
  32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 115, 111,
  114, 116, 91, 45, 49, 93, 32, 45, 44, 121, 10, 49, 44, 49, 48, 48,
  37, 44, 49, 44, 49, 44, 121, 43, 49, 32, 45, 97, 91, 45, 50, 44,
  45, 49, 93, 32, 120, 32, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49,
  93, 32, 120, 10, 45, 102, 91, 45, 49, 93, 32, 39, 62, 105, 102, 40,
  120, 44, 105, 44, 105, 102, 40, 105, 40, 50, 44, 121, 41, 61, 61, 105,
  40, 50, 44, 121, 45, 49, 41, 44, 105, 40, 48, 44, 121, 45, 49, 41,
  44, 105, 41, 41, 39, 10, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93,
  32, 45, 49, 44, 48, 44, 48, 44, 48, 44, 50, 32, 45, 115, 111, 114,
  116, 91, 45, 49, 93, 32, 43, 44, 121, 32, 45, 99, 111, 108, 117, 109,
  110, 115, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48, 37, 10, 45, 110,
  109, 91, 45, 49, 93, 32, 99, 111, 102, 102, 101, 101, 95, 98, 97, 108,
  97, 110, 99, 101, 10, 45, 99, 111, 110, 101, 51, 100, 32, 49, 46, 53,
  44, 50, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 49, 44,
  48, 44, 57, 48, 32, 45, 98, 111, 120, 51, 100, 32, 52, 44, 49, 44,
  48, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 48, 44, 45, 48, 46,
  53, 32, 45, 43, 51, 100, 91, 45, 50, 44, 45, 49, 93, 32, 45, 114,
  51, 100, 91, 45, 49, 93, 32, 48, 44, 49, 44, 48, 44, 49, 56, 48,
  10, 45, 99, 51, 100, 91, 45, 49, 93, 32, 45, 42, 51, 100, 91, 45,
  49, 93, 32, 49, 55, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93,
  32, 49, 10, 49, 50, 56, 44, 49, 50, 56, 32, 45, 111, 98, 106, 101,
  99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 53, 48,
  37, 44, 53, 48, 37, 44, 48, 44, 49, 44, 50, 32, 45, 110, 109, 91,
  45, 49, 93, 32, 97, 114, 114, 111, 119, 95, 101, 113, 95, 109, 97, 115,
  107, 10, 45, 45, 42, 91, 45, 49, 93, 32, 50, 48, 48, 32, 45, 45,
  42, 91, 45, 50, 93, 32, 50, 48, 48, 32, 45, 45, 42, 91, 45, 51,
  93, 32, 50, 48, 48, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32,
  99, 32, 45, 110, 109, 91, 45, 49, 93, 32, 97, 114, 114, 111, 119, 95,
  101, 113, 10, 45, 114, 51, 100, 91, 45, 51, 93, 32, 48, 44, 48, 44,
  49, 44, 51, 53, 10, 49, 50, 56, 44, 49, 50, 56, 32, 45, 111, 98,
  106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 52, 93, 44,
  53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 49, 44, 50, 32, 45, 110,
  109, 91, 45, 49, 93, 32, 97, 114, 114, 111, 119, 95, 117, 112, 95, 109,
  97, 115, 107, 10, 45, 45, 42, 91, 45, 49, 93, 32, 54, 52, 32, 45,
  45, 42, 91, 45, 50, 93, 32, 50, 53, 53, 32, 45, 45, 42, 91, 45,
  51, 93, 32, 54, 52, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32,
  99, 32, 45, 110, 109, 91, 45, 49, 93, 32, 97, 114, 114, 111, 119, 95,
  117, 112, 10, 45, 114, 51, 100, 91, 45, 53, 93, 32, 48, 44, 48, 44,
  49, 44, 45, 55, 48, 10, 49, 50, 56, 44, 49, 50, 56, 32, 45, 111,
  98, 106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 54, 93,
  44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 49, 44, 50, 32, 45,
  110, 109, 91, 45, 49, 93, 32, 97, 114, 114, 111, 119, 95, 100, 111, 119,
  110, 95, 109, 97, 115, 107, 10, 45, 45, 42, 91, 45, 49, 93, 32, 50,
  53, 53, 32, 45, 45, 42, 91, 45, 50, 93, 32, 54, 52, 32, 45, 45,
  42, 91, 45, 51, 93, 32, 51, 50, 32, 45, 97, 91, 45, 51, 45, 45,
  49, 93, 32, 99, 32, 45, 110, 109, 91, 45, 49, 93, 32, 97, 114, 114,
  111, 119, 95, 100, 111, 119, 110, 10, 45, 100, 105, 108, 97, 116, 101, 91,
  97, 114, 114, 111, 119, 95, 101, 113, 95, 109, 97, 115, 107, 44, 97, 114,
  114, 111, 119, 95, 117, 112, 95, 109, 97, 115, 107, 44, 97, 114, 114, 111,
  119, 95, 100, 111, 119, 110, 95, 109, 97, 115, 107, 93, 32, 51, 10, 45,
  114, 109, 91, 45, 55, 93, 10, 98, 111, 97, 114, 100, 61, 64, 35, 10,
  105, 61, 64, 35, 10, 45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100,
  32, 34, 82, 97, 110, 107, 34, 44, 52, 56, 44, 36, 114, 111, 119, 95,
  104, 101, 105, 103, 104, 116, 44, 49, 54, 44, 49, 44, 54, 10, 45, 95,
  103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 32, 34, 44, 36, 114,
  111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 36, 114, 111, 119, 95, 104,
  101, 105, 103, 104, 116, 44, 49, 54, 44, 49, 44, 54, 10, 45, 95, 103,
  112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 78, 97, 109, 101, 34, 44,
  49, 53, 48, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44,
  49, 54, 44, 49, 44, 54, 10, 45, 95, 103, 112, 116, 95, 102, 105, 101,
  108, 100, 32, 34, 83, 99, 111, 114, 101, 34, 44, 56, 48, 44, 36, 114,
  111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 49, 54, 44, 49, 44, 54,
  10, 45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 67, 104,
  105, 112, 115, 92, 110, 91, 109, 97, 108, 117, 115, 93, 34, 44, 56, 48,
  44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 50, 52, 44,
  49, 44, 54, 10, 45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32,
  34, 80, 108, 97, 121, 101, 100, 34, 44, 52, 56, 44, 36, 114, 111, 119,
  95, 104, 101, 105, 103, 104, 116, 44, 49, 50, 44, 49, 44, 54, 10, 45,
  95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 87, 111, 110, 47,
  92, 110, 76, 111, 115, 116, 34, 44, 52, 56, 44, 36, 114, 111, 119, 95,
  104, 101, 105, 103, 104, 116, 44, 50, 52, 44, 49, 44, 54, 10, 45, 105,
  102, 32, 36, 50, 32, 45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100,
  32, 34, 84, 114, 100, 34, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103,
  104, 116, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 49,
  50, 44, 49, 44, 54, 10, 45, 101, 108, 115, 101, 32, 45, 95, 103, 112,
  116, 95, 102, 105, 101, 108, 100, 32, 34, 84, 114, 101, 110, 100, 34, 44,
  36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 36, 114, 111, 119,
  95, 104, 101, 105, 103, 104, 116, 44, 49, 50, 44, 49, 44, 54, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 50, 32, 45, 95, 103,
  112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 83, 116, 97, 116, 115, 34,
  44, 123, 50, 42, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 125,
  44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 49, 50, 44,
  49, 44, 54, 10, 45, 101, 108, 115, 101, 32, 45, 95, 103, 112, 116, 95,
  102, 105, 101, 108, 100, 32, 34, 83, 116, 97, 116, 105, 115, 116, 105, 99,
  115, 34, 44, 123, 52, 42, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104,
  116, 43, 50, 125, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116,
  44, 49, 50, 44, 49, 44, 54, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 76, 97, 115, 116,
  92, 110, 40, 114, 97, 110, 107, 41, 34, 44, 54, 52, 44, 36, 114, 111,
  119, 95, 104, 101, 105, 103, 104, 116, 44, 50, 52, 44, 49, 44, 54, 10,
  45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 66, 101, 115,
  116, 92, 110, 40, 114, 97, 110, 107, 41, 34, 44, 54, 52, 44, 36, 114,
  111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 50, 52, 44, 49, 44, 54,
  10, 45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 72, 105,
  103, 104, 101, 115, 116, 92, 110, 99, 104, 105, 112, 115, 32, 40, 114, 97,
  110, 107, 41, 34, 44, 54, 52, 44, 36, 114, 111, 119, 95, 104, 101, 105,
  103, 104, 116, 44, 50, 52, 44, 49, 44, 54, 10, 45, 95, 103, 112, 116,
  95, 102, 105, 101, 108, 100, 32, 34, 76, 111, 119, 101, 115, 116, 92, 110,
  99, 104, 105, 112, 115, 32, 40, 114, 97, 110, 107, 41, 34, 44, 54, 52,
  44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 50, 52, 44,
  49, 44, 54, 10, 45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32,
  34, 80, 101, 114, 102, 111, 114, 109, 97, 110, 99, 101, 92, 110, 32, 32,
  32, 40, 114, 97, 110, 107, 41, 34, 44, 54, 52, 44, 36, 114, 111, 119,
  95, 104, 101, 105, 103, 104, 116, 44, 50, 52, 44, 49, 44, 54, 10, 45,
  95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 65, 118, 101, 114,
  97, 103, 101, 92, 110, 91, 115, 116, 100, 93, 32, 40, 114, 97, 110, 107,
  41, 34, 44, 49, 48, 48, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103,
  104, 116, 44, 50, 52, 44, 49, 44, 54, 10, 45, 95, 103, 112, 116, 95,
  102, 105, 101, 108, 100, 32, 34, 67, 111, 102, 102, 101, 101, 32, 98, 97,
  108, 97, 110, 99, 101, 92, 110, 32, 32, 32, 32, 32, 40, 114, 97, 110,
  107, 41, 34, 44, 56, 48, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103,
  104, 116, 44, 50, 52, 44, 49, 44, 54, 10, 45, 97, 91, 36, 105, 45,
  45, 49, 93, 32, 120, 10, 109, 97, 120, 95, 112, 108, 97, 121, 101, 114,
  115, 61, 64, 123, 110, 98, 95, 112, 108, 97, 121, 101, 114, 115, 44, 77,
  125, 10, 45, 45, 122, 91, 114, 97, 110, 107, 93, 32, 48, 44, 48, 32,
  109, 97, 120, 95, 114, 97, 110, 107, 61, 123, 105, 77, 125, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 45, 122, 91, 112, 101, 114, 102, 111, 114,
  109, 97, 110, 99, 101, 93, 32, 49, 44, 49, 32, 109, 97, 120, 95, 112,
  101, 114, 102, 111, 114, 109, 97, 110, 99, 101, 95, 114, 97, 110, 107, 61,
  123, 105, 77, 45, 49, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  45, 122, 91, 98, 101, 115, 116, 95, 115, 99, 111, 114, 101, 93, 32, 49,
  44, 49, 32, 109, 97, 120, 95, 98, 101, 115, 116, 95, 115, 99, 111, 114,
  101, 95, 114, 97, 110, 107, 61, 123, 105, 77, 45, 49, 125, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 45, 122, 91, 97, 118, 101, 114, 97, 103,
  101, 93, 32, 49, 44, 49, 32, 109, 97, 120, 95, 97, 118, 101, 114, 97,
  103, 101, 95, 114, 97, 110, 107, 61, 123, 105, 77, 45, 49, 125, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 45, 122, 91, 99, 111, 102, 102, 101,
  101, 95, 98, 97, 108, 97, 110, 99, 101, 93, 32, 49, 44, 49, 32, 109,
  97, 120, 95, 99, 111, 102, 102, 101, 101, 95, 98, 97, 108, 97, 110, 99,
  101, 95, 114, 97, 110, 107, 61, 123, 105, 77, 125, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 123, 114, 97,
  110, 107, 44, 104, 125, 10, 112, 61, 64, 123, 114, 97, 110, 107, 44, 40,
  49, 44, 36, 62, 41, 125, 10, 110, 61, 64, 123, 110, 98, 95, 103, 97,
  109, 101, 115, 44, 40, 48, 44, 36, 112, 41, 125, 10, 99, 61, 123, 105,
  102, 40, 64, 123, 110, 98, 95, 103, 97, 109, 101, 115, 44, 40, 48, 44,
  36, 112, 41, 125, 61, 61, 48, 44, 48, 44, 118, 61, 64, 123, 115, 99,
  111, 114, 101, 44, 40, 49, 44, 36, 112, 41, 125, 59, 105, 102, 40, 118,
  62, 61, 49, 38, 38, 118, 60, 61, 51, 44, 118, 44, 105, 102, 40, 118,
  61, 61, 36, 109, 97, 120, 95, 114, 97, 110, 107, 45, 49, 44, 52, 44,
  105, 102, 40, 118, 61, 61, 36, 109, 97, 120, 95, 114, 97, 110, 107, 44,
  53, 44, 48, 41, 41, 41, 41, 125, 10, 105, 61, 64, 35, 10, 116, 95,
  114, 97, 110, 107, 61, 64, 123, 115, 99, 111, 114, 101, 44, 40, 49, 44,
  36, 112, 41, 125, 10, 45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100,
  32, 36, 116, 95, 114, 97, 110, 107, 44, 52, 56, 44, 36, 114, 111, 119,
  95, 104, 101, 105, 103, 104, 116, 44, 49, 54, 44, 49, 44, 36, 99, 10,
  45, 105, 102, 32, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109, 112, 125,
  47, 36, 123, 112, 108, 97, 121, 101, 114, 36, 123, 112, 125, 95, 102, 105,
  108, 101, 125, 32, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109, 112, 125,
  47, 36, 123, 112, 108, 97, 121, 101, 114, 36, 123, 112, 125, 95, 102, 105,
  108, 101, 125, 10, 45, 101, 108, 115, 101, 32, 36, 123, 112, 108, 97, 121,
  101, 114, 36, 123, 112, 125, 95, 117, 114, 108, 125, 36, 123, 112, 108, 97,
  121, 101, 114, 36, 123, 112, 125, 95, 102, 105, 108, 101, 125, 32, 45, 111,
  91, 45, 49, 93, 32, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109, 112,
  125, 47, 36, 123, 112, 108, 97, 121, 101, 114, 36, 123, 112, 125, 95, 102,
  105, 108, 101, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95,
  114, 103, 98, 91, 45, 49, 93, 32, 45, 45, 91, 45, 49, 93, 32, 50,
  53, 53, 32, 45, 114, 114, 50, 100, 91, 45, 49, 93, 32, 123, 36, 114,
  111, 119, 95, 104, 101, 105, 103, 104, 116, 45, 50, 125, 44, 123, 36, 114,
  111, 119, 95, 104, 101, 105, 103, 104, 116, 45, 50, 125, 44, 50, 44, 50,
  32, 45, 43, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 102, 114, 97,
  109, 101, 91, 45, 49, 93, 32, 49, 44, 49, 44, 48, 10, 116, 95, 110,
  97, 109, 101, 61, 64, 123, 45, 95, 103, 112, 116, 95, 114, 101, 109, 111,
  118, 101, 95, 117, 110, 100, 101, 114, 115, 99, 111, 114, 101, 92, 32, 36,
  123, 112, 108, 97, 121, 101, 114, 36, 123, 112, 125, 95, 110, 97, 109, 101,
  125, 125, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 36, 116, 95, 110,
  97, 109, 101, 44, 48, 44, 48, 44, 51, 50, 44, 49, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 114, 91, 45, 49, 93, 32,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 52, 10, 45, 115,
  104, 91, 45, 49, 93, 32, 48, 44, 50, 32, 45, 42, 91, 45, 49, 93,
  32, 39, 40, 50, 45, 99, 41, 42, 48, 46, 57, 42, 121, 47, 104, 39,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 100, 114, 111, 112, 95, 115,
  104, 97, 100, 111, 119, 91, 45, 49, 93, 32, 49, 44, 49, 44, 49, 10,
  45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 32, 34, 44,
  50, 50, 53, 44, 123, 49, 46, 53, 42, 36, 114, 111, 119, 95, 104, 101,
  105, 103, 104, 116, 125, 44, 50, 48, 44, 49, 44, 36, 99, 32, 45, 109,
  118, 91, 45, 49, 93, 32, 45, 50, 10, 45, 98, 108, 101, 110, 100, 91,
  45, 50, 44, 45, 49, 93, 32, 97, 108, 112, 104, 97, 10, 45, 114, 50,
  100, 121, 91, 45, 49, 93, 32, 36, 114, 111, 119, 95, 104, 101, 105, 103,
  104, 116, 10, 45, 122, 91, 45, 49, 93, 32, 49, 44, 49, 44, 123, 119,
  45, 50, 125, 44, 123, 104, 45, 50, 125, 32, 45, 102, 114, 97, 109, 101,
  91, 45, 49, 93, 32, 49, 44, 49, 44, 48, 10, 116, 95, 115, 99, 111,
  114, 101, 61, 64, 123, 115, 99, 111, 114, 101, 44, 40, 48, 44, 36, 112,
  41, 125, 10, 45, 105, 102, 32, 123, 36, 116, 95, 115, 99, 111, 114, 101,
  62, 48, 125, 32, 116, 95, 115, 99, 111, 114, 101, 61, 43, 36, 116, 95,
  115, 99, 111, 114, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103,
  112, 116, 95, 102, 105, 101, 108, 100, 32, 36, 116, 95, 115, 99, 111, 114,
  101, 44, 56, 48, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116,
  44, 50, 48, 44, 36, 110, 44, 36, 99, 10, 116, 95, 99, 104, 105, 112,
  115, 61, 64, 123, 99, 104, 105, 112, 115, 44, 40, 48, 44, 36, 112, 41,
  125, 10, 116, 95, 109, 97, 108, 117, 115, 61, 123, 45, 64, 123, 97, 98,
  115, 95, 109, 97, 108, 117, 115, 44, 40, 48, 44, 36, 112, 41, 125, 125,
  10, 45, 105, 102, 32, 123, 36, 116, 95, 99, 104, 105, 112, 115, 62, 48,
  125, 32, 116, 95, 99, 104, 105, 112, 115, 61, 43, 36, 116, 95, 99, 104,
  105, 112, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103, 112, 116,
  95, 102, 105, 101, 108, 100, 32, 36, 116, 95, 99, 104, 105, 112, 115, 92,
  32, 91, 36, 116, 95, 109, 97, 108, 117, 115, 93, 44, 56, 48, 44, 36,
  114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 49, 54, 44, 36, 110,
  44, 36, 99, 10, 116, 95, 110, 98, 95, 103, 97, 109, 101, 115, 61, 64,
  123, 110, 98, 95, 103, 97, 109, 101, 115, 44, 40, 48, 44, 36, 112, 41,
  125, 10, 45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 36, 116,
  95, 110, 98, 95, 103, 97, 109, 101, 115, 44, 52, 56, 44, 36, 114, 111,
  119, 95, 104, 101, 105, 103, 104, 116, 44, 49, 54, 44, 36, 110, 44, 36,
  99, 10, 45, 45, 114, 111, 119, 115, 91, 119, 105, 110, 110, 101, 114, 115,
  93, 32, 36, 112, 10, 116, 95, 119, 111, 110, 61, 64, 123, 45, 49, 44,
  43, 125, 10, 45, 45, 114, 111, 119, 115, 91, 108, 111, 115, 101, 114, 115,
  93, 32, 36, 112, 10, 116, 95, 108, 111, 115, 116, 61, 64, 123, 45, 49,
  44, 43, 125, 10, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45,
  95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 36, 116, 95, 119, 111,
  110, 47, 36, 116, 95, 108, 111, 115, 116, 44, 52, 56, 44, 36, 114, 111,
  119, 95, 104, 101, 105, 103, 104, 116, 44, 49, 54, 44, 36, 110, 44, 36,
  99, 10, 45, 105, 102, 32, 123, 33, 36, 110, 125, 32, 123, 36, 114, 111,
  119, 95, 104, 101, 105, 103, 104, 116, 45, 50, 125, 44, 123, 36, 114, 111,
  119, 95, 104, 101, 105, 103, 104, 116, 45, 50, 125, 44, 49, 44, 51, 44,
  50, 53, 53, 32, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93, 32, 49,
  44, 49, 44, 48, 10, 45, 101, 108, 115, 101, 10, 116, 95, 116, 114, 101,
  110, 100, 61, 123, 45, 64, 123, 116, 114, 101, 110, 100, 44, 40, 48, 44,
  36, 112, 41, 125, 125, 10, 45, 95, 103, 112, 116, 95, 102, 105, 101, 108,
  100, 32, 34, 32, 34, 44, 49, 50, 56, 44, 49, 50, 56, 44, 49, 54,
  44, 36, 110, 44, 36, 99, 10, 45, 105, 102, 32, 123, 36, 116, 95, 116,
  114, 101, 110, 100, 62, 48, 125, 32, 116, 95, 116, 114, 101, 110, 100, 61,
  43, 36, 116, 95, 116, 114, 101, 110, 100, 32, 45, 106, 91, 45, 49, 93,
  32, 91, 97, 114, 114, 111, 119, 95, 117, 112, 93, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 49, 44, 91, 97, 114, 114, 111, 119, 95, 117, 112, 95,
  109, 97, 115, 107, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 116, 95,
  116, 114, 101, 110, 100, 60, 48, 125, 32, 45, 106, 91, 45, 49, 93, 32,
  91, 97, 114, 114, 111, 119, 95, 100, 111, 119, 110, 93, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 49, 44, 91, 97, 114, 114, 111, 119, 95, 100, 111,
  119, 110, 95, 109, 97, 115, 107, 93, 10, 45, 101, 108, 115, 101, 32, 45,
  106, 91, 45, 49, 93, 32, 91, 97, 114, 114, 111, 119, 95, 101, 113, 93,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 97, 114, 114, 111,
  119, 95, 101, 113, 95, 109, 97, 115, 107, 93, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 114, 50, 100, 121, 91, 45, 49, 93, 32, 36, 114, 111, 119,
  95, 104, 101, 105, 103, 104, 116, 10, 45, 105, 102, 32, 36, 50, 10, 45,
  122, 91, 45, 49, 93, 32, 49, 44, 49, 44, 123, 119, 45, 50, 125, 44,
  123, 104, 45, 50, 125, 32, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93,
  32, 49, 44, 49, 44, 48, 10, 45, 101, 108, 115, 101, 10, 45, 105, 102,
  32, 123, 36, 116, 95, 116, 114, 101, 110, 100, 62, 48, 125, 32, 45, 95,
  103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 92, 110, 92, 110, 32,
  32, 32, 32, 34, 36, 116, 95, 116, 114, 101, 110, 100, 44, 36, 114, 111,
  119, 95, 104, 101, 105, 103, 104, 116, 44, 36, 114, 111, 119, 95, 104, 101,
  105, 103, 104, 116, 44, 52, 56, 44, 36, 110, 44, 48, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 116, 95, 116, 114, 101, 110, 100, 60, 48, 125, 32,
  45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 92, 110, 92,
  110, 34, 36, 116, 95, 116, 114, 101, 110, 100, 34, 32, 32, 32, 32, 32,
  34, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 36, 114,
  111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 52, 56, 44, 36, 110, 44,
  48, 10, 45, 101, 108, 115, 101, 32, 45, 95, 103, 112, 116, 95, 102, 105,
  101, 108, 100, 32, 34, 32, 34, 44, 36, 114, 111, 119, 95, 104, 101, 105,
  103, 104, 116, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44,
  52, 56, 44, 36, 110, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  47, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 42, 91, 45, 50, 44,
  45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 33, 36, 110, 125, 32, 123, 105, 102, 40,
  36, 50, 44, 50, 42, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116,
  44, 52, 42, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 43, 50,
  41, 125, 44, 123, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 125,
  44, 49, 44, 51, 44, 50, 53, 53, 10, 45, 101, 108, 115, 101, 10, 123,
  51, 42, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 125, 44, 123,
  49, 46, 53, 42, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 125,
  44, 49, 44, 51, 44, 50, 53, 53, 10, 45, 45, 114, 111, 119, 115, 91,
  114, 97, 110, 107, 115, 93, 32, 36, 112, 44, 36, 112, 32, 45, 104, 105,
  115, 116, 111, 103, 114, 97, 109, 91, 45, 49, 93, 32, 36, 109, 97, 120,
  95, 112, 108, 97, 121, 101, 114, 115, 44, 49, 44, 36, 109, 97, 120, 95,
  112, 108, 97, 121, 101, 114, 115, 10, 45, 103, 114, 97, 112, 104, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 44, 51, 44, 48, 44, 48, 44, 48, 44,
  48, 46, 50, 44, 48, 44, 54, 52, 44, 50, 53, 53, 10, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 45, 114, 111, 119, 115, 91, 115, 99, 111, 114,
  101, 115, 93, 32, 36, 112, 10, 45, 100, 105, 115, 99, 97, 114, 100, 91,
  45, 49, 93, 32, 45, 49, 32, 45, 45, 91, 45, 49, 93, 32, 49, 48,
  48, 32, 45, 99, 117, 109, 117, 108, 91, 45, 49, 93, 32, 115, 97, 61,
  123, 105, 97, 125, 32, 115, 109, 61, 123, 105, 109, 125, 32, 115, 77, 61,
  123, 105, 77, 125, 10, 45, 103, 114, 105, 100, 91, 45, 50, 93, 32, 123,
  109, 97, 120, 40, 50, 48, 44, 49, 48, 48, 47, 109, 97, 120, 40, 49,
  44, 104, 45, 49, 41, 41, 125, 37, 44, 49, 48, 44, 48, 44, 48, 44,
  48, 46, 54, 44, 48, 120, 67, 67, 67, 67, 67, 67, 67, 67, 44, 48,
  10, 40, 48, 44, 48, 41, 32, 45, 103, 114, 97, 112, 104, 91, 45, 51,
  93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 123, 36, 115, 77, 43,
  49, 48, 125, 44, 123, 36, 115, 109, 45, 49, 48, 125, 44, 49, 44, 48,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 40, 36, 115, 97, 44, 36, 115,
  97, 41, 32, 45, 103, 114, 97, 112, 104, 91, 45, 51, 93, 32, 91, 45,
  49, 93, 44, 49, 44, 48, 44, 123, 36, 115, 77, 43, 49, 48, 125, 44,
  123, 36, 115, 109, 45, 49, 48, 125, 44, 49, 44, 48, 120, 53, 53, 53,
  53, 53, 53, 53, 53, 44, 48, 44, 49, 53, 48, 44, 48, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 103, 114, 97, 112, 104, 91, 45, 50, 93,
  32, 91, 45, 49, 93, 44, 50, 44, 48, 44, 123, 36, 115, 77, 43, 49,
  48, 125, 44, 123, 36, 115, 109, 45, 49, 48, 125, 44, 49, 44, 50, 53,
  53, 44, 51, 50, 44, 52, 56, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 114, 50, 100, 121, 91, 45, 49, 93, 32, 123, 36, 114, 111, 119, 95,
  104, 101, 105, 103, 104, 116, 125, 10, 45, 105, 102, 32, 123, 33, 36, 50,
  125, 10, 49, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44,
  49, 44, 51, 44, 48, 10, 45, 45, 114, 111, 119, 115, 91, 114, 97, 110,
  107, 115, 93, 32, 36, 112, 32, 45, 104, 105, 115, 116, 111, 103, 114, 97,
  109, 91, 45, 49, 93, 32, 36, 109, 97, 120, 95, 112, 108, 97, 121, 101,
  114, 115, 44, 49, 44, 36, 109, 97, 120, 95, 112, 108, 97, 121, 101, 114,
  115, 32, 45, 121, 91, 45, 49, 93, 10, 105, 112, 61, 64, 35, 10, 40,
  49, 44, 49, 48, 44, 50, 53, 53, 44, 50, 52, 50, 44, 49, 53, 51,
  41, 10, 40, 50, 44, 49, 48, 44, 50, 50, 50, 44, 50, 50, 50, 44,
  50, 50, 50, 41, 10, 40, 51, 44, 49, 48, 44, 50, 51, 50, 44, 50,
  48, 57, 44, 49, 57, 54, 41, 10, 40, 123, 36, 109, 97, 120, 95, 112,
  108, 97, 121, 101, 114, 115, 45, 49, 125, 44, 49, 48, 44, 50, 53, 53,
  44, 50, 48, 52, 44, 50, 48, 52, 41, 10, 40, 36, 109, 97, 120, 95,
  112, 108, 97, 121, 101, 114, 115, 44, 49, 48, 44, 50, 53, 53, 44, 49,
  53, 51, 44, 49, 53, 51, 41, 10, 45, 105, 102, 32, 123, 36, 109, 97,
  120, 95, 112, 108, 97, 121, 101, 114, 115, 61, 61, 49, 125, 32, 45, 114,
  109, 91, 45, 52, 45, 45, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 109, 97, 120, 95, 112, 108, 97, 121, 101, 114, 115, 61, 61, 50, 125,
  32, 45, 114, 109, 91, 45, 51, 45, 45, 49, 93, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 109, 97, 120, 95, 112, 108, 97, 121, 101, 114, 115, 61,
  61, 51, 125, 32, 45, 114, 109, 91, 45, 50, 45, 45, 49, 93, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 109, 97, 120, 95, 112, 108, 97, 121, 101,
  114, 115, 61, 61, 52, 125, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 109, 97, 120, 95, 112, 108, 97, 121, 101,
  114, 115, 62, 53, 125, 32, 45, 97, 91, 45, 51, 44, 45, 50, 93, 32,
  121, 32, 45, 114, 91, 45, 50, 93, 32, 49, 48, 48, 37, 44, 123, 36,
  109, 97, 120, 95, 112, 108, 97, 121, 101, 114, 115, 45, 51, 125, 44, 49,
  44, 49, 44, 51, 32, 45, 114, 111, 117, 110, 100, 91, 45, 50, 93, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 97, 91, 36, 105, 112, 45, 45, 49,
  93, 32, 121, 10, 45, 106, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44,
  49, 44, 48, 32, 45, 114, 109, 91, 45, 50, 93, 10, 50, 53, 54, 44,
  50, 53, 54, 44, 49, 44, 51, 44, 50, 53, 53, 32, 45, 112, 105, 101,
  99, 104, 97, 114, 116, 91, 45, 49, 93, 32, 53, 55, 44, 48, 44, 48,
  44, 48, 44, 64, 45, 50, 44, 34, 97, 98, 115, 46, 34, 44, 123, 64,
  123, 115, 99, 111, 114, 101, 115, 44, 119, 125, 45, 64, 123, 110, 98, 95,
  103, 97, 109, 101, 115, 44, 40, 48, 44, 36, 112, 41, 125, 125, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 102, 114, 97, 109,
  101, 91, 45, 49, 93, 32, 49, 48, 44, 49, 48, 44, 50, 53, 53, 10,
  49, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 49, 44,
  51, 44, 48, 10, 50, 53, 54, 44, 50, 53, 54, 44, 49, 44, 51, 44,
  50, 53, 53, 32, 45, 112, 105, 101, 99, 104, 97, 114, 116, 91, 45, 49,
  93, 32, 53, 55, 44, 48, 44, 48, 44, 48, 44, 64, 45, 52, 32, 45,
  102, 114, 97, 109, 101, 91, 45, 49, 93, 32, 49, 48, 44, 49, 48, 44,
  50, 53, 53, 10, 45, 114, 109, 91, 45, 52, 93, 32, 45, 114, 50, 100,
  121, 91, 45, 51, 44, 45, 49, 93, 32, 36, 114, 111, 119, 95, 104, 101,
  105, 103, 104, 116, 10, 45, 97, 91, 45, 53, 45, 45, 49, 93, 32, 120,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  122, 91, 45, 49, 93, 32, 49, 44, 49, 44, 123, 119, 45, 50, 125, 44,
  123, 104, 45, 50, 125, 32, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93,
  32, 49, 44, 49, 44, 48, 10, 116, 95, 108, 97, 115, 116, 95, 115, 99,
  111, 114, 101, 61, 64, 123, 115, 99, 111, 114, 101, 115, 44, 40, 49, 48,
  48, 37, 44, 36, 112, 41, 125, 10, 45, 105, 102, 32, 123, 36, 116, 95,
  108, 97, 115, 116, 95, 115, 99, 111, 114, 101, 61, 61, 45, 49, 125, 32,
  116, 95, 108, 97, 115, 116, 61, 97, 98, 115, 46, 10, 45, 101, 108, 115,
  101, 10, 116, 95, 108, 97, 115, 116, 95, 115, 99, 111, 114, 101, 61, 123,
  36, 116, 95, 108, 97, 115, 116, 95, 115, 99, 111, 114, 101, 45, 49, 48,
  48, 125, 10, 45, 105, 102, 32, 123, 36, 116, 95, 108, 97, 115, 116, 95,
  115, 99, 111, 114, 101, 62, 48, 125, 32, 116, 95, 108, 97, 115, 116, 95,
  115, 99, 111, 114, 101, 61, 43, 36, 116, 95, 108, 97, 115, 116, 95, 115,
  99, 111, 114, 101, 32, 45, 101, 110, 100, 105, 102, 10, 116, 95, 108, 97,
  115, 116, 95, 114, 97, 110, 107, 61, 64, 123, 114, 97, 110, 107, 115, 44,
  40, 49, 48, 48, 37, 44, 36, 112, 41, 125, 10, 116, 95, 108, 97, 115,
  116, 61, 36, 116, 95, 108, 97, 115, 116, 95, 115, 99, 111, 114, 101, 92,
  32, 40, 36, 116, 95, 108, 97, 115, 116, 95, 114, 97, 110, 107, 41, 10,
  45, 101, 110, 100, 105, 102, 10, 99, 61, 123, 118, 61, 64, 123, 114, 97,
  110, 107, 115, 44, 40, 49, 48, 48, 37, 44, 36, 112, 41, 125, 59, 105,
  102, 40, 118, 62, 61, 49, 38, 38, 118, 60, 61, 51, 44, 118, 44, 105,
  102, 40, 118, 61, 61, 64, 123, 110, 98, 95, 112, 108, 97, 121, 101, 114,
  115, 44, 45, 49, 125, 45, 49, 44, 52, 44, 105, 102, 40, 118, 61, 61,
  64, 123, 110, 98, 95, 112, 108, 97, 121, 101, 114, 115, 44, 45, 49, 125,
  44, 53, 44, 48, 41, 41, 41, 125, 10, 45, 95, 103, 112, 116, 95, 102,
  105, 101, 108, 100, 32, 36, 116, 95, 108, 97, 115, 116, 44, 54, 52, 44,
  36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 49, 54, 44, 36,
  110, 44, 36, 99, 10, 116, 95, 98, 101, 115, 116, 95, 115, 99, 111, 114,
  101, 61, 123, 118, 61, 64, 123, 98, 101, 115, 116, 95, 115, 99, 111, 114,
  101, 44, 40, 48, 44, 36, 112, 41, 125, 59, 105, 102, 40, 118, 61, 61,
  45, 49, 44, 45, 49, 44, 118, 41, 125, 10, 116, 95, 98, 101, 115, 116,
  95, 114, 97, 110, 107, 61, 64, 123, 98, 101, 115, 116, 95, 115, 99, 111,
  114, 101, 44, 40, 49, 44, 36, 112, 41, 125, 10, 45, 105, 102, 32, 123,
  36, 116, 95, 98, 101, 115, 116, 95, 115, 99, 111, 114, 101, 62, 48, 125,
  32, 116, 95, 98, 101, 115, 116, 95, 115, 99, 111, 114, 101, 61, 43, 36,
  116, 95, 98, 101, 115, 116, 95, 115, 99, 111, 114, 101, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 116, 95, 98, 101, 115, 116, 95, 115, 99, 111, 114,
  101, 61, 61, 45, 49, 125, 32, 116, 95, 98, 101, 115, 116, 95, 115, 99,
  111, 114, 101, 61, 97, 98, 115, 46, 10, 45, 101, 110, 100, 105, 102, 10,
  99, 61, 123, 118, 61, 64, 123, 98, 101, 115, 116, 95, 115, 99, 111, 114,
  101, 44, 40, 49, 44, 36, 112, 41, 125, 59, 105, 102, 40, 118, 62, 61,
  49, 38, 38, 118, 60, 61, 51, 44, 118, 44, 105, 102, 40, 118, 61, 61,
  36, 109, 97, 120, 95, 98, 101, 115, 116, 95, 115, 99, 111, 114, 101, 95,
  114, 97, 110, 107, 45, 49, 44, 52, 44, 105, 102, 40, 118, 61, 61, 36,
  109, 97, 120, 95, 98, 101, 115, 116, 95, 115, 99, 111, 114, 101, 95, 114,
  97, 110, 107, 44, 53, 44, 48, 41, 41, 41, 125, 10, 45, 95, 103, 112,
  116, 95, 102, 105, 101, 108, 100, 32, 36, 116, 95, 98, 101, 115, 116, 95,
  115, 99, 111, 114, 101, 92, 32, 40, 36, 116, 95, 98, 101, 115, 116, 95,
  114, 97, 110, 107, 41, 44, 54, 52, 44, 36, 114, 111, 119, 95, 104, 101,
  105, 103, 104, 116, 44, 49, 54, 44, 36, 110, 44, 36, 99, 10, 116, 95,
  104, 105, 103, 104, 101, 115, 116, 95, 99, 104, 105, 112, 115, 61, 123, 118,
  61, 64, 123, 104, 105, 103, 104, 101, 115, 116, 95, 99, 104, 105, 112, 115,
  44, 40, 48, 44, 36, 112, 41, 125, 59, 105, 102, 40, 118, 61, 61, 45,
  49, 44, 45, 49, 44, 118, 41, 125, 10, 116, 95, 104, 105, 103, 104, 101,
  115, 116, 95, 114, 97, 110, 107, 61, 64, 123, 104, 105, 103, 104, 101, 115,
  116, 95, 99, 104, 105, 112, 115, 44, 40, 49, 44, 36, 112, 41, 125, 10,
  45, 105, 102, 32, 123, 36, 116, 95, 104, 105, 103, 104, 101, 115, 116, 95,
  99, 104, 105, 112, 115, 62, 48, 125, 32, 116, 95, 104, 105, 103, 104, 101,
  115, 116, 95, 99, 104, 105, 112, 115, 61, 43, 36, 116, 95, 104, 105, 103,
  104, 101, 115, 116, 95, 99, 104, 105, 112, 115, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 116, 95, 104, 105, 103, 104, 101, 115, 116, 95, 99, 104, 105,
  112, 115, 61, 61, 45, 49, 125, 32, 116, 95, 104, 105, 103, 104, 101, 115,
  116, 95, 99, 104, 105, 112, 115, 61, 97, 98, 115, 46, 10, 45, 101, 110,
  100, 105, 102, 10, 99, 61, 123, 118, 61, 64, 123, 104, 105, 103, 104, 101,
  115, 116, 95, 99, 104, 105, 112, 115, 44, 40, 49, 44, 36, 112, 41, 125,
  59, 105, 102, 40, 118, 62, 61, 49, 38, 38, 118, 60, 61, 51, 44, 118,
  44, 105, 102, 40, 118, 61, 61, 36, 109, 97, 120, 95, 98, 101, 115, 116,
  95, 115, 99, 111, 114, 101, 95, 114, 97, 110, 107, 45, 49, 44, 52, 44,
  105, 102, 40, 118, 61, 61, 36, 109, 97, 120, 95, 98, 101, 115, 116, 95,
  115, 99, 111, 114, 101, 95, 114, 97, 110, 107, 44, 53, 44, 48, 41, 41,
  41, 125, 10, 45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 36,
  116, 95, 104, 105, 103, 104, 101, 115, 116, 95, 99, 104, 105, 112, 115, 92,
  32, 40, 36, 116, 95, 104, 105, 103, 104, 101, 115, 116, 95, 114, 97, 110,
  107, 41, 44, 54, 52, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104,
  116, 44, 49, 54, 44, 36, 110, 44, 36, 99, 10, 116, 95, 108, 111, 119,
  101, 115, 116, 95, 99, 104, 105, 112, 115, 61, 123, 118, 61, 64, 123, 108,
  111, 119, 101, 115, 116, 95, 99, 104, 105, 112, 115, 44, 40, 48, 44, 36,
  112, 41, 125, 59, 105, 102, 40, 118, 61, 61, 45, 49, 44, 45, 49, 44,
  118, 41, 125, 10, 116, 95, 108, 111, 119, 101, 115, 116, 95, 114, 97, 110,
  107, 61, 64, 123, 108, 111, 119, 101, 115, 116, 95, 99, 104, 105, 112, 115,
  44, 40, 49, 44, 36, 112, 41, 125, 10, 45, 105, 102, 32, 123, 36, 116,
  95, 108, 111, 119, 101, 115, 116, 95, 99, 104, 105, 112, 115, 62, 48, 125,
  32, 116, 95, 108, 111, 119, 101, 115, 116, 95, 99, 104, 105, 112, 115, 61,
  43, 36, 116, 95, 108, 111, 119, 101, 115, 116, 95, 99, 104, 105, 112, 115,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 116, 95, 108, 111, 119, 101, 115,
  116, 95, 99, 104, 105, 112, 115, 61, 61, 45, 49, 125, 32, 116, 95, 108,
  111, 119, 101, 115, 116, 95, 99, 104, 105, 112, 115, 61, 97, 98, 115, 46,
  10, 45, 101, 110, 100, 105, 102, 10, 99, 61, 123, 118, 61, 64, 123, 108,
  111, 119, 101, 115, 116, 95, 99, 104, 105, 112, 115, 44, 40, 49, 44, 36,
  112, 41, 125, 59, 105, 102, 40, 118, 62, 61, 49, 38, 38, 118, 60, 61,
  51, 44, 118, 44, 105, 102, 40, 118, 61, 61, 36, 109, 97, 120, 95, 112,
  101, 114, 102, 111, 114, 109, 97, 110, 99, 101, 95, 114, 97, 110, 107, 44,
  52, 44, 105, 102, 40, 118, 61, 61, 36, 109, 97, 120, 95, 112, 101, 114,
  102, 111, 114, 109, 97, 110, 99, 101, 95, 114, 97, 110, 107, 43, 49, 44,
  53, 44, 48, 41, 41, 41, 125, 10, 45, 95, 103, 112, 116, 95, 102, 105,
  101, 108, 100, 32, 36, 116, 95, 108, 111, 119, 101, 115, 116, 95, 99, 104,
  105, 112, 115, 92, 32, 40, 36, 116, 95, 108, 111, 119, 101, 115, 116, 95,
  114, 97, 110, 107, 41, 44, 54, 52, 44, 36, 114, 111, 119, 95, 104, 101,
  105, 103, 104, 116, 44, 49, 54, 44, 36, 110, 44, 36, 99, 10, 116, 95,
  112, 101, 114, 102, 111, 114, 109, 97, 110, 99, 101, 61, 64, 123, 112, 101,
  114, 102, 111, 114, 109, 97, 110, 99, 101, 44, 40, 48, 44, 36, 112, 41,
  125, 10, 116, 95, 112, 101, 114, 102, 111, 114, 109, 97, 110, 99, 101, 95,
  114, 97, 110, 107, 61, 64, 123, 112, 101, 114, 102, 111, 114, 109, 97, 110,
  99, 101, 44, 40, 49, 44, 36, 112, 41, 125, 10, 99, 61, 123, 118, 61,
  64, 123, 112, 101, 114, 102, 111, 114, 109, 97, 110, 99, 101, 44, 40, 49,
  44, 36, 112, 41, 125, 59, 105, 102, 40, 118, 62, 61, 49, 38, 38, 118,
  60, 61, 51, 44, 118, 44, 105, 102, 40, 118, 61, 61, 36, 109, 97, 120,
  95, 112, 101, 114, 102, 111, 114, 109, 97, 110, 99, 101, 95, 114, 97, 110,
  107, 45, 49, 44, 52, 44, 105, 102, 40, 118, 61, 61, 36, 109, 97, 120,
  95, 112, 101, 114, 102, 111, 114, 109, 97, 110, 99, 101, 95, 114, 97, 110,
  107, 44, 53, 44, 48, 41, 41, 41, 125, 10, 45, 95, 103, 112, 116, 95,
  102, 105, 101, 108, 100, 32, 36, 116, 95, 112, 101, 114, 102, 111, 114, 109,
  97, 110, 99, 101, 37, 92, 32, 40, 36, 116, 95, 112, 101, 114, 102, 111,
  114, 109, 97, 110, 99, 101, 95, 114, 97, 110, 107, 41, 44, 54, 52, 44,
  36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 49, 54, 44, 36,
  110, 44, 36, 99, 10, 45, 45, 114, 111, 119, 115, 91, 115, 99, 111, 114,
  101, 115, 93, 32, 36, 112, 32, 45, 100, 105, 115, 99, 97, 114, 100, 91,
  45, 49, 93, 32, 45, 49, 10, 116, 95, 97, 118, 101, 114, 97, 103, 101,
  61, 123, 105, 102, 40, 105, 61, 61, 45, 49, 44, 48, 44, 114, 111, 117,
  110, 100, 40, 105, 97, 45, 49, 48, 48, 41, 41, 125, 10, 45, 105, 102,
  32, 123, 36, 116, 95, 97, 118, 101, 114, 97, 103, 101, 62, 48, 125, 32,
  116, 95, 97, 118, 101, 114, 97, 103, 101, 61, 43, 36, 116, 95, 97, 118,
  101, 114, 97, 103, 101, 32, 45, 101, 110, 100, 105, 102, 10, 116, 95, 97,
  118, 101, 114, 97, 103, 101, 95, 115, 116, 100, 61, 123, 105, 102, 40, 105,
  61, 61, 45, 49, 44, 48, 44, 114, 111, 117, 110, 100, 40, 115, 113, 114,
  116, 40, 105, 118, 41, 41, 41, 125, 10, 45, 114, 109, 91, 45, 49, 93,
  10, 116, 95, 97, 118, 101, 114, 97, 103, 101, 95, 114, 97, 110, 107, 61,
  64, 123, 97, 118, 101, 114, 97, 103, 101, 44, 40, 49, 44, 36, 112, 41,
  125, 10, 99, 61, 123, 118, 61, 64, 123, 97, 118, 101, 114, 97, 103, 101,
  44, 40, 49, 44, 36, 112, 41, 125, 59, 105, 102, 40, 118, 62, 61, 49,
  38, 38, 118, 60, 61, 51, 44, 118, 44, 105, 102, 40, 118, 61, 61, 36,
  109, 97, 120, 95, 97, 118, 101, 114, 97, 103, 101, 95, 114, 97, 110, 107,
  45, 49, 44, 52, 44, 105, 102, 40, 118, 61, 61, 36, 109, 97, 120, 95,
  97, 118, 101, 114, 97, 103, 101, 95, 114, 97, 110, 107, 44, 53, 44, 48,
  41, 41, 41, 125, 10, 45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100,
  32, 36, 116, 95, 97, 118, 101, 114, 97, 103, 101, 92, 32, 91, 36, 116,
  95, 97, 118, 101, 114, 97, 103, 101, 95, 115, 116, 100, 93, 92, 32, 40,
  36, 116, 95, 97, 118, 101, 114, 97, 103, 101, 95, 114, 97, 110, 107, 41,
  44, 49, 48, 48, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116,
  44, 49, 54, 44, 36, 110, 44, 36, 99, 10, 116, 95, 99, 111, 102, 102,
  101, 101, 95, 98, 97, 108, 97, 110, 99, 101, 61, 123, 95, 64, 123, 99,
  111, 102, 102, 101, 101, 95, 98, 97, 108, 97, 110, 99, 101, 44, 40, 48,
  44, 36, 112, 41, 125, 125, 10, 45, 105, 102, 32, 123, 36, 116, 95, 99,
  111, 102, 102, 101, 101, 95, 98, 97, 108, 97, 110, 99, 101, 62, 48, 125,
  32, 116, 95, 99, 111, 102, 102, 101, 101, 95, 98, 97, 108, 97, 110, 99,
  101, 61, 43, 36, 116, 95, 99, 111, 102, 102, 101, 101, 95, 98, 97, 108,
  97, 110, 99, 101, 32, 45, 101, 110, 100, 105, 102, 10, 116, 95, 99, 111,
  102, 102, 101, 101, 95, 114, 97, 110, 107, 61, 64, 123, 99, 111, 102, 102,
  101, 101, 95, 98, 97, 108, 97, 110, 99, 101, 44, 40, 49, 44, 36, 112,
  41, 125, 10, 99, 61, 123, 118, 61, 64, 123, 99, 111, 102, 102, 101, 101,
  95, 98, 97, 108, 97, 110, 99, 101, 44, 40, 49, 44, 36, 112, 41, 125,
  59, 105, 102, 40, 118, 62, 61, 49, 38, 38, 118, 60, 61, 51, 44, 118,
  44, 105, 102, 40, 118, 61, 61, 36, 109, 97, 120, 95, 99, 111, 102, 102,
  101, 101, 95, 98, 97, 108, 97, 110, 99, 101, 95, 114, 97, 110, 107, 45,
  49, 44, 52, 44, 105, 102, 40, 118, 61, 61, 36, 109, 97, 120, 95, 99,
  111, 102, 102, 101, 101, 95, 98, 97, 108, 97, 110, 99, 101, 95, 114, 97,
  110, 107, 44, 53, 44, 48, 41, 41, 41, 125, 10, 45, 95, 103, 112, 116,
  95, 102, 105, 101, 108, 100, 32, 36, 116, 95, 99, 111, 102, 102, 101, 101,
  95, 98, 97, 108, 97, 110, 99, 101, 92, 36, 92, 32, 40, 36, 116, 95,
  99, 111, 102, 102, 101, 101, 95, 114, 97, 110, 107, 41, 44, 56, 48, 44,
  36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 49, 54, 44, 36,
  110, 44, 36, 99, 10, 45, 105, 102, 32, 123, 33, 36, 110, 125, 32, 45,
  102, 91, 36, 105, 44, 123, 36, 105, 43, 50, 125, 45, 45, 49, 93, 32,
  34, 105, 42, 40, 48, 46, 55, 43, 48, 46, 51, 42, 40, 40, 40, 120,
  43, 121, 41, 37, 56, 41, 33, 61, 48, 41, 41, 34, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 97, 91, 36, 105, 45, 45, 49, 93, 32, 120, 10,
  45, 100, 111, 110, 101, 10, 97, 118, 103, 95, 110, 98, 95, 112, 108, 97,
  121, 101, 114, 115, 61, 123, 114, 111, 117, 110, 100, 40, 64, 123, 110, 98,
  95, 112, 108, 97, 121, 101, 114, 115, 44, 97, 125, 44, 48, 46, 53, 41,
  125, 10, 45, 105, 102, 32, 123, 36, 50, 61, 61, 48, 125, 32, 116, 95,
  116, 105, 116, 108, 101, 61, 34, 42, 42, 32, 71, 82, 69, 89, 67, 32,
  80, 111, 107, 101, 114, 32, 84, 111, 117, 114, 32, 42, 42, 32, 83, 101,
  115, 115, 105, 111, 110, 32, 92, 35, 34, 64, 123, 115, 99, 111, 114, 101,
  115, 44, 119, 125, 34, 32, 32, 32, 40, 97, 118, 103, 46, 32, 92, 35,
  112, 108, 97, 121, 101, 114, 32, 61, 32, 34, 36, 97, 118, 103, 95, 110,
  98, 95, 112, 108, 97, 121, 101, 114, 115, 34, 41, 34, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 50, 62, 48, 125, 32, 116, 95, 116, 105, 116, 108,
  101, 61, 34, 42, 42, 32, 71, 82, 69, 89, 67, 32, 80, 111, 107, 101,
  114, 32, 84, 111, 117, 114, 32, 42, 42, 32, 76, 97, 115, 116, 32, 34,
  64, 123, 115, 99, 111, 114, 101, 115, 44, 119, 125, 34, 32, 115, 101, 115,
  115, 105, 111, 110, 115, 32, 32, 40, 97, 118, 103, 46, 32, 92, 35, 112,
  108, 97, 121, 101, 114, 32, 61, 32, 34, 36, 97, 118, 103, 95, 110, 98,
  95, 112, 108, 97, 121, 101, 114, 115, 34, 41, 34, 10, 45, 101, 108, 115,
  101, 32, 116, 95, 116, 105, 116, 108, 101, 61, 34, 42, 42, 32, 71, 82,
  69, 89, 67, 32, 80, 111, 107, 101, 114, 32, 84, 111, 117, 114, 32, 42,
  42, 32, 83, 101, 115, 115, 105, 111, 110, 32, 92, 35, 34, 64, 123, 115,
  99, 111, 114, 101, 115, 44, 119, 125, 34, 47, 34, 123, 45, 36, 50, 125,
  34, 32, 40, 97, 118, 103, 46, 32, 92, 35, 112, 108, 97, 121, 101, 114,
  32, 61, 32, 34, 36, 97, 118, 103, 95, 110, 98, 95, 112, 108, 97, 121,
  101, 114, 115, 34, 41, 34, 10, 45, 101, 110, 100, 105, 102, 10, 48, 32,
  45, 116, 91, 45, 49, 93, 32, 36, 116, 95, 116, 105, 116, 108, 101, 44,
  48, 44, 48, 44, 53, 55, 44, 49, 44, 50, 53, 53, 32, 45, 114, 91,
  45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44,
  52, 32, 45, 100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119, 91, 45,
  49, 93, 32, 53, 44, 53, 44, 50, 10, 45, 114, 50, 100, 121, 91, 45,
  49, 93, 32, 50, 52, 32, 45, 114, 91, 45, 49, 93, 32, 123, 64, 123,
  36, 98, 111, 97, 114, 100, 44, 119, 125, 45, 50, 125, 44, 123, 49, 46,
  53, 42, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 45, 50, 125,
  44, 49, 44, 52, 44, 48, 44, 48, 44, 48, 46, 53, 44, 123, 105, 102,
  40, 36, 50, 44, 48, 46, 57, 44, 48, 46, 54, 41, 125, 10, 45, 105,
  91, 45, 50, 93, 32, 49, 44, 51, 44, 49, 44, 51, 44, 51, 50, 44,
  48, 44, 54, 52, 44, 51, 50, 44, 54, 52, 44, 49, 50, 56, 44, 54,
  52, 44, 50, 48, 48, 44, 50, 53, 54, 32, 45, 114, 91, 45, 50, 93,
  32, 91, 45, 49, 93, 44, 91, 45, 49, 93, 44, 49, 44, 51, 44, 51,
  32, 45, 98, 108, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 97,
  108, 112, 104, 97, 10, 45, 105, 102, 32, 123, 36, 50, 62, 48, 125, 32,
  45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48,
  44, 49, 44, 50, 32, 45, 101, 108, 105, 102, 32, 123, 36, 50, 60, 48,
  125, 32, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 99, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 102, 114, 97, 109, 101, 91, 45, 49,
  93, 32, 49, 44, 49, 44, 48, 10, 45, 109, 118, 91, 45, 49, 93, 32,
  36, 98, 111, 97, 114, 100, 10, 45, 105, 102, 32, 123, 33, 36, 50, 125,
  10, 45, 45, 99, 111, 108, 117, 109, 110, 115, 91, 115, 99, 111, 114, 101,
  115, 93, 32, 49, 48, 48, 37, 32, 45, 45, 102, 91, 45, 49, 93, 32,
  121, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 115,
  111, 114, 116, 91, 45, 49, 93, 32, 45, 44, 121, 10, 45, 102, 91, 45,
  49, 93, 32, 39, 105, 102, 40, 105, 40, 48, 44, 121, 41, 61, 61, 105,
  40, 48, 44, 48, 41, 44, 105, 44, 45, 49, 41, 39, 32, 45, 97, 117,
  116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 45, 49, 32, 45, 110,
  109, 91, 45, 49, 93, 32, 115, 101, 115, 115, 105, 111, 110, 95, 119, 105,
  110, 110, 101, 114, 115, 10, 110, 98, 95, 115, 101, 115, 115, 105, 111, 110,
  95, 119, 105, 110, 110, 101, 114, 115, 61, 123, 104, 125, 10, 116, 95, 115,
  101, 115, 115, 105, 111, 110, 95, 119, 105, 110, 110, 101, 114, 115, 61, 34,
  34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 110, 98, 95, 115, 101,
  115, 115, 105, 111, 110, 95, 119, 105, 110, 110, 101, 114, 115, 10, 105, 61,
  64, 123, 115, 101, 115, 115, 105, 111, 110, 95, 119, 105, 110, 110, 101, 114,
  115, 44, 40, 49, 44, 36, 62, 41, 125, 10, 116, 95, 115, 101, 115, 115,
  105, 111, 110, 95, 119, 105, 110, 110, 101, 114, 115, 61, 36, 123, 112, 108,
  97, 121, 101, 114, 36, 123, 105, 125, 95, 110, 97, 109, 101, 125, 34, 95,
  95, 34, 36, 123, 116, 95, 115, 101, 115, 115, 105, 111, 110, 95, 119, 105,
  110, 110, 101, 114, 115, 125, 10, 64, 123, 45, 112, 97, 116, 104, 95, 116,
  109, 112, 125, 47, 36, 123, 112, 108, 97, 121, 101, 114, 123, 64, 123, 115,
  101, 115, 115, 105, 111, 110, 95, 119, 105, 110, 110, 101, 114, 115, 44, 40,
  49, 44, 36, 62, 41, 125, 125, 95, 102, 105, 108, 101, 125, 32, 45, 45,
  91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 114, 50, 100, 91, 45,
  49, 93, 32, 53, 54, 44, 53, 54, 44, 50, 44, 50, 32, 45, 43, 91,
  45, 49, 93, 32, 50, 53, 53, 32, 45, 102, 114, 97, 109, 101, 91, 45,
  49, 93, 32, 49, 44, 49, 44, 48, 10, 45, 100, 111, 110, 101, 10, 116,
  95, 115, 101, 115, 115, 105, 111, 110, 95, 119, 105, 110, 110, 101, 114, 115,
  61, 64, 123, 45, 95, 103, 112, 116, 95, 114, 101, 109, 111, 118, 101, 95,
  117, 110, 100, 101, 114, 115, 99, 111, 114, 101, 92, 32, 36, 116, 95, 115,
  101, 115, 115, 105, 111, 110, 95, 119, 105, 110, 110, 101, 114, 115, 125, 10,
  48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 83, 101, 115, 115, 105, 111,
  110, 32, 119, 105, 110, 110, 101, 114, 34, 64, 123, 45, 105, 102, 92, 32,
  123, 36, 110, 98, 95, 115, 101, 115, 115, 105, 111, 110, 95, 119, 105, 110,
  110, 101, 114, 115, 61, 61, 49, 125, 92, 32, 45, 117, 92, 32, 92, 34,
  92, 34, 92, 32, 45, 101, 108, 115, 101, 92, 32, 45, 117, 92, 32, 115,
  92, 32, 45, 101, 110, 100, 105, 102, 125, 34, 32, 58, 32, 34, 36, 116,
  95, 115, 101, 115, 115, 105, 111, 110, 95, 119, 105, 110, 110, 101, 114, 115,
  44, 48, 44, 48, 44, 53, 55, 44, 49, 44, 50, 53, 53, 10, 45, 114,
  91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 52, 32, 45, 100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119, 91,
  45, 49, 93, 32, 53, 44, 53, 44, 50, 10, 45, 114, 50, 100, 121, 91,
  45, 49, 93, 32, 50, 52, 32, 45, 114, 91, 45, 49, 93, 32, 123, 64,
  123, 36, 98, 111, 97, 114, 100, 44, 119, 125, 45, 50, 125, 44, 123, 49,
  46, 53, 42, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 45, 50,
  125, 44, 49, 44, 52, 44, 48, 44, 48, 44, 48, 46, 49, 44, 48, 46,
  53, 10, 45, 105, 91, 45, 50, 93, 32, 49, 44, 50, 44, 49, 44, 51,
  44, 48, 44, 49, 50, 56, 44, 49, 50, 56, 44, 50, 53, 53, 44, 54,
  52, 44, 49, 50, 56, 32, 45, 114, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 91, 45, 49, 93, 44, 49, 44, 51, 44, 51, 32, 45, 98, 108,
  101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 97, 108, 112, 104, 97,
  10, 45, 105, 102, 32, 123, 36, 50, 62, 48, 125, 32, 45, 115, 104, 105,
  102, 116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 49, 44, 50,
  32, 45, 101, 108, 105, 102, 32, 123, 36, 50, 60, 48, 125, 32, 45, 109,
  105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 99, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 110, 98, 95, 115,
  101, 115, 115, 105, 111, 110, 95, 119, 105, 110, 110, 101, 114, 115, 32, 45,
  106, 91, 45, 49, 93, 32, 91, 123, 45, 50, 45, 36, 60, 125, 93, 44,
  123, 119, 45, 54, 52, 45, 36, 62, 42, 54, 52, 125, 44, 55, 32, 45,
  100, 111, 110, 101, 10, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93, 32,
  49, 44, 49, 44, 48, 10, 45, 109, 118, 91, 45, 49, 93, 32, 123, 36,
  98, 111, 97, 114, 100, 43, 49, 125, 10, 45, 114, 109, 91, 45, 123, 36,
  110, 98, 95, 115, 101, 115, 115, 105, 111, 110, 95, 119, 105, 110, 110, 101,
  114, 115, 43, 49, 125, 45, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 33, 36, 50, 125, 10, 45, 45, 99, 111, 108,
  117, 109, 110, 115, 91, 108, 111, 115, 101, 114, 115, 93, 32, 49, 48, 48,
  37, 32, 45, 45, 102, 91, 45, 49, 93, 32, 121, 32, 45, 97, 91, 45,
  50, 44, 45, 49, 93, 32, 120, 32, 45, 115, 111, 114, 116, 91, 45, 49,
  93, 32, 45, 44, 121, 10, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102,
  40, 105, 40, 48, 44, 121, 41, 44, 105, 44, 45, 49, 41, 39, 32, 45,
  97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 45, 49, 32,
  45, 110, 109, 91, 45, 49, 93, 32, 115, 101, 115, 115, 105, 111, 110, 95,
  108, 111, 115, 101, 114, 115, 10, 110, 98, 95, 115, 101, 115, 115, 105, 111,
  110, 95, 108, 111, 115, 101, 114, 115, 61, 123, 104, 125, 10, 116, 95, 115,
  101, 115, 115, 105, 111, 110, 95, 108, 111, 115, 101, 114, 115, 61, 34, 34,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 110, 98, 95, 115, 101, 115,
  115, 105, 111, 110, 95, 108, 111, 115, 101, 114, 115, 10, 105, 61, 64, 123,
  115, 101, 115, 115, 105, 111, 110, 95, 108, 111, 115, 101, 114, 115, 44, 40,
  49, 44, 36, 62, 41, 125, 10, 116, 95, 115, 101, 115, 115, 105, 111, 110,
  95, 108, 111, 115, 101, 114, 115, 61, 36, 123, 112, 108, 97, 121, 101, 114,
  36, 123, 105, 125, 95, 110, 97, 109, 101, 125, 34, 95, 95, 34, 36, 123,
  116, 95, 115, 101, 115, 115, 105, 111, 110, 95, 108, 111, 115, 101, 114, 115,
  125, 10, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109, 112, 125, 47, 36,
  123, 112, 108, 97, 121, 101, 114, 123, 64, 123, 115, 101, 115, 115, 105, 111,
  110, 95, 108, 111, 115, 101, 114, 115, 44, 40, 49, 44, 36, 62, 41, 125,
  125, 95, 102, 105, 108, 101, 125, 32, 45, 45, 91, 45, 49, 93, 32, 50,
  53, 53, 32, 45, 114, 114, 50, 100, 91, 45, 49, 93, 32, 53, 54, 44,
  53, 54, 44, 50, 44, 50, 32, 45, 43, 91, 45, 49, 93, 32, 50, 53,
  53, 32, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93, 32, 49, 44, 49,
  44, 48, 10, 45, 100, 111, 110, 101, 10, 116, 95, 115, 101, 115, 115, 105,
  111, 110, 95, 108, 111, 115, 101, 114, 115, 61, 64, 123, 45, 95, 103, 112,
  116, 95, 114, 101, 109, 111, 118, 101, 95, 117, 110, 100, 101, 114, 115, 99,
  111, 114, 101, 92, 32, 36, 116, 95, 115, 101, 115, 115, 105, 111, 110, 95,
  108, 111, 115, 101, 114, 115, 125, 10, 48, 32, 45, 116, 91, 45, 49, 93,
  32, 34, 83, 101, 115, 115, 105, 111, 110, 32, 108, 111, 115, 101, 114, 34,
  64, 123, 45, 105, 102, 92, 32, 123, 36, 110, 98, 95, 115, 101, 115, 115,
  105, 111, 110, 95, 108, 111, 115, 101, 114, 115, 61, 61, 49, 125, 92, 32,
  45, 117, 92, 32, 92, 34, 92, 34, 92, 32, 45, 101, 108, 115, 101, 92,
  32, 45, 117, 92, 32, 115, 92, 32, 45, 101, 110, 100, 105, 102, 125, 34,
  32, 58, 32, 34, 36, 116, 95, 115, 101, 115, 115, 105, 111, 110, 95, 108,
  111, 115, 101, 114, 115, 44, 48, 44, 48, 44, 53, 55, 44, 49, 44, 50,
  53, 53, 10, 45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 49, 44, 52, 32, 45, 100, 114, 111, 112, 95, 115, 104,
  97, 100, 111, 119, 91, 45, 49, 93, 32, 53, 44, 53, 44, 50, 10, 45,
  114, 50, 100, 121, 91, 45, 49, 93, 32, 50, 52, 32, 45, 114, 91, 45,
  49, 93, 32, 123, 64, 123, 36, 98, 111, 97, 114, 100, 44, 119, 125, 45,
  50, 125, 44, 123, 49, 46, 53, 42, 36, 114, 111, 119, 95, 104, 101, 105,
  103, 104, 116, 45, 50, 125, 44, 49, 44, 52, 44, 48, 44, 48, 44, 48,
  46, 49, 44, 48, 46, 53, 10, 45, 105, 91, 45, 50, 93, 32, 49, 44,
  50, 44, 49, 44, 51, 44, 49, 50, 56, 44, 50, 53, 53, 44, 48, 44,
  49, 50, 56, 44, 54, 52, 44, 49, 50, 56, 32, 45, 114, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 44, 91, 45, 49, 93, 44, 49, 44, 51, 44,
  51, 32, 45, 98, 108, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32,
  97, 108, 112, 104, 97, 10, 45, 105, 102, 32, 123, 36, 50, 62, 48, 125,
  32, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 48, 44, 48, 44,
  48, 44, 49, 44, 50, 32, 45, 101, 108, 105, 102, 32, 123, 36, 50, 60,
  48, 125, 32, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 99,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  36, 110, 98, 95, 115, 101, 115, 115, 105, 111, 110, 95, 108, 111, 115, 101,
  114, 115, 32, 45, 106, 91, 45, 49, 93, 32, 91, 123, 45, 50, 45, 36,
  60, 125, 93, 44, 123, 119, 45, 54, 52, 45, 36, 62, 42, 54, 52, 125,
  44, 55, 32, 45, 100, 111, 110, 101, 10, 45, 102, 114, 97, 109, 101, 91,
  45, 49, 93, 32, 49, 44, 49, 44, 48, 10, 45, 114, 109, 91, 45, 123,
  36, 110, 98, 95, 115, 101, 115, 115, 105, 111, 110, 95, 108, 111, 115, 101,
  114, 115, 43, 50, 125, 45, 45, 50, 93, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 97, 91, 36, 98, 111, 97, 114, 100, 45, 45, 49, 93, 32, 121,
  10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 50,
  53, 53, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32, 45,
  100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119, 91, 45, 49, 93, 32,
  54, 44, 54, 44, 52, 32, 45, 105, 91, 45, 50, 93, 32, 123, 119, 125,
  44, 123, 104, 125, 44, 49, 44, 51, 44, 50, 53, 53, 32, 45, 98, 108,
  101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 97, 108, 112, 104, 97,
  10, 45, 107, 91, 36, 98, 111, 97, 114, 100, 93, 32, 45, 118, 32, 43,
  10, 95, 103, 112, 116, 95, 114, 101, 109, 111, 118, 101, 95, 117, 110, 100,
  101, 114, 115, 99, 111, 114, 101, 32, 58, 10, 40, 123, 39, 34, 36, 49,
  34, 39, 125, 41, 32, 45, 114, 101, 112, 108, 97, 99, 101, 91, 45, 49,
  93, 32, 123, 39, 95, 39, 125, 44, 123, 39, 92, 32, 39, 125, 32, 45,
  117, 32, 64, 123, 45, 49, 44, 116, 125, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 58, 10, 45,
  105, 102, 32, 123, 33, 36, 53, 125, 32, 123, 36, 50, 45, 50, 125, 44,
  123, 36, 51, 45, 50, 125, 44, 49, 44, 51, 44, 50, 53, 53, 32, 45,
  102, 114, 97, 109, 101, 91, 45, 49, 93, 32, 49, 44, 49, 44, 48, 32,
  45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 48,
  32, 45, 116, 91, 45, 49, 93, 32, 34, 36, 49, 34, 44, 48, 44, 48,
  44, 53, 55, 44, 49, 44, 49, 32, 45, 42, 91, 45, 49, 93, 32, 45,
  49, 32, 45, 43, 91, 45, 49, 93, 32, 49, 10, 45, 114, 50, 100, 121,
  91, 45, 49, 93, 32, 36, 52, 32, 45, 45, 91, 45, 49, 93, 32, 49,
  32, 45, 114, 91, 45, 49, 93, 32, 123, 36, 50, 45, 50, 125, 44, 123,
  36, 51, 45, 50, 125, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 32, 45, 43, 91, 45, 49, 93, 32, 49, 10, 45,
  102, 114, 97, 109, 101, 91, 45, 49, 93, 32, 49, 44, 49, 44, 48, 10,
  91, 45, 49, 93, 120, 50, 10, 45, 105, 102, 32, 123, 36, 54, 61, 61,
  49, 125, 32, 45, 42, 91, 45, 51, 93, 32, 50, 53, 53, 32, 45, 42,
  91, 45, 50, 93, 32, 50, 52, 50, 32, 45, 42, 91, 45, 49, 93, 32,
  49, 53, 51, 10, 45, 101, 108, 105, 102, 32, 123, 36, 54, 61, 61, 50,
  125, 32, 45, 42, 91, 45, 51, 93, 32, 50, 50, 50, 32, 45, 42, 91,
  45, 50, 93, 32, 50, 50, 50, 32, 45, 42, 91, 45, 49, 93, 32, 50,
  50, 50, 10, 45, 101, 108, 105, 102, 32, 123, 36, 54, 61, 61, 51, 125,
  32, 45, 42, 91, 45, 51, 93, 32, 50, 51, 50, 32, 45, 42, 91, 45,
  50, 93, 32, 50, 48, 57, 32, 45, 42, 91, 45, 49, 93, 32, 49, 57,
  54, 10, 45, 101, 108, 105, 102, 32, 123, 36, 54, 61, 61, 52, 125, 32,
  45, 42, 91, 45, 51, 93, 32, 50, 53, 53, 32, 45, 42, 91, 45, 50,
  93, 32, 50, 48, 52, 32, 45, 42, 91, 45, 49, 93, 32, 50, 48, 52,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 54, 61, 61, 53, 125, 32, 45,
  42, 91, 45, 51, 93, 32, 50, 53, 53, 32, 45, 42, 91, 45, 50, 93,
  32, 49, 53, 51, 32, 45, 42, 91, 45, 49, 93, 32, 49, 53, 51, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 54, 61, 61, 54, 125, 32, 45, 42,
  91, 45, 51, 93, 32, 50, 52, 48, 32, 45, 42, 91, 45, 50, 93, 32,
  50, 52, 48, 32, 45, 42, 91, 45, 49, 93, 32, 50, 52, 48, 10, 45,
  101, 108, 115, 101, 32, 45, 42, 91, 45, 51, 45, 45, 49, 93, 32, 50,
  53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 97, 91, 45, 51, 45,
  45, 49, 93, 32, 99, 10, 103, 105, 109, 112, 95, 102, 105, 108, 116, 101,
  114, 95, 115, 111, 117, 114, 99, 101, 115, 32, 58, 10, 40, 123, 39, 103,
  109, 105, 99, 39, 125, 41, 10, 40, 123, 39, 104, 116, 116, 112, 58, 47,
  47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103,
  101, 46, 110, 101, 116, 47, 117, 112, 100, 97, 116, 101, 64, 46, 46, 103,
  109, 105, 99, 39, 125, 44, 49, 41, 10, 103, 105, 109, 112, 95, 112, 97,
  114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 32, 58,
  10, 45, 97, 112, 112, 108, 121, 95, 112, 97, 114, 97, 108, 108, 101, 108,
  95, 111, 118, 101, 114, 108, 97, 112, 32, 34, 36, 49, 34, 44, 36, 51,
  44, 123, 105, 102, 40, 36, 50, 44, 50, 94, 40, 36, 50, 45, 49, 41,
  44, 48, 41, 125, 10, 117, 112, 100, 97, 116, 101, 95, 103, 109, 105, 99,
  95, 103, 105, 109, 112, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  49, 61, 64, 46, 125, 44, 36, 123, 50, 61, 49, 125, 10, 45, 118, 32,
  45, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103, 109, 105, 99, 95,
  103, 105, 109, 112, 95, 109, 111, 118, 101, 32, 34, 47, 84, 101, 115, 116,
  105, 110, 103, 47, 74, 38, 35, 50, 51, 51, 59, 74, 38, 35, 50, 51,
  51, 59, 47, 82, 97, 121, 115, 34, 44, 34, 47, 80, 97, 116, 116, 101,
  114, 110, 115, 34, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103, 109,
  105, 99, 95, 103, 105, 109, 112, 95, 109, 111, 118, 101, 32, 34, 47, 84,
  101, 115, 116, 105, 110, 103, 47, 73, 97, 105, 110, 126, 102, 101, 114, 103,
  117, 115, 115, 111, 110, 47, 72, 97, 108, 102, 116, 111, 110, 101, 126, 115,
  104, 97, 112, 101, 115, 34, 44, 34, 47, 80, 97, 116, 116, 101, 114, 110,
  115, 34, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103, 109, 105, 99,
  95, 103, 105, 109, 112, 95, 109, 111, 118, 101, 32, 34, 47, 84, 101, 115,
  116, 105, 110, 103, 47, 73, 97, 105, 110, 126, 102, 101, 114, 103, 117, 115,
  115, 111, 110, 47, 83, 105, 109, 112, 108, 101, 126, 108, 111, 99, 97, 108,
  126, 99, 111, 110, 116, 114, 97, 115, 116, 34, 44, 34, 47, 68, 101, 116,
  97, 105, 108, 115, 34, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103,
  109, 105, 99, 95, 103, 105, 109, 112, 95, 109, 111, 118, 101, 32, 34, 47,
  84, 101, 115, 116, 105, 110, 103, 47, 71, 97, 114, 97, 103, 101, 99, 111,
  100, 101, 114, 47, 65, 117, 114, 111, 114, 97, 34, 44, 34, 47, 65, 114,
  116, 105, 115, 116, 105, 99, 34, 10, 45, 95, 117, 112, 100, 97, 116, 101,
  95, 103, 109, 105, 99, 95, 103, 105, 109, 112, 95, 109, 111, 118, 101, 32,
  34, 47, 84, 101, 115, 116, 105, 110, 103, 47, 71, 97, 114, 97, 103, 101,
  99, 111, 100, 101, 114, 47, 68, 101, 115, 112, 101, 99, 107, 108, 101, 34,
  44, 34, 47, 82, 101, 112, 97, 105, 114, 34, 10, 45, 95, 117, 112, 100,
  97, 116, 101, 95, 103, 109, 105, 99, 95, 103, 105, 109, 112, 95, 109, 111,
  118, 101, 32, 34, 47, 84, 101, 115, 116, 105, 110, 103, 47, 71, 97, 114,
  97, 103, 101, 99, 111, 100, 101, 114, 47, 72, 83, 76, 126, 97, 100, 106,
  117, 115, 116, 109, 101, 110, 116, 34, 44, 34, 47, 67, 111, 108, 111, 114,
  115, 34, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103, 109, 105, 99,
  95, 103, 105, 109, 112, 95, 109, 111, 118, 101, 32, 34, 47, 84, 101, 115,
  116, 105, 110, 103, 47, 71, 97, 114, 97, 103, 101, 99, 111, 100, 101, 114,
  47, 72, 83, 86, 126, 115, 101, 108, 101, 99, 116, 34, 44, 34, 47, 67,
  111, 108, 111, 114, 115, 34, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95,
  103, 109, 105, 99, 95, 103, 105, 109, 112, 95, 109, 111, 118, 101, 32, 34,
  47, 84, 101, 115, 116, 105, 110, 103, 47, 71, 97, 114, 97, 103, 101, 99,
  111, 100, 101, 114, 47, 83, 116, 101, 114, 101, 111, 126, 105, 109, 97, 103,
  101, 34, 44, 34, 47, 83, 116, 101, 114, 101, 111, 115, 99, 111, 112, 105,
  99, 126, 51, 100, 34, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103,
  109, 105, 99, 95, 103, 105, 109, 112, 95, 109, 111, 118, 101, 32, 34, 47,
  84, 101, 115, 116, 105, 110, 103, 47, 71, 97, 114, 97, 103, 101, 99, 111,
  100, 101, 114, 47, 85, 110, 100, 111, 126, 97, 110, 97, 103, 108, 121, 112,
  104, 34, 44, 34, 47, 83, 116, 101, 114, 101, 111, 115, 99, 111, 112, 105,
  99, 126, 51, 100, 34, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103,
  109, 105, 99, 95, 103, 105, 109, 112, 95, 109, 111, 118, 101, 32, 34, 47,
  84, 101, 115, 116, 105, 110, 103, 47, 78, 97, 103, 103, 111, 98, 111, 116,
  47, 66, 108, 111, 99, 107, 105, 115, 109, 34, 44, 34, 47, 65, 114, 116,
  105, 115, 116, 105, 99, 34, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95,
  103, 109, 105, 99, 95, 103, 105, 109, 112, 95, 109, 111, 118, 101, 32, 34,
  47, 84, 101, 115, 116, 105, 110, 103, 47, 83, 97, 109, 106, 47, 67, 104,
  97, 108, 107, 126, 105, 116, 126, 117, 112, 34, 44, 34, 47, 65, 114, 116,
  105, 115, 116, 105, 99, 34, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95,
  103, 109, 105, 99, 95, 103, 105, 109, 112, 95, 109, 111, 118, 101, 32, 34,
  47, 84, 101, 115, 116, 105, 110, 103, 47, 83, 97, 109, 106, 47, 68, 101,
  110, 105, 109, 126, 116, 101, 120, 116, 117, 114, 101, 34, 44, 34, 47, 80,
  97, 116, 116, 101, 114, 110, 115, 34, 10, 45, 95, 117, 112, 100, 97, 116,
  101, 95, 103, 109, 105, 99, 95, 103, 105, 109, 112, 95, 109, 111, 118, 101,
  32, 34, 47, 84, 101, 115, 116, 105, 110, 103, 47, 90, 111, 110, 100, 101,
  114, 114, 47, 83, 112, 105, 114, 97, 108, 34, 44, 34, 47, 82, 101, 110,
  100, 101, 114, 105, 110, 103, 34, 10, 45, 109, 32, 34, 112, 97, 114, 101,
  110, 116, 32, 58, 32, 45, 108, 91, 93, 32, 40, 123, 39, 36, 34, 34,
  49, 39, 125, 41, 32, 45, 115, 32, 45, 44, 123, 39, 47, 39, 125, 32,
  45, 105, 102, 32, 64, 35, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  101, 110, 100, 105, 102, 32, 45, 105, 91, 48, 45, 45, 49, 93, 32, 40,
  52, 55, 41, 32, 45, 97, 32, 121, 32, 45, 117, 32, 64, 123, 48, 44,
  116, 125, 32, 45, 114, 109, 32, 45, 101, 110, 100, 108, 34, 10, 45, 109,
  32, 34, 95, 109, 97, 120, 32, 58, 32, 40, 123, 39, 92, 34, 36, 34,
  34, 49, 92, 34, 39, 125, 41, 32, 40, 123, 39, 92, 34, 36, 34, 34,
  50, 92, 34, 39, 125, 41, 32, 45, 102, 91, 45, 50, 44, 45, 49, 93,
  32, 39, 105, 102, 40, 105, 62, 61, 57, 55, 38, 38, 105, 60, 61, 49,
  50, 50, 44, 105, 45, 51, 50, 44, 105, 41, 39, 32, 45, 114, 91, 45,
  50, 44, 45, 49, 93, 32, 123, 109, 97, 120, 40, 119, 44, 64, 123, 45,
  50, 44, 119, 125, 41, 125, 44, 49, 44, 49, 44, 49, 44, 48, 32, 45,
  45, 91, 45, 50, 44, 45, 49, 93, 32, 45, 97, 117, 116, 111, 99, 114,
  111, 112, 91, 45, 49, 93, 32, 48, 32, 34, 92, 10, 34, 45, 117, 32,
  123, 105, 62, 48, 125, 32, 45, 114, 109, 91, 45, 49, 93, 34, 10, 45,
  109, 32, 34, 108, 111, 97, 100, 95, 103, 109, 105, 99, 32, 58, 32, 34,
  92, 10, 34, 95, 110, 98, 95, 115, 111, 117, 114, 99, 101, 115, 61, 123,
  36, 95, 110, 98, 95, 115, 111, 117, 114, 99, 101, 115, 43, 49, 125, 32,
  102, 105, 108, 101, 110, 97, 109, 101, 61, 64, 123, 92, 34, 45, 98, 97,
  115, 101, 110, 97, 109, 101, 32, 36, 34, 34, 49, 92, 34, 125, 32, 34,
  92, 10, 34, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 92, 34, 32,
  32, 92, 34, 36, 95, 110, 98, 95, 115, 111, 117, 114, 99, 101, 115, 92,
  34, 46, 32, 92, 34, 36, 102, 105, 108, 101, 110, 97, 109, 101, 92, 34,
  32, 32, 92, 34, 32, 45, 118, 32, 45, 32, 34, 92, 10, 34, 45, 108,
  91, 93, 32, 34, 92, 10, 34, 32, 32, 45, 105, 32, 114, 97, 119, 58,
  36, 34, 34, 49, 44, 117, 99, 104, 97, 114, 32, 45, 118, 32, 43, 32,
  45, 101, 91, 93, 32, 92, 34, 32, 32, 32, 32, 32, 32, 91, 114, 101,
  116, 114, 105, 101, 118, 101, 100, 32, 102, 114, 111, 109, 32, 115, 111, 117,
  114, 99, 101, 32, 39, 36, 34, 34, 49, 39, 93, 92, 110, 92, 34, 32,
  45, 118, 32, 45, 32, 34, 92, 10, 34, 32, 32, 45, 108, 32, 34, 92,
  10, 34, 32, 32, 32, 32, 45, 111, 32, 114, 97, 119, 58, 47, 116, 109,
  112, 47, 36, 102, 105, 108, 101, 110, 97, 109, 101, 44, 117, 99, 104, 97,
  114, 32, 34, 92, 10, 34, 32, 32, 32, 32, 45, 120, 32, 92, 34, 115,
  99, 112, 32, 47, 116, 109, 112, 47, 92, 34, 36, 102, 105, 108, 101, 110,
  97, 109, 101, 92, 34, 32, 114, 111, 110, 111, 117, 110, 111, 117, 114, 115,
  44, 103, 109, 105, 99, 64, 119, 101, 98, 46, 115, 111, 117, 114, 99, 101,
  102, 111, 114, 103, 101, 46, 110, 101, 116, 58, 104, 116, 100, 111, 99, 115,
  47, 105, 110, 99, 108, 117, 100, 101, 47, 92, 34, 32, 34, 92, 10, 34,
  32, 32, 32, 32, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 92, 34,
  32, 32, 32, 32, 32, 32, 91, 97, 114, 99, 104, 105, 118, 101, 100, 93,
  92, 110, 92, 34, 32, 45, 118, 32, 45, 32, 34, 92, 10, 34, 32, 32,
  45, 111, 110, 102, 97, 105, 108, 32, 45, 118, 32, 43, 32, 45, 101, 91,
  93, 32, 92, 34, 32, 32, 32, 32, 32, 32, 91, 99, 111, 117, 108, 100,
  32, 110, 111, 116, 32, 98, 101, 32, 97, 114, 99, 104, 105, 118, 101, 100,
  33, 93, 92, 110, 92, 34, 32, 45, 118, 32, 45, 32, 45, 101, 110, 100,
  108, 32, 34, 92, 10, 34, 45, 111, 110, 102, 97, 105, 108, 32, 45, 108,
  91, 93, 32, 34, 92, 10, 34, 32, 32, 115, 111, 117, 114, 99, 101, 61,
  104, 116, 116, 112, 58, 47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114,
  99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 105, 110, 99, 108,
  117, 100, 101, 47, 36, 102, 105, 108, 101, 110, 97, 109, 101, 32, 34, 92,
  10, 34, 32, 32, 45, 105, 32, 114, 97, 119, 58, 36, 115, 111, 117, 114,
  99, 101, 44, 117, 99, 104, 97, 114, 32, 45, 118, 32, 43, 32, 45, 101,
  91, 93, 32, 92, 34, 32, 32, 32, 32, 32, 32, 91, 114, 101, 116, 114,
  105, 101, 118, 101, 100, 32, 102, 114, 111, 109, 32, 97, 114, 99, 104, 105,
  118, 101, 32, 39, 92, 34, 36, 115, 111, 117, 114, 99, 101, 92, 34, 39,
  93, 92, 110, 92, 34, 32, 45, 118, 32, 45, 32, 34, 92, 10, 34, 32,
  32, 45, 111, 110, 102, 97, 105, 108, 32, 45, 118, 32, 43, 32, 45, 101,
  91, 93, 32, 92, 34, 32, 32, 32, 32, 32, 32, 91, 101, 114, 114, 111,
  114, 44, 32, 110, 111, 116, 32, 114, 101, 97, 99, 104, 97, 98, 108, 101,
  33, 93, 92, 110, 92, 34, 32, 45, 118, 32, 45, 34, 92, 10, 34, 32,
  32, 45, 101, 110, 100, 108, 32, 45, 101, 110, 100, 108, 34, 10, 45, 109,
  32, 34, 99, 97, 108, 105, 98, 114, 97, 116, 101, 95, 110, 97, 109, 101,
  32, 58, 32, 34, 92, 10, 34, 45, 97, 117, 116, 111, 99, 114, 111, 112,
  32, 51, 50, 32, 34, 92, 10, 34, 45, 102, 32, 39, 105, 102, 40, 105,
  62, 61, 54, 53, 38, 38, 105, 60, 61, 57, 48, 44, 105, 43, 51, 50,
  44, 105, 41, 39, 32, 34, 92, 10, 34, 45, 114, 101, 112, 108, 97, 99,
  101, 32, 123, 39, 95, 39, 125, 44, 51, 50, 32, 45, 97, 117, 116, 111,
  99, 114, 111, 112, 32, 51, 50, 32, 34, 92, 10, 34, 45, 114, 101, 112,
  108, 97, 99, 101, 95, 115, 101, 113, 32, 92, 34, 34, 123, 39, 114, 103,
  98, 39, 125, 34, 92, 34, 44, 92, 34, 34, 123, 39, 82, 71, 66, 39,
  125, 34, 92, 34, 32, 34, 92, 10, 34, 45, 114, 101, 112, 108, 97, 99,
  101, 95, 115, 101, 113, 32, 92, 34, 34, 123, 39, 108, 97, 98, 39, 125,
  34, 92, 34, 44, 92, 34, 34, 123, 39, 76, 97, 98, 39, 125, 34, 92,
  34, 32, 34, 92, 10, 34, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115,
  101, 113, 32, 92, 34, 34, 123, 39, 104, 115, 118, 39, 125, 34, 92, 34,
  44, 92, 34, 34, 123, 39, 72, 83, 86, 39, 125, 34, 92, 34, 32, 34,
  92, 10, 34, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32,
  92, 34, 34, 123, 39, 104, 115, 108, 39, 125, 34, 92, 34, 44, 92, 34,
  34, 123, 39, 72, 83, 76, 39, 125, 34, 92, 34, 32, 34, 92, 10, 34,
  45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 92, 34, 34,
  123, 39, 121, 99, 98, 99, 114, 39, 125, 34, 92, 34, 44, 92, 34, 34,
  123, 39, 89, 67, 98, 67, 114, 39, 125, 34, 92, 34, 32, 34, 92, 10,
  34, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 92, 34,
  34, 123, 39, 99, 109, 121, 107, 39, 125, 34, 92, 34, 44, 92, 34, 34,
  123, 39, 67, 77, 89, 75, 39, 125, 34, 92, 34, 32, 34, 92, 10, 34,
  45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 92, 34, 34,
  123, 39, 98, 38, 97, 109, 112, 59, 119, 39, 125, 34, 92, 34, 44, 92,
  34, 34, 123, 39, 66, 38, 97, 109, 112, 59, 87, 39, 125, 34, 92, 34,
  32, 34, 92, 10, 34, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101,
  113, 32, 92, 34, 34, 123, 39, 103, 105, 109, 112, 39, 125, 34, 92, 34,
  44, 92, 34, 34, 123, 39, 71, 73, 77, 80, 39, 125, 34, 92, 34, 32,
  34, 92, 10, 34, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113,
  32, 92, 34, 34, 123, 39, 114, 111, 100, 100, 121, 39, 125, 34, 92, 34,
  44, 92, 34, 34, 123, 39, 82, 111, 100, 100, 121, 39, 125, 34, 92, 34,
  32, 34, 92, 10, 34, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101,
  113, 32, 92, 34, 34, 123, 39, 99, 114, 116, 39, 125, 34, 92, 34, 44,
  92, 34, 34, 123, 39, 67, 82, 84, 39, 125, 34, 92, 34, 32, 34, 92,
  10, 34, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 92,
  34, 34, 123, 39, 99, 111, 108, 111, 114, 97, 98, 115, 116, 114, 97, 99,
  116, 105, 111, 110, 112, 97, 105, 110, 116, 39, 125, 34, 92, 34, 44, 92,
  34, 34, 123, 39, 34, 67, 111, 108, 111, 114, 32, 97, 98, 115, 116, 114,
  97, 99, 116, 105, 111, 110, 32, 112, 97, 105, 110, 116, 34, 39, 125, 34,
  92, 34, 32, 34, 92, 10, 34, 45, 114, 101, 112, 108, 97, 99, 101, 95,
  115, 101, 113, 32, 92, 34, 34, 123, 39, 103, 39, 125, 44, 51, 57, 44,
  123, 39, 109, 105, 99, 39, 125, 34, 92, 34, 44, 92, 34, 34, 123, 39,
  71, 39, 125, 44, 51, 57, 44, 123, 39, 77, 73, 67, 39, 125, 34, 92,
  34, 32, 34, 92, 10, 34, 45, 102, 32, 39, 105, 102, 40, 121, 61, 61,
  48, 38, 38, 105, 62, 61, 57, 55, 38, 38, 105, 60, 61, 49, 50, 50,
  44, 105, 45, 51, 50, 44, 105, 41, 39, 32, 34, 10, 45, 105, 102, 32,
  123, 36, 49, 61, 61, 64, 46, 125, 10, 45, 118, 32, 43, 32, 45, 101,
  91, 93, 32, 34, 62, 32, 85, 112, 108, 111, 97, 100, 32, 108, 97, 116,
  101, 115, 116, 32, 118, 101, 114, 115, 105, 111, 110, 32, 40, 34, 64, 123,
  45, 115, 116, 114, 118, 101, 114, 125, 34, 41, 32, 111, 102, 32, 99, 111,
  109, 109, 97, 110, 100, 115, 32, 111, 110, 32, 83, 111, 117, 114, 99, 101,
  102, 111, 114, 103, 101, 32, 115, 101, 114, 118, 101, 114, 46, 92, 110, 34,
  32, 45, 118, 32, 45, 10, 45, 120, 32, 34, 115, 99, 112, 32, 34, 36,
  72, 79, 77, 69, 47, 119, 111, 114, 107, 47, 115, 114, 99, 47, 103, 109,
  105, 99, 47, 115, 114, 99, 47, 103, 109, 105, 99, 95, 100, 101, 102, 46,
  103, 109, 105, 99, 34, 32, 114, 111, 110, 111, 117, 110, 111, 117, 114, 115,
  44, 103, 109, 105, 99, 64, 119, 101, 98, 46, 115, 111, 117, 114, 99, 101,
  102, 111, 114, 103, 101, 46, 110, 101, 116, 58, 104, 116, 100, 111, 99, 115,
  47, 103, 109, 105, 99, 95, 100, 101, 102, 46, 34, 36, 49, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34,
  62, 32, 76, 111, 97, 100, 32, 97, 110, 100, 32, 97, 114, 99, 104, 105,
  118, 101, 32, 46, 103, 109, 105, 99, 32, 115, 111, 117, 114, 99, 101, 32,
  102, 105, 108, 101, 115, 46, 92, 110, 34, 32, 45, 118, 32, 45, 10, 95,
  110, 98, 95, 115, 111, 117, 114, 99, 101, 115, 61, 48, 10, 45, 108, 111,
  97, 100, 95, 103, 109, 105, 99, 32, 104, 116, 116, 112, 58, 47, 47, 103,
  109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46,
  110, 101, 116, 47, 103, 109, 105, 99, 95, 100, 101, 102, 46, 36, 49, 10,
  45, 108, 111, 97, 100, 95, 103, 109, 105, 99, 32, 104, 116, 116, 112, 58,
  47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114,
  103, 101, 46, 110, 101, 116, 47, 99, 111, 109, 112, 97, 116, 105, 98, 105,
  108, 105, 116, 121, 46, 103, 109, 105, 99, 10, 45, 108, 111, 97, 100, 95,
  103, 109, 105, 99, 32, 104, 116, 116, 112, 58, 47, 47, 115, 52, 48, 54,
  56, 51, 51, 50, 52, 55, 46, 119, 101, 98, 115, 105, 116, 101, 104, 111,
  109, 101, 46, 99, 111, 46, 117, 107, 47, 103, 109, 105, 99, 47, 103, 97,
  114, 97, 103, 101, 99, 111, 100, 101, 114, 46, 103, 109, 105, 99, 10, 45,
  108, 111, 97, 100, 95, 103, 109, 105, 99, 32, 104, 116, 116, 112, 58, 47,
  47, 103, 101, 110, 116, 108, 101, 109, 97, 110, 98, 101, 103, 103, 97, 114,
  46, 98, 112, 108, 97, 99, 101, 100, 46, 110, 101, 116, 47, 103, 101, 110,
  116, 108, 101, 109, 97, 110, 98, 101, 103, 103, 97, 114, 95, 103, 109, 105,
  99, 46, 103, 109, 105, 99, 10, 45, 108, 111, 97, 100, 95, 103, 109, 105,
  99, 32, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 105, 97, 105,
  110, 46, 98, 112, 108, 97, 99, 101, 100, 46, 110, 101, 116, 47, 105, 97,
  105, 110, 95, 102, 101, 114, 103, 117, 115, 115, 111, 110, 46, 103, 109, 105,
  99, 10, 45, 108, 111, 97, 100, 95, 103, 109, 105, 99, 32, 104, 116, 116,
  112, 58, 47, 47, 119, 119, 119, 46, 104, 45, 112, 115, 46, 100, 101, 109,
  111, 110, 46, 99, 111, 46, 117, 107, 47, 71, 77, 73, 67, 47, 106, 97,
  121, 112, 114, 105, 99, 104, 46, 103, 109, 105, 99, 10, 45, 108, 111, 97,
  100, 95, 103, 109, 105, 99, 32, 104, 116, 116, 112, 115, 58, 47, 47, 114,
  97, 119, 46, 103, 105, 116, 104, 117, 98, 46, 99, 111, 109, 47, 106, 98,
  111, 117, 108, 97, 110, 103, 101, 114, 47, 106, 98, 111, 117, 108, 97, 110,
  103, 101, 114, 45, 103, 109, 105, 99, 47, 109, 97, 115, 116, 101, 114, 47,
  106, 98, 111, 117, 108, 97, 110, 103, 101, 114, 46, 103, 109, 105, 99, 10,
  45, 108, 111, 97, 100, 95, 103, 109, 105, 99, 32, 104, 116, 116, 112, 58,
  47, 47, 107, 97, 114, 111, 48, 51, 46, 98, 112, 108, 97, 99, 101, 100,
  46, 110, 101, 116, 47, 103, 109, 105, 99, 47, 107, 97, 114, 111, 115, 46,
  103, 109, 105, 99, 10, 45, 108, 111, 97, 100, 95, 103, 109, 105, 99, 32,
  104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 115, 97, 117, 110, 97,
  108, 97, 104, 116, 105, 46, 102, 105, 47, 110, 97, 103, 103, 111, 98, 111,
  116, 47, 110, 97, 103, 103, 111, 98, 111, 116, 46, 103, 109, 105, 99, 10,
  45, 108, 111, 97, 100, 95, 103, 109, 105, 99, 32, 104, 116, 116, 112, 58,
  47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114,
  103, 101, 46, 110, 101, 116, 47, 112, 104, 111, 116, 111, 99, 111, 109, 105,
  120, 46, 103, 109, 105, 99, 10, 45, 108, 111, 97, 100, 95, 103, 109, 105,
  99, 32, 104, 116, 116, 112, 58, 47, 47, 103, 109, 105, 99, 46, 115, 111,
  117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 114, 111,
  110, 111, 117, 110, 111, 117, 114, 115, 46, 103, 109, 105, 99, 10, 45, 108,
  111, 97, 100, 95, 103, 109, 105, 99, 32, 104, 116, 116, 112, 58, 47, 47,
  119, 119, 119, 46, 97, 108, 106, 97, 99, 111, 109, 46, 99, 111, 109, 47,
  126, 103, 109, 105, 99, 47, 115, 97, 109, 106, 46, 103, 109, 105, 99, 10,
  45, 108, 111, 97, 100, 95, 103, 109, 105, 99, 32, 104, 116, 116, 112, 58,
  47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114,
  103, 101, 46, 110, 101, 116, 47, 116, 111, 109, 107, 101, 105, 108, 46, 103,
  109, 105, 99, 10, 45, 108, 111, 97, 100, 95, 103, 109, 105, 99, 32, 104,
  116, 116, 112, 58, 47, 47, 100, 111, 99, 103, 109, 105, 99, 46, 116, 117,
  120, 102, 97, 109, 105, 108, 121, 46, 111, 114, 103, 47, 122, 111, 110, 100,
  101, 114, 114, 46, 103, 109, 105, 99, 10, 45, 105, 91, 48, 93, 32, 40,
  49, 48, 41, 32, 45, 105, 91, 50, 45, 45, 49, 93, 32, 40, 123, 34,
  39, 92, 110, 35, 64, 103, 105, 109, 112, 32, 95, 95, 95, 95, 95, 95,
  95, 95, 95, 95, 95, 95, 95, 95, 95, 95, 92, 110, 39, 34, 125, 41,
  32, 45, 121, 32, 45, 97, 32, 121, 32, 45, 100, 105, 115, 99, 97, 114,
  100, 32, 49, 51, 32, 45, 114, 101, 112, 108, 97, 99, 101, 32, 57, 44,
  51, 50, 10, 45, 115, 32, 43, 44, 123, 39, 34, 35, 64, 103, 105, 109,
  112, 34, 39, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110,
  116, 40, 40, 64, 35, 45, 49, 41, 47, 50, 41, 125, 32, 45, 97, 91,
  123, 36, 62, 43, 49, 125, 44, 123, 36, 62, 43, 50, 125, 93, 32, 121,
  32, 45, 100, 111, 110, 101, 10, 45, 110, 109, 91, 48, 93, 32, 33, 104,
  101, 97, 100, 101, 114, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32,
  34, 62, 32, 83, 116, 97, 114, 116, 32, 115, 111, 117, 114, 99, 101, 32,
  112, 97, 114, 115, 105, 110, 103, 46, 92, 110, 34, 32, 45, 118, 32, 45,
  10, 112, 114, 111, 103, 114, 101, 115, 115, 95, 102, 97, 99, 116, 111, 114,
  61, 123, 49, 48, 48, 47, 40, 64, 35, 45, 49, 41, 125, 10, 109, 101,
  114, 103, 101, 95, 114, 101, 113, 117, 101, 115, 116, 61, 48, 10, 109, 101,
  114, 103, 101, 95, 115, 116, 97, 114, 116, 61, 48, 10, 110, 98, 95, 102,
  105, 108, 116, 101, 114, 115, 61, 48, 10, 111, 102, 102, 115, 101, 116, 61,
  48, 10, 112, 97, 116, 104, 61, 47, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 10, 105, 110, 100, 61, 123, 36, 62, 45, 36, 111, 102, 102,
  115, 101, 116, 125, 10, 45, 105, 102, 32, 123, 64, 123, 123, 36, 105, 110,
  100, 45, 49, 125, 44, 45, 49, 125, 61, 61, 49, 48, 34, 32, 38, 38,
  32, 34, 123, 123, 96, 64, 123, 36, 105, 110, 100, 44, 48, 45, 53, 125,
  96, 125, 39, 61, 61, 39, 34, 35, 64, 103, 105, 109, 112, 34, 125, 34,
  32, 38, 38, 32, 34, 40, 64, 123, 36, 105, 110, 100, 44, 54, 125, 61,
  61, 51, 50, 34, 32, 124, 124, 32, 34, 64, 123, 36, 105, 110, 100, 44,
  54, 125, 61, 61, 123, 39, 95, 39, 125, 41, 125, 32, 45, 108, 91, 36,
  105, 110, 100, 93, 10, 105, 115, 95, 102, 111, 108, 100, 101, 114, 61, 48,
  10, 45, 115, 32, 43, 44, 49, 48, 10, 45, 105, 102, 32, 123, 64, 123,
  48, 44, 54, 125, 61, 61, 123, 39, 95, 39, 125, 125, 32, 45, 45, 114,
  111, 119, 115, 91, 48, 93, 32, 57, 44, 49, 48, 48, 37, 32, 45, 114,
  111, 119, 115, 91, 48, 93, 32, 48, 44, 56, 10, 45, 101, 108, 115, 101,
  32, 45, 45, 114, 111, 119, 115, 91, 48, 93, 32, 54, 44, 49, 48, 48,
  37, 32, 45, 114, 111, 119, 115, 91, 48, 93, 32, 48, 44, 53, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91,
  45, 49, 93, 32, 51, 50, 32, 45, 109, 118, 91, 45, 49, 93, 32, 49,
  10, 45, 105, 102, 32, 123, 64, 123, 49, 44, 48, 125, 33, 61, 123, 39,
  58, 39, 125, 125, 10, 45, 108, 91, 49, 93, 10, 45, 115, 32, 43, 44,
  123, 39, 58, 39, 125, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115,
  101, 113, 91, 48, 93, 32, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32,
  123, 39, 60, 98, 62, 39, 125, 125, 44, 51, 50, 10, 45, 114, 101, 112,
  108, 97, 99, 101, 95, 115, 101, 113, 91, 48, 93, 32, 64, 123, 45, 113,
  117, 111, 116, 101, 92, 32, 123, 39, 60, 47, 98, 62, 39, 125, 125, 44,
  51, 50, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 91,
  48, 93, 32, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 60,
  105, 62, 39, 125, 125, 44, 51, 50, 10, 45, 114, 101, 112, 108, 97, 99,
  101, 95, 115, 101, 113, 91, 48, 93, 32, 64, 123, 45, 113, 117, 111, 116,
  101, 92, 32, 123, 39, 60, 47, 105, 62, 39, 125, 125, 44, 51, 50, 10,
  45, 114, 101, 112, 108, 97, 99, 101, 91, 48, 93, 32, 123, 39, 47, 39,
  125, 44, 123, 39, 45, 39, 125, 10, 45, 114, 101, 112, 108, 97, 99, 101,
  91, 48, 93, 32, 123, 39, 44, 39, 125, 44, 123, 39, 59, 39, 125, 10,
  45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 48, 93, 32, 51, 50, 10,
  45, 105, 102, 32, 123, 64, 35, 62, 49, 125, 10, 45, 99, 97, 108, 105,
  98, 114, 97, 116, 101, 95, 110, 97, 109, 101, 91, 48, 93, 32, 45, 45,
  114, 101, 112, 108, 97, 99, 101, 91, 48, 93, 32, 51, 50, 44, 123, 39,
  126, 39, 125, 10, 110, 97, 109, 101, 61, 36, 112, 97, 116, 104, 64, 123,
  45, 49, 44, 116, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 109, 101,
  114, 103, 101, 95, 114, 101, 113, 117, 101, 115, 116, 61, 49, 10, 110, 98,
  95, 102, 105, 108, 116, 101, 114, 115, 61, 123, 36, 110, 98, 95, 102, 105,
  108, 116, 101, 114, 115, 43, 49, 125, 10, 45, 105, 91, 48, 44, 49, 93,
  32, 40, 51, 50, 41, 32, 45, 97, 32, 121, 10, 45, 118, 32, 43, 32,
  45, 101, 91, 93, 32, 34, 32, 32, 34, 36, 110, 98, 95, 102, 105, 108,
  116, 101, 114, 115, 34, 46, 32, 34, 36, 110, 97, 109, 101, 34, 32, 40,
  34, 123, 114, 111, 117, 110, 100, 40, 36, 62, 42, 36, 112, 114, 111, 103,
  114, 101, 115, 115, 95, 102, 97, 99, 116, 111, 114, 41, 125, 34, 37, 41,
  46, 34, 32, 45, 118, 32, 45, 10, 45, 101, 108, 115, 101, 10, 45, 105,
  102, 32, 123, 105, 61, 61, 123, 39, 95, 39, 125, 125, 10, 45, 100, 111,
  32, 112, 97, 116, 104, 61, 64, 123, 34, 45, 112, 97, 114, 101, 110, 116,
  91, 93, 32, 34, 36, 112, 97, 116, 104, 125, 32, 45, 115, 104, 105, 102,
  116, 32, 48, 44, 45, 49, 44, 48, 44, 48, 32, 45, 119, 104, 105, 108,
  101, 32, 123, 105, 61, 61, 123, 39, 95, 39, 125, 125, 10, 45, 97, 117,
  116, 111, 99, 114, 111, 112, 32, 48, 32, 45, 97, 117, 116, 111, 99, 114,
  111, 112, 32, 51, 50, 10, 45, 105, 102, 32, 123, 119, 125, 32, 45, 99,
  97, 108, 105, 98, 114, 97, 116, 101, 95, 110, 97, 109, 101, 32, 45, 114,
  101, 112, 108, 97, 99, 101, 32, 51, 50, 44, 123, 39, 126, 39, 125, 32,
  112, 97, 116, 104, 61, 36, 112, 97, 116, 104, 64, 123, 48, 44, 116, 125,
  47, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101, 10, 45,
  97, 117, 116, 111, 99, 114, 111, 112, 32, 51, 50, 32, 45, 99, 97, 108,
  105, 98, 114, 97, 116, 101, 95, 110, 97, 109, 101, 32, 45, 114, 101, 112,
  108, 97, 99, 101, 32, 51, 50, 44, 123, 39, 126, 39, 125, 32, 112, 97,
  116, 104, 61, 36, 112, 97, 116, 104, 64, 123, 48, 44, 116, 125, 47, 10,
  45, 101, 110, 100, 105, 102, 10, 105, 115, 95, 102, 111, 108, 100, 101, 114,
  61, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 10,
  45, 105, 102, 32, 36, 105, 115, 95, 102, 111, 108, 100, 101, 114, 32, 45,
  114, 109, 91, 48, 44, 49, 93, 32, 45, 105, 91, 48, 93, 32, 40, 49,
  48, 41, 10, 45, 101, 108, 115, 101, 32, 45, 110, 109, 91, 48, 93, 32,
  36, 110, 97, 109, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108,
  115, 101, 10, 45, 105, 102, 32, 123, 64, 35, 62, 61, 51, 125, 32, 45,
  108, 91, 49, 93, 10, 45, 115, 32, 43, 44, 123, 39, 61, 39, 125, 10,
  45, 105, 102, 32, 123, 64, 35, 62, 61, 51, 125, 32, 45, 105, 102, 32,
  123, 64, 123, 49, 44, 48, 125, 61, 61, 123, 39, 61, 39, 125, 125, 10,
  45, 114, 111, 119, 115, 91, 48, 93, 32, 49, 44, 49, 48, 48, 37, 32,
  45, 99, 97, 108, 105, 98, 114, 97, 116, 101, 95, 110, 97, 109, 101, 91,
  48, 93, 10, 45, 105, 91, 48, 93, 32, 40, 123, 39, 58, 39, 125, 59,
  51, 50, 41, 32, 45, 105, 91, 50, 93, 32, 40, 51, 50, 41, 10, 45,
  101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 108, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 91, 49, 93, 32,
  40, 51, 50, 41, 10, 45, 101, 110, 100, 105, 102, 10, 45, 97, 32, 121,
  10, 45, 101, 110, 100, 108, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 109, 101, 114, 103, 101, 95, 114, 101, 113, 117, 101, 115,
  116, 34, 32, 38, 38, 32, 34, 36, 105, 110, 100, 62, 48, 125, 10, 45,
  97, 91, 36, 109, 101, 114, 103, 101, 95, 115, 116, 97, 114, 116, 45, 123,
  36, 105, 110, 100, 45, 49, 125, 93, 32, 121, 10, 111, 102, 102, 115, 101,
  116, 61, 123, 36, 111, 102, 102, 115, 101, 116, 43, 36, 105, 110, 100, 45,
  36, 109, 101, 114, 103, 101, 95, 115, 116, 97, 114, 116, 45, 49, 125, 10,
  109, 101, 114, 103, 101, 95, 115, 116, 97, 114, 116, 61, 123, 36, 109, 101,
  114, 103, 101, 95, 115, 116, 97, 114, 116, 43, 49, 125, 10, 109, 101, 114,
  103, 101, 95, 114, 101, 113, 117, 101, 115, 116, 61, 48, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 97, 91, 36, 109, 101,
  114, 103, 101, 95, 115, 116, 97, 114, 116, 45, 45, 49, 93, 32, 121, 10,
  45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 110, 62, 32, 70,
  111, 114, 99, 101, 32, 102, 105, 108, 116, 101, 114, 115, 32, 116, 111, 32,
  109, 111, 118, 101, 44, 32, 105, 102, 32, 110, 101, 99, 101, 115, 115, 97,
  114, 121, 46, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 105, 110, 100, 61, 36, 62, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 36, 95, 110, 98, 109, 32, 45, 105, 102, 32, 123, 64,
  123, 36, 105, 110, 100, 44, 110, 125, 39, 61, 61, 39, 36, 123, 95, 116,
  111, 95, 109, 111, 118, 101, 36, 62, 125, 125, 10, 45, 118, 32, 43, 32,
  45, 101, 91, 93, 32, 34, 32, 32, 34, 36, 105, 110, 100, 34, 46, 32,
  77, 111, 118, 101, 32, 39, 34, 64, 123, 36, 105, 110, 100, 44, 110, 125,
  34, 39, 32, 116, 111, 32, 39, 34, 36, 123, 95, 109, 111, 118, 101, 95,
  116, 111, 36, 62, 125, 34, 39, 46, 34, 32, 45, 118, 32, 45, 10, 45,
  110, 97, 109, 101, 91, 36, 105, 110, 100, 93, 32, 36, 123, 95, 109, 111,
  118, 101, 95, 116, 111, 36, 62, 125, 47, 64, 123, 36, 105, 110, 100, 44,
  98, 125, 10, 45, 101, 110, 100, 105, 102, 32, 45, 100, 111, 110, 101, 32,
  45, 100, 111, 110, 101, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32,
  34, 92, 110, 62, 32, 83, 111, 114, 116, 32, 102, 105, 108, 116, 101, 114,
  115, 32, 98, 121, 32, 108, 101, 120, 105, 99, 111, 103, 114, 97, 112, 104,
  105, 99, 32, 111, 114, 100, 101, 114, 46, 34, 32, 45, 118, 32, 45, 10,
  45, 95, 117, 112, 100, 97, 116, 101, 95, 103, 109, 105, 99, 95, 103, 105,
  109, 112, 95, 115, 111, 114, 116, 32, 48, 44, 123, 64, 35, 45, 49, 125,
  10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 110, 62, 32,
  82, 101, 109, 111, 118, 101, 32, 100, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 102, 105, 108, 116, 101, 114, 115, 46, 34, 32, 45, 118, 32, 45, 10,
  112, 110, 97, 109, 101, 61, 64, 123, 45, 49, 44, 110, 125, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 99, 110, 97,
  109, 101, 61, 64, 123, 36, 60, 44, 110, 125, 10, 45, 105, 102, 32, 123,
  36, 99, 110, 97, 109, 101, 39, 61, 61, 39, 36, 112, 110, 97, 109, 101,
  125, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 32, 32, 34,
  36, 60, 34, 46, 32, 82, 101, 109, 111, 118, 101, 32, 100, 117, 112, 108,
  105, 99, 97, 116, 101, 32, 39, 34, 36, 99, 110, 97, 109, 101, 34, 39,
  46, 34, 32, 45, 118, 32, 45, 10, 45, 114, 109, 91, 36, 60, 93, 10,
  45, 101, 108, 115, 101, 32, 112, 110, 97, 109, 101, 61, 36, 99, 110, 97,
  109, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 10,
  45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 110, 62, 32, 82,
  101, 98, 117, 105, 108, 100, 32, 102, 111, 108, 100, 101, 114, 32, 115, 116,
  114, 117, 99, 116, 117, 114, 101, 46, 34, 32, 45, 118, 32, 45, 10, 45,
  109, 32, 34, 110, 98, 95, 108, 101, 118, 101, 108, 115, 32, 58, 32, 45,
  108, 91, 93, 32, 40, 123, 39, 36, 34, 34, 49, 39, 125, 41, 32, 45,
  115, 32, 45, 44, 123, 39, 47, 39, 125, 32, 45, 117, 32, 64, 35, 32,
  45, 114, 109, 32, 45, 101, 110, 100, 108, 34, 10, 112, 97, 116, 104, 61,
  47, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 110, 112, 97, 116, 104, 61, 64, 123, 34, 45, 112, 97,
  114, 101, 110, 116, 32, 34, 64, 123, 48, 44, 110, 125, 125, 10, 45, 105,
  102, 32, 123, 36, 112, 97, 116, 104, 39, 33, 61, 39, 36, 110, 112, 97,
  116, 104, 125, 10, 110, 99, 61, 64, 123, 34, 45, 110, 98, 95, 108, 101,
  118, 101, 108, 115, 91, 93, 32, 34, 36, 112, 97, 116, 104, 125, 10, 110,
  110, 61, 64, 123, 34, 45, 110, 98, 95, 108, 101, 118, 101, 108, 115, 91,
  93, 32, 34, 36, 110, 112, 97, 116, 104, 125, 10, 110, 98, 95, 117, 112,
  61, 48, 10, 110, 98, 95, 100, 111, 119, 110, 61, 48, 10, 98, 97, 115,
  105, 115, 61, 36, 112, 97, 116, 104, 32, 110, 98, 97, 115, 105, 115, 61,
  36, 110, 112, 97, 116, 104, 10, 45, 100, 111, 10, 110, 99, 61, 64, 123,
  34, 45, 110, 98, 95, 108, 101, 118, 101, 108, 115, 91, 93, 32, 34, 36,
  98, 97, 115, 105, 115, 125, 10, 110, 110, 61, 64, 123, 34, 45, 110, 98,
  95, 108, 101, 118, 101, 108, 115, 91, 93, 32, 34, 36, 110, 98, 97, 115,
  105, 115, 125, 10, 45, 105, 102, 32, 123, 36, 110, 99, 62, 36, 110, 110,
  125, 32, 98, 97, 115, 105, 115, 61, 64, 123, 34, 45, 112, 97, 114, 101,
  110, 116, 91, 93, 32, 34, 36, 98, 97, 115, 105, 115, 125, 32, 110, 98,
  95, 117, 112, 61, 123, 36, 110, 98, 95, 117, 112, 43, 49, 125, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 110, 110, 62, 36, 110, 99, 125, 32, 110,
  98, 97, 115, 105, 115, 61, 64, 123, 34, 45, 112, 97, 114, 101, 110, 116,
  91, 93, 32, 34, 36, 110, 98, 97, 115, 105, 115, 125, 32, 110, 98, 95,
  100, 111, 119, 110, 61, 123, 36, 110, 98, 95, 100, 111, 119, 110, 43, 49,
  125, 10, 45, 101, 108, 105, 102, 32, 123, 36, 110, 98, 97, 115, 105, 115,
  39, 33, 61, 39, 36, 98, 97, 115, 105, 115, 125, 32, 98, 97, 115, 105,
  115, 61, 64, 123, 34, 45, 112, 97, 114, 101, 110, 116, 91, 93, 32, 34,
  36, 98, 97, 115, 105, 115, 125, 32, 110, 98, 95, 117, 112, 61, 123, 36,
  110, 98, 95, 117, 112, 43, 49, 125, 32, 110, 98, 97, 115, 105, 115, 61,
  64, 123, 34, 45, 112, 97, 114, 101, 110, 116, 91, 93, 32, 34, 36, 110,
  98, 97, 115, 105, 115, 125, 32, 110, 98, 95, 100, 111, 119, 110, 61, 123,
  36, 110, 98, 95, 100, 111, 119, 110, 43, 49, 125, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123, 36, 110, 98, 97, 115,
  105, 115, 39, 33, 61, 39, 36, 98, 97, 115, 105, 115, 125, 10, 99, 111,
  109, 109, 97, 110, 100, 61, 10, 45, 105, 102, 32, 36, 110, 98, 95, 117,
  112, 32, 49, 44, 36, 110, 98, 95, 117, 112, 44, 49, 44, 49, 44, 123,
  39, 95, 39, 125, 32, 99, 111, 109, 109, 97, 110, 100, 61, 34, 35, 64,
  103, 105, 109, 112, 32, 34, 64, 123, 45, 49, 44, 116, 125, 34, 92, 110,
  34, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 36, 110, 98, 95, 100, 111, 119, 110, 32, 45, 108,
  91, 93, 10, 40, 123, 39, 36, 110, 112, 97, 116, 104, 39, 125, 41, 32,
  45, 115, 32, 45, 44, 123, 39, 47, 39, 125, 32, 45, 107, 91, 45, 36,
  110, 98, 95, 100, 111, 119, 110, 45, 45, 49, 93, 32, 45, 114, 101, 112,
  108, 97, 99, 101, 32, 123, 39, 126, 39, 125, 44, 51, 50, 10, 108, 101,
  118, 101, 108, 61, 123, 64, 123, 34, 45, 110, 98, 95, 108, 101, 118, 101,
  108, 115, 32, 34, 36, 112, 97, 116, 104, 125, 45, 36, 110, 98, 95, 117,
  112, 125, 10, 98, 97, 108, 105, 115, 101, 61, 64, 123, 34, 45, 105, 102,
  32, 34, 123, 36, 108, 101, 118, 101, 108, 60, 61, 48, 34, 32, 38, 38,
  32, 34, 123, 36, 110, 112, 97, 116, 104, 39, 33, 61, 39, 47, 65, 98,
  111, 117, 116, 47, 125, 125, 34, 32, 45, 117, 32, 98, 32, 45, 101, 108,
  115, 101, 32, 45, 117, 32, 105, 32, 45, 101, 110, 100, 105, 102, 34, 125,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 99, 111, 109, 109,
  97, 110, 100, 61, 36, 99, 111, 109, 109, 97, 110, 100, 34, 35, 64, 103,
  105, 109, 112, 32, 60, 34, 36, 98, 97, 108, 105, 115, 101, 34, 62, 34,
  64, 123, 36, 62, 44, 116, 125, 34, 60, 47, 34, 36, 98, 97, 108, 105,
  115, 101, 34, 62, 92, 110, 34, 10, 98, 97, 108, 105, 115, 101, 61, 34,
  105, 34, 10, 45, 100, 111, 110, 101, 32, 45, 114, 109, 10, 45, 101, 110,
  100, 108, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 110,
  97, 114, 103, 40, 36, 99, 111, 109, 109, 97, 110, 100, 41, 125, 32, 110,
  97, 109, 101, 61, 64, 123, 48, 44, 110, 125, 32, 45, 105, 91, 48, 93,
  32, 40, 123, 39, 36, 99, 111, 109, 109, 97, 110, 100, 39, 125, 41, 32,
  45, 121, 91, 48, 93, 32, 45, 97, 32, 121, 32, 45, 110, 109, 32, 36,
  110, 97, 109, 101, 10, 45, 101, 110, 100, 105, 102, 10, 112, 97, 116, 104,
  61, 36, 110, 112, 97, 116, 104, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 118, 32, 43, 32,
  45, 101, 91, 93, 32, 34, 62, 32, 83, 97, 118, 101, 32, 111, 117, 116,
  112, 117, 116, 32, 46, 103, 109, 105, 99, 32, 102, 105, 108, 101, 46, 92,
  110, 34, 32, 45, 118, 32, 45, 10, 45, 45, 97, 32, 121, 32, 45, 105,
  102, 32, 123, 104, 62, 49, 125, 32, 45, 114, 91, 45, 49, 93, 32, 49,
  44, 123, 104, 45, 49, 125, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48,
  44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 111, 91, 45, 49, 93,
  32, 114, 97, 119, 58, 36, 72, 79, 77, 69, 47, 46, 117, 112, 100, 97,
  116, 101, 36, 49, 46, 103, 109, 105, 99, 44, 117, 99, 104, 97, 114, 10,
  45, 120, 32, 34, 115, 99, 112, 32, 34, 36, 72, 79, 77, 69, 47, 46,
  117, 112, 100, 97, 116, 101, 36, 49, 46, 103, 109, 105, 99, 34, 32, 114,
  111, 110, 111, 117, 110, 111, 117, 114, 115, 44, 103, 109, 105, 99, 64, 119,
  101, 98, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110,
  101, 116, 58, 104, 116, 100, 111, 99, 115, 47, 34, 117, 112, 100, 97, 116,
  101, 36, 49, 46, 103, 109, 105, 99, 10, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 105, 102, 32, 36, 50, 10, 45, 118, 32, 43, 32, 45, 101, 91,
  93, 32, 34, 62, 32, 79, 117, 116, 112, 117, 116, 32, 108, 105, 115, 116,
  32, 111, 102, 32, 102, 105, 108, 116, 101, 114, 115, 32, 105, 110, 32, 115,
  116, 100, 111, 117, 116, 46, 92, 110, 34, 32, 45, 118, 32, 45, 10, 45,
  101, 120, 101, 99, 32, 34, 100, 97, 116, 101, 32, 43, 37, 89, 44, 37,
  109, 44, 37, 100, 32, 62, 34, 64, 123, 45, 112, 97, 116, 104, 95, 116,
  109, 112, 125, 47, 100, 97, 116, 101, 46, 100, 108, 109, 10, 64, 123, 45,
  112, 97, 116, 104, 95, 116, 109, 112, 125, 47, 100, 97, 116, 101, 46, 100,
  108, 109, 10, 45, 101, 99, 104, 111, 95, 115, 116, 100, 111, 117, 116, 32,
  34, 42, 42, 42, 32, 76, 105, 115, 116, 32, 111, 102, 32, 102, 105, 108,
  116, 101, 114, 115, 32, 105, 110, 32, 116, 104, 101, 32, 71, 39, 77, 73,
  67, 32, 112, 108, 117, 103, 45, 105, 110, 32, 102, 111, 114, 32, 71, 73,
  77, 80, 32, 40, 34, 36, 110, 98, 95, 102, 105, 108, 116, 101, 114, 115,
  34, 32, 102, 105, 108, 116, 101, 114, 115, 44, 32, 111, 110, 32, 34, 123,
  105, 125, 47, 123, 105, 40, 49, 41, 125, 47, 123, 105, 40, 50, 41, 125,
  34, 41, 32, 42, 42, 42, 92, 110, 34, 10, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 101, 99, 104, 111, 95, 115, 116, 100, 111, 117, 116, 32, 34,
  42, 32, 76, 105, 115, 116, 32, 111, 102, 32, 102, 105, 108, 116, 101, 114,
  115, 44, 32, 115, 111, 114, 116, 101, 100, 32, 98, 121, 32, 112, 97, 116,
  104, 58, 92, 110, 34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 40, 123, 39, 64, 123, 48, 44, 110,
  125, 39, 125, 41, 32, 45, 105, 102, 32, 123, 105, 33, 61, 123, 39, 33,
  39, 125, 125, 10, 45, 114, 91, 45, 49, 93, 32, 123, 119, 45, 49, 125,
  44, 49, 44, 49, 44, 49, 44, 48, 44, 48, 44, 49, 10, 45, 114, 101,
  112, 108, 97, 99, 101, 95, 115, 101, 113, 91, 45, 49, 93, 32, 64, 123,
  45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 38, 97, 109, 112, 59, 39,
  125, 125, 44, 123, 39, 38, 39, 125, 10, 45, 114, 101, 112, 108, 97, 99,
  101, 95, 115, 101, 113, 91, 45, 49, 93, 32, 64, 123, 45, 113, 117, 111,
  116, 101, 92, 32, 123, 39, 34, 38, 35, 50, 51, 51, 59, 34, 39, 125,
  125, 44, 123, 39, 101, 39, 125, 10, 45, 114, 101, 112, 108, 97, 99, 101,
  95, 115, 101, 113, 91, 45, 49, 93, 32, 123, 39, 47, 39, 125, 44, 64,
  123, 45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 126, 47, 126, 39, 125,
  125, 10, 45, 114, 101, 112, 108, 97, 99, 101, 91, 45, 49, 93, 32, 123,
  39, 126, 39, 125, 44, 51, 50, 10, 45, 101, 99, 104, 111, 95, 115, 116,
  100, 111, 117, 116, 91, 93, 32, 34, 32, 32, 34, 64, 123, 45, 49, 44,
  116, 125, 10, 45, 101, 110, 100, 105, 102, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101,
  99, 104, 111, 95, 115, 116, 100, 111, 117, 116, 32, 34, 92, 110, 42, 32,
  76, 105, 115, 116, 32, 111, 102, 32, 102, 105, 108, 116, 101, 114, 115, 44,
  32, 115, 111, 114, 116, 101, 100, 32, 97, 108, 112, 104, 97, 98, 101, 116,
  105, 99, 97, 108, 108, 121, 58, 92, 110, 34, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 10, 110, 97, 109, 101, 61, 64, 123, 36, 62, 44,
  98, 125, 10, 112, 97, 116, 104, 61, 64, 123, 36, 62, 44, 102, 125, 10,
  45, 110, 109, 91, 36, 62, 93, 32, 36, 110, 97, 109, 101, 34, 126, 40,
  105, 110, 126, 39, 34, 36, 112, 97, 116, 104, 34, 39, 41, 34, 10, 45,
  100, 111, 110, 101, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103, 109,
  105, 99, 95, 103, 105, 109, 112, 95, 115, 111, 114, 116, 32, 48, 44, 123,
  64, 35, 45, 49, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 40, 123, 39, 64, 123, 48, 44, 110,
  125, 39, 125, 41, 32, 45, 105, 102, 32, 123, 105, 33, 61, 123, 39, 33,
  39, 125, 125, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113,
  91, 45, 49, 93, 32, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 123,
  39, 38, 97, 109, 112, 59, 39, 125, 125, 44, 123, 39, 38, 39, 125, 10,
  45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 91, 45, 49, 93,
  32, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 34, 38, 35,
  50, 51, 51, 59, 34, 39, 125, 125, 44, 123, 39, 101, 39, 125, 10, 45,
  114, 101, 112, 108, 97, 99, 101, 91, 45, 49, 93, 32, 123, 39, 126, 39,
  125, 44, 51, 50, 10, 45, 101, 99, 104, 111, 95, 115, 116, 100, 111, 117,
  116, 91, 93, 32, 34, 32, 32, 34, 64, 123, 45, 49, 44, 116, 125, 10,
  45, 101, 110, 100, 105, 102, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 99, 104, 111,
  95, 115, 116, 100, 111, 117, 116, 32, 34, 92, 110, 42, 42, 42, 32, 69,
  110, 100, 32, 111, 102, 32, 108, 105, 115, 116, 32, 42, 42, 42, 92, 110,
  34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 32, 45, 118, 32,
  43, 32, 45, 101, 91, 93, 32, 34, 62, 32, 65, 108, 108, 32, 100, 111,
  110, 101, 32, 33, 92, 110, 34, 10, 95, 117, 112, 100, 97, 116, 101, 95,
  103, 109, 105, 99, 95, 103, 105, 109, 112, 95, 115, 111, 114, 116, 32, 58,
  10, 109, 105, 100, 61, 123, 105, 110, 116, 40, 40, 36, 49, 43, 36, 50,
  41, 47, 50, 41, 125, 10, 45, 105, 102, 32, 64, 123, 34, 45, 95, 109,
  97, 120, 91, 93, 32, 34, 64, 123, 36, 49, 44, 110, 125, 44, 64, 123,
  36, 109, 105, 100, 44, 110, 125, 125, 32, 45, 114, 118, 91, 36, 49, 44,
  36, 109, 105, 100, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 64, 123, 34, 45, 95, 109, 97, 120, 91, 93, 32, 34, 64, 123, 36,
  109, 105, 100, 44, 110, 125, 44, 64, 123, 36, 50, 44, 110, 125, 125, 32,
  45, 114, 118, 91, 36, 50, 44, 36, 109, 105, 100, 93, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 64, 123, 34, 45, 95, 109, 97, 120,
  91, 93, 32, 34, 64, 123, 36, 49, 44, 110, 125, 44, 64, 123, 36, 109,
  105, 100, 44, 110, 125, 125, 32, 45, 114, 118, 91, 36, 49, 44, 36, 109,
  105, 100, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 50, 45, 36, 49, 62, 61, 51, 125, 10, 112, 105, 118, 111, 116, 61,
  64, 123, 36, 109, 105, 100, 44, 110, 125, 10, 105, 61, 36, 49, 32, 106,
  61, 36, 50, 10, 45, 100, 111, 10, 45, 105, 102, 32, 64, 123, 34, 45,
  95, 109, 97, 120, 91, 93, 32, 34, 36, 112, 105, 118, 111, 116, 44, 64,
  123, 36, 105, 44, 110, 125, 125, 32, 45, 100, 111, 32, 105, 61, 123, 36,
  105, 43, 49, 125, 32, 45, 119, 104, 105, 108, 101, 32, 64, 123, 34, 45,
  95, 109, 97, 120, 91, 93, 32, 34, 36, 112, 105, 118, 111, 116, 44, 64,
  123, 36, 105, 44, 110, 125, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 64, 123, 34, 45, 95, 109, 97, 120, 91, 93, 32, 34, 64,
  123, 36, 106, 44, 110, 125, 44, 36, 112, 105, 118, 111, 116, 125, 32, 45,
  100, 111, 32, 106, 61, 123, 36, 106, 45, 49, 125, 32, 45, 119, 104, 105,
  108, 101, 32, 64, 123, 34, 45, 95, 109, 97, 120, 91, 93, 32, 34, 64,
  123, 36, 106, 44, 110, 125, 44, 36, 112, 105, 118, 111, 116, 125, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 105, 60, 61, 36,
  106, 125, 32, 45, 114, 118, 91, 36, 105, 44, 36, 106, 93, 32, 105, 61,
  123, 36, 105, 43, 49, 125, 32, 106, 61, 123, 36, 106, 45, 49, 125, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123, 36,
  105, 60, 61, 36, 106, 125, 10, 45, 105, 102, 32, 123, 36, 49, 60, 36,
  106, 125, 32, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103, 109, 105, 99,
  95, 103, 105, 109, 112, 95, 115, 111, 114, 116, 32, 36, 49, 44, 36, 106,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 105, 60,
  36, 50, 125, 32, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103, 109, 105,
  99, 95, 103, 105, 109, 112, 95, 115, 111, 114, 116, 32, 36, 105, 44, 36,
  50, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10,
  95, 117, 112, 100, 97, 116, 101, 95, 103, 109, 105, 99, 95, 103, 105, 109,
  112, 95, 109, 111, 118, 101, 32, 58, 10, 45, 105, 102, 32, 123, 33, 110,
  97, 114, 103, 40, 36, 95, 110, 98, 109, 41, 125, 32, 95, 110, 98, 109,
  61, 48, 32, 45, 101, 110, 100, 105, 102, 10, 95, 116, 111, 95, 109, 111,
  118, 101, 36, 123, 95, 110, 98, 109, 125, 61, 34, 36, 49, 34, 32, 95,
  109, 111, 118, 101, 95, 116, 111, 36, 123, 95, 110, 98, 109, 125, 61, 34,
  36, 50, 34, 32, 95, 110, 98, 109, 61, 123, 36, 95, 110, 98, 109, 43,
  49, 125, 10, 95, 98, 101, 102, 111, 114, 101, 32, 58, 10, 51, 51, 44,
  49, 49, 32, 45, 116, 91, 45, 49, 93, 32, 34, 66, 101, 102, 111, 114,
  101, 34, 44, 49, 44, 45, 49, 44, 49, 51, 44, 49, 44, 49, 10, 95,
  97, 102, 116, 101, 114, 32, 58, 10, 50, 54, 44, 49, 49, 32, 45, 116,
  91, 45, 49, 93, 32, 34, 65, 102, 116, 101, 114, 34, 44, 49, 44, 45,
  49, 44, 49, 51, 44, 49, 44, 49, 10, 103, 105, 109, 112, 95, 115, 112,
  108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 105, 102, 32, 123, 36, 50,
  61, 61, 48, 125, 32, 45, 101, 91, 93, 32, 34, 36, 49, 34, 32, 45,
  108, 91, 45, 49, 93, 32, 36, 49, 32, 45, 101, 110, 100, 108, 32, 45,
  109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 99, 111, 110, 116, 105, 110,
  117, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 33,
  40, 36, 50, 37, 50, 41, 125, 10, 45, 115, 91, 45, 49, 93, 32, 120,
  44, 50, 10, 45, 105, 102, 32, 123, 36, 50, 61, 61, 50, 125, 32, 45,
  108, 91, 45, 49, 93, 32, 36, 49, 32, 45, 101, 110, 100, 108, 32, 45,
  116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 91, 45, 50, 44,
  45, 49, 93, 32, 48, 32, 45, 95, 98, 101, 102, 111, 114, 101, 32, 45,
  95, 97, 102, 116, 101, 114, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50,
  61, 61, 52, 125, 32, 45, 108, 91, 45, 50, 93, 32, 36, 49, 32, 45,
  101, 110, 100, 108, 32, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111,
  100, 101, 91, 45, 50, 44, 45, 49, 93, 32, 48, 32, 45, 95, 97, 102,
  116, 101, 114, 32, 45, 95, 98, 101, 102, 111, 114, 101, 10, 45, 101, 108,
  115, 101, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 45, 108, 91, 45,
  49, 93, 32, 36, 49, 32, 45, 101, 110, 100, 108, 32, 45, 116, 111, 95,
  99, 111, 108, 111, 114, 109, 111, 100, 101, 91, 45, 50, 44, 45, 49, 93,
  32, 48, 32, 45, 95, 98, 101, 102, 111, 114, 101, 32, 45, 95, 97, 102,
  116, 101, 114, 10, 45, 101, 110, 100, 105, 102, 10, 45, 108, 105, 110, 101,
  91, 45, 51, 93, 32, 48, 44, 48, 44, 48, 44, 64, 123, 45, 51, 44,
  104, 125, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 32, 45,
  97, 91, 45, 52, 44, 45, 51, 93, 32, 120, 10, 45, 101, 108, 115, 101,
  10, 45, 115, 91, 45, 49, 93, 32, 121, 44, 50, 10, 45, 105, 102, 32,
  123, 36, 50, 61, 61, 49, 125, 32, 45, 108, 91, 45, 49, 93, 32, 36,
  49, 32, 45, 101, 110, 100, 108, 32, 45, 116, 111, 95, 99, 111, 108, 111,
  114, 109, 111, 100, 101, 91, 45, 50, 44, 45, 49, 93, 32, 123, 109, 97,
  120, 40, 64, 123, 45, 50, 44, 115, 125, 44, 115, 41, 125, 32, 45, 95,
  98, 101, 102, 111, 114, 101, 32, 45, 95, 97, 102, 116, 101, 114, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 50, 61, 61, 51, 125, 32, 45, 108, 91,
  45, 50, 93, 32, 36, 49, 32, 45, 101, 110, 100, 108, 32, 45, 116, 111,
  95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 91, 45, 50, 44, 45, 49,
  93, 32, 123, 109, 97, 120, 40, 64, 123, 45, 50, 44, 115, 125, 44, 115,
  41, 125, 32, 45, 95, 97, 102, 116, 101, 114, 32, 45, 95, 98, 101, 102,
  111, 114, 101, 10, 45, 101, 108, 115, 101, 32, 45, 114, 109, 91, 45, 49,
  93, 32, 45, 45, 108, 91, 45, 49, 93, 32, 36, 49, 32, 45, 101, 110,
  100, 108, 32, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101,
  91, 45, 50, 44, 45, 49, 93, 32, 48, 32, 45, 95, 98, 101, 102, 111,
  114, 101, 32, 45, 95, 97, 102, 116, 101, 114, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 108, 105, 110, 101, 91, 45, 51, 93, 32, 48, 44, 48, 44,
  64, 123, 45, 51, 44, 119, 125, 44, 48, 44, 49, 44, 48, 44, 48, 44,
  48, 44, 50, 53, 53, 32, 45, 97, 91, 45, 52, 44, 45, 51, 93, 32,
  121, 10, 45, 101, 110, 100, 105, 102, 10, 45, 45, 100, 105, 108, 97, 116,
  101, 91, 45, 50, 44, 45, 49, 93, 32, 51, 32, 45, 42, 91, 45, 52,
  44, 45, 51, 93, 32, 50, 53, 53, 32, 45, 116, 111, 95, 99, 111, 108,
  111, 114, 109, 111, 100, 101, 91, 45, 52, 44, 45, 51, 93, 32, 64, 123,
  45, 53, 44, 115, 125, 10, 45, 106, 91, 45, 53, 93, 32, 91, 45, 52,
  93, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46, 56, 44, 91, 45,
  50, 93, 32, 45, 106, 91, 45, 53, 93, 32, 91, 45, 51, 93, 44, 123,
  64, 123, 45, 53, 44, 119, 125, 45, 119, 45, 49, 125, 44, 123, 64, 123,
  45, 53, 44, 104, 125, 45, 104, 45, 49, 125, 44, 48, 44, 48, 44, 48,
  46, 56, 44, 91, 45, 49, 93, 10, 45, 114, 109, 91, 45, 52, 45, 45,
  49, 93, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111,
  110, 101, 10, 103, 105, 109, 112, 95, 110, 111, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 110, 111, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 78, 111, 32, 112, 114, 101, 118, 105,
  101, 119, 92, 110, 97, 118, 97, 105, 108, 97, 98, 108, 101, 34, 44, 34,
  36, 42, 34, 10, 95, 103, 105, 109, 112, 95, 110, 111, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 105, 102, 32, 123, 64, 35, 62, 48,
  125, 32, 45, 107, 91, 48, 93, 32, 45, 101, 108, 115, 101, 32, 50, 53,
  54, 44, 50, 53, 54, 44, 49, 44, 49, 44, 49, 50, 56, 32, 45, 101,
  110, 100, 105, 102, 10, 49, 49, 56, 44, 53, 48, 32, 45, 116, 91, 45,
  49, 93, 32, 34, 36, 49, 34, 44, 50, 44, 49, 44, 50, 52, 44, 49,
  44, 50, 53, 53, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  44, 91, 45, 50, 93, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 32, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109,
  111, 100, 101, 91, 45, 49, 93, 32, 64, 123, 45, 50, 44, 115, 125, 10,
  40, 49, 46, 53, 44, 48, 44, 49, 46, 53, 59, 48, 44, 48, 44, 48,
  59, 49, 46, 53, 44, 48, 44, 49, 46, 53, 41, 32, 45, 114, 91, 45,
  49, 93, 32, 91, 45, 51, 93, 44, 51, 32, 45, 42, 91, 45, 51, 44,
  45, 49, 93, 32, 45, 99, 91, 45, 50, 93, 32, 48, 44, 50, 53, 53,
  32, 45, 111, 114, 10, 45, 115, 107, 105, 112, 32, 34, 36, 42, 34, 10,
  103, 105, 109, 112, 95, 108, 111, 103, 111, 95, 118, 101, 114, 115, 105, 111,
  110, 51, 32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36, 123, 49, 61,
  80, 108, 117, 103, 45, 105, 110, 32, 102, 111, 114, 32, 71, 73, 77, 80,
  125, 34, 10, 45, 114, 109, 32, 115, 61, 34, 71, 39, 77, 73, 67, 34,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 110, 97, 114, 103, 40, 123,
  39, 36, 115, 39, 125, 41, 125, 10, 48, 32, 45, 116, 101, 120, 116, 91,
  45, 49, 93, 32, 123, 96, 123, 97, 114, 103, 40, 49, 43, 36, 62, 44,
  123, 39, 36, 115, 39, 125, 41, 125, 96, 125, 44, 48, 44, 48, 44, 53,
  55, 44, 49, 44, 49, 32, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93,
  32, 51, 44, 48, 44, 48, 10, 45, 114, 91, 45, 49, 93, 32, 53, 48,
  48, 37, 44, 53, 48, 48, 37, 44, 49, 44, 49, 44, 51, 32, 45, 98,
  91, 45, 49, 93, 32, 51, 37, 32, 45, 103, 101, 91, 45, 49, 93, 32,
  53, 48, 37, 10, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49,
  93, 32, 49, 32, 45, 108, 101, 91, 45, 49, 93, 32, 49, 48, 10, 91,
  45, 49, 93, 120, 51, 32, 45, 119, 104, 105, 114, 108, 115, 91, 45, 52,
  45, 45, 50, 93, 32, 44, 10, 114, 36, 62, 61, 123, 63, 40, 48, 46,
  52, 44, 49, 41, 125, 32, 103, 36, 62, 61, 123, 63, 40, 48, 46, 50,
  44, 49, 41, 125, 32, 98, 36, 62, 61, 123, 63, 40, 48, 46, 54, 44,
  49, 41, 125, 10, 45, 42, 91, 45, 52, 93, 32, 36, 123, 114, 36, 62,
  125, 32, 45, 42, 91, 45, 51, 93, 32, 36, 123, 103, 36, 62, 125, 32,
  45, 42, 91, 45, 50, 93, 32, 36, 123, 98, 36, 62, 125, 10, 45, 97,
  91, 45, 52, 45, 45, 50, 93, 32, 99, 32, 45, 110, 91, 45, 50, 93,
  32, 48, 44, 50, 53, 53, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53,
  53, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 100,
  111, 110, 101, 10, 45, 97, 91, 45, 53, 45, 45, 49, 93, 32, 120, 10,
  45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 50, 48, 37,
  44, 49, 44, 52, 44, 48, 44, 48, 44, 48, 46, 53, 44, 49, 10, 45,
  98, 97, 108, 108, 32, 54, 52, 44, 123, 50, 53, 53, 42, 36, 114, 51,
  125, 44, 123, 50, 53, 53, 42, 36, 103, 51, 125, 44, 123, 50, 53, 53,
  42, 36, 98, 51, 125, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 52, 50, 48, 44, 49, 53, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 115, 104, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 55,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 97, 117, 116, 111, 99, 114,
  111, 112, 91, 45, 49, 93, 10, 45, 100, 114, 111, 112, 95, 115, 104, 97,
  100, 111, 119, 91, 45, 49, 93, 32, 49, 48, 44, 49, 48, 44, 49, 37,
  44, 48, 46, 53, 10, 48, 32, 45, 116, 101, 120, 116, 91, 45, 49, 93,
  32, 34, 36, 49, 34, 44, 48, 44, 48, 44, 53, 55, 44, 49, 44, 50,
  53, 53, 32, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93, 32, 52, 44,
  52, 44, 48, 32, 91, 45, 49, 93, 120, 51, 32, 45, 100, 105, 108, 97,
  116, 101, 91, 45, 49, 93, 32, 55, 32, 45, 97, 91, 45, 52, 45, 45,
  49, 93, 32, 99, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121,
  44, 48, 46, 53, 10, 45, 114, 50, 100, 121, 91, 45, 49, 93, 32, 53,
  48, 37, 10, 45, 105, 91, 45, 50, 93, 32, 49, 50, 48, 37, 44, 49,
  50, 48, 37, 44, 49, 44, 51, 44, 50, 53, 53, 32, 45, 112, 108, 97,
  115, 109, 97, 91, 45, 50, 93, 32, 49, 44, 49, 32, 45, 115, 91, 45,
  50, 93, 32, 99, 10, 45, 110, 91, 45, 52, 93, 32, 49, 53, 48, 44,
  50, 53, 53, 32, 45, 110, 91, 45, 51, 93, 32, 49, 56, 48, 44, 50,
  53, 53, 32, 45, 110, 91, 45, 50, 93, 32, 50, 48, 48, 44, 50, 53,
  53, 32, 45, 97, 91, 45, 52, 45, 45, 50, 93, 32, 99, 10, 45, 98,
  108, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 97, 108, 112, 104,
  97, 10, 45, 102, 114, 97, 109, 101, 32, 48, 44, 49, 44, 48, 44, 48,
  44, 48, 32, 45, 102, 114, 97, 109, 101, 32, 48, 44, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 103, 105, 109, 112, 95, 108,
  111, 103, 111, 95, 118, 101, 114, 115, 105, 111, 110, 50, 32, 58, 32, 45,
  115, 107, 105, 112, 32, 34, 36, 123, 49, 61, 80, 108, 117, 103, 45, 105,
  110, 32, 102, 111, 114, 32, 71, 73, 77, 80, 125, 34, 10, 45, 105, 102,
  32, 64, 35, 32, 45, 107, 91, 48, 93, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 116, 111, 95, 114, 103, 98, 32, 48, 32, 45, 116, 91, 45, 49,
  93, 32, 34, 71, 39, 77, 73, 67, 34, 44, 48, 44, 48, 44, 53, 55,
  44, 49, 44, 49, 32, 45, 108, 97, 98, 101, 108, 91, 45, 49, 93, 10,
  54, 44, 49, 44, 49, 44, 51, 32, 45, 114, 97, 110, 100, 91, 45, 49,
  93, 32, 49, 53, 48, 44, 50, 53, 53, 32, 45, 112, 111, 105, 110, 116,
  91, 45, 49, 93, 32, 48, 32, 45, 109, 97, 112, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 120,
  112, 97, 110, 100, 95, 120, 121, 91, 45, 49, 93, 32, 49, 48, 44, 48,
  32, 45, 98, 91, 45, 49, 93, 32, 50, 32, 45, 114, 91, 45, 49, 93,
  32, 50, 48, 48, 37, 44, 50, 48, 48, 37, 44, 49, 44, 51, 44, 54,
  32, 45, 115, 113, 114, 91, 45, 49, 93, 32, 45, 99, 91, 45, 49, 93,
  32, 48, 44, 54, 48, 37, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 10, 45, 119, 97, 114, 112, 95, 112, 101, 114, 115, 112, 101,
  99, 116, 105, 118, 101, 91, 45, 49, 93, 32, 48, 46, 53, 44, 48, 44,
  49, 44, 53, 48, 44, 53, 48, 44, 48, 32, 45, 115, 104, 105, 102, 116,
  91, 45, 49, 93, 32, 48, 44, 45, 49, 48, 10, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32,
  48, 46, 56, 44, 50, 32, 45, 42, 91, 45, 49, 93, 32, 49, 56, 48,
  32, 45, 45, 98, 108, 117, 114, 95, 108, 105, 110, 101, 97, 114, 91, 45,
  49, 93, 32, 50, 48, 44, 48, 44, 52, 53, 44, 48, 32, 45, 42, 91,
  45, 49, 93, 32, 50, 48, 32, 45, 109, 97, 120, 91, 45, 51, 45, 45,
  49, 93, 10, 45, 115, 104, 91, 45, 49, 93, 32, 50, 44, 50, 32, 40,
  48, 59, 49, 50, 56, 41, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 44, 51, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  109, 105, 110, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 116, 101, 120, 116, 95, 111, 117, 116, 108, 105, 110,
  101, 91, 45, 49, 93, 32, 34, 36, 49, 34, 44, 51, 50, 37, 44, 55,
  53, 37, 44, 49, 51, 44, 51, 44, 49, 44, 50, 53, 53, 32, 45, 102,
  114, 97, 109, 101, 91, 45, 49, 93, 32, 49, 44, 49, 44, 49, 50, 56,
  32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 10, 45, 105, 102, 32, 123,
  64, 35, 62, 49, 125, 32, 45, 42, 91, 94, 48, 93, 32, 48, 46, 52,
  53, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125,
  32, 45, 106, 91, 45, 49, 93, 32, 91, 48, 93, 44, 123, 40, 119, 45,
  64, 123, 48, 44, 119, 125, 41, 47, 50, 125, 44, 123, 40, 104, 45, 64,
  123, 48, 44, 104, 125, 41, 47, 50, 125, 32, 45, 109, 118, 91, 45, 49,
  93, 32, 49, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 93,
  32, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 108, 111, 103,
  111, 95, 118, 101, 114, 115, 105, 111, 110, 49, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 34, 36, 123, 49, 61, 80, 108, 117, 103, 45, 105, 110, 32,
  102, 111, 114, 32, 71, 73, 77, 80, 125, 34, 10, 45, 105, 102, 32, 64,
  35, 32, 114, 97, 116, 105, 111, 61, 123, 119, 47, 104, 125, 32, 45, 101,
  108, 115, 101, 32, 114, 97, 116, 105, 111, 61, 49, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 114, 109, 32, 49, 49, 56, 44, 52, 52, 44, 49, 44,
  49, 32, 45, 116, 32, 34, 71, 39, 77, 73, 67, 34, 44, 51, 44, 45,
  54, 44, 53, 55, 44, 49, 44, 50, 53, 53, 32, 45, 114, 32, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 44, 49, 32, 45, 114, 32,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 50, 48, 44, 49, 44, 48,
  44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45,
  98, 32, 49, 46, 53, 10, 45, 105, 115, 111, 115, 117, 114, 102, 97, 99,
  101, 51, 100, 32, 53, 48, 37, 10, 45, 99, 111, 108, 51, 100, 32, 123,
  63, 40, 49, 53, 48, 44, 50, 53, 53, 41, 125, 44, 123, 63, 40, 49,
  53, 48, 44, 50, 53, 53, 41, 125, 44, 123, 63, 40, 49, 53, 48, 44,
  50, 53, 53, 41, 125, 10, 45, 115, 112, 104, 101, 114, 101, 51, 100, 32,
  56, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 123, 63, 40,
  49, 53, 48, 44, 50, 53, 53, 41, 125, 44, 123, 63, 40, 49, 53, 48,
  44, 50, 53, 53, 41, 125, 44, 123, 63, 40, 49, 53, 48, 44, 50, 53,
  53, 41, 125, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 55, 50, 44,
  45, 54, 32, 45, 43, 51, 100, 32, 45, 99, 51, 100, 91, 45, 49, 93,
  32, 45, 114, 118, 51, 100, 10, 45, 100, 98, 51, 100, 32, 48, 32, 45,
  115, 108, 51, 100, 32, 48, 46, 50, 32, 45, 115, 115, 51, 100, 32, 49,
  46, 51, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 49, 44, 48, 44,
  48, 44, 51, 48, 32, 45, 102, 51, 100, 32, 49, 50, 48, 32, 45, 42,
  51, 100, 91, 45, 49, 93, 32, 49, 46, 53, 10, 50, 51, 48, 44, 49,
  50, 48, 44, 49, 44, 51, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100,
  91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 53, 48, 37, 44, 51, 48,
  37, 44, 48, 44, 49, 44, 52, 32, 45, 114, 109, 91, 45, 50, 93, 32,
  45, 116, 32, 34, 36, 49, 34, 44, 51, 54, 37, 44, 55, 53, 37, 44,
  49, 51, 44, 49, 44, 50, 53, 53, 10, 45, 116, 111, 95, 114, 103, 98,
  97, 32, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114,
  32, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 48,
  44, 48, 44, 48, 44, 48, 32, 45, 100, 114, 111, 112, 95, 115, 104, 97,
  100, 111, 119, 32, 54, 44, 54, 44, 50, 10, 45, 105, 91, 45, 50, 93,
  32, 64, 123, 45, 102, 105, 116, 114, 97, 116, 105, 111, 95, 119, 104, 92,
  32, 50, 51, 48, 44, 49, 50, 48, 44, 36, 114, 97, 116, 105, 111, 125,
  44, 49, 44, 51, 10, 45, 114, 97, 110, 100, 91, 45, 50, 93, 32, 48,
  44, 50, 53, 53, 32, 45, 115, 104, 91, 45, 50, 93, 32, 48, 44, 48,
  32, 45, 47, 91, 45, 49, 93, 32, 50, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 98, 108, 117, 114, 95, 114, 97, 100, 105, 97, 108, 91, 45,
  50, 93, 32, 49, 48, 32, 45, 115, 104, 97, 114, 112, 101, 110, 91, 45,
  50, 93, 32, 54, 48, 48, 10, 45, 114, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 52, 44, 48, 44, 48, 44,
  48, 46, 53, 44, 48, 46, 53, 32, 45, 98, 108, 101, 110, 100, 32, 97,
  108, 112, 104, 97, 10, 103, 105, 109, 112, 95, 108, 111, 103, 111, 95, 101,
  110, 32, 58, 10, 45, 103, 105, 109, 112, 95, 108, 111, 103, 111, 95, 118,
  101, 114, 115, 105, 111, 110, 123, 114, 111, 117, 110, 100, 40, 63, 40, 49,
  44, 51, 41, 41, 125, 32, 34, 80, 108, 117, 103, 45, 105, 110, 32, 102,
  111, 114, 32, 71, 73, 77, 80, 92, 110, 32, 32, 32, 32, 34, 91, 34,
  32, 34, 64, 123, 45, 115, 116, 114, 118, 101, 114, 125, 34, 32, 34, 93,
  10, 103, 105, 109, 112, 95, 108, 111, 103, 111, 95, 102, 114, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 108, 111, 103, 111, 95, 118, 101, 114, 115, 105,
  111, 110, 123, 114, 111, 117, 110, 100, 40, 63, 40, 49, 44, 51, 41, 41,
  125, 32, 34, 71, 114, 101, 102, 102, 111, 110, 32, 112, 111, 117, 114, 32,
  71, 73, 77, 80, 92, 110, 32, 32, 32, 34, 91, 34, 32, 34, 64, 123,
  45, 115, 116, 114, 118, 101, 114, 125, 34, 32, 34, 93, 10, 103, 105, 109,
  112, 95, 108, 111, 103, 111, 95, 99, 97, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 108, 111, 103, 111, 95, 118, 101, 114, 115, 105, 111, 110, 123, 114,
  111, 117, 110, 100, 40, 63, 40, 49, 44, 51, 41, 41, 125, 32, 34, 32,
  32, 112, 101, 114, 32, 97, 108, 32, 71, 73, 77, 80, 92, 110, 32, 32,
  32, 34, 91, 34, 32, 34, 64, 123, 45, 115, 116, 114, 118, 101, 114, 125,
  34, 32, 34, 93, 10, 103, 105, 109, 112, 95, 100, 105, 115, 112, 108, 97,
  121, 95, 102, 105, 108, 116, 101, 114, 95, 115, 111, 117, 114, 99, 101, 115,
  32, 58, 10, 45, 105, 102, 32, 64, 35, 32, 45, 107, 91, 48, 93, 32,
  45, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 32,
  45, 102, 32, 48, 32, 45, 101, 108, 115, 101, 32, 50, 53, 54, 44, 50,
  53, 54, 32, 45, 101, 110, 100, 105, 102, 10, 45, 108, 91, 93, 32, 45,
  103, 105, 109, 112, 95, 102, 105, 108, 116, 101, 114, 95, 115, 111, 117, 114,
  99, 101, 115, 32, 45, 121, 32, 120, 32, 45, 97, 32, 121, 32, 45, 111,
  110, 102, 97, 105, 108, 32, 40, 48, 41, 32, 45, 101, 110, 100, 108, 10,
  45, 116, 101, 120, 116, 91, 48, 93, 32, 34, 69, 110, 97, 98, 108, 101,
  100, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 115, 111, 117, 114, 99,
  101, 115, 58, 92, 110, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 34, 44, 53, 44, 53, 44, 49, 51, 44, 49, 44,
  50, 53, 53, 10, 45, 105, 102, 32, 64, 123, 45, 105, 115, 95, 119, 105,
  110, 100, 111, 119, 115, 125, 32, 112, 97, 116, 104, 61, 64, 123, 45, 112,
  97, 116, 104, 95, 117, 115, 101, 114, 125, 47, 32, 45, 101, 108, 115, 101,
  32, 112, 97, 116, 104, 61, 64, 123, 45, 112, 97, 116, 104, 95, 117, 115,
  101, 114, 125, 47, 46, 32, 45, 101, 110, 100, 105, 102, 10, 105, 61, 49,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 104, 125, 10, 45, 45, 114,
  111, 119, 115, 91, 45, 49, 93, 32, 36, 62, 10, 45, 105, 102, 32, 123,
  64, 123, 45, 49, 44, 48, 45, 51, 125, 39, 61, 61, 39, 123, 39, 104,
  116, 116, 112, 39, 125, 125, 10, 45, 116, 101, 120, 116, 91, 48, 93, 32,
  91, 36, 105, 93, 34, 32, 34, 64, 123, 45, 49, 44, 116, 125, 44, 53,
  44, 123, 51, 50, 43, 49, 53, 42, 36, 105, 125, 44, 49, 51, 44, 49,
  44, 50, 53, 53, 32, 105, 61, 123, 36, 105, 43, 49, 125, 10, 45, 101,
  108, 115, 101, 10, 45, 105, 102, 32, 36, 112, 97, 116, 104, 64, 123, 45,
  49, 44, 116, 125, 32, 45, 116, 101, 120, 116, 91, 48, 93, 32, 91, 36,
  105, 93, 34, 32, 34, 64, 123, 45, 49, 44, 116, 125, 34, 32, 40, 108,
  111, 99, 97, 108, 32, 102, 105, 108, 101, 41, 34, 44, 53, 44, 123, 51,
  50, 43, 49, 53, 42, 36, 105, 125, 44, 49, 51, 44, 49, 44, 50, 53,
  53, 32, 105, 61, 123, 36, 105, 43, 49, 125, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 45, 49, 93, 10, 103,
  105, 109, 112, 95, 102, 114, 105, 101, 110, 100, 115, 32, 58, 10, 45, 105,
  102, 32, 64, 35, 32, 114, 97, 116, 105, 111, 61, 123, 119, 47, 104, 125,
  32, 45, 101, 108, 115, 101, 32, 114, 97, 116, 105, 111, 61, 49, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 114, 109, 32, 45, 95, 104, 101, 97, 114,
  116, 56, 48, 120, 55, 51, 32, 45, 115, 99, 97, 108, 101, 51, 120, 32,
  45, 114, 32, 49, 53, 48, 37, 44, 49, 53, 48, 37, 44, 49, 44, 49,
  44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45, 42,
  91, 45, 49, 93, 32, 55, 48, 32, 45, 45, 42, 91, 45, 50, 93, 32,
  49, 49, 48, 32, 45, 45, 42, 91, 45, 51, 93, 32, 50, 53, 53, 32,
  45, 42, 91, 45, 52, 93, 32, 50, 53, 53, 32, 45, 97, 32, 99, 10,
  45, 98, 108, 117, 114, 95, 114, 97, 100, 105, 97, 108, 32, 52, 32, 45,
  115, 104, 97, 114, 112, 101, 110, 32, 51, 48, 48, 10, 45, 105, 91, 45,
  50, 93, 32, 64, 123, 45, 102, 105, 116, 114, 97, 116, 105, 111, 95, 119,
  104, 92, 32, 123, 119, 125, 44, 123, 104, 125, 44, 36, 114, 97, 116, 105,
  111, 125, 44, 49, 44, 51, 10, 45, 114, 97, 110, 100, 91, 45, 50, 93,
  32, 48, 44, 50, 53, 53, 32, 45, 115, 104, 91, 45, 50, 93, 32, 49,
  44, 50, 32, 45, 47, 91, 45, 49, 93, 32, 50, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 98, 108, 117, 114, 95, 114, 97, 100, 105, 97, 108,
  91, 45, 50, 93, 32, 49, 48, 32, 45, 115, 104, 97, 114, 112, 101, 110,
  91, 45, 50, 93, 32, 54, 48, 48, 10, 45, 114, 91, 45, 49, 93, 32,
  91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 52, 44, 48, 44,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 98, 108, 101, 110, 100,
  32, 97, 108, 112, 104, 97, 10, 49, 51, 53, 44, 54, 55, 44, 49, 44,
  49, 44, 48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 71, 114, 101, 101,
  116, 105, 110, 103, 115, 32, 116, 111, 92, 110, 32, 32, 97, 108, 108, 32,
  71, 39, 77, 73, 67, 92, 110, 32, 32, 102, 114, 105, 101, 110, 100, 115,
  33, 34, 44, 50, 44, 45, 50, 44, 50, 52, 44, 49, 44, 49, 10, 45,
  45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51, 32, 45, 42,
  91, 45, 50, 93, 32, 50, 53, 53, 32, 45, 116, 111, 95, 114, 103, 98,
  91, 45, 50, 93, 32, 45, 106, 91, 45, 51, 93, 32, 91, 45, 50, 93,
  44, 123, 40, 64, 123, 45, 51, 44, 119, 125, 45, 64, 123, 45, 50, 44,
  119, 125, 41, 47, 50, 125, 44, 123, 40, 64, 123, 45, 51, 44, 104, 125,
  45, 64, 123, 45, 50, 44, 104, 125, 41, 47, 50, 46, 50, 125, 44, 48,
  44, 48, 44, 49, 44, 91, 45, 49, 93, 10, 45, 114, 109, 91, 45, 50,
  44, 45, 49, 93, 10, 95, 104, 101, 97, 114, 116, 56, 48, 120, 55, 51,
  32, 58, 10, 52, 48, 44, 55, 51, 44, 49, 44, 49, 44, 48, 32, 45,
  101, 108, 108, 105, 112, 115, 101, 32, 50, 50, 44, 50, 50, 44, 50, 48,
  44, 50, 48, 44, 48, 44, 49, 44, 49, 32, 45, 112, 111, 108, 121, 103,
  111, 110, 32, 51, 44, 55, 44, 51, 55, 44, 52, 50, 44, 55, 50, 44,
  52, 50, 44, 50, 55, 44, 49, 44, 49, 32, 45, 45, 109, 105, 114, 114,
  111, 114, 32, 120, 32, 45, 97, 32, 120, 10, 103, 105, 109, 112, 95, 103,
  109, 105, 99, 107, 121, 32, 58, 10, 45, 114, 109, 10, 45, 105, 102, 32,
  123, 36, 49, 61, 61, 48, 125, 32, 45, 103, 109, 105, 99, 107, 121, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 32, 45, 103,
  109, 105, 99, 107, 121, 95, 119, 105, 108, 98, 101, 114, 10, 45, 101, 108,
  115, 101, 32, 45, 114, 111, 100, 100, 121, 10, 45, 101, 110, 100, 105, 102,
  10, 103, 105, 109, 112, 95, 103, 109, 105, 99, 107, 121, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123,
  104, 125, 32, 45, 114, 109, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61,
  48, 125, 10, 102, 105, 108, 101, 110, 97, 109, 101, 61, 64, 123, 45, 112,
  97, 116, 104, 95, 116, 109, 112, 125, 47, 103, 109, 105, 99, 107, 121, 95,
  115, 109, 97, 108, 108, 46, 99, 105, 109, 103, 122, 10, 117, 114, 108, 61,
  104, 116, 116, 112, 58, 47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114,
  99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 105, 109, 103, 47,
  103, 109, 105, 99, 107, 121, 95, 115, 109, 97, 108, 108, 46, 99, 105, 109,
  103, 122, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125,
  10, 102, 105, 108, 101, 110, 97, 109, 101, 61, 64, 123, 45, 112, 97, 116,
  104, 95, 116, 109, 112, 125, 47, 103, 109, 105, 99, 107, 121, 95, 119, 105,
  108, 98, 101, 114, 95, 115, 109, 97, 108, 108, 46, 99, 105, 109, 103, 122,
  10, 117, 114, 108, 61, 104, 116, 116, 112, 58, 47, 47, 103, 109, 105, 99,
  46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116,
  47, 105, 109, 103, 47, 103, 109, 105, 99, 107, 121, 95, 119, 105, 108, 98,
  101, 114, 95, 115, 109, 97, 108, 108, 46, 99, 105, 109, 103, 122, 10, 45,
  101, 108, 115, 101, 10, 102, 105, 108, 101, 110, 97, 109, 101, 61, 64, 123,
  45, 112, 97, 116, 104, 95, 116, 109, 112, 125, 47, 114, 111, 100, 100, 121,
  95, 115, 109, 97, 108, 108, 46, 99, 105, 109, 103, 122, 10, 117, 114, 108,
  61, 104, 116, 116, 112, 58, 47, 47, 103, 109, 105, 99, 46, 115, 111, 117,
  114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 105, 109, 103,
  47, 114, 111, 100, 100, 121, 95, 115, 109, 97, 108, 108, 46, 99, 105, 109,
  103, 122, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 102,
  105, 108, 101, 110, 97, 109, 101, 32, 36, 102, 105, 108, 101, 110, 97, 109,
  101, 32, 45, 101, 108, 115, 101, 32, 45, 105, 32, 36, 117, 114, 108, 32,
  45, 111, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 114, 50, 100, 121, 32, 36, 104, 32, 45, 45, 32,
  50, 53, 53, 32, 45, 114, 32, 36, 119, 44, 36, 104, 44, 49, 44, 51,
  44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 43, 32,
  50, 53, 53, 10, 103, 105, 109, 112, 95, 97, 114, 114, 97, 121, 95, 102,
  97, 100, 101, 32, 58, 10, 45, 105, 102, 32, 123, 36, 55, 38, 49, 125,
  32, 45, 109, 105, 114, 114, 111, 114, 32, 120, 32, 45, 101, 110, 100, 105,
  102, 32, 45, 105, 102, 32, 123, 36, 55, 62, 49, 125, 32, 45, 109, 105,
  114, 114, 111, 114, 32, 121, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97,
  114, 114, 97, 121, 95, 102, 97, 100, 101, 32, 36, 49, 44, 36, 50, 44,
  36, 53, 44, 36, 54, 44, 36, 56, 10, 45, 115, 104, 105, 102, 116, 32,
  45, 36, 51, 37, 44, 45, 36, 52, 37, 44, 48, 44, 48, 44, 50, 10,
  103, 105, 109, 112, 95, 97, 114, 114, 97, 121, 95, 102, 97, 100, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  97, 114, 114, 97, 121, 95, 102, 97, 100, 101, 32, 36, 49, 44, 36, 50,
  44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44,
  48, 10, 103, 105, 109, 112, 95, 97, 114, 114, 97, 121, 95, 109, 105, 114,
  114, 111, 114, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 55, 61,
  48, 125, 10, 45, 105, 102, 32, 123, 36, 53, 61, 61, 49, 125, 32, 45,
  109, 105, 114, 114, 111, 114, 32, 120, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 53, 61, 61, 50, 125, 32, 45, 109, 105, 114, 114, 111, 114, 32, 121,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 53, 61, 61, 51, 125, 32, 45,
  114, 111, 116, 97, 116, 101, 32, 57, 48, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 53, 61, 61, 52, 125, 32, 45, 114, 111, 116, 97, 116, 101, 32,
  49, 56, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 53, 61, 61, 53,
  125, 32, 45, 114, 111, 116, 97, 116, 101, 32, 50, 55, 48, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 55, 10, 45, 105, 102, 32,
  123, 36, 52, 61, 61, 48, 125, 32, 45, 99, 111, 108, 117, 109, 110, 115,
  32, 48, 44, 123, 49, 48, 48, 45, 36, 55, 125, 37, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 52, 61, 61, 49, 125, 32, 45, 114, 111, 119, 115,
  32, 48, 44, 123, 49, 48, 48, 45, 36, 55, 125, 37, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 52, 61, 61, 50, 125, 32, 45, 122, 32, 48, 44,
  48, 44, 123, 49, 48, 48, 45, 36, 55, 125, 37, 44, 123, 49, 48, 48,
  45, 36, 55, 125, 37, 10, 45, 101, 108, 105, 102, 32, 123, 36, 52, 61,
  61, 51, 125, 32, 45, 122, 32, 123, 36, 55, 47, 50, 125, 37, 44, 123,
  36, 55, 47, 50, 125, 37, 44, 123, 49, 48, 48, 45, 36, 55, 47, 50,
  125, 37, 44, 123, 49, 48, 48, 45, 36, 55, 47, 50, 125, 37, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 115, 104,
  105, 102, 116, 32, 45, 36, 50, 37, 44, 45, 36, 51, 37, 44, 48, 44,
  48, 44, 50, 10, 45, 97, 114, 114, 97, 121, 95, 109, 105, 114, 114, 111,
  114, 32, 36, 49, 44, 36, 52, 44, 36, 54, 10, 103, 105, 109, 112, 95,
  97, 114, 114, 97, 121, 95, 109, 105, 114, 114, 111, 114, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 97, 114, 114,
  97, 121, 95, 109, 105, 114, 114, 111, 114, 32, 36, 49, 44, 36, 50, 44,
  36, 51, 44, 36, 52, 44, 36, 53, 44, 48, 44, 36, 55, 10, 103, 105,
  109, 112, 95, 97, 114, 114, 97, 121, 95, 99, 111, 108, 111, 114, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 45,
  49, 93, 10, 36, 49, 44, 36, 50, 44, 49, 44, 51, 32, 45, 114, 97,
  110, 100, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 116, 111,
  95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 91, 45, 49, 93, 32, 64,
  123, 45, 50, 44, 115, 125, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 32, 45, 42, 91, 45, 49, 93, 32, 36, 51, 32, 45, 42, 91,
  45, 50, 93, 32, 123, 49, 45, 36, 51, 125, 32, 45, 43, 91, 45, 50,
  44, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 109, 118, 91, 45,
  49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95,
  97, 114, 114, 97, 121, 32, 58, 10, 45, 115, 104, 105, 102, 116, 32, 45,
  36, 51, 37, 44, 45, 36, 52, 37, 44, 48, 44, 48, 44, 50, 10, 45,
  105, 102, 32, 123, 36, 53, 38, 49, 125, 32, 45, 109, 105, 114, 114, 111,
  114, 32, 120, 32, 45, 101, 110, 100, 105, 102, 32, 45, 105, 102, 32, 123,
  36, 53, 62, 49, 125, 32, 45, 109, 105, 114, 114, 111, 114, 32, 121, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 97, 114, 114, 97, 121, 32, 36, 49,
  44, 36, 50, 44, 36, 54, 10, 103, 105, 109, 112, 95, 97, 114, 114, 97,
  121, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 97, 114, 114, 97, 121, 32, 36, 49, 44, 36, 50, 44, 36, 51,
  44, 36, 52, 44, 36, 53, 44, 48, 10, 103, 105, 109, 112, 95, 99, 104,
  101, 115, 115, 98, 111, 97, 114, 100, 32, 58, 10, 45, 116, 111, 95, 114,
  103, 98, 97, 32, 45, 99, 104, 101, 115, 115, 98, 111, 97, 114, 100, 32,
  36, 123, 49, 45, 49, 52, 125, 10, 103, 105, 109, 112, 95, 99, 104, 101,
  115, 115, 98, 111, 97, 114, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 99, 104, 101,
  115, 115, 98, 111, 97, 114, 100, 32, 36, 42, 34, 44, 36, 45, 49, 10,
  103, 105, 109, 112, 95, 100, 105, 99, 101, 115, 32, 58, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 54, 32, 123, 50, 42, 36, 50, 125, 44, 123, 50,
  42, 36, 50, 125, 32, 45, 95, 100, 105, 99, 101, 36, 62, 32, 45, 100,
  111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 51, 37, 50, 125, 32, 45,
  110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 54, 45, 45, 49, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 102, 114, 97, 109, 101, 95, 114, 111,
  117, 110, 100, 91, 45, 54, 45, 45, 49, 93, 32, 49, 48, 44, 49, 48,
  44, 48, 44, 48, 44, 49, 50, 56, 44, 49, 50, 56, 44, 49, 50, 56,
  44, 48, 10, 45, 114, 50, 100, 121, 91, 45, 54, 45, 45, 49, 93, 32,
  36, 50, 32, 45, 97, 91, 45, 54, 45, 45, 49, 93, 32, 120, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 45, 108,
  91, 36, 62, 44, 45, 49, 93, 10, 45, 45, 108, 117, 109, 105, 110, 97,
  110, 99, 101, 91, 48, 93, 32, 45, 114, 118, 91, 49, 44, 50, 93, 32,
  45, 114, 91, 48, 44, 49, 93, 32, 123, 49, 48, 48, 42, 36, 49, 47,
  36, 50, 125, 37, 44, 123, 49, 48, 48, 42, 36, 49, 47, 36, 50, 125,
  37, 44, 49, 44, 49, 48, 48, 37, 44, 50, 32, 45, 113, 117, 97, 110,
  116, 105, 122, 101, 91, 49, 93, 32, 54, 44, 48, 10, 45, 42, 91, 45,
  50, 93, 32, 36, 50, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91,
  45, 50, 93, 32, 48, 44, 49, 32, 45, 114, 91, 45, 50, 93, 32, 123,
  36, 50, 42, 49, 48, 48, 125, 37, 44, 123, 36, 50, 42, 49, 48, 48,
  125, 37, 10, 36, 50, 44, 36, 50, 44, 49, 44, 50, 44, 39, 105, 102,
  40, 99, 44, 121, 44, 120, 41, 39, 32, 45, 114, 91, 45, 49, 93, 32,
  91, 45, 51, 93, 44, 91, 45, 51, 93, 44, 49, 44, 50, 44, 48, 44,
  50, 32, 45, 43, 91, 45, 51, 44, 45, 49, 93, 32, 45, 45, 119, 97,
  114, 112, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 32,
  45, 114, 109, 91, 45, 51, 93, 10, 45, 105, 102, 32, 123, 36, 51, 60,
  50, 125, 32, 45, 114, 109, 91, 48, 93, 32, 45, 109, 118, 91, 45, 49,
  93, 32, 48, 10, 45, 101, 108, 115, 101, 32, 45, 114, 91, 48, 93, 32,
  91, 50, 93, 44, 91, 50, 93, 44, 49, 44, 49, 48, 48, 37, 32, 45,
  114, 118, 91, 48, 44, 45, 49, 93, 32, 45, 98, 108, 101, 110, 100, 91,
  48, 44, 45, 49, 93, 32, 109, 117, 108, 116, 105, 112, 108, 121, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 114, 109, 91, 45, 49, 93, 10, 95, 100, 105, 99, 101, 48,
  32, 58, 32, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32,
  53, 48, 37, 44, 53, 48, 37, 44, 53, 46, 50, 37, 44, 53, 46, 50,
  37, 44, 48, 44, 49, 44, 50, 53, 53, 10, 95, 100, 105, 99, 101, 49,
  32, 58, 32, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32,
  50, 53, 37, 44, 50, 53, 37, 44, 53, 46, 50, 37, 44, 53, 46, 50,
  37, 44, 48, 44, 49, 44, 50, 53, 53, 32, 45, 101, 108, 108, 105, 112,
  115, 101, 91, 45, 49, 93, 32, 55, 53, 37, 44, 55, 53, 37, 44, 53,
  46, 50, 37, 44, 53, 46, 50, 37, 44, 48, 44, 49, 44, 50, 53, 53,
  10, 95, 100, 105, 99, 101, 50, 32, 58, 32, 45, 95, 100, 105, 99, 101,
  49, 32, 45, 95, 100, 105, 99, 101, 48, 10, 95, 100, 105, 99, 101, 51,
  32, 58, 32, 45, 95, 100, 105, 99, 101, 49, 32, 45, 101, 108, 108, 105,
  112, 115, 101, 91, 45, 49, 93, 32, 50, 53, 37, 44, 55, 53, 37, 44,
  53, 46, 50, 37, 44, 53, 46, 50, 37, 44, 48, 44, 49, 44, 50, 53,
  53, 32, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 55,
  53, 37, 44, 50, 53, 37, 44, 53, 46, 50, 37, 44, 53, 46, 50, 37,
  44, 48, 44, 49, 44, 50, 53, 53, 10, 95, 100, 105, 99, 101, 52, 32,
  58, 32, 45, 95, 100, 105, 99, 101, 51, 32, 45, 95, 100, 105, 99, 101,
  48, 10, 95, 100, 105, 99, 101, 53, 32, 58, 32, 45, 95, 100, 105, 99,
  101, 51, 32, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32,
  50, 53, 37, 44, 53, 48, 37, 44, 53, 46, 50, 37, 44, 53, 46, 50,
  37, 44, 48, 44, 49, 44, 50, 53, 53, 32, 45, 101, 108, 108, 105, 112,
  115, 101, 91, 45, 49, 93, 32, 55, 53, 37, 44, 53, 48, 37, 44, 53,
  46, 50, 37, 44, 53, 46, 50, 37, 44, 48, 44, 49, 44, 50, 53, 53,
  10, 103, 105, 109, 112, 95, 101, 120, 116, 114, 97, 99, 116, 95, 111, 98,
  106, 101, 99, 116, 115, 32, 58, 10, 45, 105, 102, 32, 36, 53, 32, 109,
  105, 110, 95, 97, 114, 101, 97, 61, 36, 53, 37, 32, 45, 101, 108, 115,
  101, 32, 109, 105, 110, 95, 97, 114, 101, 97, 61, 53, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 60, 93, 32, 45, 116, 111, 95, 114, 103, 98, 97, 10, 119,
  61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 10, 120, 61, 123, 36, 49,
  37, 42, 40, 119, 45, 49, 41, 125, 10, 121, 61, 123, 36, 50, 37, 42,
  40, 104, 45, 49, 41, 125, 10, 99, 111, 108, 111, 114, 61, 64, 123, 45,
  97, 116, 92, 32, 36, 120, 44, 36, 121, 125, 10, 45, 105, 102, 32, 123,
  36, 55, 61, 61, 48, 125, 10, 45, 45, 114, 101, 112, 108, 97, 99, 101,
  95, 99, 111, 108, 111, 114, 32, 36, 51, 44, 48, 44, 36, 99, 111, 108,
  111, 114, 44, 48, 44, 48, 44, 48, 44, 48, 32, 45, 97, 117, 116, 111,
  99, 114, 111, 112, 95, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 91,
  45, 49, 93, 32, 36, 52, 37, 44, 36, 109, 105, 110, 95, 97, 114, 101,
  97, 44, 36, 54, 44, 50, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  119, 125, 32, 45, 45, 122, 91, 48, 93, 32, 64, 123, 49, 44, 105, 40,
  36, 62, 44, 48, 41, 125, 44, 64, 123, 49, 44, 105, 40, 36, 62, 44,
  49, 41, 125, 44, 64, 123, 49, 44, 105, 40, 36, 62, 44, 51, 41, 125,
  44, 64, 123, 49, 44, 105, 40, 36, 62, 44, 52, 41, 125, 32, 45, 100,
  111, 110, 101, 32, 45, 114, 109, 91, 48, 44, 49, 93, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 55, 61, 61, 49, 125, 10, 45, 114, 101, 112, 108,
  97, 99, 101, 95, 99, 111, 108, 111, 114, 32, 36, 51, 44, 48, 44, 36,
  99, 111, 108, 111, 114, 44, 48, 44, 48, 44, 48, 44, 48, 32, 45, 97,
  117, 116, 111, 99, 114, 111, 112, 95, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 115, 32, 36, 52, 37, 44, 36, 109, 105, 110, 95, 97, 114, 101, 97,
  44, 36, 54, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 55, 61,
  61, 50, 125, 10, 45, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111,
  108, 111, 114, 32, 36, 51, 44, 48, 44, 36, 99, 111, 108, 111, 114, 44,
  48, 44, 48, 44, 48, 44, 48, 32, 45, 97, 117, 116, 111, 99, 114, 111,
  112, 95, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 91, 45, 49, 93,
  32, 36, 52, 37, 44, 36, 109, 105, 110, 95, 97, 114, 101, 97, 44, 36,
  54, 44, 50, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 119, 125, 32,
  91, 48, 93, 44, 91, 48, 93, 44, 49, 44, 52, 32, 45, 45, 122, 91,
  48, 93, 32, 64, 123, 49, 44, 105, 40, 36, 62, 44, 48, 41, 125, 44,
  64, 123, 49, 44, 105, 40, 36, 62, 44, 49, 41, 125, 44, 64, 123, 49,
  44, 105, 40, 36, 62, 44, 51, 41, 125, 44, 64, 123, 49, 44, 105, 40,
  36, 62, 44, 52, 41, 125, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 44, 64, 123, 49, 44, 105, 40, 36, 62, 44, 48, 41, 125, 44,
  64, 123, 49, 44, 105, 40, 36, 62, 44, 49, 41, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48,
  44, 49, 93, 10, 36, 119, 44, 36, 104, 44, 49, 44, 52, 32, 45, 102,
  99, 91, 45, 49, 93, 32, 36, 99, 111, 108, 111, 114, 10, 45, 101, 108,
  115, 101, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111,
  114, 32, 36, 51, 44, 48, 44, 36, 99, 111, 108, 111, 114, 44, 48, 44,
  48, 44, 48, 44, 48, 32, 45, 45, 97, 117, 116, 111, 99, 114, 111, 112,
  95, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 32, 36, 52, 37, 44,
  36, 109, 105, 110, 95, 97, 114, 101, 97, 44, 36, 54, 44, 50, 32, 45,
  97, 117, 116, 111, 99, 114, 111, 112, 95, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 115, 91, 48, 93, 32, 36, 52, 37, 44, 36, 109, 105, 110, 95,
  97, 114, 101, 97, 44, 36, 54, 44, 49, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 119, 125, 32, 120, 61, 123, 105, 40, 36, 62, 44, 48, 41,
  125, 32, 121, 61, 123, 105, 40, 36, 62, 44, 49, 41, 125, 32, 45, 108,
  91, 36, 62, 93, 32, 45, 105, 91, 48, 93, 32, 36, 119, 44, 36, 104,
  44, 49, 44, 52, 32, 45, 106, 91, 48, 93, 32, 91, 49, 93, 44, 36,
  120, 44, 36, 121, 32, 45, 114, 109, 91, 49, 93, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  36, 119, 44, 36, 104, 44, 49, 44, 52, 32, 45, 102, 99, 91, 45, 49,
  93, 32, 36, 99, 111, 108, 111, 114, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112,
  95, 101, 120, 116, 114, 97, 99, 116, 95, 111, 98, 106, 101, 99, 116, 115,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 105, 102, 32, 36,
  53, 32, 109, 105, 110, 95, 97, 114, 101, 97, 61, 36, 53, 37, 32, 45,
  101, 108, 115, 101, 32, 109, 105, 110, 95, 97, 114, 101, 97, 61, 53, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 116, 111, 95, 114, 103, 98,
  97, 10, 120, 61, 123, 36, 49, 37, 42, 40, 119, 45, 49, 41, 125, 10,
  121, 61, 123, 36, 50, 37, 42, 40, 104, 45, 49, 41, 125, 10, 99, 111,
  108, 111, 114, 61, 64, 123, 45, 97, 116, 92, 32, 36, 120, 44, 36, 121,
  125, 10, 45, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111,
  114, 32, 36, 51, 44, 48, 44, 36, 99, 111, 108, 111, 114, 44, 48, 44,
  48, 44, 48, 44, 48, 10, 45, 97, 117, 116, 111, 99, 114, 111, 112, 95,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 91, 45, 49, 93, 32, 36,
  52, 37, 44, 36, 109, 105, 110, 95, 97, 114, 101, 97, 44, 36, 54, 44,
  50, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 119, 125, 10, 120, 121,
  99, 111, 111, 114, 100, 115, 61, 64, 123, 49, 44, 105, 40, 36, 62, 44,
  48, 41, 125, 44, 64, 123, 49, 44, 105, 40, 36, 62, 44, 49, 41, 125,
  44, 64, 123, 49, 44, 105, 40, 36, 62, 44, 51, 41, 125, 44, 64, 123,
  49, 44, 105, 40, 36, 62, 44, 52, 41, 125, 10, 45, 114, 101, 99, 116,
  97, 110, 103, 108, 101, 91, 48, 93, 32, 36, 120, 121, 99, 111, 111, 114,
  100, 115, 44, 48, 46, 51, 44, 48, 44, 48, 44, 50, 53, 53, 44, 50,
  53, 53, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 48, 93,
  32, 36, 120, 121, 99, 111, 111, 114, 100, 115, 44, 49, 44, 48, 120, 70,
  70, 70, 70, 70, 70, 70, 70, 44, 48, 44, 48, 44, 48, 44, 50, 53,
  53, 10, 45, 100, 111, 110, 101, 10, 45, 100, 114, 103, 98, 97, 91, 48,
  93, 10, 45, 116, 101, 120, 116, 95, 111, 117, 116, 108, 105, 110, 101, 91,
  48, 93, 32, 123, 119, 125, 34, 32, 111, 98, 106, 101, 99, 116, 115, 34,
  44, 50, 44, 50, 44, 49, 51, 44, 50, 44, 48, 46, 51, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 107,
  91, 48, 93, 10, 45, 99, 105, 114, 99, 108, 101, 32, 36, 120, 44, 36,
  121, 44, 51, 44, 49, 44, 48, 44, 50, 53, 53, 44, 48, 10, 45, 99,
  105, 114, 99, 108, 101, 32, 36, 120, 44, 36, 121, 44, 51, 44, 49, 44,
  48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 105, 109,
  97, 103, 101, 103, 114, 105, 100, 32, 58, 10, 45, 105, 109, 97, 103, 101,
  103, 114, 105, 100, 32, 36, 49, 44, 36, 50, 10, 103, 105, 109, 112, 95,
  112, 117, 122, 122, 108, 101, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 60, 93, 10, 119, 61, 123, 119, 125,
  32, 104, 61, 123, 104, 125, 32, 45, 116, 111, 95, 114, 103, 98, 10, 45,
  112, 117, 122, 122, 108, 101, 32, 36, 119, 44, 36, 104, 44, 36, 49, 44,
  36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 10, 45, 45, 98, 91,
  45, 49, 93, 32, 36, 54, 37, 44, 48, 32, 45, 103, 114, 97, 100, 105,
  101, 110, 116, 91, 45, 49, 93, 32, 120, 121, 32, 45, 43, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 45, 36, 55, 44,
  36, 55, 32, 45, 43, 91, 48, 44, 45, 49, 93, 10, 45, 45, 98, 91,
  45, 49, 93, 32, 36, 56, 37, 44, 48, 32, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 49, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45,
  43, 91, 45, 49, 93, 32, 49, 32, 45, 110, 91, 45, 49, 93, 32, 123,
  40, 50, 53, 53, 45, 36, 57, 41, 47, 50, 53, 53, 125, 44, 49, 32,
  45, 42, 91, 48, 44, 45, 49, 93, 32, 45, 99, 32, 48, 44, 50, 53,
  53, 10, 45, 105, 102, 32, 123, 36, 49, 48, 33, 61, 49, 48, 48, 124,
  124, 36, 49, 49, 124, 124, 36, 49, 50, 124, 124, 36, 49, 51, 124, 124,
  36, 49, 52, 124, 124, 36, 49, 53, 124, 124, 36, 49, 54, 125, 10, 45,
  45, 45, 91, 45, 49, 93, 32, 49, 32, 45, 108, 97, 98, 101, 108, 95,
  102, 103, 91, 45, 49, 93, 32, 48, 10, 45, 45, 97, 114, 101, 97, 95,
  102, 103, 91, 45, 49, 93, 32, 48, 44, 48, 32, 45, 108, 116, 91, 45,
  49, 93, 32, 53, 48, 37, 32, 45, 111, 114, 91, 45, 51, 93, 32, 91,
  45, 49, 93, 32, 45, 101, 113, 91, 45, 49, 93, 32, 48, 32, 45, 42,
  91, 45, 50, 44, 45, 49, 93, 10, 45, 100, 105, 115, 116, 97, 110, 99,
  101, 91, 45, 50, 93, 32, 48, 32, 45, 42, 91, 45, 50, 93, 32, 45,
  49, 32, 45, 119, 97, 116, 101, 114, 115, 104, 101, 100, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45, 108,
  97, 98, 101, 108, 91, 45, 49, 93, 32, 48, 44, 48, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 105, 77, 43, 49, 125, 10, 45, 45, 61, 61,
  91, 49, 93, 32, 36, 62, 10, 99, 111, 111, 114, 100, 115, 61, 64, 123,
  45, 97, 117, 116, 111, 99, 114, 111, 112, 95, 99, 111, 111, 114, 100, 115,
  91, 45, 49, 93, 92, 32, 48, 125, 10, 45, 45, 122, 91, 48, 93, 32,
  36, 99, 111, 111, 114, 100, 115, 32, 45, 122, 91, 45, 50, 93, 32, 36,
  99, 111, 111, 114, 100, 115, 32, 45, 114, 118, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 42,
  91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 97, 91, 45, 50, 44, 45,
  49, 93, 32, 99, 10, 120, 36, 62, 61, 123, 97, 114, 103, 40, 49, 44,
  36, 99, 111, 111, 114, 100, 115, 41, 43, 114, 111, 117, 110, 100, 40, 119,
  47, 50, 41, 125, 32, 121, 36, 62, 61, 123, 97, 114, 103, 40, 50, 44,
  36, 99, 111, 111, 114, 100, 115, 41, 43, 114, 111, 117, 110, 100, 40, 104,
  47, 50, 41, 125, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 48,
  44, 49, 93, 10, 45, 105, 102, 32, 36, 49, 52, 32, 45, 115, 111, 114,
  116, 95, 108, 105, 115, 116, 32, 43, 44, 63, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 36, 49, 54, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 60, 93, 10, 45, 114, 50, 100,
  121, 32, 123, 109, 97, 120, 40, 48, 46, 49, 44, 36, 49, 48, 43, 36,
  49, 49, 42, 63, 40, 45, 49, 44, 49, 41, 41, 125, 37, 32, 45, 114,
  111, 116, 97, 116, 101, 32, 123, 36, 49, 50, 43, 36, 49, 51, 42, 63,
  40, 45, 49, 44, 49, 41, 125, 10, 45, 105, 102, 32, 36, 49, 53, 32,
  45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 32, 49, 44, 48, 32, 45,
  101, 110, 100, 105, 102, 10, 99, 120, 61, 123, 114, 111, 117, 110, 100, 40,
  119, 47, 50, 41, 125, 32, 99, 121, 61, 123, 114, 111, 117, 110, 100, 40,
  104, 47, 50, 41, 125, 10, 45, 115, 104, 32, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 32, 45, 105, 102, 32, 36, 49, 53, 32, 45, 100, 105, 108,
  97, 116, 101, 91, 45, 49, 93, 32, 51, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 91, 48, 93, 32, 36, 119, 44, 36, 104, 44, 49, 44, 52,
  10, 45, 106, 91, 48, 93, 32, 91, 45, 50, 93, 44, 123, 36, 123, 120,
  36, 60, 125, 45, 36, 99, 120, 125, 44, 123, 36, 123, 121, 36, 60, 125,
  45, 36, 99, 121, 125, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93,
  44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 115,
  101, 10, 45, 105, 91, 48, 93, 32, 36, 119, 44, 36, 104, 44, 49, 44,
  123, 115, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45,
  49, 125, 10, 45, 114, 50, 100, 121, 91, 45, 49, 93, 32, 123, 109, 97,
  120, 40, 48, 46, 49, 44, 36, 49, 48, 43, 36, 49, 49, 42, 63, 40,
  45, 49, 44, 49, 41, 41, 125, 37, 32, 45, 114, 111, 116, 97, 116, 101,
  91, 45, 49, 93, 32, 123, 36, 49, 50, 43, 36, 49, 51, 42, 63, 40,
  45, 49, 44, 49, 41, 125, 10, 45, 105, 102, 32, 36, 49, 53, 32, 45,
  101, 120, 112, 97, 110, 100, 95, 120, 121, 91, 45, 49, 93, 32, 49, 44,
  48, 32, 45, 101, 110, 100, 105, 102, 10, 99, 120, 61, 123, 114, 111, 117,
  110, 100, 40, 119, 47, 50, 41, 125, 32, 99, 121, 61, 123, 114, 111, 117,
  110, 100, 40, 104, 47, 50, 41, 125, 10, 45, 115, 104, 91, 45, 49, 93,
  32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 105, 102, 32, 36,
  49, 53, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 106, 91, 48, 93, 32, 91, 45,
  50, 93, 44, 123, 36, 123, 120, 36, 60, 125, 45, 36, 99, 120, 125, 44,
  123, 36, 123, 121, 36, 60, 125, 45, 36, 99, 121, 125, 44, 48, 44, 48,
  44, 49, 44, 91, 45, 49, 93, 44, 50, 53, 53, 32, 45, 114, 109, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 100, 111, 110, 101, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 108, 115, 101, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 112, 117, 122, 122, 108, 101,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 112, 117, 122, 122, 108, 101, 32, 36, 123, 49, 45, 49, 53, 125, 44,
  48, 10, 103, 105, 109, 112, 95, 116, 97, 113, 117, 105, 110, 32, 58, 10,
  45, 116, 111, 95, 97, 32, 45, 116, 97, 113, 117, 105, 110, 32, 36, 49,
  44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 37, 44, 36, 54,
  44, 36, 123, 55, 45, 49, 48, 125, 10, 103, 105, 109, 112, 95, 114, 111,
  116, 97, 116, 101, 95, 116, 105, 108, 101, 97, 98, 108, 101, 32, 58, 10,
  45, 105, 102, 32, 36, 51, 32, 45, 97, 114, 114, 97, 121, 95, 109, 105,
  114, 114, 111, 114, 32, 49, 44, 123, 36, 51, 45, 49, 125, 44, 49, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 114, 111, 116, 97, 116, 101, 95, 116,
  105, 108, 101, 97, 98, 108, 101, 32, 36, 49, 44, 123, 105, 102, 40, 36,
  51, 61, 61, 48, 44, 36, 50, 44, 36, 50, 47, 50, 41, 125, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 105, 102, 32, 123, 64,
  123, 36, 62, 44, 119, 125, 61, 61, 49, 34, 32, 38, 38, 32, 34, 64,
  123, 36, 62, 44, 104, 125, 61, 61, 49, 125, 32, 45, 114, 109, 32, 45,
  95, 103, 105, 109, 112, 95, 110, 111, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 32, 32, 73, 110, 118, 97, 108, 105, 100, 92, 110, 105, 109, 97,
  103, 101, 32, 115, 105, 122, 101, 34, 32, 45, 114, 101, 116, 117, 114, 110,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 103, 105,
  109, 112, 95, 114, 111, 116, 97, 116, 101, 95, 116, 105, 108, 101, 115, 32,
  58, 10, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 114, 111, 116, 97,
  116, 101, 95, 116, 105, 108, 101, 115, 32, 36, 51, 44, 36, 49, 44, 36,
  50, 32, 45, 100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119, 32, 36,
  52, 37, 44, 36, 53, 37, 44, 36, 54, 37, 10, 95, 103, 105, 109, 112,
  95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 116, 105, 108, 101, 115,
  32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 45, 49, 93, 32, 45, 115, 112, 108, 105, 116, 95, 116, 105, 108, 101,
  115, 32, 36, 49, 44, 36, 50, 32, 45, 110, 32, 36, 51, 44, 36, 52,
  32, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 32, 36,
  49, 44, 36, 50, 32, 45, 101, 110, 100, 108, 32, 45, 109, 118, 91, 45,
  49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95,
  110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 116, 105, 108, 101, 115, 32,
  58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 34, 45, 95, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97, 108,
  105, 122, 101, 95, 116, 105, 108, 101, 115, 32, 36, 123, 49, 45, 52, 125,
  34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 115, 104, 105, 102, 116,
  95, 116, 105, 108, 101, 115, 32, 58, 10, 45, 116, 111, 95, 114, 103, 98,
  97, 32, 45, 115, 104, 105, 102, 116, 95, 116, 105, 108, 101, 115, 32, 36,
  49, 44, 36, 50, 44, 36, 51, 10, 45, 105, 102, 32, 123, 36, 52, 60,
  49, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 115,
  91, 45, 49, 93, 32, 99, 32, 45, 42, 91, 45, 49, 93, 32, 36, 52,
  32, 45, 97, 91, 45, 52, 45, 45, 49, 93, 32, 99, 32, 45, 109, 118,
  91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110,
  100, 105, 102, 10, 103, 105, 109, 112, 95, 112, 97, 114, 97, 109, 101, 116,
  101, 114, 105, 122, 101, 95, 116, 105, 108, 101, 115, 32, 58, 10, 45, 105,
  102, 32, 36, 51, 10, 45, 113, 117, 97, 100, 114, 97, 116, 105, 122, 101,
  95, 116, 105, 108, 101, 115, 32, 36, 49, 44, 36, 50, 10, 45, 101, 108,
  115, 101, 10, 45, 108, 105, 110, 101, 97, 114, 105, 122, 101, 95, 116, 105,
  108, 101, 115, 32, 36, 49, 44, 36, 50, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 99, 32, 48, 44, 50, 53, 53, 10, 103, 105, 109, 112, 95, 105,
  115, 111, 108, 97, 116, 101, 95, 116, 105, 108, 101, 115, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 45, 116, 111, 95, 114, 103, 98, 97, 10, 45, 105, 102, 32, 36, 53,
  32, 115, 120, 61, 123, 114, 111, 117, 110, 100, 40, 109, 105, 110, 40, 119,
  44, 104, 41, 42, 109, 97, 120, 40, 36, 49, 44, 36, 50, 41, 47, 49,
  48, 48, 41, 125, 32, 115, 121, 61, 36, 115, 120, 32, 45, 101, 108, 115,
  101, 32, 115, 120, 61, 123, 114, 111, 117, 110, 100, 40, 119, 42, 36, 49,
  47, 49, 48, 48, 41, 125, 32, 115, 121, 61, 123, 114, 111, 117, 110, 100,
  40, 104, 42, 36, 50, 47, 49, 48, 48, 41, 125, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 36, 54, 32, 98, 120, 61, 123, 109, 97,
  120, 40, 36, 51, 44, 36, 52, 41, 125, 32, 98, 121, 61, 36, 98, 120,
  32, 45, 101, 108, 115, 101, 32, 98, 120, 61, 36, 51, 32, 98, 121, 61,
  36, 52, 32, 45, 101, 110, 100, 105, 102, 10, 45, 115, 32, 120, 44, 45,
  36, 115, 120, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 32, 45, 115, 32, 121, 44, 45, 36, 115, 121, 32,
  45, 114, 32, 49, 48, 48, 37, 44, 123, 49, 48, 48, 43, 36, 98, 121,
  125, 37, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 32, 45, 97, 32, 121, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 45, 114, 32, 123, 49, 48, 48, 43, 36,
  98, 120, 125, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 48, 48, 37,
  44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 97, 32,
  120, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105,
  109, 112, 95, 98, 111, 107, 101, 104, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 98, 111, 107, 101, 104, 32, 36,
  42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 99, 97, 114, 116,
  111, 111, 110, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 99, 97, 114, 116, 111, 111, 110, 32, 36, 42, 34, 44,
  36, 45, 49, 10, 103, 105, 109, 112, 95, 99, 117, 98, 105, 115, 109, 32,
  58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 32, 45, 99, 117,
  98, 105, 115, 109, 32, 36, 123, 50, 45, 45, 49, 125, 32, 45, 100, 111,
  110, 101, 10, 103, 105, 109, 112, 95, 99, 117, 98, 105, 115, 109, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115,
  112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103,
  105, 109, 112, 95, 99, 117, 98, 105, 115, 109, 32, 36, 42, 34, 44, 36,
  45, 49, 10, 103, 105, 109, 112, 95, 101, 108, 108, 105, 112, 115, 105, 111,
  110, 105, 115, 109, 32, 58, 10, 45, 101, 108, 108, 105, 112, 115, 105, 111,
  110, 105, 115, 109, 32, 36, 123, 94, 48, 125, 10, 103, 105, 109, 112, 95,
  101, 108, 108, 105, 112, 115, 105, 111, 110, 105, 115, 109, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109,
  112, 95, 101, 108, 108, 105, 112, 115, 105, 111, 110, 105, 115, 109, 32, 36,
  42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 102, 101, 108, 116,
  112, 101, 110, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 45, 45, 103, 105, 109, 112, 95, 104,
  97, 114, 100, 115, 107, 101, 116, 99, 104, 98, 119, 32, 36, 123, 49, 45,
  53, 125, 44, 48, 44, 48, 32, 45, 98, 108, 101, 110, 100, 32, 104, 97,
  114, 100, 108, 105, 103, 104, 116, 32, 45, 101, 114, 111, 100, 101, 95, 111,
  99, 116, 32, 36, 54, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 103, 105, 109, 112, 95, 102, 101, 108, 116, 112, 101, 110, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115,
  112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103,
  105, 109, 112, 95, 102, 101, 108, 116, 112, 101, 110, 32, 36, 42, 34, 44,
  36, 45, 49, 10, 103, 105, 109, 112, 95, 112, 111, 115, 116, 101, 114, 95,
  104, 111, 112, 101, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 103, 97,
  109, 109, 97, 32, 123, 49, 48, 94, 36, 49, 125, 32, 45, 112, 111, 115,
  116, 101, 114, 95, 104, 111, 112, 101, 32, 36, 50, 10, 103, 105, 109, 112,
  95, 112, 111, 115, 116, 101, 114, 95, 104, 111, 112, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109,
  112, 95, 112, 111, 115, 116, 101, 114, 95, 104, 111, 112, 101, 32, 36, 42,
  34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 107, 117, 119, 97, 104,
  97, 114, 97, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 34, 45, 114, 101, 112, 101, 97, 116, 32, 36,
  49, 32, 45, 107, 117, 119, 97, 104, 97, 114, 97, 32, 36, 50, 32, 45,
  100, 111, 110, 101, 34, 44, 36, 51, 44, 48, 10, 103, 105, 109, 112, 95,
  107, 117, 119, 97, 104, 97, 114, 97, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 107, 117,
  119, 97, 104, 97, 114, 97, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103,
  105, 109, 112, 95, 108, 121, 108, 101, 106, 107, 95, 112, 97, 105, 110, 116,
  105, 110, 103, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  10, 45, 45, 95, 103, 105, 109, 112, 95, 108, 121, 108, 101, 106, 107, 95,
  112, 97, 105, 110, 116, 105, 110, 103, 91, 45, 49, 93, 32, 49, 48, 44,
  49, 48, 46, 52, 57, 44, 48, 46, 55, 53, 44, 48, 10, 45, 115, 109,
  111, 111, 116, 104, 91, 45, 49, 93, 32, 51, 48, 48, 44, 48, 46, 50,
  54, 44, 49, 44, 48, 44, 55, 32, 45, 115, 104, 97, 114, 112, 101, 110,
  91, 45, 49, 93, 32, 36, 51, 10, 91, 45, 49, 93, 32, 45, 114, 118,
  91, 45, 51, 45, 45, 49, 93, 10, 45, 98, 108, 101, 110, 100, 91, 45,
  50, 44, 45, 49, 93, 32, 108, 105, 103, 104, 116, 101, 110, 44, 48, 46,
  53, 10, 45, 98, 108, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32,
  103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 44, 49, 10, 45, 103, 105,
  109, 112, 95, 107, 117, 119, 97, 104, 97, 114, 97, 91, 45, 49, 93, 32,
  36, 49, 44, 36, 50, 44, 48, 10, 45, 116, 101, 120, 116, 117, 114, 105,
  122, 101, 95, 99, 97, 110, 118, 97, 115, 91, 45, 49, 93, 32, 36, 51,
  44, 52, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111,
  110, 101, 10, 103, 105, 109, 112, 95, 108, 121, 108, 101, 106, 107, 95, 112,
  97, 105, 110, 116, 105, 110, 103, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 108, 121, 108,
  101, 106, 107, 95, 112, 97, 105, 110, 116, 105, 110, 103, 32, 36, 42, 34,
  44, 36, 45, 49, 10, 95, 103, 105, 109, 112, 95, 108, 121, 108, 101, 106,
  107, 95, 112, 97, 105, 110, 116, 105, 110, 103, 32, 58, 10, 45, 97, 112,
  112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 49, 32, 45, 98, 32, 36, 51, 32, 45,
  117, 110, 115, 104, 97, 114, 112, 32, 36, 51, 44, 36, 50, 32, 45, 99,
  32, 48, 44, 50, 53, 53, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48,
  32, 45, 100, 111, 110, 101, 34, 44, 36, 52, 44, 48, 10, 103, 105, 109,
  112, 95, 112, 97, 105, 110, 116, 105, 110, 103, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 52, 61, 48, 125, 44, 36, 123, 53, 61, 48, 125,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101,
  32, 123, 109, 97, 120, 40, 51, 44, 115, 41, 125, 32, 45, 115, 112, 108,
  105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 114, 118, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 36, 49, 32, 45, 103, 105, 109, 112, 95,
  110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 91,
  45, 49, 93, 32, 49, 48, 44, 54, 44, 53, 44, 50, 48, 44, 49, 44,
  51, 32, 45, 100, 111, 110, 101, 10, 45, 103, 105, 109, 112, 95, 97, 110,
  105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104,
  105, 110, 103, 91, 45, 49, 93, 32, 123, 49, 48, 48, 42, 36, 50, 125,
  44, 48, 46, 50, 44, 49, 44, 36, 50, 44, 123, 50, 42, 36, 50, 125,
  44, 48, 46, 56, 44, 57, 48, 44, 50, 44, 48, 44, 49, 44, 49, 44,
  50, 44, 49, 44, 49, 54, 10, 45, 103, 105, 109, 112, 95, 109, 105, 120,
  95, 108, 97, 98, 91, 45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 36,
  51, 44, 48, 44, 48, 46, 53, 44, 36, 51, 44, 48, 44, 48, 46, 53,
  44, 48, 44, 50, 44, 48, 10, 45, 105, 102, 32, 36, 53, 32, 45, 103,
  105, 109, 112, 95, 115, 101, 103, 109, 101, 110, 116, 95, 119, 97, 116, 101,
  114, 115, 104, 101, 100, 91, 45, 49, 93, 32, 49, 48, 44, 49, 44, 48,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 115, 109, 111, 111, 116, 104, 91,
  45, 49, 93, 32, 36, 52, 44, 48, 44, 49, 44, 49, 44, 49, 10, 45,
  114, 118, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 103, 105, 109, 112, 95, 112, 97, 105, 110, 116, 105, 110,
  103, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 112, 97, 105, 110, 116, 105, 110, 103, 32,
  36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 112, 101, 110,
  95, 100, 114, 97, 119, 105, 110, 103, 32, 58, 10, 45, 100, 114, 97, 119,
  105, 110, 103, 32, 36, 49, 10, 103, 105, 109, 112, 95, 112, 101, 110, 95,
  100, 114, 97, 119, 105, 110, 103, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 112, 101, 110,
  95, 100, 114, 97, 119, 105, 110, 103, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 103, 105, 109, 112, 95, 112, 111, 108, 121, 103, 111, 110, 105, 122, 101,
  32, 58, 10, 45, 112, 111, 108, 121, 103, 111, 110, 105, 122, 101, 32, 36,
  49, 44, 36, 50, 44, 123, 36, 51, 94, 50, 125, 44, 36, 52, 44, 36,
  53, 10, 45, 105, 102, 32, 36, 57, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 110, 111, 114,
  109, 32, 45, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32,
  120, 121, 44, 49, 32, 45, 110, 101, 113, 91, 45, 50, 44, 45, 49, 93,
  32, 48, 32, 45, 111, 114, 91, 45, 50, 44, 45, 49, 93, 32, 45, 114,
  91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 52, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111,
  114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 49, 44, 49, 44, 49, 44,
  49, 44, 36, 54, 44, 36, 55, 44, 36, 56, 44, 36, 57, 10, 45, 98,
  108, 101, 110, 100, 32, 97, 108, 112, 104, 97, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 10, 103, 105,
  109, 112, 95, 112, 111, 108, 121, 103, 111, 110, 105, 122, 101, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112,
  108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105,
  109, 112, 95, 112, 111, 108, 121, 103, 111, 110, 105, 122, 101, 32, 36, 42,
  34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 112, 111, 115, 116, 101,
  114, 95, 101, 100, 103, 101, 115, 32, 58, 10, 45, 105, 102, 32, 36, 49,
  32, 45, 98, 105, 108, 97, 116, 101, 114, 97, 108, 32, 49, 48, 44, 36,
  49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 112, 111, 115, 116, 101, 114,
  95, 101, 100, 103, 101, 115, 32, 36, 123, 50, 45, 55, 125, 10, 103, 105,
  109, 112, 95, 112, 111, 115, 116, 101, 114, 95, 101, 100, 103, 101, 115, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  103, 105, 109, 112, 95, 112, 111, 115, 116, 101, 114, 95, 101, 100, 103, 101,
  115, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 114,
  111, 100, 105, 108, 105, 117, 115, 32, 58, 10, 45, 97, 112, 112, 108, 121,
  95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 114, 111, 100, 105,
  108, 105, 117, 115, 32, 36, 123, 49, 45, 53, 44, 55, 125, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 54, 32, 45, 115, 109, 111, 111, 116, 104,
  32, 49, 48, 44, 48, 44, 49, 44, 49, 44, 49, 44, 48, 46, 56, 44,
  52, 53, 32, 45, 115, 104, 97, 114, 112, 101, 110, 32, 51, 48, 32, 45,
  100, 111, 110, 101, 32, 45, 99, 32, 48, 44, 50, 53, 53, 34, 44, 36,
  56, 44, 48, 10, 103, 105, 109, 112, 95, 114, 111, 100, 105, 108, 105, 117,
  115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 114, 111, 100, 105, 108, 105, 117, 115, 32,
  36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 115, 104, 97,
  112, 101, 105, 115, 109, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 116, 111, 95, 114, 103,
  98, 10, 45, 45, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114,
  109, 32, 45, 98, 91, 45, 49, 93, 32, 36, 49, 51, 37, 32, 45, 112,
  111, 119, 91, 45, 49, 93, 32, 36, 49, 50, 32, 45, 113, 117, 97, 110,
  116, 105, 122, 101, 91, 45, 49, 93, 32, 36, 54, 44, 48, 44, 48, 10,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 50, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 54, 10, 45, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 91, 50, 93, 32, 49, 48, 48, 37, 32, 45, 45, 103, 116,
  91, 49, 93, 32, 36, 62, 32, 45, 110, 101, 113, 91, 45, 50, 93, 32,
  48, 32, 45, 111, 114, 91, 45, 50, 44, 45, 49, 93, 32, 45, 97, 91,
  50, 44, 45, 49, 93, 32, 99, 10, 115, 105, 122, 101, 61, 123, 105, 102,
  40, 36, 54, 60, 61, 49, 44, 36, 55, 44, 36, 55, 43, 40, 36, 56,
  45, 36, 55, 41, 42, 36, 62, 47, 40, 36, 54, 45, 49, 41, 41, 125,
  10, 45, 105, 102, 32, 123, 36, 115, 105, 122, 101, 60, 49, 125, 32, 45,
  98, 114, 101, 97, 107, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 36, 53, 32, 123, 50, 42, 36, 115, 105, 122, 101, 125, 44, 123, 50,
  42, 36, 115, 105, 122, 101, 125, 32, 45, 95, 103, 105, 109, 112, 95, 115,
  104, 97, 112, 101, 105, 115, 109, 36, 49, 91, 45, 49, 93, 32, 36, 123,
  50, 45, 52, 125, 32, 45, 114, 50, 100, 121, 91, 45, 49, 93, 32, 36,
  115, 105, 122, 101, 10, 45, 101, 108, 115, 101, 32, 36, 115, 105, 122, 101,
  44, 36, 115, 105, 122, 101, 32, 45, 95, 103, 105, 109, 112, 95, 115, 104,
  97, 112, 101, 105, 115, 109, 36, 49, 91, 45, 49, 93, 32, 36, 123, 50,
  45, 52, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 45, 110, 101, 113,
  91, 45, 49, 93, 32, 48, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120,
  121, 91, 45, 50, 44, 45, 49, 93, 32, 49, 44, 48, 32, 45, 110, 91,
  45, 50, 44, 45, 49, 93, 32, 48, 44, 49, 10, 45, 105, 102, 32, 123,
  36, 49, 48, 60, 49, 125, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45,
  49, 93, 32, 51, 32, 45, 101, 110, 100, 105, 102, 10, 91, 45, 49, 93,
  32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 99, 10, 45, 114, 112,
  114, 111, 103, 114, 101, 115, 115, 32, 34, 45, 112, 97, 99, 107, 95, 115,
  112, 114, 105, 116, 101, 115, 91, 45, 50, 44, 45, 49, 93, 32, 49, 44,
  49, 48, 48, 44, 36, 57, 44, 36, 49, 48, 44, 36, 49, 49, 34, 44,
  123, 36, 62, 42, 49, 48, 48, 47, 36, 54, 125, 44, 123, 40, 36, 62,
  43, 49, 41, 42, 49, 48, 48, 47, 36, 54, 125, 10, 45, 99, 104, 97,
  110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 44, 49, 10, 45, 100,
  111, 110, 101, 10, 45, 114, 112, 114, 111, 103, 114, 101, 115, 115, 32, 57,
  55, 10, 45, 114, 109, 91, 49, 93, 10, 45, 99, 104, 97, 110, 110, 101,
  108, 115, 91, 45, 49, 93, 32, 48, 32, 45, 45, 110, 101, 113, 91, 45,
  49, 93, 32, 48, 32, 45, 98, 108, 101, 110, 100, 91, 48, 44, 45, 49,
  93, 32, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97, 103, 101, 48, 32,
  45, 42, 91, 49, 93, 32, 50, 53, 53, 32, 45, 97, 32, 99, 10, 45,
  105, 91, 48, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 52, 32, 45, 102, 99, 91, 48, 93, 32, 36, 49, 52, 44, 36, 49,
  53, 44, 36, 49, 54, 44, 36, 49, 55, 10, 45, 98, 108, 101, 110, 100,
  32, 97, 108, 112, 104, 97, 10, 45, 114, 112, 114, 111, 103, 114, 101, 115,
  115, 32, 49, 48, 48, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 105, 115, 109, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 105, 102, 32, 64, 35,
  62, 61, 49, 32, 45, 107, 91, 48, 93, 32, 45, 101, 108, 115, 101, 32,
  50, 53, 54, 44, 50, 53, 54, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  95, 103, 105, 109, 112, 95, 110, 111, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 32, 34, 44, 34, 36, 42, 34, 10, 53, 48, 37, 44, 53, 48,
  37, 32, 45, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 105, 115,
  109, 36, 49, 91, 45, 49, 93, 32, 36, 123, 50, 45, 52, 125, 32, 45,
  102, 114, 97, 109, 101, 91, 45, 49, 93, 32, 49, 44, 49, 44, 48, 32,
  45, 103, 101, 91, 45, 49, 93, 32, 53, 48, 37, 32, 45, 110, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 114, 91, 45, 49, 93, 32,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 52, 10, 45, 114,
  91, 45, 49, 93, 32, 91, 48, 93, 44, 48, 44, 48, 44, 48, 46, 53,
  44, 48, 46, 53, 32, 45, 111, 114, 10, 95, 103, 105, 109, 112, 95, 115,
  104, 97, 112, 101, 105, 115, 109, 48, 32, 58, 10, 45, 102, 32, 50, 53,
  53, 32, 45, 115, 107, 105, 112, 32, 36, 42, 10, 95, 103, 105, 109, 112,
  95, 115, 104, 97, 112, 101, 105, 115, 109, 49, 32, 58, 10, 45, 112, 111,
  108, 121, 103, 111, 110, 32, 51, 44, 53, 48, 37, 44, 48, 44, 48, 44,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 49, 32, 45, 115, 107, 105, 112, 32, 36, 42, 10, 95, 103, 105, 109,
  112, 95, 115, 104, 97, 112, 101, 105, 115, 109, 50, 32, 58, 10, 45, 95,
  100, 116, 95, 99, 105, 114, 99, 108, 101, 32, 123, 119, 125, 32, 45, 114,
  109, 91, 45, 50, 93, 32, 45, 115, 107, 105, 112, 32, 36, 42, 10, 95,
  103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 105, 115, 109, 51, 32, 58,
  10, 45, 95, 100, 116, 95, 100, 105, 97, 109, 111, 110, 100, 32, 123, 119,
  125, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45, 115, 107, 105, 112, 32,
  36, 42, 10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 105, 115,
  109, 52, 32, 58, 10, 45, 115, 116, 97, 114, 51, 100, 32, 51, 44, 49,
  32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 64, 123, 48, 44, 109, 105,
  110, 40, 119, 44, 104, 41, 47, 50, 125, 32, 45, 111, 98, 106, 101, 99,
  116, 51, 100, 91, 48, 93, 32, 91, 45, 49, 93, 44, 53, 48, 37, 44,
  53, 48, 37, 44, 48, 44, 49, 44, 50, 44, 48, 32, 45, 107, 91, 48,
  93, 32, 45, 115, 107, 105, 112, 32, 36, 42, 10, 95, 103, 105, 109, 112,
  95, 115, 104, 97, 112, 101, 105, 115, 109, 53, 32, 58, 10, 45, 115, 116,
  97, 114, 51, 100, 32, 52, 44, 49, 32, 45, 42, 51, 100, 91, 45, 49,
  93, 32, 64, 123, 48, 44, 109, 105, 110, 40, 119, 44, 104, 41, 47, 50,
  125, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 48, 93, 32, 91,
  45, 49, 93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 49, 44,
  50, 44, 48, 32, 45, 107, 91, 48, 93, 32, 45, 115, 107, 105, 112, 32,
  36, 42, 10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 105, 115,
  109, 54, 32, 58, 10, 45, 115, 116, 97, 114, 51, 100, 32, 53, 32, 45,
  42, 51, 100, 91, 45, 49, 93, 32, 64, 123, 48, 44, 109, 105, 110, 40,
  119, 44, 104, 41, 47, 50, 125, 32, 45, 111, 98, 106, 101, 99, 116, 51,
  100, 91, 48, 93, 32, 91, 45, 49, 93, 44, 53, 48, 37, 44, 53, 48,
  37, 44, 48, 44, 49, 44, 50, 44, 48, 32, 45, 107, 91, 48, 93, 32,
  45, 115, 107, 105, 112, 32, 36, 42, 10, 95, 103, 105, 109, 112, 95, 115,
  104, 97, 112, 101, 105, 115, 109, 55, 32, 58, 10, 45, 115, 116, 97, 114,
  51, 100, 32, 36, 49, 44, 36, 50, 32, 45, 42, 51, 100, 91, 45, 49,
  93, 32, 64, 123, 48, 44, 109, 105, 110, 40, 119, 44, 104, 41, 47, 50,
  125, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 48, 44, 49,
  44, 36, 51, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 48, 93,
  32, 91, 45, 49, 93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44,
  49, 44, 50, 44, 48, 32, 45, 107, 91, 48, 93, 10, 103, 105, 109, 112,
  95, 100, 114, 97, 119, 95, 119, 104, 105, 114, 108, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 100, 114, 97, 119,
  95, 119, 104, 105, 114, 108, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103,
  105, 109, 112, 95, 98, 108, 97, 99, 107, 97, 110, 100, 119, 104, 105, 116,
  101, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45,
  108, 91, 45, 49, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97,
  99, 105, 116, 121, 32, 45, 114, 118, 32, 45, 116, 111, 95, 114, 103, 98,
  91, 45, 49, 93, 32, 45, 115, 91, 45, 49, 93, 32, 99, 10, 45, 42,
  91, 45, 51, 93, 32, 36, 49, 32, 45, 98, 91, 45, 51, 93, 32, 36,
  50, 37, 10, 45, 42, 91, 45, 50, 93, 32, 36, 51, 32, 45, 98, 91,
  45, 50, 93, 32, 36, 52, 37, 10, 45, 42, 91, 45, 49, 93, 32, 36,
  53, 32, 45, 98, 91, 45, 49, 93, 32, 36, 54, 37, 10, 45, 43, 91,
  45, 51, 45, 45, 49, 93, 32, 45, 47, 91, 45, 49, 93, 32, 123, 36,
  49, 43, 36, 51, 43, 36, 53, 125, 32, 45, 99, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 10, 45, 97, 112, 112, 108, 121, 95, 103, 97, 109,
  109, 97, 91, 45, 49, 93, 32, 123, 49, 48, 94, 36, 55, 125, 10, 45,
  45, 91, 45, 49, 93, 32, 49, 50, 56, 32, 45, 42, 91, 45, 49, 93,
  32, 36, 56, 32, 45, 43, 91, 45, 49, 93, 32, 49, 50, 56, 32, 45,
  43, 91, 45, 49, 93, 32, 36, 57, 32, 45, 99, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36, 49, 50, 124, 124,
  36, 49, 51, 124, 124, 36, 49, 52, 125, 10, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 32, 91, 45, 49, 93, 120, 50, 10, 45, 110, 111, 105, 115,
  101, 91, 45, 51, 93, 32, 49, 48, 48, 44, 36, 49, 55, 32, 45, 98,
  91, 45, 51, 93, 32, 36, 49, 54, 37, 32, 45, 110, 91, 45, 51, 93,
  32, 45, 36, 49, 50, 44, 36, 49, 50, 10, 45, 110, 111, 105, 115, 101,
  91, 45, 50, 93, 32, 49, 48, 48, 44, 36, 49, 55, 32, 45, 98, 91,
  45, 50, 93, 32, 36, 49, 54, 37, 32, 45, 110, 91, 45, 50, 93, 32,
  45, 36, 49, 51, 44, 36, 49, 51, 10, 45, 110, 111, 105, 115, 101, 91,
  45, 49, 93, 32, 49, 48, 48, 44, 36, 49, 55, 32, 45, 98, 91, 45,
  49, 93, 32, 36, 49, 54, 37, 32, 45, 110, 91, 45, 49, 93, 32, 45,
  36, 49, 52, 44, 36, 49, 52, 10, 45, 45, 116, 111, 110, 101, 115, 91,
  45, 52, 93, 32, 51, 32, 45, 98, 91, 45, 51, 45, 45, 49, 93, 32,
  36, 49, 53, 37, 10, 45, 42, 91, 45, 54, 44, 45, 51, 93, 32, 45,
  42, 91, 45, 52, 44, 45, 50, 93, 32, 45, 42, 91, 45, 50, 44, 45,
  49, 93, 10, 45, 43, 91, 45, 52, 45, 45, 49, 93, 32, 45, 99, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 49, 48, 124, 124, 36, 49, 49, 125, 10,
  45, 47, 91, 45, 49, 93, 32, 50, 53, 53, 10, 45, 105, 91, 45, 50,
  93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44,
  36, 49, 49, 10, 45, 105, 91, 45, 51, 93, 32, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 44, 49, 44, 49, 44, 36, 49, 48, 10, 45, 97, 91,
  45, 51, 45, 45, 49, 93, 32, 99, 32, 45, 104, 115, 118, 50, 114, 103,
  98, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 118,
  32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 109, 118, 91,
  45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32,
  36, 49, 56, 32, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 108,
  111, 99, 97, 108, 32, 36, 49, 56, 44, 36, 49, 57, 44, 36, 50, 48,
  44, 50, 37, 44, 49, 44, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 36, 50, 50, 32, 45, 110, 32, 48, 44,
  50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36,
  50, 49, 32, 45, 116, 111, 95, 112, 115, 101, 117, 100, 111, 103, 114, 97,
  121, 32, 36, 50, 49, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 103,
  105, 109, 112, 95, 98, 108, 97, 99, 107, 97, 110, 100, 119, 104, 105, 116,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 98, 108, 97, 99, 107, 97, 110, 100, 119,
  104, 105, 116, 101, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109,
  112, 95, 115, 116, 101, 110, 99, 105, 108, 98, 119, 32, 58, 10, 45, 115,
  116, 101, 110, 99, 105, 108, 98, 119, 32, 36, 49, 44, 36, 50, 10, 45,
  105, 102, 32, 123, 36, 51, 124, 124, 36, 52, 125, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115,
  112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 10, 45, 47, 91,
  48, 93, 32, 50, 53, 53, 32, 45, 105, 91, 48, 93, 32, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 36, 52, 32, 45, 105,
  91, 48, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44,
  49, 44, 36, 51, 32, 45, 97, 91, 48, 45, 50, 93, 32, 99, 32, 45,
  104, 115, 118, 50, 114, 103, 98, 91, 48, 93, 10, 45, 97, 32, 99, 32,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100,
  105, 102, 10, 103, 105, 109, 112, 95, 115, 116, 101, 110, 99, 105, 108, 98,
  119, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 115, 116, 101, 110, 99, 105, 108, 98, 119,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 99, 104,
  97, 114, 99, 111, 97, 108, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105,
  116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91, 48, 93, 10,
  45, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 109, 97, 120, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104,
  125, 10, 45, 105, 102, 32, 36, 53, 32, 45, 114, 101, 115, 105, 122, 101,
  91, 45, 49, 93, 32, 49, 53, 48, 37, 44, 49, 53, 48, 37, 44, 49,
  44, 49, 44, 54, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  36, 52, 32, 45, 101, 113, 117, 97, 108, 105, 122, 101, 91, 45, 49, 93,
  32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 115, 104, 97, 114, 112, 101, 110, 32, 123, 36,
  49, 42, 51, 125, 32, 45, 99, 117, 116, 32, 48, 44, 50, 53, 53, 10,
  45, 105, 102, 32, 36, 54, 32, 45, 45, 116, 50, 32, 36, 55, 44, 36,
  56, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 50, 91, 48, 93, 32,
  36, 50, 44, 36, 51, 10, 45, 105, 102, 32, 123, 33, 36, 49, 53, 125,
  32, 45, 101, 113, 91, 48, 93, 32, 48, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 111, 114, 10, 45, 45, 42, 91, 48, 93, 32, 36, 49, 48, 32,
  45, 45, 42, 91, 48, 93, 32, 36, 49, 49, 32, 45, 42, 91, 48, 93,
  32, 36, 57, 10, 45, 97, 112, 112, 101, 110, 100, 91, 45, 51, 45, 45,
  49, 93, 32, 99, 32, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111,
  108, 111, 114, 32, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 36, 49,
  50, 44, 36, 49, 51, 44, 36, 49, 52, 10, 45, 114, 32, 36, 119, 44,
  36, 104, 44, 49, 44, 49, 48, 48, 37, 44, 50, 10, 45, 101, 110, 100,
  108, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 103, 105, 109, 112, 95, 99, 104, 97, 114, 99, 111, 97, 108,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 103, 105, 109, 112, 95, 99, 104, 97, 114, 99, 111, 97, 108, 32, 36,
  42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 99, 111, 108, 111,
  114, 105, 122, 101, 95, 99, 111, 109, 105, 99, 115, 32, 58, 10, 45, 105,
  102, 32, 123, 64, 35, 60, 50, 125, 32, 45, 114, 101, 116, 117, 114, 110,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 60,
  50, 125, 32, 115, 101, 108, 101, 99, 116, 105, 111, 110, 61, 48, 44, 49,
  32, 45, 101, 108, 115, 101, 32, 115, 101, 108, 101, 99, 116, 105, 111, 110,
  61, 48, 44, 49, 44, 50, 32, 45, 101, 110, 100, 105, 102, 10, 45, 108,
  91, 36, 115, 101, 108, 101, 99, 116, 105, 111, 110, 93, 10, 45, 105, 102,
  32, 123, 36, 49, 61, 61, 48, 125, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 61, 61, 49, 125, 32, 45, 114, 118, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 61, 61, 50, 125, 32, 45, 114, 109, 91, 49, 93, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 51, 125, 32, 45, 114,
  109, 91, 50, 93, 32, 45, 114, 118, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 45, 116, 111, 95, 114, 103, 98, 97, 91, 48, 93, 32, 45, 115, 112,
  108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 91, 45, 49, 93, 32,
  45, 43, 91, 45, 50, 93, 32, 49, 32, 45, 110, 101, 113, 91, 45, 49,
  93, 32, 48, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 10, 45, 45,
  110, 111, 114, 109, 91, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 49, 32, 45, 45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45,
  49, 93, 32, 50, 44, 48, 44, 49, 10, 45, 105, 102, 32, 123, 105, 40,
  48, 41, 62, 105, 40, 49, 41, 125, 32, 45, 42, 91, 45, 50, 93, 32,
  45, 49, 32, 45, 43, 91, 45, 50, 93, 32, 49, 32, 45, 101, 110, 100,
  105, 102, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 98, 91, 45, 49,
  93, 32, 36, 51, 37, 32, 45, 119, 97, 116, 101, 114, 115, 104, 101, 100,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 45, 91, 45, 49, 93, 32, 49, 10, 45, 105, 102, 32, 123,
  36, 50, 61, 61, 48, 125, 32, 45, 114, 109, 91, 48, 93, 32, 45, 114,
  118, 32, 45, 98, 108, 101, 110, 100, 91, 48, 44, 49, 93, 32, 109, 117,
  108, 116, 105, 112, 108, 121, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50,
  61, 61, 49, 125, 32, 45, 114, 109, 91, 48, 93, 32, 45, 114, 118, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 50, 61, 61, 50, 125, 32, 45, 114,
  109, 91, 48, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 61, 61,
  51, 125, 32, 45, 114, 118, 91, 49, 44, 50, 93, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 50, 61, 61, 52, 125, 32, 45, 114, 118, 91, 48, 44,
  49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 10,
  103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 105, 122, 101, 95, 99, 111,
  109, 105, 99, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 105, 122, 101, 95, 99, 111,
  109, 105, 99, 115, 32, 36, 49, 44, 48, 44, 36, 51, 10, 103, 105, 109,
  112, 95, 114, 101, 99, 111, 108, 111, 114, 105, 122, 101, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50,
  41, 125, 10, 45, 105, 102, 32, 36, 51, 32, 115, 61, 36, 62, 44, 123,
  36, 62, 43, 49, 125, 32, 45, 101, 108, 115, 101, 32, 115, 61, 123, 50,
  42, 36, 62, 125, 44, 123, 50, 42, 36, 62, 43, 49, 125, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 108, 91, 36, 115, 93, 32, 45, 114, 118, 91,
  48, 44, 49, 93, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48,
  93, 32, 48, 32, 45, 116, 111, 95, 114, 103, 98, 91, 45, 50, 93, 10,
  45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 32, 45, 115, 112,
  108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 91, 45, 49, 93, 32,
  45, 110, 101, 113, 91, 45, 49, 93, 32, 48, 10, 45, 115, 114, 103, 98,
  50, 114, 103, 98, 91, 45, 51, 44, 45, 50, 93, 32, 45, 114, 103, 98,
  50, 108, 97, 98, 56, 91, 45, 51, 44, 45, 50, 93, 32, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 45, 51, 93, 32, 48, 32, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 45, 50, 93, 32, 49, 44, 50, 10, 45,
  43, 91, 45, 50, 93, 32, 49, 32, 45, 42, 91, 45, 50, 93, 32, 91,
  45, 49, 93, 32, 45, 45, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110,
  111, 114, 109, 91, 45, 51, 93, 32, 45, 42, 91, 45, 49, 93, 32, 45,
  49, 32, 45, 119, 97, 116, 101, 114, 115, 104, 101, 100, 91, 45, 51, 93,
  32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 45,
  91, 45, 50, 93, 32, 49, 10, 45, 45, 100, 105, 102, 102, 117, 115, 105,
  111, 110, 116, 101, 110, 115, 111, 114, 115, 91, 45, 51, 93, 32, 36, 50,
  44, 49, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 101, 113, 91, 45,
  50, 93, 32, 48, 32, 45, 42, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 115, 109, 111, 111, 116, 104,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 123, 36, 49, 42, 56, 48,
  125, 44, 48, 46, 56, 44, 54, 48, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 108, 97,
  98, 56, 50, 114, 103, 98, 91, 45, 49, 93, 32, 45, 114, 103, 98, 50,
  115, 114, 103, 98, 91, 45, 49, 93, 10, 45, 105, 102, 32, 36, 51, 32,
  45, 114, 103, 98, 50, 104, 115, 118, 91, 45, 49, 93, 32, 45, 115, 91,
  45, 49, 93, 32, 99, 32, 45, 105, 91, 50, 93, 32, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 49, 32, 45, 105, 91, 51,
  93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 50, 44,
  48, 32, 45, 97, 91, 48, 45, 50, 93, 32, 99, 32, 45, 97, 91, 94,
  48, 93, 32, 99, 32, 45, 104, 115, 118, 50, 114, 103, 98, 32, 45, 114,
  118, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 10, 45,
  100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 114, 101, 99, 111, 108, 111,
  114, 105, 122, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 114, 101, 99, 111, 108, 111, 114, 105, 122, 101, 32,
  36, 42, 32, 45, 97, 32, 120, 10, 103, 105, 109, 112, 95, 98, 119, 114,
  101, 99, 111, 108, 111, 114, 105, 122, 101, 32, 58, 10, 45, 114, 101, 109,
  111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 10, 45, 105, 102, 32,
  36, 52, 32, 45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 53, 61, 61, 48, 125, 10, 40,
  36, 123, 57, 45, 45, 50, 125, 41, 32, 45, 114, 91, 45, 49, 93, 32,
  52, 44, 36, 56, 44, 49, 44, 49, 44, 45, 49, 32, 45, 112, 101, 114,
  109, 117, 116, 101, 91, 45, 49, 93, 32, 121, 122, 99, 120, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 53, 61, 61, 49, 125, 10, 40, 48, 44, 50,
  53, 53, 94, 48, 44, 50, 53, 53, 94, 48, 44, 50, 53, 53, 94, 50,
  53, 53, 44, 50, 53, 53, 41, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  53, 61, 61, 50, 125, 10, 40, 50, 53, 53, 44, 48, 94, 50, 53, 53,
  44, 48, 94, 50, 53, 53, 44, 48, 94, 50, 53, 53, 44, 50, 53, 53,
  41, 10, 45, 101, 108, 105, 102, 32, 123, 36, 53, 61, 61, 51, 125, 10,
  40, 48, 44, 52, 52, 44, 49, 49, 53, 44, 49, 52, 51, 44, 49, 57,
  54, 44, 50, 52, 52, 94, 48, 44, 50, 48, 44, 56, 52, 44, 49, 49,
  57, 44, 49, 56, 52, 44, 50, 51, 53, 94, 48, 44, 53, 44, 52, 52,
  44, 55, 51, 44, 49, 52, 52, 44, 50, 48, 48, 94, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 41, 10, 45, 101, 108, 115, 101, 10, 40, 48, 44, 51, 53,
  57, 94, 49, 44, 49, 94, 49, 44, 49, 94, 50, 53, 53, 44, 50, 53,
  53, 41, 32, 45, 114, 91, 45, 49, 93, 32, 50, 53, 54, 44, 49, 44,
  49, 44, 52, 44, 51, 32, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44,
  50, 32, 45, 104, 115, 118, 50, 114, 103, 98, 91, 45, 49, 93, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 54, 61, 61, 48, 125, 32, 45, 114, 91, 45, 49, 93,
  32, 50, 53, 54, 44, 49, 44, 49, 44, 52, 44, 49, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 54, 61, 61, 49, 125, 32, 45, 114, 91, 45, 49,
  93, 32, 50, 53, 54, 44, 49, 44, 49, 44, 52, 44, 51, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 54, 61, 61, 50, 125, 32, 45, 114, 91, 45,
  49, 93, 32, 50, 53, 54, 44, 49, 44, 49, 44, 52, 44, 53, 32, 45,
  99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 108, 115,
  101, 32, 45, 114, 91, 45, 49, 93, 32, 50, 53, 54, 44, 49, 44, 49,
  44, 52, 44, 54, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 55, 61, 61, 49, 125, 32, 45, 115, 104, 91, 45, 49, 93, 32,
  48, 44, 50, 32, 45, 114, 103, 98, 50, 104, 115, 118, 91, 45, 49, 93,
  32, 45, 115, 104, 91, 45, 49, 93, 32, 50, 44, 50, 32, 45, 102, 91,
  45, 49, 93, 32, 120, 47, 119, 32, 45, 104, 115, 118, 50, 114, 103, 98,
  91, 45, 50, 93, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 108, 91, 94, 45, 49, 93, 32, 45,
  108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 97, 112, 112, 108, 121,
  95, 103, 97, 109, 109, 97, 32, 123, 49, 48, 94, 36, 49, 125, 32, 45,
  45, 32, 49, 50, 56, 32, 45, 42, 32, 36, 50, 32, 45, 43, 32, 123,
  36, 51, 43, 49, 50, 56, 125, 32, 45, 99, 32, 48, 44, 50, 53, 53,
  32, 45, 101, 110, 100, 108, 32, 45, 109, 97, 112, 91, 94, 45, 49, 93,
  32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 103, 105,
  109, 112, 95, 98, 119, 114, 101, 99, 111, 108, 111, 114, 105, 122, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  103, 105, 109, 112, 95, 98, 119, 114, 101, 99, 111, 108, 111, 114, 105, 122,
  101, 32, 36, 123, 94, 48, 125, 34, 44, 36, 45, 49, 10, 103, 105, 109,
  112, 95, 100, 105, 116, 104, 101, 114, 101, 100, 98, 119, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32,
  45, 108, 91, 48, 93, 10, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101,
  32, 45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 97, 112, 112, 108, 121,
  95, 103, 97, 109, 109, 97, 32, 123, 49, 48, 94, 36, 49, 125, 32, 45,
  45, 32, 49, 50, 56, 32, 45, 42, 32, 36, 50, 32, 45, 43, 32, 49,
  50, 56, 32, 45, 43, 32, 36, 51, 32, 45, 98, 32, 36, 52, 32, 45,
  99, 32, 48, 44, 50, 53, 53, 32, 45, 100, 105, 116, 104, 101, 114, 101,
  100, 98, 119, 10, 45, 105, 102, 32, 123, 36, 53, 124, 124, 36, 54, 125,
  32, 45, 47, 32, 50, 53, 53, 32, 45, 105, 91, 48, 93, 32, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 50, 32, 45, 102, 99, 91,
  48, 93, 32, 36, 53, 44, 36, 54, 32, 45, 97, 32, 99, 32, 45, 104,
  115, 118, 50, 114, 103, 98, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 100, 105, 116, 104, 101, 114,
  101, 100, 98, 119, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 100, 105, 116, 104, 101, 114,
  101, 100, 98, 119, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109,
  112, 95, 104, 97, 114, 100, 115, 107, 101, 116, 99, 104, 98, 119, 32, 58,
  10, 45, 98, 32, 36, 51, 10, 45, 105, 102, 32, 123, 36, 55, 61, 61,
  52, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 32, 45, 45, 104, 97, 114, 100, 115, 107, 101, 116, 99,
  104, 98, 119, 32, 36, 49, 44, 36, 50, 44, 36, 52, 44, 36, 53, 44,
  36, 54, 32, 45, 98, 108, 101, 110, 100, 32, 104, 97, 114, 100, 108, 105,
  103, 104, 116, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  104, 97, 114, 100, 115, 107, 101, 116, 99, 104, 98, 119, 32, 36, 49, 44,
  36, 50, 44, 36, 52, 44, 36, 53, 44, 36, 54, 10, 45, 105, 102, 32,
  123, 36, 55, 38, 49, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 55, 61,
  61, 50, 125, 32, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 49, 44, 52, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 115, 104, 91, 36, 62, 93, 32, 51, 44, 51, 32, 45, 42, 91, 45,
  49, 93, 32, 45, 50, 32, 45, 43, 91, 45, 49, 93, 32, 123, 50, 42,
  50, 53, 53, 125, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 55, 61, 61, 51, 125, 32, 45, 114,
  32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 52, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 115, 104, 91, 36, 62,
  93, 32, 51, 44, 51, 32, 45, 42, 91, 45, 49, 93, 32, 50, 32, 45,
  99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105, 102,
  10, 103, 105, 109, 112, 95, 104, 97, 114, 100, 115, 107, 101, 116, 99, 104,
  98, 119, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 104, 97, 114, 100, 115, 107, 101, 116,
  99, 104, 98, 119, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109,
  112, 95, 104, 111, 117, 103, 104, 115, 107, 101, 116, 99, 104, 98, 119, 32,
  58, 10, 45, 98, 32, 36, 49, 32, 45, 110, 32, 48, 44, 50, 53, 53,
  10, 45, 105, 102, 32, 123, 36, 54, 61, 61, 52, 125, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45,
  45, 104, 111, 117, 103, 104, 115, 107, 101, 116, 99, 104, 98, 119, 32, 36,
  123, 50, 45, 53, 125, 32, 45, 98, 108, 101, 110, 100, 32, 104, 97, 114,
  100, 108, 105, 103, 104, 116, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 104, 111, 117, 103, 104, 115, 107, 101, 116, 99, 104, 98, 119,
  32, 36, 123, 50, 45, 53, 125, 10, 45, 105, 102, 32, 123, 36, 54, 38,
  49, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 54, 61, 61, 50, 125, 32,
  45, 114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 52,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 115, 104, 91,
  36, 62, 93, 32, 51, 44, 51, 32, 45, 42, 91, 45, 49, 93, 32, 45,
  50, 32, 45, 43, 91, 45, 49, 93, 32, 123, 50, 42, 50, 53, 53, 125,
  32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 54, 61, 61, 51, 125, 32, 45, 114, 32, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 49, 44, 52, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 115, 104, 91, 36, 62, 93, 32, 51, 44,
  51, 32, 45, 42, 91, 45, 49, 93, 32, 50, 32, 45, 99, 91, 45, 49,
  93, 32, 48, 44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109,
  112, 95, 104, 111, 117, 103, 104, 115, 107, 101, 116, 99, 104, 98, 119, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  103, 105, 109, 112, 95, 104, 111, 117, 103, 104, 115, 107, 101, 116, 99, 104,
  98, 119, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95,
  105, 110, 107, 95, 119, 97, 115, 104, 32, 58, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112,
  108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91, 48,
  93, 10, 45, 103, 105, 109, 112, 95, 112, 101, 110, 99, 105, 108, 98, 119,
  91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 48, 44, 48, 44, 48,
  10, 45, 105, 102, 32, 123, 36, 51, 61, 61, 49, 125, 32, 45, 99, 111,
  110, 116, 105, 110, 117, 101, 10, 45, 101, 108, 105, 102, 32, 123, 36, 51,
  61, 61, 48, 125, 32, 45, 103, 105, 109, 112, 95, 97, 110, 105, 115, 111,
  116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103,
  91, 45, 49, 93, 32, 54, 48, 44, 36, 52, 44, 36, 53, 44, 36, 54,
  44, 49, 46, 49, 44, 48, 46, 56, 44, 51, 48, 44, 50, 44, 48, 44,
  49, 44, 49, 44, 48, 44, 49, 44, 49, 54, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 55, 61, 61, 49, 125, 32, 45, 110,
  111, 114, 109, 97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 91, 45,
  49, 93, 32, 50, 44, 54, 44, 53, 44, 50, 52, 44, 49, 44, 48, 44,
  50, 53, 53, 10, 9, 45, 101, 108, 105, 102, 32, 123, 36, 55, 61, 61,
  50, 125, 32, 32, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 108,
  111, 99, 97, 108, 91, 45, 49, 93, 32, 50, 44, 54, 44, 53, 44, 50,
  52, 44, 49, 44, 48, 44, 50, 53, 53, 32, 45, 103, 105, 109, 112, 95,
  99, 111, 110, 116, 114, 97, 115, 116, 95, 115, 119, 109, 32, 50, 44, 48,
  44, 48, 46, 53, 49, 50, 10, 45, 101, 108, 105, 102, 32, 123, 36, 55,
  61, 61, 51, 125, 32, 45, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97,
  108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 91, 45, 49, 93, 32, 36,
  56, 44, 36, 57, 44, 36, 49, 48, 44, 36, 49, 49, 44, 49, 44, 51,
  44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32,
  45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 103, 105, 109, 112, 95, 112, 101, 110, 99, 105, 108, 98, 119, 32, 58,
  10, 45, 112, 101, 110, 99, 105, 108, 98, 119, 32, 36, 49, 44, 36, 50,
  10, 45, 105, 102, 32, 123, 36, 51, 124, 124, 36, 52, 125, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32,
  45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 10, 45,
  47, 91, 48, 93, 32, 50, 53, 53, 32, 45, 105, 91, 48, 93, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 36, 52, 32,
  45, 105, 91, 48, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  49, 44, 49, 44, 36, 51, 32, 45, 97, 91, 48, 45, 50, 93, 32, 99,
  32, 45, 104, 115, 118, 50, 114, 103, 98, 91, 48, 93, 10, 45, 97, 32,
  99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 101,
  110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 112, 101, 110, 99, 105, 108,
  98, 119, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 112, 101, 110, 99, 105, 108, 98, 119,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 112, 101,
  110, 99, 105, 108, 95, 112, 111, 114, 116, 114, 97, 105, 116, 98, 119, 32,
  58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105,
  116, 121, 32, 45, 108, 91, 48, 93, 10, 45, 45, 98, 32, 50, 37, 10,
  45, 45, 98, 108, 101, 110, 100, 32, 100, 105, 118, 105, 100, 101, 32, 45,
  114, 109, 91, 45, 50, 93, 32, 45, 108, 117, 109, 105, 110, 97, 110, 99,
  101, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 105, 110, 107, 95,
  119, 97, 115, 104, 91, 45, 50, 93, 32, 48, 44, 49, 54, 55, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 52, 44, 50, 46, 50, 53, 44, 48,
  44, 50, 44, 54, 44, 53, 44, 50, 48, 10, 45, 45, 103, 105, 109, 112,
  95, 104, 97, 114, 100, 115, 107, 101, 116, 99, 104, 98, 119, 91, 45, 49,
  93, 32, 56, 48, 44, 51, 50, 44, 49, 46, 56, 57, 44, 48, 46, 50,
  49, 44, 51, 49, 46, 52, 54, 44, 48, 44, 48, 10, 45, 45, 103, 105,
  109, 112, 95, 115, 107, 101, 116, 99, 104, 98, 119, 91, 45, 50, 93, 32,
  49, 44, 36, 50, 44, 49, 56, 48, 44, 36, 49, 44, 36, 51, 44, 48,
  46, 48, 51, 44, 48, 44, 48, 46, 54, 44, 48, 46, 49, 44, 48, 46,
  54, 44, 48, 46, 50, 53, 44, 49, 44, 48, 44, 49, 44, 48, 10, 45,
  98, 108, 101, 110, 100, 91, 48, 44, 49, 93, 32, 100, 97, 114, 107, 101,
  110, 10, 45, 98, 108, 101, 110, 100, 91, 48, 44, 49, 93, 32, 109, 117,
  108, 116, 105, 112, 108, 121, 44, 48, 46, 53, 10, 45, 98, 108, 101, 110,
  100, 91, 48, 44, 49, 93, 32, 108, 105, 103, 104, 116, 101, 110, 44, 36,
  52, 10, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 108, 111, 99,
  97, 108, 32, 44, 10, 45, 116, 111, 95, 114, 103, 98, 32, 45, 45, 102,
  99, 32, 36, 123, 53, 45, 55, 125, 32, 45, 98, 108, 101, 110, 100, 32,
  115, 111, 102, 116, 108, 105, 103, 104, 116, 10, 45, 101, 110, 100, 108, 32,
  45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 103, 105, 109, 112, 95, 112, 101, 110, 99, 105, 108, 95, 112, 111, 114,
  116, 114, 97, 105, 116, 98, 119, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 112, 101, 110,
  99, 105, 108, 95, 112, 111, 114, 116, 114, 97, 105, 116, 98, 119, 32, 36,
  42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 115, 107, 101, 116,
  99, 104, 98, 119, 32, 58, 10, 45, 105, 102, 32, 123, 36, 49, 53, 61,
  61, 52, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 32, 45, 45, 115, 107, 101, 116, 99, 104, 98, 119,
  32, 36, 123, 49, 45, 49, 52, 125, 32, 45, 98, 108, 101, 110, 100, 32,
  104, 97, 114, 100, 108, 105, 103, 104, 116, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 115, 107, 101, 116, 99, 104, 98, 119, 32, 36,
  123, 49, 45, 49, 52, 125, 10, 45, 105, 102, 32, 123, 36, 49, 53, 38,
  49, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 53, 61, 61, 50, 125,
  32, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44,
  52, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 115, 104,
  91, 36, 62, 93, 32, 51, 44, 51, 32, 45, 42, 91, 45, 49, 93, 32,
  45, 50, 32, 45, 43, 91, 45, 49, 93, 32, 123, 50, 42, 50, 53, 53,
  125, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 53, 61, 61, 51, 125, 32, 45, 114, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 52, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 115, 104, 91, 36, 62, 93, 32,
  51, 44, 51, 32, 45, 42, 91, 45, 49, 93, 32, 50, 32, 45, 99, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49,
  93, 32, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 103,
  105, 109, 112, 95, 115, 107, 101, 116, 99, 104, 98, 119, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109,
  112, 95, 115, 107, 101, 116, 99, 104, 98, 119, 32, 36, 42, 34, 44, 36,
  45, 49, 10, 103, 105, 109, 112, 95, 115, 116, 97, 109, 112, 32, 58, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121,
  10, 45, 110, 111, 114, 109, 32, 45, 110, 111, 105, 115, 101, 32, 36, 53,
  10, 45, 105, 102, 32, 36, 49, 32, 45, 111, 116, 115, 117, 32, 50, 53,
  54, 32, 45, 101, 108, 115, 101, 32, 45, 103, 101, 32, 36, 50, 37, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 98, 32, 36, 51, 44, 48, 32, 45,
  115, 104, 97, 114, 112, 101, 110, 32, 36, 52, 32, 45, 110, 32, 48, 44,
  50, 53, 53, 10, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101,
  32, 49, 44, 48, 44, 48, 44, 49, 48, 49, 44, 51, 51, 44, 49, 55,
  48, 44, 50, 50, 57, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 105,
  102, 32, 36, 54, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 115, 116, 97, 109,
  112, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 115, 116, 97, 109, 112, 32, 36, 42, 34,
  44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 95,
  97, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 32, 58, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32,
  45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45,
  108, 91, 48, 93, 32, 45, 116, 111, 95, 114, 103, 98, 10, 45, 98, 32,
  36, 49, 32, 45, 115, 32, 99, 32, 45, 113, 117, 97, 110, 116, 105, 122,
  101, 32, 36, 50, 44, 49, 44, 48, 32, 45, 97, 114, 101, 97, 32, 48,
  32, 45, 94, 32, 36, 51, 32, 45, 110, 32, 48, 44, 50, 53, 53, 10,
  45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 99, 111, 108, 111,
  114, 95, 97, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112,
  108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105,
  109, 112, 95, 99, 111, 108, 111, 114, 95, 97, 98, 115, 116, 114, 97, 99,
  116, 105, 111, 110, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109,
  112, 95, 98, 111, 111, 115, 116, 95, 102, 97, 100, 101, 32, 58, 10, 45,
  105, 91, 48, 93, 32, 54, 52, 48, 44, 52, 56, 48, 44, 49, 44, 51,
  32, 45, 114, 97, 110, 100, 91, 48, 93, 32, 48, 44, 49, 32, 45, 98,
  91, 48, 93, 32, 123, 49, 48, 45, 36, 49, 125, 32, 45, 110, 91, 48,
  93, 32, 48, 44, 50, 53, 53, 32, 45, 116, 114, 97, 110, 115, 102, 101,
  114, 95, 99, 111, 108, 111, 114, 115, 32, 45, 114, 109, 91, 48, 93, 10,
  103, 105, 109, 112, 95, 98, 111, 111, 115, 116, 95, 102, 97, 100, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  103, 105, 109, 112, 95, 98, 111, 111, 115, 116, 95, 102, 97, 100, 101, 32,
  36, 42, 34, 44, 36, 45, 49, 10, 95, 103, 105, 109, 112, 95, 99, 104,
  97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103,
  32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 103, 97, 109, 109, 97, 91,
  45, 49, 93, 32, 123, 49, 48, 94, 36, 49, 125, 10, 45, 105, 102, 32,
  123, 36, 50, 33, 61, 49, 125, 32, 45, 45, 91, 45, 49, 93, 32, 49,
  50, 56, 32, 45, 42, 91, 45, 49, 93, 32, 36, 50, 32, 45, 43, 91,
  45, 49, 93, 32, 49, 50, 56, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  43, 91, 45, 49, 93, 32, 36, 51, 10, 45, 98, 91, 45, 49, 93, 32,
  36, 52, 37, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  10, 45, 105, 102, 32, 123, 36, 53, 61, 61, 49, 125, 32, 45, 99, 91,
  45, 49, 93, 32, 36, 54, 37, 44, 36, 55, 37, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 53, 61, 61, 50, 125, 32, 45, 99, 91, 45, 49, 93,
  32, 36, 54, 37, 44, 36, 55, 37, 32, 45, 110, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 10, 45, 101, 108, 105, 102, 32, 123, 36, 53, 61,
  61, 51, 125, 32, 45, 110, 91, 45, 49, 93, 32, 36, 54, 37, 44, 36,
  55, 37, 10, 45, 101, 108, 105, 102, 32, 123, 36, 53, 61, 61, 52, 125,
  32, 45, 116, 50, 91, 45, 49, 93, 32, 36, 54, 37, 44, 36, 55, 37,
  32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 56, 33, 61, 50, 53, 54, 125,
  32, 45, 113, 117, 97, 110, 116, 105, 122, 101, 91, 45, 49, 93, 32, 36,
  56, 44, 49, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 36, 57, 32, 45, 101, 113, 117, 97, 108, 105, 122, 101, 91, 45, 49,
  93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 49, 48,
  32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32, 45,
  101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110,
  101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 58, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 45, 49,
  93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121,
  32, 45, 114, 118, 32, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93,
  10, 45, 103, 105, 109, 112, 95, 115, 116, 97, 114, 116, 95, 109, 105, 120,
  32, 36, 49, 49, 44, 36, 49, 50, 10, 45, 97, 112, 112, 108, 121, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 34, 45, 95,
  103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111,
  99, 101, 115, 115, 105, 110, 103, 32, 36, 49, 44, 36, 50, 44, 36, 51,
  44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 44,
  36, 57, 44, 36, 49, 48, 34, 44, 36, 49, 51, 44, 48, 10, 45, 103,
  105, 109, 112, 95, 101, 110, 100, 95, 109, 105, 120, 32, 36, 49, 49, 10,
  45, 105, 102, 32, 123, 64, 35, 33, 61, 51, 125, 32, 45, 114, 118, 32,
  45, 97, 32, 99, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100,
  108, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110,
  101, 10, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112,
  114, 111, 99, 101, 115, 115, 105, 110, 103, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 99,
  104, 97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110,
  103, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 98,
  97, 108, 97, 110, 99, 101, 95, 103, 97, 109, 109, 97, 32, 58, 10, 45,
  98, 97, 108, 97, 110, 99, 101, 95, 103, 97, 109, 109, 97, 32, 36, 123,
  49, 45, 51, 125, 10, 45, 105, 102, 32, 36, 52, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115,
  112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91,
  48, 93, 32, 45, 115, 32, 99, 32, 45, 110, 32, 48, 44, 50, 53, 53,
  32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110,
  100, 105, 102, 10, 103, 105, 109, 112, 95, 98, 97, 108, 97, 110, 99, 101,
  95, 103, 97, 109, 109, 97, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 98, 97, 108, 97,
  110, 99, 101, 95, 103, 97, 109, 109, 97, 32, 36, 42, 34, 44, 36, 45,
  49, 10, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 109, 97, 112, 32,
  58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105,
  116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 10, 45, 105,
  102, 32, 123, 36, 49, 62, 61, 50, 125, 10, 45, 105, 110, 100, 101, 120,
  91, 48, 93, 32, 123, 36, 49, 45, 50, 125, 44, 36, 50, 44, 49, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 10, 40, 36,
  123, 53, 45, 50, 56, 125, 41, 32, 45, 122, 91, 45, 49, 93, 32, 48,
  44, 123, 51, 42, 36, 52, 45, 49, 125, 10, 45, 114, 91, 45, 49, 93,
  32, 51, 44, 123, 119, 47, 51, 125, 44, 49, 44, 49, 44, 45, 49, 32,
  45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 49, 93, 32, 121, 122, 99,
  120, 32, 45, 114, 91, 45, 49, 93, 32, 36, 51, 44, 49, 44, 49, 44,
  51, 44, 51, 10, 45, 105, 110, 100, 101, 120, 91, 48, 93, 32, 91, 45,
  49, 93, 44, 36, 50, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 101, 108, 115, 101, 10, 45, 97, 117, 116, 111, 105, 110, 100, 101, 120,
  91, 48, 93, 32, 36, 51, 44, 36, 50, 44, 123, 105, 102, 40, 36, 51,
  60, 61, 51, 50, 44, 49, 44, 48, 41, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 109, 97, 112,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 109, 97, 112, 32, 36,
  42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 97, 112, 112, 108,
  121, 95, 99, 117, 114, 118, 101, 32, 58, 10, 45, 97, 112, 112, 108, 121,
  95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 95, 103, 105, 109,
  112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 32, 36, 123,
  49, 45, 49, 51, 125, 34, 44, 36, 49, 52, 44, 36, 49, 53, 10, 95,
  103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101,
  32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 32,
  36, 49, 51, 44, 48, 44, 36, 49, 44, 92, 10, 64, 123, 34, 45, 105,
  102, 32, 123, 36, 50, 62, 61, 48, 125, 32, 45, 117, 32, 36, 50, 44,
  36, 51, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92,
  34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45,
  105, 102, 32, 123, 36, 52, 62, 61, 48, 125, 32, 45, 117, 32, 36, 52,
  44, 36, 53, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34,
  92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34,
  45, 105, 102, 32, 123, 36, 54, 62, 61, 48, 125, 32, 45, 117, 32, 36,
  54, 44, 36, 55, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92,
  34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123,
  34, 45, 105, 102, 32, 123, 36, 56, 62, 61, 48, 125, 32, 45, 117, 32,
  36, 56, 44, 36, 57, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32,
  92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64,
  123, 34, 45, 105, 102, 32, 123, 36, 49, 48, 62, 61, 48, 125, 32, 45,
  117, 32, 36, 49, 48, 44, 36, 49, 49, 44, 32, 45, 101, 108, 115, 101,
  32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34,
  125, 92, 10, 50, 53, 53, 44, 36, 49, 50, 10, 103, 105, 109, 112, 95,
  97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 102, 117, 110, 99, 116, 105, 111, 110, 49,
  100, 32, 36, 49, 51, 44, 48, 44, 36, 49, 44, 92, 10, 64, 123, 34,
  45, 105, 102, 32, 123, 36, 50, 62, 61, 48, 125, 32, 45, 117, 32, 36,
  50, 44, 36, 51, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92,
  34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123,
  34, 45, 105, 102, 32, 123, 36, 52, 62, 61, 48, 125, 32, 45, 117, 32,
  36, 52, 44, 36, 53, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32,
  92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64,
  123, 34, 45, 105, 102, 32, 123, 36, 54, 62, 61, 48, 125, 32, 45, 117,
  32, 36, 54, 44, 36, 55, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117,
  32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10,
  64, 123, 34, 45, 105, 102, 32, 123, 36, 56, 62, 61, 48, 125, 32, 45,
  117, 32, 36, 56, 44, 36, 57, 44, 32, 45, 101, 108, 115, 101, 32, 45,
  117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92,
  10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 49, 48, 62, 61, 48, 125,
  32, 45, 117, 32, 36, 49, 48, 44, 36, 49, 49, 44, 32, 45, 101, 108,
  115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105,
  102, 34, 125, 92, 10, 50, 53, 53, 44, 36, 49, 50, 10, 45, 109, 118,
  91, 45, 49, 93, 32, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  64, 35, 45, 49, 125, 10, 45, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 91, 45, 49, 93, 32, 34,
  45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118,
  101, 32, 36, 42, 34, 44, 36, 45, 49, 10, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 32, 45, 97, 120, 101, 115, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 49, 51, 44, 49, 44, 50,
  53, 53, 32, 45, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32,
  51, 32, 45, 114, 91, 45, 50, 93, 32, 91, 45, 51, 93, 32, 45, 106,
  91, 45, 51, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 44,
  48, 44, 49, 44, 91, 45, 49, 93, 44, 50, 53, 53, 32, 45, 114, 109,
  91, 45, 50, 44, 45, 49, 93, 10, 45, 103, 114, 105, 100, 91, 45, 49,
  93, 32, 49, 48, 37, 44, 49, 48, 37, 44, 48, 44, 48, 44, 48, 46,
  51, 44, 48, 120, 67, 67, 67, 67, 67, 67, 67, 67, 44, 50, 53, 53,
  10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 48, 44, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 48, 44, 48, 46, 51, 44, 48, 120, 67,
  67, 67, 67, 67, 67, 67, 67, 44, 50, 53, 53, 10, 45, 105, 102, 32,
  36, 45, 50, 10, 91, 45, 49, 93, 44, 91, 45, 49, 93, 32, 45, 116,
  111, 95, 103, 114, 97, 121, 91, 45, 51, 93, 32, 45, 104, 105, 115, 116,
  111, 103, 114, 97, 109, 91, 45, 51, 93, 32, 50, 53, 54, 44, 48, 44,
  50, 53, 53, 32, 45, 103, 114, 97, 112, 104, 91, 45, 49, 93, 32, 91,
  45, 51, 93, 44, 51, 44, 48, 44, 48, 44, 48, 44, 49, 44, 49, 32,
  45, 110, 101, 113, 91, 45, 49, 93, 32, 48, 32, 45, 42, 91, 45, 49,
  93, 32, 50, 53, 53, 32, 45, 114, 109, 91, 45, 51, 93, 10, 45, 45,
  120, 111, 114, 91, 45, 50, 44, 45, 49, 93, 32, 45, 106, 91, 45, 51,
  93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 36,
  49, 54, 44, 91, 45, 50, 93, 44, 50, 53, 53, 32, 45, 114, 109, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 101, 108, 115, 101, 32, 45, 114, 109,
  91, 45, 50, 93, 32, 45, 101, 110, 100, 105, 102, 10, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 32, 45, 103, 114, 97, 112, 104, 91, 45, 49, 93,
  32, 91, 48, 93, 44, 49, 44, 48, 44, 50, 53, 53, 44, 48, 44, 49,
  44, 50, 53, 53, 32, 45, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49,
  93, 32, 51, 32, 45, 114, 91, 45, 50, 93, 32, 91, 45, 51, 93, 32,
  45, 106, 91, 45, 51, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 44, 50, 53, 53, 32, 45,
  114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 95, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 48, 44, 36, 49, 44, 48, 32, 45, 95, 103, 105,
  109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 36, 50, 44, 36, 51, 44, 49, 10, 45,
  95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 52, 44, 36, 53, 44,
  50, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99,
  117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 54, 44,
  36, 55, 44, 51, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108,
  121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  36, 56, 44, 36, 57, 44, 52, 32, 45, 95, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 36, 49, 48, 44, 36, 49, 49, 44, 53, 10, 45, 95, 103,
  105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 50, 53, 53, 44, 36, 49, 50, 44,
  54, 10, 45, 109, 118, 91, 45, 49, 93, 32, 49, 32, 45, 100, 111, 110,
  101, 32, 45, 114, 109, 91, 48, 93, 10, 95, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 105, 102, 32, 123, 36, 49, 62, 61, 48, 125,
  10, 120, 61, 123, 36, 49, 42, 49, 48, 48, 47, 50, 53, 53, 125, 37,
  32, 121, 61, 123, 49, 48, 48, 45, 36, 50, 42, 49, 48, 48, 47, 50,
  53, 53, 125, 37, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49,
  93, 32, 36, 120, 44, 36, 121, 44, 51, 44, 51, 44, 48, 44, 49, 44,
  48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 44, 48, 44, 48,
  32, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 120,
  44, 36, 121, 44, 50, 44, 50, 44, 48, 44, 49, 44, 48, 44, 50, 53,
  53, 44, 48, 10, 45, 116, 91, 45, 49, 93, 32, 36, 51, 44, 36, 120,
  44, 123, 36, 121, 42, 104, 45, 50, 48, 125, 44, 49, 51, 44, 49, 44,
  50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95,
  97, 112, 112, 108, 121, 95, 82, 71, 66, 99, 117, 114, 118, 101, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 49, 10, 45, 103, 105, 109, 112, 95,
  97, 112, 112, 108, 121, 95, 82, 71, 66, 99, 117, 114, 118, 101, 95, 99,
  111, 110, 102, 105, 103, 102, 105, 108, 101, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 64, 35, 45, 49, 125, 32, 45, 108, 91, 36, 62, 44, 45,
  49, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101,
  91, 48, 93, 32, 123, 109, 97, 120, 40, 51, 44, 115, 41, 125, 10, 45,
  115, 104, 91, 48, 93, 32, 48, 44, 48, 32, 45, 95, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 82, 71, 66, 99, 117, 114, 118, 101, 91,
  45, 49, 93, 32, 64, 123, 45, 50, 44, 48, 45, 49, 50, 125, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 48, 93, 32, 49, 44,
  49, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 82,
  71, 66, 99, 117, 114, 118, 101, 91, 45, 49, 93, 32, 64, 123, 45, 50,
  44, 49, 51, 45, 50, 53, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 115, 104, 91, 48, 93, 32, 50, 44, 50, 32, 45, 95, 103, 105, 109,
  112, 95, 97, 112, 112, 108, 121, 95, 82, 71, 66, 99, 117, 114, 118, 101,
  91, 45, 49, 93, 32, 64, 123, 45, 50, 44, 50, 54, 45, 51, 56, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 45, 114, 109, 91, 45, 49, 93, 10, 95, 103, 105,
  109, 112, 95, 97, 112, 112, 108, 121, 95, 82, 71, 66, 99, 117, 114, 118,
  101, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101,
  32, 36, 49, 51, 44, 48, 44, 36, 49, 44, 92, 10, 64, 123, 34, 45,
  105, 102, 32, 123, 36, 50, 62, 61, 48, 125, 32, 45, 117, 32, 36, 50,
  44, 36, 51, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34,
  92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34,
  45, 105, 102, 32, 123, 36, 52, 62, 61, 48, 125, 32, 45, 117, 32, 36,
  52, 44, 36, 53, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92,
  34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123,
  34, 45, 105, 102, 32, 123, 36, 54, 62, 61, 48, 125, 32, 45, 117, 32,
  36, 54, 44, 36, 55, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32,
  92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64,
  123, 34, 45, 105, 102, 32, 123, 36, 56, 62, 61, 48, 125, 32, 45, 117,
  32, 36, 56, 44, 36, 57, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117,
  32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10,
  64, 123, 34, 45, 105, 102, 32, 123, 36, 49, 48, 62, 61, 48, 125, 32,
  45, 117, 32, 36, 49, 48, 44, 36, 49, 49, 44, 32, 45, 101, 108, 115,
  101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102,
  34, 125, 92, 10, 50, 53, 53, 44, 36, 49, 50, 10, 45, 99, 32, 48,
  44, 50, 53, 53, 10, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  82, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 82, 71, 66,
  99, 117, 114, 118, 101, 95, 99, 111, 110, 102, 105, 103, 102, 105, 108, 101,
  10, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48,
  32, 45, 102, 91, 45, 49, 93, 32, 36, 123, 49, 45, 45, 51, 125, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 97, 112,
  112, 108, 121, 95, 82, 71, 66, 99, 117, 114, 118, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 91, 94, 45, 49, 93, 32, 64, 45, 49, 44, 48, 44,
  36, 123, 45, 50, 44, 45, 49, 125, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 71, 99, 117, 114,
  118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 97, 112, 112, 108, 121, 95, 82, 71, 66, 99, 117, 114, 118,
  101, 95, 99, 111, 110, 102, 105, 103, 102, 105, 108, 101, 10, 45, 115, 104,
  91, 45, 49, 93, 32, 49, 44, 49, 44, 48, 44, 48, 32, 45, 102, 91,
  45, 49, 93, 32, 36, 123, 49, 45, 45, 51, 125, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  82, 71, 66, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119,
  91, 94, 45, 49, 93, 32, 64, 45, 49, 44, 49, 44, 36, 123, 45, 50,
  44, 45, 49, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 103, 105, 109,
  112, 95, 97, 112, 112, 108, 121, 95, 66, 99, 117, 114, 118, 101, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 82, 71, 66, 99, 117, 114, 118, 101, 95, 99, 111,
  110, 102, 105, 103, 102, 105, 108, 101, 10, 45, 115, 104, 91, 45, 49, 93,
  32, 50, 44, 50, 44, 48, 44, 48, 32, 45, 102, 91, 45, 49, 93, 32,
  36, 123, 49, 45, 45, 51, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 82, 71, 66, 99,
  117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 91, 94, 45, 49,
  93, 32, 64, 45, 49, 44, 50, 44, 36, 123, 45, 50, 44, 45, 49, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 103, 105, 109, 112, 95, 97, 112,
  112, 108, 121, 95, 82, 71, 66, 99, 117, 114, 118, 101, 95, 99, 111, 110,
  102, 105, 103, 102, 105, 108, 101, 32, 58, 10, 102, 105, 108, 101, 110, 97,
  109, 101, 61, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109, 112, 125, 47,
  46, 103, 109, 105, 99, 95, 82, 71, 66, 99, 117, 114, 118, 101, 46, 100,
  108, 109, 10, 45, 105, 102, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101,
  32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 32, 45, 101, 108, 115, 101,
  32, 40, 48, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50,
  56, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50, 56, 44,
  45, 49, 44, 49, 50, 56, 44, 50, 53, 53, 44, 49, 41, 32, 45, 114,
  91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 51, 32, 45, 101, 110, 100,
  105, 102, 10, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 82, 71,
  66, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 40, 36, 123, 49, 45, 45, 51, 125, 41, 32, 45, 114, 91, 45, 49,
  93, 32, 49, 51, 44, 51, 44, 49, 44, 49, 44, 45, 49, 32, 45, 111,
  91, 45, 49, 93, 32, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109, 112,
  125, 47, 46, 103, 109, 105, 99, 95, 82, 71, 66, 99, 117, 114, 118, 101,
  46, 100, 108, 109, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 102, 117,
  110, 99, 116, 105, 111, 110, 49, 100, 32, 36, 49, 51, 44, 48, 44, 36,
  49, 44, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 50, 62, 61,
  48, 125, 32, 45, 117, 32, 36, 50, 44, 36, 51, 44, 32, 45, 101, 108,
  115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105,
  102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 52, 62,
  61, 48, 125, 32, 45, 117, 32, 36, 52, 44, 36, 53, 44, 32, 45, 101,
  108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100,
  105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 54,
  62, 61, 48, 125, 32, 45, 117, 32, 36, 54, 44, 36, 55, 44, 32, 45,
  101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110,
  100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36,
  56, 62, 61, 48, 125, 32, 45, 117, 32, 36, 56, 44, 36, 57, 44, 32,
  45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101,
  110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123,
  36, 49, 48, 62, 61, 48, 125, 32, 45, 117, 32, 36, 49, 48, 44, 36,
  49, 49, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92,
  34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 50, 53, 53, 44,
  36, 49, 50, 10, 45, 102, 117, 110, 99, 116, 105, 111, 110, 49, 100, 32,
  36, 50, 54, 44, 48, 44, 36, 49, 52, 44, 92, 10, 64, 123, 34, 45,
  105, 102, 32, 123, 36, 49, 53, 62, 61, 48, 125, 32, 45, 117, 32, 36,
  49, 53, 44, 36, 49, 54, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117,
  32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10,
  64, 123, 34, 45, 105, 102, 32, 123, 36, 49, 55, 62, 61, 48, 125, 32,
  45, 117, 32, 36, 49, 55, 44, 36, 49, 56, 44, 32, 45, 101, 108, 115,
  101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102,
  34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 49, 57, 62,
  61, 48, 125, 32, 45, 117, 32, 36, 49, 57, 44, 36, 50, 48, 44, 32,
  45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101,
  110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123,
  36, 50, 49, 62, 61, 48, 125, 32, 45, 117, 32, 36, 50, 49, 44, 36,
  50, 50, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92,
  34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45,
  105, 102, 32, 123, 36, 50, 51, 62, 61, 48, 125, 32, 45, 117, 32, 36,
  50, 51, 44, 36, 50, 52, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117,
  32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10,
  50, 53, 53, 44, 36, 50, 53, 10, 45, 102, 117, 110, 99, 116, 105, 111,
  110, 49, 100, 32, 36, 51, 57, 44, 48, 44, 36, 50, 55, 44, 92, 10,
  64, 123, 34, 45, 105, 102, 32, 123, 36, 50, 56, 62, 61, 48, 125, 32,
  45, 117, 32, 36, 50, 56, 44, 36, 50, 57, 44, 32, 45, 101, 108, 115,
  101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102,
  34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 51, 48, 62,
  61, 48, 125, 32, 45, 117, 32, 36, 51, 48, 44, 36, 51, 49, 44, 32,
  45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101,
  110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123,
  36, 51, 50, 62, 61, 48, 125, 32, 45, 117, 32, 36, 51, 50, 44, 36,
  51, 51, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92,
  34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45,
  105, 102, 32, 123, 36, 51, 52, 62, 61, 48, 125, 32, 45, 117, 32, 36,
  51, 52, 44, 36, 51, 53, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117,
  32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10,
  64, 123, 34, 45, 105, 102, 32, 123, 36, 51, 54, 62, 61, 48, 125, 32,
  45, 117, 32, 36, 51, 54, 44, 36, 51, 55, 44, 32, 45, 101, 108, 115,
  101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102,
  34, 125, 92, 10, 50, 53, 53, 44, 36, 51, 56, 10, 45, 97, 91, 45,
  51, 45, 45, 49, 93, 32, 121, 32, 45, 109, 118, 91, 45, 49, 93, 32,
  48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125,
  10, 45, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 91, 45, 49, 93, 32, 34, 45, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 82, 71, 66, 99, 117, 114, 118, 101, 32,
  48, 34, 44, 36, 45, 49, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  32, 45, 97, 120, 101, 115, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 48, 44, 49, 51, 44, 49, 44, 50, 53, 53, 32,
  45, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51, 32, 45,
  114, 91, 45, 50, 93, 32, 91, 45, 51, 93, 32, 45, 106, 91, 45, 51,
  93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49,
  44, 91, 45, 49, 93, 44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 50,
  44, 45, 49, 93, 10, 45, 103, 114, 105, 100, 91, 45, 49, 93, 32, 49,
  48, 37, 44, 49, 48, 37, 44, 48, 44, 48, 44, 48, 46, 51, 44, 48,
  120, 67, 67, 67, 67, 67, 67, 67, 67, 44, 50, 53, 53, 10, 45, 108,
  105, 110, 101, 91, 45, 49, 93, 32, 48, 44, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 48, 44, 48, 46, 51, 44, 48, 120, 67, 67, 67, 67,
  67, 67, 67, 67, 44, 50, 53, 53, 10, 45, 105, 102, 32, 36, 45, 50,
  10, 91, 45, 49, 93, 44, 91, 45, 49, 93, 44, 49, 44, 49, 44, 45,
  123, 36, 45, 50, 42, 50, 53, 53, 47, 49, 48, 48, 125, 32, 45, 116,
  111, 95, 103, 114, 97, 121, 91, 45, 51, 93, 32, 45, 104, 105, 115, 116,
  111, 103, 114, 97, 109, 91, 45, 51, 93, 32, 50, 53, 54, 44, 48, 44,
  50, 53, 53, 32, 45, 103, 114, 97, 112, 104, 91, 45, 49, 93, 32, 91,
  45, 51, 93, 44, 51, 44, 48, 44, 48, 44, 48, 44, 49, 44, 48, 10,
  45, 114, 109, 91, 45, 51, 93, 32, 45, 43, 91, 45, 49, 93, 32, 123,
  36, 45, 50, 42, 50, 53, 53, 47, 49, 48, 48, 125, 32, 45, 43, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 10, 45, 101, 108, 115, 101, 32, 45, 114, 109, 91, 45, 50,
  93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 108, 105, 110, 101, 91, 45,
  49, 93, 32, 48, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48,
  44, 48, 46, 51, 44, 48, 120, 67, 67, 67, 67, 67, 67, 67, 67, 44,
  50, 53, 53, 10, 45, 115, 104, 91, 48, 93, 32, 48, 44, 48, 44, 48,
  44, 48, 10, 45, 103, 114, 97, 112, 104, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 44, 49, 44, 48, 44, 50, 53, 53, 44, 48, 44, 49, 44, 50,
  53, 53, 44, 49, 50, 56, 44, 49, 50, 56, 32, 45, 45, 91, 45, 49,
  93, 32, 49, 10, 45, 103, 114, 97, 112, 104, 91, 45, 50, 93, 32, 91,
  45, 49, 93, 44, 49, 44, 48, 44, 50, 53, 53, 44, 48, 44, 48, 46,
  53, 44, 50, 48, 48, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 115, 104, 91, 48, 93, 32, 49, 44, 49, 44, 48, 44, 48,
  10, 45, 103, 114, 97, 112, 104, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  44, 49, 44, 48, 44, 50, 53, 53, 44, 48, 44, 49, 44, 49, 50, 56,
  44, 50, 53, 53, 44, 49, 50, 56, 32, 45, 45, 91, 45, 49, 93, 32,
  49, 10, 45, 103, 114, 97, 112, 104, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 49, 44, 48, 44, 50, 53, 53, 44, 48, 44, 48, 46, 53, 44,
  48, 44, 50, 48, 48, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 115, 104, 91, 48, 93, 32, 50, 44, 50, 44, 48, 44, 48, 10, 45,
  103, 114, 97, 112, 104, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49,
  44, 48, 44, 50, 53, 53, 44, 48, 44, 49, 44, 49, 50, 56, 44, 49,
  50, 56, 44, 50, 53, 53, 32, 45, 45, 91, 45, 49, 93, 32, 49, 10,
  45, 103, 114, 97, 112, 104, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44,
  49, 44, 48, 44, 50, 53, 53, 44, 48, 44, 48, 46, 53, 44, 48, 44,
  48, 44, 50, 48, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 105,
  102, 32, 123, 36, 52, 48, 61, 61, 48, 125, 10, 45, 95, 103, 105, 109,
  112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 48, 44, 36, 49, 44, 48, 32, 45, 95, 103,
  105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 36, 50, 44, 36, 51, 44, 49, 10,
  45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114,
  118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 52, 44, 36, 53,
  44, 50, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 54,
  44, 36, 55, 44, 51, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112,
  108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 36, 56, 44, 36, 57, 44, 52, 32, 45, 95, 103, 105, 109, 112, 95,
  97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 36, 49, 48, 44, 36, 49, 49, 44, 53, 10, 45, 95,
  103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 50, 53, 53, 44, 36, 49, 50,
  44, 54, 10, 45, 101, 108, 105, 102, 32, 123, 36, 52, 48, 61, 61, 49,
  125, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99,
  117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 48, 44, 36,
  49, 52, 44, 48, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108,
  121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  36, 49, 53, 44, 36, 49, 54, 44, 49, 10, 45, 95, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 36, 49, 55, 44, 36, 49, 56, 44, 50, 32, 45,
  95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 49, 57, 44, 36, 50,
  48, 44, 51, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121,
  95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36,
  50, 49, 44, 36, 50, 50, 44, 52, 32, 45, 95, 103, 105, 109, 112, 95,
  97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 36, 50, 51, 44, 36, 50, 52, 44, 53, 10, 45, 95,
  103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 50, 53, 53, 44, 36, 50, 53,
  44, 54, 10, 45, 101, 108, 115, 101, 10, 45, 95, 103, 105, 109, 112, 95,
  97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 48, 44, 36, 50, 55, 44, 48, 32, 45, 95, 103, 105,
  109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 36, 50, 56, 44, 36, 50, 57, 44, 49,
  10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117,
  114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 51, 48, 44,
  36, 51, 49, 44, 50, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112,
  108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 36, 51, 50, 44, 36, 51, 51, 44, 51, 10, 45, 95, 103, 105, 109,
  112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 36, 51, 52, 44, 36, 51, 53, 44, 52, 32,
  45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114,
  118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 51, 54, 44, 36,
  51, 55, 44, 53, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108,
  121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  50, 53, 53, 44, 36, 51, 56, 44, 54, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 109, 118, 91, 45, 49, 93, 32, 49, 32, 45, 100, 111, 110, 101,
  32, 45, 114, 109, 91, 48, 93, 10, 103, 105, 109, 112, 95, 97, 112, 112,
  108, 121, 95, 89, 67, 98, 67, 114, 99, 117, 114, 118, 101, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 36, 49, 10, 45, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 89, 67, 98, 67, 114, 99, 117, 114, 118, 101, 95,
  99, 111, 110, 102, 105, 103, 102, 105, 108, 101, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 45, 108, 91, 36, 62, 44,
  45, 49, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100,
  101, 91, 48, 93, 32, 123, 109, 97, 120, 40, 51, 44, 115, 41, 125, 32,
  45, 115, 104, 91, 48, 93, 32, 48, 44, 50, 32, 45, 114, 103, 98, 50,
  121, 99, 98, 99, 114, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 115, 104, 91, 48, 93, 32, 48, 44, 48, 32, 45, 95, 103,
  105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 89, 67, 98, 67, 114, 99,
  117, 114, 118, 101, 91, 45, 49, 93, 32, 64, 123, 45, 50, 44, 48, 45,
  49, 50, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91,
  48, 93, 32, 49, 44, 49, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112,
  112, 108, 121, 95, 89, 67, 98, 67, 114, 99, 117, 114, 118, 101, 91, 45,
  49, 93, 32, 64, 123, 45, 50, 44, 49, 51, 45, 50, 53, 125, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 48, 93, 32, 50, 44,
  50, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 89,
  67, 98, 67, 114, 99, 117, 114, 118, 101, 91, 45, 49, 93, 32, 64, 123,
  45, 50, 44, 50, 54, 45, 51, 56, 125, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 115, 104, 91, 48, 93, 32, 48, 44, 50, 32, 45, 121, 99,
  98, 99, 114, 50, 114, 103, 98, 91, 45, 49, 93, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  45, 114, 109, 91, 45, 49, 93, 10, 95, 103, 105, 109, 112, 95, 97, 112,
  112, 108, 121, 95, 89, 67, 98, 67, 114, 99, 117, 114, 118, 101, 32, 58,
  10, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 32, 36, 49,
  51, 44, 48, 44, 36, 49, 44, 92, 10, 64, 123, 34, 45, 105, 102, 32,
  123, 36, 50, 62, 61, 48, 125, 32, 45, 117, 32, 36, 50, 44, 36, 51,
  44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32,
  45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102,
  32, 123, 36, 52, 62, 61, 48, 125, 32, 45, 117, 32, 36, 52, 44, 36,
  53, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34,
  32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105,
  102, 32, 123, 36, 54, 62, 61, 48, 125, 32, 45, 117, 32, 36, 54, 44,
  36, 55, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92,
  34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45,
  105, 102, 32, 123, 36, 56, 62, 61, 48, 125, 32, 45, 117, 32, 36, 56,
  44, 36, 57, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34,
  92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34,
  45, 105, 102, 32, 123, 36, 49, 48, 62, 61, 48, 125, 32, 45, 117, 32,
  36, 49, 48, 44, 36, 49, 49, 44, 32, 45, 101, 108, 115, 101, 32, 45,
  117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92,
  10, 50, 53, 53, 44, 36, 49, 50, 10, 45, 99, 32, 48, 44, 50, 53,
  53, 10, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 89, 99, 117,
  114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 89, 67, 98, 67, 114, 99,
  117, 114, 118, 101, 95, 99, 111, 110, 102, 105, 103, 102, 105, 108, 101, 10,
  45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 32,
  45, 102, 91, 45, 49, 93, 32, 36, 123, 49, 45, 45, 51, 125, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 97, 112, 112,
  108, 121, 95, 89, 67, 98, 67, 114, 99, 117, 114, 118, 101, 95, 112, 114,
  101, 118, 105, 101, 119, 91, 94, 45, 49, 93, 32, 64, 45, 49, 44, 48,
  44, 36, 123, 45, 50, 44, 45, 49, 125, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 67, 98, 99,
  117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 89, 67, 98, 67, 114,
  99, 117, 114, 118, 101, 95, 99, 111, 110, 102, 105, 103, 102, 105, 108, 101,
  10, 45, 115, 104, 91, 45, 49, 93, 32, 49, 44, 49, 44, 48, 44, 48,
  32, 45, 102, 91, 45, 49, 93, 32, 36, 123, 49, 45, 45, 51, 125, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 97, 112,
  112, 108, 121, 95, 89, 67, 98, 67, 114, 99, 117, 114, 118, 101, 95, 112,
  114, 101, 118, 105, 101, 119, 91, 94, 45, 49, 93, 32, 64, 45, 49, 44,
  49, 44, 36, 123, 45, 50, 44, 45, 49, 125, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 67, 114,
  99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 89, 67, 98, 67,
  114, 99, 117, 114, 118, 101, 95, 99, 111, 110, 102, 105, 103, 102, 105, 108,
  101, 10, 45, 115, 104, 91, 45, 49, 93, 32, 50, 44, 50, 44, 48, 44,
  48, 32, 45, 102, 91, 45, 49, 93, 32, 36, 123, 49, 45, 45, 51, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 89, 67, 98, 67, 114, 99, 117, 114, 118, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 91, 94, 45, 49, 93, 32, 64, 45, 49,
  44, 50, 44, 36, 123, 45, 50, 44, 45, 49, 125, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 89,
  67, 98, 67, 114, 99, 117, 114, 118, 101, 95, 99, 111, 110, 102, 105, 103,
  102, 105, 108, 101, 32, 58, 10, 102, 105, 108, 101, 110, 97, 109, 101, 61,
  64, 123, 45, 112, 97, 116, 104, 95, 116, 109, 112, 125, 47, 46, 103, 109,
  105, 99, 95, 89, 67, 98, 67, 114, 99, 117, 114, 118, 101, 46, 100, 108,
  109, 10, 45, 105, 102, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 32,
  36, 102, 105, 108, 101, 110, 97, 109, 101, 32, 45, 101, 108, 115, 101, 32,
  40, 48, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50, 56,
  44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50, 56, 44, 45,
  49, 44, 49, 50, 56, 44, 50, 53, 53, 44, 49, 41, 32, 45, 114, 91,
  45, 49, 93, 32, 49, 48, 48, 37, 44, 51, 32, 45, 101, 110, 100, 105,
  102, 10, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 89, 67, 98,
  67, 114, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 40, 36, 123, 49, 45, 45, 51, 125, 41, 32, 45, 114, 91, 45,
  49, 93, 32, 49, 51, 44, 51, 44, 49, 44, 49, 44, 45, 49, 32, 45,
  111, 91, 45, 49, 93, 32, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109,
  112, 125, 47, 46, 103, 109, 105, 99, 95, 89, 67, 98, 67, 114, 99, 117,
  114, 118, 101, 46, 100, 108, 109, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 102, 117, 110, 99, 116, 105, 111, 110, 49, 100, 32, 36, 49, 51, 44,
  48, 44, 36, 49, 44, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36,
  50, 62, 61, 48, 125, 32, 45, 117, 32, 36, 50, 44, 36, 51, 44, 32,
  45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101,
  110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123,
  36, 52, 62, 61, 48, 125, 32, 45, 117, 32, 36, 52, 44, 36, 53, 44,
  32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45,
  101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32,
  123, 36, 54, 62, 61, 48, 125, 32, 45, 117, 32, 36, 54, 44, 36, 55,
  44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32,
  45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102,
  32, 123, 36, 56, 62, 61, 48, 125, 32, 45, 117, 32, 36, 56, 44, 36,
  57, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34,
  32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105,
  102, 32, 123, 36, 49, 48, 62, 61, 48, 125, 32, 45, 117, 32, 36, 49,
  48, 44, 36, 49, 49, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32,
  92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 50,
  53, 53, 44, 36, 49, 50, 10, 45, 102, 117, 110, 99, 116, 105, 111, 110,
  49, 100, 32, 36, 50, 54, 44, 48, 44, 36, 49, 52, 44, 92, 10, 64,
  123, 34, 45, 105, 102, 32, 123, 36, 49, 53, 62, 61, 48, 125, 32, 45,
  117, 32, 36, 49, 53, 44, 36, 49, 54, 44, 32, 45, 101, 108, 115, 101,
  32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34,
  125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 49, 55, 62, 61,
  48, 125, 32, 45, 117, 32, 36, 49, 55, 44, 36, 49, 56, 44, 32, 45,
  101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110,
  100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36,
  49, 57, 62, 61, 48, 125, 32, 45, 117, 32, 36, 49, 57, 44, 36, 50,
  48, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34,
  32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105,
  102, 32, 123, 36, 50, 49, 62, 61, 48, 125, 32, 45, 117, 32, 36, 50,
  49, 44, 36, 50, 50, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32,
  92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64,
  123, 34, 45, 105, 102, 32, 123, 36, 50, 51, 62, 61, 48, 125, 32, 45,
  117, 32, 36, 50, 51, 44, 36, 50, 52, 44, 32, 45, 101, 108, 115, 101,
  32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34,
  125, 92, 10, 50, 53, 53, 44, 36, 50, 53, 10, 45, 102, 117, 110, 99,
  116, 105, 111, 110, 49, 100, 32, 36, 51, 57, 44, 48, 44, 36, 50, 55,
  44, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 50, 56, 62, 61,
  48, 125, 32, 45, 117, 32, 36, 50, 56, 44, 36, 50, 57, 44, 32, 45,
  101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110,
  100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36,
  51, 48, 62, 61, 48, 125, 32, 45, 117, 32, 36, 51, 48, 44, 36, 51,
  49, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34,
  32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105,
  102, 32, 123, 36, 51, 50, 62, 61, 48, 125, 32, 45, 117, 32, 36, 51,
  50, 44, 36, 51, 51, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32,
  92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64,
  123, 34, 45, 105, 102, 32, 123, 36, 51, 52, 62, 61, 48, 125, 32, 45,
  117, 32, 36, 51, 52, 44, 36, 51, 53, 44, 32, 45, 101, 108, 115, 101,
  32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34,
  125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 51, 54, 62, 61,
  48, 125, 32, 45, 117, 32, 36, 51, 54, 44, 36, 51, 55, 44, 32, 45,
  101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110,
  100, 105, 102, 34, 125, 92, 10, 50, 53, 53, 44, 36, 51, 56, 10, 45,
  97, 91, 45, 51, 45, 45, 49, 93, 32, 121, 32, 45, 109, 118, 91, 45,
  49, 93, 32, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35,
  45, 49, 125, 10, 45, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 91, 45, 49, 93, 32, 34, 45, 103,
  105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 89, 67, 98, 67, 114, 99,
  117, 114, 118, 101, 32, 48, 34, 44, 36, 45, 49, 10, 45, 97, 120, 101,
  115, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  48, 44, 49, 51, 44, 49, 44, 50, 53, 53, 10, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 32, 45, 97, 120, 101, 115, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 49, 51, 44, 49, 44,
  50, 53, 53, 32, 45, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93,
  32, 51, 32, 45, 114, 91, 45, 50, 93, 32, 91, 45, 51, 93, 32, 45,
  106, 91, 45, 51, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 49, 44, 91, 45, 49, 93, 44, 50, 53, 53, 32, 45, 114,
  109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 103, 114, 105, 100, 91, 45,
  49, 93, 32, 49, 48, 37, 44, 49, 48, 37, 44, 48, 44, 48, 44, 48,
  46, 51, 44, 48, 120, 67, 67, 67, 67, 67, 67, 67, 67, 44, 50, 53,
  53, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 48, 44, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 48, 44, 48, 46, 51, 44, 48, 120,
  67, 67, 67, 67, 67, 67, 67, 67, 44, 50, 53, 53, 10, 45, 105, 102,
  32, 36, 45, 50, 10, 91, 45, 49, 93, 44, 91, 45, 49, 93, 44, 49,
  44, 49, 44, 45, 123, 36, 45, 50, 42, 50, 53, 53, 47, 49, 48, 48,
  125, 32, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 51, 93, 32, 45,
  104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 51, 93, 32, 50, 53,
  54, 44, 48, 44, 50, 53, 53, 32, 45, 103, 114, 97, 112, 104, 91, 45,
  49, 93, 32, 91, 45, 51, 93, 44, 51, 44, 48, 44, 48, 44, 48, 44,
  49, 44, 48, 10, 45, 114, 109, 91, 45, 51, 93, 32, 45, 43, 91, 45,
  49, 93, 32, 123, 36, 45, 50, 42, 50, 53, 53, 47, 49, 48, 48, 125,
  32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 99, 91, 45, 49,
  93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 108, 115, 101, 32, 45, 114,
  109, 91, 45, 50, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 108, 105,
  110, 101, 91, 45, 49, 93, 32, 48, 44, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 48, 44, 48, 46, 51, 44, 48, 120, 67, 67, 67, 67, 67,
  67, 67, 67, 44, 50, 53, 53, 10, 45, 115, 104, 91, 48, 93, 32, 48,
  44, 48, 44, 48, 44, 48, 10, 45, 103, 114, 97, 112, 104, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 50, 53, 53, 44, 48,
  44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45,
  45, 91, 45, 49, 93, 32, 49, 10, 45, 103, 114, 97, 112, 104, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 50, 53, 53, 44,
  48, 44, 48, 46, 53, 44, 50, 48, 48, 44, 50, 48, 48, 44, 50, 48,
  48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 48, 93,
  32, 49, 44, 49, 44, 48, 44, 48, 10, 45, 103, 114, 97, 112, 104, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 50, 53, 53,
  44, 48, 44, 49, 44, 49, 50, 56, 44, 49, 50, 56, 44, 50, 53, 53,
  32, 45, 45, 91, 45, 49, 93, 32, 49, 10, 45, 103, 114, 97, 112, 104,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 50, 53,
  53, 44, 48, 44, 48, 46, 53, 44, 48, 44, 48, 44, 50, 48, 48, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 48, 93, 32, 50,
  44, 50, 44, 48, 44, 48, 10, 45, 103, 114, 97, 112, 104, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 50, 53, 53, 44, 48,
  44, 49, 44, 50, 53, 53, 44, 49, 50, 56, 44, 49, 50, 56, 32, 45,
  45, 91, 45, 49, 93, 32, 49, 10, 45, 103, 114, 97, 112, 104, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 50, 53, 53, 44,
  48, 44, 48, 46, 53, 44, 50, 48, 48, 44, 48, 44, 48, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 52, 48, 61, 61,
  48, 125, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 48, 44,
  36, 49, 44, 48, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108,
  121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  36, 50, 44, 36, 51, 44, 49, 10, 45, 95, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 36, 52, 44, 36, 53, 44, 50, 32, 45, 95, 103, 105, 109,
  112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 36, 54, 44, 36, 55, 44, 51, 10, 45, 95,
  103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 56, 44, 36, 57, 44, 52,
  32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117,
  114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 49, 48, 44,
  36, 49, 49, 44, 53, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112,
  108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 50, 53, 53, 44, 36, 49, 50, 44, 54, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 52, 48, 61, 61, 49, 125, 10, 45, 95, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 48, 44, 36, 49, 52, 44, 48, 32, 45, 95, 103,
  105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 36, 49, 53, 44, 36, 49, 54, 44,
  49, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99,
  117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 49, 55,
  44, 36, 49, 56, 44, 50, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112,
  112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 36, 49, 57, 44, 36, 50, 48, 44, 51, 10, 45, 95, 103, 105,
  109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 36, 50, 49, 44, 36, 50, 50, 44, 52,
  32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117,
  114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 50, 51, 44,
  36, 50, 52, 44, 53, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112,
  108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 50, 53, 53, 44, 36, 50, 53, 44, 54, 10, 45, 101, 108, 115, 101,
  10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117,
  114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 48, 44, 36, 50,
  55, 44, 48, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121,
  95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36,
  50, 56, 44, 36, 50, 57, 44, 49, 10, 45, 95, 103, 105, 109, 112, 95,
  97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 36, 51, 48, 44, 36, 51, 49, 44, 50, 32, 45, 95,
  103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 51, 50, 44, 36, 51, 51,
  44, 51, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 51,
  52, 44, 36, 51, 53, 44, 52, 32, 45, 95, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 36, 51, 54, 44, 36, 51, 55, 44, 53, 10, 45, 95, 103,
  105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 50, 53, 53, 44, 36, 51, 56, 44,
  54, 10, 45, 101, 110, 100, 105, 102, 10, 45, 109, 118, 91, 45, 49, 93,
  32, 49, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 93, 10,
  103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 76, 97, 98, 99, 117,
  114, 118, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 49, 10, 45,
  103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 76, 97, 98, 99, 117,
  114, 118, 101, 95, 99, 111, 110, 102, 105, 103, 102, 105, 108, 101, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 45, 108,
  91, 36, 62, 44, 45, 49, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111,
  114, 109, 111, 100, 101, 91, 48, 93, 32, 123, 109, 97, 120, 40, 51, 44,
  115, 41, 125, 32, 45, 115, 104, 91, 48, 93, 32, 48, 44, 50, 32, 45,
  114, 103, 98, 50, 108, 97, 98, 91, 45, 49, 93, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 115, 104, 91, 48, 93, 32, 48, 44, 48, 32, 45,
  42, 91, 45, 49, 93, 32, 50, 46, 53, 53, 32, 45, 95, 103, 105, 109,
  112, 95, 97, 112, 112, 108, 121, 95, 76, 97, 98, 99, 117, 114, 118, 101,
  91, 45, 49, 93, 32, 64, 123, 45, 50, 44, 48, 45, 49, 50, 125, 32,
  45, 47, 91, 45, 49, 93, 32, 50, 46, 53, 53, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 115, 104, 91, 48, 93, 32, 49, 44, 49, 32, 45,
  43, 91, 45, 49, 93, 32, 56, 54, 32, 45, 42, 91, 45, 49, 93, 32,
  49, 46, 51, 56, 53, 56, 55, 32, 45, 95, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 76, 97, 98, 99, 117, 114, 118, 101, 91, 45, 49,
  93, 32, 64, 123, 45, 50, 44, 49, 51, 45, 50, 53, 125, 32, 45, 47,
  91, 45, 49, 93, 32, 49, 46, 51, 56, 53, 56, 55, 32, 45, 45, 91,
  45, 49, 93, 32, 56, 54, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  115, 104, 91, 48, 93, 32, 50, 44, 50, 32, 45, 43, 91, 45, 49, 93,
  32, 49, 48, 56, 32, 45, 42, 91, 45, 49, 93, 32, 49, 46, 50, 53,
  54, 49, 54, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121,
  95, 76, 97, 98, 99, 117, 114, 118, 101, 91, 45, 49, 93, 32, 64, 123,
  45, 50, 44, 50, 54, 45, 51, 56, 125, 32, 45, 47, 91, 45, 49, 93,
  32, 49, 46, 50, 53, 54, 49, 54, 32, 45, 45, 91, 45, 49, 93, 32,
  49, 48, 56, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91,
  48, 93, 32, 48, 44, 50, 32, 45, 108, 97, 98, 50, 114, 103, 98, 91,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 45, 49, 93, 10,
  95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 76, 97, 98, 99,
  117, 114, 118, 101, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 117,
  114, 118, 101, 32, 36, 49, 51, 44, 48, 44, 36, 49, 44, 92, 10, 64,
  123, 34, 45, 105, 102, 32, 123, 36, 50, 62, 61, 48, 125, 32, 45, 117,
  32, 36, 50, 44, 36, 51, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117,
  32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10,
  64, 123, 34, 45, 105, 102, 32, 123, 36, 52, 62, 61, 48, 125, 32, 45,
  117, 32, 36, 52, 44, 36, 53, 44, 32, 45, 101, 108, 115, 101, 32, 45,
  117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92,
  10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 54, 62, 61, 48, 125, 32,
  45, 117, 32, 36, 54, 44, 36, 55, 44, 32, 45, 101, 108, 115, 101, 32,
  45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125,
  92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 56, 62, 61, 48, 125,
  32, 45, 117, 32, 36, 56, 44, 36, 57, 44, 32, 45, 101, 108, 115, 101,
  32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34,
  125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 49, 48, 62, 61,
  48, 125, 32, 45, 117, 32, 36, 49, 48, 44, 36, 49, 49, 44, 32, 45,
  101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110,
  100, 105, 102, 34, 125, 92, 10, 50, 53, 53, 44, 36, 49, 50, 10, 45,
  99, 32, 48, 44, 50, 53, 53, 10, 103, 105, 109, 112, 95, 97, 112, 112,
  108, 121, 95, 76, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  76, 97, 98, 99, 117, 114, 118, 101, 95, 99, 111, 110, 102, 105, 103, 102,
  105, 108, 101, 10, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 48, 44,
  48, 44, 48, 32, 45, 102, 91, 45, 49, 93, 32, 36, 123, 49, 45, 45,
  51, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 76, 97, 98, 99, 117, 114, 118, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 91, 94, 45, 49, 93, 32, 64, 45, 49,
  44, 48, 44, 36, 123, 45, 50, 44, 45, 49, 125, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 97,
  99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 76, 97, 98, 99,
  117, 114, 118, 101, 95, 99, 111, 110, 102, 105, 103, 102, 105, 108, 101, 10,
  45, 115, 104, 91, 45, 49, 93, 32, 49, 44, 49, 44, 48, 44, 48, 32,
  45, 102, 91, 45, 49, 93, 32, 36, 123, 49, 45, 45, 51, 125, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 97, 112, 112,
  108, 121, 95, 76, 97, 98, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 91, 94, 45, 49, 93, 32, 64, 45, 49, 44, 49, 44, 36,
  123, 45, 50, 44, 45, 49, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 98, 99, 117, 114, 118,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 97, 112, 112, 108, 121, 95, 76, 97, 98, 99, 117, 114, 118, 101,
  95, 99, 111, 110, 102, 105, 103, 102, 105, 108, 101, 10, 45, 115, 104, 91,
  45, 49, 93, 32, 50, 44, 50, 44, 48, 44, 48, 32, 45, 102, 91, 45,
  49, 93, 32, 36, 123, 49, 45, 45, 51, 125, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 76,
  97, 98, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 91,
  94, 45, 49, 93, 32, 64, 45, 49, 44, 50, 44, 36, 123, 45, 50, 44,
  45, 49, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 76, 97, 98, 99, 117, 114, 118, 101, 95,
  99, 111, 110, 102, 105, 103, 102, 105, 108, 101, 32, 58, 10, 102, 105, 108,
  101, 110, 97, 109, 101, 61, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109,
  112, 125, 47, 46, 103, 109, 105, 99, 95, 76, 97, 98, 99, 117, 114, 118,
  101, 46, 100, 108, 109, 10, 45, 105, 102, 32, 36, 102, 105, 108, 101, 110,
  97, 109, 101, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 32, 45, 101,
  108, 115, 101, 32, 40, 48, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49,
  44, 49, 50, 56, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49,
  50, 56, 44, 45, 49, 44, 49, 50, 56, 44, 50, 53, 53, 44, 49, 41,
  32, 45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 51, 32, 45,
  101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121,
  95, 76, 97, 98, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 40, 36, 123, 49, 45, 45, 51, 125, 41, 32, 45, 114,
  91, 45, 49, 93, 32, 49, 51, 44, 51, 44, 49, 44, 49, 44, 45, 49,
  32, 45, 111, 91, 45, 49, 93, 32, 64, 123, 45, 112, 97, 116, 104, 95,
  116, 109, 112, 125, 47, 46, 103, 109, 105, 99, 95, 76, 97, 98, 99, 117,
  114, 118, 101, 46, 100, 108, 109, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 102, 117, 110, 99, 116, 105, 111, 110, 49, 100, 32, 36, 49, 51, 44,
  48, 44, 36, 49, 44, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36,
  50, 62, 61, 48, 125, 32, 45, 117, 32, 36, 50, 44, 36, 51, 44, 32,
  45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101,
  110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123,
  36, 52, 62, 61, 48, 125, 32, 45, 117, 32, 36, 52, 44, 36, 53, 44,
  32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45,
  101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32,
  123, 36, 54, 62, 61, 48, 125, 32, 45, 117, 32, 36, 54, 44, 36, 55,
  44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32,
  45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102,
  32, 123, 36, 56, 62, 61, 48, 125, 32, 45, 117, 32, 36, 56, 44, 36,
  57, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34,
  32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105,
  102, 32, 123, 36, 49, 48, 62, 61, 48, 125, 32, 45, 117, 32, 36, 49,
  48, 44, 36, 49, 49, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32,
  92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 50,
  53, 53, 44, 36, 49, 50, 10, 45, 102, 117, 110, 99, 116, 105, 111, 110,
  49, 100, 32, 36, 50, 54, 44, 48, 44, 36, 49, 52, 44, 92, 10, 64,
  123, 34, 45, 105, 102, 32, 123, 36, 49, 53, 62, 61, 48, 125, 32, 45,
  117, 32, 36, 49, 53, 44, 36, 49, 54, 44, 32, 45, 101, 108, 115, 101,
  32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34,
  125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 49, 55, 62, 61,
  48, 125, 32, 45, 117, 32, 36, 49, 55, 44, 36, 49, 56, 44, 32, 45,
  101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110,
  100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36,
  49, 57, 62, 61, 48, 125, 32, 45, 117, 32, 36, 49, 57, 44, 36, 50,
  48, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34,
  32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105,
  102, 32, 123, 36, 50, 49, 62, 61, 48, 125, 32, 45, 117, 32, 36, 50,
  49, 44, 36, 50, 50, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32,
  92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64,
  123, 34, 45, 105, 102, 32, 123, 36, 50, 51, 62, 61, 48, 125, 32, 45,
  117, 32, 36, 50, 51, 44, 36, 50, 52, 44, 32, 45, 101, 108, 115, 101,
  32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34,
  125, 92, 10, 50, 53, 53, 44, 36, 50, 53, 10, 45, 102, 117, 110, 99,
  116, 105, 111, 110, 49, 100, 32, 36, 51, 57, 44, 48, 44, 36, 50, 55,
  44, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 50, 56, 62, 61,
  48, 125, 32, 45, 117, 32, 36, 50, 56, 44, 36, 50, 57, 44, 32, 45,
  101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110,
  100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36,
  51, 48, 62, 61, 48, 125, 32, 45, 117, 32, 36, 51, 48, 44, 36, 51,
  49, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34,
  32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105,
  102, 32, 123, 36, 51, 50, 62, 61, 48, 125, 32, 45, 117, 32, 36, 51,
  50, 44, 36, 51, 51, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32,
  92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64,
  123, 34, 45, 105, 102, 32, 123, 36, 51, 52, 62, 61, 48, 125, 32, 45,
  117, 32, 36, 51, 52, 44, 36, 51, 53, 44, 32, 45, 101, 108, 115, 101,
  32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34,
  125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 51, 54, 62, 61,
  48, 125, 32, 45, 117, 32, 36, 51, 54, 44, 36, 51, 55, 44, 32, 45,
  101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110,
  100, 105, 102, 34, 125, 92, 10, 50, 53, 53, 44, 36, 51, 56, 10, 45,
  97, 91, 45, 51, 45, 45, 49, 93, 32, 121, 32, 45, 109, 118, 91, 45,
  49, 93, 32, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35,
  45, 49, 125, 10, 45, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 91, 45, 49, 93, 32, 34, 45, 103,
  105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 76, 97, 98, 99, 117, 114,
  118, 101, 32, 48, 34, 44, 36, 45, 49, 10, 45, 97, 120, 101, 115, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44,
  49, 51, 44, 49, 44, 50, 53, 53, 10, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 32, 45, 97, 120, 101, 115, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 48, 44, 49, 51, 44, 49, 44, 50, 53,
  53, 32, 45, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51,
  32, 45, 114, 91, 45, 50, 93, 32, 91, 45, 51, 93, 32, 45, 106, 91,
  45, 51, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 49, 44, 91, 45, 49, 93, 44, 50, 53, 53, 32, 45, 114, 109, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 103, 114, 105, 100, 91, 45, 49, 93,
  32, 49, 48, 37, 44, 49, 48, 37, 44, 48, 44, 48, 44, 48, 46, 51,
  44, 48, 120, 67, 67, 67, 67, 67, 67, 67, 67, 44, 50, 53, 53, 10,
  45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 48, 44, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 48, 44, 48, 46, 51, 44, 48, 120, 67, 67,
  67, 67, 67, 67, 67, 67, 44, 50, 53, 53, 10, 45, 105, 102, 32, 36,
  45, 50, 10, 91, 45, 49, 93, 44, 91, 45, 49, 93, 44, 49, 44, 49,
  44, 45, 123, 36, 45, 50, 42, 50, 53, 53, 47, 49, 48, 48, 125, 32,
  45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 51, 93, 32, 45, 104, 105,
  115, 116, 111, 103, 114, 97, 109, 91, 45, 51, 93, 32, 50, 53, 54, 44,
  48, 44, 50, 53, 53, 32, 45, 103, 114, 97, 112, 104, 91, 45, 49, 93,
  32, 91, 45, 51, 93, 44, 51, 44, 48, 44, 48, 44, 48, 44, 49, 44,
  48, 10, 45, 114, 109, 91, 45, 51, 93, 32, 45, 43, 91, 45, 49, 93,
  32, 123, 36, 45, 50, 42, 50, 53, 53, 47, 49, 48, 48, 125, 32, 45,
  43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 99, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 10, 45, 101, 108, 115, 101, 32, 45, 114, 109, 91,
  45, 50, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 108, 105, 110, 101,
  91, 45, 49, 93, 32, 48, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 48, 44, 48, 46, 51, 44, 48, 120, 67, 67, 67, 67, 67, 67, 67,
  67, 44, 50, 53, 53, 10, 45, 115, 104, 91, 48, 93, 32, 48, 44, 48,
  44, 48, 44, 48, 10, 45, 103, 114, 97, 112, 104, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 49, 44, 48, 44, 50, 53, 53, 44, 48, 44, 49,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 45, 91,
  45, 49, 93, 32, 49, 10, 45, 103, 114, 97, 112, 104, 91, 45, 50, 93,
  32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 50, 53, 53, 44, 48, 44,
  48, 46, 53, 44, 50, 48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 48, 93, 32, 49,
  44, 49, 44, 48, 44, 48, 10, 45, 103, 114, 97, 112, 104, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 50, 53, 53, 44, 48,
  44, 49, 44, 50, 53, 53, 44, 49, 50, 56, 44, 49, 50, 56, 32, 45,
  45, 91, 45, 49, 93, 32, 49, 10, 45, 103, 114, 97, 112, 104, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 50, 53, 53, 44,
  48, 44, 48, 46, 53, 44, 50, 48, 48, 44, 48, 44, 48, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 48, 93, 32, 50, 44, 50,
  44, 48, 44, 48, 10, 45, 103, 114, 97, 112, 104, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 49, 44, 48, 44, 50, 53, 53, 44, 48, 44, 49,
  44, 49, 50, 56, 44, 49, 50, 56, 44, 50, 53, 53, 32, 45, 45, 91,
  45, 49, 93, 32, 49, 10, 45, 103, 114, 97, 112, 104, 91, 45, 50, 93,
  32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 50, 53, 53, 44, 48, 44,
  48, 46, 53, 44, 48, 44, 48, 44, 50, 48, 48, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 52, 48, 61, 61, 48, 125,
  10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117,
  114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 48, 44, 36, 49,
  44, 48, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 50,
  44, 36, 51, 44, 49, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112,
  108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 36, 52, 44, 36, 53, 44, 50, 32, 45, 95, 103, 105, 109, 112, 95,
  97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 36, 54, 44, 36, 55, 44, 51, 10, 45, 95, 103, 105,
  109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 36, 56, 44, 36, 57, 44, 52, 32, 45,
  95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 49, 48, 44, 36, 49,
  49, 44, 53, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121,
  95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 50,
  53, 53, 44, 36, 49, 50, 44, 54, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 52, 48, 61, 61, 49, 125, 10, 45, 95, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 48, 44, 36, 49, 52, 44, 48, 32, 45, 95, 103, 105, 109,
  112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 36, 49, 53, 44, 36, 49, 54, 44, 49, 10,
  45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114,
  118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 49, 55, 44, 36,
  49, 56, 44, 50, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108,
  121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  36, 49, 57, 44, 36, 50, 48, 44, 51, 10, 45, 95, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 36, 50, 49, 44, 36, 50, 50, 44, 52, 32, 45,
  95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 50, 51, 44, 36, 50,
  52, 44, 53, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121,
  95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 50,
  53, 53, 44, 36, 50, 53, 44, 54, 10, 45, 101, 108, 115, 101, 10, 45,
  95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 48, 44, 36, 50, 55, 44,
  48, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99,
  117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 50, 56,
  44, 36, 50, 57, 44, 49, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112,
  112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 36, 51, 48, 44, 36, 51, 49, 44, 50, 32, 45, 95, 103, 105,
  109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 36, 51, 50, 44, 36, 51, 51, 44, 51,
  10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117,
  114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 51, 52, 44,
  36, 51, 53, 44, 52, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112,
  108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 36, 51, 54, 44, 36, 51, 55, 44, 53, 10, 45, 95, 103, 105, 109,
  112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 50, 53, 53, 44, 36, 51, 56, 44, 54, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 109, 118, 91, 45, 49, 93, 32, 49,
  32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 93, 10, 103, 105,
  109, 112, 95, 100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 58, 10, 45, 105, 102, 32, 123, 33, 36, 50,
  125, 10, 45, 105, 102, 32, 36, 52, 32, 45, 116, 111, 95, 114, 103, 98,
  97, 32, 45, 101, 108, 115, 101, 32, 45, 116, 111, 95, 114, 103, 98, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 45, 49, 93, 10, 45, 115, 112, 108, 105, 116, 95,
  111, 112, 97, 99, 105, 116, 121, 32, 45, 95, 103, 105, 109, 112, 95, 100,
  101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 36, 49, 91, 48, 93, 10, 45, 115, 91, 48, 93, 32, 99, 32, 45,
  105, 102, 32, 123, 33, 36, 51, 125, 32, 45, 97, 32, 120, 32, 45, 101,
  110, 100, 105, 102, 10, 110, 98, 61, 64, 35, 10, 45, 101, 110, 100, 108,
  32, 45, 109, 118, 91, 45, 36, 110, 98, 45, 45, 49, 93, 32, 48, 32,
  45, 100, 111, 110, 101, 10, 45, 101, 108, 115, 101, 10, 45, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 48, 32, 110, 98, 99, 61, 123, 51, 43, 40,
  36, 49, 61, 61, 49, 48, 41, 125, 32, 110, 98, 61, 123, 36, 110, 98,
  99, 43, 36, 52, 125, 10, 45, 105, 102, 32, 36, 51, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 36, 110, 98,
  41, 125, 32, 45, 108, 91, 48, 45, 123, 36, 110, 98, 45, 49, 125, 93,
  10, 45, 97, 91, 48, 45, 123, 36, 110, 98, 99, 45, 49, 125, 93, 32,
  99, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 99, 111, 109, 112, 111,
  115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 36, 49, 91, 48, 93,
  32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 109, 118, 91,
  45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 115,
  101, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 115, 32, 120, 44, 36, 110, 98, 32, 45, 97, 91,
  48, 45, 123, 36, 110, 98, 99, 45, 49, 125, 93, 32, 99, 32, 45, 95,
  103, 105, 109, 112, 95, 114, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 36, 49, 91, 48, 93, 32, 45, 97, 32,
  99, 10, 45, 101, 110, 100, 108, 32, 45, 109, 118, 91, 45, 49, 93, 32,
  48, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 100, 101, 99, 111, 109,
  112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 100, 101,
  99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 36, 123, 94, 48, 125, 32, 45, 97, 112, 112, 101, 110, 100, 95, 116,
  105, 108, 101, 115, 32, 44, 10, 95, 103, 105, 109, 112, 95, 100, 101, 99,
  111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 48,
  32, 58, 10, 95, 103, 105, 109, 112, 95, 100, 101, 99, 111, 109, 112, 111,
  115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 49, 32, 58, 32, 45,
  114, 103, 98, 50, 104, 115, 118, 56, 10, 95, 103, 105, 109, 112, 95, 100,
  101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 50, 32, 58, 32, 45, 114, 103, 98, 50, 104, 115, 108, 56, 10, 95,
  103, 105, 109, 112, 95, 100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 51, 32, 58, 32, 45, 114, 103, 98, 50,
  104, 115, 105, 56, 10, 95, 103, 105, 109, 112, 95, 100, 101, 99, 111, 109,
  112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 52, 32, 58,
  32, 45, 114, 103, 98, 50, 121, 117, 118, 56, 10, 95, 103, 105, 109, 112,
  95, 100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110,
  101, 108, 115, 53, 32, 58, 32, 45, 114, 103, 98, 50, 121, 99, 98, 99,
  114, 10, 95, 103, 105, 109, 112, 95, 100, 101, 99, 111, 109, 112, 111, 115,
  101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 54, 32, 58, 32, 45, 114,
  103, 98, 50, 120, 121, 122, 56, 10, 95, 103, 105, 109, 112, 95, 100, 101,
  99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  55, 32, 58, 32, 45, 114, 103, 98, 50, 108, 97, 98, 56, 10, 95, 103,
  105, 109, 112, 95, 100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104,
  97, 110, 110, 101, 108, 115, 56, 32, 58, 32, 45, 114, 103, 98, 50, 108,
  99, 104, 56, 10, 95, 103, 105, 109, 112, 95, 100, 101, 99, 111, 109, 112,
  111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 57, 32, 58, 32,
  45, 114, 103, 98, 50, 99, 109, 121, 10, 95, 103, 105, 109, 112, 95, 100,
  101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 49, 48, 32, 58, 32, 45, 114, 103, 98, 50, 99, 109, 121, 107, 10,
  95, 103, 105, 109, 112, 95, 114, 101, 99, 111, 109, 112, 111, 115, 101, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 48, 32, 58, 10, 95, 103, 105, 109,
  112, 95, 114, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 49, 32, 58, 32, 45, 104, 115, 118, 56, 50, 114, 103,
  98, 10, 95, 103, 105, 109, 112, 95, 114, 101, 99, 111, 109, 112, 111, 115,
  101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 50, 32, 58, 32, 45, 104,
  115, 108, 56, 50, 114, 103, 98, 10, 95, 103, 105, 109, 112, 95, 114, 101,
  99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  51, 32, 58, 32, 45, 104, 115, 105, 56, 50, 114, 103, 98, 10, 95, 103,
  105, 109, 112, 95, 114, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104,
  97, 110, 110, 101, 108, 115, 52, 32, 58, 32, 45, 121, 117, 118, 56, 50,
  114, 103, 98, 10, 95, 103, 105, 109, 112, 95, 114, 101, 99, 111, 109, 112,
  111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 53, 32, 58, 32,
  45, 121, 99, 98, 99, 114, 50, 114, 103, 98, 10, 95, 103, 105, 109, 112,
  95, 114, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110,
  101, 108, 115, 54, 32, 58, 32, 45, 120, 121, 122, 56, 50, 114, 103, 98,
  10, 95, 103, 105, 109, 112, 95, 114, 101, 99, 111, 109, 112, 111, 115, 101,
  95, 99, 104, 97, 110, 110, 101, 108, 115, 55, 32, 58, 32, 45, 108, 97,
  98, 56, 50, 114, 103, 98, 10, 95, 103, 105, 109, 112, 95, 114, 101, 99,
  111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 56,
  32, 58, 32, 45, 108, 99, 104, 56, 50, 114, 103, 98, 10, 95, 103, 105,
  109, 112, 95, 114, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97,
  110, 110, 101, 108, 115, 57, 32, 58, 32, 45, 99, 109, 121, 50, 114, 103,
  98, 10, 95, 103, 105, 109, 112, 95, 114, 101, 99, 111, 109, 112, 111, 115,
  101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 49, 48, 32, 58, 32, 45,
  99, 109, 121, 107, 50, 114, 103, 98, 10, 103, 105, 109, 112, 95, 100, 101,
  116, 101, 99, 116, 95, 115, 107, 105, 110, 32, 58, 10, 45, 116, 111, 95,
  114, 103, 98, 10, 45, 109, 32, 34, 95, 103, 105, 109, 112, 95, 100, 101,
  116, 101, 99, 116, 95, 115, 107, 105, 110, 32, 58, 10, 45, 105, 102, 32,
  36, 53, 32, 45, 98, 97, 108, 97, 110, 99, 101, 95, 103, 97, 109, 109,
  97, 32, 49, 50, 56, 44, 49, 50, 56, 44, 49, 50, 56, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 49, 32, 45, 100, 101, 116,
  101, 99, 116, 95, 115, 107, 105, 110, 32, 36, 50, 32, 45, 101, 108, 115,
  101, 32, 45, 100, 101, 116, 101, 99, 116, 95, 115, 107, 105, 110, 32, 36,
  50, 44, 36, 54, 37, 44, 36, 55, 37, 44, 36, 56, 37, 32, 45, 101,
  110, 100, 105, 102, 10, 77, 61, 123, 105, 77, 125, 32, 45, 98, 32, 36,
  51, 37, 32, 45, 42, 32, 123, 50, 53, 53, 42, 36, 77, 47, 105, 77,
  125, 32, 45, 42, 32, 36, 52, 32, 45, 99, 32, 48, 44, 50, 53, 53,
  34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 105, 102, 32, 36, 57, 10, 45, 45, 95, 103, 105,
  109, 112, 95, 100, 101, 116, 101, 99, 116, 95, 115, 107, 105, 110, 32, 45,
  97, 32, 99, 10, 45, 105, 102, 32, 123, 36, 57, 62, 49, 125, 32, 45,
  115, 104, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 42, 91,
  45, 49, 93, 32, 45, 49, 32, 45, 43, 91, 45, 49, 93, 32, 50, 53,
  53, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 108, 115, 101, 32, 45, 95, 103, 105, 109, 112, 95, 100, 101,
  116, 101, 99, 116, 95, 115, 107, 105, 110, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 117, 110,
  99, 111, 109, 109, 97, 110, 100, 32, 95, 103, 105, 109, 112, 95, 100, 101,
  116, 101, 99, 116, 95, 115, 107, 105, 110, 10, 103, 105, 109, 112, 95, 100,
  101, 116, 101, 99, 116, 95, 115, 107, 105, 110, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95,
  100, 101, 116, 101, 99, 116, 95, 115, 107, 105, 110, 32, 36, 42, 34, 44,
  36, 45, 49, 10, 45, 105, 102, 32, 123, 33, 36, 49, 125, 10, 45, 99,
  105, 114, 99, 108, 101, 32, 36, 54, 37, 44, 36, 55, 37, 44, 36, 56,
  37, 44, 48, 46, 51, 44, 48, 44, 50, 53, 53, 44, 48, 44, 50, 53,
  53, 10, 45, 99, 105, 114, 99, 108, 101, 32, 36, 54, 37, 44, 36, 55,
  37, 44, 36, 56, 37, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70,
  70, 70, 44, 48, 44, 50, 53, 53, 44, 48, 44, 50, 53, 53, 10, 45,
  108, 105, 110, 101, 32, 123, 36, 54, 45, 48, 46, 50, 53, 42, 36, 56,
  125, 37, 44, 123, 36, 55, 45, 48, 46, 50, 53, 42, 36, 56, 125, 37,
  44, 123, 36, 54, 43, 48, 46, 50, 53, 42, 36, 56, 125, 37, 44, 123,
  36, 55, 43, 48, 46, 50, 53, 42, 36, 56, 125, 37, 44, 49, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 48, 44, 50, 53, 53, 10, 45, 108, 105,
  110, 101, 32, 123, 36, 54, 43, 48, 46, 50, 53, 42, 36, 56, 125, 37,
  44, 123, 36, 55, 45, 48, 46, 50, 53, 42, 36, 56, 125, 37, 44, 123,
  36, 54, 45, 48, 46, 50, 53, 42, 36, 56, 125, 37, 44, 123, 36, 55,
  43, 48, 46, 50, 53, 42, 36, 56, 125, 37, 44, 49, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105,
  102, 10, 103, 105, 109, 112, 95, 104, 115, 118, 95, 101, 113, 117, 97, 108,
  105, 122, 101, 114, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 111, 99, 97, 108, 91, 64, 123, 62, 44, 45, 49, 125,
  93, 10, 45, 116, 111, 95, 114, 103, 98, 32, 45, 114, 103, 98, 50, 104,
  115, 118, 32, 45, 115, 112, 108, 105, 116, 32, 99, 10, 45, 45, 102, 91,
  48, 93, 32, 105, 102, 40, 97, 98, 115, 40, 105, 45, 36, 50, 41, 60,
  36, 51, 47, 50, 124, 97, 98, 115, 40, 105, 45, 36, 50, 45, 51, 54,
  48, 41, 60, 36, 51, 47, 50, 124, 97, 98, 115, 40, 105, 45, 36, 50,
  43, 51, 54, 48, 41, 60, 36, 51, 47, 50, 44, 49, 44, 48, 41, 10,
  45, 45, 102, 91, 48, 93, 32, 105, 102, 40, 97, 98, 115, 40, 105, 45,
  36, 55, 41, 60, 36, 56, 47, 50, 124, 97, 98, 115, 40, 105, 45, 36,
  55, 45, 51, 54, 48, 41, 60, 36, 56, 47, 50, 124, 97, 98, 115, 40,
  105, 45, 36, 55, 43, 51, 54, 48, 41, 60, 36, 56, 47, 50, 44, 49,
  44, 48, 41, 10, 45, 45, 102, 91, 48, 93, 32, 105, 102, 40, 97, 98,
  115, 40, 105, 45, 36, 49, 50, 41, 60, 36, 49, 51, 47, 50, 124, 97,
  98, 115, 40, 105, 45, 36, 49, 50, 45, 51, 54, 48, 41, 60, 36, 49,
  51, 47, 50, 124, 97, 98, 115, 40, 105, 45, 36, 49, 50, 43, 51, 54,
  48, 41, 60, 36, 49, 51, 47, 50, 44, 49, 44, 48, 41, 10, 45, 45,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 91, 49, 44, 50, 93, 32, 48,
  46, 48, 49, 32, 45, 42, 91, 45, 49, 44, 45, 50, 93, 32, 91, 45,
  49, 93, 120, 50, 32, 45, 42, 91, 45, 49, 44, 51, 93, 32, 45, 42,
  91, 45, 49, 44, 52, 93, 32, 45, 42, 91, 45, 49, 44, 53, 93, 9,
  35, 48, 32, 115, 97, 116, 117, 114, 97, 116, 105, 111, 110, 32, 97, 110,
  100, 32, 118, 97, 108, 117, 101, 32, 110, 111, 116, 32, 105, 110, 32, 109,
  97, 115, 107, 10, 45, 45, 42, 91, 51, 93, 32, 36, 52, 32, 45, 45,
  42, 91, 52, 93, 32, 36, 57, 32, 45, 45, 42, 91, 53, 93, 32, 36,
  49, 52, 32, 45, 43, 91, 45, 49, 44, 45, 50, 44, 45, 51, 93, 10,
  45, 43, 91, 45, 49, 44, 48, 93, 32, 45, 37, 91, 48, 93, 32, 51,
  54, 48, 10, 45, 105, 102, 32, 123, 36, 53, 62, 61, 48, 125, 32, 45,
  45, 42, 91, 51, 93, 32, 45, 36, 53, 32, 45, 101, 108, 115, 101, 32,
  45, 45, 42, 91, 51, 93, 32, 123, 49, 47, 40, 49, 43, 36, 53, 41,
  45, 49, 125, 32, 45, 101, 110, 100, 105, 102, 32, 45, 43, 91, 45, 49,
  93, 32, 49, 10, 45, 105, 102, 32, 123, 36, 49, 48, 62, 61, 48, 125,
  32, 45, 45, 42, 91, 52, 93, 32, 45, 36, 49, 48, 32, 45, 101, 108,
  115, 101, 32, 45, 45, 42, 91, 52, 93, 32, 123, 49, 47, 40, 49, 43,
  36, 49, 48, 41, 45, 49, 125, 32, 45, 101, 110, 100, 105, 102, 32, 45,
  43, 91, 45, 49, 93, 32, 49, 10, 45, 105, 102, 32, 123, 36, 49, 53,
  62, 61, 48, 125, 32, 45, 45, 42, 91, 53, 93, 32, 45, 36, 49, 53,
  32, 45, 101, 108, 115, 101, 32, 45, 45, 42, 91, 53, 93, 32, 123, 49,
  47, 40, 49, 43, 36, 49, 53, 41, 45, 49, 125, 32, 45, 101, 110, 100,
  105, 102, 32, 45, 43, 91, 45, 49, 93, 32, 49, 10, 45, 42, 91, 45,
  49, 44, 45, 50, 44, 45, 51, 93, 32, 45, 94, 91, 49, 44, 45, 49,
  93, 10, 45, 105, 102, 32, 123, 36, 54, 62, 61, 48, 125, 32, 45, 45,
  42, 91, 51, 93, 32, 45, 36, 54, 32, 45, 101, 108, 115, 101, 32, 45,
  45, 42, 91, 51, 93, 32, 123, 49, 47, 40, 49, 43, 36, 54, 41, 45,
  49, 125, 32, 45, 101, 110, 100, 105, 102, 32, 45, 43, 91, 45, 49, 93,
  32, 49, 10, 45, 105, 102, 32, 123, 36, 49, 49, 62, 61, 48, 125, 32,
  45, 45, 42, 91, 52, 93, 32, 45, 36, 49, 49, 32, 45, 101, 108, 115,
  101, 32, 45, 45, 42, 91, 52, 93, 32, 123, 49, 47, 40, 49, 43, 36,
  49, 49, 41, 45, 49, 125, 32, 45, 101, 110, 100, 105, 102, 32, 45, 43,
  91, 45, 49, 93, 32, 49, 10, 45, 105, 102, 32, 123, 36, 49, 54, 62,
  61, 48, 125, 32, 45, 45, 42, 91, 53, 93, 32, 45, 36, 49, 54, 32,
  45, 101, 108, 115, 101, 32, 45, 45, 42, 91, 53, 93, 32, 123, 49, 47,
  40, 49, 43, 36, 49, 54, 41, 45, 49, 125, 32, 45, 101, 110, 100, 105,
  102, 32, 45, 43, 91, 45, 49, 93, 32, 49, 10, 45, 42, 91, 45, 49,
  44, 45, 50, 44, 45, 51, 93, 32, 45, 94, 91, 50, 44, 45, 49, 93,
  10, 45, 114, 109, 91, 51, 44, 52, 44, 53, 93, 32, 45, 97, 112, 112,
  101, 110, 100, 91, 48, 44, 49, 44, 50, 93, 32, 99, 32, 45, 104, 115,
  118, 50, 114, 103, 98, 10, 45, 101, 110, 100, 108, 111, 99, 97, 108, 32,
  45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 104, 115, 118, 95, 101,
  113, 117, 97, 108, 105, 122, 101, 114, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 108, 111, 99, 97, 108, 91, 45, 49, 93, 10, 45, 105,
  102, 32, 123, 36, 49, 61, 61, 48, 125, 32, 45, 103, 105, 109, 112, 95,
  104, 115, 118, 95, 101, 113, 117, 97, 108, 105, 122, 101, 114, 32, 36, 49,
  44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44,
  36, 55, 44, 36, 56, 44, 36, 57, 44, 36, 49, 48, 44, 36, 49, 49,
  44, 36, 49, 50, 44, 36, 49, 51, 44, 36, 49, 52, 44, 36, 49, 53,
  44, 36, 49, 54, 10, 45, 101, 108, 115, 101, 10, 45, 116, 111, 95, 114,
  103, 98, 32, 45, 114, 103, 98, 50, 104, 115, 118, 32, 45, 115, 112, 108,
  105, 116, 32, 99, 10, 40, 48, 44, 51, 53, 57, 41, 32, 45, 114, 101,
  115, 105, 122, 101, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 123, 64,
  123, 48, 44, 104, 125, 47, 49, 48, 125, 44, 49, 44, 49, 44, 51, 32,
  91, 45, 49, 93, 32, 45, 102, 91, 45, 49, 93, 32, 49, 9, 35, 99,
  114, 101, 97, 116, 101, 32, 108, 111, 119, 101, 114, 32, 98, 97, 110, 100,
  10, 45, 106, 91, 48, 93, 32, 91, 51, 93, 44, 48, 44, 57, 49, 37,
  32, 45, 106, 91, 49, 93, 32, 91, 52, 93, 44, 48, 44, 57, 49, 37,
  32, 45, 106, 91, 50, 93, 32, 91, 52, 93, 44, 48, 44, 57, 49, 37,
  32, 45, 114, 109, 91, 45, 49, 44, 45, 50, 93, 10, 45, 45, 102, 91,
  48, 93, 32, 105, 102, 40, 97, 98, 115, 40, 105, 45, 36, 50, 41, 60,
  36, 51, 47, 50, 124, 97, 98, 115, 40, 105, 45, 36, 50, 45, 51, 54,
  48, 41, 60, 36, 51, 47, 50, 124, 97, 98, 115, 40, 105, 45, 36, 50,
  43, 51, 54, 48, 41, 60, 36, 51, 47, 50, 44, 49, 44, 48, 41, 10,
  45, 45, 102, 91, 48, 93, 32, 105, 102, 40, 97, 98, 115, 40, 105, 45,
  36, 55, 41, 60, 36, 56, 47, 50, 124, 97, 98, 115, 40, 105, 45, 36,
  55, 45, 51, 54, 48, 41, 60, 36, 56, 47, 50, 124, 97, 98, 115, 40,
  105, 45, 36, 55, 43, 51, 54, 48, 41, 60, 36, 56, 47, 50, 44, 49,
  44, 48, 41, 10, 45, 45, 102, 91, 48, 93, 32, 105, 102, 40, 97, 98,
  115, 40, 105, 45, 36, 49, 50, 41, 60, 36, 49, 51, 47, 50, 124, 97,
  98, 115, 40, 105, 45, 36, 49, 50, 45, 51, 54, 48, 41, 60, 36, 49,
  51, 47, 50, 124, 97, 98, 115, 40, 105, 45, 36, 49, 50, 43, 51, 54,
  48, 41, 60, 36, 49, 51, 47, 50, 44, 49, 44, 48, 41, 10, 45, 111,
  114, 91, 45, 51, 45, 45, 49, 93, 32, 45, 43, 91, 45, 49, 93, 32,
  48, 46, 51, 51, 32, 45, 47, 91, 45, 49, 93, 32, 49, 46, 51, 51,
  9, 35, 49, 32, 97, 110, 100, 32, 48, 46, 50, 53, 10, 45, 42, 91,
  50, 44, 45, 49, 93, 32, 45, 97, 112, 112, 101, 110, 100, 32, 99, 32,
  45, 104, 115, 118, 50, 114, 103, 98, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 108, 111, 99, 97, 108, 10, 103, 105, 109, 112, 95, 115,
  116, 97, 114, 116, 95, 109, 105, 120, 32, 58, 10, 45, 105, 102, 32, 123,
  36, 49, 61, 61, 49, 125, 32, 45, 45, 116, 111, 110, 101, 115, 91, 45,
  49, 93, 32, 51, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  98, 91, 45, 50, 44, 45, 49, 93, 32, 36, 50, 37, 32, 45, 114, 91,
  45, 50, 44, 45, 49, 93, 32, 91, 45, 51, 93, 32, 45, 42, 91, 45,
  49, 93, 32, 91, 45, 51, 93, 32, 45, 109, 118, 91, 45, 51, 93, 32,
  64, 35, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 50, 125,
  32, 45, 45, 116, 111, 110, 101, 115, 91, 45, 49, 93, 32, 51, 32, 45,
  43, 91, 45, 51, 44, 45, 49, 93, 32, 45, 98, 91, 45, 50, 44, 45,
  49, 93, 32, 36, 50, 37, 32, 45, 114, 91, 45, 50, 44, 45, 49, 93,
  32, 91, 45, 51, 93, 32, 45, 42, 91, 45, 50, 93, 32, 91, 45, 51,
  93, 32, 45, 109, 118, 91, 45, 51, 93, 32, 64, 35, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 61, 61, 51, 125, 32, 45, 45, 116, 111, 110,
  101, 115, 91, 45, 49, 93, 32, 51, 32, 45, 43, 91, 45, 51, 44, 45,
  50, 93, 32, 45, 98, 91, 45, 50, 44, 45, 49, 93, 32, 36, 50, 37,
  32, 45, 114, 91, 45, 50, 44, 45, 49, 93, 32, 91, 45, 51, 93, 32,
  45, 42, 91, 45, 50, 93, 32, 91, 45, 51, 93, 32, 45, 109, 118, 91,
  45, 51, 93, 32, 64, 35, 10, 45, 101, 110, 100, 105, 102, 10, 103, 105,
  109, 112, 95, 101, 110, 100, 95, 109, 105, 120, 32, 58, 10, 45, 105, 102,
  32, 123, 36, 49, 61, 61, 49, 125, 32, 45, 42, 91, 45, 51, 44, 45,
  49, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 61, 61, 50, 125, 32, 45, 42, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 51, 125, 32, 45, 42, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93,
  10, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 109, 105, 120,
  95, 114, 103, 98, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 45, 49, 93, 32, 45, 115, 112, 108, 105, 116, 95,
  111, 112, 97, 99, 105, 116, 121, 32, 45, 114, 118, 32, 45, 116, 111, 95,
  114, 103, 98, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 115, 116,
  97, 114, 116, 95, 109, 105, 120, 32, 36, 49, 48, 44, 36, 49, 49, 10,
  45, 45, 91, 45, 49, 93, 32, 49, 50, 56, 32, 45, 115, 91, 45, 49,
  93, 32, 99, 10, 45, 42, 91, 45, 51, 93, 32, 36, 49, 32, 45, 43,
  91, 45, 51, 93, 32, 36, 50, 32, 45, 98, 91, 45, 51, 93, 32, 36,
  51, 37, 10, 45, 42, 91, 45, 50, 93, 32, 36, 52, 32, 45, 43, 91,
  45, 50, 93, 32, 36, 53, 32, 45, 98, 91, 45, 50, 93, 32, 36, 54,
  37, 10, 45, 42, 91, 45, 49, 93, 32, 36, 55, 32, 45, 43, 91, 45,
  49, 93, 32, 36, 56, 32, 45, 98, 91, 45, 49, 93, 32, 36, 57, 37,
  10, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 99, 32, 45, 43, 91,
  45, 49, 93, 32, 49, 50, 56, 32, 45, 99, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 10, 45, 103, 105, 109, 112, 95, 101, 110, 100, 95, 109,
  105, 120, 32, 36, 49, 48, 10, 45, 105, 102, 32, 123, 64, 35, 33, 61,
  51, 125, 32, 45, 114, 118, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100,
  105, 102, 32, 45, 101, 110, 100, 108, 32, 45, 109, 118, 91, 45, 49, 93,
  32, 48, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 109, 105,
  120, 95, 114, 103, 98, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 109, 105, 120, 95, 114,
  103, 98, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95,
  109, 105, 120, 95, 121, 99, 98, 99, 114, 32, 58, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 45, 49, 93, 32, 45, 115,
  112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 114, 118,
  32, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10, 45, 103, 105,
  109, 112, 95, 115, 116, 97, 114, 116, 95, 109, 105, 120, 32, 36, 49, 48,
  44, 36, 49, 49, 10, 45, 114, 103, 98, 50, 121, 99, 98, 99, 114, 91,
  45, 49, 93, 32, 45, 45, 91, 45, 49, 93, 32, 49, 50, 56, 32, 45,
  115, 91, 45, 49, 93, 32, 99, 10, 45, 42, 91, 45, 51, 93, 32, 36,
  49, 32, 45, 43, 91, 45, 51, 93, 32, 36, 50, 32, 45, 98, 91, 45,
  51, 93, 32, 36, 51, 37, 10, 45, 42, 91, 45, 50, 93, 32, 36, 52,
  32, 45, 43, 91, 45, 50, 93, 32, 36, 53, 32, 45, 98, 91, 45, 50,
  93, 32, 36, 54, 37, 10, 45, 42, 91, 45, 49, 93, 32, 36, 55, 32,
  45, 43, 91, 45, 49, 93, 32, 36, 56, 32, 45, 98, 91, 45, 49, 93,
  32, 36, 57, 37, 10, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 99,
  32, 45, 43, 91, 45, 49, 93, 32, 49, 50, 56, 32, 45, 99, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 121, 99, 98, 99, 114, 50,
  114, 103, 98, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 101, 110,
  100, 95, 109, 105, 120, 32, 36, 49, 48, 10, 45, 105, 102, 32, 123, 64,
  35, 33, 61, 51, 125, 32, 45, 114, 118, 32, 45, 97, 32, 99, 32, 45,
  101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 108, 32, 45, 109, 118, 91,
  45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112,
  95, 109, 105, 120, 95, 121, 99, 98, 99, 114, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95,
  109, 105, 120, 95, 121, 99, 98, 99, 114, 32, 36, 42, 34, 44, 36, 45,
  49, 10, 103, 105, 109, 112, 95, 109, 105, 120, 95, 104, 115, 118, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 45,
  49, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116,
  121, 32, 45, 114, 118, 32, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49,
  93, 10, 45, 103, 105, 109, 112, 95, 115, 116, 97, 114, 116, 95, 109, 105,
  120, 32, 36, 49, 48, 44, 36, 49, 49, 10, 45, 114, 103, 98, 50, 104,
  115, 118, 91, 45, 49, 93, 32, 45, 115, 91, 45, 49, 93, 32, 99, 32,
  45, 45, 91, 45, 50, 44, 45, 49, 93, 32, 48, 46, 53, 10, 45, 42,
  91, 45, 51, 93, 32, 36, 49, 32, 45, 43, 91, 45, 51, 93, 32, 36,
  50, 32, 45, 98, 91, 45, 51, 93, 32, 36, 51, 37, 10, 45, 42, 91,
  45, 50, 93, 32, 36, 52, 32, 45, 43, 91, 45, 50, 93, 32, 36, 53,
  32, 45, 98, 91, 45, 50, 93, 32, 36, 54, 37, 10, 45, 42, 91, 45,
  49, 93, 32, 36, 55, 32, 45, 43, 91, 45, 49, 93, 32, 36, 56, 32,
  45, 98, 91, 45, 49, 93, 32, 36, 57, 37, 10, 45, 37, 91, 45, 51,
  93, 32, 51, 54, 48, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32,
  48, 46, 53, 32, 45, 99, 91, 45, 50, 44, 45, 49, 93, 32, 48, 44,
  49, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 99, 32, 45, 104,
  115, 118, 50, 114, 103, 98, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112,
  95, 101, 110, 100, 95, 109, 105, 120, 32, 36, 49, 48, 10, 45, 105, 102,
  32, 123, 64, 35, 33, 61, 51, 125, 32, 45, 114, 118, 32, 45, 97, 32,
  99, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 108, 32, 45,
  109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 103,
  105, 109, 112, 95, 109, 105, 120, 95, 104, 115, 118, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112,
  95, 109, 105, 120, 95, 104, 115, 118, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 103, 105, 109, 112, 95, 109, 105, 120, 95, 108, 97, 98, 32, 58, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121,
  32, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 10, 45, 103, 105, 109,
  112, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108,
  97, 112, 91, 48, 93, 32, 34, 45, 95, 103, 105, 109, 112, 95, 109, 105,
  120, 95, 108, 97, 98, 32, 36, 42, 34, 44, 48, 44, 123, 51, 42, 109,
  97, 120, 40, 36, 51, 44, 36, 54, 44, 36, 57, 41, 125, 10, 45, 97,
  32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 109, 118, 91, 36, 62, 93,
  32, 48, 32, 45, 100, 111, 110, 101, 10, 95, 103, 105, 109, 112, 95, 109,
  105, 120, 95, 108, 97, 98, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115,
  116, 97, 114, 116, 95, 109, 105, 120, 32, 36, 49, 48, 44, 36, 49, 49,
  10, 45, 114, 103, 98, 50, 108, 97, 98, 91, 45, 49, 93, 32, 45, 115,
  91, 45, 49, 93, 32, 99, 10, 45, 42, 91, 45, 51, 93, 32, 36, 49,
  32, 45, 43, 91, 45, 51, 93, 32, 36, 50, 32, 45, 98, 91, 45, 51,
  93, 32, 36, 51, 37, 10, 45, 42, 91, 45, 50, 93, 32, 36, 52, 32,
  45, 43, 91, 45, 50, 93, 32, 36, 53, 32, 45, 98, 91, 45, 50, 93,
  32, 36, 54, 37, 10, 45, 42, 91, 45, 49, 93, 32, 36, 55, 32, 45,
  43, 91, 45, 49, 93, 32, 36, 56, 32, 45, 98, 91, 45, 49, 93, 32,
  36, 57, 37, 10, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 99, 32,
  45, 108, 97, 98, 50, 114, 103, 98, 91, 45, 49, 93, 10, 45, 103, 105,
  109, 112, 95, 101, 110, 100, 95, 109, 105, 120, 32, 36, 49, 48, 10, 103,
  105, 109, 112, 95, 109, 105, 120, 95, 108, 97, 98, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112,
  95, 109, 105, 120, 95, 108, 97, 98, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 103, 105, 109, 112, 95, 109, 105, 120, 95, 99, 109, 121, 107, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 45,
  49, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116,
  121, 32, 45, 114, 118, 32, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49,
  93, 10, 45, 103, 105, 109, 112, 95, 115, 116, 97, 114, 116, 95, 109, 105,
  120, 32, 36, 49, 51, 44, 36, 49, 52, 10, 45, 114, 103, 98, 50, 99,
  109, 121, 107, 91, 45, 49, 93, 32, 45, 115, 91, 45, 49, 93, 32, 99,
  10, 45, 42, 91, 45, 52, 93, 32, 36, 49, 32, 45, 43, 91, 45, 52,
  93, 32, 36, 50, 32, 45, 98, 91, 45, 52, 93, 32, 36, 51, 37, 10,
  45, 42, 91, 45, 51, 93, 32, 36, 52, 32, 45, 43, 91, 45, 51, 93,
  32, 36, 53, 32, 45, 98, 91, 45, 51, 93, 32, 36, 54, 37, 10, 45,
  42, 91, 45, 50, 93, 32, 36, 55, 32, 45, 43, 91, 45, 50, 93, 32,
  36, 56, 32, 45, 98, 91, 45, 50, 93, 32, 36, 57, 37, 10, 45, 42,
  91, 45, 49, 93, 32, 36, 49, 48, 32, 45, 43, 91, 45, 49, 93, 32,
  36, 49, 49, 32, 45, 98, 91, 45, 49, 93, 32, 36, 49, 50, 37, 10,
  45, 97, 91, 45, 52, 45, 45, 49, 93, 32, 99, 32, 45, 99, 109, 121,
  107, 50, 114, 103, 98, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95,
  101, 110, 100, 95, 109, 105, 120, 32, 36, 49, 51, 10, 45, 105, 102, 32,
  123, 64, 35, 33, 61, 51, 125, 32, 45, 114, 118, 32, 45, 97, 32, 99,
  32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 108, 32, 45, 109,
  118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 103, 105,
  109, 112, 95, 109, 105, 120, 95, 99, 109, 121, 107, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112,
  95, 109, 105, 120, 95, 99, 109, 121, 107, 32, 36, 42, 34, 44, 36, 45,
  49, 10, 95, 103, 105, 109, 112, 95, 115, 101, 108, 101, 99, 116, 95, 99,
  111, 108, 111, 114, 32, 58, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61,
  49, 125, 32, 45, 116, 111, 95, 114, 103, 98, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 61, 61, 50, 125, 32, 45, 116, 111, 95, 114, 103, 98,
  32, 45, 114, 103, 98, 50, 121, 99, 98, 99, 114, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 61, 61, 51, 125, 32, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61,
  61, 52, 125, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 49, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 53, 125, 32, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 50, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 49, 61, 61, 54, 125, 32, 45, 116, 111, 95, 114, 103, 98, 97,
  32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 51, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 61, 61, 55, 125, 32, 45, 116, 111, 95, 114,
  103, 98, 32, 45, 114, 103, 98, 50, 121, 99, 98, 99, 114, 32, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 48, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 49, 61, 61, 56, 125, 32, 45, 116, 111, 95, 114, 103, 98, 32,
  45, 114, 103, 98, 50, 121, 99, 98, 99, 114, 32, 45, 99, 104, 97, 110,
  110, 101, 108, 115, 32, 49, 44, 50, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 61, 61, 57, 125, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45,
  114, 103, 98, 50, 104, 115, 118, 32, 45, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49,
  48, 125, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 114, 103, 98, 50,
  104, 115, 118, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 49, 10,
  45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 115, 101, 108, 101,
  99, 116, 95, 99, 111, 108, 111, 114, 32, 58, 10, 40, 36, 52, 94, 36,
  53, 94, 36, 54, 94, 36, 55, 41, 32, 45, 95, 103, 105, 109, 112, 95,
  115, 101, 108, 101, 99, 116, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93,
  32, 36, 49, 32, 99, 111, 108, 111, 114, 61, 64, 45, 49, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 45, 116, 111, 95, 114, 103, 98, 97,
  10, 45, 45, 95, 103, 105, 109, 112, 95, 115, 101, 108, 101, 99, 116, 95,
  99, 111, 108, 111, 114, 32, 36, 49, 10, 45, 115, 101, 108, 101, 99, 116,
  95, 99, 111, 108, 111, 114, 91, 49, 93, 32, 36, 50, 37, 44, 36, 99,
  111, 108, 111, 114, 10, 45, 98, 91, 49, 93, 32, 36, 51, 37, 32, 45,
  110, 91, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123,
  36, 56, 61, 61, 48, 125, 32, 45, 115, 104, 91, 48, 93, 32, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 32, 45, 97, 110, 100, 91, 45, 49, 93,
  32, 91, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 56, 61, 61,
  49, 125, 32, 45, 114, 109, 91, 48, 93, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 56, 61, 61, 50, 125, 32, 45, 45, 91, 49, 93, 32, 50, 53,
  53, 32, 45, 42, 91, 49, 93, 32, 45, 49, 32, 45, 115, 104, 91, 48,
  93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 97, 110, 100,
  91, 45, 49, 93, 32, 91, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 56, 61, 61, 51, 125, 32, 45, 114, 109, 91, 48, 93, 32, 45, 45,
  32, 50, 53, 53, 32, 45, 42, 32, 45, 49, 10, 45, 101, 108, 115, 101,
  10, 45, 47, 91, 49, 93, 32, 50, 53, 53, 32, 45, 45, 42, 91, 48,
  44, 49, 93, 32, 45, 45, 42, 91, 49, 93, 32, 36, 49, 48, 32, 45,
  45, 42, 91, 49, 93, 32, 36, 49, 49, 32, 45, 45, 42, 91, 49, 93,
  32, 36, 49, 50, 32, 45, 42, 91, 49, 93, 32, 36, 57, 32, 45, 97,
  91, 49, 44, 45, 51, 45, 45, 49, 93, 32, 99, 32, 45, 45, 91, 49,
  44, 50, 93, 32, 45, 43, 10, 45, 101, 110, 100, 105, 102, 10, 45, 107,
  91, 48, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  103, 105, 109, 112, 95, 115, 101, 108, 101, 99, 116, 95, 99, 111, 108, 111,
  114, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 115, 101, 108, 101, 99, 116, 95, 99, 111,
  108, 111, 114, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112,
  95, 115, 101, 112, 105, 97, 32, 58, 10, 45, 115, 101, 112, 105, 97, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 115, 104, 91, 45,
  49, 93, 32, 48, 44, 50, 32, 45, 97, 112, 112, 108, 121, 95, 103, 97,
  109, 109, 97, 91, 45, 49, 93, 32, 123, 49, 48, 94, 36, 49, 125, 32,
  45, 45, 91, 45, 49, 93, 32, 49, 50, 56, 32, 45, 42, 91, 45, 49,
  93, 32, 36, 50, 32, 45, 43, 91, 45, 49, 93, 32, 123, 49, 50, 56,
  43, 36, 51, 125, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 109, 118, 91, 45, 49,
  93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 115,
  101, 112, 105, 97, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 115, 101, 112, 105, 97, 32,
  36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 99, 117, 115,
  116, 111, 109, 95, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32, 58, 10,
  45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 10, 45, 102, 91, 45, 49, 93, 32, 34, 36, 49, 34, 10,
  45, 115, 91, 45, 49, 93, 32, 99, 32, 45, 97, 91, 45, 52, 45, 45,
  50, 93, 32, 99, 32, 45, 102, 91, 45, 50, 93, 32, 34, 36, 50, 34,
  10, 45, 115, 91, 45, 50, 93, 32, 99, 32, 45, 102, 91, 45, 52, 93,
  32, 34, 36, 51, 34, 32, 45, 102, 91, 45, 51, 93, 32, 34, 36, 52,
  34, 32, 45, 102, 91, 45, 50, 93, 32, 34, 36, 53, 34, 32, 45, 102,
  91, 45, 49, 93, 32, 34, 36, 54, 34, 10, 45, 105, 102, 32, 123, 36,
  55, 61, 61, 48, 125, 32, 45, 97, 91, 45, 52, 45, 45, 49, 93, 32,
  99, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 55, 61, 61, 49, 125, 32, 45, 97, 91,
  45, 52, 45, 45, 50, 93, 32, 99, 32, 45, 110, 91, 45, 50, 93, 32,
  48, 44, 50, 53, 53, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45,
  101, 108, 115, 101, 32, 45, 97, 91, 45, 52, 45, 45, 49, 93, 32, 99,
  32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45,
  100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 99, 111, 110, 118, 111, 108,
  118, 101, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 32, 34, 45, 95, 103, 105, 109, 112, 95, 99, 111, 110,
  118, 111, 108, 118, 101, 32, 36, 49, 44, 36, 50, 44, 92, 34, 36, 51,
  92, 34, 44, 36, 123, 52, 45, 45, 51, 125, 34, 44, 36, 45, 50, 44,
  48, 10, 95, 103, 105, 109, 112, 95, 99, 111, 110, 118, 111, 108, 118, 101,
  32, 58, 10, 45, 105, 102, 32, 36, 49, 32, 45, 95, 103, 105, 109, 112,
  95, 99, 111, 110, 118, 111, 108, 118, 101, 36, 49, 91, 93, 32, 45, 101,
  108, 115, 101, 32, 40, 36, 51, 41, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 33, 36, 52, 125, 32, 45, 42, 91, 45, 49, 93,
  32, 36, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 99, 111, 110, 118,
  111, 108, 118, 101, 91, 48, 45, 45, 50, 93, 32, 91, 45, 49, 93, 44,
  36, 50, 10, 45, 105, 102, 32, 36, 52, 32, 45, 110, 32, 48, 44, 50,
  53, 53, 32, 45, 101, 108, 115, 101, 32, 45, 99, 32, 48, 44, 50, 53,
  53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 49, 93,
  10, 95, 103, 105, 109, 112, 95, 99, 111, 110, 118, 111, 108, 118, 101, 49,
  32, 58, 32, 51, 44, 51, 32, 45, 102, 32, 49, 32, 45, 110, 111, 114,
  109, 97, 108, 105, 122, 101, 95, 115, 117, 109, 10, 95, 103, 105, 109, 112,
  95, 99, 111, 110, 118, 111, 108, 118, 101, 50, 32, 58, 32, 53, 44, 53,
  32, 45, 102, 32, 49, 32, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101,
  95, 115, 117, 109, 10, 95, 103, 105, 109, 112, 95, 99, 111, 110, 118, 111,
  108, 118, 101, 51, 32, 58, 32, 55, 44, 55, 32, 45, 102, 32, 49, 32,
  45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 115, 117, 109, 10, 95,
  103, 105, 109, 112, 95, 99, 111, 110, 118, 111, 108, 118, 101, 52, 32, 58,
  32, 57, 44, 57, 32, 45, 102, 32, 49, 32, 45, 110, 111, 114, 109, 97,
  108, 105, 122, 101, 95, 115, 117, 109, 10, 95, 103, 105, 109, 112, 95, 99,
  111, 110, 118, 111, 108, 118, 101, 53, 32, 58, 32, 40, 49, 44, 48, 44,
  45, 49, 59, 49, 44, 48, 44, 45, 49, 59, 49, 44, 48, 44, 45, 49,
  41, 10, 95, 103, 105, 109, 112, 95, 99, 111, 110, 118, 111, 108, 118, 101,
  54, 32, 58, 32, 40, 49, 44, 49, 44, 49, 59, 48, 44, 48, 44, 48,
  59, 45, 49, 44, 45, 49, 44, 45, 49, 41, 10, 95, 103, 105, 109, 112,
  95, 99, 111, 110, 118, 111, 108, 118, 101, 55, 32, 58, 32, 40, 49, 44,
  48, 44, 45, 49, 59, 50, 44, 48, 44, 45, 50, 59, 49, 44, 48, 44,
  45, 49, 41, 10, 95, 103, 105, 109, 112, 95, 99, 111, 110, 118, 111, 108,
  118, 101, 56, 32, 58, 32, 40, 49, 44, 50, 44, 49, 59, 48, 44, 48,
  44, 48, 59, 45, 49, 44, 45, 50, 44, 45, 49, 41, 10, 95, 103, 105,
  109, 112, 95, 99, 111, 110, 118, 111, 108, 118, 101, 57, 32, 58, 32, 97,
  61, 123, 48, 46, 50, 53, 42, 40, 50, 45, 115, 113, 114, 116, 40, 50,
  41, 41, 125, 32, 98, 61, 123, 48, 46, 53, 42, 40, 115, 113, 114, 116,
  40, 50, 41, 45, 49, 41, 125, 32, 40, 36, 97, 44, 48, 44, 45, 36,
  97, 59, 36, 98, 44, 48, 44, 45, 36, 98, 59, 36, 97, 44, 48, 44,
  45, 36, 97, 41, 10, 95, 103, 105, 109, 112, 95, 99, 111, 110, 118, 111,
  108, 118, 101, 49, 48, 32, 58, 32, 97, 61, 123, 48, 46, 50, 53, 42,
  40, 50, 45, 115, 113, 114, 116, 40, 50, 41, 41, 125, 32, 98, 61, 123,
  48, 46, 53, 42, 40, 115, 113, 114, 116, 40, 50, 41, 45, 49, 41, 125,
  32, 40, 36, 97, 44, 36, 98, 44, 36, 97, 59, 48, 44, 48, 44, 48,
  59, 45, 36, 97, 44, 45, 36, 98, 44, 45, 36, 97, 41, 10, 95, 103,
  105, 109, 112, 95, 99, 111, 110, 118, 111, 108, 118, 101, 49, 49, 32, 58,
  32, 40, 48, 44, 49, 44, 48, 59, 49, 44, 45, 52, 44, 49, 59, 48,
  44, 49, 44, 48, 41, 10, 95, 103, 105, 109, 112, 95, 99, 111, 110, 118,
  111, 108, 118, 101, 49, 50, 32, 58, 32, 40, 49, 44, 48, 59, 48, 44,
  45, 49, 41, 10, 95, 103, 105, 109, 112, 95, 99, 111, 110, 118, 111, 108,
  118, 101, 49, 51, 32, 58, 32, 40, 48, 44, 49, 59, 45, 49, 44, 48,
  41, 10, 95, 103, 105, 109, 112, 95, 99, 111, 110, 118, 111, 108, 118, 101,
  49, 52, 32, 58, 32, 51, 44, 51, 32, 45, 102, 32, 49, 32, 45, 114,
  32, 55, 44, 55, 44, 49, 44, 49, 44, 52, 44, 48, 44, 48, 46, 53,
  44, 48, 46, 53, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 45,
  110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 115, 117, 109, 10, 95, 103,
  105, 109, 112, 95, 99, 111, 110, 118, 111, 108, 118, 101, 49, 53, 32, 58,
  32, 51, 44, 51, 32, 45, 102, 32, 49, 32, 45, 114, 32, 57, 44, 57,
  44, 49, 44, 49, 44, 52, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53,
  32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 45, 110, 111, 114, 109,
  97, 108, 105, 122, 101, 95, 115, 117, 109, 10, 95, 103, 105, 109, 112, 95,
  99, 111, 110, 118, 111, 108, 118, 101, 49, 54, 32, 58, 32, 51, 44, 51,
  32, 45, 102, 32, 49, 32, 45, 114, 32, 49, 49, 44, 49, 49, 44, 49,
  44, 49, 44, 52, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45,
  97, 117, 116, 111, 99, 114, 111, 112, 32, 45, 110, 111, 114, 109, 97, 108,
  105, 122, 101, 95, 115, 117, 109, 10, 103, 105, 109, 112, 95, 99, 111, 110,
  118, 111, 108, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 99, 111, 110, 118, 111,
  108, 118, 101, 32, 36, 49, 44, 36, 50, 44, 92, 34, 36, 51, 92, 34,
  44, 36, 123, 52, 45, 45, 49, 125, 34, 44, 36, 45, 49, 10, 103, 105,
  109, 112, 95, 99, 117, 114, 118, 97, 116, 117, 114, 101, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32,
  45, 108, 91, 48, 93, 10, 45, 98, 32, 36, 49, 32, 45, 105, 101, 101,
  10, 45, 105, 102, 32, 36, 52, 32, 45, 97, 98, 115, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 99, 32, 36, 50, 37, 44, 36, 51, 37, 10, 45,
  105, 102, 32, 36, 53, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10,
  45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 99, 117, 114, 118,
  97, 116, 117, 114, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 99, 117, 114, 118, 97,
  116, 117, 114, 101, 32, 36, 123, 94, 48, 125, 34, 44, 36, 45, 49, 10,
  103, 105, 109, 112, 95, 100, 111, 103, 32, 58, 10, 45, 100, 111, 103, 32,
  36, 49, 37, 44, 36, 50, 37, 10, 45, 99, 32, 36, 51, 37, 44, 123,
  49, 48, 48, 45, 36, 51, 125, 37, 10, 45, 105, 102, 32, 36, 52, 32,
  45, 110, 101, 103, 97, 116, 105, 118, 101, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 110, 32, 48, 44, 50, 53, 53, 10, 103, 105, 109, 112, 95, 100,
  111, 103, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 100, 111, 103, 32, 36, 123, 94, 48,
  125, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 100, 105, 115, 116,
  97, 110, 99, 101, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95,
  111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91, 48, 93, 10, 45, 100,
  105, 115, 116, 97, 110, 99, 101, 32, 36, 49, 44, 36, 50, 10, 45, 105,
  102, 32, 123, 36, 51, 61, 61, 48, 125, 32, 45, 99, 32, 48, 44, 50,
  53, 53, 10, 45, 101, 108, 105, 102, 32, 123, 36, 51, 61, 61, 49, 125,
  32, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 101, 108, 115, 101, 32,
  45, 37, 32, 36, 52, 32, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109,
  112, 95, 100, 105, 115, 116, 97, 110, 99, 101, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95,
  100, 105, 115, 116, 97, 110, 99, 101, 32, 36, 123, 94, 48, 125, 34, 44,
  36, 45, 49, 10, 103, 105, 109, 112, 95, 101, 100, 103, 101, 115, 32, 58,
  10, 45, 116, 111, 95, 114, 103, 98, 32, 45, 98, 32, 36, 49, 37, 32,
  45, 101, 100, 103, 101, 115, 32, 36, 50, 37, 10, 45, 105, 102, 32, 36,
  51, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10, 103, 105, 109, 112,
  95, 101, 100, 103, 101, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 101, 100, 103, 101,
  115, 32, 36, 123, 94, 48, 125, 34, 44, 36, 45, 49, 10, 103, 105, 109,
  112, 95, 101, 100, 103, 101, 95, 111, 102, 102, 115, 101, 116, 115, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 111, 115, 61, 123,
  115, 125, 10, 45, 98, 91, 45, 49, 93, 32, 36, 49, 37, 32, 45, 103,
  114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 91, 45, 49, 93,
  32, 45, 103, 101, 91, 45, 49, 93, 32, 36, 50, 37, 32, 45, 115, 107,
  101, 108, 101, 116, 111, 110, 91, 45, 49, 93, 32, 48, 32, 45, 100, 105,
  115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 114, 111,
  117, 110, 100, 91, 45, 49, 93, 32, 49, 32, 45, 37, 91, 45, 49, 93,
  32, 36, 51, 32, 45, 103, 101, 91, 45, 49, 93, 32, 123, 109, 97, 120,
  40, 49, 44, 36, 51, 45, 36, 52, 41, 125, 10, 45, 105, 102, 32, 123,
  33, 36, 53, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45,
  49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 32, 45, 116, 111, 95, 99, 111, 108, 111, 114,
  109, 111, 100, 101, 91, 45, 49, 93, 32, 36, 111, 115, 10, 45, 109, 118,
  91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109,
  112, 95, 101, 100, 103, 101, 95, 111, 102, 102, 115, 101, 116, 115, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115,
  112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103,
  105, 109, 112, 95, 101, 100, 103, 101, 95, 111, 102, 102, 115, 101, 116, 115,
  32, 36, 123, 94, 48, 125, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112,
  95, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 32, 58,
  10, 45, 98, 32, 36, 49, 32, 45, 103, 114, 97, 100, 105, 101, 110, 116,
  95, 110, 111, 114, 109, 32, 45, 94, 32, 36, 50, 10, 45, 99, 32, 36,
  51, 37, 44, 36, 52, 37, 10, 45, 105, 102, 32, 36, 53, 32, 45, 110,
  101, 103, 97, 116, 105, 118, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  110, 32, 48, 44, 50, 53, 53, 10, 103, 105, 109, 112, 95, 103, 114, 97,
  100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95,
  103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 32, 36, 123,
  94, 48, 125, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 103, 114,
  97, 100, 105, 101, 110, 116, 50, 114, 103, 98, 32, 58, 10, 45, 98, 32,
  36, 49, 32, 45, 103, 114, 97, 100, 105, 101, 110, 116, 50, 114, 103, 98,
  32, 36, 52, 10, 45, 99, 32, 36, 50, 37, 44, 36, 51, 37, 10, 45,
  105, 102, 32, 36, 53, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10,
  103, 105, 109, 112, 95, 103, 114, 97, 100, 105, 101, 110, 116, 50, 114, 103,
  98, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 103, 114, 97, 100, 105, 101, 110, 116, 50,
  114, 103, 98, 32, 36, 123, 94, 48, 125, 34, 44, 36, 45, 49, 10, 103,
  105, 109, 112, 95, 105, 115, 111, 112, 104, 111, 116, 101, 115, 32, 58, 10,
  45, 105, 102, 32, 36, 51, 10, 45, 116, 111, 112, 111, 103, 114, 97, 112,
  104, 105, 99, 95, 109, 97, 112, 32, 36, 49, 44, 36, 50, 10, 45, 101,
  108, 115, 101, 10, 45, 98, 32, 36, 50, 32, 45, 105, 115, 111, 112, 104,
  111, 116, 101, 115, 32, 36, 49, 10, 45, 101, 110, 100, 105, 102, 10, 103,
  105, 109, 112, 95, 105, 115, 111, 112, 104, 111, 116, 101, 115, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112,
  108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105,
  109, 112, 95, 105, 115, 111, 112, 104, 111, 116, 101, 115, 32, 36, 123, 94,
  48, 125, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 108, 97, 112,
  108, 97, 99, 105, 97, 110, 32, 58, 10, 45, 98, 32, 36, 49, 32, 45,
  108, 97, 112, 108, 97, 99, 105, 97, 110, 10, 45, 105, 102, 32, 36, 52,
  32, 45, 97, 98, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 99, 32,
  36, 50, 37, 44, 36, 51, 37, 10, 45, 105, 102, 32, 36, 53, 32, 45,
  110, 101, 103, 97, 116, 105, 118, 101, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 110, 32, 48, 44, 50, 53, 53, 10, 103, 105, 109, 112, 95, 108, 97,
  112, 108, 97, 99, 105, 97, 110, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 108, 97, 112,
  108, 97, 99, 105, 97, 110, 32, 36, 123, 94, 48, 125, 34, 44, 36, 45,
  49, 10, 95, 103, 105, 109, 112, 95, 108, 111, 99, 97, 108, 95, 111, 114,
  105, 101, 110, 116, 97, 116, 105, 111, 110, 32, 58, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115,
  112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91,
  48, 93, 10, 45, 98, 32, 36, 49, 37, 32, 45, 103, 114, 97, 100, 105,
  101, 110, 116, 95, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 32,
  50, 32, 45, 99, 111, 109, 112, 108, 101, 120, 50, 112, 111, 108, 97, 114,
  32, 45, 114, 109, 91, 48, 45, 45, 49, 58, 50, 93, 10, 45, 99, 32,
  36, 50, 37, 44, 36, 51, 37, 10, 45, 105, 102, 32, 36, 52, 32, 45,
  110, 101, 103, 97, 116, 105, 118, 101, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45,
  97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  103, 105, 109, 112, 95, 108, 111, 99, 97, 108, 95, 111, 114, 105, 101, 110,
  116, 97, 116, 105, 111, 110, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 95, 103, 105, 109, 112,
  95, 108, 111, 99, 97, 108, 95, 111, 114, 105, 101, 110, 116, 97, 116, 105,
  111, 110, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 34, 44,
  36, 53, 44, 49, 10, 103, 105, 109, 112, 95, 108, 111, 99, 97, 108, 95,
  111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112,
  95, 108, 111, 99, 97, 108, 95, 111, 114, 105, 101, 110, 116, 97, 116, 105,
  111, 110, 32, 36, 123, 94, 48, 125, 34, 44, 36, 45, 49, 10, 103, 105,
  109, 112, 95, 109, 111, 114, 112, 104, 111, 32, 58, 10, 45, 97, 112, 112,
  108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 95, 95,
  103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111, 32, 36, 123, 94, 48,
  125, 34, 44, 36, 53, 44, 36, 54, 10, 103, 105, 109, 112, 95, 109, 111,
  114, 112, 104, 111, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111,
  32, 36, 123, 94, 48, 125, 34, 44, 36, 45, 49, 10, 95, 95, 103, 105,
  109, 112, 95, 109, 111, 114, 112, 104, 111, 32, 58, 10, 45, 105, 102, 32,
  123, 36, 52, 61, 61, 49, 125, 32, 115, 117, 102, 61, 34, 95, 111, 99,
  116, 34, 32, 45, 101, 108, 105, 102, 32, 123, 36, 52, 61, 61, 48, 125,
  32, 115, 117, 102, 61, 34, 34, 32, 45, 101, 108, 115, 101, 32, 115, 117,
  102, 61, 34, 95, 99, 105, 114, 99, 34, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 125, 32, 45, 101, 114,
  111, 100, 101, 36, 115, 117, 102, 32, 36, 50, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 61, 61, 49, 125, 32, 45, 100, 105, 108, 97, 116, 101,
  36, 115, 117, 102, 32, 36, 50, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  49, 61, 61, 50, 125, 32, 45, 101, 114, 111, 100, 101, 36, 115, 117, 102,
  32, 36, 50, 32, 45, 100, 105, 108, 97, 116, 101, 36, 115, 117, 102, 32,
  36, 50, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 51, 125,
  32, 45, 100, 105, 108, 97, 116, 101, 36, 115, 117, 102, 32, 36, 50, 32,
  45, 101, 114, 111, 100, 101, 36, 115, 117, 102, 32, 36, 50, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 49, 61, 61, 52, 125, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 45, 101, 114, 111, 100, 101, 36, 115,
  117, 102, 32, 36, 50, 32, 45, 45, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 53, 125, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 45, 100, 105, 108, 97, 116,
  101, 36, 115, 117, 102, 32, 36, 50, 32, 45, 114, 118, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 45, 91, 45, 50, 44, 45, 49, 93, 32, 45, 109,
  118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 49, 61, 61, 54, 125, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 45, 101, 114, 111, 100, 101, 36, 115,
  117, 102, 32, 36, 50, 32, 45, 100, 105, 108, 97, 116, 101, 36, 115, 117,
  102, 91, 45, 49, 93, 32, 36, 50, 32, 45, 45, 91, 45, 50, 44, 45,
  49, 93, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111,
  110, 101, 10, 45, 101, 108, 115, 101, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 45, 100, 105, 108, 97, 116, 101, 36, 115, 117, 102,
  32, 36, 50, 32, 45, 101, 114, 111, 100, 101, 36, 115, 117, 102, 91, 45,
  49, 93, 32, 36, 50, 32, 45, 114, 118, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 45, 91, 45, 50, 44, 45, 49, 93, 32, 45, 109, 118, 91, 45,
  49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 36, 51, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105,
  116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 110, 101, 103, 97, 116,
  105, 118, 101, 91, 48, 93, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 10, 103,
  105, 109, 112, 95, 115, 101, 103, 109, 101, 110, 116, 95, 119, 97, 116, 101,
  114, 115, 104, 101, 100, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 98, 32, 36, 50, 32, 45,
  115, 101, 103, 109, 101, 110, 116, 95, 119, 97, 116, 101, 114, 115, 104, 101,
  100, 32, 36, 49, 34, 44, 36, 51, 44, 48, 10, 103, 105, 109, 112, 95,
  115, 101, 103, 109, 101, 110, 116, 95, 119, 97, 116, 101, 114, 115, 104, 101,
  100, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 115, 101, 103, 109, 101, 110, 116, 95, 119,
  97, 116, 101, 114, 115, 104, 101, 100, 32, 36, 123, 94, 48, 125, 34, 44,
  36, 45, 49, 10, 103, 105, 109, 112, 95, 115, 107, 101, 108, 101, 116, 111,
  110, 32, 58, 10, 45, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99,
  105, 116, 121, 10, 45, 105, 102, 32, 123, 33, 36, 52, 125, 32, 45, 110,
  111, 114, 109, 32, 45, 101, 110, 100, 105, 102, 10, 45, 98, 32, 36, 50,
  37, 10, 45, 105, 102, 32, 36, 49, 32, 45, 116, 104, 105, 110, 110, 105,
  110, 103, 32, 45, 101, 108, 115, 101, 32, 45, 115, 107, 101, 108, 101, 116,
  111, 110, 32, 36, 51, 37, 32, 45, 101, 110, 100, 105, 102, 10, 45, 42,
  32, 50, 53, 53, 10, 103, 105, 109, 112, 95, 115, 107, 101, 108, 101, 116,
  111, 110, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 115, 107, 101, 108, 101, 116, 111, 110,
  32, 36, 123, 94, 48, 125, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112,
  95, 116, 104, 105, 110, 95, 101, 100, 103, 101, 115, 32, 58, 10, 45, 98,
  32, 36, 49, 37, 32, 45, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110,
  111, 114, 109, 32, 45, 103, 101, 32, 36, 50, 37, 32, 45, 116, 104, 105,
  110, 110, 105, 110, 103, 10, 45, 105, 102, 32, 123, 33, 36, 51, 125, 32,
  45, 110, 101, 103, 97, 116, 105, 118, 101, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 110, 32, 48, 44, 50, 53, 53, 10, 103, 105, 109, 112, 95, 116,
  104, 105, 110, 95, 101, 100, 103, 101, 115, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 116,
  104, 105, 110, 95, 101, 100, 103, 101, 115, 32, 36, 123, 94, 48, 125, 34,
  44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109,
  95, 100, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 45, 110, 111, 114, 109,
  91, 45, 49, 93, 32, 91, 45, 49, 93, 32, 45, 102, 91, 45, 50, 93,
  32, 34, 36, 49, 34, 32, 45, 102, 91, 45, 49, 93, 32, 34, 36, 50,
  34, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 119,
  97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 51, 44,
  36, 52, 44, 36, 53, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10,
  103, 105, 109, 112, 95, 99, 105, 114, 99, 108, 101, 95, 116, 114, 97, 110,
  115, 102, 111, 114, 109, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 116, 111, 95, 114, 103,
  98, 97, 10, 114, 61, 123, 36, 53, 42, 115, 113, 114, 116, 40, 119, 94,
  50, 43, 104, 94, 50, 41, 125, 10, 45, 105, 102, 32, 123, 36, 54, 61,
  61, 48, 125, 32, 99, 111, 110, 100, 61, 34, 105, 40, 88, 44, 89, 44,
  122, 44, 99, 44, 36, 55, 44, 36, 56, 41, 34, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 54, 61, 61, 49, 125, 32, 99, 111, 110, 100, 61, 34,
  105, 102, 40, 78, 60, 34, 36, 114, 34, 44, 105, 40, 88, 44, 89, 44,
  122, 44, 99, 44, 36, 55, 44, 36, 56, 41, 44, 105, 41, 34, 10, 45,
  101, 108, 115, 101, 32, 99, 111, 110, 100, 61, 34, 105, 102, 40, 78, 62,
  34, 36, 114, 34, 44, 105, 40, 88, 44, 89, 44, 122, 44, 99, 44, 36,
  55, 44, 36, 56, 41, 44, 105, 41, 34, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 102, 32, 39, 85, 61, 120, 45, 119, 42, 36, 49, 59, 86, 61,
  121, 45, 104, 42, 36, 50, 59, 78, 61, 115, 113, 114, 116, 40, 85, 42,
  85, 43, 86, 42, 86, 41, 59, 78, 114, 61, 78, 45, 36, 114, 59, 88,
  61, 120, 43, 36, 51, 42, 78, 114, 42, 85, 47, 78, 59, 89, 61, 121,
  43, 36, 52, 42, 78, 114, 42, 86, 47, 78, 59, 36, 99, 111, 110, 100,
  39, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105,
  109, 112, 95, 99, 105, 114, 99, 108, 101, 95, 116, 114, 97, 110, 115, 102,
  111, 114, 109, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 99, 105, 114, 99, 108, 101, 95, 116, 114, 97, 110, 115,
  102, 111, 114, 109, 32, 36, 42, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 120, 48, 61, 123, 36, 49,
  42, 119, 125, 10, 121, 48, 61, 123, 36, 50, 42, 104, 125, 10, 114, 61,
  123, 36, 53, 42, 115, 113, 114, 116, 40, 119, 94, 50, 43, 104, 94, 50,
  41, 125, 10, 45, 105, 102, 32, 36, 57, 10, 45, 99, 105, 114, 99, 108,
  101, 32, 36, 120, 48, 44, 36, 121, 48, 44, 123, 36, 114, 45, 49, 125,
  44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 44,
  48, 44, 48, 44, 50, 53, 53, 10, 45, 99, 105, 114, 99, 108, 101, 32,
  36, 120, 48, 44, 36, 121, 48, 44, 123, 36, 114, 43, 49, 125, 44, 49,
  44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 44, 48, 44,
  48, 44, 50, 53, 53, 10, 45, 99, 105, 114, 99, 108, 101, 32, 36, 120,
  48, 44, 36, 121, 48, 44, 36, 114, 44, 49, 44, 48, 120, 70, 70, 70,
  70, 70, 70, 70, 70, 44, 48, 44, 50, 53, 53, 44, 48, 44, 50, 53,
  53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 101, 117, 99, 108, 105, 100,
  101, 97, 110, 50, 112, 111, 108, 97, 114, 32, 58, 10, 45, 105, 102, 32,
  36, 53, 32, 45, 112, 111, 108, 97, 114, 50, 101, 117, 99, 108, 105, 100,
  101, 97, 110, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 32,
  45, 101, 108, 115, 101, 32, 45, 101, 117, 99, 108, 105, 100, 101, 97, 110,
  50, 112, 111, 108, 97, 114, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44,
  36, 52, 32, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 102,
  108, 111, 119, 101, 114, 32, 58, 10, 45, 102, 108, 111, 119, 101, 114, 32,
  36, 49, 44, 36, 50, 44, 36, 51, 37, 44, 36, 52, 44, 36, 53, 44,
  36, 54, 44, 36, 55, 10, 103, 105, 109, 112, 95, 114, 111, 116, 111, 105,
  100, 111, 115, 99, 111, 112, 101, 32, 58, 10, 45, 114, 111, 116, 111, 105,
  100, 111, 115, 99, 111, 112, 101, 32, 123, 36, 49, 42, 49, 48, 48, 125,
  37, 44, 123, 36, 50, 42, 49, 48, 48, 125, 37, 44, 36, 51, 44, 36,
  52, 37, 44, 36, 53, 10, 103, 105, 109, 112, 95, 107, 97, 108, 101, 105,
  100, 111, 115, 99, 111, 112, 101, 32, 58, 10, 45, 115, 104, 105, 102, 116,
  32, 36, 51, 37, 44, 36, 52, 37, 44, 48, 44, 48, 44, 50, 32, 45,
  107, 97, 108, 101, 105, 100, 111, 115, 99, 111, 112, 101, 32, 36, 49, 44,
  36, 50, 44, 36, 53, 44, 36, 54, 44, 36, 55, 10, 103, 105, 109, 112,
  95, 115, 121, 109, 109, 101, 116, 114, 105, 122, 111, 115, 99, 111, 112, 101,
  32, 58, 10, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 36, 49, 10, 97, 110, 103, 61, 123, 36, 50, 43, 49,
  56, 48, 42, 36, 62, 47, 109, 97, 120, 40, 49, 44, 36, 49, 45, 49,
  41, 125, 10, 45, 115, 121, 109, 109, 101, 116, 114, 105, 122, 101, 32, 53,
  48, 37, 44, 53, 48, 37, 44, 36, 97, 110, 103, 44, 36, 51, 44, 48,
  44, 123, 105, 102, 40, 36, 52, 33, 61, 50, 44, 36, 52, 44, 36, 62,
  37, 50, 41, 125, 10, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95,
  119, 97, 114, 112, 95, 112, 101, 114, 115, 112, 101, 99, 116, 105, 118, 101,
  32, 58, 10, 45, 115, 104, 105, 102, 116, 32, 36, 54, 37, 44, 36, 55,
  37, 44, 48, 44, 48, 44, 50, 32, 45, 119, 97, 114, 112, 95, 112, 101,
  114, 115, 112, 101, 99, 116, 105, 118, 101, 32, 36, 49, 44, 36, 50, 44,
  36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 56, 10, 103, 105, 109, 112,
  95, 116, 114, 97, 110, 115, 102, 111, 114, 109, 95, 112, 111, 108, 97, 114,
  32, 58, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 125, 10, 45,
  116, 114, 97, 110, 115, 102, 111, 114, 109, 95, 112, 111, 108, 97, 114, 32,
  34, 36, 52, 34, 44, 34, 36, 53, 34, 44, 36, 50, 44, 36, 51, 44,
  36, 54, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125,
  10, 45, 116, 114, 97, 110, 115, 102, 111, 114, 109, 95, 112, 111, 108, 97,
  114, 32, 82, 45, 114, 44, 97, 44, 36, 50, 44, 36, 51, 44, 36, 54,
  10, 45, 101, 108, 115, 101, 10, 45, 116, 114, 97, 110, 115, 102, 111, 114,
  109, 95, 112, 111, 108, 97, 114, 32, 97, 42, 82, 47, 40, 50, 42, 112,
  105, 41, 44, 114, 42, 50, 42, 112, 105, 47, 82, 44, 36, 50, 44, 36,
  51, 44, 36, 54, 10, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112,
  95, 114, 101, 102, 108, 101, 99, 116, 32, 58, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45,
  49, 93, 32, 45, 45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 123, 49,
  48, 48, 45, 36, 49, 125, 37, 44, 49, 48, 48, 37, 32, 45, 109, 105,
  114, 114, 111, 114, 91, 45, 49, 93, 32, 121, 32, 45, 119, 97, 116, 101,
  114, 91, 45, 49, 93, 32, 36, 55, 44, 36, 56, 10, 45, 115, 91, 45,
  49, 93, 32, 99, 10, 45, 102, 91, 45, 52, 93, 32, 34, 40, 105, 42,
  40, 50, 53, 53, 45, 36, 54, 41, 32, 43, 32, 36, 54, 42, 36, 51,
  41, 47, 50, 53, 53, 34, 10, 45, 102, 91, 45, 51, 93, 32, 34, 40,
  105, 42, 40, 50, 53, 53, 45, 36, 54, 41, 32, 43, 32, 36, 54, 42,
  36, 52, 41, 47, 50, 53, 53, 34, 10, 45, 102, 91, 45, 50, 93, 32,
  34, 40, 105, 42, 40, 50, 53, 53, 45, 36, 54, 41, 32, 43, 32, 36,
  54, 42, 36, 53, 41, 47, 50, 53, 53, 34, 32, 45, 97, 91, 45, 52,
  45, 45, 49, 93, 32, 99, 10, 45, 42, 91, 45, 49, 93, 32, 39, 40,
  104, 94, 36, 50, 45, 121, 94, 36, 50, 41, 47, 104, 94, 36, 50, 39,
  32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 10, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 36, 49,
  49, 42, 36, 49, 50, 42, 40, 120, 47, 119, 45, 48, 46, 53, 41, 10,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 36, 49, 49, 42, 36, 49, 50, 42, 40, 121, 47, 104, 45, 48, 46,
  53, 41, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 44, 49, 44, 34, 36, 49, 48, 42, 40, 120, 47, 119, 45, 48, 46,
  53, 41, 32, 43, 32, 36, 57, 42, 40, 121, 47, 104, 45, 48, 46, 53,
  41, 32, 43, 32, 36, 49, 49, 34, 10, 45, 47, 91, 45, 51, 93, 32,
  91, 45, 49, 93, 32, 45, 43, 91, 45, 51, 93, 32, 48, 46, 53, 32,
  45, 42, 91, 45, 51, 93, 32, 64, 123, 45, 51, 44, 119, 125, 10, 45,
  47, 91, 45, 50, 44, 45, 49, 93, 32, 45, 43, 91, 45, 49, 93, 32,
  48, 46, 53, 32, 45, 42, 91, 45, 49, 93, 32, 123, 104, 125, 10, 45,
  97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 119, 97, 114, 112,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 49, 44, 48, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 109, 118, 91, 45, 49, 93, 32,
  48, 32, 45, 100, 111, 110, 101, 10, 45, 97, 117, 116, 111, 99, 114, 111,
  112, 32, 48, 44, 48, 44, 48, 44, 48, 10, 103, 105, 109, 112, 95, 109,
  97, 112, 95, 115, 112, 104, 101, 114, 101, 32, 58, 10, 45, 114, 111, 116,
  97, 116, 101, 32, 123, 36, 56, 42, 57, 48, 125, 10, 45, 105, 102, 32,
  36, 54, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 115,
  104, 105, 102, 116, 91, 45, 49, 93, 32, 53, 48, 37, 44, 48, 44, 48,
  44, 48, 44, 50, 32, 45, 45, 99, 111, 108, 117, 109, 110, 115, 91, 45,
  49, 93, 32, 123, 40, 49, 45, 36, 55, 47, 49, 48, 48, 41, 42, 119,
  47, 50, 125, 44, 123, 40, 49, 43, 36, 55, 47, 49, 48, 48, 41, 42,
  119, 47, 50, 125, 10, 49, 48, 48, 37, 32, 45, 103, 97, 117, 115, 115,
  105, 97, 110, 91, 45, 49, 93, 32, 123, 48, 46, 49, 42, 119, 125, 44,
  123, 104, 125, 44, 48, 32, 49, 48, 48, 37, 32, 49, 48, 48, 37, 32,
  45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 99, 32, 45, 114, 91, 45,
  49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 51,
  10, 45, 115, 109, 111, 111, 116, 104, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 36, 54, 44, 53, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 123, 40, 49,
  45, 36, 55, 47, 49, 48, 48, 41, 42, 64, 123, 45, 50, 44, 119, 125,
  47, 50, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 115, 104, 105,
  102, 116, 91, 45, 49, 93, 32, 45, 53, 48, 37, 44, 48, 44, 48, 44,
  48, 44, 50, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100,
  111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 115, 104, 105, 102,
  116, 32, 36, 53, 37, 44, 48, 44, 48, 44, 48, 44, 50, 32, 45, 116,
  111, 95, 114, 103, 98, 97, 10, 45, 105, 102, 32, 36, 57, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 45, 114, 111, 119, 115, 91,
  36, 62, 93, 32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 49, 44, 49,
  44, 49, 44, 52, 44, 50, 32, 82, 71, 66, 65, 36, 62, 61, 64, 45,
  49, 10, 45, 114, 91, 45, 49, 93, 32, 91, 36, 62, 93, 44, 91, 36,
  62, 93, 44, 49, 44, 52, 32, 45, 45, 91, 36, 62, 44, 45, 49, 93,
  10, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 109,
  97, 112, 95, 115, 112, 104, 101, 114, 101, 32, 36, 49, 44, 36, 50, 44,
  36, 51, 44, 36, 52, 44, 36, 49, 48, 44, 36, 49, 49, 10, 45, 105,
  102, 32, 36, 57, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10,
  40, 36, 123, 82, 71, 66, 65, 36, 62, 125, 41, 32, 45, 121, 91, 45,
  49, 93, 32, 99, 32, 45, 114, 91, 45, 49, 93, 32, 91, 36, 62, 93,
  44, 91, 36, 62, 93, 44, 49, 44, 52, 32, 45, 43, 91, 36, 62, 44,
  45, 49, 93, 10, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105, 102,
  10, 103, 105, 109, 112, 95, 109, 97, 112, 95, 115, 112, 104, 101, 114, 101,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 109, 97, 112, 95, 115, 112, 104, 101, 114, 101, 32, 123, 119, 125, 44,
  123, 104, 125, 44, 36, 123, 51, 45, 45, 49, 125, 10, 103, 105, 109, 112,
  95, 115, 121, 109, 109, 101, 116, 114, 105, 122, 101, 32, 58, 10, 45, 116,
  111, 95, 114, 103, 98, 97, 32, 45, 115, 121, 109, 109, 101, 116, 114, 105,
  122, 101, 32, 36, 49, 37, 44, 36, 50, 37, 44, 36, 51, 44, 36, 52,
  44, 36, 53, 44, 36, 54, 10, 103, 105, 109, 112, 95, 115, 121, 109, 109,
  101, 116, 114, 105, 122, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 121, 109, 109, 101, 116, 114, 105, 122,
  101, 32, 36, 42, 10, 116, 104, 101, 116, 97, 61, 123, 36, 51, 42, 112,
  105, 47, 49, 56, 48, 125, 32, 117, 61, 123, 99, 111, 115, 40, 36, 116,
  104, 101, 116, 97, 41, 125, 32, 118, 61, 123, 115, 105, 110, 40, 36, 116,
  104, 101, 116, 97, 41, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 120, 48, 61, 123, 119, 42, 36,
  49, 37, 125, 10, 121, 48, 61, 123, 104, 42, 36, 50, 37, 125, 10, 120,
  49, 61, 123, 36, 120, 48, 45, 109, 97, 120, 40, 119, 44, 104, 41, 42,
  36, 117, 125, 32, 121, 49, 61, 123, 36, 121, 48, 45, 109, 97, 120, 40,
  119, 44, 104, 41, 42, 36, 118, 125, 10, 120, 50, 61, 123, 36, 120, 48,
  43, 109, 97, 120, 40, 119, 44, 104, 41, 42, 36, 117, 125, 32, 121, 50,
  61, 123, 36, 121, 48, 43, 109, 97, 120, 40, 119, 44, 104, 41, 42, 36,
  118, 125, 10, 45, 108, 105, 110, 101, 32, 36, 120, 49, 44, 36, 121, 49,
  44, 36, 120, 50, 44, 36, 121, 50, 44, 49, 44, 48, 120, 48, 70, 48,
  70, 48, 70, 48, 70, 44, 48, 10, 45, 108, 105, 110, 101, 32, 36, 120,
  49, 44, 36, 121, 49, 44, 36, 120, 50, 44, 36, 121, 50, 44, 49, 44,
  48, 120, 70, 48, 70, 48, 70, 48, 70, 48, 44, 50, 53, 53, 10, 45,
  99, 105, 114, 99, 108, 101, 32, 36, 120, 48, 44, 36, 121, 48, 44, 51,
  44, 49, 44, 48, 44, 50, 53, 53, 44, 48, 44, 50, 53, 53, 10, 45,
  99, 105, 114, 99, 108, 101, 32, 36, 120, 48, 44, 36, 121, 48, 44, 51,
  44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 44,
  48, 44, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 103, 105, 109, 112, 95, 116, 101, 120, 116, 117, 114, 101,
  100, 95, 103, 108, 97, 115, 115, 32, 58, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 44, 49, 10, 45, 105, 102, 32, 36, 55,
  32, 45, 112, 108, 97, 115, 109, 97, 91, 45, 49, 93, 32, 49, 44, 49,
  44, 36, 55, 32, 45, 101, 108, 115, 101, 32, 45, 114, 97, 110, 100, 91,
  45, 49, 93, 32, 48, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  103, 91, 45, 49, 93, 32, 120, 121, 10, 45, 105, 102, 32, 36, 53, 10,
  45, 45, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 91,
  45, 51, 93, 32, 45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 98, 91,
  45, 49, 93, 32, 36, 54, 32, 45, 112, 111, 119, 91, 45, 49, 93, 32,
  45, 36, 53, 10, 45, 42, 91, 45, 51, 93, 32, 91, 45, 49, 93, 32,
  45, 42, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 98, 108, 117, 114, 95, 120, 121, 91, 45, 50, 44, 45, 49, 93,
  32, 36, 51, 44, 36, 52, 10, 45, 42, 91, 45, 50, 93, 32, 64, 123,
  45, 50, 44, 36, 49, 47, 109, 97, 120, 40, 97, 98, 115, 40, 105, 109,
  41, 44, 97, 98, 115, 40, 105, 77, 41, 41, 125, 10, 45, 42, 91, 45,
  49, 93, 32, 64, 123, 45, 49, 44, 36, 50, 47, 109, 97, 120, 40, 97,
  98, 115, 40, 105, 109, 41, 44, 97, 98, 115, 40, 105, 77, 41, 41, 125,
  10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 119, 97,
  114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 49, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 103, 105, 109, 112, 95, 116, 101, 120, 116, 117, 114, 101,
  100, 95, 103, 108, 97, 115, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 116, 101, 120,
  116, 117, 114, 101, 100, 95, 103, 108, 97, 115, 115, 32, 36, 42, 34, 44,
  36, 45, 49, 10, 103, 105, 109, 112, 95, 119, 105, 110, 100, 32, 58, 10,
  45, 105, 102, 32, 123, 33, 36, 53, 125, 32, 45, 110, 101, 103, 97, 116,
  105, 118, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 112, 112, 108,
  121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 119, 105, 110,
  100, 32, 36, 123, 49, 45, 52, 125, 34, 44, 36, 45, 50, 10, 45, 105,
  102, 32, 123, 33, 36, 53, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118,
  101, 32, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 119, 105,
  110, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 119, 105, 110, 100, 32, 36, 42, 34,
  44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 122, 111, 111, 109, 32, 58,
  10, 45, 105, 102, 32, 123, 36, 49, 60, 49, 125, 32, 45, 116, 111, 95,
  114, 103, 98, 97, 32, 45, 101, 110, 100, 105, 102, 10, 45, 122, 111, 111,
  109, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 48, 44, 36, 52, 10,
  103, 105, 109, 112, 95, 98, 108, 117, 114, 95, 97, 110, 103, 117, 108, 97,
  114, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 34, 45, 98, 108, 117, 114, 95, 97, 110, 103, 117, 108,
  97, 114, 32, 36, 49, 37, 44, 36, 50, 44, 36, 51, 32, 45, 115, 104,
  97, 114, 112, 101, 110, 32, 36, 52, 34, 44, 36, 53, 44, 36, 54, 10,
  103, 105, 109, 112, 95, 98, 108, 117, 114, 95, 100, 111, 102, 32, 58, 10,
  45, 95, 36, 48, 32, 36, 123, 49, 45, 56, 125, 44, 48, 10, 95, 103,
  105, 109, 112, 95, 98, 108, 117, 114, 95, 100, 111, 102, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 114, 109, 97, 120, 61, 123, 40, 119, 42, 119, 43, 104, 42, 104, 41,
  94, 48, 46, 53, 125, 32, 82, 61, 123, 36, 53, 42, 36, 114, 109, 97,
  120, 47, 49, 48, 48, 125, 32, 114, 61, 123, 36, 54, 42, 36, 114, 109,
  97, 120, 47, 49, 48, 48, 125, 10, 116, 61, 123, 36, 55, 42, 112, 105,
  47, 49, 56, 48, 125, 32, 117, 61, 123, 99, 111, 115, 40, 36, 116, 41,
  125, 32, 118, 61, 123, 115, 105, 110, 40, 36, 116, 41, 125, 10, 108, 49,
  61, 123, 40, 36, 114, 109, 97, 120, 47, 40, 49, 101, 45, 56, 43, 36,
  82, 41, 41, 94, 50, 125, 32, 108, 50, 61, 123, 40, 36, 114, 109, 97,
  120, 47, 40, 49, 101, 45, 56, 43, 36, 114, 41, 41, 94, 50, 125, 10,
  97, 61, 123, 36, 108, 49, 42, 40, 36, 117, 41, 94, 50, 43, 36, 108,
  50, 42, 40, 36, 118, 41, 94, 50, 125, 32, 98, 61, 123, 36, 117, 42,
  36, 118, 42, 40, 36, 108, 49, 45, 36, 108, 50, 41, 125, 32, 99, 61,
  123, 36, 108, 49, 42, 40, 36, 118, 41, 94, 50, 43, 36, 108, 50, 42,
  40, 36, 117, 41, 94, 50, 125, 10, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 44, 49, 44, 49, 44, 39, 88, 61, 40, 120, 45, 36, 51, 42, 119,
  47, 49, 48, 48, 41, 47, 109, 97, 120, 40, 119, 44, 104, 41, 59, 89,
  61, 40, 121, 45, 36, 52, 42, 104, 47, 49, 48, 48, 41, 47, 109, 97,
  120, 40, 119, 44, 104, 41, 59, 102, 61, 36, 97, 42, 88, 42, 88, 43,
  50, 42, 36, 98, 42, 88, 42, 89, 43, 36, 99, 42, 89, 42, 89, 59,
  118, 61, 101, 120, 112, 40, 45, 102, 47, 50, 46, 53, 41, 39, 10, 100,
  61, 123, 109, 105, 110, 40, 49, 45, 36, 56, 44, 48, 46, 57, 57, 41,
  47, 50, 125, 32, 45, 99, 91, 49, 93, 32, 36, 100, 44, 123, 49, 45,
  36, 100, 125, 32, 45, 45, 91, 49, 93, 32, 36, 100, 32, 45, 42, 91,
  49, 93, 32, 123, 40, 36, 49, 45, 49, 41, 47, 40, 49, 45, 50, 42,
  36, 100, 41, 125, 10, 45, 105, 102, 32, 36, 57, 10, 45, 45, 105, 115,
  111, 108, 105, 110, 101, 51, 100, 91, 49, 93, 32, 123, 36, 49, 45, 49,
  46, 53, 125, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 50,
  53, 53, 44, 50, 53, 53, 44, 48, 10, 45, 45, 105, 115, 111, 108, 105,
  110, 101, 51, 100, 91, 49, 93, 32, 123, 36, 49, 47, 50, 125, 32, 45,
  99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 50, 53, 53, 44, 49, 50,
  56, 44, 48, 10, 45, 45, 105, 115, 111, 108, 105, 110, 101, 51, 100, 91,
  49, 93, 32, 48, 46, 53, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49,
  93, 32, 50, 53, 53, 44, 48, 44, 48, 10, 45, 43, 51, 100, 91, 45,
  51, 45, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 111,
  117, 110, 100, 91, 49, 93, 32, 49, 10, 91, 48, 93, 44, 91, 48, 93,
  44, 49, 44, 91, 48, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36,
  49, 10, 45, 45, 61, 61, 91, 49, 93, 32, 123, 105, 102, 40, 36, 50,
  44, 36, 60, 44, 36, 62, 41, 125, 10, 45, 106, 91, 45, 50, 93, 32,
  91, 48, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45,
  49, 93, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 98, 91,
  48, 93, 32, 123, 40, 49, 43, 36, 62, 41, 47, 54, 48, 125, 37, 10,
  45, 114, 112, 114, 111, 103, 114, 101, 115, 115, 32, 123, 36, 62, 42, 49,
  48, 48, 47, 40, 36, 49, 45, 49, 41, 125, 10, 45, 100, 111, 110, 101,
  10, 45, 114, 109, 91, 48, 44, 49, 93, 10, 45, 105, 102, 32, 36, 57,
  10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 51, 32, 45,
  111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 48, 93,
  44, 48, 44, 48, 44, 48, 44, 49, 44, 49, 44, 48, 44, 48, 10, 45,
  114, 109, 91, 48, 93, 10, 45, 99, 105, 114, 99, 108, 101, 91, 45, 49,
  93, 32, 36, 51, 37, 44, 36, 52, 37, 44, 51, 44, 49, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 45, 99, 111, 109, 112,
  111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93,
  32, 43, 32, 45, 110, 101, 113, 91, 45, 49, 93, 32, 48, 32, 45, 100,
  105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51, 10, 45, 106, 91, 48,
  93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48,
  46, 53, 44, 91, 45, 49, 93, 44, 49, 32, 45, 114, 109, 91, 45, 50,
  44, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 98, 108, 117,
  114, 95, 100, 111, 102, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 95, 103, 105, 109, 112, 95, 98, 108, 117, 114, 95, 100, 111, 102, 32,
  36, 42, 10, 95, 103, 105, 109, 112, 95, 103, 97, 117, 115, 115, 105, 97,
  110, 95, 98, 108, 117, 114, 32, 58, 10, 45, 98, 32, 36, 49, 44, 36,
  52, 10, 45, 105, 102, 32, 123, 36, 50, 62, 48, 125, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 45, 49, 93, 32, 45,
  115, 32, 121, 32, 45, 98, 32, 36, 50, 44, 36, 52, 32, 45, 97, 32,
  121, 32, 45, 101, 110, 100, 108, 32, 45, 109, 118, 91, 45, 49, 93, 32,
  48, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 51, 62, 48, 125, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 45, 49, 93, 32, 45, 115, 32, 120,
  32, 45, 98, 32, 36, 51, 44, 36, 52, 32, 45, 97, 32, 120, 32, 45,
  101, 110, 100, 108, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45,
  100, 111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112,
  95, 103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 32, 58,
  10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 34, 45, 95, 103, 105, 109, 112, 95, 103, 97, 117, 115, 115, 105, 97,
  110, 95, 98, 108, 117, 114, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44,
  36, 52, 34, 44, 36, 53, 44, 36, 54, 10, 103, 105, 109, 112, 95, 103,
  97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109,
  112, 95, 103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 32,
  36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 103, 108, 111,
  119, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 34, 45, 103, 108, 111, 119, 32, 36, 49, 34, 44, 36,
  50, 44, 48, 10, 103, 105, 109, 112, 95, 103, 108, 111, 119, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112,
  108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105,
  109, 112, 95, 103, 108, 111, 119, 32, 36, 42, 34, 44, 36, 45, 49, 10,
  103, 105, 109, 112, 95, 98, 108, 117, 114, 95, 108, 105, 110, 101, 97, 114,
  32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101,
  108, 115, 32, 34, 45, 98, 108, 117, 114, 95, 108, 105, 110, 101, 97, 114,
  32, 36, 49, 44, 123, 36, 50, 42, 36, 49, 47, 49, 48, 48, 125, 44,
  36, 51, 44, 36, 53, 32, 45, 115, 104, 97, 114, 112, 101, 110, 32, 36,
  52, 34, 44, 36, 54, 44, 36, 55, 10, 103, 105, 109, 112, 95, 98, 108,
  117, 114, 95, 108, 105, 110, 101, 97, 114, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 98,
  108, 117, 114, 95, 108, 105, 110, 101, 97, 114, 32, 36, 42, 34, 44, 36,
  45, 49, 10, 103, 105, 109, 112, 95, 98, 108, 117, 114, 95, 114, 97, 100,
  105, 97, 108, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 34, 45, 98, 108, 117, 114, 95, 114, 97, 100,
  105, 97, 108, 32, 36, 49, 37, 44, 36, 50, 44, 36, 51, 32, 45, 115,
  104, 97, 114, 112, 101, 110, 32, 36, 52, 34, 44, 36, 53, 44, 36, 54,
  10, 103, 105, 109, 112, 95, 108, 111, 109, 111, 32, 58, 10, 45, 114, 101,
  109, 111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45,
  45, 103, 97, 117, 115, 115, 105, 97, 110, 32, 123, 49, 48, 48, 45, 36,
  49, 125, 37, 44, 123, 49, 48, 48, 45, 36, 49, 125, 37, 32, 45, 110,
  111, 114, 109, 97, 108, 105, 122, 101, 91, 45, 49, 93, 32, 48, 44, 49,
  32, 45, 42, 10, 45, 115, 32, 99, 10, 45, 102, 91, 48, 93, 32, 39,
  50, 53, 53, 42, 97, 116, 97, 110, 40, 40, 105, 45, 49, 50, 56, 41,
  47, 49, 50, 56, 41, 39, 10, 45, 102, 91, 49, 93, 32, 39, 50, 53,
  53, 42, 116, 97, 110, 40, 40, 105, 45, 49, 50, 56, 41, 47, 49, 50,
  56, 41, 39, 10, 45, 102, 91, 50, 93, 32, 39, 50, 53, 53, 42, 97,
  116, 97, 110, 40, 40, 105, 45, 49, 50, 56, 41, 47, 50, 53, 53, 41,
  39, 10, 45, 97, 32, 99, 10, 45, 115, 104, 97, 114, 112, 101, 110, 32,
  49, 10, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 32, 48, 44, 50,
  53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103,
  105, 109, 112, 95, 108, 111, 109, 111, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 108, 111,
  109, 111, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95,
  110, 111, 105, 115, 101, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 110, 111, 105, 115, 101, 32,
  36, 49, 44, 36, 50, 34, 44, 36, 51, 44, 36, 52, 10, 103, 105, 109,
  112, 95, 110, 111, 105, 115, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 110, 111, 105,
  115, 101, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95,
  115, 112, 114, 101, 97, 100, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 115, 112, 114, 101, 97,
  100, 32, 36, 49, 44, 36, 50, 34, 44, 36, 51, 44, 48, 10, 103, 105,
  109, 112, 95, 115, 112, 114, 101, 97, 100, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 115,
  112, 114, 101, 97, 100, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105,
  109, 112, 95, 115, 116, 114, 105, 112, 101, 115, 95, 121, 32, 58, 10, 45,
  97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34,
  45, 115, 116, 114, 105, 112, 101, 115, 95, 121, 32, 36, 49, 34, 44, 36,
  50, 44, 48, 10, 103, 105, 109, 112, 95, 115, 116, 114, 105, 112, 101, 115,
  95, 121, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 115, 116, 114, 105, 112, 101, 115, 95,
  121, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 56,
  98, 105, 116, 115, 32, 58, 10, 45, 114, 101, 109, 111, 118, 101, 95, 111,
  112, 97, 99, 105, 116, 121, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 61, 123, 119, 125, 32, 104,
  61, 123, 104, 125, 10, 45, 114, 32, 36, 49, 37, 44, 36, 49, 37, 44,
  49, 44, 49, 48, 48, 37, 44, 50, 10, 45, 45, 108, 117, 109, 105, 110,
  97, 110, 99, 101, 32, 45, 115, 104, 97, 114, 112, 101, 110, 91, 45, 49,
  93, 32, 36, 50, 32, 45, 111, 116, 115, 117, 91, 45, 49, 93, 32, 50,
  53, 54, 32, 45, 98, 108, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93,
  32, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97, 103, 101, 48, 10, 45,
  108, 91, 45, 49, 93, 32, 45, 115, 32, 99, 32, 45, 113, 117, 97, 110,
  116, 105, 122, 101, 32, 36, 51, 44, 49, 44, 49, 32, 45, 97, 32, 99,
  32, 45, 101, 110, 100, 108, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45,
  49, 93, 32, 36, 119, 44, 36, 104, 44, 49, 44, 49, 48, 48, 37, 44,
  49, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105,
  109, 112, 95, 56, 98, 105, 116, 115, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 56, 98,
  105, 116, 115, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112,
  95, 115, 104, 97, 100, 101, 95, 115, 116, 114, 105, 112, 101, 115, 32, 58,
  10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 34, 45, 115, 104, 97, 100, 101, 95, 115, 116, 114, 105, 112, 101, 115,
  32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 34, 44, 36, 53,
  44, 48, 10, 103, 105, 109, 112, 95, 115, 104, 97, 100, 101, 95, 115, 116,
  114, 105, 112, 101, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 115, 104, 97, 100, 101,
  95, 115, 116, 114, 105, 112, 101, 115, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 103, 105, 109, 112, 95, 119, 97, 116, 101, 114, 109, 97, 114, 107, 95,
  118, 105, 115, 105, 98, 108, 101, 32, 58, 10, 45, 119, 97, 116, 101, 114,
  109, 97, 114, 107, 95, 118, 105, 115, 105, 98, 108, 101, 32, 34, 36, 49,
  34, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 54, 44, 36, 53,
  10, 95, 103, 105, 109, 112, 95, 101, 113, 117, 97, 108, 105, 122, 101, 95,
  100, 101, 116, 97, 105, 108, 115, 32, 58, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 112, 108,
  105, 116, 95, 100, 101, 116, 97, 105, 108, 115, 32, 53, 44, 53, 37, 44,
  48, 46, 53, 37, 10, 45, 95, 95, 103, 105, 109, 112, 95, 101, 113, 117,
  97, 108, 105, 122, 101, 95, 100, 101, 116, 97, 105, 108, 115, 91, 49, 93,
  32, 36, 123, 49, 45, 52, 125, 44, 56, 10, 45, 95, 95, 103, 105, 109,
  112, 95, 101, 113, 117, 97, 108, 105, 122, 101, 95, 100, 101, 116, 97, 105,
  108, 115, 91, 50, 93, 32, 36, 123, 53, 45, 56, 125, 44, 52, 10, 45,
  95, 95, 103, 105, 109, 112, 95, 101, 113, 117, 97, 108, 105, 122, 101, 95,
  100, 101, 116, 97, 105, 108, 115, 91, 51, 93, 32, 36, 123, 57, 45, 49,
  50, 125, 44, 50, 10, 45, 95, 95, 103, 105, 109, 112, 95, 101, 113, 117,
  97, 108, 105, 122, 101, 95, 100, 101, 116, 97, 105, 108, 115, 91, 52, 93,
  32, 36, 123, 49, 51, 45, 49, 54, 125, 44, 49, 10, 45, 43, 32, 45,
  99, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 95, 95, 103, 105, 109, 112, 95, 101, 113, 117, 97, 108,
  105, 122, 101, 95, 100, 101, 116, 97, 105, 108, 115, 32, 58, 10, 45, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 32, 36, 49, 44, 49, 10, 45, 105,
  102, 32, 123, 36, 51, 61, 61, 48, 125, 32, 45, 98, 32, 123, 36, 50,
  42, 36, 53, 47, 50, 125, 10, 45, 101, 108, 105, 102, 32, 123, 36, 51,
  61, 61, 49, 125, 10, 45, 105, 102, 32, 123, 36, 50, 62, 48, 125, 10,
  109, 61, 123, 105, 109, 125, 32, 77, 61, 123, 105, 77, 125, 32, 45, 110,
  91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 105, 110, 116, 40, 36, 50, 47, 53, 41, 125, 32, 45,
  98, 105, 108, 97, 116, 101, 114, 97, 108, 32, 49, 53, 44, 123, 53, 42,
  36, 53, 125, 32, 45, 100, 111, 110, 101, 10, 45, 98, 105, 108, 97, 116,
  101, 114, 97, 108, 32, 49, 53, 44, 123, 40, 36, 50, 37, 53, 41, 42,
  36, 53, 125, 10, 45, 42, 91, 45, 49, 93, 32, 123, 40, 36, 77, 45,
  36, 109, 41, 47, 50, 53, 53, 125, 32, 45, 43, 91, 45, 49, 93, 32,
  36, 109, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101, 32,
  45, 115, 109, 111, 111, 116, 104, 32, 123, 36, 50, 42, 53, 48, 125, 44,
  48, 46, 50, 44, 48, 46, 56, 44, 36, 53, 44, 36, 53, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 42, 32, 123, 49, 48, 94, 36, 52, 125, 10,
  103, 105, 109, 112, 95, 101, 113, 117, 97, 108, 105, 122, 101, 95, 100, 101,
  116, 97, 105, 108, 115, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 103, 105, 109, 112, 95, 112,
  97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 32,
  92, 34, 45, 95, 103, 105, 109, 112, 95, 101, 113, 117, 97, 108, 105, 122,
  101, 95, 100, 101, 116, 97, 105, 108, 115, 32, 36, 123, 49, 45, 49, 54,
  125, 92, 34, 44, 36, 49, 55, 44, 36, 49, 56, 34, 44, 36, 49, 57,
  44, 48, 10, 103, 105, 109, 112, 95, 101, 113, 117, 97, 108, 105, 122, 101,
  95, 100, 101, 116, 97, 105, 108, 115, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 101, 113,
  117, 97, 108, 105, 122, 101, 95, 100, 101, 116, 97, 105, 108, 115, 32, 36,
  42, 34, 44, 36, 45, 49, 10, 95, 103, 105, 109, 112, 95, 102, 114, 101,
  97, 107, 121, 95, 100, 101, 116, 97, 105, 108, 115, 32, 58, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 36, 51, 10, 91, 45, 49, 93, 32,
  45, 45, 45, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 42, 91, 45,
  49, 93, 32, 45, 49, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49,
  32, 45, 98, 105, 108, 97, 116, 101, 114, 97, 108, 91, 45, 49, 93, 32,
  36, 50, 44, 123, 49, 46, 53, 42, 36, 50, 125, 32, 45, 100, 111, 110,
  101, 10, 45, 98, 108, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32,
  118, 105, 118, 105, 100, 108, 105, 103, 104, 116, 32, 45, 98, 108, 101, 110,
  100, 32, 111, 118, 101, 114, 108, 97, 121, 10, 45, 100, 111, 110, 101, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112,
  95, 102, 114, 101, 97, 107, 121, 95, 100, 101, 116, 97, 105, 108, 115, 32,
  58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 34, 45, 103, 105, 109, 112, 95, 112, 97, 114, 97, 108, 108, 101,
  108, 95, 111, 118, 101, 114, 108, 97, 112, 32, 92, 34, 45, 95, 103, 105,
  109, 112, 95, 102, 114, 101, 97, 107, 121, 95, 100, 101, 116, 97, 105, 108,
  115, 32, 36, 123, 49, 45, 51, 125, 92, 34, 44, 36, 53, 44, 36, 54,
  34, 44, 36, 52, 44, 48, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10,
  103, 105, 109, 112, 95, 102, 114, 101, 97, 107, 121, 95, 100, 101, 116, 97,
  105, 108, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 103, 105, 109, 112, 95, 102, 114, 101, 97, 107, 121, 95,
  100, 101, 116, 97, 105, 108, 115, 32, 36, 42, 34, 44, 36, 45, 49, 10,
  103, 105, 109, 112, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 108,
  111, 99, 97, 108, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104,
  97, 110, 110, 101, 108, 115, 32, 34, 45, 110, 111, 114, 109, 97, 108, 105,
  122, 101, 95, 108, 111, 99, 97, 108, 32, 36, 49, 44, 36, 50, 44, 36,
  51, 44, 36, 52, 44, 36, 53, 44, 48, 44, 50, 53, 53, 34, 44, 36,
  54, 44, 48, 10, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97, 108, 105,
  122, 101, 95, 108, 111, 99, 97, 108, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 110, 111,
  114, 109, 97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 32, 36, 42,
  34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 100, 101, 98, 108, 117,
  114, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 34, 45, 103, 105, 109, 112, 95, 112, 97, 114, 97, 108,
  108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 32, 92, 34, 45, 100,
  101, 98, 108, 117, 114, 32, 36, 123, 49, 45, 53, 125, 32, 45, 99, 32,
  48, 44, 50, 53, 53, 92, 34, 44, 36, 55, 44, 36, 56, 34, 44, 36,
  54, 44, 48, 10, 103, 105, 109, 112, 95, 100, 101, 98, 108, 117, 114, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  103, 105, 109, 112, 95, 100, 101, 98, 108, 117, 114, 32, 36, 42, 34, 44,
  36, 45, 49, 10, 103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112,
  95, 103, 111, 108, 100, 109, 101, 105, 110, 101, 108, 58, 10, 45, 103, 105,
  109, 112, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114,
  108, 97, 112, 32, 34, 45, 100, 101, 98, 108, 117, 114, 95, 103, 111, 108,
  100, 109, 101, 105, 110, 101, 108, 32, 36, 42, 32, 45, 105, 102, 32, 36,
  53, 32, 45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 115, 101,
  32, 45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102,
  34, 44, 36, 54, 44, 36, 55, 10, 103, 105, 109, 112, 95, 117, 110, 115,
  104, 97, 114, 112, 95, 103, 111, 108, 100, 109, 101, 105, 110, 101, 108, 95,
  112, 114, 101, 118, 105, 101, 119, 58, 10, 45, 103, 105, 109, 112, 95, 115,
  112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103,
  105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112, 95, 103, 111, 108, 100,
  109, 101, 105, 110, 101, 108, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103,
  105, 109, 112, 95, 115, 104, 97, 114, 112, 101, 110, 95, 105, 110, 118, 101,
  114, 115, 101, 100, 105, 102, 102, 32, 58, 10, 45, 97, 112, 112, 108, 121,
  95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 103, 105, 109, 112,
  95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97,
  112, 32, 92, 34, 45, 114, 101, 112, 101, 97, 116, 32, 36, 50, 32, 45,
  115, 104, 97, 114, 112, 101, 110, 32, 36, 49, 32, 45, 99, 32, 48, 44,
  50, 53, 53, 32, 45, 100, 111, 110, 101, 92, 34, 44, 36, 52, 44, 36,
  53, 34, 44, 36, 51, 44, 48, 10, 103, 105, 109, 112, 95, 115, 104, 97,
  114, 112, 101, 110, 95, 105, 110, 118, 101, 114, 115, 101, 100, 105, 102, 102,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 103, 105, 109, 112, 95, 115, 104, 97, 114, 112, 101, 110, 95, 105, 110,
  118, 101, 114, 115, 101, 100, 105, 102, 102, 32, 36, 42, 34, 44, 36, 45,
  49, 10, 103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112, 95, 111,
  99, 116, 97, 118, 101, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 103, 105, 109, 112, 95, 112,
  97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 32,
  92, 34, 45, 117, 110, 115, 104, 97, 114, 112, 95, 111, 99, 116, 97, 118,
  101, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 92, 34, 44,
  36, 54, 44, 36, 55, 34, 44, 36, 53, 44, 48, 10, 103, 105, 109, 112,
  95, 117, 110, 115, 104, 97, 114, 112, 95, 111, 99, 116, 97, 118, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112, 95, 111, 99, 116,
  97, 118, 101, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112,
  95, 117, 110, 115, 104, 97, 114, 112, 95, 114, 105, 99, 104, 97, 114, 100,
  115, 111, 110, 108, 117, 99, 121, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112,
  32, 34, 45, 100, 101, 98, 108, 117, 114, 95, 114, 105, 99, 104, 97, 114,
  100, 115, 111, 110, 108, 117, 99, 121, 32, 36, 42, 32, 45, 105, 102, 32,
  36, 52, 32, 45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 115,
  101, 32, 45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105,
  102, 34, 44, 36, 53, 44, 36, 54, 10, 103, 105, 109, 112, 95, 117, 110,
  115, 104, 97, 114, 112, 95, 114, 105, 99, 104, 97, 114, 100, 115, 111, 110,
  108, 117, 99, 121, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114,
  112, 95, 114, 105, 99, 104, 97, 114, 100, 115, 111, 110, 108, 117, 99, 121,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 115, 104,
  97, 114, 112, 101, 110, 95, 115, 104, 111, 99, 107, 32, 58, 10, 45, 97,
  112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45,
  103, 105, 109, 112, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118,
  101, 114, 108, 97, 112, 32, 92, 34, 45, 114, 101, 112, 101, 97, 116, 32,
  36, 53, 32, 45, 115, 104, 97, 114, 112, 101, 110, 32, 36, 49, 44, 36,
  50, 44, 36, 51, 44, 36, 52, 32, 45, 99, 32, 48, 44, 50, 53, 53,
  32, 45, 100, 111, 110, 101, 92, 34, 44, 36, 55, 44, 36, 56, 34, 44,
  36, 54, 44, 48, 10, 103, 105, 109, 112, 95, 115, 104, 97, 114, 112, 101,
  110, 95, 115, 104, 111, 99, 107, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 115, 104, 97,
  114, 112, 101, 110, 95, 115, 104, 111, 99, 107, 32, 36, 42, 34, 44, 36,
  45, 49, 10, 95, 103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112,
  32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 56, 10, 45, 105, 102, 32, 123, 36, 49,
  61, 61, 48, 125, 32, 45, 45, 98, 91, 45, 49, 93, 32, 36, 50, 32,
  45, 101, 108, 115, 101, 32, 45, 45, 98, 105, 108, 97, 116, 101, 114, 97,
  108, 91, 45, 49, 93, 32, 36, 50, 44, 36, 51, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 45, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45,
  42, 91, 45, 49, 93, 32, 45, 36, 52, 10, 45, 45, 110, 111, 114, 109,
  91, 45, 49, 93, 32, 45, 103, 101, 91, 45, 49, 93, 32, 36, 53, 37,
  32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 42, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 105, 102, 32, 36, 57, 32, 45, 42,
  91, 45, 49, 93, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  45, 99, 91, 45, 49, 93, 32, 48, 44, 49, 48, 48, 37, 32, 45, 99,
  91, 45, 50, 93, 32, 45, 49, 48, 48, 37, 44, 48, 32, 45, 42, 91,
  45, 50, 93, 32, 36, 54, 32, 45, 42, 91, 45, 49, 93, 32, 36, 55,
  32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 43, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 10, 45, 100, 111, 110, 101, 32, 45, 109, 118, 91, 45, 49, 93, 32,
  48, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 117, 110, 115,
  104, 97, 114, 112, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104,
  97, 110, 110, 101, 108, 115, 32, 34, 45, 95, 103, 105, 109, 112, 95, 117,
  110, 115, 104, 97, 114, 112, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44,
  36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 44, 36,
  57, 34, 44, 36, 49, 48, 44, 48, 10, 103, 105, 109, 112, 95, 117, 110,
  115, 104, 97, 114, 112, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 117, 110, 115, 104, 97,
  114, 112, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 100, 101, 116, 97, 105, 108, 115, 32, 58, 10,
  45, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 10,
  45, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 60, 93, 10, 45, 45,
  114, 111, 119, 115, 32, 48, 32, 118, 108, 105, 115, 116, 61, 64, 123, 45,
  49, 44, 116, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 109, 97, 103,
  105, 99, 107, 61, 123, 97, 114, 103, 40, 49, 44, 36, 118, 108, 105, 115,
  116, 41, 125, 32, 110, 98, 95, 105, 109, 103, 115, 61, 123, 49, 43, 97,
  114, 103, 40, 50, 44, 36, 118, 108, 105, 115, 116, 41, 125, 32, 109, 111,
  100, 101, 61, 123, 97, 114, 103, 40, 51, 44, 36, 118, 108, 105, 115, 116,
  41, 125, 10, 45, 105, 102, 32, 123, 36, 109, 97, 103, 105, 99, 107, 33,
  61, 55, 49, 55, 55, 55, 51, 54, 55, 124, 124, 36, 110, 98, 95, 105,
  109, 103, 115, 60, 50, 124, 124, 36, 109, 111, 100, 101, 60, 48, 124, 124,
  36, 109, 111, 100, 101, 62, 50, 125, 32, 45, 101, 114, 114, 111, 114, 32,
  34, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  109, 111, 100, 101, 61, 61, 48, 125, 32, 45, 115, 32, 120, 44, 36, 110,
  98, 95, 105, 109, 103, 115, 32, 45, 101, 108, 105, 102, 32, 123, 36, 109,
  111, 100, 101, 61, 61, 49, 125, 32, 45, 115, 32, 121, 44, 36, 110, 98,
  95, 105, 109, 103, 115, 10, 45, 101, 108, 115, 101, 32, 78, 61, 123, 105,
  110, 116, 40, 115, 113, 114, 116, 40, 36, 110, 98, 95, 105, 109, 103, 115,
  41, 41, 125, 32, 77, 61, 123, 114, 111, 117, 110, 100, 40, 36, 110, 98,
  95, 105, 109, 103, 115, 47, 36, 78, 44, 49, 44, 49, 41, 125, 32, 45,
  115, 112, 108, 105, 116, 95, 116, 105, 108, 101, 115, 32, 36, 77, 44, 36,
  78, 32, 45, 107, 91, 48, 45, 123, 36, 110, 98, 95, 105, 109, 103, 115,
  45, 49, 125, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91,
  48, 93, 32, 45, 108, 91, 94, 48, 93, 32, 45, 45, 32, 49, 50, 56,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 42, 91, 36,
  62, 93, 32, 123, 97, 114, 103, 40, 36, 62, 43, 52, 44, 36, 118, 108,
  105, 115, 116, 41, 47, 49, 50, 55, 125, 32, 45, 100, 111, 110, 101, 32,
  45, 101, 110, 100, 108, 32, 45, 43, 32, 45, 99, 32, 48, 44, 50, 53,
  53, 10, 45, 111, 110, 102, 97, 105, 108, 32, 45, 101, 114, 114, 111, 114,
  32, 34, 67, 97, 110, 110, 111, 116, 32, 114, 101, 99, 111, 109, 112, 111,
  115, 101, 32, 105, 109, 97, 103, 101, 44, 32, 100, 101, 99, 111, 109, 112,
  111, 115, 101, 32, 105, 116, 32, 98, 101, 102, 111, 114, 101, 32, 116, 114,
  121, 105, 110, 103, 32, 116, 111, 32, 114, 101, 99, 111, 109, 112, 111, 115,
  101, 32, 105, 116, 32, 33, 34, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 45, 101, 108, 115, 101, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 60, 93, 10, 45, 45, 114, 111,
  119, 115, 32, 48, 32, 118, 108, 105, 115, 116, 61, 64, 123, 45, 49, 44,
  116, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 109, 97, 103, 105, 99,
  107, 61, 123, 97, 114, 103, 40, 49, 44, 36, 118, 108, 105, 115, 116, 41,
  125, 32, 110, 98, 95, 105, 109, 103, 115, 61, 123, 49, 43, 97, 114, 103,
  40, 50, 44, 36, 118, 108, 105, 115, 116, 41, 125, 32, 109, 111, 100, 101,
  61, 123, 97, 114, 103, 40, 51, 44, 36, 118, 108, 105, 115, 116, 41, 125,
  10, 45, 105, 102, 32, 123, 36, 109, 97, 103, 105, 99, 107, 33, 61, 55,
  49, 55, 55, 55, 51, 54, 55, 124, 124, 36, 110, 98, 95, 105, 109, 103,
  115, 60, 50, 124, 124, 36, 109, 111, 100, 101, 60, 48, 124, 124, 36, 109,
  111, 100, 101, 62, 50, 125, 32, 45, 101, 114, 114, 111, 114, 32, 34, 34,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 108, 10, 45, 105, 102, 32,
  123, 36, 109, 111, 100, 101, 61, 61, 48, 125, 32, 45, 115, 32, 120, 44,
  36, 110, 98, 95, 105, 109, 103, 115, 32, 45, 101, 108, 105, 102, 32, 123,
  36, 109, 111, 100, 101, 61, 61, 49, 125, 32, 45, 115, 32, 121, 44, 36,
  110, 98, 95, 105, 109, 103, 115, 10, 45, 101, 108, 115, 101, 32, 78, 61,
  123, 105, 110, 116, 40, 115, 113, 114, 116, 40, 36, 110, 98, 95, 105, 109,
  103, 115, 41, 41, 125, 32, 77, 61, 123, 114, 111, 117, 110, 100, 40, 36,
  110, 98, 95, 105, 109, 103, 115, 47, 36, 78, 44, 49, 44, 49, 41, 125,
  32, 45, 115, 112, 108, 105, 116, 95, 116, 105, 108, 101, 115, 32, 36, 77,
  44, 36, 78, 32, 45, 107, 91, 48, 45, 123, 36, 110, 98, 95, 105, 109,
  103, 115, 45, 49, 125, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114,
  109, 91, 48, 93, 32, 45, 108, 91, 94, 48, 93, 32, 45, 45, 32, 49,
  50, 56, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 42,
  91, 36, 62, 93, 32, 123, 97, 114, 103, 40, 36, 62, 43, 52, 44, 36,
  118, 108, 105, 115, 116, 41, 47, 49, 50, 55, 125, 32, 45, 100, 111, 110,
  101, 32, 45, 101, 110, 100, 108, 32, 45, 43, 32, 45, 99, 32, 48, 44,
  50, 53, 53, 10, 45, 101, 110, 100, 108, 10, 45, 106, 91, 48, 93, 32,
  91, 49, 93, 32, 45, 114, 109, 91, 49, 93, 32, 40, 123, 39, 36, 118,
  108, 105, 115, 116, 39, 125, 44, 48, 41, 32, 45, 106, 91, 48, 93, 32,
  91, 49, 93, 32, 45, 114, 109, 91, 49, 93, 10, 45, 111, 110, 102, 97,
  105, 108, 10, 45, 45, 115, 112, 108, 105, 116, 95, 100, 101, 116, 97, 105,
  108, 115, 32, 36, 50, 44, 36, 51, 44, 36, 52, 10, 118, 108, 105, 115,
  116, 61, 55, 49, 55, 55, 55, 51, 54, 55, 44, 36, 50, 44, 36, 53,
  10, 45, 108, 91, 50, 45, 45, 49, 93, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 10, 102, 97, 99, 116, 61, 123, 114, 111, 117, 110, 100,
  40, 109, 97, 120, 40, 97, 98, 115, 40, 105, 109, 41, 44, 97, 98, 115,
  40, 105, 77, 41, 41, 44, 48, 46, 48, 49, 41, 125, 32, 118, 108, 105,
  115, 116, 61, 36, 118, 108, 105, 115, 116, 44, 36, 102, 97, 99, 116, 32,
  45, 42, 91, 36, 62, 93, 32, 123, 49, 50, 55, 47, 36, 102, 97, 99,
  116, 125, 10, 45, 100, 111, 110, 101, 32, 45, 43, 32, 49, 50, 56, 32,
  45, 101, 110, 100, 108, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45,
  105, 102, 32, 123, 36, 53, 61, 61, 48, 125, 32, 45, 97, 32, 120, 32,
  45, 101, 108, 105, 102, 32, 123, 36, 53, 61, 61, 49, 125, 32, 45, 97,
  32, 121, 32, 45, 101, 108, 115, 101, 32, 45, 97, 112, 112, 101, 110, 100,
  95, 116, 105, 108, 101, 115, 32, 44, 32, 45, 101, 110, 100, 105, 102, 10,
  40, 123, 39, 36, 118, 108, 105, 115, 116, 39, 125, 44, 48, 41, 32, 45,
  106, 91, 48, 93, 32, 91, 49, 93, 32, 45, 114, 109, 91, 49, 93, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100,
  105, 102, 10, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 100, 101,
  116, 97, 105, 108, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 10,
  45, 105, 102, 32, 36, 49, 32, 45, 103, 105, 109, 112, 95, 110, 111, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 44, 10, 45, 101, 108, 115, 101, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 45, 115, 112, 108, 105, 116, 95, 100, 101, 116, 97, 105, 108,
  115, 32, 36, 50, 44, 36, 51, 44, 36, 52, 32, 45, 110, 91, 50, 45,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36,
  54, 61, 61, 48, 125, 32, 45, 107, 91, 49, 93, 32, 45, 101, 108, 105,
  102, 32, 123, 36, 54, 61, 61, 49, 125, 32, 45, 107, 91, 50, 45, 45,
  49, 93, 32, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115,
  32, 44, 32, 45, 101, 108, 105, 102, 32, 123, 36, 54, 61, 61, 50, 125,
  32, 45, 107, 91, 45, 49, 93, 32, 45, 101, 108, 115, 101, 32, 45, 97,
  112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 32, 44, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 109, 97, 112,
  95, 116, 111, 110, 101, 115, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 109, 97, 112, 95, 116,
  111, 110, 101, 115, 32, 36, 123, 49, 45, 52, 125, 34, 44, 36, 53, 44,
  48, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10, 103, 105, 109, 112, 95,
  109, 97, 112, 95, 116, 111, 110, 101, 115, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 109,
  97, 112, 95, 116, 111, 110, 101, 115, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 103, 105, 109, 112, 95, 109, 97, 112, 95, 116, 111, 110, 101, 115, 95,
  102, 97, 115, 116, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104,
  97, 110, 110, 101, 108, 115, 32, 34, 45, 109, 97, 112, 95, 116, 111, 110,
  101, 115, 95, 102, 97, 115, 116, 32, 36, 49, 44, 36, 50, 34, 44, 36,
  51, 44, 48, 10, 103, 105, 109, 112, 95, 109, 97, 112, 95, 116, 111, 110,
  101, 115, 95, 102, 97, 115, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 109, 97, 112,
  95, 116, 111, 110, 101, 115, 95, 102, 97, 115, 116, 32, 36, 123, 94, 48,
  125, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 101, 109, 117, 108,
  97, 116, 101, 95, 102, 105, 108, 109, 95, 98, 119, 32, 58, 10, 45, 95,
  103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108,
  109, 32, 36, 49, 44, 64, 123, 45, 97, 114, 103, 92, 32, 36, 49, 44,
  64, 123, 45, 95, 36, 48, 125, 125, 44, 36, 123, 50, 45, 45, 49, 125,
  10, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102,
  105, 108, 109, 95, 98, 119, 32, 58, 10, 45, 117, 32, 97, 103, 102, 97,
  95, 97, 112, 120, 95, 49, 48, 48, 44, 97, 103, 102, 97, 95, 97, 112,
  120, 95, 50, 53, 44, 102, 117, 106, 105, 95, 110, 101, 111, 112, 97, 110,
  95, 49, 54, 48, 48, 44, 102, 117, 106, 105, 95, 110, 101, 111, 112, 97,
  110, 95, 97, 99, 114, 111, 115, 95, 49, 48, 48, 44, 105, 108, 102, 111,
  114, 100, 95, 100, 101, 108, 116, 97, 95, 49, 48, 48, 44, 105, 108, 102,
  111, 114, 100, 95, 100, 101, 108, 116, 97, 95, 51, 50, 48, 48, 44, 105,
  108, 102, 111, 114, 100, 95, 100, 101, 108, 116, 97, 95, 52, 48, 48, 44,
  105, 108, 102, 111, 114, 100, 95, 102, 112, 52, 95, 112, 108, 117, 115, 95,
  49, 50, 53, 44, 92, 10, 105, 108, 102, 111, 114, 100, 95, 104, 112, 53,
  95, 112, 108, 117, 115, 95, 52, 48, 48, 44, 105, 108, 102, 111, 114, 100,
  95, 104, 112, 115, 95, 56, 48, 48, 44, 105, 108, 102, 111, 114, 100, 95,
  112, 97, 110, 95, 102, 95, 112, 108, 117, 115, 95, 53, 48, 44, 105, 108,
  102, 111, 114, 100, 95, 120, 112, 50, 44, 107, 111, 100, 97, 107, 95, 98,
  119, 95, 52, 48, 48, 95, 99, 110, 44, 107, 111, 100, 97, 107, 95, 104,
  105, 101, 95, 40, 104, 115, 95, 105, 110, 102, 114, 97, 41, 44, 107, 111,
  100, 97, 107, 95, 116, 45, 109, 97, 120, 95, 49, 48, 48, 44, 107, 111,
  100, 97, 107, 95, 116, 45, 109, 97, 120, 95, 51, 50, 48, 48, 44, 92,
  10, 107, 111, 100, 97, 107, 95, 116, 45, 109, 97, 120, 95, 52, 48, 48,
  44, 107, 111, 100, 97, 107, 95, 116, 114, 105, 45, 120, 95, 52, 48, 48,
  44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 54, 52, 44, 112, 111,
  108, 97, 114, 111, 105, 100, 95, 54, 54, 55, 44, 112, 111, 108, 97, 114,
  111, 105, 100, 95, 54, 55, 50, 44, 114, 111, 108, 108, 101, 105, 95, 105,
  114, 95, 52, 48, 48, 44, 114, 111, 108, 108, 101, 105, 95, 111, 114, 116,
  104, 111, 95, 50, 53, 44, 114, 111, 108, 108, 101, 105, 95, 114, 101, 116,
  114, 111, 95, 49, 48, 48, 95, 116, 111, 110, 97, 108, 44, 114, 111, 108,
  108, 101, 105, 95, 114, 101, 116, 114, 111, 95, 56, 48, 115, 10, 103, 105,
  109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95,
  98, 119, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95,
  102, 105, 108, 109, 95, 98, 119, 32, 36, 42, 34, 44, 36, 45, 49, 10,
  103, 105, 109, 112, 95, 103, 114, 97, 105, 110, 32, 58, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45,
  97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34,
  45, 95, 103, 105, 109, 112, 95, 103, 114, 97, 105, 110, 32, 36, 123, 49,
  45, 49, 51, 125, 34, 44, 36, 52, 44, 48, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 95, 103, 105, 109, 112, 95, 103, 114, 97,
  105, 110, 32, 58, 10, 45, 105, 102, 32, 123, 33, 36, 49, 125, 32, 45,
  114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 115, 61,
  123, 115, 125, 32, 45, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 10,
  45, 105, 102, 32, 36, 53, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 49, 44, 36, 115, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93,
  32, 49, 44, 36, 51, 32, 45, 98, 91, 45, 49, 93, 32, 36, 54, 32,
  45, 42, 91, 45, 49, 93, 32, 123, 40, 49, 45, 36, 55, 41, 47, 109,
  97, 120, 40, 97, 98, 115, 40, 105, 109, 41, 44, 97, 98, 115, 40, 105,
  77, 41, 41, 125, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 49, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 49, 44,
  36, 51, 32, 45, 98, 91, 45, 49, 93, 32, 36, 54, 32, 45, 42, 91,
  45, 49, 93, 32, 123, 36, 55, 47, 109, 97, 120, 40, 97, 98, 115, 40,
  105, 109, 41, 44, 97, 98, 115, 40, 105, 77, 41, 41, 125, 10, 45, 43,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 45, 116, 50, 91, 49, 93, 32,
  48, 44, 56, 53, 32, 45, 98, 91, 45, 49, 93, 32, 36, 50, 32, 45,
  110, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 42, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 36, 53, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 56, 10, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 44, 36, 115, 32, 45, 110, 111, 105, 115,
  101, 91, 45, 49, 93, 32, 49, 44, 36, 51, 32, 45, 98, 91, 45, 49,
  93, 32, 36, 57, 32, 45, 42, 91, 45, 49, 93, 32, 123, 40, 49, 45,
  36, 49, 48, 41, 47, 109, 97, 120, 40, 97, 98, 115, 40, 105, 109, 41,
  44, 97, 98, 115, 40, 105, 77, 41, 41, 125, 10, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 44, 49, 44, 49, 32, 45, 110, 111, 105, 115, 101, 91,
  45, 49, 93, 32, 49, 44, 36, 51, 32, 45, 98, 91, 45, 49, 93, 32,
  36, 57, 32, 45, 42, 91, 45, 49, 93, 32, 123, 36, 49, 48, 47, 109,
  97, 120, 40, 97, 98, 115, 40, 105, 109, 41, 44, 97, 98, 115, 40, 105,
  77, 41, 41, 125, 10, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  45, 116, 50, 91, 49, 93, 32, 56, 54, 44, 49, 54, 57, 32, 45, 98,
  91, 45, 49, 93, 32, 36, 50, 32, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 49, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 42, 91,
  45, 49, 93, 32, 36, 56, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 36, 49, 49, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  49, 44, 36, 115, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32,
  49, 44, 36, 51, 32, 45, 98, 91, 45, 49, 93, 32, 36, 49, 50, 32,
  45, 42, 91, 45, 49, 93, 32, 123, 40, 49, 45, 36, 49, 51, 41, 47,
  109, 97, 120, 40, 97, 98, 115, 40, 105, 109, 41, 44, 97, 98, 115, 40,
  105, 77, 41, 41, 125, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  49, 44, 49, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 49,
  44, 36, 51, 32, 45, 98, 91, 45, 49, 93, 32, 36, 49, 50, 32, 45,
  42, 91, 45, 49, 93, 32, 123, 36, 49, 51, 47, 109, 97, 120, 40, 97,
  98, 115, 40, 105, 109, 41, 44, 97, 98, 115, 40, 105, 77, 41, 41, 125,
  10, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 45, 116, 50, 91,
  49, 93, 32, 49, 55, 48, 44, 50, 53, 54, 32, 45, 98, 91, 45, 49,
  93, 32, 36, 50, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 49, 32,
  45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93,
  32, 36, 49, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91,
  49, 93, 32, 45, 43, 91, 45, 51, 45, 45, 49, 93, 32, 45, 110, 91,
  45, 49, 93, 32, 45, 36, 49, 44, 36, 49, 32, 45, 43, 32, 45, 99,
  32, 48, 44, 50, 53, 53, 10, 103, 105, 109, 112, 95, 103, 114, 97, 105,
  110, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 103, 114, 97, 105, 110, 32, 36, 42, 34,
  44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116,
  101, 95, 102, 105, 108, 109, 95, 105, 110, 115, 116, 97, 110, 116, 95, 99,
  111, 110, 115, 117, 109, 101, 114, 32, 58, 10, 45, 95, 103, 105, 109, 112,
  95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 32, 36, 49,
  44, 64, 123, 45, 97, 114, 103, 92, 32, 36, 49, 44, 64, 123, 45, 95,
  36, 48, 125, 125, 44, 36, 123, 50, 45, 45, 49, 125, 10, 95, 103, 105,
  109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95,
  105, 110, 115, 116, 97, 110, 116, 95, 99, 111, 110, 115, 117, 109, 101, 114,
  32, 58, 10, 45, 117, 32, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112,
  120, 45, 49, 48, 48, 117, 118, 43, 95, 99, 111, 108, 100, 95, 45, 45,
  44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 49, 48, 48,
  117, 118, 43, 95, 99, 111, 108, 100, 95, 45, 44, 112, 111, 108, 97, 114,
  111, 105, 100, 95, 112, 120, 45, 49, 48, 48, 117, 118, 43, 95, 99, 111,
  108, 100, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 49,
  48, 48, 117, 118, 43, 95, 99, 111, 108, 100, 95, 43, 44, 112, 111, 108,
  97, 114, 111, 105, 100, 95, 112, 120, 45, 49, 48, 48, 117, 118, 43, 95,
  99, 111, 108, 100, 95, 43, 43, 44, 112, 111, 108, 97, 114, 111, 105, 100,
  95, 112, 120, 45, 49, 48, 48, 117, 118, 43, 95, 99, 111, 108, 100, 95,
  43, 43, 43, 44, 92, 10, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112,
  120, 45, 49, 48, 48, 117, 118, 43, 95, 119, 97, 114, 109, 95, 45, 45,
  44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 49, 48, 48,
  117, 118, 43, 95, 119, 97, 114, 109, 95, 45, 44, 112, 111, 108, 97, 114,
  111, 105, 100, 95, 112, 120, 45, 49, 48, 48, 117, 118, 43, 95, 119, 97,
  114, 109, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 49,
  48, 48, 117, 118, 43, 95, 119, 97, 114, 109, 95, 43, 44, 112, 111, 108,
  97, 114, 111, 105, 100, 95, 112, 120, 45, 49, 48, 48, 117, 118, 43, 95,
  119, 97, 114, 109, 95, 43, 43, 44, 112, 111, 108, 97, 114, 111, 105, 100,
  95, 112, 120, 45, 49, 48, 48, 117, 118, 43, 95, 119, 97, 114, 109, 95,
  43, 43, 43, 44, 92, 10, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112,
  120, 45, 54, 56, 48, 95, 45, 45, 44, 112, 111, 108, 97, 114, 111, 105,
  100, 95, 112, 120, 45, 54, 56, 48, 95, 45, 44, 112, 111, 108, 97, 114,
  111, 105, 100, 95, 112, 120, 45, 54, 56, 48, 44, 112, 111, 108, 97, 114,
  111, 105, 100, 95, 112, 120, 45, 54, 56, 48, 95, 43, 44, 112, 111, 108,
  97, 114, 111, 105, 100, 95, 112, 120, 45, 54, 56, 48, 95, 43, 43, 44,
  92, 10, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 54, 56,
  48, 95, 99, 111, 108, 100, 95, 45, 45, 44, 112, 111, 108, 97, 114, 111,
  105, 100, 95, 112, 120, 45, 54, 56, 48, 95, 99, 111, 108, 100, 95, 45,
  44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 54, 56, 48,
  95, 99, 111, 108, 100, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112,
  120, 45, 54, 56, 48, 95, 99, 111, 108, 100, 95, 43, 44, 112, 111, 108,
  97, 114, 111, 105, 100, 95, 112, 120, 45, 54, 56, 48, 95, 99, 111, 108,
  100, 95, 43, 43, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120,
  45, 54, 56, 48, 95, 99, 111, 108, 100, 95, 43, 43, 95, 97, 108, 116,
  44, 92, 10, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 54,
  56, 48, 95, 119, 97, 114, 109, 95, 45, 45, 44, 112, 111, 108, 97, 114,
  111, 105, 100, 95, 112, 120, 45, 54, 56, 48, 95, 119, 97, 114, 109, 95,
  45, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 54, 56,
  48, 95, 119, 97, 114, 109, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95,
  112, 120, 45, 54, 56, 48, 95, 119, 97, 114, 109, 95, 43, 44, 112, 111,
  108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 54, 56, 48, 95, 119, 97,
  114, 109, 95, 43, 43, 44, 92, 10, 112, 111, 108, 97, 114, 111, 105, 100,
  95, 112, 120, 45, 55, 48, 95, 45, 45, 44, 112, 111, 108, 97, 114, 111,
  105, 100, 95, 112, 120, 45, 55, 48, 95, 45, 44, 112, 111, 108, 97, 114,
  111, 105, 100, 95, 112, 120, 45, 55, 48, 44, 112, 111, 108, 97, 114, 111,
  105, 100, 95, 112, 120, 45, 55, 48, 95, 43, 44, 112, 111, 108, 97, 114,
  111, 105, 100, 95, 112, 120, 45, 55, 48, 95, 43, 43, 44, 112, 111, 108,
  97, 114, 111, 105, 100, 95, 112, 120, 45, 55, 48, 95, 43, 43, 43, 44,
  92, 10, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 55, 48,
  95, 99, 111, 108, 100, 95, 45, 45, 44, 112, 111, 108, 97, 114, 111, 105,
  100, 95, 112, 120, 45, 55, 48, 95, 99, 111, 108, 100, 95, 45, 44, 112,
  111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 55, 48, 95, 99, 111,
  108, 100, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 55,
  48, 95, 99, 111, 108, 100, 95, 43, 44, 112, 111, 108, 97, 114, 111, 105,
  100, 95, 112, 120, 45, 55, 48, 95, 99, 111, 108, 100, 95, 43, 43, 44,
  92, 10, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 55, 48,
  95, 119, 97, 114, 109, 95, 45, 45, 44, 112, 111, 108, 97, 114, 111, 105,
  100, 95, 112, 120, 45, 55, 48, 95, 119, 97, 114, 109, 95, 45, 44, 112,
  111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 55, 48, 95, 119, 97,
  114, 109, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 55,
  48, 95, 119, 97, 114, 109, 95, 43, 44, 112, 111, 108, 97, 114, 111, 105,
  100, 95, 112, 120, 45, 55, 48, 95, 119, 97, 114, 109, 95, 43, 43, 44,
  92, 10, 112, 111, 108, 97, 114, 111, 105, 100, 95, 116, 105, 109, 101, 95,
  122, 101, 114, 111, 95, 40, 101, 120, 112, 105, 114, 101, 100, 41, 95, 45,
  45, 45, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 116, 105, 109, 101,
  95, 122, 101, 114, 111, 95, 40, 101, 120, 112, 105, 114, 101, 100, 41, 95,
  45, 45, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 116, 105, 109, 101,
  95, 122, 101, 114, 111, 95, 40, 101, 120, 112, 105, 114, 101, 100, 41, 95,
  45, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 116, 105, 109, 101, 95,
  122, 101, 114, 111, 95, 40, 101, 120, 112, 105, 114, 101, 100, 41, 44, 112,
  111, 108, 97, 114, 111, 105, 100, 95, 116, 105, 109, 101, 95, 122, 101, 114,
  111, 95, 40, 101, 120, 112, 105, 114, 101, 100, 41, 95, 43, 44, 112, 111,
  108, 97, 114, 111, 105, 100, 95, 116, 105, 109, 101, 95, 122, 101, 114, 111,
  95, 40, 101, 120, 112, 105, 114, 101, 100, 41, 95, 43, 43, 44, 92, 10,
  112, 111, 108, 97, 114, 111, 105, 100, 95, 116, 105, 109, 101, 95, 122, 101,
  114, 111, 95, 40, 101, 120, 112, 105, 114, 101, 100, 41, 95, 99, 111, 108,
  100, 95, 45, 45, 45, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 116,
  105, 109, 101, 95, 122, 101, 114, 111, 95, 40, 101, 120, 112, 105, 114, 101,
  100, 41, 95, 99, 111, 108, 100, 95, 45, 45, 44, 112, 111, 108, 97, 114,
  111, 105, 100, 95, 116, 105, 109, 101, 95, 122, 101, 114, 111, 95, 40, 101,
  120, 112, 105, 114, 101, 100, 41, 95, 99, 111, 108, 100, 95, 45, 44, 112,
  111, 108, 97, 114, 111, 105, 100, 95, 116, 105, 109, 101, 95, 122, 101, 114,
  111, 95, 40, 101, 120, 112, 105, 114, 101, 100, 41, 95, 99, 111, 108, 100,
  10, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105,
  108, 109, 95, 105, 110, 115, 116, 97, 110, 116, 95, 99, 111, 110, 115, 117,
  109, 101, 114, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101,
  95, 102, 105, 108, 109, 95, 105, 110, 115, 116, 97, 110, 116, 95, 99, 111,
  110, 115, 117, 109, 101, 114, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103,
  105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109,
  95, 105, 110, 115, 116, 97, 110, 116, 95, 112, 114, 111, 32, 58, 10, 45,
  95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105,
  108, 109, 32, 36, 49, 44, 64, 123, 45, 97, 114, 103, 92, 32, 36, 49,
  44, 64, 123, 45, 95, 36, 48, 125, 125, 44, 36, 123, 50, 45, 45, 49,
  125, 10, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95,
  102, 105, 108, 109, 95, 105, 110, 115, 116, 97, 110, 116, 95, 112, 114, 111,
  32, 58, 10, 45, 117, 32, 102, 117, 106, 105, 95, 102, 112, 45, 49, 48,
  48, 99, 95, 45, 45, 44, 102, 117, 106, 105, 95, 102, 112, 45, 49, 48,
  48, 99, 95, 45, 44, 102, 117, 106, 105, 95, 102, 112, 45, 49, 48, 48,
  99, 44, 102, 117, 106, 105, 95, 102, 112, 45, 49, 48, 48, 99, 95, 43,
  44, 102, 117, 106, 105, 95, 102, 112, 45, 49, 48, 48, 99, 95, 43, 43,
  44, 102, 117, 106, 105, 95, 102, 112, 45, 49, 48, 48, 99, 95, 43, 43,
  95, 97, 108, 116, 44, 102, 117, 106, 105, 95, 102, 112, 45, 49, 48, 48,
  99, 95, 43, 43, 43, 44, 92, 10, 102, 117, 106, 105, 95, 102, 112, 45,
  49, 48, 48, 99, 95, 99, 111, 111, 108, 95, 45, 45, 44, 102, 117, 106,
  105, 95, 102, 112, 45, 49, 48, 48, 99, 95, 99, 111, 111, 108, 95, 45,
  44, 102, 117, 106, 105, 95, 102, 112, 45, 49, 48, 48, 99, 95, 99, 111,
  111, 108, 44, 102, 117, 106, 105, 95, 102, 112, 45, 49, 48, 48, 99, 95,
  99, 111, 111, 108, 95, 43, 44, 102, 117, 106, 105, 95, 102, 112, 45, 49,
  48, 48, 99, 95, 99, 111, 111, 108, 95, 43, 43, 44, 92, 10, 102, 117,
  106, 105, 95, 102, 112, 45, 49, 48, 48, 99, 95, 110, 101, 103, 97, 116,
  105, 118, 101, 95, 45, 45, 44, 102, 117, 106, 105, 95, 102, 112, 45, 49,
  48, 48, 99, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 45, 44, 102,
  117, 106, 105, 95, 102, 112, 45, 49, 48, 48, 99, 95, 110, 101, 103, 97,
  116, 105, 118, 101, 44, 102, 117, 106, 105, 95, 102, 112, 45, 49, 48, 48,
  99, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 43, 44, 102, 117, 106,
  105, 95, 102, 112, 45, 49, 48, 48, 99, 95, 110, 101, 103, 97, 116, 105,
  118, 101, 95, 43, 43, 44, 102, 117, 106, 105, 95, 102, 112, 45, 49, 48,
  48, 99, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 43, 43, 95, 97,
  108, 116, 44, 102, 117, 106, 105, 95, 102, 112, 45, 49, 48, 48, 99, 95,
  110, 101, 103, 97, 116, 105, 118, 101, 95, 43, 43, 43, 44, 92, 10, 102,
  117, 106, 105, 95, 102, 112, 45, 51, 48, 48, 48, 98, 95, 45, 45, 44,
  102, 117, 106, 105, 95, 102, 112, 45, 51, 48, 48, 48, 98, 95, 45, 44,
  102, 117, 106, 105, 95, 102, 112, 45, 51, 48, 48, 48, 98, 44, 102, 117,
  106, 105, 95, 102, 112, 45, 51, 48, 48, 48, 98, 95, 43, 44, 102, 117,
  106, 105, 95, 102, 112, 45, 51, 48, 48, 48, 98, 95, 43, 43, 44, 102,
  117, 106, 105, 95, 102, 112, 45, 51, 48, 48, 48, 98, 95, 43, 43, 43,
  44, 102, 117, 106, 105, 95, 102, 112, 45, 51, 48, 48, 48, 98, 95, 104,
  99, 44, 92, 10, 102, 117, 106, 105, 95, 102, 112, 45, 51, 48, 48, 48,
  98, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 45, 45, 44, 102, 117,
  106, 105, 95, 102, 112, 45, 51, 48, 48, 48, 98, 95, 110, 101, 103, 97,
  116, 105, 118, 101, 95, 45, 44, 102, 117, 106, 105, 95, 102, 112, 45, 51,
  48, 48, 48, 98, 95, 110, 101, 103, 97, 116, 105, 118, 101, 44, 102, 117,
  106, 105, 95, 102, 112, 45, 51, 48, 48, 48, 98, 95, 110, 101, 103, 97,
  116, 105, 118, 101, 95, 43, 44, 102, 117, 106, 105, 95, 102, 112, 45, 51,
  48, 48, 48, 98, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 43, 43,
  44, 102, 117, 106, 105, 95, 102, 112, 45, 51, 48, 48, 48, 98, 95, 110,
  101, 103, 97, 116, 105, 118, 101, 95, 43, 43, 43, 44, 102, 117, 106, 105,
  95, 102, 112, 45, 51, 48, 48, 48, 98, 95, 110, 101, 103, 97, 116, 105,
  118, 101, 95, 101, 97, 114, 108, 121, 44, 92, 10, 112, 111, 108, 97, 114,
  111, 105, 100, 95, 54, 54, 53, 95, 45, 45, 44, 112, 111, 108, 97, 114,
  111, 105, 100, 95, 54, 54, 53, 95, 45, 44, 112, 111, 108, 97, 114, 111,
  105, 100, 95, 54, 54, 53, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95,
  54, 54, 53, 95, 43, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 54,
  54, 53, 95, 43, 43, 44, 92, 10, 112, 111, 108, 97, 114, 111, 105, 100,
  95, 54, 54, 53, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 45, 44,
  112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 54, 53, 95, 110, 101, 103,
  97, 116, 105, 118, 101, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 54,
  54, 53, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 43, 44, 112, 111,
  108, 97, 114, 111, 105, 100, 95, 54, 54, 53, 95, 110, 101, 103, 97, 116,
  105, 118, 101, 95, 104, 99, 44, 92, 10, 112, 111, 108, 97, 114, 111, 105,
  100, 95, 54, 54, 57, 95, 45, 45, 44, 112, 111, 108, 97, 114, 111, 105,
  100, 95, 54, 54, 57, 95, 45, 44, 112, 111, 108, 97, 114, 111, 105, 100,
  95, 54, 54, 57, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 54,
  57, 95, 43, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 54, 57,
  95, 43, 43, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 54, 57,
  95, 43, 43, 43, 44, 92, 10, 112, 111, 108, 97, 114, 111, 105, 100, 95,
  54, 54, 57, 95, 99, 111, 108, 100, 95, 45, 45, 44, 112, 111, 108, 97,
  114, 111, 105, 100, 95, 54, 54, 57, 95, 99, 111, 108, 100, 95, 45, 44,
  112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 54, 57, 95, 99, 111, 108,
  100, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 54, 57, 95, 99,
  111, 108, 100, 95, 43, 44, 92, 10, 112, 111, 108, 97, 114, 111, 105, 100,
  95, 54, 57, 48, 95, 45, 45, 44, 112, 111, 108, 97, 114, 111, 105, 100,
  95, 54, 57, 48, 95, 45, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95,
  54, 57, 48, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 57, 48,
  95, 43, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 57, 48, 95,
  43, 43, 44, 92, 10, 112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 57,
  48, 95, 99, 111, 108, 100, 95, 45, 45, 44, 112, 111, 108, 97, 114, 111,
  105, 100, 95, 54, 57, 48, 95, 99, 111, 108, 100, 95, 45, 44, 112, 111,
  108, 97, 114, 111, 105, 100, 95, 54, 57, 48, 95, 99, 111, 108, 100, 44,
  112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 57, 48, 95, 99, 111, 108,
  100, 95, 43, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 57, 48,
  95, 99, 111, 108, 100, 95, 43, 43, 44, 92, 10, 112, 111, 108, 97, 114,
  111, 105, 100, 95, 54, 57, 48, 95, 119, 97, 114, 109, 95, 45, 45, 44,
  112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 57, 48, 95, 119, 97, 114,
  109, 95, 45, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 57, 48,
  95, 119, 97, 114, 109, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 54,
  57, 48, 95, 119, 97, 114, 109, 95, 43, 44, 112, 111, 108, 97, 114, 111,
  105, 100, 95, 54, 57, 48, 95, 119, 97, 114, 109, 95, 43, 43, 10, 103,
  105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109,
  95, 105, 110, 115, 116, 97, 110, 116, 95, 112, 114, 111, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109,
  112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 105,
  110, 115, 116, 97, 110, 116, 95, 112, 114, 111, 32, 36, 42, 34, 44, 36,
  45, 49, 10, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95,
  102, 105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 99, 111,
  108, 111, 114, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117,
  108, 97, 116, 101, 95, 102, 105, 108, 109, 32, 36, 49, 44, 64, 123, 45,
  97, 114, 103, 92, 32, 36, 49, 44, 64, 123, 45, 95, 36, 48, 125, 125,
  44, 36, 123, 50, 45, 45, 49, 125, 10, 95, 103, 105, 109, 112, 95, 101,
  109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 110, 101, 103, 97,
  116, 105, 118, 101, 95, 99, 111, 108, 111, 114, 32, 58, 10, 45, 117, 32,
  97, 103, 102, 97, 95, 117, 108, 116, 114, 97, 95, 99, 111, 108, 111, 114,
  95, 49, 48, 48, 44, 97, 103, 102, 97, 95, 118, 105, 115, 116, 97, 95,
  50, 48, 48, 44, 102, 117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97,
  95, 50, 48, 48, 44, 102, 117, 106, 105, 95, 115, 117, 112, 101, 114, 105,
  97, 95, 104, 103, 95, 49, 54, 48, 48, 44, 102, 117, 106, 105, 95, 115,
  117, 112, 101, 114, 105, 97, 95, 114, 101, 97, 108, 97, 95, 49, 48, 48,
  44, 102, 117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97, 95, 120, 45,
  116, 114, 97, 95, 56, 48, 48, 44, 92, 10, 107, 111, 100, 97, 107, 95,
  101, 108, 105, 116, 101, 95, 49, 48, 48, 95, 120, 112, 114, 111, 44, 107,
  111, 100, 97, 107, 95, 101, 108, 105, 116, 101, 95, 99, 111, 108, 111, 114,
  95, 50, 48, 48, 44, 107, 111, 100, 97, 107, 95, 101, 108, 105, 116, 101,
  95, 99, 111, 108, 111, 114, 95, 52, 48, 48, 44, 107, 111, 100, 97, 107,
  95, 112, 111, 114, 116, 114, 97, 95, 49, 54, 48, 95, 110, 99, 44, 107,
  111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 49, 54, 48, 95,
  118, 99, 44, 108, 111, 109, 111, 103, 114, 97, 112, 104, 121, 95, 114, 101,
  100, 115, 99, 97, 108, 101, 95, 49, 48, 48, 10, 103, 105, 109, 112, 95,
  101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 110, 101, 103,
  97, 116, 105, 118, 101, 95, 99, 111, 108, 111, 114, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112,
  95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 110, 101,
  103, 97, 116, 105, 118, 101, 95, 99, 111, 108, 111, 114, 32, 36, 42, 34,
  44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116,
  101, 95, 102, 105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95,
  110, 101, 119, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117,
  108, 97, 116, 101, 95, 102, 105, 108, 109, 32, 36, 49, 44, 64, 123, 45,
  97, 114, 103, 92, 32, 123, 109, 97, 120, 40, 49, 44, 52, 42, 36, 49,
  43, 36, 50, 45, 51, 41, 125, 44, 64, 123, 45, 95, 36, 48, 125, 125,
  44, 36, 123, 51, 45, 45, 49, 125, 10, 95, 103, 105, 109, 112, 95, 101,
  109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 110, 101, 103, 97,
  116, 105, 118, 101, 95, 110, 101, 119, 32, 58, 10, 45, 117, 32, 102, 117,
  106, 105, 95, 49, 54, 48, 99, 95, 45, 44, 102, 117, 106, 105, 95, 49,
  54, 48, 99, 44, 102, 117, 106, 105, 95, 49, 54, 48, 99, 95, 43, 44,
  102, 117, 106, 105, 95, 49, 54, 48, 99, 95, 43, 43, 44, 92, 10, 102,
  117, 106, 105, 95, 52, 48, 48, 104, 95, 45, 44, 102, 117, 106, 105, 95,
  52, 48, 48, 104, 44, 102, 117, 106, 105, 95, 52, 48, 48, 104, 95, 43,
  44, 102, 117, 106, 105, 95, 52, 48, 48, 104, 95, 43, 43, 44, 92, 10,
  102, 117, 106, 105, 95, 56, 48, 48, 122, 95, 45, 44, 102, 117, 106, 105,
  95, 56, 48, 48, 122, 44, 102, 117, 106, 105, 95, 56, 48, 48, 122, 95,
  43, 44, 102, 117, 106, 105, 95, 56, 48, 48, 122, 95, 43, 43, 44, 92,
  10, 102, 117, 106, 105, 95, 105, 108, 102, 111, 114, 100, 95, 104, 112, 53,
  95, 45, 44, 102, 117, 106, 105, 95, 105, 108, 102, 111, 114, 100, 95, 104,
  112, 53, 44, 102, 117, 106, 105, 95, 105, 108, 102, 111, 114, 100, 95, 104,
  112, 53, 95, 43, 44, 102, 117, 106, 105, 95, 105, 108, 102, 111, 114, 100,
  95, 104, 112, 53, 95, 43, 43, 44, 92, 10, 107, 111, 100, 97, 107, 95,
  112, 111, 114, 116, 114, 97, 95, 49, 54, 48, 95, 45, 44, 107, 111, 100,
  97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 49, 54, 48, 44, 107, 111,
  100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 49, 54, 48, 95, 43,
  44, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 49, 54,
  48, 95, 43, 43, 44, 92, 10, 107, 111, 100, 97, 107, 95, 112, 111, 114,
  116, 114, 97, 95, 52, 48, 48, 95, 45, 44, 107, 111, 100, 97, 107, 95,
  112, 111, 114, 116, 114, 97, 95, 52, 48, 48, 44, 107, 111, 100, 97, 107,
  95, 112, 111, 114, 116, 114, 97, 95, 52, 48, 48, 95, 43, 44, 107, 111,
  100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 52, 48, 48, 95, 43,
  43, 44, 92, 10, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97,
  95, 56, 48, 48, 95, 45, 44, 107, 111, 100, 97, 107, 95, 112, 111, 114,
  116, 114, 97, 95, 56, 48, 48, 44, 107, 111, 100, 97, 107, 95, 112, 111,
  114, 116, 114, 97, 95, 56, 48, 48, 95, 43, 44, 107, 111, 100, 97, 107,
  95, 112, 111, 114, 116, 114, 97, 95, 56, 48, 48, 95, 43, 43, 44, 92,
  10, 107, 111, 100, 97, 107, 95, 116, 109, 97, 120, 95, 51, 50, 48, 48,
  95, 45, 44, 107, 111, 100, 97, 107, 95, 116, 109, 97, 120, 95, 51, 50,
  48, 48, 44, 107, 111, 100, 97, 107, 95, 116, 109, 97, 120, 95, 51, 50,
  48, 48, 95, 43, 44, 107, 111, 100, 97, 107, 95, 116, 109, 97, 120, 95,
  51, 50, 48, 48, 95, 43, 43, 44, 92, 10, 107, 111, 100, 97, 107, 95,
  116, 114, 105, 45, 120, 95, 52, 48, 48, 95, 45, 44, 107, 111, 100, 97,
  107, 95, 116, 114, 105, 45, 120, 95, 52, 48, 48, 44, 107, 111, 100, 97,
  107, 95, 116, 114, 105, 45, 120, 95, 52, 48, 48, 95, 43, 44, 107, 111,
  100, 97, 107, 95, 116, 114, 105, 45, 120, 95, 52, 48, 48, 95, 43, 43,
  10, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105,
  108, 109, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 110, 101, 119, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108,
  109, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 110, 101, 119, 32, 36,
  42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 101, 109, 117, 108,
  97, 116, 101, 95, 102, 105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118,
  101, 95, 111, 108, 100, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 101,
  109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 32, 36, 49, 44, 64,
  123, 45, 97, 114, 103, 92, 32, 123, 109, 97, 120, 40, 49, 44, 52, 42,
  36, 49, 43, 36, 50, 45, 51, 41, 125, 44, 64, 123, 45, 95, 36, 48,
  125, 125, 44, 36, 123, 51, 45, 45, 49, 125, 10, 95, 103, 105, 109, 112,
  95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 110, 101,
  103, 97, 116, 105, 118, 101, 95, 111, 108, 100, 32, 58, 10, 45, 117, 32,
  102, 117, 106, 105, 95, 105, 108, 102, 111, 114, 100, 95, 100, 101, 108, 116,
  97, 95, 51, 50, 48, 48, 95, 45, 44, 102, 117, 106, 105, 95, 105, 108,
  102, 111, 114, 100, 95, 100, 101, 108, 116, 97, 95, 51, 50, 48, 48, 44,
  102, 117, 106, 105, 95, 105, 108, 102, 111, 114, 100, 95, 100, 101, 108, 116,
  97, 95, 51, 50, 48, 48, 95, 43, 44, 102, 117, 106, 105, 95, 105, 108,
  102, 111, 114, 100, 95, 100, 101, 108, 116, 97, 95, 51, 50, 48, 48, 95,
  43, 43, 44, 92, 10, 102, 117, 106, 105, 95, 110, 101, 111, 112, 97, 110,
  95, 49, 54, 48, 48, 95, 45, 44, 102, 117, 106, 105, 95, 110, 101, 111,
  112, 97, 110, 95, 49, 54, 48, 48, 44, 102, 117, 106, 105, 95, 110, 101,
  111, 112, 97, 110, 95, 49, 54, 48, 48, 95, 43, 44, 102, 117, 106, 105,
  95, 110, 101, 111, 112, 97, 110, 95, 49, 54, 48, 48, 95, 43, 43, 44,
  92, 10, 102, 117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97, 95, 49,
  48, 48, 95, 45, 44, 102, 117, 106, 105, 95, 115, 117, 112, 101, 114, 105,
  97, 95, 49, 48, 48, 44, 102, 117, 106, 105, 95, 115, 117, 112, 101, 114,
  105, 97, 95, 49, 48, 48, 95, 43, 44, 102, 117, 106, 105, 95, 115, 117,
  112, 101, 114, 105, 97, 95, 49, 48, 48, 95, 43, 43, 44, 92, 10, 102,
  117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97, 95, 52, 48, 48, 95,
  45, 44, 102, 117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97, 95, 52,
  48, 48, 44, 102, 117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97, 95,
  52, 48, 48, 95, 43, 44, 102, 117, 106, 105, 95, 115, 117, 112, 101, 114,
  105, 97, 95, 52, 48, 48, 95, 43, 43, 44, 92, 10, 102, 117, 106, 105,
  95, 115, 117, 112, 101, 114, 105, 97, 95, 56, 48, 48, 95, 45, 44, 102,
  117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97, 95, 56, 48, 48, 44,
  102, 117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97, 95, 56, 48, 48,
  95, 43, 44, 102, 117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97, 95,
  56, 48, 48, 95, 43, 43, 44, 92, 10, 102, 117, 106, 105, 95, 115, 117,
  112, 101, 114, 105, 97, 95, 49, 54, 48, 48, 95, 45, 44, 102, 117, 106,
  105, 95, 115, 117, 112, 101, 114, 105, 97, 95, 49, 54, 48, 48, 44, 102,
  117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97, 95, 49, 54, 48, 48,
  95, 43, 44, 102, 117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97, 95,
  49, 54, 48, 48, 95, 43, 43, 44, 92, 10, 107, 111, 100, 97, 107, 95,
  112, 111, 114, 116, 114, 97, 95, 49, 54, 48, 95, 110, 99, 95, 45, 44,
  107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 49, 54, 48,
  95, 110, 99, 44, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97,
  95, 49, 54, 48, 95, 110, 99, 95, 43, 44, 107, 111, 100, 97, 107, 95,
  112, 111, 114, 116, 114, 97, 95, 49, 54, 48, 95, 110, 99, 95, 43, 43,
  44, 92, 10, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95,
  49, 54, 48, 95, 118, 99, 95, 45, 44, 107, 111, 100, 97, 107, 95, 112,
  111, 114, 116, 114, 97, 95, 49, 54, 48, 95, 118, 99, 44, 107, 111, 100,
  97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 49, 54, 48, 95, 118, 99,
  95, 43, 44, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95,
  49, 54, 48, 95, 118, 99, 95, 43, 43, 44, 92, 10, 107, 111, 100, 97,
  107, 95, 112, 111, 114, 116, 114, 97, 95, 52, 48, 48, 95, 110, 99, 95,
  45, 44, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 52,
  48, 48, 95, 110, 99, 44, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116,
  114, 97, 95, 52, 48, 48, 95, 110, 99, 95, 43, 44, 107, 111, 100, 97,
  107, 95, 112, 111, 114, 116, 114, 97, 95, 52, 48, 48, 95, 110, 99, 95,
  43, 43, 44, 92, 10, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114,
  97, 95, 52, 48, 48, 95, 117, 99, 95, 45, 44, 107, 111, 100, 97, 107,
  95, 112, 111, 114, 116, 114, 97, 95, 52, 48, 48, 95, 117, 99, 44, 107,
  111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 52, 48, 48, 95,
  117, 99, 95, 43, 44, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114,
  97, 95, 52, 48, 48, 95, 117, 99, 95, 43, 43, 44, 92, 10, 107, 111,
  100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 52, 48, 48, 95, 118,
  99, 95, 45, 44, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97,
  95, 52, 48, 48, 95, 118, 99, 44, 107, 111, 100, 97, 107, 95, 112, 111,
  114, 116, 114, 97, 95, 52, 48, 48, 95, 118, 99, 95, 43, 44, 107, 111,
  100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 52, 48, 48, 95, 118,
  99, 95, 43, 43, 10, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116,
  101, 95, 102, 105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95,
  111, 108, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101,
  95, 102, 105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 111,
  108, 100, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95,
  101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 111, 116, 104,
  101, 114, 115, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117,
  108, 97, 116, 101, 95, 102, 105, 108, 109, 32, 36, 49, 44, 64, 123, 45,
  97, 114, 103, 92, 32, 36, 49, 44, 64, 123, 45, 95, 36, 48, 125, 125,
  44, 36, 123, 50, 45, 45, 49, 125, 10, 95, 103, 105, 109, 112, 95, 101,
  109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 111, 116, 104, 101,
  114, 115, 32, 58, 10, 45, 117, 32, 54, 48, 115, 44, 54, 48, 115, 95,
  50, 44, 54, 48, 115, 95, 51, 44, 104, 107, 102, 105, 108, 109, 44, 108,
  111, 109, 111, 44, 110, 111, 115, 116, 97, 108, 103, 105, 99, 44, 114, 101,
  116, 114, 111, 44, 115, 117, 116, 114, 111, 102, 120, 44, 118, 105, 110, 116,
  97, 103, 101, 44, 118, 105, 110, 116, 97, 103, 101, 95, 50, 44, 119, 97,
  114, 109, 44, 119, 97, 114, 109, 95, 115, 112, 114, 105, 110, 103, 44, 119,
  97, 114, 109, 95, 121, 101, 108, 108, 111, 119, 10, 103, 105, 109, 112, 95,
  101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 111, 116, 104,
  101, 114, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101,
  95, 102, 105, 108, 109, 95, 111, 116, 104, 101, 114, 115, 32, 36, 42, 34,
  44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116,
  101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 111, 114, 115, 108, 105, 100,
  101, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97,
  116, 101, 95, 102, 105, 108, 109, 32, 36, 49, 44, 64, 123, 45, 97, 114,
  103, 92, 32, 36, 49, 44, 64, 123, 45, 95, 36, 48, 125, 125, 44, 36,
  123, 50, 45, 45, 49, 125, 10, 95, 103, 105, 109, 112, 95, 101, 109, 117,
  108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 111, 114, 115,
  108, 105, 100, 101, 32, 58, 10, 45, 117, 32, 97, 103, 102, 97, 95, 112,
  114, 101, 99, 105, 115, 97, 95, 49, 48, 48, 44, 102, 117, 106, 105, 95,
  97, 115, 116, 105, 97, 95, 49, 48, 48, 102, 44, 102, 117, 106, 105, 95,
  102, 112, 95, 49, 48, 48, 99, 44, 102, 117, 106, 105, 95, 112, 114, 111,
  118, 105, 97, 95, 49, 48, 48, 102, 44, 102, 117, 106, 105, 95, 112, 114,
  111, 118, 105, 97, 95, 52, 48, 48, 102, 44, 102, 117, 106, 105, 95, 112,
  114, 111, 118, 105, 97, 95, 52, 48, 48, 120, 44, 102, 117, 106, 105, 95,
  115, 101, 110, 115, 105, 97, 95, 49, 48, 48, 44, 92, 10, 102, 117, 106,
  105, 95, 115, 117, 112, 101, 114, 105, 97, 95, 50, 48, 48, 95, 120, 112,
  114, 111, 44, 102, 117, 106, 105, 95, 118, 101, 108, 118, 105, 97, 95, 53,
  48, 44, 103, 101, 110, 101, 114, 105, 99, 95, 102, 117, 106, 105, 95, 97,
  115, 116, 105, 97, 95, 49, 48, 48, 44, 103, 101, 110, 101, 114, 105, 99,
  95, 102, 117, 106, 105, 95, 112, 114, 111, 118, 105, 97, 95, 49, 48, 48,
  44, 103, 101, 110, 101, 114, 105, 99, 95, 102, 117, 106, 105, 95, 118, 101,
  108, 118, 105, 97, 95, 49, 48, 48, 44, 92, 10, 103, 101, 110, 101, 114,
  105, 99, 95, 107, 111, 100, 97, 99, 104, 114, 111, 109, 101, 95, 54, 52,
  44, 103, 101, 110, 101, 114, 105, 99, 95, 107, 111, 100, 97, 107, 95, 101,
  107, 116, 97, 99, 104, 114, 111, 109, 101, 95, 49, 48, 48, 95, 118, 115,
  44, 107, 111, 100, 97, 107, 95, 101, 45, 49, 48, 48, 95, 103, 120, 95,
  101, 107, 116, 97, 99, 104, 114, 111, 109, 101, 95, 49, 48, 48, 44, 107,
  111, 100, 97, 107, 95, 101, 107, 116, 97, 99, 104, 114, 111, 109, 101, 95,
  49, 48, 48, 95, 118, 115, 44, 107, 111, 100, 97, 107, 95, 101, 108, 105,
  116, 101, 95, 99, 104, 114, 111, 109, 101, 95, 50, 48, 48, 44, 92, 10,
  107, 111, 100, 97, 107, 95, 101, 108, 105, 116, 101, 95, 99, 104, 114, 111,
  109, 101, 95, 52, 48, 48, 44, 107, 111, 100, 97, 107, 95, 101, 108, 105,
  116, 101, 95, 101, 120, 116, 114, 97, 99, 111, 108, 111, 114, 95, 49, 48,
  48, 44, 107, 111, 100, 97, 107, 95, 107, 111, 100, 97, 99, 104, 114, 111,
  109, 101, 95, 50, 48, 48, 44, 107, 111, 100, 97, 107, 95, 107, 111, 100,
  97, 99, 104, 114, 111, 109, 101, 95, 50, 53, 44, 107, 111, 100, 97, 107,
  95, 107, 111, 100, 97, 99, 104, 114, 111, 109, 101, 95, 54, 52, 44, 108,
  111, 109, 111, 103, 114, 97, 112, 104, 121, 95, 120, 45, 112, 114, 111, 95,
  115, 108, 105, 100, 101, 95, 50, 48, 48, 44, 92, 10, 112, 111, 108, 97,
  114, 111, 105, 100, 95, 54, 54, 57, 44, 112, 111, 108, 97, 114, 111, 105,
  100, 95, 54, 57, 48, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112,
  111, 108, 97, 99, 104, 114, 111, 109, 101, 10, 103, 105, 109, 112, 95, 101,
  109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 111,
  114, 115, 108, 105, 100, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 101, 109, 117, 108,
  97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 111, 114, 115, 108,
  105, 100, 101, 32, 36, 42, 34, 44, 36, 45, 49, 10, 95, 103, 105, 109,
  112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 32, 58,
  10, 45, 105, 102, 32, 36, 49, 10, 100, 105, 114, 61, 64, 123, 45, 112,
  97, 116, 104, 95, 117, 115, 101, 114, 125, 10, 45, 105, 102, 32, 123, 33,
  64, 123, 45, 105, 115, 95, 119, 105, 110, 100, 111, 119, 115, 125, 125, 10,
  100, 105, 114, 61, 36, 100, 105, 114, 47, 46, 103, 109, 105, 99, 95, 102,
  105, 108, 109, 95, 112, 114, 101, 115, 101, 116, 115, 10, 45, 105, 102, 32,
  36, 100, 105, 114, 32, 45, 101, 108, 115, 101, 32, 45, 101, 120, 101, 99,
  32, 34, 109, 107, 100, 105, 114, 32, 34, 36, 100, 105, 114, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 110, 97, 114, 103, 40, 36, 95, 102, 111, 114, 99, 101, 95, 114, 101,
  100, 111, 119, 110, 108, 111, 97, 100, 41, 125, 10, 45, 105, 32, 104, 116,
  116, 112, 58, 47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101,
  102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 100, 97, 116, 97, 95, 102,
  105, 108, 109, 95, 112, 114, 101, 115, 101, 116, 115, 47, 36, 50, 46, 99,
  105, 109, 103, 122, 32, 45, 111, 91, 45, 49, 93, 32, 36, 100, 105, 114,
  47, 103, 109, 105, 99, 95, 36, 50, 46, 99, 105, 109, 103, 122, 10, 45,
  101, 108, 115, 101, 10, 45, 105, 102, 32, 36, 100, 105, 114, 47, 103, 109,
  105, 99, 95, 36, 50, 46, 99, 105, 109, 103, 122, 32, 45, 105, 32, 36,
  100, 105, 114, 47, 103, 109, 105, 99, 95, 36, 50, 46, 99, 105, 109, 103,
  122, 10, 45, 101, 108, 115, 101, 32, 45, 105, 32, 104, 116, 116, 112, 58,
  47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114,
  103, 101, 46, 110, 101, 116, 47, 100, 97, 116, 97, 95, 102, 105, 108, 109,
  95, 112, 114, 101, 115, 101, 116, 115, 47, 36, 50, 46, 99, 105, 109, 103,
  122, 32, 45, 111, 91, 45, 49, 93, 32, 36, 100, 105, 114, 47, 103, 109,
  105, 99, 95, 36, 50, 46, 99, 105, 109, 103, 122, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 109, 97, 112, 95, 99,
  108, 117, 116, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112,
  108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 10, 45, 97, 112, 112,
  108, 121, 95, 103, 97, 109, 109, 97, 91, 48, 93, 32, 123, 49, 48, 94,
  36, 51, 125, 10, 45, 45, 91, 48, 93, 32, 49, 50, 56, 32, 45, 42,
  91, 48, 93, 32, 36, 52, 32, 45, 43, 91, 48, 93, 32, 49, 50, 56,
  32, 45, 43, 91, 48, 93, 32, 36, 53, 32, 45, 99, 91, 48, 93, 32,
  48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36, 54, 124, 124, 36,
  55, 33, 61, 49, 124, 124, 36, 56, 125, 10, 45, 114, 103, 98, 50, 104,
  115, 118, 91, 48, 93, 10, 45, 115, 104, 91, 48, 93, 32, 48, 44, 48,
  32, 45, 43, 91, 45, 49, 93, 32, 36, 54, 32, 45, 37, 91, 45, 49,
  93, 32, 51, 54, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115,
  104, 91, 48, 93, 32, 49, 44, 49, 32, 45, 42, 91, 45, 49, 93, 32,
  36, 55, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 104, 115, 118, 50,
  114, 103, 98, 91, 48, 93, 10, 45, 105, 102, 32, 36, 56, 32, 45, 110,
  91, 48, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 97, 32, 99, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 101, 109,
  117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 108, 97,
  103, 101, 95, 98, 119, 32, 58, 10, 45, 107, 91, 48, 93, 32, 45, 105,
  102, 32, 123, 109, 97, 120, 40, 119, 44, 104, 41, 62, 36, 49, 125, 32,
  45, 105, 102, 32, 123, 119, 62, 104, 125, 32, 45, 114, 50, 100, 120, 32,
  36, 49, 32, 45, 101, 108, 115, 101, 32, 45, 114, 50, 100, 121, 32, 36,
  49, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10,
  95, 110, 98, 99, 61, 36, 50, 32, 45, 95, 103, 105, 109, 112, 95, 101,
  109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 108,
  97, 103, 101, 32, 64, 123, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117,
  108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 98, 119, 125, 10, 103, 105,
  109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95,
  99, 111, 108, 108, 97, 103, 101, 95, 105, 110, 115, 116, 97, 110, 116, 95,
  99, 111, 110, 115, 117, 109, 101, 114, 32, 58, 10, 45, 107, 91, 48, 93,
  32, 45, 105, 102, 32, 123, 109, 97, 120, 40, 119, 44, 104, 41, 62, 36,
  49, 125, 32, 45, 105, 102, 32, 123, 119, 62, 104, 125, 32, 45, 114, 50,
  100, 120, 32, 36, 49, 32, 45, 101, 108, 115, 101, 32, 45, 114, 50, 100,
  121, 32, 36, 49, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100,
  105, 102, 10, 95, 110, 98, 99, 61, 36, 50, 32, 45, 95, 103, 105, 109,
  112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99,
  111, 108, 108, 97, 103, 101, 32, 64, 123, 45, 95, 103, 105, 109, 112, 95,
  101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 105, 110, 115,
  116, 97, 110, 116, 95, 99, 111, 110, 115, 117, 109, 101, 114, 125, 10, 103,
  105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109,
  95, 99, 111, 108, 108, 97, 103, 101, 95, 105, 110, 115, 116, 97, 110, 116,
  95, 112, 114, 111, 32, 58, 10, 45, 107, 91, 48, 93, 32, 45, 105, 102,
  32, 123, 109, 97, 120, 40, 119, 44, 104, 41, 62, 36, 49, 125, 32, 45,
  105, 102, 32, 123, 119, 62, 104, 125, 32, 45, 114, 50, 100, 120, 32, 36,
  49, 32, 45, 101, 108, 115, 101, 32, 45, 114, 50, 100, 121, 32, 36, 49,
  32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 95,
  110, 98, 99, 61, 36, 50, 32, 45, 95, 103, 105, 109, 112, 95, 101, 109,
  117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 108, 97,
  103, 101, 32, 64, 123, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108,
  97, 116, 101, 95, 102, 105, 108, 109, 95, 105, 110, 115, 116, 97, 110, 116,
  95, 112, 114, 111, 125, 10, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97,
  116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 108, 97, 103, 101, 95,
  110, 101, 103, 97, 116, 105, 118, 101, 95, 99, 111, 108, 111, 114, 32, 58,
  10, 45, 107, 91, 48, 93, 32, 45, 105, 102, 32, 123, 109, 97, 120, 40,
  119, 44, 104, 41, 62, 36, 49, 125, 32, 45, 105, 102, 32, 123, 119, 62,
  104, 125, 32, 45, 114, 50, 100, 120, 32, 36, 49, 32, 45, 101, 108, 115,
  101, 32, 45, 114, 50, 100, 121, 32, 36, 49, 32, 45, 101, 110, 100, 105,
  102, 32, 45, 101, 110, 100, 105, 102, 10, 95, 110, 98, 99, 61, 36, 50,
  32, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95,
  102, 105, 108, 109, 95, 99, 111, 108, 108, 97, 103, 101, 32, 64, 123, 45,
  95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105,
  108, 109, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 99, 111, 108, 111,
  114, 125, 10, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95,
  102, 105, 108, 109, 95, 99, 111, 108, 108, 97, 103, 101, 95, 110, 101, 103,
  97, 116, 105, 118, 101, 95, 110, 101, 119, 32, 58, 10, 45, 107, 91, 48,
  93, 32, 45, 105, 102, 32, 123, 109, 97, 120, 40, 119, 44, 104, 41, 62,
  36, 49, 125, 32, 45, 105, 102, 32, 123, 119, 62, 104, 125, 32, 45, 114,
  50, 100, 120, 32, 36, 49, 32, 45, 101, 108, 115, 101, 32, 45, 114, 50,
  100, 121, 32, 36, 49, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110,
  100, 105, 102, 10, 95, 110, 98, 99, 61, 36, 50, 32, 45, 95, 103, 105,
  109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95,
  99, 111, 108, 108, 97, 103, 101, 32, 64, 123, 45, 95, 103, 105, 109, 112,
  95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 110, 101,
  103, 97, 116, 105, 118, 101, 95, 110, 101, 119, 125, 10, 103, 105, 109, 112,
  95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111,
  108, 108, 97, 103, 101, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 111,
  108, 100, 32, 58, 10, 45, 107, 91, 48, 93, 32, 45, 105, 102, 32, 123,
  109, 97, 120, 40, 119, 44, 104, 41, 62, 36, 49, 125, 32, 45, 105, 102,
  32, 123, 119, 62, 104, 125, 32, 45, 114, 50, 100, 120, 32, 36, 49, 32,
  45, 101, 108, 115, 101, 32, 45, 114, 50, 100, 121, 32, 36, 49, 32, 45,
  101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 95, 110, 98,
  99, 61, 36, 50, 32, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108,
  97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 108, 97, 103, 101,
  32, 64, 123, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116,
  101, 95, 102, 105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95,
  111, 108, 100, 125, 10, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116,
  101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 108, 97, 103, 101, 95, 111,
  116, 104, 101, 114, 115, 32, 58, 10, 45, 107, 91, 48, 93, 32, 45, 105,
  102, 32, 123, 109, 97, 120, 40, 119, 44, 104, 41, 62, 36, 49, 125, 32,
  45, 105, 102, 32, 123, 119, 62, 104, 125, 32, 45, 114, 50, 100, 120, 32,
  36, 49, 32, 45, 101, 108, 115, 101, 32, 45, 114, 50, 100, 121, 32, 36,
  49, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10,
  95, 110, 98, 99, 61, 36, 50, 32, 45, 95, 103, 105, 109, 112, 95, 101,
  109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 108,
  97, 103, 101, 32, 64, 123, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117,
  108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 111, 116, 104, 101, 114, 115,
  125, 10, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102,
  105, 108, 109, 95, 99, 111, 108, 108, 97, 103, 101, 95, 99, 111, 108, 111,
  114, 115, 108, 105, 100, 101, 32, 58, 10, 45, 107, 91, 48, 93, 32, 45,
  105, 102, 32, 123, 109, 97, 120, 40, 119, 44, 104, 41, 62, 36, 49, 125,
  32, 45, 105, 102, 32, 123, 119, 62, 104, 125, 32, 45, 114, 50, 100, 120,
  32, 36, 49, 32, 45, 101, 108, 115, 101, 32, 45, 114, 50, 100, 121, 32,
  36, 49, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102,
  10, 95, 110, 98, 99, 61, 36, 50, 32, 45, 95, 103, 105, 109, 112, 95,
  101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108,
  108, 97, 103, 101, 32, 64, 123, 45, 95, 103, 105, 109, 112, 95, 101, 109,
  117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 111, 114,
  115, 108, 105, 100, 101, 125, 10, 95, 103, 105, 109, 112, 95, 101, 109, 117,
  108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 108, 97, 103,
  101, 32, 58, 10, 36, 61, 97, 114, 103, 32, 45, 112, 114, 111, 103, 114,
  101, 115, 115, 32, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 35,
  10, 112, 114, 101, 115, 101, 116, 61, 36, 123, 97, 114, 103, 123, 36, 62,
  43, 49, 125, 125, 10, 45, 45, 108, 91, 48, 93, 10, 45, 95, 103, 105,
  109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 91,
  48, 93, 32, 49, 44, 36, 112, 114, 101, 115, 101, 116, 44, 48, 44, 49,
  44, 48, 44, 48, 44, 49, 44, 48, 10, 40, 123, 39, 36, 112, 114, 101,
  115, 101, 116, 39, 125, 41, 32, 45, 114, 101, 112, 108, 97, 99, 101, 91,
  45, 49, 93, 32, 123, 39, 95, 39, 125, 44, 51, 50, 32, 45, 102, 91,
  45, 49, 93, 32, 105, 102, 40, 120, 61, 61, 48, 38, 38, 105, 62, 61,
  123, 39, 97, 39, 125, 38, 38, 105, 60, 61, 123, 39, 122, 39, 125, 44,
  105, 43, 123, 39, 65, 39, 125, 45, 123, 39, 97, 39, 125, 44, 105, 41,
  32, 116, 105, 116, 108, 101, 61, 64, 123, 45, 49, 44, 116, 125, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 116, 101, 120, 116, 95, 111, 117, 116,
  108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 116, 105, 116, 108, 101, 44,
  50, 44, 50, 44, 49, 51, 44, 50, 44, 49, 44, 50, 53, 53, 10, 45,
  101, 110, 100, 108, 10, 45, 112, 114, 111, 103, 114, 101, 115, 115, 32, 123,
  40, 49, 43, 36, 62, 41, 42, 49, 48, 48, 47, 36, 35, 125, 10, 45,
  100, 111, 110, 101, 10, 45, 116, 101, 120, 116, 95, 111, 117, 116, 108, 105,
  110, 101, 91, 48, 93, 32, 34, 79, 114, 105, 103, 105, 110, 97, 108, 32,
  105, 109, 97, 103, 101, 34, 44, 50, 44, 50, 44, 49, 51, 44, 50, 44,
  49, 44, 50, 53, 53, 10, 45, 102, 114, 97, 109, 101, 32, 49, 44, 49,
  44, 48, 32, 45, 102, 114, 97, 109, 101, 32, 53, 44, 53, 44, 50, 53,
  53, 32, 45, 45, 32, 50, 53, 53, 32, 45, 97, 112, 112, 101, 110, 100,
  95, 116, 105, 108, 101, 115, 32, 123, 109, 105, 110, 40, 36, 95, 110, 98,
  99, 44, 64, 35, 41, 125, 32, 45, 43, 32, 50, 53, 53, 10, 103, 105,
  109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95,
  100, 111, 119, 110, 108, 111, 97, 100, 32, 58, 10, 45, 95, 103, 105, 109,
  112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 100,
  111, 119, 110, 108, 111, 97, 100, 32, 64, 123, 45, 95, 103, 105, 109, 112,
  95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 98, 119,
  125, 44, 92, 10, 64, 123, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117,
  108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 105, 110, 115, 116, 97, 110,
  116, 95, 99, 111, 110, 115, 117, 109, 101, 114, 125, 44, 92, 10, 64, 123,
  45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102,
  105, 108, 109, 95, 105, 110, 115, 116, 97, 110, 116, 95, 112, 114, 111, 125,
  44, 92, 10, 64, 123, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108,
  97, 116, 101, 95, 102, 105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118,
  101, 95, 99, 111, 108, 111, 114, 125, 44, 92, 10, 64, 123, 45, 95, 103,
  105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109,
  95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 110, 101, 119, 125, 44, 92,
  10, 64, 123, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116,
  101, 95, 102, 105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95,
  111, 108, 100, 125, 44, 92, 10, 64, 123, 45, 95, 103, 105, 109, 112, 95,
  101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 111, 116, 104,
  101, 114, 115, 125, 44, 92, 10, 64, 123, 45, 95, 103, 105, 109, 112, 95,
  101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108,
  111, 114, 115, 108, 105, 100, 101, 125, 10, 45, 108, 91, 93, 32, 49, 32,
  45, 112, 114, 111, 103, 114, 101, 115, 115, 32, 48, 10, 45, 105, 102, 32,
  36, 49, 32, 95, 102, 111, 114, 99, 101, 95, 114, 101, 100, 111, 119, 110,
  108, 111, 97, 100, 61, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 95, 110, 98, 95, 112, 114, 101, 115, 101,
  116, 115, 32, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116,
  101, 95, 102, 105, 108, 109, 32, 49, 44, 36, 123, 95, 112, 114, 101, 115,
  101, 116, 123, 49, 43, 36, 62, 125, 125, 44, 49, 44, 49, 44, 48, 44,
  48, 44, 49, 44, 48, 32, 45, 112, 114, 111, 103, 114, 101, 115, 115, 32,
  123, 40, 36, 62, 43, 49, 41, 42, 49, 48, 48, 47, 36, 95, 110, 98,
  95, 112, 114, 101, 115, 101, 116, 115, 125, 32, 45, 100, 111, 110, 101, 10,
  45, 114, 109, 32, 45, 101, 110, 100, 108, 10, 95, 103, 105, 109, 112, 95,
  101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 100, 111, 119,
  110, 108, 111, 97, 100, 32, 58, 10, 95, 110, 98, 95, 112, 114, 101, 115,
  101, 116, 115, 61, 36, 35, 10, 36, 61, 95, 112, 114, 101, 115, 101, 116,
  10, 103, 105, 109, 112, 95, 100, 114, 111, 115, 116, 101, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 105, 102, 32, 123, 36,
  49, 54, 61, 61, 49, 125, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 49, 44, 49, 44, 39, 120, 39, 32, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 44, 49, 44, 39, 121, 39, 32, 45, 97, 91, 45, 50,
  44, 45, 49, 93, 32, 99, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 57, 10, 120, 48, 61, 123, 114, 111, 117,
  110, 100, 40, 36, 49, 42, 119, 47, 49, 48, 48, 41, 125, 32, 121, 48,
  61, 123, 114, 111, 117, 110, 100, 40, 36, 50, 42, 104, 47, 49, 48, 48,
  41, 125, 32, 120, 49, 61, 123, 114, 111, 117, 110, 100, 40, 36, 51, 42,
  119, 47, 49, 48, 48, 41, 125, 32, 121, 49, 61, 123, 114, 111, 117, 110,
  100, 40, 36, 52, 42, 104, 47, 49, 48, 48, 41, 125, 10, 120, 50, 61,
  123, 114, 111, 117, 110, 100, 40, 36, 53, 42, 119, 47, 49, 48, 48, 41,
  125, 32, 121, 50, 61, 123, 114, 111, 117, 110, 100, 40, 36, 54, 42, 104,
  47, 49, 48, 48, 41, 125, 32, 120, 51, 61, 123, 114, 111, 117, 110, 100,
  40, 36, 55, 42, 119, 47, 49, 48, 48, 41, 125, 32, 121, 51, 61, 123,
  114, 111, 117, 110, 100, 40, 36, 56, 42, 104, 47, 49, 48, 48, 41, 125,
  10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 50, 44, 45,
  51, 50, 55, 54, 55, 32, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45,
  49, 93, 32, 52, 44, 36, 120, 48, 44, 36, 121, 48, 44, 36, 120, 49,
  44, 36, 121, 49, 44, 36, 120, 50, 44, 36, 121, 50, 44, 36, 120, 51,
  44, 36, 121, 51, 44, 49, 44, 45, 54, 53, 53, 51, 53, 10, 45, 115,
  104, 91, 45, 49, 93, 32, 48, 44, 48, 32, 45, 102, 91, 45, 49, 93,
  32, 39, 105, 102, 40, 105, 61, 61, 45, 54, 53, 53, 51, 53, 44, 120,
  48, 51, 61, 36, 120, 48, 43, 40, 121, 45, 36, 121, 48, 41, 47, 40,
  36, 121, 51, 45, 36, 121, 48, 41, 42, 40, 36, 120, 51, 45, 36, 120,
  48, 41, 59, 120, 49, 50, 61, 36, 120, 49, 43, 40, 121, 45, 36, 121,
  49, 41, 47, 40, 36, 121, 50, 45, 36, 121, 49, 41, 42, 40, 36, 120,
  50, 45, 36, 120, 49, 41, 59, 40, 120, 45, 120, 48, 51, 41, 47, 40,
  120, 49, 50, 45, 120, 48, 51, 41, 42, 40, 119, 45, 49, 41, 44, 105,
  41, 39, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 45,
  49, 93, 32, 49, 44, 49, 32, 45, 102, 91, 45, 49, 93, 32, 39, 105,
  102, 40, 105, 61, 61, 45, 54, 53, 53, 51, 53, 44, 121, 48, 49, 61,
  36, 121, 48, 43, 40, 120, 45, 36, 120, 48, 41, 47, 40, 36, 120, 49,
  45, 36, 120, 48, 41, 42, 40, 36, 121, 49, 45, 36, 121, 48, 41, 59,
  121, 51, 50, 61, 36, 121, 51, 43, 40, 120, 45, 36, 120, 51, 41, 47,
  40, 36, 120, 50, 45, 36, 120, 51, 41, 42, 40, 36, 121, 50, 45, 36,
  121, 51, 41, 59, 40, 121, 45, 121, 48, 49, 41, 47, 40, 121, 51, 50,
  45, 121, 48, 49, 41, 42, 40, 104, 45, 49, 41, 44, 105, 41, 39, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 120, 115, 104, 105, 102, 116, 61, 123,
  119, 42, 36, 49, 48, 47, 49, 48, 48, 125, 32, 121, 115, 104, 105, 102,
  116, 61, 123, 104, 42, 36, 49, 49, 47, 49, 48, 48, 125, 32, 97, 108,
  112, 104, 97, 61, 123, 45, 36, 49, 50, 42, 112, 105, 47, 49, 56, 48,
  125, 32, 99, 97, 61, 123, 99, 111, 115, 40, 36, 97, 108, 112, 104, 97,
  41, 47, 36, 49, 51, 125, 32, 115, 97, 61, 123, 115, 105, 110, 40, 36,
  97, 108, 112, 104, 97, 41, 47, 36, 49, 51, 125, 32, 119, 50, 61, 123,
  119, 47, 50, 125, 32, 104, 50, 61, 123, 104, 47, 50, 125, 10, 45, 102,
  91, 45, 49, 93, 32, 39, 105, 102, 40, 105, 61, 61, 45, 51, 50, 55,
  54, 55, 44, 105, 44, 88, 61, 105, 40, 120, 44, 121, 44, 48, 44, 48,
  41, 45, 36, 119, 50, 59, 89, 61, 105, 40, 120, 44, 121, 44, 48, 44,
  49, 41, 45, 36, 104, 50, 59, 105, 102, 40, 99, 61, 61, 48, 44, 36,
  119, 50, 45, 36, 120, 115, 104, 105, 102, 116, 43, 88, 42, 36, 99, 97,
  45, 89, 42, 36, 115, 97, 44, 36, 104, 50, 45, 36, 121, 115, 104, 105,
  102, 116, 43, 88, 42, 36, 115, 97, 43, 89, 42, 36, 99, 97, 41, 41,
  39, 10, 45, 105, 102, 32, 123, 36, 49, 52, 61, 61, 48, 125, 32, 45,
  115, 104, 91, 45, 49, 93, 32, 48, 44, 48, 32, 45, 102, 91, 45, 49,
  93, 32, 39, 105, 102, 40, 105, 61, 61, 45, 51, 50, 55, 54, 55, 44,
  120, 44, 105, 41, 39, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 115,
  104, 91, 45, 49, 93, 32, 49, 44, 49, 32, 45, 102, 91, 45, 49, 93,
  32, 39, 105, 102, 40, 105, 61, 61, 45, 51, 50, 55, 54, 55, 44, 121,
  44, 105, 41, 39, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 52, 61, 61, 49, 125, 32, 45, 115, 104, 91,
  45, 49, 93, 32, 48, 44, 48, 32, 45, 102, 91, 45, 49, 93, 32, 39,
  105, 102, 40, 105, 61, 61, 45, 51, 50, 55, 54, 55, 44, 120, 44, 119,
  45, 49, 45, 105, 41, 39, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  115, 104, 91, 45, 49, 93, 32, 49, 44, 49, 32, 45, 102, 91, 45, 49,
  93, 32, 39, 105, 102, 40, 105, 61, 61, 45, 51, 50, 55, 54, 55, 44,
  121, 44, 105, 41, 39, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 49, 52, 61, 61, 50, 125, 32, 45, 115, 104,
  91, 45, 49, 93, 32, 48, 44, 48, 32, 45, 102, 91, 45, 49, 93, 32,
  39, 105, 102, 40, 105, 61, 61, 45, 51, 50, 55, 54, 55, 44, 120, 44,
  105, 41, 39, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 115, 104, 91,
  45, 49, 93, 32, 49, 44, 49, 32, 45, 102, 91, 45, 49, 93, 32, 39,
  105, 102, 40, 105, 61, 61, 45, 51, 50, 55, 54, 55, 44, 121, 44, 104,
  45, 49, 45, 105, 41, 39, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  101, 108, 115, 101, 32, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 48,
  32, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102, 40, 105, 61, 61, 45,
  51, 50, 55, 54, 55, 44, 120, 44, 119, 45, 49, 45, 105, 41, 39, 32,
  45, 114, 109, 91, 45, 49, 93, 32, 45, 115, 104, 91, 45, 49, 93, 32,
  49, 44, 49, 32, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102, 40, 105,
  61, 61, 45, 51, 50, 55, 54, 55, 44, 121, 44, 104, 45, 49, 45, 105,
  41, 39, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 49, 54, 60, 50, 125, 32, 45, 119,
  97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 123,
  36, 49, 54, 61, 61, 48, 125, 44, 36, 49, 53, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 101, 108, 115, 101, 10, 45, 45, 119, 97, 114, 112,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 49, 44, 36, 49,
  53, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 105, 102, 32, 123, 36,
  49, 54, 61, 61, 51, 125, 32, 45, 114, 118, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 98, 108, 101, 110, 100, 91,
  45, 50, 44, 45, 49, 93, 32, 97, 108, 112, 104, 97, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36,
  49, 54, 61, 61, 49, 125, 32, 45, 119, 97, 114, 112, 91, 45, 50, 93,
  32, 91, 45, 49, 93, 44, 48, 44, 49, 44, 49, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 109, 118, 91, 45,
  49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95,
  100, 114, 111, 115, 116, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 105, 102, 32, 123, 33, 36, 49, 55, 125, 32, 45, 103, 105, 109,
  112, 95, 100, 114, 111, 115, 116, 101, 32, 36, 42, 32, 45, 101, 108, 115,
  101, 32, 45, 112, 111, 108, 121, 103, 111, 110, 32, 52, 44, 36, 49, 37,
  44, 36, 50, 37, 44, 36, 51, 37, 44, 36, 52, 37, 44, 36, 53, 37,
  44, 36, 54, 37, 44, 36, 55, 37, 44, 36, 56, 37, 44, 48, 46, 51,
  44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 112, 111, 108, 121, 103, 111, 110, 32, 52, 44, 36, 49, 37,
  44, 36, 50, 37, 44, 36, 51, 37, 44, 36, 52, 37, 44, 36, 53, 37,
  44, 36, 54, 37, 44, 36, 55, 37, 44, 36, 56, 37, 44, 49, 44, 48,
  120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 44, 48, 44, 48, 44,
  50, 53, 53, 10, 45, 101, 108, 108, 105, 112, 115, 101, 32, 36, 49, 37,
  44, 36, 50, 37, 44, 51, 44, 51, 44, 48, 44, 49, 44, 50, 53, 53,
  44, 48, 44, 48, 44, 50, 53, 53, 32, 45, 101, 108, 108, 105, 112, 115,
  101, 32, 36, 49, 37, 44, 36, 50, 37, 44, 51, 44, 51, 44, 48, 44,
  49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 44, 48,
  44, 48, 44, 50, 53, 53, 10, 45, 101, 108, 108, 105, 112, 115, 101, 32,
  36, 51, 37, 44, 36, 52, 37, 44, 51, 44, 51, 44, 48, 44, 49, 44,
  50, 53, 53, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 101,
  108, 108, 105, 112, 115, 101, 32, 36, 51, 37, 44, 36, 52, 37, 44, 51,
  44, 51, 44, 48, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70,
  70, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 10, 45, 101, 108, 108,
  105, 112, 115, 101, 32, 36, 53, 37, 44, 36, 54, 37, 44, 51, 44, 51,
  44, 48, 44, 49, 44, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53,
  32, 45, 101, 108, 108, 105, 112, 115, 101, 32, 36, 53, 37, 44, 36, 54,
  37, 44, 51, 44, 51, 44, 48, 44, 49, 44, 48, 120, 70, 70, 70, 70,
  70, 70, 70, 70, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 10, 45,
  101, 108, 108, 105, 112, 115, 101, 32, 36, 55, 37, 44, 36, 56, 37, 44,
  51, 44, 51, 44, 48, 44, 49, 44, 48, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 32, 45, 101, 108, 108, 105, 112, 115, 101, 32, 36,
  55, 37, 44, 36, 56, 37, 44, 51, 44, 51, 44, 48, 44, 49, 44, 48,
  120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 44, 48, 44, 48, 44,
  50, 53, 53, 10, 103, 105, 109, 112, 95, 102, 114, 97, 109, 101, 95, 98,
  108, 117, 114, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 45, 116, 111, 95, 114, 103, 98, 10,
  45, 45, 114, 32, 123, 49, 48, 48, 43, 36, 49, 125, 37, 44, 123, 49,
  48, 48, 43, 36, 49, 125, 37, 44, 49, 44, 49, 48, 48, 37, 44, 51,
  32, 45, 98, 91, 49, 93, 32, 36, 51, 37, 10, 45, 105, 102, 32, 36,
  53, 32, 45, 98, 97, 108, 97, 110, 99, 101, 95, 103, 97, 109, 109, 97,
  91, 49, 93, 32, 36, 123, 54, 45, 56, 125, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 57, 61, 61, 49, 125, 32, 45, 110,
  91, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 105, 102, 32,
  123, 36, 57, 61, 61, 50, 125, 32, 45, 110, 91, 49, 93, 32, 48, 44,
  50, 53, 53, 32, 45, 101, 113, 117, 97, 108, 105, 122, 101, 91, 49, 93,
  32, 50, 53, 54, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 118, 10,
  45, 122, 91, 49, 93, 32, 123, 36, 50, 47, 50, 125, 37, 44, 123, 36,
  50, 47, 50, 125, 37, 44, 123, 49, 48, 48, 45, 36, 50, 47, 50, 125,
  37, 44, 123, 49, 48, 48, 45, 36, 50, 47, 50, 125, 37, 10, 45, 116,
  111, 95, 114, 103, 98, 97, 91, 49, 93, 10, 45, 105, 102, 32, 36, 52,
  32, 114, 61, 123, 49, 43, 49, 47, 36, 52, 125, 32, 45, 115, 104, 91,
  49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 102, 91,
  45, 49, 93, 32, 39, 49, 45, 40, 97, 98, 115, 40, 120, 47, 119, 45,
  48, 46, 53, 41, 94, 36, 114, 43, 97, 98, 115, 40, 121, 47, 104, 45,
  48, 46, 53, 41, 94, 36, 114, 41, 94, 40, 49, 47, 36, 114, 41, 39,
  10, 118, 61, 123, 109, 105, 110, 40, 105, 40, 119, 47, 50, 44, 48, 41,
  44, 105, 40, 119, 45, 49, 44, 104, 47, 50, 41, 44, 105, 40, 119, 47,
  50, 44, 104, 45, 49, 41, 44, 105, 40, 48, 44, 104, 47, 50, 41, 41,
  125, 10, 45, 99, 91, 45, 49, 93, 32, 36, 118, 44, 123, 36, 118, 43,
  48, 46, 53, 47, 109, 97, 120, 40, 119, 44, 104, 41, 125, 32, 45, 110,
  91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 114, 109, 91, 45,
  49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 115, 61, 123, 36, 49, 48,
  37, 42, 109, 97, 120, 40, 119, 44, 104, 41, 125, 10, 45, 114, 91, 49,
  93, 32, 123, 119, 43, 36, 115, 125, 44, 123, 104, 43, 36, 115, 125, 44,
  49, 44, 52, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10,
  45, 105, 91, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  49, 44, 51, 32, 45, 102, 99, 91, 49, 93, 32, 36, 123, 49, 49, 45,
  49, 51, 125, 32, 45, 98, 108, 101, 110, 100, 91, 49, 44, 50, 93, 32,
  97, 108, 112, 104, 97, 32, 45, 116, 111, 95, 97, 91, 45, 49, 93, 10,
  45, 105, 102, 32, 36, 52, 32, 45, 115, 104, 91, 49, 93, 32, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 32, 45, 102, 91, 45, 49, 93, 32, 39,
  49, 45, 40, 97, 98, 115, 40, 120, 47, 119, 45, 48, 46, 53, 41, 94,
  36, 114, 43, 97, 98, 115, 40, 121, 47, 104, 45, 48, 46, 53, 41, 94,
  36, 114, 41, 94, 40, 49, 47, 36, 114, 41, 39, 10, 118, 61, 123, 109,
  105, 110, 40, 105, 40, 119, 47, 50, 44, 48, 41, 44, 105, 40, 119, 45,
  49, 44, 104, 47, 50, 41, 44, 105, 40, 119, 47, 50, 44, 104, 45, 49,
  41, 44, 105, 40, 48, 44, 104, 47, 50, 41, 41, 125, 10, 45, 99, 91,
  45, 49, 93, 32, 36, 118, 44, 123, 36, 118, 43, 48, 46, 53, 47, 109,
  97, 120, 40, 119, 44, 104, 41, 125, 32, 45, 110, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 91, 49, 93, 32, 91, 48, 93, 44, 91,
  48, 93, 44, 49, 44, 52, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48,
  46, 53, 10, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 49, 93,
  32, 49, 48, 48, 37, 32, 45, 98, 91, 45, 49, 93, 32, 36, 49, 54,
  37, 44, 48, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 123, 109, 97,
  120, 40, 49, 44, 49, 48, 48, 45, 36, 49, 55, 41, 125, 37, 32, 45,
  110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 115, 104, 105,
  102, 116, 91, 45, 49, 93, 32, 36, 49, 52, 37, 44, 36, 49, 53, 37,
  44, 48, 44, 48, 44, 48, 32, 45, 47, 91, 45, 49, 93, 32, 45, 50,
  53, 53, 32, 45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 42, 91, 48,
  44, 45, 49, 93, 10, 45, 98, 108, 101, 110, 100, 32, 97, 108, 112, 104,
  97, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105,
  109, 112, 95, 102, 114, 97, 109, 101, 95, 102, 117, 122, 122, 121, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 40, 123, 119, 42,
  36, 49, 47, 50, 48, 48, 125, 44, 123, 104, 42, 36, 50, 47, 50, 48,
  48, 125, 41, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 49,
  10, 45, 102, 114, 97, 109, 101, 95, 102, 117, 122, 122, 121, 91, 45, 50,
  93, 32, 64, 45, 49, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36,
  54, 44, 36, 55, 44, 36, 56, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10,
  103, 105, 109, 112, 95, 102, 114, 97, 109, 101, 95, 112, 97, 105, 110, 116,
  105, 110, 103, 32, 58, 10, 45, 105, 102, 32, 36, 49, 52, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 44, 52, 32, 45, 102, 114, 97, 109, 101, 95, 112, 97,
  105, 110, 116, 105, 110, 103, 91, 45, 49, 93, 32, 36, 49, 37, 44, 36,
  50, 44, 36, 51, 37, 44, 36, 123, 52, 45, 54, 125, 44, 36, 55, 37,
  44, 36, 123, 56, 45, 49, 51, 125, 10, 45, 114, 118, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 116, 111, 95, 97, 91, 45, 49, 93, 32, 45, 114,
  91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 49,
  44, 52, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45,
  109, 118, 91, 45, 50, 44, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110,
  101, 10, 45, 101, 108, 115, 101, 32, 45, 102, 114, 97, 109, 101, 95, 112,
  97, 105, 110, 116, 105, 110, 103, 32, 36, 49, 37, 44, 36, 50, 44, 36,
  51, 37, 44, 36, 123, 52, 45, 54, 125, 44, 36, 55, 37, 44, 36, 123,
  56, 45, 49, 51, 125, 10, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109,
  112, 95, 102, 114, 97, 109, 101, 95, 112, 97, 105, 110, 116, 105, 110, 103,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 102, 114, 97, 109,
  101, 95, 112, 97, 105, 110, 116, 105, 110, 103, 32, 36, 49, 37, 44, 36,
  50, 44, 36, 51, 37, 44, 36, 123, 52, 45, 54, 125, 44, 36, 55, 37,
  44, 36, 123, 56, 45, 49, 51, 125, 10, 103, 105, 109, 112, 95, 102, 114,
  97, 109, 101, 95, 112, 97, 116, 116, 101, 114, 110, 32, 58, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 51, 32, 45, 102, 114, 97, 109, 101, 95,
  112, 97, 116, 116, 101, 114, 110, 32, 36, 49, 44, 36, 50, 44, 36, 52,
  32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 102, 114, 97, 109,
  101, 95, 112, 97, 116, 116, 101, 114, 110, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 102, 114, 97, 109, 101, 95,
  112, 97, 116, 116, 101, 114, 110, 32, 36, 49, 44, 36, 50, 44, 36, 51,
  44, 49, 10, 103, 105, 109, 112, 95, 102, 114, 97, 109, 101, 32, 58, 10,
  45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 10, 45, 122, 91, 45, 49, 93, 32, 36, 49, 37, 44, 36,
  51, 37, 44, 36, 50, 37, 44, 36, 52, 37, 10, 45, 102, 114, 97, 109,
  101, 91, 45, 49, 93, 32, 36, 49, 49, 44, 36, 49, 49, 44, 36, 123,
  49, 50, 45, 49, 53, 125, 10, 45, 102, 114, 97, 109, 101, 91, 45, 49,
  93, 32, 36, 53, 37, 44, 36, 54, 37, 44, 36, 123, 55, 45, 49, 48,
  125, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110,
  101, 10, 103, 105, 109, 112, 95, 102, 114, 97, 109, 101, 95, 114, 111, 117,
  110, 100, 32, 58, 10, 45, 102, 114, 97, 109, 101, 95, 114, 111, 117, 110,
  100, 32, 36, 123, 49, 45, 56, 125, 10, 45, 105, 102, 32, 36, 57, 32,
  45, 102, 114, 97, 109, 101, 95, 98, 108, 117, 114, 32, 36, 49, 44, 123,
  109, 105, 110, 40, 57, 57, 44, 36, 49, 43, 36, 57, 41, 125, 44, 36,
  51, 44, 36, 49, 48, 44, 36, 49, 49, 37, 32, 45, 101, 110, 100, 105,
  102, 10, 103, 105, 109, 112, 95, 111, 108, 100, 95, 112, 104, 111, 116, 111,
  32, 58, 10, 45, 118, 105, 103, 110, 101, 116, 116, 101, 32, 36, 123, 49,
  45, 51, 125, 32, 45, 111, 108, 100, 95, 112, 104, 111, 116, 111, 10, 103,
  105, 109, 112, 95, 112, 111, 108, 97, 114, 111, 105, 100, 32, 58, 10, 45,
  118, 105, 103, 110, 101, 116, 116, 101, 32, 36, 123, 55, 45, 57, 125, 32,
  45, 112, 111, 108, 97, 114, 111, 105, 100, 32, 36, 49, 44, 36, 50, 32,
  45, 100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119, 32, 36, 51, 37,
  44, 36, 52, 37, 44, 36, 53, 37, 32, 45, 114, 111, 116, 97, 116, 101,
  32, 36, 54, 44, 49, 44, 48, 10, 103, 105, 109, 112, 95, 116, 117, 110,
  110, 101, 108, 32, 58, 10, 45, 116, 117, 110, 110, 101, 108, 32, 36, 49,
  44, 36, 50, 37, 44, 36, 123, 51, 45, 54, 125, 10, 103, 105, 109, 112,
  95, 118, 105, 103, 110, 101, 116, 116, 101, 32, 58, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45,
  115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 61,
  91, 45, 49, 93, 32, 48, 32, 45, 118, 105, 103, 110, 101, 116, 116, 101,
  91, 45, 49, 93, 32, 36, 123, 49, 45, 51, 125, 32, 45, 97, 32, 99,
  32, 45, 45, 102, 99, 32, 36, 123, 52, 45, 55, 125, 32, 45, 98, 108,
  101, 110, 100, 32, 97, 108, 112, 104, 97, 44, 49, 44, 49, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 98,
  108, 101, 110, 100, 95, 97, 118, 101, 114, 97, 103, 101, 95, 97, 108, 108,
  32, 58, 10, 45, 105, 102, 32, 64, 35, 10, 78, 61, 64, 35, 32, 45,
  43, 32, 45, 47, 32, 36, 78, 10, 45, 101, 110, 100, 105, 102, 10, 103,
  105, 109, 112, 95, 98, 108, 101, 110, 100, 32, 58, 10, 109, 111, 100, 101,
  61, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 36, 49, 44, 97, 100,
  100, 44, 97, 108, 112, 104, 97, 44, 97, 110, 100, 44, 97, 118, 101, 114,
  97, 103, 101, 44, 98, 108, 117, 101, 44, 98, 117, 114, 110, 44, 100, 97,
  114, 107, 101, 110, 44, 100, 105, 102, 102, 101, 114, 101, 110, 99, 101, 44,
  92, 10, 100, 105, 118, 105, 100, 101, 44, 100, 111, 100, 103, 101, 44, 101,
  120, 99, 108, 117, 115, 105, 111, 110, 44, 102, 114, 101, 101, 122, 101, 44,
  103, 114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116, 44, 103, 114, 97,
  105, 110, 109, 101, 114, 103, 101, 44, 103, 114, 101, 101, 110, 44, 104, 97,
  114, 100, 108, 105, 103, 104, 116, 44, 92, 10, 104, 97, 114, 100, 109, 105,
  120, 44, 104, 117, 101, 44, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116,
  105, 111, 110, 44, 108, 105, 103, 104, 116, 101, 110, 44, 108, 105, 103, 104,
  116, 110, 101, 115, 115, 44, 108, 105, 110, 101, 97, 114, 98, 117, 114, 110,
  44, 108, 105, 110, 101, 97, 114, 108, 105, 103, 104, 116, 44, 108, 117, 109,
  105, 110, 97, 110, 99, 101, 44, 92, 10, 109, 117, 108, 116, 105, 112, 108,
  121, 44, 110, 101, 103, 97, 116, 105, 111, 110, 44, 111, 114, 44, 111, 118,
  101, 114, 108, 97, 121, 44, 112, 105, 110, 108, 105, 103, 104, 116, 44, 114,
  101, 100, 44, 114, 101, 102, 108, 101, 99, 116, 44, 115, 97, 116, 117, 114,
  97, 116, 105, 111, 110, 44, 92, 10, 115, 104, 97, 112, 101, 97, 118, 101,
  114, 97, 103, 101, 44, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97, 103,
  101, 48, 44, 115, 111, 102, 116, 98, 117, 114, 110, 44, 115, 111, 102, 116,
  100, 111, 100, 103, 101, 44, 115, 111, 102, 116, 108, 105, 103, 104, 116, 44,
  115, 99, 114, 101, 101, 110, 44, 115, 116, 97, 109, 112, 44, 115, 117, 98,
  116, 114, 97, 99, 116, 44, 118, 97, 108, 117, 101, 44, 92, 10, 118, 105,
  118, 105, 100, 108, 105, 103, 104, 116, 44, 120, 111, 114, 125, 10, 45, 98,
  108, 101, 110, 100, 32, 36, 109, 111, 100, 101, 44, 36, 50, 44, 123, 49,
  45, 36, 51, 125, 10, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 95,
  101, 100, 103, 101, 115, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36,
  62, 44, 123, 36, 62, 43, 49, 125, 93, 32, 45, 105, 102, 32, 36, 51,
  32, 45, 114, 118, 32, 45, 101, 110, 100, 105, 102, 32, 45, 45, 98, 108,
  101, 110, 100, 95, 101, 100, 103, 101, 115, 91, 45, 50, 44, 45, 49, 93,
  32, 36, 50, 32, 45, 114, 109, 91, 45, 51, 93, 32, 45, 98, 108, 101,
  110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 97, 108, 112, 104, 97, 44,
  36, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103,
  105, 109, 112, 95, 98, 108, 101, 110, 100, 95, 102, 97, 100, 101, 32, 58,
  10, 45, 105, 102, 32, 123, 64, 35, 61, 61, 49, 125, 32, 45, 114, 101,
  116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95,
  99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 52, 10, 45, 105, 102, 32,
  123, 36, 55, 61, 61, 49, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 115, 104, 91, 36, 62, 93, 32, 48, 44, 50, 32, 45,
  114, 103, 98, 50, 104, 115, 118, 91, 45, 49, 93, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 55, 61, 61, 50, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 115, 104, 91, 36, 62, 93, 32, 48, 44, 50, 32, 45,
  115, 114, 103, 98, 50, 114, 103, 98, 91, 45, 49, 93, 32, 45, 114, 103,
  98, 50, 108, 97, 98, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49,
  93, 32, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 49, 61, 61, 48, 125, 32, 91, 48, 93, 44, 91,
  48, 93, 44, 49, 44, 49, 44, 34, 36, 49, 49, 34, 10, 45, 101, 108,
  115, 101, 32, 45, 95, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 95,
  102, 97, 100, 101, 36, 49, 32, 36, 56, 44, 36, 57, 44, 36, 49, 48,
  32, 45, 114, 91, 45, 49, 93, 32, 91, 48, 93, 44, 91, 48, 93, 44,
  49, 44, 49, 44, 51, 10, 45, 101, 110, 100, 105, 102, 10, 45, 110, 91,
  45, 49, 93, 32, 123, 45, 40, 64, 35, 45, 50, 41, 42, 36, 51, 125,
  44, 123, 40, 64, 35, 45, 50, 41, 42, 40, 49, 43, 36, 51, 41, 125,
  10, 45, 45, 91, 45, 49, 93, 32, 123, 36, 50, 42, 40, 49, 43, 36,
  51, 41, 42, 40, 64, 35, 45, 50, 41, 125, 10, 45, 99, 91, 45, 49,
  93, 32, 48, 44, 123, 64, 35, 45, 50, 125, 10, 45, 105, 102, 32, 36,
  54, 32, 45, 114, 118, 91, 94, 45, 49, 93, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 36, 53, 32, 45, 114, 111, 117, 110, 100, 91,
  45, 49, 93, 32, 49, 10, 45, 101, 108, 115, 101, 32, 45, 114, 111, 117,
  110, 100, 105, 102, 121, 91, 45, 49, 93, 32, 36, 52, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 98, 108, 101, 110, 100, 95, 102, 97, 100, 101, 10,
  45, 105, 102, 32, 123, 36, 55, 61, 61, 49, 125, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 115, 104, 91, 36, 62, 93, 32, 48,
  44, 50, 32, 45, 104, 115, 118, 50, 114, 103, 98, 91, 45, 49, 93, 32,
  45, 114, 109, 91, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 55, 61, 61, 50, 125, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 115, 104, 91, 36, 62, 93, 32, 48,
  44, 50, 32, 45, 108, 97, 98, 50, 114, 103, 98, 91, 45, 49, 93, 32,
  45, 114, 103, 98, 50, 115, 114, 103, 98, 91, 45, 49, 93, 32, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10, 95, 103, 105, 109,
  112, 95, 98, 108, 101, 110, 100, 95, 102, 97, 100, 101, 49, 32, 58, 32,
  91, 48, 93, 44, 91, 48, 93, 44, 49, 44, 49, 44, 34, 97, 61, 36,
  49, 42, 112, 105, 47, 50, 59, 32, 120, 42, 99, 111, 115, 40, 97, 41,
  32, 43, 32, 121, 42, 115, 105, 110, 40, 97, 41, 34, 10, 95, 103, 105,
  109, 112, 95, 98, 108, 101, 110, 100, 95, 102, 97, 100, 101, 50, 32, 58,
  32, 91, 48, 93, 44, 91, 48, 93, 44, 49, 44, 49, 44, 48, 32, 45,
  61, 91, 45, 49, 93, 32, 49, 44, 123, 40, 36, 49, 43, 49, 41, 42,
  53, 48, 125, 37, 44, 123, 40, 36, 50, 43, 49, 41, 42, 53, 48, 125,
  37, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32,
  49, 10, 95, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 95, 102, 97,
  100, 101, 51, 32, 58, 32, 91, 48, 93, 44, 91, 48, 93, 44, 49, 44,
  49, 44, 48, 32, 45, 61, 91, 45, 49, 93, 32, 49, 44, 123, 40, 36,
  49, 43, 49, 41, 42, 53, 48, 125, 37, 44, 123, 40, 36, 50, 43, 49,
  41, 42, 53, 48, 125, 37, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101,
  91, 45, 49, 93, 32, 49, 32, 45, 42, 91, 45, 49, 93, 32, 123, 48,
  46, 48, 49, 43, 36, 51, 47, 50, 125, 32, 45, 99, 111, 115, 91, 45,
  49, 93, 10, 95, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 95, 102,
  97, 100, 101, 52, 32, 58, 32, 91, 48, 93, 44, 91, 48, 93, 44, 49,
  44, 49, 44, 34, 40, 40, 120, 45, 119, 42, 40, 36, 49, 43, 48, 46,
  53, 41, 41, 42, 40, 121, 45, 104, 42, 40, 36, 50, 43, 48, 46, 53,
  41, 41, 41, 37, 40, 48, 46, 50, 42, 119, 42, 104, 42, 40, 49, 46,
  48, 48, 49, 43, 36, 51, 41, 41, 34, 10, 103, 105, 109, 112, 95, 97,
  108, 105, 103, 110, 95, 108, 97, 121, 101, 114, 115, 32, 58, 10, 45, 105,
  102, 32, 36, 123, 52, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95,
  114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97,
  99, 105, 116, 121, 10, 45, 105, 102, 32, 36, 49, 32, 45, 114, 101, 103,
  105, 115, 116, 101, 114, 95, 110, 111, 110, 114, 105, 103, 105, 100, 32, 36,
  50, 44, 48, 46, 49, 44, 36, 51, 10, 45, 101, 108, 115, 101, 32, 40,
  36, 50, 41, 32, 45, 42, 91, 45, 49, 93, 32, 51, 32, 45, 114, 101,
  103, 105, 115, 116, 101, 114, 95, 114, 105, 103, 105, 100, 91, 94, 45, 49,
  93, 32, 64, 45, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101,
  110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 97, 108, 105, 103, 110, 95,
  108, 97, 121, 101, 114, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 97, 108, 105, 103, 110, 95, 108, 97, 121,
  101, 114, 115, 32, 36, 49, 44, 36, 50, 44, 48, 32, 45, 98, 108, 101,
  110, 100, 95, 101, 100, 103, 101, 115, 32, 48, 46, 49, 10, 95, 103, 105,
  109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115,
  32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40,
  64, 35, 47, 50, 41, 125, 32, 45, 114, 118, 91, 123, 50, 42, 36, 62,
  125, 44, 123, 50, 42, 36, 62, 43, 49, 125, 93, 32, 45, 100, 111, 110,
  101, 10, 103, 105, 109, 112, 95, 102, 97, 100, 101, 95, 108, 97, 121, 101,
  114, 115, 32, 58, 10, 45, 105, 102, 32, 123, 64, 35, 60, 50, 125, 32,
  45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  97, 32, 122, 32, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 123, 40, 100, 45, 49, 41, 42, 36, 49, 43, 49, 125, 44, 49, 48,
  48, 37, 44, 51, 32, 45, 115, 32, 122, 10, 103, 105, 109, 112, 95, 102,
  97, 100, 101, 95, 108, 97, 121, 101, 114, 115, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 105, 102, 32, 123, 64, 35, 60, 50, 125, 32,
  45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  107, 91, 48, 44, 49, 93, 32, 45, 43, 32, 45, 47, 32, 50, 10, 103,
  105, 109, 112, 95, 109, 111, 114, 112, 104, 32, 58, 10, 45, 105, 102, 32,
  36, 123, 52, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101,
  118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 116, 111, 95, 114, 103, 98, 32, 45, 109, 111, 114, 112,
  104, 32, 36, 49, 44, 36, 50, 44, 36, 51, 10, 103, 105, 109, 112, 95,
  97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 102, 114, 97, 109, 101, 32, 49, 44,
  49, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 32, 45, 97, 112, 112,
  101, 110, 100, 95, 116, 105, 108, 101, 115, 32, 36, 49, 44, 36, 50, 10,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 116, 105, 108, 101, 115,
  32, 58, 10, 45, 115, 112, 108, 105, 116, 95, 116, 105, 108, 101, 115, 32,
  36, 49, 44, 36, 50, 44, 36, 51, 32, 45, 107, 91, 53, 48, 37, 93,
  10, 103, 105, 109, 112, 95, 116, 114, 97, 110, 115, 102, 101, 114, 95, 99,
  111, 108, 111, 114, 115, 32, 58, 10, 45, 105, 102, 32, 36, 123, 50, 61,
  48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116,
  95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  116, 114, 97, 110, 115, 102, 101, 114, 95, 99, 111, 108, 111, 114, 115, 32,
  36, 49, 10, 103, 105, 109, 112, 95, 116, 114, 97, 110, 115, 112, 97, 114,
  101, 110, 116, 95, 100, 105, 102, 102, 32, 58, 10, 45, 105, 102, 32, 36,
  123, 53, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118,
  101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64,
  35, 47, 50, 41, 125, 10, 45, 105, 102, 32, 36, 51, 10, 45, 45, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 110, 111, 114, 109, 91, 45,
  50, 93, 32, 45, 98, 91, 45, 50, 93, 32, 36, 50, 37, 32, 45, 103,
  101, 91, 45, 50, 93, 32, 36, 49, 37, 32, 45, 114, 118, 91, 45, 50,
  44, 45, 49, 93, 10, 45, 101, 108, 115, 101, 10, 45, 45, 91, 45, 49,
  93, 32, 91, 45, 50, 93, 32, 45, 110, 111, 114, 109, 91, 45, 49, 93,
  32, 45, 98, 91, 45, 49, 93, 32, 36, 50, 37, 32, 45, 103, 101, 91,
  45, 49, 93, 32, 36, 49, 37, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 33, 36, 52, 125, 32, 45, 110, 101, 103, 97, 116, 105,
  118, 101, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116,
  111, 95, 114, 103, 98, 97, 91, 45, 50, 93, 32, 45, 42, 91, 45, 50,
  44, 45, 49, 93, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45,
  100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  116, 111, 110, 101, 115, 32, 58, 10, 45, 114, 101, 109, 111, 118, 101, 95,
  111, 112, 97, 99, 105, 116, 121, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 60, 93, 10, 45, 45, 116, 111, 110, 101,
  115, 32, 36, 49, 32, 45, 114, 91, 94, 48, 93, 32, 91, 48, 93, 32,
  45, 42, 91, 94, 48, 93, 32, 91, 48, 93, 32, 45, 114, 109, 91, 48,
  93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 116, 111, 110, 101, 115, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115,
  112, 108, 105, 116, 95, 116, 111, 110, 101, 115, 32, 36, 49, 32, 45, 97,
  112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 32, 44, 10, 95, 103,
  105, 109, 112, 95, 98, 117, 114, 110, 32, 58, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 61, 123,
  119, 125, 32, 104, 61, 123, 104, 125, 10, 45, 45, 110, 111, 114, 109, 10,
  45, 103, 105, 109, 112, 95, 102, 111, 117, 114, 105, 101, 114, 91, 45, 49,
  93, 32, 48, 10, 45, 45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 48,
  44, 123, 36, 104, 45, 49, 125, 32, 45, 114, 91, 45, 49, 93, 32, 36,
  50, 37, 44, 36, 50, 37, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 98, 91, 45, 49, 93,
  32, 36, 51, 37, 10, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  44, 123, 40, 36, 119, 45, 119, 41, 47, 50, 125, 44, 123, 40, 36, 104,
  45, 104, 41, 47, 50, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  103, 105, 109, 112, 95, 102, 111, 117, 114, 105, 101, 114, 91, 45, 49, 93,
  32, 49, 10, 45, 98, 108, 101, 110, 100, 32, 111, 118, 101, 114, 108, 97,
  121, 44, 36, 49, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 103, 105, 109, 112, 95, 98, 117, 114, 110, 32, 58, 10, 45, 97, 112,
  112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 95,
  103, 105, 109, 112, 95, 98, 117, 114, 110, 32, 36, 123, 49, 45, 51, 125,
  34, 44, 36, 52, 44, 49, 10, 103, 105, 109, 112, 95, 98, 117, 114, 110,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 103, 105, 109, 112, 95, 98, 117, 114, 110, 32, 36, 123, 94, 48, 125,
  34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 99, 111, 110, 116, 114,
  97, 115, 116, 95, 115, 119, 109, 32, 58, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108,
  105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91, 48, 93,
  10, 45, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 116, 111,
  95, 114, 103, 98, 10, 45, 98, 108, 117, 114, 95, 120, 121, 91, 49, 93,
  32, 36, 49, 44, 36, 49, 10, 45, 105, 102, 32, 123, 36, 50, 61, 61,
  48, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 49, 93, 32,
  45, 101, 108, 105, 102, 32, 123, 36, 50, 61, 61, 49, 125, 32, 45, 103,
  105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 114, 118, 32, 45, 98, 108, 101, 110, 100,
  32, 104, 97, 114, 100, 108, 105, 103, 104, 116, 44, 36, 51, 10, 45, 101,
  110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 100, 114, 111, 112, 95, 115,
  104, 97, 100, 111, 119, 32, 58, 10, 45, 42, 32, 45, 49, 32, 45, 43,
  32, 50, 53, 53, 32, 45, 118, 105, 103, 110, 101, 116, 116, 101, 32, 123,
  50, 53, 53, 42, 36, 53, 125, 44, 56, 48, 44, 57, 53, 32, 45, 42,
  32, 45, 49, 32, 45, 43, 32, 50, 53, 53, 10, 45, 100, 114, 111, 112,
  95, 115, 104, 97, 100, 111, 119, 32, 36, 49, 37, 44, 36, 50, 37, 44,
  36, 51, 37, 44, 36, 52, 32, 45, 114, 111, 116, 97, 116, 101, 32, 36,
  54, 44, 49, 44, 48, 10, 103, 105, 109, 112, 95, 100, 114, 111, 112, 95,
  115, 104, 97, 100, 111, 119, 51, 100, 32, 58, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 60, 93, 10, 45, 45, 95,
  103, 105, 109, 112, 95, 100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119,
  51, 100, 32, 36, 42, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 103, 105, 109, 112, 95, 100, 114, 111, 112, 95, 115, 104, 97, 100,
  111, 119, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 60, 93,
  10, 45, 105, 102, 32, 36, 49, 51, 32, 45, 95, 103, 105, 109, 112, 95,
  100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119, 51, 100, 32, 36, 42,
  10, 45, 101, 108, 115, 101, 32, 45, 45, 95, 103, 105, 109, 112, 95, 100,
  114, 111, 112, 95, 115, 104, 97, 100, 111, 119, 51, 100, 32, 36, 42, 32,
  45, 114, 118, 32, 45, 98, 108, 101, 110, 100, 32, 97, 108, 112, 104, 97,
  44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 95, 103, 105, 109, 112, 95, 100, 114, 111, 112,
  95, 115, 104, 97, 100, 111, 119, 51, 100, 32, 58, 10, 45, 112, 111, 105,
  110, 116, 51, 100, 32, 48, 44, 48, 44, 49, 32, 45, 114, 51, 100, 91,
  45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 36, 49, 32, 45, 114, 51,
  100, 91, 45, 49, 93, 32, 48, 44, 49, 44, 48, 44, 36, 50, 32, 45,
  114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 48, 44, 49, 44, 36, 51,
  10, 117, 61, 123, 105, 40, 48, 44, 56, 41, 125, 32, 118, 61, 123, 105,
  40, 48, 44, 57, 41, 125, 32, 119, 61, 123, 105, 40, 48, 44, 49, 48,
  41, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 116, 111, 95, 97,
  32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 49, 48, 48, 37, 32,
  45, 105, 102, 32, 123, 105, 109, 61, 61, 105, 77, 125, 32, 45, 114, 101,
  116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 102, 32,
  39, 88, 61, 120, 47, 119, 45, 48, 46, 53, 59, 89, 61, 121, 47, 104,
  45, 48, 46, 53, 59, 65, 61, 40, 36, 55, 45, 36, 52, 42, 36, 55,
  47, 49, 48, 48, 41, 42, 36, 119, 47, 40, 88, 42, 36, 117, 43, 89,
  42, 36, 118, 43, 36, 55, 42, 36, 119, 41, 59, 105, 102, 40, 65, 60,
  48, 44, 49, 101, 56, 44, 65, 41, 39, 10, 45, 45, 42, 91, 45, 49,
  93, 32, 39, 121, 47, 104, 45, 48, 46, 53, 39, 32, 45, 42, 91, 45,
  50, 93, 32, 39, 120, 47, 119, 45, 48, 46, 53, 39, 32, 45, 43, 91,
  45, 50, 93, 32, 123, 48, 46, 53, 45, 36, 53, 47, 49, 48, 48, 125,
  32, 45, 43, 91, 45, 49, 93, 32, 123, 48, 46, 53, 45, 36, 54, 47,
  49, 48, 48, 125, 32, 45, 42, 91, 45, 50, 93, 32, 123, 119, 125, 32,
  45, 42, 91, 45, 49, 93, 32, 123, 104, 125, 10, 45, 97, 91, 45, 50,
  44, 45, 49, 93, 32, 99, 32, 45, 119, 97, 114, 112, 91, 48, 93, 32,
  91, 45, 49, 93, 44, 48, 44, 49, 44, 48, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 98, 32, 36, 56, 37, 32, 45, 110, 32, 48, 44, 36,
  49, 50, 32, 45, 105, 91, 45, 50, 93, 32, 40, 36, 57, 94, 36, 49,
  48, 94, 36, 49, 49, 41, 32, 45, 114, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 44, 91, 45, 49, 93, 44, 49, 44, 51, 32, 45, 97, 91, 45,
  50, 44, 45, 49, 93, 32, 99, 10, 103, 105, 109, 112, 95, 101, 113, 117,
  97, 108, 105, 122, 101, 95, 115, 104, 97, 100, 111, 119, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 45, 45, 110, 101, 103, 97, 116, 105, 118, 101, 32, 45, 98, 108, 101,
  110, 100, 32, 115, 111, 102, 116, 108, 105, 103, 104, 116, 44, 36, 49, 32,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112,
  95, 101, 113, 117, 97, 108, 105, 122, 101, 95, 115, 104, 97, 100, 111, 119,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 103, 105, 109, 112, 95, 101, 113, 117, 97, 108, 105, 122, 101, 95, 115,
  104, 97, 100, 111, 119, 32, 36, 49, 34, 44, 36, 45, 49, 10, 95, 103,
  105, 109, 112, 95, 108, 105, 103, 104, 116, 103, 108, 111, 119, 32, 58, 10,
  109, 111, 100, 101, 61, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 36,
  51, 44, 98, 117, 114, 110, 44, 100, 111, 100, 103, 101, 44, 102, 114, 101,
  101, 122, 101, 44, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 44, 104,
  97, 114, 100, 108, 105, 103, 104, 116, 44, 105, 110, 116, 101, 114, 112, 111,
  108, 97, 116, 105, 111, 110, 44, 108, 105, 103, 104, 116, 101, 110, 44, 109,
  117, 108, 116, 105, 112, 108, 121, 44, 111, 118, 101, 114, 108, 97, 121, 44,
  114, 101, 102, 108, 101, 99, 116, 44, 115, 111, 102, 116, 108, 105, 103, 104,
  116, 44, 115, 116, 97, 109, 112, 44, 118, 97, 108, 117, 101, 125, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 45, 103, 114, 97, 100,
  105, 101, 110, 116, 95, 110, 111, 114, 109, 91, 45, 49, 93, 32, 45, 103,
  101, 91, 45, 49, 93, 32, 123, 49, 48, 48, 45, 36, 49, 125, 37, 32,
  45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32,
  45, 94, 91, 45, 49, 93, 32, 36, 50, 32, 45, 42, 91, 45, 49, 93,
  32, 45, 49, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  32, 45, 98, 108, 101, 110, 100, 32, 36, 109, 111, 100, 101, 44, 36, 52,
  10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101,
  10, 103, 105, 109, 112, 95, 108, 105, 103, 104, 116, 103, 108, 111, 119, 32,
  58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 34, 45, 95, 103, 105, 109, 112, 95, 108, 105, 103, 104, 116, 103,
  108, 111, 119, 32, 36, 123, 49, 45, 52, 125, 34, 44, 36, 53, 44, 48,
  10, 103, 105, 109, 112, 95, 108, 105, 103, 104, 116, 103, 108, 111, 119, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  103, 105, 109, 112, 95, 108, 105, 103, 104, 116, 103, 108, 111, 119, 32, 36,
  42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 108, 105, 103, 104,
  116, 95, 112, 97, 116, 99, 104, 32, 58, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108,
  105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91, 48, 93,
  10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 34, 45, 108, 105, 103, 104, 116, 95, 112, 97, 116, 99, 104, 32, 36,
  49, 44, 36, 50, 44, 36, 51, 34, 44, 36, 52, 44, 48, 10, 45, 101,
  110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 108, 105, 103, 104, 116, 114,
  97, 121, 115, 32, 58, 10, 45, 108, 105, 103, 104, 116, 114, 97, 121, 115,
  32, 36, 123, 49, 45, 53, 125, 10, 45, 105, 102, 32, 36, 54, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 114, 91, 36, 62, 93,
  32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 123, 64, 123,
  36, 62, 44, 115, 125, 43, 40, 64, 123, 36, 62, 44, 115, 125, 37, 50,
  41, 125, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 10,
  103, 105, 109, 112, 95, 108, 105, 103, 104, 116, 95, 114, 101, 108, 105, 101,
  102, 32, 58, 10, 45, 98, 32, 36, 49, 49, 37, 32, 45, 108, 105, 103,
  104, 116, 95, 114, 101, 108, 105, 101, 102, 32, 36, 123, 49, 45, 49, 48,
  125, 10, 103, 105, 109, 112, 95, 115, 104, 97, 100, 111, 119, 95, 112, 97,
  116, 99, 104, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111,
  112, 97, 99, 105, 116, 121, 32, 45, 108, 91, 48, 93, 10, 45, 97, 112,
  112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 115,
  104, 97, 100, 111, 119, 95, 112, 97, 116, 99, 104, 32, 36, 49, 34, 44,
  36, 50, 44, 48, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112,
  95, 98, 111, 120, 102, 105, 116, 116, 105, 110, 103, 32, 58, 10, 45, 98,
  111, 120, 102, 105, 116, 116, 105, 110, 103, 32, 36, 123, 49, 45, 51, 125,
  44, 51, 10, 45, 105, 102, 32, 36, 52, 32, 45, 116, 111, 95, 114, 103,
  98, 97, 32, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111,
  114, 32, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44,
  48, 44, 48, 44, 48, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 103,
  105, 109, 112, 95, 98, 111, 120, 102, 105, 116, 116, 105, 110, 103, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 98, 111, 120, 102, 105, 116,
  116, 105, 110, 103, 32, 36, 123, 49, 45, 51, 125, 44, 49, 10, 45, 105,
  102, 32, 36, 52, 32, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 114,
  101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 32, 48, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48,
  44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 99,
  97, 110, 118, 97, 115, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 45, 49, 93, 10, 45, 105, 102, 32, 36, 52,
  10, 40, 123, 99, 111, 115, 40, 36, 50, 42, 112, 105, 47, 49, 56, 48,
  41, 125, 94, 123, 115, 105, 110, 40, 36, 50, 42, 112, 105, 47, 49, 56,
  48, 41, 125, 41, 32, 45, 118, 101, 99, 116, 111, 114, 50, 116, 101, 110,
  115, 111, 114, 91, 45, 49, 93, 32, 45, 114, 91, 45, 49, 93, 32, 91,
  45, 50, 93, 44, 91, 45, 50, 93, 32, 45, 45, 115, 109, 111, 111, 116,
  104, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 49, 32, 45, 114,
  109, 91, 45, 50, 93, 32, 45, 115, 104, 97, 114, 112, 101, 110, 91, 45,
  49, 93, 32, 36, 51, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 10, 40, 123, 99, 111, 115, 40, 36, 54, 42, 112, 105, 47, 49,
  56, 48, 41, 125, 94, 123, 115, 105, 110, 40, 36, 54, 42, 112, 105, 47,
  49, 56, 48, 41, 125, 41, 32, 45, 118, 101, 99, 116, 111, 114, 50, 116,
  101, 110, 115, 111, 114, 91, 45, 49, 93, 32, 45, 114, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 32, 45, 115, 109, 111, 111,
  116, 104, 91, 45, 51, 93, 32, 91, 45, 49, 93, 44, 36, 53, 32, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 115, 104, 97, 114, 112, 101, 110, 91,
  45, 50, 93, 32, 36, 55, 32, 45, 99, 91, 45, 50, 93, 32, 48, 44,
  50, 53, 53, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 47,
  91, 45, 49, 93, 32, 50, 10, 45, 101, 108, 115, 101, 10, 40, 123, 99,
  111, 115, 40, 36, 50, 42, 112, 105, 47, 49, 56, 48, 41, 125, 94, 123,
  115, 105, 110, 40, 36, 50, 42, 112, 105, 47, 49, 56, 48, 41, 125, 41,
  32, 45, 118, 101, 99, 116, 111, 114, 50, 116, 101, 110, 115, 111, 114, 91,
  45, 49, 93, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44,
  91, 45, 50, 93, 32, 45, 115, 109, 111, 111, 116, 104, 91, 45, 50, 93,
  32, 91, 45, 49, 93, 44, 36, 49, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 115, 104, 97, 114, 112, 101, 110, 91, 45, 49, 93, 32, 36, 51,
  32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 109, 118, 91, 45,
  49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95,
  99, 97, 110, 118, 97, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 99, 97, 110, 118,
  97, 115, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95,
  99, 114, 97, 99, 107, 115, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 99, 114, 97, 99, 107,
  115, 32, 36, 49, 44, 36, 50, 44, 36, 51, 34, 44, 36, 52, 44, 48,
  10, 103, 105, 109, 112, 95, 99, 114, 97, 99, 107, 115, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109,
  112, 95, 99, 114, 97, 99, 107, 115, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 103, 105, 109, 112, 95, 104, 97, 108, 102, 116, 111, 110, 101, 32, 58,
  10, 45, 97, 112, 112, 108, 121, 95, 103, 97, 109, 109, 97, 32, 123, 49,
  48, 94, 36, 49, 125, 32, 45, 45, 32, 49, 50, 56, 32, 45, 42, 32,
  36, 50, 32, 45, 43, 32, 49, 50, 56, 32, 45, 43, 32, 36, 51, 32,
  45, 98, 32, 36, 52, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 10,
  45, 104, 97, 108, 102, 116, 111, 110, 101, 91, 48, 93, 32, 36, 123, 53,
  45, 57, 125, 10, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 104, 97, 108, 102, 116, 111,
  110, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 104, 97, 108, 102, 116, 111, 110, 101,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 104, 101,
  97, 114, 116, 115, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104,
  97, 110, 110, 101, 108, 115, 32, 34, 45, 104, 101, 97, 114, 116, 115, 32,
  36, 49, 34, 44, 36, 50, 44, 48, 10, 103, 105, 109, 112, 95, 104, 101,
  97, 114, 116, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 104, 101, 97, 114, 116, 115,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 108, 97,
  118, 97, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112,
  97, 99, 105, 116, 121, 32, 45, 108, 91, 48, 93, 32, 45, 110, 111, 114,
  109, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 112, 108, 97,
  115, 109, 97, 91, 45, 49, 93, 32, 49, 44, 49, 44, 123, 49, 54, 45,
  36, 49, 125, 32, 45, 115, 109, 111, 111, 116, 104, 91, 45, 49, 93, 32,
  36, 50, 44, 48, 44, 49, 44, 36, 51, 44, 36, 51, 44, 48, 46, 56,
  44, 57, 48, 32, 45, 42, 10, 45, 103, 114, 97, 100, 105, 101, 110, 116,
  95, 110, 111, 114, 109, 32, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45,
  101, 113, 117, 97, 108, 105, 122, 101, 32, 45, 109, 97, 112, 32, 51, 10,
  45, 115, 104, 97, 114, 112, 101, 110, 32, 36, 52, 10, 45, 101, 110, 100,
  108, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 103, 105, 109, 112, 95, 108, 97, 118, 97, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109,
  112, 95, 108, 97, 118, 97, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103,
  105, 109, 112, 95, 109, 97, 114, 98, 108, 101, 32, 58, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45,
  115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108,
  91, 48, 93, 10, 45, 109, 97, 114, 98, 108, 101, 32, 36, 49, 47, 49,
  48, 44, 36, 50, 47, 49, 48, 44, 36, 51, 44, 36, 52, 44, 36, 53,
  44, 36, 54, 44, 36, 55, 44, 36, 56, 44, 36, 57, 37, 44, 36, 49,
  48, 37, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 109,
  97, 122, 101, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 10, 45, 114, 91,
  45, 49, 93, 32, 123, 49, 48, 48, 47, 36, 49, 125, 37, 44, 123, 49,
  48, 48, 47, 36, 49, 125, 37, 44, 49, 44, 49, 48, 48, 37, 44, 50,
  10, 45, 105, 102, 32, 123, 36, 51, 61, 61, 48, 125, 32, 45, 102, 91,
  45, 49, 93, 32, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 51, 61,
  61, 49, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49,
  93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 109, 97, 122, 101, 95, 109,
  97, 115, 107, 91, 45, 49, 93, 32, 36, 49, 32, 45, 100, 105, 108, 97,
  116, 101, 91, 45, 49, 93, 32, 36, 50, 32, 45, 42, 91, 45, 49, 93,
  32, 50, 53, 53, 10, 45, 105, 102, 32, 123, 33, 36, 53, 125, 32, 45,
  110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 36, 52, 32, 45, 114, 91, 45, 49,
  93, 32, 36, 119, 44, 36, 104, 44, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 32, 45, 101, 110, 100, 105, 102, 10, 45, 109, 118, 91, 45, 49, 93,
  32, 48, 32, 45, 100, 111, 110, 101, 10, 100, 116, 95, 109, 105, 110, 101,
  114, 97, 108, 95, 109, 111, 115, 97, 105, 99, 32, 58, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45,
  116, 111, 95, 114, 103, 98, 10, 45, 45, 98, 32, 36, 51, 32, 45, 115,
  101, 103, 109, 101, 110, 116, 95, 119, 97, 116, 101, 114, 115, 104, 101, 100,
  91, 45, 49, 93, 32, 36, 49, 32, 45, 45, 110, 111, 114, 109, 91, 45,
  49, 93, 10, 45, 97, 114, 101, 97, 91, 45, 49, 93, 32, 48, 32, 45,
  45, 108, 101, 91, 45, 49, 93, 32, 123, 36, 50, 94, 50, 125, 32, 45,
  105, 110, 112, 97, 105, 110, 116, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 108, 97, 98, 101, 108, 91,
  45, 49, 93, 10, 45, 45, 102, 91, 48, 93, 32, 39, 105, 102, 40, 99,
  61, 61, 48, 44, 120, 44, 121, 41, 39, 32, 45, 45, 98, 108, 101, 110,
  100, 91, 45, 50, 44, 45, 49, 93, 32, 115, 104, 97, 112, 101, 97, 118,
  101, 114, 97, 103, 101, 44, 49, 44, 49, 10, 45, 45, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 114, 109, 91, 48, 44, 50, 93, 32, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 44, 49, 10, 97,
  108, 112, 104, 97, 61, 123, 36, 53, 42, 112, 105, 47, 49, 56, 48, 125,
  32, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 48, 32, 45, 42, 91,
  45, 49, 93, 32, 123, 99, 111, 115, 40, 36, 97, 108, 112, 104, 97, 41,
  125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 115, 104, 91, 45, 49,
  93, 32, 49, 44, 49, 32, 45, 42, 91, 45, 49, 93, 32, 123, 115, 105,
  110, 40, 36, 97, 108, 112, 104, 97, 41, 125, 32, 45, 114, 109, 91, 45,
  49, 93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 91, 45, 49, 93, 32, 43, 10, 45, 110, 111, 114, 109,
  97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 91, 45, 49, 93, 32,
  49, 48, 48, 48, 32, 45, 110, 91, 45, 49, 93, 32, 45, 36, 52, 44,
  36, 52, 10, 45, 43, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95,
  109, 111, 115, 97, 105, 99, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 109, 111, 115, 97, 105,
  99, 32, 36, 49, 44, 36, 50, 34, 44, 36, 51, 44, 48, 10, 103, 105,
  109, 112, 95, 109, 111, 115, 97, 105, 99, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 109,
  111, 115, 97, 105, 99, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105,
  109, 112, 95, 115, 104, 97, 112, 101, 115, 32, 58, 10, 45, 105, 102, 32,
  36, 49, 10, 45, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105,
  116, 121, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 33, 36, 55, 125, 32, 45,
  95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 32, 36, 42, 32,
  45, 42, 32, 50, 53, 53, 10, 45, 101, 108, 105, 102, 32, 123, 36, 55,
  61, 61, 49, 125, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99,
  105, 116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 32, 45,
  115, 91, 48, 93, 32, 99, 32, 45, 114, 101, 112, 101, 97, 116, 32, 51,
  32, 45, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 91, 36,
  62, 93, 32, 36, 42, 32, 45, 100, 111, 110, 101, 32, 45, 42, 91, 48,
  45, 50, 93, 32, 50, 53, 53, 32, 45, 97, 91, 48, 45, 50, 93, 32,
  99, 32, 45, 97, 32, 99, 10, 45, 101, 108, 115, 101, 32, 45, 45, 95,
  103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 32, 36, 42, 32, 45,
  114, 91, 48, 93, 32, 36, 51, 37, 44, 36, 51, 37, 32, 45, 114, 91,
  48, 93, 32, 91, 49, 93, 44, 91, 49, 93, 32, 45, 42, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 45, 101, 108, 115, 101, 10, 45, 105, 102, 32, 123, 64, 35, 60, 61,
  36, 50, 125, 32, 45, 101, 114, 114, 111, 114, 91, 93, 32, 34, 83, 111,
  109, 101, 32, 108, 97, 121, 101, 114, 115, 32, 97, 114, 101, 32, 109, 105,
  115, 115, 105, 110, 103, 32, 105, 110, 32, 39, 67, 117, 115, 116, 111, 109,
  32, 108, 97, 121, 101, 114, 115, 39, 32, 109, 111, 100, 101, 32, 40, 34,
  123, 36, 50, 43, 49, 125, 34, 32, 101, 120, 112, 101, 99, 116, 101, 100,
  32, 97, 116, 32, 108, 101, 97, 115, 116, 44, 32, 34, 64, 35, 34, 32,
  112, 114, 111, 118, 105, 100, 101, 100, 41, 46, 34, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101,
  91, 48, 45, 123, 36, 50, 45, 49, 125, 93, 32, 64, 123, 45, 109, 97,
  120, 95, 115, 91, 48, 45, 123, 36, 50, 45, 49, 125, 93, 125, 32, 45,
  114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 91, 36,
  50, 45, 45, 49, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64,
  35, 45, 36, 50, 125, 32, 45, 108, 91, 48, 45, 123, 36, 50, 45, 49,
  125, 44, 123, 36, 50, 43, 36, 62, 125, 93, 10, 45, 110, 111, 114, 109,
  91, 45, 49, 93, 32, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125,
  32, 45, 114, 91, 45, 49, 93, 32, 36, 51, 37, 44, 36, 51, 37, 44,
  49, 44, 49, 44, 50, 10, 115, 61, 123, 36, 52, 42, 109, 97, 120, 40,
  114, 111, 117, 110, 100, 40, 36, 119, 47, 119, 41, 44, 114, 111, 117, 110,
  100, 40, 36, 104, 47, 104, 41, 41, 125, 10, 114, 48, 61, 123, 36, 115,
  42, 36, 53, 37, 125, 32, 114, 49, 61, 123, 36, 115, 42, 36, 54, 37,
  125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 50, 32, 114, 61, 123,
  114, 111, 117, 110, 100, 40, 36, 114, 48, 43, 36, 62, 42, 40, 36, 114,
  49, 45, 36, 114, 48, 41, 47, 40, 36, 50, 45, 49, 41, 41, 125, 32,
  45, 105, 102, 32, 36, 114, 32, 45, 45, 114, 91, 36, 62, 93, 32, 36,
  114, 44, 36, 114, 44, 49, 44, 49, 48, 48, 37, 44, 51, 32, 45, 101,
  108, 115, 101, 32, 49, 44, 49, 32, 45, 101, 110, 100, 105, 102, 32, 45,
  100, 111, 110, 101, 10, 45, 114, 91, 45, 36, 50, 45, 45, 49, 93, 32,
  36, 115, 44, 36, 115, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 109, 97, 112, 95, 115, 112,
  114, 105, 116, 101, 115, 91, 36, 50, 45, 45, 49, 93, 32, 36, 50, 44,
  36, 56, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  114, 109, 91, 48, 45, 123, 36, 50, 45, 49, 125, 93, 10, 45, 101, 110,
  100, 105, 102, 10, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 105, 102, 32, 36, 49,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 10, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115,
  32, 36, 123, 49, 45, 51, 125, 44, 49, 44, 36, 123, 53, 45, 45, 50,
  125, 34, 44, 36, 45, 49, 10, 45, 114, 32, 36, 119, 44, 36, 104, 44,
  49, 44, 49, 48, 48, 37, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48,
  46, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45,
  101, 108, 115, 101, 10, 45, 105, 102, 32, 123, 64, 35, 62, 36, 50, 125,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 36, 50, 125,
  32, 45, 108, 91, 48, 45, 123, 36, 50, 45, 49, 125, 44, 123, 36, 50,
  43, 36, 62, 125, 93, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104,
  125, 10, 45, 45, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 32,
  36, 123, 49, 45, 51, 125, 44, 49, 44, 36, 123, 53, 45, 45, 50, 125,
  32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 114, 91, 45, 49, 93, 32,
  36, 119, 44, 36, 104, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 45, 123, 36, 50, 45, 49,
  125, 93, 10, 45, 101, 108, 115, 101, 32, 45, 95, 103, 105, 109, 112, 95,
  110, 111, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 77, 105, 115, 115,
  105, 110, 103, 92, 110, 108, 97, 121, 101, 114, 115, 32, 33, 34, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 95, 103, 105,
  109, 112, 95, 115, 104, 97, 112, 101, 115, 32, 58, 10, 45, 110, 111, 114,
  109, 32, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 32, 45, 114,
  32, 36, 51, 37, 44, 36, 51, 37, 44, 49, 44, 49, 44, 50, 10, 115,
  61, 123, 40, 49, 43, 36, 49, 48, 41, 42, 36, 52, 42, 109, 97, 120,
  40, 114, 111, 117, 110, 100, 40, 36, 119, 47, 119, 41, 44, 114, 111, 117,
  110, 100, 40, 36, 104, 47, 104, 41, 41, 125, 10, 114, 48, 61, 123, 36,
  115, 42, 36, 53, 37, 125, 32, 114, 49, 61, 123, 36, 115, 42, 36, 54,
  37, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 50, 32, 114, 61,
  123, 114, 111, 117, 110, 100, 40, 36, 114, 48, 43, 36, 62, 42, 40, 36,
  114, 49, 45, 36, 114, 48, 41, 47, 40, 36, 50, 45, 49, 41, 41, 125,
  32, 45, 105, 102, 32, 36, 114, 32, 45, 95, 103, 105, 109, 112, 95, 115,
  104, 97, 112, 101, 115, 123, 36, 49, 45, 49, 125, 91, 93, 32, 36, 114,
  44, 36, 115, 32, 45, 101, 108, 115, 101, 32, 49, 44, 49, 32, 45, 101,
  110, 100, 105, 102, 32, 45, 100, 111, 110, 101, 10, 45, 114, 91, 45, 36,
  50, 45, 45, 49, 93, 32, 36, 115, 44, 36, 115, 44, 49, 44, 49, 44,
  48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 105, 102, 32,
  36, 57, 32, 45, 114, 118, 91, 45, 36, 50, 45, 45, 49, 93, 32, 45,
  42, 91, 45, 36, 50, 45, 45, 49, 93, 32, 45, 49, 32, 45, 43, 91,
  45, 36, 50, 45, 45, 49, 93, 32, 49, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 109, 97, 112, 95, 115, 112, 114, 105, 116, 101, 115, 32, 36, 50,
  44, 36, 56, 10, 45, 105, 102, 32, 36, 49, 48, 32, 45, 114, 32, 53,
  48, 37, 44, 53, 48, 37, 44, 49, 44, 49, 44, 50, 32, 45, 101, 110,
  100, 105, 102, 10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115,
  48, 32, 58, 10, 45, 95, 100, 116, 95, 99, 105, 114, 99, 108, 101, 91,
  93, 32, 36, 49, 10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101,
  115, 49, 32, 58, 10, 36, 49, 44, 36, 49, 44, 49, 44, 49, 44, 49,
  10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 50, 32, 58,
  10, 36, 49, 44, 36, 49, 44, 49, 44, 49, 32, 45, 61, 32, 49, 44,
  53, 48, 37, 44, 53, 48, 37, 32, 45, 100, 105, 115, 116, 97, 110, 99,
  101, 32, 49, 44, 49, 32, 45, 108, 116, 32, 123, 36, 49, 47, 50, 125,
  10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 51, 32, 58,
  10, 36, 50, 44, 36, 50, 44, 49, 44, 49, 44, 39, 120, 43, 121, 60,
  61, 50, 42, 36, 49, 45, 49, 39, 10, 95, 103, 105, 109, 112, 95, 115,
  104, 97, 112, 101, 115, 52, 32, 58, 10, 36, 50, 44, 36, 49, 44, 49,
  44, 49, 44, 49, 10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101,
  115, 53, 32, 58, 10, 36, 49, 44, 36, 50, 44, 49, 44, 49, 44, 49,
  10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 54, 32, 58,
  10, 45, 98, 97, 108, 108, 32, 36, 49, 44, 50, 48, 48, 32, 45, 110,
  32, 48, 44, 49, 10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101,
  115, 55, 32, 58, 10, 45, 104, 101, 97, 114, 116, 32, 54, 53, 32, 45,
  114, 32, 36, 49, 44, 36, 49, 44, 49, 44, 49, 44, 50, 32, 45, 103,
  101, 32, 53, 48, 37, 10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112,
  101, 115, 56, 32, 58, 10, 45, 115, 116, 97, 114, 32, 36, 49, 44, 36,
  49, 10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 57, 32,
  58, 10, 45, 97, 114, 114, 111, 119, 51, 100, 32, 48, 44, 48, 44, 48,
  44, 49, 44, 48, 44, 48, 44, 49, 53, 37, 44, 52, 48, 37, 44, 51,
  48, 37, 32, 45, 99, 111, 108, 51, 100, 32, 49, 32, 45, 42, 51, 100,
  32, 36, 49, 32, 45, 99, 51, 100, 10, 36, 50, 44, 36, 50, 32, 45,
  111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50,
  93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 49, 44, 50, 44,
  48, 44, 48, 10, 45, 114, 109, 91, 45, 50, 93, 32, 45, 45, 109, 105,
  114, 114, 111, 114, 32, 121, 32, 45, 109, 97, 120, 10, 95, 103, 105, 109,
  112, 95, 115, 104, 97, 112, 101, 115, 49, 48, 32, 58, 10, 83, 61, 123,
  36, 50, 43, 49, 45, 40, 36, 50, 37, 50, 41, 125, 10, 36, 83, 44,
  36, 83, 44, 49, 44, 49, 44, 34, 88, 61, 120, 47, 40, 119, 45, 49,
  41, 59, 89, 61, 121, 47, 40, 104, 45, 49, 41, 59, 114, 61, 97, 98,
  115, 40, 48, 46, 53, 45, 115, 113, 114, 116, 40, 88, 94, 50, 43, 89,
  94, 50, 41, 41, 59, 97, 61, 97, 116, 97, 110, 50, 40, 121, 44, 120,
  41, 59, 114, 60, 48, 46, 49, 45, 48, 46, 49, 55, 42, 40, 48, 46,
  53, 45, 36, 49, 47, 36, 50, 41, 42, 115, 105, 110, 40, 50, 42, 97,
  41, 34, 10, 45, 45, 109, 105, 114, 114, 111, 114, 32, 120, 121, 32, 45,
  109, 97, 120, 10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115,
  49, 49, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112,
  101, 115, 48, 32, 36, 42, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120,
  121, 32, 49, 44, 48, 32, 45, 45, 101, 114, 111, 100, 101, 32, 51, 32,
  45, 45, 10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 49,
  50, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101,
  115, 49, 32, 36, 42, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121,
  32, 49, 44, 48, 32, 45, 45, 101, 114, 111, 100, 101, 32, 51, 32, 45,
  45, 10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 49, 51,
  32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115,
  50, 32, 36, 42, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 32,
  49, 44, 48, 32, 45, 45, 101, 114, 111, 100, 101, 32, 51, 32, 45, 45,
  10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 49, 52, 32,
  58, 10, 45, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 51,
  32, 36, 42, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 32, 49,
  44, 48, 32, 45, 45, 101, 114, 111, 100, 101, 32, 51, 32, 45, 45, 10,
  95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 49, 53, 32, 58,
  10, 45, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 55, 32,
  36, 42, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 32, 49, 44,
  48, 32, 45, 45, 101, 114, 111, 100, 101, 32, 51, 32, 45, 45, 10, 95,
  103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 49, 54, 32, 58, 10,
  45, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 56, 32, 36,
  42, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 32, 49, 44, 48,
  32, 45, 45, 101, 114, 111, 100, 101, 32, 51, 32, 45, 45, 10, 95, 103,
  105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 49, 55, 32, 58, 10, 45,
  95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 57, 32, 36, 42,
  32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 32, 49, 44, 48, 32,
  45, 45, 101, 114, 111, 100, 101, 32, 51, 32, 45, 45, 10, 103, 105, 109,
  112, 95, 112, 97, 99, 107, 95, 115, 112, 114, 105, 116, 101, 115, 32, 58,
  10, 45, 105, 102, 32, 36, 54, 10, 45, 105, 102, 32, 123, 64, 35, 60,
  50, 125, 32, 45, 101, 114, 114, 111, 114, 91, 93, 32, 34, 77, 97, 115,
  107, 105, 110, 103, 32, 114, 101, 113, 117, 105, 114, 101, 115, 32, 97, 116,
  32, 108, 101, 97, 115, 116, 32, 116, 119, 111, 32, 105, 110, 112, 117, 116,
  32, 108, 97, 121, 101, 114, 115, 32, 33, 32, 40, 112, 108, 101, 97, 115,
  101, 32, 99, 104, 101, 99, 107, 32, 116, 104, 97, 116, 32, 39, 73, 110,
  112, 117, 116, 32, 76, 97, 121, 101, 114, 115, 39, 32, 105, 115, 32, 99,
  111, 114, 114, 101, 99, 116, 108, 121, 32, 115, 101, 116, 41, 46, 34, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  64, 35, 45, 49, 125, 32, 45, 108, 91, 36, 62, 93, 32, 45, 116, 111,
  95, 114, 103, 98, 97, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97,
  99, 105, 116, 121, 32, 45, 45, 110, 101, 113, 91, 49, 93, 32, 48, 32,
  45, 42, 91, 48, 93, 32, 91, 45, 49, 93, 32, 45, 97, 32, 99, 32,
  45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 48, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 45, 114, 101, 109, 111, 118, 101, 95,
  101, 109, 112, 116, 121, 91, 48, 45, 45, 50, 93, 32, 45, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 49, 48, 48, 37, 32,
  45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 45, 52,
  44, 48, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 10, 45, 112, 97,
  99, 107, 95, 115, 112, 114, 105, 116, 101, 115, 91, 48, 45, 45, 50, 93,
  32, 36, 123, 49, 45, 53, 125, 10, 45, 101, 108, 115, 101, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32,
  45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 115, 112, 108, 105, 116, 95,
  111, 112, 97, 99, 105, 116, 121, 32, 45, 45, 110, 101, 113, 91, 49, 93,
  32, 48, 32, 45, 42, 91, 48, 93, 32, 91, 45, 49, 93, 32, 45, 97,
  32, 99, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 48, 32, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 114, 101, 109, 111,
  118, 101, 95, 101, 109, 112, 116, 121, 32, 45, 105, 91, 48, 93, 32, 36,
  55, 44, 36, 56, 44, 49, 44, 53, 32, 45, 112, 97, 99, 107, 95, 115,
  112, 114, 105, 116, 101, 115, 32, 36, 123, 49, 45, 53, 125, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48,
  93, 32, 48, 44, 64, 123, 48, 44, 115, 45, 50, 125, 10, 103, 105, 109,
  112, 95, 112, 97, 112, 101, 114, 32, 58, 10, 45, 97, 112, 112, 108, 121,
  95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 116, 101, 120, 116,
  117, 114, 105, 122, 101, 95, 112, 97, 112, 101, 114, 34, 44, 36, 49, 44,
  48, 10, 103, 105, 109, 112, 95, 112, 97, 112, 101, 114, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109,
  112, 95, 112, 97, 112, 101, 114, 32, 36, 42, 34, 44, 36, 45, 49, 10,
  103, 105, 109, 112, 95, 112, 108, 97, 105, 100, 95, 116, 101, 120, 116, 117,
  114, 101, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123,
  104, 125, 32, 115, 61, 123, 115, 125, 10, 45, 114, 111, 119, 115, 32, 36,
  49, 37, 10, 45, 98, 32, 36, 53, 37, 32, 45, 115, 104, 97, 114, 112,
  101, 110, 32, 36, 54, 10, 45, 114, 101, 115, 105, 122, 101, 32, 36, 119,
  44, 36, 104, 44, 49, 44, 36, 115, 44, 50, 10, 45, 45, 114, 111, 116,
  97, 116, 101, 91, 48, 93, 32, 36, 51, 44, 49, 44, 50, 44, 53, 48,
  37, 44, 53, 48, 37, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36,
  50, 45, 49, 125, 32, 45, 45, 114, 111, 116, 97, 116, 101, 91, 48, 93,
  32, 123, 36, 51, 43, 36, 52, 42, 40, 36, 62, 43, 49, 41, 47, 40,
  36, 50, 45, 49, 41, 125, 44, 49, 44, 50, 44, 53, 48, 37, 44, 53,
  48, 37, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 100, 111,
  110, 101, 32, 45, 114, 109, 91, 48, 93, 10, 45, 47, 32, 36, 50, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112,
  95, 112, 108, 97, 115, 109, 97, 32, 58, 32, 45, 115, 107, 105, 112, 32,
  36, 123, 52, 61, 48, 125, 44, 36, 123, 53, 61, 48, 125, 10, 45, 105,
  102, 32, 36, 53, 32, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 101,
  108, 115, 101, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 36, 52, 32, 45, 114, 97, 110, 100, 32,
  48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 112, 108,
  97, 115, 109, 97, 32, 36, 49, 44, 36, 50, 44, 36, 51, 32, 45, 110,
  32, 48, 44, 50, 53, 53, 10, 45, 98, 97, 108, 97, 110, 99, 101, 95,
  103, 97, 109, 109, 97, 32, 36, 123, 54, 45, 56, 125, 10, 103, 105, 109,
  112, 95, 112, 111, 108, 107, 97, 95, 100, 111, 116, 115, 32, 58, 10, 45,
  116, 111, 95, 114, 103, 98, 97, 32, 45, 112, 111, 108, 107, 97, 95, 100,
  111, 116, 115, 32, 123, 36, 49, 42, 36, 50, 47, 49, 48, 48, 125, 44,
  36, 123, 50, 45, 45, 49, 125, 10, 103, 105, 109, 112, 95, 99, 111, 108,
  111, 114, 95, 101, 108, 108, 105, 112, 115, 101, 115, 32, 58, 10, 45, 99,
  111, 108, 111, 114, 95, 101, 108, 108, 105, 112, 115, 101, 115, 32, 36, 49,
  44, 36, 50, 44, 36, 51, 10, 103, 105, 109, 112, 95, 114, 111, 114, 115,
  99, 104, 97, 99, 104, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105,
  116, 121, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 36,
  51, 61, 61, 48, 125, 32, 45, 110, 111, 114, 109, 32, 45, 114, 111, 114,
  115, 99, 104, 97, 99, 104, 32, 36, 49, 37, 44, 36, 50, 32, 45, 42,
  32, 50, 53, 53, 10, 45, 101, 108, 105, 102, 32, 123, 36, 51, 61, 61,
  49, 125, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 114, 111, 114, 115,
  99, 104, 97, 99, 104, 32, 36, 49, 37, 44, 36, 50, 32, 45, 42, 32,
  50, 53, 53, 10, 45, 101, 108, 115, 101, 32, 45, 45, 110, 111, 114, 109,
  32, 45, 114, 111, 114, 115, 99, 104, 97, 99, 104, 91, 45, 49, 93, 32,
  36, 49, 37, 44, 36, 50, 32, 45, 98, 108, 101, 110, 100, 32, 115, 104,
  97, 112, 101, 97, 118, 101, 114, 97, 103, 101, 48, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103,
  105, 109, 112, 95, 115, 101, 97, 109, 108, 101, 115, 115, 95, 116, 117, 114,
  98, 117, 108, 101, 110, 99, 101, 32, 58, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 104, 61, 123,
  119, 125, 44, 123, 104, 125, 32, 45, 114, 109, 10, 36, 119, 104, 44, 49,
  44, 123, 105, 102, 40, 36, 54, 44, 51, 44, 49, 41, 125, 32, 45, 114,
  97, 110, 100, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 36, 119,
  104, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 123, 36, 51, 42,
  112, 105, 47, 49, 56, 48, 45, 36, 52, 42, 49, 48, 42, 112, 105, 125,
  44, 123, 36, 51, 42, 112, 105, 47, 49, 56, 48, 43, 36, 52, 42, 49,
  48, 42, 112, 105, 125, 32, 45, 45, 115, 105, 110, 91, 45, 49, 93, 32,
  45, 99, 111, 115, 91, 45, 50, 93, 32, 45, 97, 91, 45, 50, 44, 45,
  49, 93, 32, 99, 10, 45, 114, 91, 45, 50, 44, 45, 49, 93, 32, 49,
  51, 48, 37, 44, 49, 51, 48, 37, 44, 49, 44, 49, 48, 48, 37, 44,
  48, 44, 50, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 98, 91, 45,
  49, 93, 32, 36, 50, 32, 45, 111, 114, 105, 101, 110, 116, 97, 116, 105,
  111, 110, 91, 45, 49, 93, 10, 45, 118, 101, 99, 116, 111, 114, 50, 116,
  101, 110, 115, 111, 114, 91, 45, 49, 93, 10, 45, 115, 109, 111, 111, 116,
  104, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 49, 44, 48, 46,
  53, 44, 50, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 114, 91,
  45, 49, 93, 32, 36, 119, 104, 44, 49, 44, 49, 48, 48, 37, 44, 48,
  44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 105, 102, 32, 123,
  36, 53, 33, 61, 49, 125, 32, 105, 97, 61, 123, 105, 97, 125, 32, 45,
  45, 32, 36, 105, 97, 32, 45, 42, 32, 36, 53, 32, 45, 43, 32, 36,
  105, 97, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 45, 99, 32, 48, 44, 50, 53, 53, 32, 45,
  110, 32, 48, 44, 50, 53, 53, 10, 103, 105, 109, 112, 95, 115, 112, 111,
  110, 103, 101, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 34, 45, 115, 112, 111, 110, 103, 101, 32, 36,
  49, 34, 44, 36, 50, 44, 48, 10, 103, 105, 109, 112, 95, 115, 112, 111,
  110, 103, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 103, 105, 109, 112, 95, 115, 112, 111, 110, 103, 101, 32,
  36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 115, 116, 97,
  105, 110, 101, 100, 95, 103, 108, 97, 115, 115, 32, 58, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45,
  115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108,
  91, 48, 93, 10, 45, 115, 116, 97, 105, 110, 101, 100, 95, 103, 108, 97,
  115, 115, 32, 36, 49, 44, 36, 50, 44, 36, 51, 10, 45, 110, 32, 48,
  44, 50, 53, 53, 10, 45, 105, 102, 32, 36, 52, 32, 45, 101, 113, 117,
  97, 108, 105, 122, 101, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 114, 103, 98, 50, 108, 97, 98, 91, 45, 49, 93, 32, 45, 115,
  104, 91, 45, 49, 93, 32, 49, 44, 50, 32, 45, 42, 91, 45, 49, 93,
  32, 36, 53, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 108, 97, 98,
  50, 114, 103, 98, 91, 45, 49, 93, 10, 45, 97, 112, 112, 108, 121, 95,
  103, 97, 109, 109, 97, 91, 45, 49, 93, 32, 123, 49, 48, 94, 36, 54,
  125, 32, 45, 45, 91, 45, 49, 93, 32, 49, 50, 56, 32, 45, 42, 91,
  45, 49, 93, 32, 36, 55, 32, 45, 43, 91, 45, 49, 93, 32, 123, 49,
  50, 56, 43, 36, 56, 125, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 97, 112, 112, 101, 110,
  100, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  103, 105, 109, 112, 95, 115, 116, 97, 105, 110, 101, 100, 95, 103, 108, 97,
  115, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 115, 116, 97, 105, 110, 101, 100, 95,
  103, 108, 97, 115, 115, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105,
  109, 112, 95, 115, 116, 97, 114, 115, 32, 58, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112,
  108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 114, 118, 10,
  45, 115, 116, 97, 114, 115, 32, 36, 49, 37, 44, 36, 50, 44, 36, 51,
  44, 36, 52, 44, 36, 53, 44, 36, 54, 37, 44, 36, 123, 55, 45, 57,
  125, 44, 123, 36, 49, 48, 47, 50, 53, 53, 125, 10, 45, 114, 118, 32,
  45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 103, 105, 109, 112, 95, 115, 116, 101, 110, 99, 105, 108, 32, 58, 10,
  45, 118, 32, 45, 10, 45, 105, 102, 32, 123, 36, 53, 61, 61, 48, 125,
  32, 45, 110, 111, 114, 109, 32, 45, 115, 116, 101, 110, 99, 105, 108, 32,
  36, 49, 44, 36, 50, 44, 36, 51, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 53, 61, 61, 49, 125, 32, 45, 115, 116, 101, 110, 99, 105, 108, 32,
  36, 49, 44, 36, 50, 44, 36, 51, 10, 45, 101, 108, 115, 101, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 45, 110, 111, 114, 109,
  91, 45, 49, 93, 32, 45, 115, 116, 101, 110, 99, 105, 108, 91, 45, 49,
  93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 32, 45, 103, 101, 91, 45,
  49, 93, 32, 53, 48, 37, 32, 45, 98, 108, 101, 110, 100, 91, 45, 50,
  44, 45, 49, 93, 32, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97, 103,
  101, 48, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111,
  110, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 54,
  32, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 114, 101, 112, 108, 97,
  99, 101, 95, 99, 111, 108, 111, 114, 32, 48, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 48, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 52, 32, 45, 115, 109,
  111, 111, 116, 104, 32, 123, 51, 48, 42, 36, 52, 125, 44, 48, 44, 49,
  44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 115,
  116, 101, 110, 99, 105, 108, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 115, 116, 101, 110,
  99, 105, 108, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112,
  95, 116, 101, 116, 114, 105, 115, 32, 58, 10, 45, 116, 101, 116, 114, 105,
  115, 32, 36, 49, 10, 103, 105, 109, 112, 95, 116, 114, 117, 99, 104, 101,
  116, 32, 58, 10, 45, 105, 102, 32, 36, 54, 32, 45, 116, 111, 95, 97,
  32, 45, 101, 108, 115, 101, 32, 45, 114, 101, 109, 111, 118, 101, 95, 111,
  112, 97, 99, 105, 116, 121, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116,
  114, 117, 99, 104, 101, 116, 32, 36, 49, 44, 36, 50, 44, 36, 52, 10,
  45, 105, 102, 32, 36, 53, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32,
  48, 32, 45, 108, 97, 98, 101, 108, 91, 45, 49, 93, 32, 48, 44, 49,
  32, 123, 105, 77, 43, 49, 125, 44, 49, 44, 49, 44, 51, 32, 45, 114,
  97, 110, 100, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 109,
  97, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100,
  111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 98, 32, 36, 51,
  32, 45, 110, 32, 48, 44, 50, 53, 53, 10, 103, 105, 109, 112, 95, 116,
  117, 114, 98, 117, 108, 101, 110, 99, 101, 32, 58, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115,
  112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91,
  48, 93, 10, 45, 116, 117, 114, 98, 117, 108, 101, 110, 99, 101, 32, 36,
  123, 94, 48, 125, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112,
  95, 119, 104, 105, 114, 108, 115, 32, 58, 10, 45, 97, 112, 112, 108, 121,
  95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 119, 104, 105, 114,
  108, 115, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 34, 44,
  36, 53, 44, 48, 10, 103, 105, 109, 112, 95, 119, 104, 105, 114, 108, 115,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 103, 105, 109, 112, 95, 119, 104, 105, 114, 108, 115, 32, 36, 42, 34,
  44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 100, 101, 105, 110, 116, 101,
  114, 108, 97, 99, 101, 32, 58, 10, 45, 100, 101, 105, 110, 116, 101, 114,
  108, 97, 99, 101, 32, 48, 32, 45, 115, 107, 105, 112, 32, 36, 123, 94,
  48, 125, 10, 103, 105, 109, 112, 95, 100, 101, 105, 110, 116, 101, 114, 108,
  97, 99, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 103, 105, 109, 112, 95, 100, 101, 105, 110, 116, 101, 114,
  108, 97, 99, 101, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109,
  112, 95, 105, 110, 112, 97, 105, 110, 116, 95, 100, 105, 102, 102, 117, 115,
  105, 111, 110, 32, 58, 10, 45, 105, 102, 32, 36, 55, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45,
  45, 115, 101, 108, 101, 99, 116, 95, 99, 111, 108, 111, 114, 32, 48, 44,
  36, 123, 56, 45, 49, 49, 125, 32, 45, 114, 118, 10, 45, 105, 102, 32,
  36, 49, 32, 45, 105, 110, 112, 97, 105, 110, 116, 95, 102, 108, 111, 119,
  32, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 37, 44, 36, 54,
  37, 32, 45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 115, 101,
  32, 45, 105, 110, 112, 97, 105, 110, 116, 91, 49, 93, 32, 91, 48, 93,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 48, 93, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 115, 101,
  10, 45, 105, 102, 32, 123, 64, 35, 61, 61, 49, 125, 32, 45, 114, 101,
  116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95,
  97, 91, 48, 93, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48,
  93, 32, 49, 48, 48, 37, 32, 45, 103, 101, 91, 48, 93, 32, 53, 48,
  37, 10, 45, 105, 102, 32, 36, 49, 32, 45, 105, 110, 112, 97, 105, 110,
  116, 95, 102, 108, 111, 119, 32, 36, 50, 44, 36, 51, 44, 36, 52, 44,
  36, 53, 37, 44, 36, 54, 37, 32, 45, 99, 32, 48, 44, 50, 53, 53,
  32, 45, 101, 108, 115, 101, 32, 45, 105, 110, 112, 97, 105, 110, 116, 91,
  94, 48, 93, 32, 91, 48, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  116, 111, 95, 97, 91, 48, 93, 32, 45, 102, 91, 48, 93, 32, 48, 10,
  45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 105, 110, 112, 97,
  105, 110, 116, 95, 100, 105, 102, 102, 117, 115, 105, 111, 110, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 105, 110,
  112, 97, 105, 110, 116, 95, 100, 105, 102, 102, 117, 115, 105, 111, 110, 32,
  36, 123, 94, 48, 125, 10, 45, 105, 102, 32, 123, 33, 36, 55, 34, 32,
  38, 38, 32, 34, 64, 35, 62, 49, 125, 32, 45, 114, 109, 91, 48, 93,
  32, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 105, 110, 112,
  97, 105, 110, 116, 95, 112, 97, 116, 99, 104, 32, 58, 10, 45, 105, 102,
  32, 123, 64, 46, 62, 61, 49, 53, 56, 49, 125, 32, 105, 110, 112, 97,
  105, 110, 116, 61, 105, 110, 112, 97, 105, 110, 116, 32, 45, 101, 108, 115,
  101, 32, 105, 110, 112, 97, 105, 110, 116, 61, 114, 101, 112, 97, 105, 114,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 57, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 45, 115, 101, 108, 101, 99, 116, 95, 99, 111, 108, 111, 114, 32,
  48, 44, 36, 123, 49, 48, 45, 49, 51, 125, 10, 45, 105, 102, 32, 123,
  64, 46, 62, 61, 49, 53, 56, 52, 125, 32, 45, 36, 105, 110, 112, 97,
  105, 110, 116, 91, 48, 93, 32, 91, 49, 93, 44, 36, 49, 44, 123, 36,
  49, 42, 36, 50, 125, 44, 36, 51, 44, 49, 44, 123, 36, 52, 42, 36,
  49, 125, 44, 36, 123, 53, 45, 56, 125, 10, 45, 101, 108, 105, 102, 32,
  123, 64, 46, 62, 61, 49, 53, 56, 51, 125, 32, 45, 36, 105, 110, 112,
  97, 105, 110, 116, 91, 48, 93, 32, 91, 49, 93, 44, 36, 49, 44, 123,
  36, 49, 42, 36, 50, 125, 44, 36, 51, 44, 123, 36, 52, 42, 36, 49,
  125, 44, 36, 123, 53, 45, 56, 125, 10, 45, 101, 108, 115, 101, 32, 45,
  36, 105, 110, 112, 97, 105, 110, 116, 91, 48, 93, 32, 91, 49, 93, 44,
  36, 49, 44, 123, 36, 49, 42, 36, 50, 125, 44, 123, 114, 111, 117, 110,
  100, 40, 49, 43, 36, 51, 41, 125, 44, 123, 36, 52, 42, 36, 49, 125,
  44, 36, 123, 53, 45, 56, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 109, 91, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 45, 101, 108, 115, 101, 10, 45, 105, 102, 32, 123, 64, 35, 61,
  61, 49, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 116, 111, 95, 97, 91, 48, 93, 32, 45, 99, 104, 97,
  110, 110, 101, 108, 115, 91, 48, 93, 32, 49, 48, 48, 37, 32, 45, 103,
  101, 91, 48, 93, 32, 53, 48, 37, 10, 45, 105, 102, 32, 123, 64, 46,
  62, 61, 49, 53, 56, 52, 125, 32, 45, 36, 105, 110, 112, 97, 105, 110,
  116, 91, 94, 48, 93, 32, 91, 48, 93, 44, 36, 49, 44, 123, 36, 49,
  42, 36, 50, 125, 44, 36, 51, 44, 49, 44, 123, 36, 52, 42, 36, 49,
  125, 44, 36, 123, 53, 45, 56, 125, 10, 45, 101, 108, 105, 102, 32, 123,
  64, 46, 62, 61, 49, 53, 56, 51, 125, 32, 45, 36, 105, 110, 112, 97,
  105, 110, 116, 91, 94, 48, 93, 32, 91, 48, 93, 44, 36, 49, 44, 123,
  36, 49, 42, 36, 50, 125, 44, 36, 51, 44, 123, 36, 52, 42, 36, 49,
  125, 44, 36, 123, 53, 45, 56, 125, 10, 45, 101, 108, 115, 101, 32, 45,
  36, 105, 110, 112, 97, 105, 110, 116, 91, 94, 48, 93, 32, 91, 48, 93,
  44, 36, 49, 44, 123, 36, 49, 42, 36, 50, 125, 44, 123, 114, 111, 117,
  110, 100, 40, 49, 43, 36, 51, 41, 125, 44, 123, 36, 52, 42, 36, 49,
  125, 44, 36, 123, 53, 45, 56, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 116, 111, 95, 97, 91, 48, 93, 32, 45, 102, 91, 48, 93, 32, 48,
  10, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 115, 111, 108,
  105, 100, 105, 102, 121, 32, 58, 10, 45, 105, 102, 32, 36, 49, 32, 45,
  115, 111, 108, 105, 100, 105, 102, 121, 10, 45, 101, 108, 115, 101, 32, 45,
  115, 111, 108, 105, 100, 105, 102, 121, 95, 108, 105, 110, 101, 97, 114, 32,
  36, 50, 44, 36, 51, 44, 36, 52, 10, 45, 101, 110, 100, 105, 102, 10,
  103, 105, 109, 112, 95, 115, 111, 108, 105, 100, 105, 102, 121, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112,
  108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105,
  109, 112, 95, 115, 111, 108, 105, 100, 105, 102, 121, 32, 36, 42, 34, 44,
  36, 45, 49, 10, 103, 105, 109, 112, 95, 114, 101, 109, 111, 118, 101, 95,
  104, 111, 116, 112, 105, 120, 101, 108, 115, 32, 58, 10, 45, 114, 101, 109,
  111, 118, 101, 95, 104, 111, 116, 112, 105, 120, 101, 108, 115, 32, 36, 49,
  44, 36, 50, 10, 103, 105, 109, 112, 95, 114, 101, 109, 111, 118, 101, 95,
  104, 111, 116, 112, 105, 120, 101, 108, 115, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 114,
  101, 109, 111, 118, 101, 95, 104, 111, 116, 112, 105, 120, 101, 108, 115, 32,
  36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 97, 110, 105,
  115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105,
  110, 103, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 51, 61,
  49, 125, 44, 36, 123, 49, 52, 61, 48, 125, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 97, 112,
  112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 103,
  105, 109, 112, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101,
  114, 108, 97, 112, 32, 92, 34, 45, 114, 101, 112, 101, 97, 116, 32, 36,
  49, 49, 32, 45, 115, 109, 111, 111, 116, 104, 32, 36, 49, 44, 36, 50,
  44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44,
  36, 56, 44, 36, 57, 44, 36, 49, 48, 32, 45, 100, 111, 110, 101, 92,
  34, 44, 36, 49, 51, 44, 36, 49, 52, 34, 44, 36, 49, 50, 44, 48,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 99, 32,
  48, 44, 50, 53, 53, 10, 103, 105, 109, 112, 95, 97, 110, 105, 115, 111,
  116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 103, 105, 109, 112, 95, 97, 110, 105, 115, 111, 116, 114, 111, 112, 105,
  99, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 32, 36, 42, 34, 44,
  36, 45, 49, 10, 103, 105, 109, 112, 95, 98, 105, 108, 97, 116, 101, 114,
  97, 108, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 53, 61, 48,
  125, 44, 36, 123, 54, 61, 48, 125, 10, 45, 97, 112, 112, 108, 121, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 103, 105, 109, 112, 95,
  112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112,
  32, 92, 34, 45, 114, 101, 112, 101, 97, 116, 32, 36, 51, 32, 45, 98,
  105, 108, 97, 116, 101, 114, 97, 108, 32, 36, 49, 44, 36, 50, 32, 45,
  100, 111, 110, 101, 92, 34, 44, 36, 53, 44, 36, 54, 34, 44, 36, 52,
  44, 48, 10, 103, 105, 109, 112, 95, 98, 105, 108, 97, 116, 101, 114, 97,
  108, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 98, 105, 108, 97, 116, 101, 114, 97, 108,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 100, 105,
  102, 102, 117, 115, 105, 111, 110, 95, 115, 109, 111, 111, 116, 104, 105, 110,
  103, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 34, 45, 103, 105, 109, 112, 95, 112, 97, 114, 97, 108,
  108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 32, 92, 34, 45, 115,
  109, 111, 111, 116, 104, 32, 36, 54, 44, 36, 49, 44, 36, 50, 44, 36,
  51, 44, 36, 52, 44, 36, 53, 44, 48, 32, 45, 99, 32, 48, 44, 50,
  53, 53, 92, 34, 44, 36, 56, 44, 36, 57, 34, 44, 36, 55, 44, 48,
  10, 103, 105, 109, 112, 95, 100, 105, 102, 102, 117, 115, 105, 111, 110, 95,
  115, 109, 111, 111, 116, 104, 105, 110, 103, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 100,
  105, 102, 102, 117, 115, 105, 111, 110, 95, 115, 109, 111, 111, 116, 104, 105,
  110, 103, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95,
  109, 101, 97, 110, 99, 117, 114, 118, 97, 116, 117, 114, 101, 95, 115, 109,
  111, 111, 116, 104, 105, 110, 103, 32, 58, 10, 45, 97, 112, 112, 108, 121,
  95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 103, 105, 109, 112,
  95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97,
  112, 32, 92, 34, 45, 109, 101, 97, 110, 99, 117, 114, 118, 97, 116, 117,
  114, 101, 95, 102, 108, 111, 119, 32, 36, 50, 44, 36, 49, 44, 36, 51,
  32, 45, 99, 32, 48, 44, 50, 53, 53, 92, 34, 44, 36, 53, 44, 36,
  54, 34, 44, 36, 52, 44, 48, 10, 103, 105, 109, 112, 95, 109, 101, 97,
  110, 99, 117, 114, 118, 97, 116, 117, 114, 101, 95, 115, 109, 111, 111, 116,
  104, 105, 110, 103, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 109, 101, 97, 110, 99, 117,
  114, 118, 97, 116, 117, 114, 101, 95, 115, 109, 111, 111, 116, 104, 105, 110,
  103, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 109,
  101, 100, 105, 97, 110, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 109, 101, 100, 105, 97, 110,
  32, 36, 49, 34, 44, 36, 50, 44, 48, 10, 103, 105, 109, 112, 95, 109,
  101, 100, 105, 97, 110, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 109, 101, 100, 105, 97,
  110, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 112,
  97, 116, 99, 104, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 32, 58,
  10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 34, 45, 103, 105, 109, 112, 95, 112, 97, 114, 97, 108, 108, 101, 108,
  95, 111, 118, 101, 114, 108, 97, 112, 32, 92, 34, 45, 114, 101, 112, 101,
  97, 116, 32, 36, 55, 32, 45, 100, 101, 110, 111, 105, 115, 101, 32, 36,
  49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54,
  32, 45, 100, 111, 110, 101, 32, 45, 99, 32, 48, 44, 50, 53, 53, 92,
  34, 44, 36, 57, 44, 36, 49, 48, 34, 44, 36, 56, 44, 48, 10, 103,
  105, 109, 112, 95, 112, 97, 116, 99, 104, 95, 115, 109, 111, 111, 116, 104,
  105, 110, 103, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 103, 105, 109, 112, 95, 112, 97, 116, 99, 104, 95, 115,
  109, 111, 111, 116, 104, 105, 110, 103, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 103, 105, 109, 112, 95, 115, 101, 108, 101, 99, 116, 105, 118, 101, 95,
  115, 109, 111, 111, 116, 104, 105, 110, 103, 32, 58, 10, 45, 97, 112, 112,
  108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 103, 105,
  109, 112, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114,
  108, 97, 112, 32, 92, 34, 45, 114, 101, 112, 101, 97, 116, 32, 36, 52,
  32, 45, 98, 108, 117, 114, 95, 115, 101, 108, 101, 99, 116, 105, 118, 101,
  32, 36, 49, 44, 36, 50, 44, 36, 51, 32, 45, 100, 111, 110, 101, 32,
  45, 99, 32, 48, 44, 50, 53, 53, 92, 34, 44, 36, 54, 44, 36, 55,
  34, 44, 36, 53, 44, 48, 10, 103, 105, 109, 112, 95, 115, 101, 108, 101,
  99, 116, 105, 118, 101, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  103, 105, 109, 112, 95, 115, 101, 108, 101, 99, 116, 105, 118, 101, 95, 115,
  109, 111, 111, 116, 104, 105, 110, 103, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 103, 105, 109, 112, 95, 115, 109, 111, 111, 116, 104, 95, 115, 107, 105,
  110, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97,
  99, 105, 116, 121, 32, 45, 108, 91, 48, 93, 32, 45, 116, 111, 95, 114,
  103, 98, 10, 45, 105, 102, 32, 36, 53, 32, 45, 45, 98, 97, 108, 97,
  110, 99, 101, 95, 103, 97, 109, 109, 97, 32, 49, 50, 56, 44, 49, 50,
  56, 44, 49, 50, 56, 32, 45, 101, 108, 115, 101, 32, 91, 48, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61,
  48, 125, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93,
  32, 48, 32, 45, 102, 91, 45, 49, 93, 32, 49, 32, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 61, 61, 50, 125, 32, 45, 100, 101, 116, 101, 99,
  116, 95, 115, 107, 105, 110, 91, 45, 49, 93, 32, 36, 50, 32, 45, 101,
  108, 115, 101, 32, 45, 100, 101, 116, 101, 99, 116, 95, 115, 107, 105, 110,
  91, 45, 49, 93, 32, 36, 50, 44, 36, 54, 37, 44, 36, 55, 37, 44,
  36, 56, 37, 32, 45, 101, 110, 100, 105, 102, 10, 77, 61, 123, 105, 77,
  125, 32, 45, 98, 91, 45, 49, 93, 32, 36, 51, 37, 32, 45, 42, 91,
  45, 49, 93, 32, 123, 36, 77, 47, 105, 77, 125, 32, 45, 42, 91, 45,
  49, 93, 32, 36, 52, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 49,
  10, 45, 115, 112, 108, 105, 116, 95, 100, 101, 116, 97, 105, 108, 115, 91,
  48, 93, 32, 52, 44, 36, 57, 37, 44, 36, 49, 48, 37, 10, 45, 45,
  95, 103, 105, 109, 112, 95, 115, 109, 111, 111, 116, 104, 95, 115, 107, 105,
  110, 91, 50, 93, 32, 36, 49, 50, 44, 36, 49, 49, 10, 45, 106, 91,
  50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44,
  49, 44, 91, 45, 50, 93, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49,
  93, 10, 45, 42, 91, 45, 49, 93, 32, 123, 49, 48, 94, 36, 49, 51,
  125, 32, 45, 43, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 101,
  110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 95, 103, 105, 109, 112, 95, 115, 109, 111, 111, 116,
  104, 95, 115, 107, 105, 110, 32, 58, 10, 45, 105, 102, 32, 123, 36, 49,
  61, 61, 48, 125, 32, 45, 98, 32, 123, 36, 50, 47, 56, 125, 37, 10,
  45, 101, 108, 115, 101, 10, 45, 105, 102, 32, 123, 36, 50, 62, 48, 125,
  10, 109, 61, 123, 105, 109, 125, 32, 77, 61, 123, 105, 77, 125, 32, 45,
  110, 32, 48, 44, 50, 53, 53, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 105, 110, 116, 40, 36, 50, 47, 53, 41, 125, 32, 45, 98, 105, 108,
  97, 116, 101, 114, 97, 108, 32, 51, 37, 44, 123, 53, 42, 51, 125, 32,
  45, 100, 111, 110, 101, 10, 45, 98, 105, 108, 97, 116, 101, 114, 97, 108,
  32, 51, 37, 44, 123, 40, 36, 50, 37, 53, 41, 42, 51, 125, 10, 45,
  42, 32, 123, 40, 36, 77, 45, 36, 109, 41, 47, 50, 53, 53, 125, 32,
  45, 43, 32, 36, 109, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 105, 102, 10, 103, 105, 109, 112, 95, 115, 109, 111, 111, 116, 104, 95,
  115, 107, 105, 110, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  105, 102, 32, 123, 36, 45, 50, 61, 61, 48, 125, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 105, 102, 32, 36, 53, 32, 45, 98, 97, 108, 97, 110, 99, 101,
  95, 103, 97, 109, 109, 97, 32, 49, 50, 56, 44, 49, 50, 56, 44, 49,
  50, 56, 32, 45, 101, 110, 100, 105, 102, 32, 45, 105, 102, 32, 123, 36,
  49, 61, 61, 48, 125, 32, 45, 102, 32, 49, 32, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 61, 61, 50, 125, 32, 45, 100, 101, 116, 101, 99, 116,
  95, 115, 107, 105, 110, 32, 36, 50, 32, 45, 101, 108, 115, 101, 32, 45,
  100, 101, 116, 101, 99, 116, 95, 115, 107, 105, 110, 32, 36, 50, 44, 36,
  54, 37, 44, 36, 55, 37, 44, 36, 56, 37, 32, 45, 101, 110, 100, 105,
  102, 32, 77, 61, 123, 105, 77, 125, 32, 45, 98, 32, 36, 51, 37, 32,
  45, 42, 32, 123, 50, 53, 53, 42, 36, 77, 47, 105, 77, 125, 32, 45,
  42, 32, 36, 52, 32, 45, 99, 32, 48, 44, 50, 53, 53, 34, 44, 36,
  45, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 45, 50, 61, 61, 49,
  125, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 98, 32, 36, 57, 37, 34, 44, 36,
  45, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 45, 50, 61, 61, 50,
  125, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 115, 112, 108, 105, 116, 95, 100, 101,
  116, 97, 105, 108, 115, 32, 52, 44, 36, 57, 37, 44, 36, 49, 48, 37,
  32, 45, 107, 91, 45, 50, 93, 32, 45, 110, 32, 48, 44, 50, 53, 53,
  34, 44, 36, 45, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 45, 50,
  61, 61, 51, 125, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 112, 108, 105, 116,
  95, 100, 101, 116, 97, 105, 108, 115, 32, 52, 44, 36, 57, 37, 44, 36,
  49, 48, 37, 32, 45, 107, 91, 45, 50, 93, 32, 45, 95, 103, 105, 109,
  112, 95, 115, 109, 111, 111, 116, 104, 95, 115, 107, 105, 110, 32, 36, 49,
  50, 44, 36, 49, 49, 32, 45, 110, 32, 48, 44, 50, 53, 53, 34, 44,
  36, 45, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 45, 50, 61, 61,
  52, 125, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 112, 108, 105, 116, 95, 100,
  101, 116, 97, 105, 108, 115, 32, 52, 44, 36, 57, 37, 44, 36, 49, 48,
  37, 32, 45, 107, 91, 45, 49, 93, 32, 45, 110, 32, 48, 44, 50, 53,
  53, 34, 44, 36, 45, 49, 10, 45, 101, 108, 115, 101, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 115, 109, 111, 111, 116, 104, 95, 115,
  107, 105, 110, 32, 36, 42, 34, 44, 36, 45, 49, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 10, 45,
  116, 111, 95, 114, 103, 98, 10, 45, 99, 105, 114, 99, 108, 101, 32, 36,
  54, 37, 44, 36, 55, 37, 44, 36, 56, 37, 44, 48, 46, 50, 44, 48,
  44, 50, 53, 53, 44, 48, 10, 45, 99, 105, 114, 99, 108, 101, 32, 36,
  54, 37, 44, 36, 55, 37, 44, 36, 56, 37, 44, 48, 46, 52, 44, 48,
  120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 44, 50, 53, 53, 44,
  48, 10, 45, 108, 105, 110, 101, 32, 123, 36, 54, 45, 48, 46, 50, 53,
  42, 36, 56, 125, 37, 44, 123, 36, 55, 45, 48, 46, 50, 53, 42, 36,
  56, 125, 37, 44, 123, 36, 54, 43, 48, 46, 50, 53, 42, 36, 56, 125,
  37, 44, 123, 36, 55, 43, 48, 46, 50, 53, 42, 36, 56, 125, 37, 44,
  48, 46, 56, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 10, 45, 108,
  105, 110, 101, 32, 123, 36, 54, 43, 48, 46, 50, 53, 42, 36, 56, 125,
  37, 44, 123, 36, 55, 45, 48, 46, 50, 53, 42, 36, 56, 125, 37, 44,
  123, 36, 54, 45, 48, 46, 50, 53, 42, 36, 56, 125, 37, 44, 123, 36,
  55, 43, 48, 46, 50, 53, 42, 36, 56, 125, 37, 44, 48, 46, 56, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 48, 10, 45, 101, 110, 100, 105, 102,
  10, 103, 105, 109, 112, 95, 116, 118, 95, 115, 109, 111, 111, 116, 104, 105,
  110, 103, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 32, 34, 45, 103, 105, 109, 112, 95, 112, 97, 114, 97,
  108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 32, 92, 34, 45,
  116, 118, 95, 102, 108, 111, 119, 32, 36, 50, 44, 36, 49, 44, 36, 51,
  32, 45, 99, 32, 48, 44, 50, 53, 53, 92, 34, 44, 36, 53, 44, 36,
  54, 34, 44, 36, 52, 44, 48, 10, 103, 105, 109, 112, 95, 116, 118, 95,
  115, 109, 111, 111, 116, 104, 105, 110, 103, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 116,
  118, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 32, 36, 42, 34, 44,
  36, 45, 49, 10, 103, 105, 109, 112, 95, 104, 97, 97, 114, 95, 115, 109,
  111, 111, 116, 104, 105, 110, 103, 32, 58, 10, 45, 97, 112, 112, 108, 121,
  95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 103, 105, 109, 112,
  95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97,
  112, 32, 92, 34, 45, 100, 101, 110, 111, 105, 115, 101, 95, 104, 97, 97,
  114, 32, 36, 49, 44, 36, 51, 44, 36, 50, 32, 45, 99, 32, 48, 44,
  50, 53, 53, 92, 34, 44, 36, 53, 44, 36, 54, 34, 44, 36, 52, 44,
  48, 10, 103, 105, 109, 112, 95, 104, 97, 97, 114, 95, 115, 109, 111, 111,
  116, 104, 105, 110, 103, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 104, 97, 97, 114, 95,
  115, 109, 111, 111, 116, 104, 105, 110, 103, 32, 36, 42, 34, 44, 36, 45,
  49, 10, 103, 105, 109, 112, 95, 117, 112, 115, 99, 97, 108, 101, 95, 115,
  109, 97, 114, 116, 32, 58, 10, 45, 116, 111, 95, 114, 103, 98, 32, 45,
  117, 112, 115, 99, 97, 108, 101, 95, 115, 109, 97, 114, 116, 32, 36, 49,
  44, 36, 50, 44, 49, 44, 36, 51, 44, 36, 52, 44, 36, 53, 32, 45,
  99, 32, 48, 44, 50, 53, 53, 10, 103, 105, 109, 112, 95, 117, 112, 115,
  99, 97, 108, 101, 95, 115, 109, 97, 114, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10,
  45, 45, 114, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 49, 44,
  49, 44, 48, 10, 45, 105, 102, 32, 123, 119, 60, 64, 123, 45, 50, 44,
  119, 125, 124, 124, 104, 60, 64, 123, 45, 50, 44, 104, 125, 125, 10, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 47, 91, 45, 49, 93, 32, 52, 10,
  48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 68, 111, 119, 110, 115, 99,
  97, 108, 105, 110, 103, 32, 105, 115, 92, 110, 110, 111, 116, 32, 97, 108,
  108, 111, 119, 101, 100, 33, 34, 44, 53, 44, 53, 44, 50, 48, 44, 49,
  44, 50, 53, 53, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  44, 91, 45, 50, 93, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 10, 45, 111, 114, 91, 45, 50, 44, 45, 49, 93,
  10, 45, 101, 108, 115, 101, 10, 45, 122, 91, 45, 50, 93, 32, 123, 53,
  48, 45, 53, 48, 42, 64, 123, 45, 50, 44, 119, 125, 47, 119, 125, 37,
  44, 123, 53, 48, 45, 53, 48, 42, 64, 123, 45, 50, 44, 104, 125, 47,
  104, 125, 37, 44, 123, 53, 48, 43, 53, 48, 42, 64, 123, 45, 50, 44,
  119, 125, 47, 119, 125, 37, 44, 123, 53, 48, 43, 53, 48, 42, 64, 123,
  45, 50, 44, 104, 125, 47, 104, 125, 37, 10, 45, 114, 109, 91, 45, 49,
  93, 32, 45, 103, 105, 109, 112, 95, 117, 112, 115, 99, 97, 108, 101, 95,
  115, 109, 97, 114, 116, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44,
  36, 51, 44, 36, 52, 44, 36, 53, 32, 45, 99, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 109, 118,
  91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109,
  112, 95, 115, 99, 97, 108, 101, 110, 120, 32, 58, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115,
  112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 10, 45, 105, 102,
  32, 123, 36, 50, 61, 61, 49, 125, 32, 45, 114, 103, 98, 50, 121, 99,
  98, 99, 114, 91, 48, 93, 32, 45, 114, 111, 117, 110, 100, 91, 48, 93,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 61, 61, 50, 125, 32, 45,
  114, 103, 98, 50, 108, 97, 98, 56, 91, 48, 93, 32, 45, 114, 111, 117,
  110, 100, 91, 48, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 49, 61, 61, 48, 125, 32, 45, 115, 99, 97, 108, 101, 50,
  120, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 32,
  45, 115, 99, 97, 108, 101, 51, 120, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 61, 61, 50, 125, 32, 45, 115, 99, 97, 108, 101, 50, 120, 32,
  45, 115, 99, 97, 108, 101, 50, 120, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 61, 61, 51, 125, 32, 45, 115, 99, 97, 108, 101, 51, 120, 32,
  45, 115, 99, 97, 108, 101, 50, 120, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 61, 61, 52, 125, 32, 45, 115, 99, 97, 108, 101, 50, 120, 32,
  45, 115, 99, 97, 108, 101, 50, 120, 32, 45, 115, 99, 97, 108, 101, 50,
  120, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 53, 125, 32,
  45, 115, 99, 97, 108, 101, 51, 120, 32, 45, 115, 99, 97, 108, 101, 51,
  120, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 54, 125, 32,
  45, 115, 99, 97, 108, 101, 51, 120, 32, 45, 115, 99, 97, 108, 101, 50,
  120, 32, 45, 115, 99, 97, 108, 101, 50, 120, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 61, 61, 55, 125, 32, 45, 115, 99, 97, 108, 101, 50,
  120, 32, 45, 115, 99, 97, 108, 101, 50, 120, 32, 45, 115, 99, 97, 108,
  101, 50, 120, 32, 45, 115, 99, 97, 108, 101, 50, 120, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 61, 61, 56, 125, 32, 45, 115, 99, 97, 108,
  101, 51, 120, 32, 45, 115, 99, 97, 108, 101, 51, 120, 32, 45, 115, 99,
  97, 108, 101, 50, 120, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61,
  61, 57, 125, 32, 45, 115, 99, 97, 108, 101, 51, 120, 32, 45, 115, 99,
  97, 108, 101, 51, 120, 32, 45, 115, 99, 97, 108, 101, 51, 120, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 50, 61, 61, 49,
  125, 32, 45, 121, 99, 98, 99, 114, 50, 114, 103, 98, 91, 48, 93, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 50, 61, 61, 50, 125, 32, 45, 108,
  97, 98, 56, 50, 114, 103, 98, 91, 48, 93, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 103, 105, 109, 112, 95, 115, 99, 97, 108, 101, 110, 120, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 122, 32, 52, 48, 37,
  44, 52, 48, 37, 44, 54, 48, 37, 44, 54, 48, 37, 10, 45, 103, 105,
  109, 112, 95, 115, 99, 97, 108, 101, 110, 120, 32, 36, 49, 44, 36, 50,
  10, 103, 105, 109, 112, 95, 114, 101, 110, 100, 101, 114, 51, 100, 32, 58,
  10, 45, 110, 51, 100, 32, 45, 99, 51, 100, 32, 45, 109, 51, 100, 32,
  36, 49, 51, 32, 102, 51, 100, 61, 123, 48, 46, 53, 42, 109, 97, 120,
  40, 36, 49, 44, 36, 50, 41, 47, 116, 97, 110, 40, 36, 55, 42, 112,
  105, 47, 51, 54, 48, 41, 125, 10, 45, 102, 51, 100, 32, 36, 102, 51,
  100, 32, 45, 108, 51, 100, 32, 123, 36, 56, 42, 36, 102, 51, 100, 125,
  44, 123, 36, 57, 42, 36, 102, 51, 100, 125, 44, 123, 36, 49, 48, 42,
  36, 102, 51, 100, 125, 32, 45, 115, 108, 51, 100, 32, 36, 49, 49, 32,
  45, 115, 115, 51, 100, 32, 36, 49, 50, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 42, 51, 100,
  32, 123, 36, 51, 42, 109, 97, 120, 40, 36, 49, 44, 36, 50, 41, 125,
  32, 45, 114, 51, 100, 32, 48, 44, 48, 44, 49, 44, 36, 54, 32, 45,
  114, 51, 100, 32, 48, 44, 49, 44, 48, 44, 36, 53, 32, 45, 114, 51,
  100, 32, 49, 44, 48, 44, 48, 44, 36, 52, 10, 36, 49, 44, 36, 50,
  44, 49, 44, 51, 44, 45, 49, 32, 45, 111, 98, 106, 101, 99, 116, 51,
  100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 53, 48, 37, 44, 53,
  48, 37, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 116, 111, 95, 114,
  103, 98, 97, 32, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108,
  111, 114, 32, 48, 44, 48, 44, 45, 49, 44, 45, 49, 44, 45, 49, 44,
  50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 48, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 98, 108, 111,
  99, 107, 115, 51, 100, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 87, 61, 123, 119, 125, 32,
  72, 61, 123, 104, 125, 32, 77, 61, 123, 109, 97, 120, 40, 119, 44, 104,
  41, 125, 10, 45, 105, 102, 32, 123, 119, 62, 104, 125, 32, 45, 114, 50,
  100, 120, 32, 36, 49, 32, 45, 101, 108, 115, 101, 32, 45, 114, 50, 100,
  121, 32, 36, 49, 32, 45, 101, 110, 100, 105, 102, 10, 119, 61, 123, 119,
  125, 32, 104, 61, 123, 104, 125, 32, 109, 61, 123, 109, 97, 120, 40, 119,
  44, 104, 41, 125, 10, 45, 105, 102, 32, 123, 36, 51, 62, 48, 125, 32,
  45, 109, 105, 114, 114, 111, 114, 32, 121, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 109, 97, 103, 101, 98, 108, 111, 99, 107, 115, 51, 100, 32,
  36, 51, 44, 36, 50, 37, 10, 45, 45, 51, 100, 91, 45, 49, 93, 32,
  123, 36, 119, 47, 50, 125, 44, 123, 36, 104, 47, 50, 125, 32, 102, 61,
  123, 36, 52, 42, 36, 77, 47, 40, 36, 109, 42, 40, 50, 45, 36, 49,
  54, 41, 41, 125, 32, 45, 42, 51, 100, 32, 36, 102, 44, 36, 102, 44,
  123, 36, 102, 42, 97, 98, 115, 40, 36, 51, 42, 36, 49, 47, 49, 48,
  48, 41, 125, 10, 45, 105, 102, 32, 123, 36, 51, 62, 48, 125, 32, 45,
  114, 51, 100, 32, 49, 44, 48, 44, 48, 44, 49, 56, 48, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 51, 100, 32, 48, 44, 48, 44, 49, 44,
  36, 53, 32, 45, 114, 51, 100, 32, 49, 44, 48, 44, 48, 44, 36, 54,
  10, 45, 105, 102, 32, 36, 49, 54, 32, 123, 50, 42, 36, 77, 125, 44,
  123, 50, 42, 36, 77, 125, 44, 49, 44, 52, 44, 45, 49, 32, 45, 101,
  108, 115, 101, 32, 36, 77, 44, 36, 77, 44, 49, 44, 52, 44, 45, 49,
  32, 45, 101, 110, 100, 105, 102, 10, 102, 51, 100, 61, 123, 48, 46, 53,
  42, 119, 47, 116, 97, 110, 40, 36, 55, 42, 112, 105, 47, 51, 54, 48,
  41, 125, 32, 45, 102, 51, 100, 32, 36, 102, 51, 100, 10, 45, 108, 51,
  100, 32, 123, 36, 49, 48, 42, 36, 102, 51, 100, 125, 44, 123, 36, 49,
  49, 42, 36, 102, 51, 100, 125, 44, 123, 36, 49, 50, 42, 36, 102, 51,
  100, 125, 32, 45, 115, 108, 51, 100, 32, 36, 49, 51, 32, 45, 115, 115,
  51, 100, 32, 36, 49, 52, 10, 45, 111, 98, 106, 101, 99, 116, 51, 100,
  91, 45, 49, 93, 32, 91, 48, 93, 44, 36, 56, 37, 44, 36, 57, 37,
  44, 48, 44, 49, 44, 123, 105, 102, 40, 36, 49, 53, 44, 51, 44, 50,
  41, 125, 44, 48, 44, 49, 10, 45, 115, 104, 91, 45, 49, 93, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 43, 91, 45, 49, 93, 32,
  49, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 105, 102, 32, 36, 50, 48, 10, 91, 45, 49,
  93, 44, 91, 45, 49, 93, 44, 49, 44, 51, 44, 45, 49, 10, 45, 111,
  98, 106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 48, 93, 44,
  36, 56, 37, 44, 36, 57, 37, 44, 48, 44, 49, 44, 51, 44, 48, 44,
  49, 32, 45, 114, 109, 91, 48, 93, 10, 45, 103, 114, 97, 100, 105, 101,
  110, 116, 91, 45, 49, 93, 32, 120, 121, 44, 49, 32, 45, 43, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 110, 111, 114, 109, 91, 45, 49, 93, 32,
  45, 110, 101, 113, 91, 45, 49, 93, 32, 48, 10, 45, 45, 114, 91, 45,
  49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 51,
  10, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 48, 32, 45, 42, 91,
  45, 49, 93, 32, 36, 49, 55, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 115, 104, 91, 45, 49, 93, 32, 49, 44, 49, 32, 45, 42, 91, 45,
  49, 93, 32, 36, 49, 56, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  115, 104, 91, 45, 49, 93, 32, 50, 44, 50, 32, 45, 42, 91, 45, 49,
  93, 32, 36, 49, 57, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 106,
  91, 48, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 123, 36, 50, 48, 47, 50, 53, 53, 125, 44, 91, 45, 50, 93, 32,
  45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 108, 115, 101,
  32, 45, 114, 109, 91, 48, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 32, 48, 44,
  48, 44, 45, 49, 44, 45, 49, 44, 45, 49, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 48, 10, 45, 105, 102, 32, 36, 49, 54, 32, 45, 114, 32,
  53, 48, 37, 44, 53, 48, 37, 44, 49, 44, 52, 44, 50, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 95, 103, 105, 109, 112, 95,
  99, 111, 108, 111, 114, 101, 100, 111, 98, 106, 101, 99, 116, 51, 100, 32,
  58, 10, 45, 116, 111, 95, 114, 103, 98, 32, 45, 95, 103, 105, 109, 112,
  95, 99, 111, 108, 111, 114, 101, 100, 111, 98, 106, 101, 99, 116, 51, 100,
  36, 49, 36, 50, 32, 36, 123, 54, 45, 56, 125, 32, 45, 99, 111, 108,
  51, 100, 91, 45, 49, 93, 32, 36, 123, 51, 45, 53, 125, 10, 45, 100,
  98, 51, 100, 32, 48, 10, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114,
  101, 100, 111, 98, 106, 101, 99, 116, 51, 100, 32, 58, 10, 45, 95, 103,
  105, 109, 112, 95, 99, 111, 108, 111, 114, 101, 100, 111, 98, 106, 101, 99,
  116, 51, 100, 32, 34, 95, 34, 44, 36, 123, 49, 45, 52, 44, 54, 45,
  56, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49,
  125, 10, 45, 45, 103, 105, 109, 112, 95, 114, 101, 110, 100, 101, 114, 51,
  100, 91, 45, 49, 93, 32, 64, 123, 36, 62, 44, 119, 125, 44, 64, 123,
  36, 62, 44, 104, 125, 44, 36, 54, 44, 36, 123, 57, 45, 45, 49, 125,
  10, 45, 115, 104, 91, 45, 49, 93, 32, 51, 44, 51, 32, 45, 42, 91,
  45, 49, 93, 32, 123, 36, 53, 47, 50, 53, 53, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 98, 108, 101, 110, 100, 91, 36, 62, 44, 45,
  49, 93, 32, 97, 108, 112, 104, 97, 10, 45, 100, 111, 110, 101, 10, 45,
  114, 109, 91, 45, 49, 93, 10, 103, 105, 109, 112, 95, 99, 111, 108, 111,
  114, 101, 100, 111, 98, 106, 101, 99, 116, 51, 100, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 99, 111, 108,
  111, 114, 101, 100, 111, 98, 106, 101, 99, 116, 51, 100, 32, 34, 95, 112,
  114, 101, 118, 105, 101, 119, 95, 34, 44, 36, 123, 49, 45, 52, 44, 54,
  45, 56, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45,
  49, 125, 10, 45, 45, 103, 105, 109, 112, 95, 114, 101, 110, 100, 101, 114,
  51, 100, 91, 45, 49, 93, 32, 64, 123, 36, 62, 44, 119, 125, 44, 64,
  123, 36, 62, 44, 104, 125, 44, 36, 54, 44, 36, 123, 57, 45, 45, 49,
  125, 10, 45, 115, 104, 91, 45, 49, 93, 32, 51, 44, 51, 32, 45, 42,
  91, 45, 49, 93, 32, 123, 36, 53, 47, 50, 53, 53, 125, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 98, 108, 101, 110, 100, 91, 36, 62, 44,
  45, 49, 93, 32, 97, 108, 112, 104, 97, 10, 45, 100, 111, 110, 101, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 95, 103, 105, 109, 112, 95, 99, 111,
  108, 111, 114, 101, 100, 111, 98, 106, 101, 99, 116, 51, 100, 95, 48, 32,
  58, 32, 45, 112, 108, 97, 110, 101, 51, 100, 32, 49, 32, 45, 42, 51,
  100, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 49, 10, 95, 103,
  105, 109, 112, 95, 99, 111, 108, 111, 114, 101, 100, 111, 98, 106, 101, 99,
  116, 51, 100, 95, 49, 32, 58, 32, 45, 98, 111, 120, 51, 100, 32, 49,
  32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44,
  36, 51, 10, 95, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 101, 100,
  111, 98, 106, 101, 99, 116, 51, 100, 95, 50, 32, 58, 32, 45, 112, 121,
  114, 97, 109, 105, 100, 51, 100, 32, 49, 44, 49, 32, 45, 42, 51, 100,
  91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 10, 95, 103,
  105, 109, 112, 95, 99, 111, 108, 111, 114, 101, 100, 111, 98, 106, 101, 99,
  116, 51, 100, 95, 51, 32, 58, 32, 45, 115, 112, 104, 101, 114, 101, 51,
  100, 32, 49, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 49, 44, 123,
  50, 42, 36, 50, 125, 44, 123, 50, 42, 36, 51, 125, 10, 95, 103, 105,
  109, 112, 95, 99, 111, 108, 111, 114, 101, 100, 111, 98, 106, 101, 99, 116,
  51, 100, 95, 52, 32, 58, 32, 45, 116, 111, 114, 117, 115, 51, 100, 32,
  36, 49, 44, 123, 36, 50, 47, 50, 125, 32, 45, 42, 51, 100, 91, 45,
  49, 93, 32, 36, 51, 44, 48, 46, 53, 44, 48, 46, 53, 10, 95, 103,
  105, 109, 112, 95, 99, 111, 108, 111, 114, 101, 100, 111, 98, 106, 101, 99,
  116, 51, 100, 95, 53, 32, 58, 32, 45, 103, 121, 114, 111, 105, 100, 51,
  100, 32, 50, 52, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 36, 49,
  44, 36, 50, 44, 36, 51, 10, 95, 103, 105, 109, 112, 95, 99, 111, 108,
  111, 114, 101, 100, 111, 98, 106, 101, 99, 116, 51, 100, 95, 54, 32, 58,
  32, 45, 119, 101, 105, 114, 100, 51, 100, 32, 51, 50, 32, 45, 42, 51,
  100, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 10, 95,
  103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 101, 100, 111, 98, 106, 101,
  99, 116, 51, 100, 95, 55, 32, 58, 32, 45, 99, 117, 112, 51, 100, 32,
  49, 50, 56, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 36, 49, 44,
  36, 50, 44, 36, 51, 10, 95, 103, 105, 109, 112, 95, 99, 111, 108, 111,
  114, 101, 100, 111, 98, 106, 101, 99, 116, 51, 100, 95, 112, 114, 101, 118,
  105, 101, 119, 95, 48, 32, 58, 32, 45, 112, 108, 97, 110, 101, 51, 100,
  32, 49, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 36, 49, 44, 36,
  50, 44, 49, 10, 95, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 101,
  100, 111, 98, 106, 101, 99, 116, 51, 100, 95, 112, 114, 101, 118, 105, 101,
  119, 95, 49, 32, 58, 32, 45, 98, 111, 120, 51, 100, 32, 49, 32, 45,
  42, 51, 100, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51,
  10, 95, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 101, 100, 111, 98,
  106, 101, 99, 116, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 95, 50,
  32, 58, 32, 45, 112, 121, 114, 97, 109, 105, 100, 51, 100, 32, 49, 44,
  49, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50,
  44, 36, 51, 10, 95, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 101,
  100, 111, 98, 106, 101, 99, 116, 51, 100, 95, 112, 114, 101, 118, 105, 101,
  119, 95, 51, 32, 58, 32, 45, 115, 112, 104, 101, 114, 101, 51, 100, 32,
  49, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 49, 44, 123, 50, 42,
  36, 50, 125, 44, 123, 50, 42, 36, 51, 125, 10, 95, 103, 105, 109, 112,
  95, 99, 111, 108, 111, 114, 101, 100, 111, 98, 106, 101, 99, 116, 51, 100,
  95, 112, 114, 101, 118, 105, 101, 119, 95, 52, 32, 58, 32, 45, 116, 111,
  114, 117, 115, 51, 100, 32, 36, 49, 44, 123, 36, 50, 47, 50, 125, 32,
  45, 42, 51, 100, 91, 45, 49, 93, 32, 36, 51, 44, 48, 46, 53, 44,
  48, 46, 53, 10, 95, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 101,
  100, 111, 98, 106, 101, 99, 116, 51, 100, 95, 112, 114, 101, 118, 105, 101,
  119, 95, 53, 32, 58, 32, 45, 103, 121, 114, 111, 105, 100, 51, 100, 32,
  56, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50,
  44, 36, 51, 10, 95, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 101,
  100, 111, 98, 106, 101, 99, 116, 51, 100, 95, 112, 114, 101, 118, 105, 101,
  119, 95, 54, 32, 58, 32, 45, 119, 101, 105, 114, 100, 51, 100, 32, 49,
  50, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50,
  44, 36, 51, 10, 95, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 101,
  100, 111, 98, 106, 101, 99, 116, 51, 100, 95, 112, 114, 101, 118, 105, 101,
  119, 95, 55, 32, 58, 32, 45, 99, 117, 112, 51, 100, 32, 54, 52, 32,
  45, 42, 51, 100, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36,
  51, 10, 95, 103, 105, 109, 112, 95, 101, 108, 101, 118, 97, 116, 105, 111,
  110, 51, 100, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64,
  35, 47, 50, 125, 32, 45, 108, 91, 36, 62, 44, 123, 109, 105, 110, 40,
  36, 62, 43, 49, 44, 64, 35, 45, 49, 41, 125, 93, 10, 45, 105, 102,
  32, 123, 64, 35, 61, 61, 49, 125, 32, 45, 45, 110, 111, 114, 109, 32,
  45, 101, 108, 115, 101, 32, 45, 114, 91, 49, 93, 32, 91, 48, 93, 44,
  51, 32, 45, 101, 110, 100, 105, 102, 10, 45, 110, 91, 49, 93, 32, 48,
  44, 36, 49, 32, 45, 98, 91, 49, 93, 32, 36, 50, 10, 45, 101, 108,
  101, 118, 97, 116, 105, 111, 110, 51, 100, 91, 48, 93, 32, 91, 49, 93,
  32, 45, 114, 109, 91, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 45, 100, 98, 51, 100, 10, 103, 105, 109, 112, 95, 101,
  108, 101, 118, 97, 116, 105, 111, 110, 51, 100, 32, 58, 10, 45, 95, 103,
  105, 109, 112, 95, 101, 108, 101, 118, 97, 116, 105, 111, 110, 51, 100, 32,
  36, 123, 49, 45, 50, 125, 32, 45, 103, 105, 109, 112, 95, 114, 101, 110,
  100, 101, 114, 51, 100, 32, 36, 123, 51, 45, 45, 49, 125, 10, 103, 105,
  109, 112, 95, 101, 108, 101, 118, 97, 116, 105, 111, 110, 51, 100, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 101,
  108, 101, 118, 97, 116, 105, 111, 110, 51, 100, 32, 36, 123, 49, 45, 50,
  125, 44, 123, 119, 125, 44, 123, 104, 125, 44, 36, 123, 53, 45, 45, 49,
  125, 10, 95, 103, 105, 109, 112, 95, 101, 120, 116, 114, 117, 100, 101, 51,
  100, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 47,
  50, 125, 32, 45, 108, 91, 36, 62, 44, 123, 109, 105, 110, 40, 36, 62,
  43, 49, 44, 64, 35, 45, 49, 41, 125, 93, 10, 45, 101, 120, 116, 114,
  117, 100, 101, 51, 100, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44,
  36, 51, 37, 10, 45, 105, 102, 32, 123, 64, 35, 61, 61, 50, 125, 32,
  45, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 114,
  109, 91, 45, 50, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 100, 98, 51, 100, 32, 48,
  10, 103, 105, 109, 112, 95, 101, 120, 116, 114, 117, 100, 101, 51, 100, 32,
  58, 10, 45, 95, 103, 105, 109, 112, 95, 101, 120, 116, 114, 117, 100, 101,
  51, 100, 32, 36, 123, 49, 45, 51, 125, 32, 45, 103, 105, 109, 112, 95,
  114, 101, 110, 100, 101, 114, 51, 100, 32, 36, 123, 52, 45, 45, 49, 125,
  10, 103, 105, 109, 112, 95, 101, 120, 116, 114, 117, 100, 101, 51, 100, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  101, 120, 116, 114, 117, 100, 101, 51, 100, 32, 36, 123, 49, 45, 51, 125,
  44, 123, 119, 125, 44, 123, 104, 125, 44, 36, 123, 54, 45, 45, 49, 125,
  10, 95, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101,
  99, 116, 51, 100, 32, 58, 10, 45, 116, 111, 95, 114, 103, 98, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 45, 95, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106,
  101, 99, 116, 51, 100, 36, 49, 36, 50, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 45, 100, 98, 51, 100, 32, 48, 10, 103, 105,
  109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100,
  32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111,
  98, 106, 101, 99, 116, 51, 100, 32, 34, 95, 34, 44, 36, 49, 32, 45,
  103, 105, 109, 112, 95, 114, 101, 110, 100, 101, 114, 51, 100, 32, 36, 123,
  50, 45, 45, 49, 125, 10, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101,
  111, 98, 106, 101, 99, 116, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 32, 45,
  95, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99,
  116, 51, 100, 32, 34, 95, 112, 114, 101, 118, 105, 101, 119, 95, 34, 44,
  36, 49, 32, 45, 103, 105, 109, 112, 95, 114, 101, 110, 100, 101, 114, 51,
  100, 32, 36, 119, 44, 36, 104, 44, 36, 123, 52, 45, 45, 49, 125, 10,
  95, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99,
  116, 51, 100, 95, 48, 32, 58, 32, 45, 105, 109, 97, 103, 101, 112, 108,
  97, 110, 101, 51, 100, 10, 95, 103, 105, 109, 112, 95, 105, 109, 97, 103,
  101, 111, 98, 106, 101, 99, 116, 51, 100, 95, 49, 32, 58, 32, 45, 105,
  109, 97, 103, 101, 99, 117, 98, 101, 51, 100, 10, 95, 103, 105, 109, 112,
  95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 95, 50,
  32, 58, 32, 45, 105, 109, 97, 103, 101, 112, 121, 114, 97, 109, 105, 100,
  51, 100, 10, 95, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98,
  106, 101, 99, 116, 51, 100, 95, 51, 32, 58, 32, 45, 105, 109, 97, 103,
  101, 115, 112, 104, 101, 114, 101, 51, 100, 32, 54, 52, 44, 51, 50, 10,
  95, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99,
  116, 51, 100, 95, 52, 32, 58, 32, 45, 116, 111, 114, 117, 115, 51, 100,
  32, 49, 48, 48, 44, 51, 48, 32, 45, 116, 51, 100, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 32, 45, 114, 109, 91, 45, 50, 93, 10, 95, 103,
  105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51,
  100, 95, 53, 32, 58, 32, 45, 103, 121, 114, 111, 105, 100, 51, 100, 32,
  50, 52, 32, 45, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  32, 45, 114, 109, 91, 45, 50, 93, 10, 95, 103, 105, 109, 112, 95, 105,
  109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 95, 54, 32, 58,
  32, 45, 119, 101, 105, 114, 100, 51, 100, 32, 51, 50, 32, 45, 116, 51,
  100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 114, 109, 91, 45,
  50, 93, 10, 95, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98,
  106, 101, 99, 116, 51, 100, 95, 55, 32, 58, 32, 45, 99, 117, 112, 51,
  100, 32, 49, 50, 56, 32, 45, 116, 51, 100, 91, 45, 49, 93, 32, 91,
  45, 50, 93, 32, 45, 114, 109, 91, 45, 50, 93, 10, 95, 103, 105, 109,
  112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 95,
  56, 32, 58, 32, 45, 105, 109, 97, 103, 101, 114, 117, 98, 105, 107, 51,
  100, 32, 53, 44, 53, 10, 95, 103, 105, 109, 112, 95, 105, 109, 97, 103,
  101, 111, 98, 106, 101, 99, 116, 51, 100, 95, 112, 114, 101, 118, 105, 101,
  119, 95, 48, 32, 58, 32, 45, 105, 109, 97, 103, 101, 112, 108, 97, 110,
  101, 51, 100, 10, 95, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111,
  98, 106, 101, 99, 116, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 95,
  49, 32, 58, 32, 45, 105, 109, 97, 103, 101, 99, 117, 98, 101, 51, 100,
  10, 95, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101,
  99, 116, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 95, 50, 32, 58,
  32, 45, 105, 109, 97, 103, 101, 112, 121, 114, 97, 109, 105, 100, 51, 100,
  10, 95, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101,
  99, 116, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 95, 51, 32, 58,
  32, 45, 105, 109, 97, 103, 101, 115, 112, 104, 101, 114, 101, 51, 100, 32,
  49, 54, 44, 56, 10, 95, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101,
  111, 98, 106, 101, 99, 116, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119,
  95, 52, 32, 58, 32, 45, 116, 111, 114, 117, 115, 51, 100, 32, 49, 48,
  48, 44, 51, 48, 32, 45, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 32, 45, 114, 109, 91, 45, 50, 93, 10, 95, 103, 105, 109, 112,
  95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 95, 112,
  114, 101, 118, 105, 101, 119, 95, 53, 32, 58, 32, 45, 103, 121, 114, 111,
  105, 100, 51, 100, 32, 56, 32, 45, 99, 51, 100, 91, 45, 49, 93, 32,
  45, 110, 51, 100, 91, 45, 49, 93, 32, 45, 116, 51, 100, 91, 45, 49,
  93, 32, 91, 45, 50, 93, 32, 45, 114, 109, 91, 45, 50, 93, 10, 95,
  103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116,
  51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 95, 54, 32, 58, 32, 45,
  119, 101, 105, 114, 100, 51, 100, 32, 49, 50, 32, 45, 116, 51, 100, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 114, 109, 91, 45, 50, 93,
  10, 95, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101,
  99, 116, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 95, 55, 32, 58,
  32, 45, 99, 117, 112, 51, 100, 32, 54, 52, 32, 45, 116, 51, 100, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 114, 109, 91, 45, 50, 93,
  10, 95, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101,
  99, 116, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 95, 56, 32, 58,
  32, 45, 105, 109, 97, 103, 101, 114, 117, 98, 105, 107, 51, 100, 32, 51,
  44, 51, 44, 53, 44, 53, 10, 95, 103, 105, 109, 112, 95, 108, 97, 116,
  104, 105, 110, 103, 51, 100, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 123, 64, 35, 47, 50, 125, 32, 45, 108, 91, 36, 62, 44, 123, 109,
  105, 110, 40, 36, 62, 43, 49, 44, 64, 35, 45, 49, 41, 125, 93, 10,
  45, 108, 97, 116, 104, 101, 51, 100, 91, 45, 49, 93, 32, 36, 49, 44,
  36, 50, 37, 44, 36, 51, 10, 45, 105, 102, 32, 123, 64, 35, 61, 61,
  50, 125, 32, 45, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  32, 45, 114, 109, 91, 45, 50, 93, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 100, 98, 51,
  100, 32, 48, 10, 103, 105, 109, 112, 95, 108, 97, 116, 104, 105, 110, 103,
  51, 100, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 108, 97, 116, 104,
  105, 110, 103, 51, 100, 32, 36, 123, 49, 45, 51, 125, 32, 45, 103, 105,
  109, 112, 95, 114, 101, 110, 100, 101, 114, 51, 100, 32, 36, 123, 52, 45,
  45, 49, 125, 10, 103, 105, 109, 112, 95, 108, 97, 116, 104, 105, 110, 103,
  51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 108, 97, 116, 104, 105, 110, 103, 51, 100, 32, 36, 123, 49,
  45, 51, 125, 44, 123, 119, 125, 44, 123, 104, 125, 44, 36, 123, 54, 45,
  45, 49, 125, 10, 103, 105, 109, 112, 95, 114, 97, 110, 100, 111, 109, 51,
  100, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 102, 51, 100, 61, 123, 48, 46, 53, 42, 109,
  97, 120, 40, 119, 44, 104, 41, 47, 116, 97, 110, 40, 36, 53, 42, 112,
  105, 47, 51, 54, 48, 41, 125, 32, 45, 102, 51, 100, 32, 36, 102, 51,
  100, 32, 45, 108, 51, 100, 32, 123, 36, 54, 42, 36, 102, 51, 100, 125,
  44, 123, 36, 55, 42, 36, 102, 51, 100, 125, 44, 123, 36, 56, 42, 36,
  102, 51, 100, 125, 32, 45, 115, 108, 51, 100, 32, 36, 57, 32, 45, 115,
  115, 51, 100, 32, 36, 49, 48, 10, 45, 116, 111, 95, 114, 103, 98, 32,
  40, 123, 119, 125, 44, 123, 104, 125, 44, 123, 100, 125, 44, 123, 115, 125,
  41, 32, 45, 47, 91, 45, 49, 93, 32, 50, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 36, 50, 10, 40, 64, 123, 49, 44, 48, 125, 41, 32, 45,
  43, 91, 45, 49, 93, 32, 64, 123, 49, 44, 49, 125, 32, 45, 42, 91,
  45, 49, 93, 32, 36, 51, 32, 45, 47, 91, 45, 49, 93, 32, 49, 48,
  48, 32, 45, 95, 103, 105, 109, 112, 95, 114, 97, 110, 100, 111, 109, 51,
  100, 36, 49, 32, 64, 45, 49, 32, 45, 114, 109, 91, 45, 50, 93, 10,
  45, 114, 51, 100, 91, 45, 49, 93, 32, 49, 44, 49, 44, 48, 44, 123,
  63, 40, 48, 44, 51, 54, 48, 41, 125, 10, 40, 123, 63, 40, 45, 49,
  44, 49, 41, 125, 41, 32, 45, 42, 91, 45, 49, 93, 32, 64, 123, 49,
  44, 48, 125, 32, 40, 123, 63, 40, 45, 49, 44, 49, 41, 125, 41, 32,
  45, 42, 91, 45, 49, 93, 32, 64, 123, 49, 44, 49, 125, 10, 45, 43,
  51, 100, 91, 45, 51, 93, 32, 64, 45, 50, 44, 64, 45, 49, 44, 123,
  63, 40, 45, 36, 52, 44, 36, 52, 41, 125, 32, 45, 114, 109, 91, 45,
  50, 44, 45, 49, 93, 10, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93,
  32, 123, 63, 40, 50, 53, 53, 41, 125, 44, 123, 63, 40, 50, 53, 53,
  41, 125, 44, 123, 63, 40, 50, 53, 53, 41, 125, 32, 45, 100, 111, 110,
  101, 32, 45, 43, 51, 100, 91, 50, 45, 45, 49, 93, 32, 45, 111, 98,
  106, 101, 99, 116, 51, 100, 91, 48, 93, 32, 91, 45, 49, 93, 44, 53,
  48, 37, 44, 53, 48, 37, 44, 48, 44, 36, 49, 50, 44, 36, 49, 49,
  44, 48, 44, 49, 10, 45, 107, 91, 48, 93, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 95, 103, 105, 109, 112, 95, 114, 97, 110,
  100, 111, 109, 51, 100, 48, 32, 58, 32, 45, 98, 111, 120, 51, 100, 32,
  36, 49, 10, 95, 103, 105, 109, 112, 95, 114, 97, 110, 100, 111, 109, 51,
  100, 49, 32, 58, 32, 40, 36, 49, 41, 32, 45, 47, 91, 45, 49, 93,
  32, 50, 32, 45, 99, 111, 110, 101, 51, 100, 32, 64, 45, 49, 44, 36,
  49, 32, 45, 114, 109, 91, 45, 50, 93, 10, 95, 103, 105, 109, 112, 95,
  114, 97, 110, 100, 111, 109, 51, 100, 50, 32, 58, 32, 40, 36, 49, 41,
  32, 45, 47, 91, 45, 49, 93, 32, 50, 32, 45, 99, 121, 108, 105, 110,
  100, 101, 114, 51, 100, 32, 64, 45, 49, 44, 36, 49, 32, 45, 114, 109,
  91, 45, 50, 93, 10, 95, 103, 105, 109, 112, 95, 114, 97, 110, 100, 111,
  109, 51, 100, 51, 32, 58, 32, 45, 115, 112, 104, 101, 114, 101, 51, 100,
  32, 36, 49, 44, 50, 10, 95, 103, 105, 109, 112, 95, 114, 97, 110, 100,
  111, 109, 51, 100, 52, 32, 58, 32, 40, 36, 49, 41, 32, 45, 47, 91,
  45, 49, 93, 32, 51, 32, 45, 116, 111, 114, 117, 115, 51, 100, 32, 36,
  49, 44, 64, 45, 49, 32, 45, 114, 109, 91, 45, 50, 93, 10, 103, 105,
  109, 112, 95, 98, 97, 108, 108, 32, 58, 10, 45, 98, 97, 108, 108, 32,
  36, 49, 44, 36, 123, 53, 45, 55, 125, 44, 36, 123, 50, 45, 52, 125,
  32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 10, 103, 105, 109, 112, 95,
  98, 97, 108, 108, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 98, 97, 108, 108, 32, 36, 42, 10, 45, 105, 102,
  32, 123, 64, 35, 62, 49, 125, 32, 45, 98, 108, 101, 110, 100, 91, 45,
  50, 44, 45, 49, 93, 32, 97, 108, 112, 104, 97, 44, 49, 44, 49, 32,
  45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 99, 117, 112, 105,
  100, 32, 58, 10, 45, 105, 102, 32, 123, 64, 35, 62, 48, 125, 32, 115,
  105, 122, 61, 123, 109, 105, 110, 40, 64, 123, 45, 109, 105, 110, 95, 119,
  125, 44, 64, 123, 45, 109, 105, 110, 95, 104, 125, 41, 125, 32, 45, 101,
  108, 115, 101, 32, 115, 105, 122, 61, 53, 49, 50, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 99, 117, 112, 105, 100, 32, 36, 115, 105, 122, 32, 45,
  116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 10, 45, 114, 101, 112,
  108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 48,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 36, 50, 44,
  36, 51, 44, 36, 52, 44, 48, 10, 45, 114, 101, 112, 108, 97, 99, 101,
  95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 49,
  44, 49, 44, 49, 44, 50, 53, 53, 44, 36, 50, 44, 36, 51, 44, 36,
  52, 44, 36, 53, 10, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93, 32,
  123, 50, 46, 53, 42, 36, 49, 125, 37, 44, 123, 50, 46, 53, 42, 36,
  49, 125, 37, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 48, 32, 45,
  98, 91, 45, 49, 93, 32, 36, 49, 37, 10, 45, 98, 108, 101, 110, 100,
  91, 45, 50, 44, 45, 49, 93, 32, 97, 108, 112, 104, 97, 10, 103, 105,
  109, 112, 95, 101, 113, 117, 97, 116, 105, 111, 110, 95, 112, 97, 114, 97,
  109, 101, 116, 114, 105, 99, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 61, 123, 119, 125,
  32, 104, 61, 123, 104, 125, 32, 45, 114, 109, 10, 36, 53, 44, 49, 44,
  49, 44, 50, 44, 39, 34, 116, 61, 36, 51, 43, 120, 42, 40, 36, 52,
  45, 36, 51, 41, 47, 40, 36, 53, 45, 49, 41, 59, 105, 102, 40, 99,
  61, 61, 48, 44, 36, 49, 44, 36, 50, 41, 34, 39, 10, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 44, 50, 10, 40,
  36, 56, 44, 36, 49, 49, 94, 36, 57, 44, 36, 49, 50, 94, 36, 49,
  48, 44, 36, 49, 51, 41, 32, 45, 114, 91, 45, 49, 93, 32, 64, 123,
  45, 50, 44, 119, 125, 44, 49, 44, 49, 44, 51, 44, 51, 32, 45, 97,
  32, 99, 10, 45, 100, 105, 115, 112, 108, 97, 121, 95, 112, 97, 114, 97,
  109, 101, 116, 114, 105, 99, 32, 36, 119, 44, 36, 104, 44, 123, 36, 54,
  43, 36, 49, 52, 42, 49, 46, 48, 48, 49, 125, 44, 36, 55, 44, 36,
  49, 53, 44, 36, 49, 54, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 103, 105, 109, 112, 95, 101, 113, 117, 97, 116, 105, 111, 110,
  95, 112, 108, 111, 116, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 61, 123, 119, 125, 32,
  104, 61, 123, 104, 125, 32, 45, 114, 109, 10, 36, 52, 44, 49, 44, 49,
  44, 36, 53, 44, 34, 88, 61, 36, 50, 43, 40, 36, 51, 45, 36, 50,
  41, 42, 120, 47, 40, 36, 52, 45, 49, 41, 59, 36, 49, 34, 10, 45,
  100, 103, 32, 36, 119, 44, 36, 104, 44, 36, 54, 44, 36, 55, 44, 36,
  50, 44, 36, 51, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 103, 105, 109, 112, 95, 99, 111, 114, 110, 101, 114, 95, 103, 114, 97,
  100, 105, 101, 110, 116, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 10, 40, 123, 119, 125, 44, 123, 104, 125, 41, 32, 45, 114, 109,
  91, 45, 50, 93, 10, 40, 36, 49, 44, 36, 53, 59, 36, 57, 44, 36,
  49, 51, 94, 36, 50, 44, 36, 54, 59, 36, 49, 48, 44, 36, 49, 52,
  94, 36, 51, 44, 36, 55, 59, 36, 49, 49, 44, 36, 49, 53, 94, 36,
  52, 44, 36, 56, 59, 36, 49, 50, 44, 36, 49, 54, 41, 32, 45, 114,
  91, 45, 49, 93, 32, 64, 45, 50, 44, 49, 44, 52, 44, 51, 32, 45,
  114, 109, 91, 45, 50, 93, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48,
  32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 99, 117, 115, 116,
  111, 109, 95, 103, 114, 97, 100, 105, 101, 110, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36, 123, 49,
  53, 61, 125, 34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 36, 52, 10, 45, 45,
  95, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 103, 114, 97,
  100, 105, 101, 110, 116, 49, 32, 36, 123, 49, 45, 49, 52, 125, 44, 34,
  36, 49, 53, 34, 44, 36, 123, 49, 54, 45, 45, 49, 125, 32, 45, 45,
  101, 114, 111, 100, 101, 91, 45, 49, 93, 32, 51, 32, 45, 45, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 45, 100, 105, 108, 97, 116, 101, 91, 45,
  49, 93, 32, 53, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99,
  32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 103,
  105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 103, 114, 97, 100, 105,
  101, 110, 116, 91, 48, 93, 32, 36, 123, 49, 45, 49, 52, 125, 44, 34,
  36, 49, 53, 34, 44, 36, 123, 49, 54, 45, 45, 49, 125, 44, 45, 49,
  32, 45, 98, 108, 101, 110, 100, 32, 97, 108, 112, 104, 97, 10, 45, 101,
  108, 115, 101, 32, 45, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109,
  95, 103, 114, 97, 100, 105, 101, 110, 116, 32, 36, 123, 49, 45, 49, 52,
  125, 44, 34, 36, 49, 53, 34, 44, 36, 123, 49, 54, 45, 45, 49, 125,
  44, 45, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36,
  49, 52, 10, 45, 45, 95, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111,
  109, 95, 103, 114, 97, 100, 105, 101, 110, 116, 48, 91, 93, 32, 36, 123,
  49, 45, 49, 52, 125, 44, 34, 36, 49, 53, 34, 44, 36, 123, 49, 54,
  45, 45, 49, 125, 32, 45, 114, 91, 45, 49, 93, 32, 123, 64, 123, 48,
  44, 119, 125, 45, 49, 54, 125, 44, 49, 54, 44, 49, 44, 52, 32, 45,
  102, 114, 97, 109, 101, 91, 45, 49, 93, 32, 49, 44, 49, 44, 48, 32,
  45, 106, 91, 48, 93, 32, 91, 45, 49, 93, 44, 56, 44, 64, 123, 48,
  44, 104, 45, 50, 53, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 103, 114,
  97, 100, 105, 101, 110, 116, 32, 58, 32, 45, 115, 107, 105, 112, 32, 34,
  36, 123, 49, 53, 61, 125, 34, 10, 45, 95, 103, 105, 109, 112, 95, 99,
  117, 115, 116, 111, 109, 95, 103, 114, 97, 100, 105, 101, 110, 116, 48, 32,
  36, 123, 49, 45, 49, 52, 125, 44, 34, 36, 49, 53, 34, 44, 36, 123,
  49, 54, 45, 45, 49, 125, 10, 45, 105, 102, 32, 123, 36, 45, 49, 62,
  61, 48, 38, 38, 110, 97, 114, 103, 40, 34, 36, 49, 53, 34, 41, 125,
  10, 100, 105, 114, 95, 103, 103, 114, 61, 64, 123, 45, 112, 97, 116, 104,
  95, 103, 105, 109, 112, 125, 47, 103, 114, 97, 100, 105, 101, 110, 116, 115,
  10, 48, 32, 45, 110, 109, 91, 45, 49, 93, 32, 64, 123, 34, 45, 110,
  111, 114, 109, 97, 108, 105, 122, 101, 95, 102, 105, 108, 101, 110, 97, 109,
  101, 32, 92, 34, 36, 49, 53, 92, 34, 34, 125, 32, 110, 97, 109, 101,
  95, 103, 103, 114, 61, 64, 123, 45, 49, 44, 98, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 111, 117, 116, 112, 117, 116, 95, 103, 103, 114,
  91, 45, 49, 93, 32, 36, 100, 105, 114, 95, 103, 103, 114, 47, 36, 110,
  97, 109, 101, 95, 103, 103, 114, 46, 103, 103, 114, 44, 34, 36, 49, 53,
  34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 91, 45, 50, 93, 32,
  40, 48, 94, 48, 94, 48, 94, 48, 41, 32, 45, 97, 91, 45, 50, 44,
  45, 49, 93, 32, 120, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64,
  35, 45, 49, 125, 32, 45, 108, 91, 36, 62, 44, 45, 49, 93, 10, 45,
  95, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 103, 114, 97,
  100, 105, 101, 110, 116, 49, 91, 48, 93, 32, 36, 123, 49, 45, 49, 52,
  125, 44, 34, 36, 49, 53, 34, 44, 36, 123, 49, 54, 45, 45, 49, 125,
  10, 45, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 48, 93, 32, 49,
  44, 36, 49, 49, 32, 45, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91,
  48, 93, 32, 48, 44, 36, 49, 49, 32, 45, 42, 91, 45, 49, 93, 32,
  45, 49, 32, 45, 43, 91, 48, 93, 32, 49, 32, 45, 43, 91, 48, 44,
  45, 50, 44, 45, 49, 93, 10, 109, 61, 123, 36, 57, 37, 42, 64, 123,
  48, 44, 105, 109, 125, 125, 32, 77, 61, 123, 36, 49, 48, 37, 42, 64,
  123, 48, 44, 105, 77, 125, 125, 10, 45, 45, 91, 48, 93, 32, 36, 109,
  32, 45, 42, 91, 48, 93, 32, 123, 64, 123, 49, 44, 119, 45, 50, 125,
  47, 40, 36, 77, 45, 36, 109, 41, 125, 32, 45, 43, 91, 48, 93, 32,
  49, 10, 45, 114, 111, 117, 110, 100, 91, 48, 93, 32, 45, 109, 97, 112,
  91, 48, 93, 32, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 45, 114, 109, 91, 45, 49, 93, 10, 95, 103, 105,
  109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 103, 114, 97, 100, 105, 101,
  110, 116, 48, 32, 58, 10, 45, 105, 102, 32, 36, 49, 54, 32, 52, 44,
  56, 44, 49, 44, 49, 44, 36, 123, 49, 56, 45, 53, 54, 125, 32, 45,
  112, 101, 114, 109, 117, 116, 101, 91, 45, 49, 93, 32, 121, 122, 99, 120,
  10, 45, 101, 108, 115, 101, 32, 56, 44, 49, 44, 49, 44, 51, 32, 45,
  115, 114, 97, 110, 100, 32, 36, 49, 55, 32, 45, 114, 97, 110, 100, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 116, 111, 95, 114, 103,
  98, 97, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 122,
  91, 45, 49, 93, 32, 48, 44, 123, 36, 53, 45, 49, 125, 10, 45, 105,
  102, 32, 36, 49, 51, 10, 45, 114, 91, 45, 49, 93, 32, 123, 50, 48,
  48, 42, 36, 54, 125, 37, 44, 49, 44, 49, 44, 52, 44, 48, 44, 50,
  10, 45, 95, 95, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95,
  103, 114, 97, 100, 105, 101, 110, 116, 48, 91, 45, 49, 93, 32, 36, 49,
  50, 44, 36, 56, 10, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32,
  123, 45, 36, 55, 47, 50, 125, 37, 44, 48, 44, 48, 44, 48, 44, 50,
  32, 45, 122, 91, 45, 49, 93, 32, 48, 44, 123, 119, 47, 50, 45, 49,
  125, 10, 45, 101, 108, 115, 101, 10, 45, 95, 95, 103, 105, 109, 112, 95,
  99, 117, 115, 116, 111, 109, 95, 103, 114, 97, 100, 105, 101, 110, 116, 48,
  91, 45, 49, 93, 32, 36, 49, 50, 44, 36, 56, 10, 45, 114, 91, 45,
  49, 93, 32, 123, 49, 48, 48, 42, 36, 54, 125, 37, 44, 49, 44, 49,
  44, 52, 44, 48, 44, 50, 32, 45, 115, 104, 105, 102, 116, 91, 45, 49,
  93, 32, 45, 36, 55, 37, 44, 48, 44, 48, 44, 48, 44, 50, 10, 45,
  101, 110, 100, 105, 102, 10, 95, 95, 103, 105, 109, 112, 95, 99, 117, 115,
  116, 111, 109, 95, 103, 114, 97, 100, 105, 101, 110, 116, 48, 32, 58, 10,
  45, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 32, 45, 115, 104, 91,
  45, 49, 93, 32, 48, 44, 50, 32, 45, 114, 103, 98, 50, 104, 115, 118,
  91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 61, 61, 50, 125, 32, 45, 115, 104, 91, 45,
  49, 93, 32, 48, 44, 50, 32, 45, 115, 114, 103, 98, 50, 114, 103, 98,
  91, 45, 49, 93, 32, 45, 114, 103, 98, 50, 108, 97, 98, 91, 45, 49,
  93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 114, 91, 45, 49, 93, 32, 123, 36, 50, 42, 119, 125, 44, 49,
  44, 49, 44, 52, 44, 51, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61,
  49, 125, 32, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 50, 32, 45,
  104, 115, 118, 50, 114, 103, 98, 91, 45, 49, 93, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 50,
  125, 32, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 50, 32, 45, 108,
  97, 98, 50, 114, 103, 98, 91, 45, 49, 93, 32, 45, 114, 103, 98, 50,
  115, 114, 103, 98, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 101, 110, 100, 105, 102, 10, 95, 103, 105, 109, 112, 95, 99, 117,
  115, 116, 111, 109, 95, 103, 114, 97, 100, 105, 101, 110, 116, 49, 32, 58,
  10, 45, 98, 32, 36, 50, 37, 10, 45, 105, 102, 32, 123, 36, 49, 61,
  61, 48, 125, 10, 45, 116, 111, 95, 97, 32, 45, 115, 112, 108, 105, 116,
  95, 111, 112, 97, 99, 105, 116, 121, 10, 45, 105, 102, 32, 123, 105, 77,
  62, 105, 109, 43, 51, 50, 125, 10, 45, 114, 109, 91, 45, 50, 93, 32,
  45, 103, 101, 91, 48, 93, 32, 123, 49, 48, 48, 45, 36, 51, 125, 37,
  10, 45, 101, 108, 115, 101, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  110, 111, 114, 109, 32, 45, 110, 32, 48, 44, 49, 10, 45, 105, 102, 32,
  123, 105, 97, 62, 48, 46, 53, 125, 32, 45, 108, 101, 91, 48, 93, 32,
  36, 51, 37, 32, 45, 101, 108, 115, 101, 32, 45, 103, 101, 91, 48, 93,
  32, 123, 49, 48, 48, 45, 36, 51, 125, 37, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 61, 61, 49, 125, 10, 45, 114, 101, 109, 111, 118, 101, 95, 111,
  112, 97, 99, 105, 116, 121, 32, 45, 110, 111, 114, 109, 32, 45, 108, 101,
  32, 36, 51, 37, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61,
  50, 125, 10, 45, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105,
  116, 121, 32, 45, 110, 111, 114, 109, 32, 45, 103, 101, 32, 123, 49, 48,
  48, 45, 36, 51, 125, 37, 10, 45, 101, 108, 115, 101, 10, 45, 116, 111,
  95, 97, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 49, 48, 48,
  37, 32, 45, 103, 101, 32, 123, 49, 48, 48, 45, 36, 51, 125, 37, 10,
  45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 108, 105, 110, 101,
  95, 103, 114, 97, 100, 105, 101, 110, 116, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 34, 36, 123, 49, 48, 61, 125, 34, 10, 45, 95, 103, 105, 109,
  112, 95, 108, 105, 110, 101, 95, 103, 114, 97, 100, 105, 101, 110, 116, 32,
  36, 42, 10, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40, 34, 36, 49,
  48, 34, 41, 125, 10, 100, 105, 114, 95, 103, 103, 114, 61, 64, 123, 45,
  112, 97, 116, 104, 95, 103, 105, 109, 112, 125, 47, 103, 114, 97, 100, 105,
  101, 110, 116, 115, 10, 48, 32, 45, 110, 109, 91, 45, 49, 93, 32, 64,
  123, 34, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 102, 105, 108,
  101, 110, 97, 109, 101, 32, 92, 34, 36, 49, 48, 92, 34, 34, 125, 32,
  110, 97, 109, 101, 95, 103, 103, 114, 61, 64, 123, 45, 49, 44, 98, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 111, 117, 116, 112, 117, 116,
  95, 103, 103, 114, 91, 45, 49, 93, 32, 36, 100, 105, 114, 95, 103, 103,
  114, 47, 36, 110, 97, 109, 101, 95, 103, 103, 114, 46, 103, 103, 114, 44,
  34, 36, 49, 48, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 114, 91, 36, 62, 93, 32, 49,
  48, 48, 37, 44, 54, 52, 44, 49, 44, 49, 48, 48, 37, 32, 45, 100,
  111, 110, 101, 10, 103, 105, 109, 112, 95, 108, 105, 110, 101, 95, 103, 114,
  97, 100, 105, 101, 110, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 45, 116, 111, 95, 114, 103, 98, 97, 10, 45, 105, 102, 32,
  36, 57, 32, 45, 45, 95, 103, 105, 109, 112, 95, 108, 105, 110, 101, 95,
  103, 114, 97, 100, 105, 101, 110, 116, 32, 36, 42, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 108, 91, 48, 93, 10, 45, 108, 105, 110, 101, 32, 36,
  49, 37, 44, 36, 50, 37, 44, 36, 51, 37, 44, 36, 52, 37, 44, 49,
  44, 48, 120, 70, 48, 70, 48, 70, 48, 70, 48, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 108, 105, 110,
  101, 32, 36, 49, 37, 44, 36, 50, 37, 44, 36, 51, 37, 44, 36, 52,
  37, 44, 49, 44, 48, 120, 48, 70, 48, 70, 48, 70, 48, 70, 44, 48,
  44, 48, 44, 48, 44, 50, 53, 53, 10, 45, 99, 105, 114, 99, 108, 101,
  32, 36, 49, 37, 44, 36, 50, 37, 44, 52, 44, 49, 44, 50, 53, 53,
  44, 48, 44, 48, 44, 50, 53, 53, 10, 45, 99, 105, 114, 99, 108, 101,
  32, 36, 51, 37, 44, 36, 52, 37, 44, 52, 44, 49, 44, 48, 44, 48,
  44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 99, 105, 114, 99, 108, 101,
  32, 36, 49, 37, 44, 36, 50, 37, 44, 52, 44, 49, 44, 48, 120, 70,
  70, 70, 70, 70, 70, 70, 70, 44, 48, 44, 48, 44, 48, 44, 50, 53,
  53, 10, 45, 99, 105, 114, 99, 108, 101, 32, 36, 51, 37, 44, 36, 52,
  37, 44, 52, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70,
  44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108,
  10, 45, 105, 102, 32, 123, 64, 35, 62, 49, 125, 32, 45, 114, 91, 45,
  49, 93, 32, 123, 64, 123, 48, 44, 119, 125, 45, 51, 50, 125, 44, 51,
  50, 44, 49, 44, 52, 44, 49, 32, 45, 102, 114, 97, 109, 101, 91, 45,
  49, 93, 32, 49, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53,
  32, 45, 106, 91, 48, 93, 32, 91, 49, 93, 44, 49, 54, 44, 123, 64,
  123, 48, 44, 104, 125, 45, 52, 56, 125, 32, 45, 114, 109, 91, 45, 49,
  93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 95, 103, 105, 109, 112, 95, 108, 105, 110, 101, 95,
  103, 114, 97, 100, 105, 101, 110, 116, 32, 58, 10, 45, 97, 116, 95, 108,
  105, 110, 101, 32, 36, 49, 37, 44, 36, 50, 37, 44, 48, 44, 36, 51,
  37, 44, 36, 52, 37, 44, 48, 32, 45, 114, 32, 123, 109, 97, 120, 40,
  48, 46, 49, 44, 36, 53, 41, 125, 37, 44, 49, 44, 49, 44, 49, 48,
  48, 37, 44, 49, 10, 45, 109, 32, 34, 102, 101, 97, 116, 117, 114, 101,
  49, 32, 58, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48, 34,
  10, 45, 109, 32, 34, 102, 101, 97, 116, 117, 114, 101, 50, 32, 58, 32,
  45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 49, 34, 10, 45, 109, 32,
  34, 102, 101, 97, 116, 117, 114, 101, 51, 32, 58, 32, 45, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 50, 34, 10, 45, 109, 32, 34, 102, 101, 97,
  116, 117, 114, 101, 52, 32, 58, 32, 45, 116, 111, 95, 114, 103, 98, 32,
  45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 34, 10, 45, 109, 32, 34,
  102, 101, 97, 116, 117, 114, 101, 53, 32, 58, 32, 45, 116, 111, 95, 114,
  103, 98, 32, 45, 114, 103, 98, 50, 121, 99, 98, 99, 114, 32, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 49, 34, 10, 45, 109, 32, 34, 102,
  101, 97, 116, 117, 114, 101, 54, 32, 58, 32, 45, 116, 111, 95, 114, 103,
  98, 32, 45, 114, 103, 98, 50, 121, 99, 98, 99, 114, 32, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 32, 50, 34, 10, 45, 109, 32, 34, 102, 101,
  97, 116, 117, 114, 101, 55, 32, 58, 32, 45, 116, 111, 95, 114, 103, 98,
  32, 45, 115, 114, 103, 98, 50, 114, 103, 98, 32, 45, 114, 103, 98, 50,
  108, 97, 98, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48, 34,
  10, 45, 105, 102, 32, 36, 55, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 45, 102, 101, 97, 116,
  117, 114, 101, 36, 55, 32, 45, 114, 118, 32, 45, 97, 32, 121, 32, 45,
  115, 111, 114, 116, 32, 43, 44, 120, 32, 45, 114, 111, 119, 115, 32, 49,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 36, 54, 32, 45, 114, 32, 36, 54,
  44, 49, 44, 49, 44, 49, 48, 48, 37, 44, 51, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 36, 56, 32, 45, 109, 105, 114, 114, 111,
  114, 32, 120, 32, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95,
  108, 105, 110, 101, 97, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 32,
  58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 40, 123, 119,
  125, 44, 123, 104, 125, 41, 32, 45, 114, 109, 91, 45, 50, 93, 10, 40,
  36, 49, 94, 36, 50, 94, 36, 51, 94, 36, 52, 41, 32, 40, 36, 53,
  94, 36, 54, 94, 36, 55, 94, 36, 56, 41, 10, 45, 105, 102, 32, 36,
  57, 32, 45, 114, 118, 91, 45, 50, 44, 45, 49, 93, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 114, 91, 45, 50, 44, 45, 49, 93, 32, 64, 45,
  51, 32, 45, 114, 109, 91, 45, 51, 93, 10, 45, 102, 97, 100, 101, 95,
  108, 105, 110, 101, 97, 114, 32, 36, 49, 48, 44, 36, 49, 49, 44, 36,
  49, 50, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111,
  110, 101, 10, 103, 105, 109, 112, 95, 114, 97, 100, 105, 97, 108, 95, 103,
  114, 97, 100, 105, 101, 110, 116, 32, 58, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 10, 40, 123, 119, 125, 44, 123, 104, 125, 41, 32, 45,
  114, 109, 91, 45, 50, 93, 10, 40, 36, 49, 94, 36, 50, 94, 36, 51,
  94, 36, 52, 41, 32, 40, 36, 53, 94, 36, 54, 94, 36, 55, 94, 36,
  56, 41, 10, 45, 105, 102, 32, 36, 57, 32, 45, 114, 118, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 91, 45,
  50, 44, 45, 49, 93, 32, 64, 45, 51, 32, 45, 114, 109, 91, 45, 51,
  93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 61, 91, 45,
  49, 93, 32, 49, 44, 36, 49, 50, 37, 44, 36, 49, 51, 37, 32, 45,
  100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45,
  95, 102, 97, 100, 101, 32, 36, 49, 48, 44, 36, 49, 49, 10, 45, 109,
  118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 103, 105,
  109, 112, 95, 104, 101, 97, 114, 116, 32, 58, 10, 45, 105, 102, 32, 123,
  64, 35, 62, 48, 125, 32, 119, 104, 61, 64, 123, 45, 109, 97, 120, 95,
  119, 104, 125, 32, 119, 61, 123, 36, 49, 37, 42, 109, 105, 110, 40, 53,
  49, 50, 44, 97, 114, 103, 40, 49, 44, 36, 119, 104, 41, 41, 125, 32,
  104, 61, 123, 36, 49, 37, 42, 109, 105, 110, 40, 53, 49, 50, 44, 97,
  114, 103, 40, 50, 44, 36, 119, 104, 41, 41, 125, 32, 45, 101, 108, 115,
  101, 32, 119, 61, 123, 36, 49, 37, 42, 53, 49, 50, 125, 32, 104, 61,
  123, 36, 49, 37, 42, 53, 49, 50, 125, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 104, 101, 97, 114, 116, 32, 123, 109, 97, 120, 40, 49, 44, 36,
  119, 41, 125, 44, 123, 109, 97, 120, 40, 49, 44, 36, 104, 41, 125, 32,
  45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 10, 45, 114, 101,
  112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32,
  48, 44, 48, 44, 49, 44, 49, 44, 49, 44, 50, 53, 53, 44, 36, 51,
  44, 36, 52, 44, 36, 53, 44, 36, 54, 10, 45, 114, 101, 112, 108, 97,
  99, 101, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 36, 51, 44, 36, 52,
  44, 36, 53, 44, 48, 10, 45, 98, 91, 45, 49, 93, 32, 36, 50, 37,
  32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 10, 103, 105, 109, 112, 95,
  104, 101, 97, 114, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 104, 101, 97, 114, 116, 32, 36, 42, 32, 45,
  98, 108, 101, 110, 100, 91, 48, 44, 45, 49, 93, 32, 97, 108, 112, 104,
  97, 44, 49, 44, 49, 10, 103, 105, 109, 112, 95, 108, 105, 115, 115, 97,
  106, 111, 117, 115, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 116, 111, 95, 114, 103, 98,
  97, 10, 123, 119, 125, 44, 123, 104, 125, 10, 45, 102, 51, 100, 32, 123,
  48, 46, 53, 42, 109, 97, 120, 40, 119, 44, 104, 41, 47, 116, 97, 110,
  40, 36, 52, 42, 112, 105, 47, 51, 54, 48, 41, 125, 10, 45, 108, 105,
  115, 115, 97, 106, 111, 117, 115, 51, 100, 32, 36, 49, 44, 36, 53, 44,
  36, 56, 44, 36, 54, 44, 36, 57, 44, 36, 55, 44, 36, 49, 48, 10,
  45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 48, 44, 49, 44, 36,
  49, 51, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 49, 44,
  48, 44, 36, 49, 50, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 49,
  44, 48, 44, 48, 44, 36, 49, 49, 10, 45, 42, 51, 100, 91, 45, 49,
  93, 32, 123, 48, 46, 53, 42, 36, 50, 42, 64, 123, 45, 50, 44, 119,
  125, 125, 44, 123, 48, 46, 53, 42, 36, 51, 42, 64, 123, 45, 50, 44,
  104, 125, 125, 44, 123, 48, 46, 53, 42, 36, 52, 42, 109, 97, 120, 40,
  64, 123, 45, 50, 44, 119, 125, 44, 64, 123, 45, 50, 44, 104, 125, 41,
  125, 10, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 49, 32, 45,
  111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 49, 44, 49, 44,
  48, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 100, 105, 115,
  116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 103, 116, 91,
  45, 49, 93, 32, 36, 49, 52, 37, 32, 45, 42, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 32, 45, 101, 113, 91, 45, 49, 93, 32, 48, 10, 45,
  114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  49, 44, 52, 10, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 48, 32,
  45, 42, 91, 45, 49, 93, 32, 36, 49, 53, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 115, 104, 91, 45, 49, 93, 32, 49, 44, 49, 32, 45,
  42, 91, 45, 49, 93, 32, 36, 49, 54, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 115, 104, 91, 45, 49, 93, 32, 50, 44, 50, 32, 45, 42,
  91, 45, 49, 93, 32, 36, 49, 55, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 115, 104, 91, 45, 49, 93, 32, 51, 44, 51, 32, 45, 42, 91,
  45, 49, 93, 32, 36, 49, 56, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 109, 97, 110, 100, 101,
  108, 98, 114, 111, 116, 32, 58, 10, 40, 48, 94, 48, 94, 48, 41, 32,
  40, 36, 56, 94, 36, 57, 94, 36, 49, 48, 41, 32, 40, 36, 49, 49,
  94, 36, 49, 50, 94, 36, 49, 51, 41, 32, 40, 36, 49, 52, 94, 36,
  49, 53, 94, 36, 49, 54, 41, 32, 40, 36, 49, 55, 94, 36, 49, 56,
  94, 36, 49, 57, 41, 10, 45, 97, 91, 45, 52, 45, 45, 49, 93, 32,
  120, 32, 45, 114, 91, 45, 49, 93, 32, 36, 52, 44, 49, 44, 49, 44,
  51, 44, 51, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32,
  45, 109, 118, 91, 45, 49, 93, 32, 48, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 64, 35, 45, 49, 125, 10, 119, 104, 61, 123, 119, 125, 44,
  123, 104, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 36, 119, 104, 10,
  45, 109, 97, 110, 100, 101, 108, 98, 114, 111, 116, 91, 45, 49, 93, 32,
  123, 36, 49, 45, 50, 47, 40, 49, 43, 36, 51, 41, 125, 44, 123, 36,
  50, 45, 50, 47, 40, 49, 43, 36, 51, 41, 125, 44, 123, 36, 49, 43,
  50, 47, 40, 49, 43, 36, 51, 41, 125, 44, 123, 36, 50, 43, 50, 47,
  40, 49, 43, 36, 51, 41, 125, 44, 36, 52, 44, 36, 53, 44, 123, 105,
  102, 40, 36, 53, 44, 36, 54, 44, 48, 41, 125, 44, 123, 105, 102, 40,
  36, 53, 44, 36, 55, 44, 48, 41, 125, 10, 45, 109, 97, 112, 91, 45,
  49, 93, 32, 91, 48, 93, 10, 45, 109, 118, 91, 45, 49, 93, 32, 49,
  32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 93, 10, 103, 105,
  109, 112, 95, 109, 97, 110, 100, 101, 108, 98, 114, 111, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 109, 97,
  110, 100, 101, 108, 98, 114, 111, 116, 32, 36, 123, 94, 48, 125, 10, 45,
  108, 105, 110, 101, 32, 48, 44, 53, 48, 37, 44, 49, 48, 48, 37, 44,
  53, 48, 37, 44, 48, 46, 53, 44, 50, 53, 53, 10, 45, 108, 105, 110,
  101, 32, 53, 48, 37, 44, 48, 44, 53, 48, 37, 44, 49, 48, 48, 37,
  44, 48, 46, 53, 44, 50, 53, 53, 10, 103, 105, 109, 112, 95, 113, 117,
  105, 99, 107, 95, 99, 111, 112, 121, 114, 105, 103, 104, 116, 32, 58, 10,
  45, 105, 91, 48, 93, 32, 48, 32, 45, 116, 91, 48, 93, 32, 34, 36,
  49, 34, 44, 48, 44, 48, 44, 36, 50, 44, 49, 44, 36, 51, 44, 36,
  52, 44, 36, 53, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 48,
  93, 32, 48, 32, 45, 114, 91, 48, 93, 32, 123, 64, 123, 48, 44, 119,
  125, 43, 50, 42, 36, 55, 125, 44, 123, 64, 123, 48, 44, 104, 125, 43,
  50, 42, 36, 55, 125, 44, 49, 44, 51, 44, 48, 44, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 10, 45, 105, 91, 49, 93, 32, 48, 32, 45, 116,
  91, 49, 93, 32, 34, 36, 49, 34, 44, 48, 44, 48, 44, 36, 50, 44,
  49, 44, 49, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 49, 93,
  32, 48, 32, 45, 114, 91, 49, 93, 32, 123, 64, 123, 49, 44, 119, 125,
  43, 50, 42, 36, 55, 125, 44, 123, 64, 123, 49, 44, 104, 125, 43, 50,
  42, 36, 55, 125, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53,
  44, 48, 46, 53, 32, 45, 100, 105, 108, 97, 116, 101, 91, 49, 93, 32,
  123, 49, 43, 50, 42, 36, 55, 125, 10, 45, 114, 111, 116, 97, 116, 101,
  91, 48, 44, 49, 93, 32, 123, 57, 48, 42, 40, 36, 49, 48, 45, 49,
  41, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 50,
  125, 10, 45, 105, 102, 32, 123, 36, 56, 61, 61, 48, 125, 32, 45, 106,
  91, 45, 49, 93, 32, 91, 48, 93, 44, 36, 57, 44, 36, 57, 44, 48,
  44, 48, 44, 123, 36, 54, 47, 50, 53, 53, 125, 44, 91, 49, 93, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 56, 61, 61, 49, 125, 32, 45, 106,
  91, 45, 49, 93, 32, 91, 48, 93, 44, 123, 119, 45, 49, 45, 64, 123,
  48, 44, 119, 125, 45, 36, 57, 125, 44, 36, 57, 44, 48, 44, 48, 44,
  123, 36, 54, 47, 50, 53, 53, 125, 44, 91, 49, 93, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 56, 61, 61, 50, 125, 32, 45, 106, 91, 45, 49,
  93, 32, 91, 48, 93, 44, 36, 57, 44, 123, 104, 45, 49, 45, 64, 123,
  48, 44, 104, 125, 45, 36, 57, 125, 44, 48, 44, 48, 44, 123, 36, 54,
  47, 50, 53, 53, 125, 44, 91, 49, 93, 10, 45, 101, 108, 115, 101, 32,
  45, 106, 91, 45, 49, 93, 32, 91, 48, 93, 44, 123, 119, 45, 49, 45,
  64, 123, 48, 44, 119, 125, 45, 36, 57, 125, 44, 123, 104, 45, 49, 45,
  64, 123, 48, 44, 104, 125, 45, 36, 57, 125, 44, 48, 44, 48, 44, 123,
  36, 54, 47, 50, 53, 53, 125, 44, 91, 49, 93, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 109, 118, 91, 45, 49, 93, 32, 50, 32, 45, 100, 111,
  110, 101, 10, 45, 114, 109, 91, 48, 44, 49, 93, 10, 103, 105, 109, 112,
  95, 114, 97, 105, 110, 98, 111, 119, 32, 58, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 32, 45, 115, 112, 108, 105, 110, 101, 91, 45,
  49, 93, 32, 48, 44, 36, 49, 37, 44, 49, 48, 48, 44, 123, 45, 36,
  51, 125, 37, 44, 49, 48, 48, 37, 44, 36, 50, 37, 44, 49, 48, 48,
  44, 36, 52, 37, 44, 50, 53, 54, 44, 49, 44, 49, 10, 45, 102, 108,
  111, 111, 100, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 44,
  48, 44, 49, 44, 49, 32, 45, 102, 108, 111, 111, 100, 91, 45, 49, 93,
  32, 123, 119, 45, 49, 125, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49,
  44, 49, 10, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93,
  32, 48, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32,
  45, 110, 91, 45, 49, 93, 32, 48, 44, 123, 36, 53, 42, 50, 53, 53,
  125, 10, 45, 114, 97, 105, 110, 98, 111, 119, 95, 108, 117, 116, 32, 45,
  45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 45, 49, 93, 32, 45,
  99, 91, 45, 49, 93, 32, 48, 44, 123, 109, 105, 110, 40, 49, 48, 48,
  44, 50, 48, 48, 45, 36, 54, 41, 125, 37, 32, 45, 110, 91, 45, 49,
  93, 32, 48, 44, 50, 53, 53, 32, 45, 97, 91, 45, 50, 44, 45, 49,
  93, 32, 99, 10, 45, 109, 97, 112, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36,
  54, 60, 49, 48, 48, 125, 32, 45, 115, 104, 91, 45, 49, 93, 32, 51,
  44, 51, 32, 45, 42, 91, 45, 49, 93, 32, 123, 36, 54, 47, 49, 48,
  48, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 98, 108, 101, 110, 100, 32, 97, 108, 112, 104, 97, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95,
  115, 104, 97, 100, 101, 98, 111, 98, 115, 32, 58, 10, 45, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 48, 32, 45, 102, 32, 48, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 116,
  61, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 51, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 49, 10, 114, 61, 123, 36, 54, 43, 36,
  53, 42, 99, 111, 115, 40, 54, 42, 36, 55, 42, 36, 116, 41, 43, 40,
  49, 45, 36, 53, 41, 42, 115, 105, 110, 40, 54, 42, 36, 56, 42, 36,
  116, 41, 125, 10, 97, 61, 123, 40, 51, 54, 48, 42, 115, 105, 110, 40,
  36, 55, 42, 36, 116, 41, 43, 51, 48, 42, 36, 54, 42, 36, 62, 41,
  42, 112, 105, 47, 49, 56, 48, 125, 10, 97, 120, 61, 123, 50, 42, 36,
  62, 42, 112, 105, 47, 36, 49, 43, 36, 116, 125, 10, 99, 120, 61, 123,
  40, 49, 43, 36, 57, 42, 99, 111, 115, 40, 36, 97, 120, 41, 43, 36,
  114, 42, 99, 111, 115, 40, 36, 97, 41, 41, 42, 119, 47, 50, 125, 10,
  99, 121, 61, 123, 40, 49, 43, 36, 57, 42, 115, 105, 110, 40, 36, 97,
  120, 41, 43, 36, 114, 42, 115, 105, 110, 40, 36, 97, 41, 41, 42, 104,
  47, 50, 125, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93,
  32, 36, 99, 120, 44, 36, 99, 121, 44, 36, 50, 37, 44, 36, 50, 37,
  44, 48, 44, 45, 49, 44, 49, 10, 45, 100, 111, 110, 101, 10, 116, 61,
  123, 36, 116, 43, 36, 52, 47, 49, 48, 48, 125, 10, 45, 100, 111, 110,
  101, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 97,
  110, 100, 32, 50, 53, 53, 32, 45, 105, 102, 32, 36, 49, 48, 32, 45,
  109, 97, 112, 32, 123, 36, 49, 48, 45, 49, 125, 32, 45, 101, 110, 100,
  105, 102, 10, 103, 105, 109, 112, 95, 115, 105, 101, 114, 112, 105, 110, 115,
  107, 105, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112,
  97, 99, 105, 116, 121, 32, 45, 108, 91, 48, 93, 10, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 32, 45, 115, 105, 101, 114, 112, 105, 110, 115, 107,
  105, 91, 45, 49, 93, 32, 36, 123, 49, 45, 55, 125, 10, 45, 45, 102,
  99, 91, 45, 50, 93, 32, 36, 56, 44, 36, 57, 44, 36, 49, 48, 32,
  45, 106, 91, 48, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 36, 49, 49, 44, 91, 45, 50, 93, 44, 50, 53, 53, 32,
  45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 110, 100, 108,
  32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 103, 105, 109, 112, 95, 115, 110, 111, 119, 102, 108, 97, 107, 101,
  32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99,
  105, 116, 121, 32, 45, 108, 91, 48, 93, 10, 45, 115, 110, 111, 119, 102,
  108, 97, 107, 101, 32, 36, 123, 49, 45, 49, 49, 125, 10, 45, 101, 110,
  100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 103, 105, 109, 112, 95, 115, 117, 112, 101, 114, 102, 111,
  114, 109, 117, 108, 97, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 116, 111, 95, 114, 103,
  98, 97, 10, 123, 119, 125, 44, 123, 104, 125, 10, 45, 102, 51, 100, 32,
  123, 48, 46, 53, 42, 109, 97, 120, 40, 119, 44, 104, 41, 47, 116, 97,
  110, 40, 36, 52, 42, 112, 105, 47, 51, 54, 48, 41, 125, 10, 45, 115,
  117, 112, 101, 114, 102, 111, 114, 109, 117, 108, 97, 51, 100, 32, 36, 49,
  44, 36, 123, 52, 45, 55, 125, 10, 45, 114, 51, 100, 91, 45, 49, 93,
  32, 48, 44, 48, 44, 49, 44, 36, 49, 48, 32, 45, 114, 51, 100, 91,
  45, 49, 93, 32, 48, 44, 49, 44, 48, 44, 36, 57, 32, 45, 114, 51,
  100, 91, 45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 36, 56, 10, 45,
  42, 51, 100, 91, 45, 49, 93, 32, 123, 48, 46, 53, 42, 36, 50, 42,
  64, 123, 45, 50, 44, 119, 125, 125, 44, 123, 48, 46, 53, 42, 36, 51,
  42, 64, 123, 45, 50, 44, 104, 125, 125, 10, 45, 99, 111, 108, 51, 100,
  91, 45, 49, 93, 32, 49, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 53, 48, 37, 44, 53, 48,
  37, 44, 48, 44, 49, 44, 49, 44, 48, 44, 48, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49,
  93, 32, 49, 32, 45, 103, 116, 91, 45, 49, 93, 32, 36, 49, 49, 37,
  32, 45, 42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 101, 113,
  91, 45, 49, 93, 32, 48, 10, 45, 114, 91, 45, 49, 93, 32, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 52, 10, 45, 115, 104, 91,
  45, 49, 93, 32, 48, 44, 48, 32, 45, 42, 91, 45, 49, 93, 32, 36,
  49, 50, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 45,
  49, 93, 32, 49, 44, 49, 32, 45, 42, 91, 45, 49, 93, 32, 36, 49,
  51, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 45, 49,
  93, 32, 50, 44, 50, 32, 45, 42, 91, 45, 49, 93, 32, 36, 49, 52,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 45, 49, 93,
  32, 51, 44, 51, 32, 45, 42, 91, 45, 49, 93, 32, 36, 49, 53, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 43, 91, 45, 50, 44, 45, 49,
  93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105,
  109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 52, 61, 49,
  125, 44, 36, 123, 53, 61, 48, 125, 44, 36, 123, 54, 61, 36, 53, 125,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 105, 102, 32,
  36, 53, 32, 119, 105, 100, 116, 104, 61, 36, 53, 32, 45, 101, 108, 115,
  101, 32, 119, 105, 100, 116, 104, 61, 123, 119, 125, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 36, 54, 32, 104, 101, 105, 103, 104, 116,
  61, 36, 54, 32, 45, 101, 108, 115, 101, 32, 104, 101, 105, 103, 104, 116,
  61, 123, 104, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  36, 52, 32, 45, 115, 91, 45, 49, 93, 32, 120, 44, 50, 32, 45, 101,
  108, 115, 101, 32, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 36, 49, 91, 45, 50, 93, 32, 36, 50, 32, 45, 36, 49, 91, 45,
  49, 93, 32, 36, 51, 10, 45, 114, 91, 45, 50, 44, 45, 49, 93, 32,
  123, 109, 97, 120, 40, 119, 44, 64, 123, 45, 50, 44, 119, 125, 41, 125,
  44, 123, 109, 97, 120, 40, 104, 44, 64, 123, 45, 50, 44, 104, 125, 41,
  125, 44, 49, 44, 49, 48, 48, 37, 44, 51, 10, 45, 105, 102, 32, 123,
  33, 36, 52, 125, 32, 45, 99, 111, 108, 117, 109, 110, 115, 91, 45, 50,
  93, 32, 48, 44, 53, 48, 37, 32, 45, 99, 111, 108, 117, 109, 110, 115,
  91, 45, 49, 93, 32, 53, 48, 37, 44, 49, 48, 48, 37, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120,
  32, 45, 114, 91, 45, 49, 93, 32, 36, 119, 105, 100, 116, 104, 44, 36,
  104, 101, 105, 103, 104, 116, 44, 49, 44, 49, 48, 48, 37, 44, 50, 32,
  45, 100, 114, 103, 98, 97, 91, 45, 49, 93, 10, 45, 108, 105, 110, 101,
  91, 45, 49, 93, 32, 53, 48, 37, 44, 48, 44, 53, 48, 37, 44, 49,
  48, 48, 37, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 10,
  45, 116, 101, 120, 116, 95, 111, 117, 116, 108, 105, 110, 101, 91, 45, 49,
  93, 32, 34, 83, 116, 97, 114, 116, 34, 44, 49, 44, 48, 44, 49, 51,
  44, 49, 44, 49, 44, 50, 53, 53, 32, 45, 116, 101, 120, 116, 95, 111,
  117, 116, 108, 105, 110, 101, 91, 45, 49, 93, 32, 34, 69, 110, 100, 34,
  44, 123, 119, 45, 50, 51, 125, 44, 123, 104, 45, 49, 54, 125, 44, 49,
  51, 44, 49, 44, 49, 44, 50, 53, 53, 10, 45, 109, 118, 91, 45, 49,
  93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 97,
  110, 105, 109, 97, 116, 101, 95, 101, 108, 101, 118, 97, 116, 105, 111, 110,
  51, 100, 32, 58, 10, 45, 105, 102, 32, 36, 51, 32, 102, 105, 108, 101,
  110, 97, 109, 101, 61, 34, 36, 52, 47, 103, 109, 105, 99, 95, 101, 108,
  101, 118, 97, 116, 105, 111, 110, 51, 100, 46, 112, 110, 103, 34, 32, 45,
  101, 108, 115, 101, 32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 34,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 101,
  108, 101, 118, 97, 116, 105, 111, 110, 51, 100, 32, 36, 123, 53, 45, 54,
  125, 10, 45, 97, 110, 105, 109, 97, 116, 101, 32, 103, 105, 109, 112, 95,
  114, 101, 110, 100, 101, 114, 51, 100, 44, 34, 36, 123, 55, 45, 56, 125,
  44, 36, 123, 49, 48, 45, 49, 57, 125, 44, 36, 57, 34, 44, 92, 10,
  34, 36, 123, 55, 45, 56, 125, 44, 36, 123, 50, 48, 45, 50, 57, 125,
  44, 36, 57, 34, 44, 36, 49, 44, 36, 50, 44, 64, 123, 45, 113, 117,
  111, 116, 101, 92, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 125, 10,
  103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 101, 108, 101,
  118, 97, 116, 105, 111, 110, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 10, 45,
  95, 103, 105, 109, 112, 95, 101, 108, 101, 118, 97, 116, 105, 111, 110, 51,
  100, 32, 36, 123, 53, 45, 54, 125, 10, 45, 103, 105, 109, 112, 95, 97,
  110, 105, 109, 97, 116, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 103,
  105, 109, 112, 95, 114, 101, 110, 100, 101, 114, 51, 100, 44, 36, 119, 34,
  44, 34, 36, 104, 34, 44, 36, 123, 49, 48, 45, 49, 57, 125, 44, 36,
  57, 34, 44, 92, 10, 36, 119, 34, 44, 34, 36, 104, 34, 44, 36, 123,
  50, 48, 45, 50, 57, 125, 44, 36, 57, 34, 44, 48, 44, 36, 119, 44,
  36, 104, 10, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95,
  101, 120, 116, 114, 117, 100, 101, 51, 100, 32, 58, 10, 45, 105, 102, 32,
  36, 51, 32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 36, 52, 47,
  103, 109, 105, 99, 95, 101, 120, 116, 114, 117, 100, 101, 51, 100, 46, 112,
  110, 103, 34, 32, 45, 101, 108, 115, 101, 32, 102, 105, 108, 101, 110, 97,
  109, 101, 61, 34, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103,
  105, 109, 112, 95, 101, 120, 116, 114, 117, 100, 101, 51, 100, 32, 36, 123,
  53, 45, 55, 125, 10, 45, 97, 110, 105, 109, 97, 116, 101, 32, 103, 105,
  109, 112, 95, 114, 101, 110, 100, 101, 114, 51, 100, 44, 34, 36, 123, 56,
  45, 57, 125, 44, 36, 123, 49, 49, 45, 50, 48, 125, 44, 36, 49, 48,
  34, 44, 92, 10, 34, 36, 123, 56, 45, 57, 125, 44, 36, 123, 50, 49,
  45, 51, 48, 125, 44, 36, 49, 48, 34, 44, 36, 49, 44, 36, 50, 44,
  64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 36, 102, 105, 108, 101, 110,
  97, 109, 101, 125, 10, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116,
  101, 95, 101, 120, 116, 114, 117, 100, 101, 51, 100, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104,
  125, 10, 45, 95, 103, 105, 109, 112, 95, 101, 120, 116, 114, 117, 100, 101,
  51, 100, 32, 36, 123, 53, 45, 55, 125, 10, 45, 103, 105, 109, 112, 95,
  97, 110, 105, 109, 97, 116, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  103, 105, 109, 112, 95, 114, 101, 110, 100, 101, 114, 51, 100, 44, 36, 119,
  34, 44, 34, 36, 104, 34, 44, 36, 123, 49, 49, 45, 50, 48, 125, 44,
  36, 49, 48, 34, 44, 92, 10, 36, 119, 34, 44, 34, 36, 104, 34, 44,
  36, 123, 50, 49, 45, 51, 48, 125, 44, 36, 49, 48, 34, 44, 48, 44,
  36, 119, 44, 36, 104, 10, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97,
  116, 101, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100,
  32, 58, 10, 45, 105, 102, 32, 36, 51, 32, 102, 105, 108, 101, 110, 97,
  109, 101, 61, 34, 36, 52, 47, 103, 109, 105, 99, 95, 105, 109, 97, 103,
  101, 111, 98, 106, 101, 99, 116, 51, 100, 46, 112, 110, 103, 34, 32, 45,
  101, 108, 115, 101, 32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 34,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 105,
  109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 32, 34, 95, 34,
  44, 36, 53, 10, 45, 97, 110, 105, 109, 97, 116, 101, 32, 103, 105, 109,
  112, 95, 114, 101, 110, 100, 101, 114, 51, 100, 44, 34, 36, 123, 54, 45,
  55, 125, 44, 36, 123, 57, 45, 49, 56, 125, 44, 36, 56, 34, 44, 92,
  10, 34, 36, 123, 54, 45, 55, 125, 44, 36, 123, 49, 57, 45, 50, 56,
  125, 44, 36, 56, 34, 44, 36, 49, 44, 36, 50, 44, 64, 123, 45, 113,
  117, 111, 116, 101, 92, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 125,
  10, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 105, 109,
  97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104,
  125, 10, 45, 95, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98,
  106, 101, 99, 116, 51, 100, 32, 34, 95, 112, 114, 101, 118, 105, 101, 119,
  95, 34, 44, 36, 53, 10, 45, 103, 105, 109, 112, 95, 97, 110, 105, 109,
  97, 116, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 103, 105, 109, 112,
  95, 114, 101, 110, 100, 101, 114, 51, 100, 44, 36, 119, 34, 44, 34, 36,
  104, 34, 44, 36, 123, 57, 45, 49, 56, 125, 44, 36, 56, 34, 44, 92,
  10, 36, 119, 34, 44, 34, 36, 104, 34, 44, 36, 123, 49, 57, 45, 50,
  56, 125, 44, 36, 56, 34, 44, 48, 44, 36, 119, 44, 36, 104, 10, 103,
  105, 109, 112, 95, 116, 101, 120, 116, 95, 112, 111, 105, 110, 116, 99, 108,
  111, 117, 100, 51, 100, 32, 58, 10, 87, 61, 123, 119, 125, 32, 72, 61,
  123, 104, 125, 32, 77, 61, 123, 114, 111, 117, 110, 100, 40, 49, 46, 53,
  42, 109, 97, 120, 40, 119, 44, 104, 41, 41, 125, 32, 45, 114, 109, 10,
  45, 116, 101, 120, 116, 95, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100,
  51, 100, 32, 34, 36, 50, 34, 44, 34, 36, 51, 34, 44, 36, 52, 10,
  45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 36, 123, 53, 45, 55,
  125, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 123, 48, 46, 55, 42,
  36, 77, 125, 10, 45, 102, 51, 100, 32, 52, 48, 48, 48, 32, 45, 100,
  98, 51, 100, 32, 48, 32, 45, 109, 51, 100, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 36, 49, 10, 45, 114, 112, 114, 111, 103, 114, 101, 115, 115,
  32, 123, 54, 48, 42, 36, 62, 47, 36, 49, 125, 10, 97, 110, 103, 108,
  101, 61, 123, 36, 62, 42, 51, 54, 48, 47, 36, 49, 125, 10, 45, 45,
  114, 51, 100, 91, 48, 93, 32, 49, 44, 48, 44, 49, 44, 36, 97, 110,
  103, 108, 101, 10, 36, 77, 44, 36, 77, 44, 49, 44, 51, 44, 45, 49,
  32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91,
  45, 50, 93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 49, 32,
  45, 114, 109, 91, 45, 50, 93, 10, 45, 100, 111, 110, 101, 10, 45, 114,
  109, 91, 48, 93, 32, 45, 97, 32, 122, 32, 45, 97, 117, 116, 111, 99,
  114, 111, 112, 32, 45, 49, 32, 45, 116, 111, 95, 114, 103, 98, 97, 32,
  45, 115, 32, 122, 32, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111,
  108, 111, 114, 32, 48, 44, 48, 44, 45, 49, 44, 45, 49, 44, 45, 49,
  44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 48, 10, 45, 105, 102,
  32, 36, 49, 49, 32, 78, 61, 64, 35, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 114, 112, 114,
  111, 103, 114, 101, 115, 115, 32, 123, 54, 48, 43, 52, 48, 42, 36, 62,
  47, 36, 78, 125, 10, 45, 105, 91, 48, 93, 32, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 44, 49, 44, 52, 32, 45, 102, 99, 91, 48, 93, 32,
  36, 123, 56, 45, 49, 49, 125, 32, 45, 45, 99, 104, 97, 110, 110, 101,
  108, 115, 91, 45, 49, 93, 32, 51, 44, 51, 32, 45, 45, 110, 101, 103,
  97, 116, 105, 118, 101, 91, 45, 49, 93, 32, 45, 98, 91, 45, 50, 44,
  45, 49, 93, 32, 36, 49, 52, 37, 32, 45, 116, 111, 95, 114, 103, 98,
  97, 91, 45, 49, 93, 10, 45, 106, 91, 48, 93, 32, 91, 45, 49, 93,
  44, 36, 49, 50, 37, 44, 36, 49, 51, 37, 44, 48, 44, 48, 44, 49,
  44, 91, 45, 50, 93, 44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 98, 108, 101, 110, 100, 32, 97, 108, 112, 104,
  97, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 87, 62, 36, 72, 125,
  32, 45, 114, 50, 100, 120, 32, 36, 87, 32, 45, 101, 108, 115, 101, 32,
  45, 114, 50, 100, 121, 32, 36, 72, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 49, 53, 62, 49, 125, 10, 45, 105, 91, 123,
  105, 110, 116, 40, 36, 49, 47, 50, 41, 125, 93, 32, 91, 123, 105, 110,
  116, 40, 36, 49, 47, 50, 41, 125, 93, 120, 123, 36, 49, 53, 45, 49,
  125, 10, 45, 105, 91, 48, 93, 32, 91, 48, 93, 120, 123, 36, 49, 53,
  45, 49, 125, 10, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95,
  116, 101, 120, 116, 95, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 51,
  100, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 116, 101, 120, 116, 95, 112, 111, 105, 110, 116, 99, 108, 111, 117,
  100, 51, 100, 32, 52, 44, 34, 36, 50, 34, 44, 34, 36, 51, 34, 44,
  36, 52, 44, 36, 123, 53, 45, 55, 125, 44, 36, 123, 56, 45, 49, 49,
  125, 44, 36, 123, 49, 50, 45, 49, 52, 125, 44, 49, 32, 45, 100, 114,
  103, 98, 97, 10, 45, 102, 114, 97, 109, 101, 32, 49, 44, 49, 44, 48,
  32, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 32, 50,
  44, 50, 10, 103, 105, 109, 112, 95, 116, 114, 97, 110, 115, 105, 116, 105,
  111, 110, 51, 100, 32, 58, 10, 45, 102, 51, 100, 32, 36, 55, 10, 45,
  116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 51, 100, 32, 36, 49, 44,
  36, 50, 44, 36, 51, 44, 34, 36, 52, 34, 44, 34, 36, 53, 34, 44,
  34, 36, 54, 34, 44, 36, 56, 10, 103, 105, 109, 112, 95, 116, 114, 97,
  110, 115, 105, 116, 105, 111, 110, 51, 100, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 102, 51, 100, 32, 36, 55, 10, 45, 105, 102, 32,
  123, 64, 35, 61, 61, 49, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 107, 91, 48, 44, 49, 93, 32, 45,
  116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 51, 100, 32, 52, 44, 36,
  50, 44, 36, 51, 44, 34, 36, 52, 34, 44, 34, 36, 53, 34, 44, 34,
  36, 54, 34, 44, 36, 56, 10, 45, 107, 91, 49, 44, 50, 93, 10, 45,
  114, 91, 48, 93, 32, 53, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44,
  49, 48, 48, 37, 44, 48, 10, 45, 114, 91, 49, 93, 32, 53, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44, 48,
  44, 49, 10, 45, 97, 32, 120, 10, 45, 108, 105, 110, 101, 32, 53, 48,
  37, 44, 48, 44, 53, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 48,
  44, 48, 44, 48, 44, 50, 53, 53, 10, 103, 105, 109, 112, 95, 116, 114,
  97, 110, 115, 105, 116, 105, 111, 110, 95, 112, 108, 97, 115, 109, 97, 32,
  58, 10, 45, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 95, 112, 108,
  97, 115, 109, 97, 32, 36, 49, 44, 36, 50, 44, 36, 51, 37, 10, 103,
  105, 109, 112, 95, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 95, 112,
  108, 97, 115, 109, 97, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 105, 102, 32, 123, 64, 35, 61, 61, 49, 125, 32, 45, 114, 101, 116,
  117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 107, 91, 48, 44,
  49, 93, 32, 45, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 95, 112,
  108, 97, 115, 109, 97, 32, 54, 44, 36, 50, 44, 36, 51, 37, 32, 45,
  107, 91, 49, 45, 45, 50, 93, 32, 45, 102, 114, 97, 109, 101, 32, 49,
  44, 49, 44, 48, 32, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108,
  101, 115, 32, 44, 10, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116,
  101, 95, 112, 101, 110, 99, 105, 108, 98, 119, 32, 58, 10, 45, 105, 102,
  32, 36, 51, 32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 36, 52,
  47, 103, 109, 105, 99, 95, 112, 101, 110, 99, 105, 108, 98, 119, 46, 112,
  110, 103, 34, 32, 45, 101, 108, 115, 101, 32, 102, 105, 108, 101, 110, 97,
  109, 101, 61, 34, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 110,
  105, 109, 97, 116, 101, 32, 112, 101, 110, 99, 105, 108, 98, 119, 44, 34,
  36, 123, 53, 45, 54, 125, 34, 44, 92, 10, 34, 36, 123, 55, 45, 56,
  125, 34, 44, 36, 49, 44, 36, 50, 44, 64, 123, 45, 113, 117, 111, 116,
  101, 92, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 125, 10, 103, 105,
  109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 112, 101, 110, 99, 105,
  108, 98, 119, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 112, 101, 110, 99, 105, 108, 98, 119, 44, 34, 36, 123,
  53, 45, 54, 125, 34, 44, 92, 10, 34, 36, 123, 55, 45, 56, 125, 34,
  10, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 115, 116,
  101, 110, 99, 105, 108, 98, 119, 32, 58, 10, 45, 105, 102, 32, 36, 51,
  32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 36, 52, 47, 103, 109,
  105, 99, 95, 115, 116, 101, 110, 99, 105, 108, 98, 119, 46, 112, 110, 103,
  34, 32, 45, 101, 108, 115, 101, 32, 102, 105, 108, 101, 110, 97, 109, 101,
  61, 34, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 110, 105, 109,
  97, 116, 101, 32, 115, 116, 101, 110, 99, 105, 108, 98, 119, 44, 34, 36,
  123, 53, 45, 54, 125, 34, 44, 92, 10, 34, 36, 123, 55, 45, 56, 125,
  34, 44, 36, 49, 44, 36, 50, 44, 64, 123, 45, 113, 117, 111, 116, 101,
  92, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 125, 10, 103, 105, 109,
  112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 115, 116, 101, 110, 99, 105,
  108, 98, 119, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 115, 116, 101, 110, 99, 105, 108, 98, 119, 44, 34, 36,
  123, 53, 45, 54, 125, 34, 44, 92, 10, 34, 36, 123, 55, 45, 56, 125,
  34, 10, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 99,
  97, 114, 116, 111, 111, 110, 32, 58, 10, 45, 105, 102, 32, 36, 51, 32,
  102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 36, 52, 47, 103, 109, 105,
  99, 95, 99, 97, 114, 116, 111, 111, 110, 46, 112, 110, 103, 34, 32, 45,
  101, 108, 115, 101, 32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 34,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 110, 105, 109, 97, 116, 101,
  32, 99, 97, 114, 116, 111, 111, 110, 44, 34, 36, 123, 54, 45, 49, 48,
  125, 44, 36, 53, 34, 44, 92, 10, 34, 36, 123, 49, 49, 45, 49, 53,
  125, 44, 36, 53, 34, 44, 36, 49, 44, 36, 50, 44, 64, 123, 45, 113,
  117, 111, 116, 101, 92, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 125,
  10, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 99, 97,
  114, 116, 111, 111, 110, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 99, 97, 114, 116, 111, 111, 110, 44, 34, 36,
  123, 54, 45, 49, 48, 125, 44, 36, 53, 34, 44, 92, 10, 34, 36, 123,
  49, 49, 45, 49, 53, 125, 44, 36, 53, 34, 10, 103, 105, 109, 112, 95,
  97, 110, 105, 109, 97, 116, 101, 95, 101, 100, 103, 101, 115, 32, 58, 10,
  45, 105, 102, 32, 36, 51, 32, 102, 105, 108, 101, 110, 97, 109, 101, 61,
  34, 36, 52, 47, 103, 109, 105, 99, 95, 101, 100, 103, 101, 115, 46, 112,
  110, 103, 34, 32, 45, 101, 108, 115, 101, 32, 102, 105, 108, 101, 110, 97,
  109, 101, 61, 34, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 110,
  105, 109, 97, 116, 101, 32, 103, 105, 109, 112, 95, 101, 100, 103, 101, 115,
  44, 34, 36, 123, 54, 45, 55, 125, 44, 36, 53, 34, 44, 92, 10, 34,
  36, 123, 56, 45, 57, 125, 44, 36, 53, 34, 44, 36, 49, 44, 36, 50,
  44, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 36, 102, 105, 108, 101,
  110, 97, 109, 101, 125, 10, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97,
  116, 101, 95, 101, 100, 103, 101, 115, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 103, 105, 109, 112, 95, 101, 100,
  103, 101, 115, 44, 34, 36, 123, 54, 45, 55, 125, 44, 36, 53, 34, 44,
  92, 10, 34, 36, 123, 56, 45, 57, 125, 44, 36, 53, 34, 10, 103, 105,
  109, 112, 95, 102, 105, 114, 101, 95, 101, 100, 103, 101, 115, 32, 58, 10,
  45, 102, 105, 114, 101, 95, 101, 100, 103, 101, 115, 32, 36, 123, 49, 45,
  55, 125, 32, 45, 114, 118, 10, 103, 105, 109, 112, 95, 102, 105, 114, 101,
  95, 101, 100, 103, 101, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 102, 105, 114, 101, 95, 101, 100, 103, 101,
  115, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 49, 44,
  36, 54, 44, 48, 34, 44, 36, 45, 49, 10, 103, 105, 109, 112, 95, 108,
  97, 118, 97, 108, 97, 109, 112, 98, 119, 32, 58, 10, 45, 105, 102, 32,
  123, 33, 64, 35, 125, 32, 40, 50, 53, 53, 59, 49, 48, 48, 94, 54,
  52, 59, 49, 54, 94, 49, 50, 56, 59, 48, 41, 32, 45, 114, 91, 45,
  49, 93, 32, 53, 49, 50, 44, 53, 49, 50, 44, 49, 44, 51, 44, 51,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 60, 93, 10, 119, 61, 123, 119, 125, 32,
  104, 61, 123, 104, 125, 10, 45, 45, 114, 32, 36, 52, 37, 44, 36, 52,
  37, 44, 49, 44, 49, 44, 48, 32, 91, 45, 49, 93, 120, 123, 36, 49,
  45, 49, 125, 32, 45, 114, 97, 110, 100, 91, 94, 48, 93, 32, 48, 44,
  49, 32, 45, 115, 116, 101, 110, 99, 105, 108, 91, 94, 48, 93, 32, 36,
  53, 44, 48, 10, 45, 105, 102, 32, 36, 51, 32, 91, 49, 93, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 109, 111, 114, 112, 104, 91, 94, 48, 93,
  32, 36, 50, 44, 36, 54, 44, 48, 10, 45, 115, 116, 101, 110, 99, 105,
  108, 91, 94, 48, 93, 32, 36, 53, 44, 48, 10, 45, 114, 91, 94, 48,
  93, 32, 36, 119, 44, 36, 104, 44, 49, 44, 49, 44, 51, 32, 45, 98,
  91, 94, 48, 93, 32, 49, 48, 32, 45, 103, 101, 91, 94, 48, 93, 32,
  53, 48, 37, 32, 45, 42, 91, 94, 48, 93, 32, 50, 53, 53, 10, 45,
  114, 91, 94, 48, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  49, 44, 52, 32, 45, 106, 91, 94, 48, 93, 32, 91, 48, 93, 32, 45,
  114, 109, 91, 48, 93, 10, 45, 105, 102, 32, 36, 51, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 33, 36, 55,
  125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105,
  116, 121, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 42,
  91, 94, 45, 49, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45,
  49, 93, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 108, 97, 118, 97, 108,
  97, 109, 112, 98, 119, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 108, 97, 118, 97, 108, 97, 109, 112, 98, 119,
  32, 50, 44, 50, 44, 49, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44,
  36, 55, 32, 45, 107, 91, 48, 93, 10, 103, 105, 109, 112, 95, 97, 110,
  105, 109, 97, 116, 101, 95, 108, 105, 115, 115, 97, 106, 111, 117, 115, 32,
  58, 10, 45, 105, 102, 32, 36, 51, 32, 102, 105, 108, 101, 110, 97, 109,
  101, 61, 34, 36, 52, 47, 103, 109, 105, 99, 95, 108, 105, 115, 115, 97,
  106, 111, 117, 115, 46, 112, 110, 103, 34, 32, 45, 101, 108, 115, 101, 32,
  102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 34, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 97, 110, 105, 109, 97, 116, 101, 32, 103, 105, 109, 112,
  95, 108, 105, 115, 115, 97, 106, 111, 117, 115, 44, 34, 36, 123, 53, 45,
  50, 50, 125, 34, 44, 92, 10, 34, 36, 123, 50, 51, 45, 52, 48, 125,
  34, 44, 36, 49, 44, 36, 50, 44, 64, 123, 45, 113, 117, 111, 116, 101,
  92, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 125, 10, 103, 105, 109,
  112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 108, 105, 115, 115, 97, 106,
  111, 117, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 103, 105, 109, 112, 95, 108, 105, 115, 115, 97, 106, 111,
  117, 115, 44, 34, 36, 123, 53, 45, 50, 50, 125, 34, 44, 92, 10, 34,
  36, 123, 50, 51, 45, 52, 48, 125, 34, 44, 48, 10, 103, 105, 109, 112,
  95, 97, 110, 105, 109, 97, 116, 101, 95, 109, 111, 114, 112, 104, 111, 32,
  58, 10, 45, 105, 102, 32, 36, 51, 32, 102, 105, 108, 101, 110, 97, 109,
  101, 61, 34, 36, 52, 47, 103, 109, 105, 99, 95, 109, 111, 114, 112, 104,
  111, 46, 112, 110, 103, 34, 32, 45, 101, 108, 115, 101, 32, 102, 105, 108,
  101, 110, 97, 109, 101, 61, 34, 34, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 97, 110, 105, 109, 97, 116, 101, 32, 103, 105, 109, 112, 95, 109, 111,
  114, 112, 104, 111, 44, 34, 36, 53, 44, 36, 56, 44, 36, 54, 44, 36,
  55, 44, 48, 44, 49, 34, 44, 92, 10, 34, 36, 53, 44, 36, 57, 44,
  36, 54, 44, 36, 55, 44, 48, 44, 49, 34, 44, 36, 49, 44, 36, 50,
  44, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 36, 102, 105, 108, 101,
  110, 97, 109, 101, 125, 10, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97,
  116, 101, 95, 109, 111, 114, 112, 104, 111, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 103, 105, 109, 112, 95, 109,
  111, 114, 112, 104, 111, 44, 34, 36, 53, 44, 36, 56, 44, 36, 54, 44,
  36, 55, 44, 48, 44, 49, 34, 44, 92, 10, 34, 36, 53, 44, 36, 57,
  44, 36, 54, 44, 36, 55, 44, 48, 44, 49, 34, 10, 103, 105, 109, 112,
  95, 97, 110, 105, 109, 97, 116, 101, 95, 114, 111, 100, 105, 108, 105, 117,
  115, 32, 58, 10, 45, 105, 102, 32, 36, 51, 32, 102, 105, 108, 101, 110,
  97, 109, 101, 61, 34, 36, 52, 47, 103, 109, 105, 99, 95, 114, 111, 100,
  105, 108, 105, 117, 115, 46, 112, 110, 103, 34, 32, 45, 101, 108, 115, 101,
  32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 34, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 97, 110, 105, 109, 97, 116, 101, 32, 114, 111, 100,
  105, 108, 105, 117, 115, 44, 34, 36, 123, 54, 45, 49, 48, 125, 44, 36,
  53, 34, 44, 92, 10, 34, 36, 123, 49, 49, 45, 49, 53, 125, 44, 36,
  53, 34, 44, 36, 49, 44, 36, 50, 44, 64, 123, 45, 113, 117, 111, 116,
  101, 92, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 125, 10, 103, 105,
  109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 114, 111, 100, 105, 108,
  105, 117, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 114, 111, 100, 105, 108, 105, 117, 115, 44, 34, 36, 123,
  54, 45, 49, 48, 125, 44, 36, 53, 34, 44, 92, 10, 34, 36, 123, 49,
  49, 45, 49, 53, 125, 44, 36, 53, 34, 10, 103, 105, 109, 112, 95, 97,
  110, 105, 109, 97, 116, 101, 95, 103, 108, 111, 119, 32, 58, 10, 45, 105,
  102, 32, 36, 51, 32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 36,
  52, 47, 103, 109, 105, 99, 95, 103, 108, 111, 119, 46, 112, 110, 103, 34,
  32, 45, 101, 108, 115, 101, 32, 102, 105, 108, 101, 110, 97, 109, 101, 61,
  34, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 110, 105, 109, 97,
  116, 101, 32, 103, 108, 111, 119, 44, 34, 36, 53, 34, 44, 92, 10, 34,
  36, 54, 34, 44, 36, 49, 44, 36, 50, 44, 64, 123, 45, 113, 117, 111,
  116, 101, 92, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 125, 10, 103,
  105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 103, 108, 111, 119,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 97, 110, 105, 109, 97, 116, 101, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 103, 108, 111, 119, 44, 34, 36, 53, 34, 44, 92, 10, 34, 36, 54,
  34, 10, 103, 105, 109, 112, 95, 98, 97, 110, 100, 112, 97, 115, 115, 32,
  58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 34, 45, 98, 97, 110, 100, 112, 97, 115, 115, 32, 36, 49, 37,
  44, 36, 50, 37, 34, 44, 36, 51, 44, 36, 52, 10, 103, 105, 109, 112,
  95, 98, 97, 110, 100, 112, 97, 115, 115, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 98,
  97, 110, 100, 112, 97, 115, 115, 32, 36, 42, 34, 44, 36, 45, 49, 10,
  103, 105, 109, 112, 95, 100, 105, 115, 112, 108, 97, 121, 95, 102, 102, 116,
  32, 58, 10, 45, 116, 111, 95, 114, 103, 98, 32, 45, 100, 105, 115, 112,
  108, 97, 121, 95, 102, 102, 116, 10, 103, 105, 109, 112, 95, 102, 111, 117,
  114, 105, 101, 114, 32, 58, 10, 45, 105, 102, 32, 36, 49, 32, 45, 102,
  102, 116, 56, 50, 102, 108, 111, 97, 116, 32, 45, 99, 32, 48, 44, 50,
  53, 53, 10, 45, 101, 108, 115, 101, 32, 45, 102, 108, 111, 97, 116, 50,
  102, 102, 116, 56, 10, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112,
  95, 102, 111, 117, 114, 105, 101, 114, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 105, 102, 32, 36, 49, 32, 45, 103, 105, 109, 112, 95,
  110, 111, 95, 112, 114, 101, 118, 105, 101, 119, 32, 48, 10, 45, 101, 108,
  115, 101, 32, 45, 100, 102, 102, 116, 10, 45, 101, 110, 100, 105, 102, 10,
  103, 105, 109, 112, 95, 119, 97, 116, 101, 114, 109, 97, 114, 107, 95, 102,
  111, 117, 114, 105, 101, 114, 32, 58, 10, 45, 119, 97, 116, 101, 114, 109,
  97, 114, 107, 95, 102, 111, 117, 114, 105, 101, 114, 32, 34, 36, 49, 34,
  44, 36, 50, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10, 103, 105, 109,
  112, 95, 99, 117, 115, 116, 111, 109, 95, 99, 111, 100, 101, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 34, 36, 123, 49, 61, 45, 115, 107, 105, 112,
  32, 44, 125, 34, 10, 45, 109, 32, 34, 95, 103, 105, 109, 112, 95, 99,
  117, 115, 116, 111, 109, 95, 99, 111, 100, 101, 95, 115, 116, 97, 114, 116,
  32, 58, 32, 36, 49, 34, 10, 45, 105, 102, 32, 123, 36, 51, 62, 48,
  125, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 34, 45, 95, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109,
  95, 99, 111, 100, 101, 95, 115, 116, 97, 114, 116, 34, 44, 36, 51, 44,
  36, 50, 10, 45, 101, 108, 115, 101, 10, 45, 95, 103, 105, 109, 112, 95,
  99, 117, 115, 116, 111, 109, 95, 99, 111, 100, 101, 10, 45, 105, 102, 32,
  36, 50, 32, 45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 115,
  101, 32, 45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 117, 110, 99, 111, 109, 109,
  97, 110, 100, 32, 95, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109,
  95, 99, 111, 100, 101, 95, 115, 116, 97, 114, 116, 10, 103, 105, 109, 112,
  95, 99, 117, 115, 116, 111, 109, 95, 99, 111, 100, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36, 123,
  49, 61, 45, 115, 107, 105, 112, 32, 44, 125, 34, 10, 95, 103, 99, 112,
  95, 97, 114, 103, 61, 34, 36, 49, 34, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 99, 111, 100, 101,
  32, 36, 95, 103, 99, 112, 95, 97, 114, 103, 44, 36, 123, 50, 45, 45,
  50, 125, 34, 44, 36, 45, 49, 10, 95, 103, 105, 109, 112, 95, 99, 117,
  115, 116, 111, 109, 95, 99, 111, 100, 101, 32, 58, 10, 45, 95, 103, 105,
  109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 99, 111, 100, 101, 95, 115,
  116, 97, 114, 116, 10, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116,
  104, 105, 110, 103, 32, 58, 10, 103, 105, 109, 112, 95, 103, 112, 116, 32,
  58, 10, 45, 103, 112, 116, 32, 44, 64, 123, 45, 95, 103, 105, 109, 112,
  95, 103, 112, 116, 36, 49, 125, 10, 95, 103, 105, 109, 112, 95, 103, 112,
  116, 48, 32, 58, 32, 45, 117, 32, 48, 10, 95, 103, 105, 109, 112, 95,
  103, 112, 116, 49, 32, 58, 32, 45, 117, 32, 53, 48, 10, 95, 103, 105,
  109, 112, 95, 103, 112, 116, 50, 32, 58, 32, 45, 117, 32, 50, 53, 10,
  95, 103, 105, 109, 112, 95, 103, 112, 116, 51, 32, 58, 32, 45, 117, 32,
  49, 48, 10, 95, 103, 105, 109, 112, 95, 103, 112, 116, 52, 32, 58, 32,
  45, 117, 32, 45, 53, 48, 10, 95, 103, 105, 109, 112, 95, 103, 112, 116,
  53, 32, 58, 32, 45, 117, 32, 45, 50, 53, 10, 95, 103, 105, 109, 112,
  95, 103, 112, 116, 54, 32, 58, 32, 45, 117, 32, 45, 49, 48, 10, 103,
  105, 109, 112, 95, 100, 105, 115, 112, 108, 97, 121, 95, 104, 105, 115, 116,
  111, 103, 114, 97, 109, 32, 58, 10, 45, 116, 111, 95, 114, 103, 98, 32,
  45, 105, 102, 32, 36, 50, 32, 45, 108, 117, 109, 105, 110, 97, 110, 99,
  101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 10, 45, 100, 105, 115, 112, 108, 97, 121, 95, 104, 105, 115,
  116, 111, 103, 114, 97, 109, 91, 45, 49, 93, 32, 123, 119, 125, 44, 123,
  104, 125, 44, 36, 49, 44, 48, 44, 50, 53, 53, 10, 45, 109, 118, 91,
  45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112,
  95, 105, 109, 112, 111, 114, 116, 95, 105, 109, 97, 103, 101, 32, 58, 10,
  45, 114, 109, 32, 45, 105, 32, 34, 36, 49, 34, 32, 45, 115, 32, 122,
  32, 45, 105, 102, 32, 36, 50, 32, 45, 110, 32, 48, 44, 50, 53, 53,
  32, 45, 101, 108, 115, 101, 32, 45, 99, 32, 48, 44, 50, 53, 53, 32,
  45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 115, 111, 108, 118,
  101, 95, 109, 97, 122, 101, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 10, 45, 45, 110, 111, 114, 109, 91, 45, 49, 93, 32, 45,
  103, 101, 91, 45, 49, 93, 32, 53, 48, 37, 10, 45, 105, 102, 32, 123,
  33, 36, 49, 48, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91,
  45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 42, 91, 45, 49,
  93, 32, 50, 53, 53, 32, 45, 45, 98, 91, 45, 49, 93, 32, 36, 53,
  37, 32, 45, 42, 91, 45, 50, 93, 32, 49, 101, 49, 48, 32, 45, 43,
  91, 45, 50, 44, 45, 49, 93, 10, 45, 109, 105, 110, 105, 109, 97, 108,
  95, 112, 97, 116, 104, 91, 45, 49, 93, 32, 36, 49, 37, 44, 36, 50,
  37, 44, 48, 44, 36, 51, 37, 44, 36, 52, 37, 44, 48, 10, 45, 112,
  111, 105, 110, 116, 99, 108, 111, 117, 100, 91, 45, 49, 93, 32, 48, 32,
  45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 36, 54, 32, 45,
  114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44,
  49, 44, 49, 44, 48, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45,
  49, 93, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111,
  114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 49, 44, 49, 44, 49, 44,
  50, 53, 53, 44, 36, 123, 55, 45, 57, 125, 44, 50, 53, 53, 10, 45,
  114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 45, 49,
  93, 32, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44,
  48, 44, 48, 44, 48, 44, 48, 10, 45, 101, 108, 108, 105, 112, 115, 101,
  91, 45, 49, 93, 32, 36, 49, 37, 44, 36, 50, 37, 44, 53, 44, 53,
  44, 48, 44, 49, 44, 36, 123, 55, 45, 57, 125, 44, 50, 53, 53, 10,
  45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 51, 37,
  44, 36, 52, 37, 44, 53, 44, 53, 44, 48, 44, 49, 44, 36, 123, 55,
  45, 57, 125, 44, 50, 53, 53, 10, 45, 114, 118, 91, 45, 50, 44, 45,
  49, 93, 10, 45, 109, 118, 91, 45, 50, 44, 45, 49, 93, 32, 48, 32,
  45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 115, 111, 108, 118, 101,
  95, 109, 97, 122, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 100, 114, 103, 98, 97, 10, 45, 108, 105, 110, 101, 32, 36, 49, 37,
  44, 36, 50, 37, 44, 36, 51, 37, 44, 36, 52, 37, 44, 49, 44, 48,
  120, 67, 67, 67, 67, 67, 67, 67, 67, 44, 36, 123, 55, 45, 57, 125,
  10, 45, 101, 108, 108, 105, 112, 115, 101, 32, 36, 49, 37, 44, 36, 50,
  37, 44, 51, 44, 51, 44, 48, 44, 49, 44, 36, 123, 55, 45, 57, 125,
  10, 45, 101, 108, 108, 105, 112, 115, 101, 32, 36, 49, 37, 44, 36, 50,
  37, 44, 51, 44, 51, 44, 48, 44, 49, 44, 48, 120, 49, 44, 48, 10,
  45, 101, 108, 108, 105, 112, 115, 101, 32, 36, 51, 37, 44, 36, 52, 37,
  44, 51, 44, 51, 44, 48, 44, 49, 44, 36, 123, 55, 45, 57, 125, 10,
  45, 101, 108, 108, 105, 112, 115, 101, 32, 36, 51, 37, 44, 36, 52, 37,
  44, 51, 44, 51, 44, 48, 44, 49, 44, 48, 120, 49, 44, 48, 10, 103,
  109, 105, 99, 111, 108, 95, 108, 111, 103, 111, 95, 101, 110, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 108, 111, 103, 111, 32, 34, 32, 32, 32, 32,
  45, 32, 79, 110, 108, 105, 110, 101, 32, 45, 34, 10, 103, 109, 105, 99,
  111, 108, 95, 97, 100, 106, 117, 115, 116, 95, 99, 111, 108, 111, 114, 115,
  32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 97, 118, 103, 61, 123, 105, 97, 125, 32, 45, 45,
  32, 36, 97, 118, 103, 32, 45, 42, 32, 36, 49, 32, 45, 43, 32, 36,
  97, 118, 103, 10, 45, 43, 32, 123, 36, 50, 42, 50, 53, 54, 125, 10,
  45, 105, 102, 32, 123, 36, 51, 33, 61, 49, 125, 32, 45, 97, 112, 112,
  108, 121, 95, 103, 97, 109, 109, 97, 32, 123, 49, 48, 94, 36, 51, 125,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 52, 37,
  51, 54, 48, 125, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111,
  100, 101, 32, 123, 109, 97, 120, 40, 51, 44, 115, 41, 43, 49, 45, 115,
  37, 50, 125, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105,
  116, 121, 32, 45, 108, 91, 48, 93, 10, 45, 114, 103, 98, 50, 104, 115,
  118, 32, 45, 115, 104, 32, 48, 44, 48, 32, 45, 43, 91, 45, 49, 93,
  32, 36, 52, 32, 45, 37, 91, 45, 49, 93, 32, 51, 54, 48, 32, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 104, 115, 118, 50, 114, 103, 98, 10,
  45, 101, 110, 100, 108, 10, 45, 97, 32, 99, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 99,
  32, 48, 44, 50, 53, 53, 10, 103, 109, 105, 99, 111, 108, 95, 97, 100,
  106, 117, 115, 116, 95, 99, 111, 108, 111, 114, 115, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 109, 105, 99,
  111, 108, 95, 97, 100, 106, 117, 115, 116, 95, 99, 111, 108, 111, 114, 115,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 109, 105, 99, 111, 108, 95,
  99, 114, 111, 112, 32, 58, 10, 45, 99, 114, 111, 112, 32, 36, 49, 37,
  44, 36, 50, 37, 44, 36, 51, 37, 44, 36, 52, 37, 10, 103, 109, 105,
  99, 111, 108, 95, 99, 114, 111, 112, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 32, 36, 49,
  37, 44, 36, 50, 37, 44, 36, 51, 37, 44, 36, 52, 37, 44, 48, 46,
  53, 44, 49, 50, 56, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101,
  32, 36, 49, 37, 44, 36, 50, 37, 44, 36, 51, 37, 44, 36, 52, 37,
  44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 10,
  45, 99, 105, 114, 99, 108, 101, 32, 36, 49, 37, 44, 36, 50, 37, 44,
  51, 44, 49, 44, 48, 44, 50, 53, 53, 44, 48, 32, 45, 99, 105, 114,
  99, 108, 101, 32, 36, 49, 37, 44, 36, 50, 37, 44, 51, 44, 49, 44,
  48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 10, 45, 99, 105,
  114, 99, 108, 101, 32, 36, 51, 37, 44, 36, 50, 37, 44, 51, 44, 49,
  44, 48, 44, 50, 53, 53, 44, 48, 32, 45, 99, 105, 114, 99, 108, 101,
  32, 36, 51, 37, 44, 36, 50, 37, 44, 51, 44, 49, 44, 48, 120, 70,
  70, 70, 70, 70, 70, 70, 70, 44, 48, 10, 45, 99, 105, 114, 99, 108,
  101, 32, 36, 51, 37, 44, 36, 52, 37, 44, 51, 44, 49, 44, 48, 44,
  50, 53, 53, 44, 48, 32, 45, 99, 105, 114, 99, 108, 101, 32, 36, 51,
  37, 44, 36, 52, 37, 44, 51, 44, 49, 44, 48, 120, 70, 70, 70, 70,
  70, 70, 70, 70, 44, 48, 10, 45, 99, 105, 114, 99, 108, 101, 32, 36,
  49, 37, 44, 36, 52, 37, 44, 51, 44, 49, 44, 48, 44, 50, 53, 53,
  44, 48, 32, 45, 99, 105, 114, 99, 108, 101, 32, 36, 49, 37, 44, 36,
  52, 37, 44, 51, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70,
  70, 44, 48, 10, 103, 109, 105, 99, 111, 108, 95, 101, 113, 117, 97, 108,
  105, 122, 101, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 34, 45, 101, 113, 117, 97, 108, 105, 122, 101,
  32, 50, 53, 54, 44, 48, 44, 50, 53, 53, 34, 44, 36, 49, 44, 49,
  10, 103, 109, 105, 99, 111, 108, 95, 101, 113, 117, 97, 108, 105, 122, 101,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 103, 109, 105, 99, 111, 108, 95, 101, 113, 117, 97, 108, 105, 122, 101,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 109, 105, 99, 111, 108, 95,
  102, 108, 105, 112, 32, 58, 10, 45, 105, 102, 32, 36, 49, 32, 45, 109,
  105, 114, 114, 111, 114, 32, 121, 32, 45, 101, 108, 115, 101, 32, 45, 109,
  105, 114, 114, 111, 114, 32, 120, 32, 45, 101, 110, 100, 105, 102, 10, 103,
  109, 105, 99, 111, 108, 95, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32,
  58, 10, 45, 116, 111, 95, 114, 103, 98, 32, 45, 100, 104, 32, 54, 52,
  48, 44, 52, 56, 48, 44, 36, 49, 10, 103, 109, 105, 99, 111, 108, 95,
  104, 105, 115, 116, 111, 103, 114, 97, 109, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 116, 111, 95, 114, 103, 98, 32, 45, 100, 104, 32,
  51, 50, 48, 44, 50, 52, 48, 44, 36, 49, 10, 103, 109, 105, 99, 111,
  108, 95, 114, 101, 115, 105, 122, 101, 32, 58, 10, 45, 105, 102, 32, 123,
  36, 49, 61, 61, 48, 125, 10, 45, 114, 101, 115, 105, 122, 101, 32, 36,
  50, 37, 44, 36, 50, 37, 44, 49, 44, 49, 48, 48, 37, 44, 54, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 10, 45, 114,
  101, 115, 105, 122, 101, 50, 100, 120, 32, 36, 51, 44, 54, 10, 45, 101,
  108, 115, 101, 10, 45, 114, 101, 115, 105, 122, 101, 50, 100, 121, 32, 36,
  52, 44, 54, 10, 45, 101, 110, 100, 105, 102, 10, 45, 99, 32, 48, 44,
  50, 53, 53, 10, 103, 109, 105, 99, 111, 108, 95, 114, 111, 116, 97, 116,
  101, 32, 58, 10, 45, 105, 102, 32, 36, 50, 10, 45, 114, 111, 116, 97,
  116, 101, 32, 123, 57, 48, 42, 114, 111, 117, 110, 100, 40, 36, 49, 47,
  57, 48, 41, 125, 44, 48, 44, 48, 10, 45, 101, 108, 115, 101, 10, 45,
  116, 111, 95, 114, 103, 98, 97, 32, 45, 114, 111, 116, 97, 116, 101, 32,
  36, 49, 44, 49, 44, 36, 51, 10, 45, 101, 110, 100, 105, 102, 10, 95,
  103, 109, 105, 99, 111, 108, 95, 114, 103, 98, 95, 100, 105, 115, 116, 114,
  105, 98, 117, 116, 105, 111, 110, 32, 58, 10, 45, 100, 105, 115, 116, 114,
  105, 98, 117, 116, 105, 111, 110, 51, 100, 32, 45, 99, 111, 108, 111, 114,
  99, 117, 98, 101, 51, 100, 32, 45, 112, 51, 100, 91, 45, 49, 93, 32,
  49, 32, 45, 43, 51, 100, 10, 45, 114, 101, 112, 101, 97, 116, 32, 52,
  10, 45, 45, 115, 110, 97, 112, 115, 104, 111, 116, 51, 100, 91, 48, 93,
  32, 36, 49, 44, 48, 46, 57, 44, 50, 53, 53, 10, 45, 114, 51, 100,
  91, 48, 93, 32, 48, 44, 49, 44, 48, 46, 50, 44, 57, 48, 10, 45,
  100, 111, 110, 101, 10, 45, 114, 109, 91, 48, 93, 32, 45, 97, 117, 116,
  111, 99, 114, 111, 112, 32, 45, 45, 32, 50, 53, 53, 10, 45, 114, 32,
  64, 123, 45, 109, 97, 120, 95, 119, 104, 125, 44, 49, 44, 51, 44, 48,
  44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 43, 32, 50, 53,
  53, 32, 45, 102, 114, 97, 109, 101, 32, 53, 44, 53, 44, 50, 53, 53,
  32, 45, 102, 114, 97, 109, 101, 32, 49, 44, 49, 44, 48, 32, 45, 97,
  112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 32, 44, 10, 103, 109,
  105, 99, 111, 108, 95, 114, 103, 98, 95, 100, 105, 115, 116, 114, 105, 98,
  117, 116, 105, 111, 110, 32, 58, 10, 45, 95, 103, 109, 105, 99, 111, 108,
  95, 114, 103, 98, 95, 100, 105, 115, 116, 114, 105, 98, 117, 116, 105, 111,
  110, 32, 53, 49, 50, 10, 103, 109, 105, 99, 111, 108, 95, 114, 103, 98,
  95, 100, 105, 115, 116, 114, 105, 98, 117, 116, 105, 111, 110, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 95, 103, 109, 105, 99, 111, 108,
  95, 114, 103, 98, 95, 100, 105, 115, 116, 114, 105, 98, 117, 116, 105, 111,
  110, 32, 51, 50, 48, 10, 103, 109, 105, 99, 111, 108, 95, 97, 110, 105,
  109, 97, 116, 101, 95, 101, 108, 101, 118, 97, 116, 105, 111, 110, 51, 100,
  32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 101, 108, 101, 118, 97, 116,
  105, 111, 110, 51, 100, 32, 36, 123, 50, 45, 51, 125, 10, 45, 97, 110,
  105, 109, 97, 116, 101, 32, 103, 105, 109, 112, 95, 114, 101, 110, 100, 101,
  114, 51, 100, 44, 34, 36, 123, 52, 45, 53, 125, 44, 36, 123, 55, 45,
  49, 54, 125, 44, 36, 54, 34, 44, 92, 10, 34, 36, 123, 52, 45, 53,
  125, 44, 36, 123, 49, 55, 45, 50, 54, 125, 44, 36, 54, 34, 44, 36,
  49, 10, 45, 111, 32, 36, 95, 111, 117, 116, 112, 117, 116, 46, 103, 105,
  102, 44, 49, 48, 10, 45, 114, 109, 10, 103, 109, 105, 99, 111, 108, 95,
  97, 110, 105, 109, 97, 116, 101, 95, 101, 108, 101, 118, 97, 116, 105, 111,
  110, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 101, 108, 101, 118,
  97, 116, 105, 111, 110, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  36, 49, 44, 49, 44, 48, 44, 92, 34, 92, 34, 44, 36, 123, 50, 45,
  45, 49, 125, 10, 103, 109, 105, 99, 111, 108, 95, 97, 110, 105, 109, 97,
  116, 101, 95, 101, 120, 116, 114, 117, 100, 101, 51, 100, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 101, 120, 116,
  114, 117, 100, 101, 51, 100, 32, 36, 49, 44, 49, 44, 48, 44, 92, 34,
  92, 34, 44, 36, 123, 50, 45, 45, 49, 125, 10, 103, 109, 105, 99, 111,
  108, 95, 97, 110, 105, 109, 97, 116, 101, 95, 101, 120, 116, 114, 117, 100,
  101, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 101, 120, 116, 114,
  117, 100, 101, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 49,
  44, 49, 44, 48, 44, 92, 34, 92, 34, 44, 36, 123, 50, 45, 45, 49,
  125, 10, 103, 109, 105, 99, 111, 108, 95, 97, 110, 105, 109, 97, 116, 101,
  95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 105,
  109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 32, 36, 49, 44,
  49, 44, 48, 44, 92, 34, 92, 34, 44, 36, 123, 50, 45, 45, 49, 125,
  10, 103, 109, 105, 99, 111, 108, 95, 97, 110, 105, 109, 97, 116, 101, 95,
  105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 97, 110,
  105, 109, 97, 116, 101, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99,
  116, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 49, 44, 49,
  44, 48, 44, 92, 34, 92, 34, 44, 36, 123, 50, 45, 45, 49, 125, 0 };

unsigned int size_data_gmic_def = sizeof(data_gmic_def);

#else
# 44568 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic_def.h"
/* Define image 'gmic_def' of size 1x1617086x1x1 and type 'char' */
char data_gmic_def[] = {
  104, 32, 58, 10, 45, 104, 101, 108, 112, 32, 36, 42, 10, 104, 101, 108,
  112, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 34, 34,
  125, 44, 36, 123, 50, 61, 49, 125, 10, 45, 105, 102, 32, 123, 33, 64,
  35, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 121, 32, 45, 97, 32, 121, 10, 45, 45, 95, 104, 101, 108,
  112, 32, 36, 49, 44, 36, 50, 32, 45, 107, 91, 48, 93, 10, 45, 105,
  102, 32, 123, 110, 97, 114, 103, 40, 64, 123, 125, 41, 125, 32, 45, 95,
  104, 101, 108, 112, 91, 48, 93, 32, 64, 123, 125, 44, 48, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 109, 10, 95, 104, 101, 108, 112, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 34, 34, 125, 10, 45,
  118, 32, 45, 49, 10, 45, 105, 102, 32, 123, 33, 110, 97, 114, 103, 40,
  34, 36, 49, 34, 41, 125, 32, 95, 105, 115, 95, 101, 120, 97, 109, 112,
  108, 101, 61, 48, 32, 45, 95, 95, 104, 101, 108, 112, 32, 97, 115, 99,
  105, 105, 32, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 34, 32,
  45, 118, 32, 45, 32, 45, 114, 109, 32, 45, 117, 32, 34, 34, 32, 45,
  114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 40, 123,
  39, 34, 36, 49, 34, 39, 125, 41, 32, 45, 97, 117, 116, 111, 99, 114,
  111, 112, 91, 45, 49, 93, 32, 123, 39, 45, 39, 125, 10, 45, 105, 102,
  32, 123, 64, 123, 45, 49, 44, 49, 48, 48, 37, 125, 61, 61, 123, 39,
  93, 39, 125, 34, 32, 38, 38, 32, 34, 105, 33, 61, 123, 39, 91, 39,
  125, 125, 32, 45, 108, 91, 45, 49, 93, 32, 45, 115, 32, 45, 44, 123,
  39, 91, 39, 125, 32, 45, 107, 91, 48, 93, 32, 45, 101, 110, 100, 108,
  32, 45, 101, 110, 100, 105, 102, 10, 99, 111, 109, 109, 97, 110, 100, 61,
  64, 123, 45, 49, 44, 116, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  107, 115, 48, 61, 34, 48, 34, 32, 107, 115, 49, 61, 34, 45, 107, 91,
  48, 93, 34, 10, 45, 105, 102, 32, 36, 50, 32, 45, 95, 95, 104, 101,
  108, 112, 95, 104, 101, 97, 100, 101, 114, 95, 97, 115, 99, 105, 105, 91,
  93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 32, 49, 44, 123, 104,
  43, 49, 125, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 44, 49, 10,
  45, 115, 32, 43, 44, 123, 39, 34, 35, 64, 103, 109, 105, 99, 32, 34,
  36, 99, 111, 109, 109, 97, 110, 100, 34, 32, 58, 34, 39, 125, 10, 45,
  105, 102, 32, 123, 64, 35, 61, 61, 49, 125, 32, 45, 115, 32, 43, 44,
  123, 39, 34, 35, 64, 103, 109, 105, 99, 32, 34, 36, 99, 111, 109, 109,
  97, 110, 100, 34, 58, 34, 39, 125, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 64, 35, 61, 61, 49, 125, 32, 45, 115, 32, 43,
  44, 123, 39, 34, 35, 64, 103, 109, 105, 99, 32, 34, 36, 99, 111, 109,
  109, 97, 110, 100, 34, 92, 110, 34, 39, 125, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 64, 35, 61, 61, 49, 125, 32, 45, 118,
  32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 110, 91, 103, 109, 105, 99,
  93, 32, 67, 111, 109, 109, 97, 110, 100, 32, 39, 34, 36, 99, 111, 109,
  109, 97, 110, 100, 34, 39, 32, 104, 97, 115, 32, 110, 111, 32, 100, 101,
  115, 99, 114, 105, 112, 116, 105, 111, 110, 46, 32, 84, 114, 121, 32, 39,
  103, 109, 105, 99, 32, 45, 104, 39, 32, 102, 111, 114, 32, 103, 108, 111,
  98, 97, 108, 32, 104, 101, 108, 112, 46, 92, 110, 92, 110, 34, 32, 45,
  118, 32, 45, 32, 45, 114, 109, 32, 45, 117, 32, 34, 34, 32, 45, 114,
  101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109,
  91, 48, 93, 32, 45, 97, 32, 121, 32, 45, 115, 32, 45, 44, 49, 48,
  10, 115, 116, 111, 112, 102, 108, 97, 103, 61, 48, 10, 95, 105, 115, 95,
  101, 120, 97, 109, 112, 108, 101, 61, 48, 10, 45, 95, 100, 111, 99, 117,
  109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 104, 101, 97, 100, 101, 114,
  95, 97, 115, 99, 105, 105, 91, 93, 32, 48, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 105, 102,
  32, 123, 104, 62, 55, 34, 32, 38, 38, 32, 34, 123, 64, 123, 45, 49,
  44, 48, 45, 53, 125, 39, 61, 61, 39, 123, 39, 34, 35, 64, 103, 109,
  105, 99, 34, 39, 125, 125, 125, 10, 45, 114, 111, 119, 115, 32, 55, 44,
  49, 48, 48, 37, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 123,
  39, 34, 32, 34, 39, 125, 10, 45, 105, 102, 32, 123, 105, 33, 61, 123,
  39, 58, 39, 125, 125, 10, 45, 115, 32, 45, 44, 123, 39, 34, 58, 32,
  34, 39, 125, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 123, 39,
  34, 32, 34, 39, 125, 10, 45, 105, 102, 32, 123, 64, 123, 48, 44, 116,
  125, 39, 61, 61, 39, 36, 99, 111, 109, 109, 97, 110, 100, 125, 10, 45,
  95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 100,
  101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 95, 97, 115, 99, 105, 105,
  10, 45, 105, 102, 32, 36, 95, 115, 104, 111, 114, 116, 99, 117, 116, 10,
  45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 110, 32, 32, 32,
  32, 45, 34, 36, 99, 111, 109, 109, 97, 110, 100, 34, 58, 32, 69, 113,
  117, 105, 118, 97, 108, 101, 110, 116, 32, 116, 111, 32, 39, 34, 36, 95,
  115, 104, 111, 114, 116, 99, 117, 116, 108, 105, 110, 107, 48, 34, 39, 46,
  34, 32, 45, 118, 32, 45, 10, 45, 117, 32, 36, 95, 115, 104, 111, 114,
  116, 99, 117, 116, 108, 105, 110, 107, 48, 32, 45, 114, 101, 116, 117, 114,
  110, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101, 32, 115,
  116, 111, 112, 102, 108, 97, 103, 61, 49, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 108, 115, 101, 10, 45, 114, 111, 119, 115, 32, 49, 44, 49,
  48, 48, 37, 10, 45, 105, 102, 32, 123, 105, 61, 61, 123, 39, 58, 39,
  125, 125, 32, 115, 116, 111, 112, 102, 108, 97, 103, 61, 49, 10, 45, 101,
  108, 115, 101, 10, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 123, 39,
  34, 32, 34, 39, 125, 10, 45, 105, 102, 32, 123, 105, 61, 61, 123, 39,
  36, 39, 125, 125, 10, 45, 114, 111, 119, 115, 32, 49, 44, 49, 48, 48,
  37, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 123, 39, 34, 32,
  34, 39, 125, 10, 45, 105, 102, 32, 36, 95, 105, 115, 95, 101, 120, 97,
  109, 112, 108, 101, 32, 45, 105, 91, 48, 93, 32, 40, 123, 39, 34, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 34, 39, 125, 41, 10,
  45, 101, 108, 115, 101, 32, 45, 105, 91, 48, 93, 32, 40, 123, 39, 34,
  92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 69, 120, 97, 109, 112, 108,
  101, 40, 115, 41, 58, 32, 34, 39, 125, 41, 32, 95, 105, 115, 95, 101,
  120, 97, 109, 112, 108, 101, 61, 49, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 121, 91, 48, 93, 32, 45, 97, 32, 121, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105,
  99, 95, 100, 101, 115, 99, 114, 105, 112, 116, 105, 111, 110, 95, 97, 115,
  99, 105, 105, 32, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 108, 115, 101, 32, 115, 116, 111, 112, 102, 108,
  97, 103, 61, 49, 32, 45, 101, 110, 100, 105, 102, 32, 36, 123, 107, 115,
  123, 64, 35, 33, 61, 48, 125, 125, 32, 45, 101, 110, 100, 108, 32, 45,
  105, 102, 32, 36, 115, 116, 111, 112, 102, 108, 97, 103, 32, 45, 98, 114,
  101, 97, 107, 32, 45, 101, 110, 100, 105, 102, 32, 45, 100, 111, 110, 101,
  10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 110, 34, 32,
  45, 118, 32, 45, 32, 45, 114, 109, 10, 45, 117, 32, 34, 34, 10, 95,
  95, 104, 101, 108, 112, 32, 58, 10, 45, 109, 32, 34, 95, 104, 101, 108,
  112, 95, 115, 101, 99, 116, 105, 111, 110, 32, 58, 32, 45, 95, 104, 101,
  108, 112, 95, 115, 101, 99, 116, 105, 111, 110, 95, 36, 49, 32, 92, 34,
  36, 34, 34, 49, 92, 34, 34, 10, 45, 109, 32, 34, 95, 104, 101, 108,
  112, 95, 112, 97, 114, 97, 103, 114, 97, 112, 104, 32, 58, 32, 45, 95,
  104, 101, 108, 112, 95, 112, 97, 114, 97, 103, 114, 97, 112, 104, 95, 36,
  49, 32, 92, 34, 36, 34, 34, 49, 92, 34, 34, 10, 45, 95, 104, 101,
  108, 112, 95, 104, 101, 97, 100, 101, 114, 95, 36, 49, 91, 93, 10, 45,
  95, 104, 101, 108, 112, 95, 117, 115, 97, 103, 101, 91, 93, 10, 45, 100,
  111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 32, 36, 49, 44,
  34, 105, 109, 103, 47, 34, 44, 48, 10, 45, 95, 104, 101, 108, 112, 95,
  101, 120, 97, 109, 112, 108, 101, 115, 91, 93, 10, 45, 95, 104, 101, 108,
  112, 95, 102, 111, 111, 116, 101, 114, 95, 36, 49, 91, 93, 10, 95, 104,
  101, 108, 112, 95, 104, 101, 97, 100, 101, 114, 95, 108, 97, 116, 101, 120,
  32, 58, 10, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40, 36, 95, 103,
  109, 105, 99, 95, 105, 115, 95, 98, 101, 116, 97, 41, 125, 32, 115, 116,
  114, 98, 101, 116, 97, 61, 34, 32, 40, 98, 101, 116, 97, 41, 34, 32,
  45, 101, 108, 115, 101, 32, 115, 116, 114, 98, 101, 116, 97, 61, 34, 34,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 110, 97, 114,
  103, 40, 36, 95, 103, 109, 105, 99, 95, 118, 101, 114, 115, 105, 111, 110,
  41, 125, 32, 115, 116, 114, 118, 101, 114, 61, 36, 95, 103, 109, 105, 99,
  95, 118, 101, 114, 115, 105, 111, 110, 32, 45, 101, 108, 115, 101, 32, 115,
  116, 114, 118, 101, 114, 61, 64, 123, 45, 115, 116, 114, 118, 101, 114, 125,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 32, 45, 101, 91,
  93, 32, 34, 92, 92, 100, 111, 99, 117, 109, 101, 110, 116, 99, 108, 97,
  115, 115, 91, 97, 52, 112, 97, 112, 101, 114, 44, 49, 49, 112, 116, 44,
  116, 119, 111, 115, 105, 100, 101, 93, 123, 98, 111, 111, 107, 125, 10, 92,
  110, 92, 92, 117, 115, 101, 112, 97, 99, 107, 97, 103, 101, 123, 104, 121,
  112, 101, 114, 114, 101, 102, 44, 102, 97, 110, 99, 121, 104, 100, 114, 44,
  103, 114, 97, 112, 104, 105, 99, 120, 44, 97, 109, 115, 115, 121, 109, 98,
  44, 97, 109, 115, 109, 97, 116, 104, 44, 116, 105, 109, 101, 115, 44, 109,
  97, 107, 101, 105, 100, 120, 44, 108, 105, 115, 116, 105, 110, 103, 115, 125,
  10, 92, 110, 92, 92, 103, 114, 97, 112, 104, 105, 99, 115, 112, 97, 116,
  104, 123, 123, 105, 109, 103, 47, 125, 125, 10, 92, 110, 92, 92, 112, 97,
  103, 101, 115, 116, 121, 108, 101, 123, 102, 97, 110, 99, 121, 112, 108, 97,
  105, 110, 125, 10, 92, 110, 92, 92, 108, 104, 101, 97, 100, 91, 92, 92,
  102, 97, 110, 99, 121, 112, 108, 97, 105, 110, 123, 125, 123, 92, 92, 116,
  101, 120, 116, 98, 102, 92, 92, 116, 104, 101, 112, 97, 103, 101, 125, 93,
  123, 92, 92, 102, 97, 110, 99, 121, 112, 108, 97, 105, 110, 123, 125, 123,
  92, 92, 114, 105, 103, 104, 116, 109, 97, 114, 107, 125, 125, 10, 92, 110,
  92, 92, 114, 104, 101, 97, 100, 91, 92, 92, 102, 97, 110, 99, 121, 112,
  108, 97, 105, 110, 123, 125, 123, 92, 92, 108, 101, 102, 116, 109, 97, 114,
  107, 125, 93, 123, 92, 92, 102, 97, 110, 99, 121, 112, 108, 97, 105, 110,
  123, 125, 123, 92, 92, 116, 101, 120, 116, 98, 102, 92, 92, 116, 104, 101,
  112, 97, 103, 101, 125, 125, 10, 92, 110, 92, 92, 99, 102, 111, 111, 116,
  123, 125, 10, 92, 110, 92, 92, 115, 101, 116, 108, 101, 110, 103, 116, 104,
  123, 92, 92, 116, 101, 120, 116, 119, 105, 100, 116, 104, 125, 123, 53, 46,
  56, 55, 53, 105, 110, 125, 10, 92, 110, 92, 92, 115, 101, 116, 108, 101,
  110, 103, 116, 104, 123, 92, 92, 112, 97, 114, 105, 110, 100, 101, 110, 116,
  125, 123, 48, 112, 99, 125, 10, 92, 110, 92, 92, 115, 101, 116, 108, 101,
  110, 103, 116, 104, 123, 92, 92, 104, 111, 102, 102, 115, 101, 116, 125, 123,
  45, 48, 46, 56, 99, 109, 125, 10, 92, 110, 92, 92, 115, 101, 116, 99,
  111, 117, 110, 116, 101, 114, 123, 116, 111, 99, 100, 101, 112, 116, 104, 125,
  123, 49, 125, 10, 92, 110, 92, 92, 115, 108, 111, 112, 112, 121, 123, 125,
  10, 92, 110, 92, 92, 116, 105, 116, 108, 101, 123, 92, 92, 102, 98, 111,
  120, 123, 92, 92, 112, 97, 114, 98, 111, 120, 123, 92, 92, 116, 101, 120,
  116, 119, 105, 100, 116, 104, 125, 123, 92, 92, 98, 101, 103, 105, 110, 123,
  99, 101, 110, 116, 101, 114, 125, 92, 92, 118, 115, 112, 97, 99, 101, 42,
  123, 50, 99, 109, 125, 92, 92, 105, 110, 99, 108, 117, 100, 101, 103, 114,
  97, 112, 104, 105, 99, 115, 91, 119, 105, 100, 116, 104, 61, 49, 50, 99,
  109, 93, 123, 108, 111, 103, 111, 51, 46, 106, 112, 103, 125, 92, 92, 92,
  92, 92, 92, 118, 115, 112, 97, 99, 101, 42, 123, 49, 99, 109, 125, 123,
  92, 92, 72, 117, 103, 101, 32, 92, 92, 116, 101, 120, 116, 98, 102, 123,
  84, 104, 101, 32, 72, 97, 110, 100, 98, 111, 111, 107, 125, 92, 92, 92,
  92, 123, 92, 92, 115, 109, 97, 108, 108, 32, 86, 101, 114, 115, 105, 111,
  110, 32, 34, 36, 115, 116, 114, 118, 101, 114, 36, 115, 116, 114, 98, 101,
  116, 97, 34, 125, 92, 92, 92, 92, 92, 92, 118, 115, 112, 97, 99, 101,
  42, 123, 49, 99, 109, 125, 125, 92, 92, 101, 110, 100, 123, 99, 101, 110,
  116, 101, 114, 125, 125, 125, 125, 10, 92, 110, 92, 92, 97, 117, 116, 104,
  111, 114, 123, 92, 92, 76, 97, 114, 103, 101, 32, 92, 92, 98, 102, 32,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  92, 92, 39, 101, 125, 10, 92, 110, 92, 92, 114, 101, 110, 101, 119, 99,
  111, 109, 109, 97, 110, 100, 92, 92, 105, 110, 100, 101, 120, 110, 97, 109,
  101, 123, 73, 110, 100, 101, 120, 32, 111, 102, 32, 99, 111, 109, 109, 97,
  110, 100, 115, 125, 10, 92, 110, 92, 92, 109, 97, 107, 101, 105, 110, 100,
  101, 120, 10, 92, 110, 92, 92, 108, 115, 116, 115, 101, 116, 123, 99, 111,
  108, 117, 109, 110, 115, 61, 102, 117, 108, 108, 102, 108, 101, 120, 105, 98,
  108, 101, 44, 98, 97, 115, 105, 99, 115, 116, 121, 108, 101, 61, 92, 92,
  110, 111, 114, 109, 97, 108, 102, 111, 110, 116, 125, 10, 92, 110, 92, 92,
  98, 101, 103, 105, 110, 123, 100, 111, 99, 117, 109, 101, 110, 116, 125, 10,
  92, 110, 92, 92, 109, 97, 107, 101, 116, 105, 116, 108, 101, 10, 92, 110,
  92, 92, 116, 97, 98, 108, 101, 111, 102, 99, 111, 110, 116, 101, 110, 116,
  115, 10, 92, 110, 92, 92, 99, 104, 97, 112, 116, 101, 114, 42, 123, 80,
  114, 101, 97, 109, 98, 108, 101, 125, 10, 92, 110, 92, 92, 115, 101, 99,
  116, 105, 111, 110, 42, 123, 76, 105, 99, 101, 110, 115, 101, 125, 10, 92,
  110, 84, 104, 105, 115, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 105,
  115, 32, 100, 105, 115, 116, 114, 105, 98, 117, 116, 101, 100, 32, 117, 110,
  100, 101, 114, 32, 116, 104, 101, 32, 92, 92, 116, 101, 120, 116, 98, 102,
  123, 71, 78, 85, 32, 70, 114, 101, 101, 32, 68, 111, 99, 117, 109, 101,
  110, 116, 97, 116, 105, 111, 110, 32, 76, 105, 99, 101, 110, 115, 101, 125,
  44, 32, 118, 101, 114, 115, 105, 111, 110, 32, 49, 46, 51, 46, 92, 92,
  92, 92, 10, 92, 110, 82, 101, 97, 100, 32, 116, 104, 101, 32, 102, 117,
  108, 108, 32, 108, 105, 99, 101, 110, 115, 101, 32, 116, 101, 114, 109, 115,
  32, 97, 116, 32, 92, 92, 116, 101, 120, 116, 116, 116, 123, 104, 116, 116,
  112, 58, 47, 47, 119, 119, 119, 46, 103, 110, 117, 46, 111, 114, 103, 47,
  108, 105, 99, 101, 110, 115, 101, 115, 47, 102, 100, 108, 45, 49, 46, 51,
  46, 116, 120, 116, 125, 46, 92, 92, 92, 92, 126, 92, 92, 92, 92, 10,
  92, 110, 65, 110, 32, 111, 110, 108, 105, 110, 101, 32, 118, 101, 114, 115,
  105, 111, 110, 32, 111, 102, 32, 116, 104, 105, 115, 32, 100, 111, 99, 117,
  109, 101, 110, 116, 97, 116, 105, 111, 110, 32, 105, 115, 32, 97, 118, 97,
  105, 108, 97, 98, 108, 101, 32, 97, 116, 58, 92, 92, 92, 92, 92, 92,
  116, 101, 120, 116, 116, 116, 123, 104, 116, 116, 112, 58, 47, 47, 103, 109,
  105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110,
  101, 116, 47, 114, 101, 102, 101, 114, 101, 110, 99, 101, 46, 115, 104, 116,
  109, 108, 125, 46, 10, 92, 110, 92, 92, 115, 101, 99, 116, 105, 111, 110,
  42, 123, 77, 111, 116, 105, 118, 97, 116, 105, 111, 110, 115, 125, 10, 92,
  110, 71, 39, 77, 73, 67, 32, 105, 115, 32, 97, 110, 32, 111, 112, 101,
  110, 32, 97, 110, 100, 32, 102, 117, 108, 108, 45, 102, 101, 97, 116, 117,
  114, 101, 100, 32, 102, 114, 97, 109, 101, 119, 111, 114, 107, 32, 102, 111,
  114, 32, 105, 109, 97, 103, 101, 32, 112, 114, 111, 99, 101, 115, 115, 105,
  110, 103, 44, 32, 112, 114, 111, 118, 105, 100, 105, 110, 103, 32, 115, 101,
  118, 101, 114, 97, 108, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32,
  117, 115, 101, 114, 32, 105, 110, 116, 101, 114, 102, 97, 99, 101, 115, 32,
  116, 111, 10, 92, 110, 99, 111, 110, 118, 101, 114, 116, 47, 109, 97, 110,
  105, 112, 117, 108, 97, 116, 101, 47, 102, 105, 108, 116, 101, 114, 47, 118,
  105, 115, 117, 97, 108, 105, 122, 101, 32, 103, 101, 110, 101, 114, 105, 99,
  32, 105, 109, 97, 103, 101, 32, 100, 97, 116, 97, 115, 101, 116, 115, 44,
  32, 102, 114, 111, 109, 32, 49, 100, 32, 115, 99, 97, 108, 97, 114, 32,
  115, 105, 103, 110, 97, 108, 101, 115, 32, 116, 111, 32, 51, 100, 43, 116,
  32, 115, 101, 113, 117, 101, 110, 99, 101, 115, 32, 111, 102, 32, 109, 117,
  108, 116, 105, 45, 115, 112, 101, 99, 116, 114, 97, 108, 32, 118, 111, 108,
  117, 109, 101, 116, 114, 105, 99, 32, 105, 109, 97, 103, 101, 115, 46, 10,
  92, 110, 84, 101, 99, 104, 110, 105, 99, 97, 108, 108, 121, 32, 115, 112,
  101, 97, 107, 105, 110, 103, 44, 32, 119, 104, 97, 116, 32, 105, 116, 32,
  100, 111, 101, 115, 32, 105, 115, 58, 10, 92, 110, 92, 92, 98, 101, 103,
  105, 110, 123, 105, 116, 101, 109, 105, 122, 101, 125, 10, 92, 110, 92, 92,
  105, 116, 101, 109, 32, 68, 101, 102, 105, 110, 101, 32, 97, 32, 108, 105,
  103, 104, 116, 119, 101, 105, 103, 104, 116, 32, 98, 117, 116, 32, 112, 111,
  119, 101, 114, 102, 117, 108, 32, 115, 99, 114, 105, 112, 116, 32, 108, 97,
  110, 103, 117, 97, 103, 101, 32, 40, 116, 104, 101, 32, 71, 39, 77, 73,
  67, 32, 108, 97, 110, 103, 117, 97, 103, 101, 41, 32, 100, 101, 100, 105,
  99, 97, 116, 101, 100, 32, 116, 111, 32, 116, 104, 101, 32, 100, 101, 115,
  105, 103, 110, 32, 111, 102, 32, 105, 109, 97, 103, 101, 32, 112, 114, 111,
  99, 101, 115, 115, 105, 110, 103, 32, 112, 105, 112, 101, 108, 105, 110, 101,
  115, 46, 10, 92, 110, 92, 92, 105, 116, 101, 109, 32, 80, 114, 111, 118,
  105, 100, 101, 32, 115, 101, 118, 101, 114, 97, 108, 32, 117, 115, 101, 114,
  32, 105, 110, 116, 101, 114, 102, 97, 99, 101, 115, 32, 101, 109, 98, 101,
  100, 100, 105, 110, 103, 32, 116, 104, 101, 32, 99, 111, 114, 114, 101, 115,
  112, 111, 110, 100, 105, 110, 103, 32, 105, 110, 116, 101, 114, 112, 114, 101,
  116, 101, 114, 58, 10, 92, 110, 92, 92, 98, 101, 103, 105, 110, 123, 105,
  116, 101, 109, 105, 122, 101, 125, 10, 92, 110, 92, 92, 105, 116, 101, 109,
  32, 65, 32, 99, 111, 109, 109, 97, 110, 100, 45, 108, 105, 110, 101, 32,
  101, 120, 101, 99, 117, 116, 97, 98, 108, 101, 32, 39, 103, 109, 105, 99,
  39, 44, 32, 116, 111, 32, 117, 115, 101, 32, 116, 104, 101, 32, 71, 39,
  77, 73, 67, 32, 102, 114, 97, 109, 101, 119, 111, 114, 107, 32, 102, 114,
  111, 109, 32, 97, 32, 115, 104, 101, 108, 108, 46, 10, 92, 110, 73, 110,
  32, 116, 104, 105, 115, 32, 115, 101, 116, 116, 105, 110, 103, 44, 32, 71,
  39, 77, 73, 67, 32, 109, 97, 121, 32, 98, 101, 32, 115, 101, 101, 110,
  32, 97, 115, 32, 97, 32, 100, 105, 114, 101, 99, 116, 32, 40, 97, 110,
  100, 32, 102, 114, 105, 101, 110, 100, 108, 121, 41, 32, 99, 111, 109, 112,
  101, 116, 105, 116, 111, 114, 32, 111, 102, 32, 116, 104, 101, 32, 73, 109,
  97, 103, 101, 77, 97, 103, 105, 99, 107, 32, 111, 114, 32, 71, 114, 97,
  112, 104, 105, 99, 115, 77, 97, 103, 105, 99, 107, 32, 115, 111, 102, 116,
  119, 97, 114, 101, 32, 115, 117, 105, 116, 101, 115, 46, 10, 92, 110, 92,
  92, 105, 116, 101, 109, 32, 65, 32, 112, 108, 117, 103, 45, 105, 110, 32,
  39, 103, 109, 105, 99, 92, 92, 95, 103, 105, 109, 112, 39, 44, 32, 116,
  111, 32, 98, 114, 105, 110, 103, 32, 71, 39, 77, 73, 67, 32, 99, 97,
  112, 97, 98, 105, 108, 105, 116, 105, 101, 115, 32, 116, 111, 32, 116, 104,
  101, 32, 71, 73, 77, 80, 32, 105, 109, 97, 103, 101, 32, 114, 101, 116,
  111, 117, 99, 104, 105, 110, 103, 32, 115, 111, 102, 116, 119, 97, 114, 101,
  46, 10, 92, 110, 92, 92, 105, 116, 101, 109, 32, 65, 32, 119, 101, 98,
  45, 115, 101, 114, 118, 105, 99, 101, 32, 39, 71, 39, 77, 73, 67, 32,
  79, 110, 108, 105, 110, 101, 39, 44, 32, 116, 111, 32, 97, 108, 108, 111,
  119, 32, 117, 115, 101, 114, 115, 32, 97, 112, 112, 108, 121, 105, 110, 103,
  32, 105, 109, 97, 103, 101, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110,
  103, 32, 97, 108, 103, 111, 114, 105, 116, 104, 109, 115, 32, 100, 105, 114,
  101, 99, 116, 108, 121, 32, 105, 110, 32, 97, 32, 119, 101, 98, 32, 98,
  114, 111, 119, 101, 114, 46, 10, 92, 110, 92, 92, 105, 116, 101, 109, 32,
  65, 32, 81, 116, 45, 98, 97, 115, 101, 100, 32, 105, 110, 116, 101, 114,
  102, 97, 99, 101, 32, 39, 90, 65, 114, 116, 39, 44, 32, 102, 111, 114,
  32, 114, 101, 97, 108, 45, 116, 105, 109, 101, 32, 109, 97, 110, 105, 112,
  117, 108, 97, 116, 105, 111, 110, 32, 111, 102, 32, 119, 101, 98, 99, 97,
  109, 32, 105, 109, 97, 103, 101, 115, 46, 10, 92, 110, 92, 92, 105, 116,
  101, 109, 32, 65, 32, 67, 43, 43, 32, 108, 105, 98, 114, 97, 114, 121,
  32, 39, 108, 105, 98, 103, 109, 105, 99, 39, 44, 32, 116, 111, 32, 98,
  101, 32, 108, 105, 110, 107, 101, 100, 32, 119, 105, 116, 104, 32, 116, 104,
  105, 114, 100, 45, 112, 97, 114, 116, 121, 32, 97, 112, 112, 108, 105, 99,
  97, 116, 105, 111, 110, 115, 46, 10, 92, 110, 92, 92, 101, 110, 100, 123,
  105, 116, 101, 109, 105, 122, 101, 125, 10, 92, 110, 92, 92, 101, 110, 100,
  123, 105, 116, 101, 109, 105, 122, 101, 125, 10, 92, 110, 71, 39, 77, 73,
  67, 32, 105, 115, 32, 102, 111, 99, 117, 115, 101, 100, 32, 111, 110, 32,
  116, 104, 101, 32, 100, 101, 115, 105, 103, 110, 32, 111, 102, 32, 112, 111,
  115, 115, 105, 98, 108, 121, 32, 99, 111, 109, 112, 108, 101, 120, 32, 112,
  105, 112, 101, 108, 105, 110, 101, 115, 32, 102, 111, 114, 32, 99, 111, 110,
  118, 101, 114, 116, 105, 110, 103, 44, 32, 109, 97, 110, 105, 112, 117, 108,
  97, 116, 105, 110, 103, 44, 32, 102, 105, 108, 116, 101, 114, 105, 110, 103,
  32, 97, 110, 100, 32, 118, 105, 115, 117, 97, 108, 105, 122, 105, 110, 103,
  32, 103, 101, 110, 101, 114, 105, 99, 32, 49, 100, 47, 50, 100, 47, 51,
  100, 32, 109, 117, 108, 116, 105, 45, 115, 112, 101, 99, 116, 114, 97, 108,
  32, 105, 109, 97, 103, 101, 32, 100, 97, 116, 97, 115, 101, 116, 115, 46,
  32, 84, 104, 105, 115, 32, 105, 110, 99, 108, 117, 100, 101, 115, 32, 111,
  102, 32, 99, 111, 117, 114, 115, 101, 32, 99, 111, 108, 111, 114, 32, 105,
  109, 97, 103, 101, 115, 44, 32, 98, 117, 116, 32, 97, 108, 115, 111, 32,
  109, 111, 114, 101, 32, 99, 111, 109, 112, 108, 101, 120, 32, 100, 97, 116,
  97, 32, 97, 115, 32, 105, 109, 97, 103, 101, 32, 115, 101, 113, 117, 101,
  110, 99, 101, 115, 32, 111, 114, 32, 51, 100, 40, 43, 116, 41, 32, 118,
  111, 108, 117, 109, 101, 116, 114, 105, 99, 32, 102, 108, 111, 97, 116, 45,
  118, 97, 108, 117, 101, 100, 32, 100, 97, 116, 97, 115, 101, 116, 115, 46,
  92, 92, 92, 92, 10, 92, 110, 10, 92, 110, 71, 39, 77, 73, 67, 32,
  105, 115, 32, 97, 110, 32, 111, 112, 101, 110, 32, 102, 114, 97, 109, 101,
  119, 111, 114, 107, 58, 32, 116, 104, 101, 32, 100, 101, 102, 97, 117, 108,
  116, 32, 108, 97, 110, 103, 117, 97, 103, 101, 32, 99, 97, 110, 32, 98,
  101, 32, 101, 120, 116, 101, 110, 100, 101, 100, 32, 119, 105, 116, 104, 32,
  99, 117, 115, 116, 111, 109, 32, 71, 39, 77, 73, 67, 45, 119, 114, 105,
  116, 116, 101, 110, 32, 99, 111, 109, 109, 97, 110, 100, 115, 44, 32, 100,
  101, 102, 105, 110, 105, 110, 103, 32, 116, 104, 117, 115, 32, 110, 101, 119,
  32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 32, 105, 109, 97, 103, 101,
  32, 102, 105, 108, 116, 101, 114, 115, 32, 111, 114, 32, 101, 102, 102, 101,
  99, 116, 115, 46, 32, 66, 121, 32, 116, 104, 101, 32, 119, 97, 121, 44,
  32, 71, 39, 77, 73, 67, 32, 97, 108, 114, 101, 97, 100, 121, 32, 99,
  111, 110, 116, 97, 105, 110, 115, 32, 97, 32, 115, 117, 98, 115, 116, 97,
  110, 116, 105, 97, 108, 32, 115, 101, 116, 32, 111, 102, 32, 112, 114, 101,
  45, 100, 101, 102, 105, 110, 101, 100, 32, 105, 109, 97, 103, 101, 32, 112,
  114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 97, 108, 103, 111, 114, 105,
  116, 104, 109, 115, 32, 97, 110, 100, 32, 112, 105, 112, 101, 108, 105, 110,
  101, 115, 32, 40, 109, 111, 114, 101, 32, 116, 104, 97, 110, 32, 49, 48,
  48, 48, 41, 46, 92, 92, 92, 92, 10, 92, 110, 10, 92, 110, 71, 39,
  77, 73, 67, 32, 104, 97, 115, 32, 98, 101, 101, 110, 32, 100, 101, 115,
  105, 103, 110, 101, 100, 32, 119, 105, 116, 104, 32, 112, 111, 114, 116, 97,
  98, 105, 108, 105, 116, 121, 32, 105, 110, 32, 109, 105, 110, 100, 32, 97,
  110, 100, 32, 114, 117, 110, 115, 32, 111, 110, 32, 100, 105, 102, 102, 101,
  114, 101, 110, 116, 32, 112, 108, 97, 116, 102, 111, 114, 109, 115, 32, 40,
  87, 105, 110, 100, 111, 119, 115, 44, 32, 85, 110, 105, 120, 44, 32, 77,
  97, 99, 79, 83, 88, 41, 46, 32, 73, 116, 32, 105, 115, 32, 100, 105,
  115, 116, 114, 105, 98, 117, 116, 101, 100, 32, 117, 110, 100, 101, 114, 32,
  116, 104, 101, 32, 67, 101, 67, 73, 76, 76, 32, 108, 105, 99, 101, 110,
  115, 101, 32, 40, 71, 80, 76, 45, 99, 111, 109, 112, 97, 116, 105, 98,
  108, 101, 41, 46, 32, 83, 105, 110, 99, 101, 32, 50, 48, 48, 56, 44,
  32, 105, 116, 32, 105, 115, 32, 100, 101, 118, 101, 108, 111, 112, 101, 100,
  32, 105, 110, 32, 116, 104, 101, 32, 73, 109, 97, 103, 101, 32, 84, 101,
  97, 109, 32, 111, 102, 32, 116, 104, 101, 32, 71, 82, 69, 89, 67, 32,
  108, 97, 98, 111, 114, 97, 116, 111, 114, 121, 44, 32, 105, 110, 32, 67,
  97, 101, 110, 47, 70, 114, 97, 110, 99, 101, 44, 32, 98, 121, 32, 112,
  101, 114, 109, 97, 110, 101, 110, 116, 32, 114, 101, 115, 101, 97, 114, 99,
  104, 101, 114, 115, 32, 119, 111, 114, 107, 105, 110, 103, 32, 105, 110, 32,
  116, 104, 101, 32, 102, 105, 101, 108, 100, 32, 111, 102, 32, 105, 109, 97,
  103, 101, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 111, 110,
  32, 97, 32, 100, 97, 105, 108, 121, 32, 98, 97, 115, 105, 115, 46, 10,
  92, 110, 92, 92, 115, 101, 99, 116, 105, 111, 110, 42, 123, 86, 101, 114,
  115, 105, 111, 110, 125, 10, 92, 110, 10, 92, 110, 32, 103, 109, 105, 99,
  58, 32, 71, 82, 69, 89, 67, 39, 115, 32, 77, 97, 103, 105, 99, 32,
  102, 111, 114, 32, 73, 109, 97, 103, 101, 32, 67, 111, 109, 112, 117, 116,
  105, 110, 103, 46, 10, 92, 110, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 32, 86, 101, 114, 115, 105, 111, 110, 32, 34, 36, 115, 116, 114, 118,
  101, 114, 36, 115, 116, 114, 98, 101, 116, 97, 34, 44, 32, 67, 111, 112,
  121, 114, 105, 103, 104, 116, 32, 40, 99, 41, 32, 50, 48, 48, 56, 45,
  50, 48, 49, 52, 44, 32, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104,
  117, 109, 112, 101, 114, 108, 92, 92, 39, 101, 10, 92, 110, 32, 32, 32,
  32, 32, 32, 32, 32, 40, 104, 116, 116, 112, 58, 47, 47, 103, 109, 105,
  99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101,
  116, 41, 10, 92, 110, 92, 92, 99, 104, 97, 112, 116, 101, 114, 123, 85,
  115, 97, 103, 101, 125, 10, 34, 10, 45, 118, 32, 45, 10, 95, 104, 101,
  108, 112, 95, 115, 101, 99, 116, 105, 111, 110, 95, 108, 97, 116, 101, 120,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36, 49, 34, 10, 45, 118,
  32, 43, 10, 45, 101, 91, 93, 32, 34, 92, 92, 115, 101, 99, 116, 105,
  111, 110, 123, 36, 49, 125, 34, 10, 45, 118, 32, 45, 10, 95, 104, 101,
  108, 112, 95, 112, 97, 114, 97, 103, 114, 97, 112, 104, 95, 108, 97, 116,
  101, 120, 32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36, 49, 34, 10,
  45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 34, 92, 92, 115, 109, 97,
  108, 108, 34, 10, 45, 101, 91, 93, 32, 34, 92, 92, 98, 101, 103, 105,
  110, 123, 108, 115, 116, 108, 105, 115, 116, 105, 110, 103, 125, 34, 10, 45,
  101, 91, 93, 32, 34, 36, 49, 34, 10, 45, 101, 91, 93, 32, 34, 92,
  92, 101, 110, 100, 123, 108, 115, 116, 108, 105, 115, 116, 105, 110, 103, 125,
  34, 10, 45, 101, 91, 93, 32, 34, 92, 92, 110, 111, 114, 109, 97, 108,
  115, 105, 122, 101, 34, 10, 45, 118, 32, 45, 10, 95, 104, 101, 108, 112,
  95, 102, 111, 111, 116, 101, 114, 95, 108, 97, 116, 101, 120, 32, 58, 10,
  45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 34, 10, 92, 110, 92, 92,
  112, 114, 105, 110, 116, 105, 110, 100, 101, 120, 10, 92, 110, 126, 92, 92,
  92, 92, 36, 92, 92, 115, 113, 117, 97, 114, 101, 36, 126, 69, 110, 100,
  32, 111, 102, 32, 100, 111, 99, 117, 109, 101, 110, 116, 46, 10, 92, 110,
  92, 110, 92, 92, 101, 110, 100, 123, 100, 111, 99, 117, 109, 101, 110, 116,
  125, 34, 10, 45, 118, 32, 45, 10, 95, 104, 101, 108, 112, 95, 104, 101,
  97, 100, 101, 114, 95, 104, 116, 109, 108, 32, 58, 10, 95, 115, 101, 99,
  116, 105, 111, 110, 61, 48, 10, 45, 105, 102, 32, 123, 110, 97, 114, 103,
  40, 36, 95, 103, 109, 105, 99, 95, 105, 115, 95, 98, 101, 116, 97, 41,
  125, 32, 115, 116, 114, 98, 101, 116, 97, 61, 34, 32, 40, 98, 101, 116,
  97, 41, 34, 32, 45, 101, 108, 115, 101, 32, 115, 116, 114, 98, 101, 116,
  97, 61, 34, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 110, 97, 114, 103, 40, 36, 95, 103, 109, 105, 99, 95, 118, 101, 114,
  115, 105, 111, 110, 41, 125, 32, 115, 116, 114, 118, 101, 114, 61, 36, 95,
  103, 109, 105, 99, 95, 118, 101, 114, 115, 105, 111, 110, 32, 45, 101, 108,
  115, 101, 32, 115, 116, 114, 118, 101, 114, 61, 64, 123, 45, 115, 116, 114,
  118, 101, 114, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43,
  10, 45, 101, 91, 93, 32, 34, 60, 33, 68, 79, 67, 84, 89, 80, 69,
  32, 104, 116, 109, 108, 32, 80, 85, 66, 76, 73, 67, 32, 92, 34, 45,
  47, 47, 87, 51, 67, 47, 47, 68, 84, 68, 32, 88, 72, 84, 77, 76,
  32, 49, 46, 48, 32, 84, 114, 97, 110, 115, 105, 116, 105, 111, 110, 97,
  108, 47, 47, 69, 78, 92, 34, 32, 92, 34, 104, 116, 116, 112, 58, 47,
  47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 84, 82, 47, 120,
  104, 116, 109, 108, 49, 47, 68, 84, 68, 47, 120, 104, 116, 109, 108, 49,
  45, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 97, 108, 46, 100, 116,
  100, 92, 34, 62, 10, 92, 110, 60, 33, 45, 45, 35, 105, 110, 99, 108,
  117, 100, 101, 32, 102, 105, 108, 101, 61, 92, 34, 104, 101, 97, 100, 101,
  114, 46, 104, 116, 109, 108, 92, 34, 32, 45, 45, 62, 10, 92, 110, 60,
  108, 105, 110, 107, 32, 104, 114, 101, 102, 61, 92, 34, 115, 116, 121, 108,
  101, 46, 99, 115, 115, 92, 34, 32, 114, 101, 108, 61, 92, 34, 115, 116,
  121, 108, 101, 115, 104, 101, 101, 116, 92, 34, 32, 116, 121, 112, 101, 61,
  92, 34, 116, 101, 120, 116, 47, 99, 115, 115, 92, 34, 62, 10, 92, 110,
  60, 100, 105, 118, 32, 105, 100, 61, 92, 34, 98, 108, 111, 99, 95, 111,
  112, 116, 105, 111, 110, 92, 34, 62, 10, 92, 110, 60, 100, 105, 118, 32,
  105, 100, 61, 92, 34, 116, 111, 112, 95, 114, 111, 117, 103, 101, 92, 34,
  62, 60, 100, 105, 118, 32, 105, 100, 61, 92, 34, 116, 101, 120, 116, 95,
  116, 111, 112, 92, 34, 62, 82, 101, 102, 101, 114, 101, 110, 99, 101, 60,
  47, 100, 105, 118, 62, 60, 47, 100, 105, 118, 62, 10, 92, 110, 60, 100,
  105, 118, 32, 105, 100, 61, 92, 34, 99, 101, 110, 116, 101, 114, 92, 34,
  62, 60, 100, 105, 118, 32, 105, 100, 61, 92, 34, 116, 101, 120, 116, 95,
  99, 101, 110, 116, 114, 101, 95, 105, 110, 116, 114, 111, 92, 34, 62, 10,
  92, 110, 60, 104, 50, 62, 60, 102, 111, 110, 116, 32, 99, 111, 108, 111,
  114, 61, 92, 34, 98, 114, 111, 119, 110, 92, 34, 62, 60, 117, 62, 80,
  114, 101, 97, 109, 98, 108, 101, 60, 47, 117, 62, 60, 47, 102, 111, 110,
  116, 62, 60, 47, 104, 50, 62, 10, 92, 110, 60, 117, 108, 62, 10, 92,
  110, 60, 108, 105, 62, 84, 104, 105, 115, 32, 100, 111, 99, 117, 109, 101,
  110, 116, 32, 105, 115, 32, 100, 105, 115, 116, 114, 105, 98, 117, 116, 101,
  100, 32, 117, 110, 100, 101, 114, 32, 116, 104, 101, 32, 60, 97, 32, 104,
  114, 101, 102, 61, 92, 34, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119,
  46, 103, 110, 117, 46, 111, 114, 103, 47, 108, 105, 99, 101, 110, 115, 101,
  115, 47, 102, 100, 108, 45, 49, 46, 51, 46, 116, 120, 116, 92, 34, 62,
  71, 78, 85, 32, 70, 114, 101, 101, 32, 68, 111, 99, 117, 109, 101, 110,
  116, 97, 116, 105, 111, 110, 32, 76, 105, 99, 101, 110, 115, 101, 60, 47,
  97, 62, 44, 32, 118, 101, 114, 115, 105, 111, 110, 32, 49, 46, 51, 46,
  60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 65, 32, 60, 97,
  32, 104, 114, 101, 102, 61, 92, 34, 103, 109, 105, 99, 95, 114, 101, 102,
  101, 114, 101, 110, 99, 101, 46, 112, 100, 102, 92, 34, 62, 46, 112, 100,
  102, 32, 118, 101, 114, 115, 105, 111, 110, 60, 47, 97, 62, 32, 111, 102,
  32, 116, 104, 105, 115, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 105,
  115, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 46, 60, 47, 108, 105,
  62, 10, 92, 110, 60, 108, 105, 62, 87, 101, 32, 97, 108, 115, 111, 32,
  115, 117, 103, 103, 101, 115, 116, 32, 121, 111, 117, 32, 114, 101, 97, 100,
  32, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 104, 116, 116, 112, 58,
  47, 47, 112, 97, 114, 116, 105, 99, 117, 108, 97, 114, 97, 114, 116, 46,
  99, 111, 109, 47, 116, 111, 111, 108, 115, 45, 97, 110, 100, 45, 116, 111,
  121, 115, 47, 103, 109, 105, 99, 47, 92, 34, 62, 116, 104, 105, 115, 32,
  112, 97, 103, 101, 60, 47, 97, 62, 44, 32, 119, 114, 105, 116, 116, 101,
  110, 32, 98, 121, 32, 60, 105, 62, 71, 97, 114, 121, 32, 79, 115, 103,
  111, 111, 100, 60, 47, 105, 62, 32, 119, 104, 111, 32, 112, 114, 111, 118,
  105, 100, 101, 115, 32, 97, 32, 118, 101, 114, 121, 32, 99, 108, 101, 97,
  114, 32, 97, 110, 100, 32, 117, 115, 101, 114, 45, 102, 114, 105, 101, 110,
  100, 108, 121, 32, 101, 120, 112, 108, 97, 110, 97, 116, 105, 111, 110, 32,
  111, 102, 32, 109, 111, 115, 116, 32, 111, 102, 32, 116, 104, 101, 32, 71,
  39, 77, 73, 67, 32, 98, 97, 115, 105, 99, 115, 46, 60, 47, 108, 105,
  62, 10, 92, 110, 60, 47, 117, 108, 62, 10, 92, 110, 60, 104, 50, 62,
  60, 97, 32, 105, 100, 61, 92, 34, 116, 111, 99, 92, 34, 62, 60, 102,
  111, 110, 116, 32, 99, 111, 108, 111, 114, 61, 92, 34, 98, 114, 111, 119,
  110, 92, 34, 62, 60, 117, 62, 84, 97, 98, 108, 101, 32, 111, 102, 32,
  99, 111, 110, 116, 101, 110, 116, 115, 60, 47, 117, 62, 60, 47, 102, 111,
  110, 116, 62, 60, 47, 97, 62, 60, 47, 104, 50, 62, 10, 92, 110, 60,
  117, 108, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101,
  102, 61, 92, 34, 35, 115, 101, 99, 116, 105, 111, 110, 48, 92, 34, 62,
  86, 101, 114, 115, 105, 111, 110, 60, 47, 97, 62, 60, 47, 108, 105, 62,
  10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92,
  34, 35, 115, 101, 99, 116, 105, 111, 110, 49, 92, 34, 62, 85, 115, 97,
  103, 101, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 117,
  108, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102,
  61, 92, 34, 35, 115, 101, 99, 116, 105, 111, 110, 50, 92, 34, 62, 79,
  118, 101, 114, 97, 108, 108, 32, 99, 111, 110, 116, 101, 120, 116, 60, 47,
  97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97,
  32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 101, 99, 116, 105, 111, 110,
  51, 92, 34, 62, 73, 109, 97, 103, 101, 32, 100, 101, 102, 105, 110, 105,
  116, 105, 111, 110, 32, 97, 110, 100, 32, 116, 101, 114, 109, 105, 110, 111,
  108, 111, 103, 121, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110,
  60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115,
  101, 99, 116, 105, 111, 110, 52, 92, 34, 62, 73, 116, 101, 109, 115, 32,
  111, 102, 32, 97, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32,
  112, 105, 112, 101, 108, 105, 110, 101, 60, 47, 97, 62, 60, 47, 108, 105,
  62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61,
  92, 34, 35, 115, 101, 99, 116, 105, 111, 110, 53, 92, 34, 62, 73, 110,
  112, 117, 116, 32, 100, 97, 116, 97, 32, 105, 116, 101, 109, 115, 60, 47,
  97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97,
  32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 101, 99, 116, 105, 111, 110,
  54, 92, 34, 62, 67, 111, 109, 109, 97, 110, 100, 32, 105, 116, 101, 109,
  115, 32, 97, 110, 100, 32, 115, 101, 108, 101, 99, 116, 105, 111, 110, 115,
  60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62,
  60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 101, 99, 116, 105,
  111, 110, 55, 92, 34, 62, 73, 110, 112, 117, 116, 47, 111, 117, 116, 112,
  117, 116, 32, 112, 114, 111, 112, 101, 114, 116, 105, 101, 115, 60, 47, 97,
  62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32,
  104, 114, 101, 102, 61, 92, 34, 35, 115, 101, 99, 116, 105, 111, 110, 56,
  92, 34, 62, 83, 117, 98, 115, 116, 105, 116, 117, 116, 105, 111, 110, 32,
  114, 117, 108, 101, 115, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92,
  110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35,
  115, 101, 99, 116, 105, 111, 110, 57, 92, 34, 62, 77, 97, 116, 104, 101,
  109, 97, 116, 105, 99, 97, 108, 32, 101, 120, 112, 114, 101, 115, 115, 105,
  111, 110, 115, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60,
  108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 101,
  99, 116, 105, 111, 110, 49, 48, 92, 34, 62, 73, 109, 97, 103, 101, 32,
  97, 110, 100, 32, 100, 97, 116, 97, 32, 118, 105, 101, 119, 101, 114, 115,
  60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62,
  60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 101, 99, 116, 105,
  111, 110, 49, 49, 92, 34, 62, 65, 100, 100, 105, 110, 103, 32, 99, 117,
  115, 116, 111, 109, 32, 99, 111, 109, 109, 97, 110, 100, 115, 60, 47, 97,
  62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 47, 117, 108, 62, 10, 92,
  110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35,
  115, 101, 99, 116, 105, 111, 110, 49, 50, 92, 34, 62, 76, 105, 115, 116,
  32, 111, 102, 32, 99, 111, 109, 109, 97, 110, 100, 115, 60, 47, 97, 62,
  60, 47, 108, 105, 62, 10, 92, 110, 60, 117, 108, 62, 10, 92, 110, 60,
  108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 117,
  98, 115, 101, 99, 116, 105, 111, 110, 49, 92, 34, 62, 71, 108, 111, 98,
  97, 108, 32, 111, 112, 116, 105, 111, 110, 115, 60, 47, 97, 62, 60, 47,
  108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101,
  102, 61, 92, 34, 35, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 50,
  92, 34, 62, 73, 110, 112, 117, 116, 115, 47, 111, 117, 116, 112, 117, 116,
  115, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105,
  62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 117, 98, 115,
  101, 99, 116, 105, 111, 110, 51, 92, 34, 62, 76, 105, 115, 116, 32, 109,
  97, 110, 105, 112, 117, 108, 97, 116, 105, 111, 110, 60, 47, 97, 62, 60,
  47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114,
  101, 102, 61, 92, 34, 35, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110,
  52, 92, 34, 62, 77, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108,
  32, 111, 112, 101, 114, 97, 116, 111, 114, 115, 60, 47, 97, 62, 60, 47,
  108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101,
  102, 61, 92, 34, 35, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 53,
  92, 34, 62, 86, 97, 108, 117, 101, 115, 32, 109, 97, 110, 105, 112, 117,
  108, 97, 116, 105, 111, 110, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10,
  92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34,
  35, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 54, 92, 34, 62, 67,
  111, 108, 111, 114, 115, 32, 109, 97, 110, 105, 112, 117, 108, 97, 116, 105,
  111, 110, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108,
  105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 117, 98,
  115, 101, 99, 116, 105, 111, 110, 55, 92, 34, 62, 71, 101, 111, 109, 101,
  116, 114, 121, 32, 109, 97, 110, 105, 112, 117, 108, 97, 116, 105, 111, 110,
  60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62,
  60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 117, 98, 115, 101,
  99, 116, 105, 111, 110, 56, 92, 34, 62, 70, 105, 108, 116, 101, 114, 105,
  110, 103, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108,
  105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 117, 98,
  115, 101, 99, 116, 105, 111, 110, 57, 92, 34, 62, 70, 101, 97, 116, 117,
  114, 101, 115, 32, 101, 120, 116, 114, 97, 99, 116, 105, 111, 110, 60, 47,
  97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97,
  32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 117, 98, 115, 101, 99, 116,
  105, 111, 110, 49, 48, 92, 34, 62, 73, 109, 97, 103, 101, 32, 100, 114,
  97, 119, 105, 110, 103, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92,
  110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35,
  115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 49, 49, 92, 34, 62, 77,
  97, 116, 114, 105, 120, 32, 99, 111, 109, 112, 117, 116, 97, 116, 105, 111,
  110, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105,
  62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 117, 98, 115,
  101, 99, 116, 105, 111, 110, 49, 50, 92, 34, 62, 51, 100, 32, 114, 101,
  110, 100, 101, 114, 105, 110, 103, 60, 47, 97, 62, 60, 47, 108, 105, 62,
  10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92,
  34, 35, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 49, 51, 92, 34,
  62, 80, 114, 111, 103, 114, 97, 109, 32, 99, 111, 110, 116, 114, 111, 108,
  115, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105,
  62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 117, 98, 115,
  101, 99, 116, 105, 111, 110, 49, 52, 92, 34, 62, 65, 114, 114, 97, 121,
  115, 44, 116, 105, 108, 101, 115, 32, 97, 110, 100, 32, 102, 114, 97, 109,
  101, 115, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108,
  105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 117, 98,
  115, 101, 99, 116, 105, 111, 110, 49, 53, 92, 34, 62, 65, 114, 116, 105,
  115, 116, 105, 99, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110,
  60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115,
  117, 98, 115, 101, 99, 116, 105, 111, 110, 49, 54, 92, 34, 62, 87, 97,
  114, 112, 105, 110, 103, 115, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10,
  92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34,
  35, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 49, 55, 92, 34, 62,
  68, 101, 103, 114, 97, 100, 97, 116, 105, 111, 110, 115, 60, 47, 97, 62,
  60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104,
  114, 101, 102, 61, 92, 34, 35, 115, 117, 98, 115, 101, 99, 116, 105, 111,
  110, 49, 56, 92, 34, 62, 66, 108, 101, 110, 100, 105, 110, 103, 32, 97,
  110, 100, 32, 102, 97, 100, 105, 110, 103, 60, 47, 97, 62, 60, 47, 108,
  105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104, 114, 101, 102,
  61, 92, 34, 35, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 49, 57,
  92, 34, 62, 73, 109, 97, 103, 101, 32, 115, 101, 113, 117, 101, 110, 99,
  101, 115, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108,
  105, 62, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 117, 98,
  115, 101, 99, 116, 105, 111, 110, 50, 48, 92, 34, 62, 73, 110, 116, 101,
  114, 97, 99, 116, 105, 118, 101, 32, 100, 101, 109, 111, 115, 60, 47, 97,
  62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32,
  104, 114, 101, 102, 61, 92, 34, 35, 115, 117, 98, 115, 101, 99, 116, 105,
  111, 110, 50, 49, 92, 34, 62, 80, 73, 78, 75, 45, 108, 105, 98, 114,
  97, 114, 121, 32, 111, 112, 101, 114, 97, 116, 111, 114, 115, 60, 47, 97,
  62, 60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32,
  104, 114, 101, 102, 61, 92, 34, 35, 115, 117, 98, 115, 101, 99, 116, 105,
  111, 110, 50, 50, 92, 34, 62, 67, 111, 110, 118, 101, 110, 105, 101, 110,
  99, 101, 32, 102, 117, 110, 99, 116, 105, 111, 110, 115, 60, 47, 97, 62,
  60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104,
  114, 101, 102, 61, 92, 34, 35, 115, 117, 98, 115, 101, 99, 116, 105, 111,
  110, 50, 51, 92, 34, 62, 79, 116, 104, 101, 114, 115, 60, 47, 97, 62,
  60, 47, 108, 105, 62, 10, 92, 110, 60, 108, 105, 62, 60, 97, 32, 104,
  114, 101, 102, 61, 92, 34, 35, 115, 117, 98, 115, 101, 99, 116, 105, 111,
  110, 50, 52, 92, 34, 62, 67, 111, 109, 109, 97, 110, 100, 115, 32, 115,
  104, 111, 114, 116, 99, 117, 116, 115, 60, 47, 97, 62, 60, 47, 108, 105,
  62, 10, 92, 110, 60, 47, 117, 108, 62, 10, 92, 110, 60, 108, 105, 62,
  60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 115, 101, 99, 116, 105,
  111, 110, 49, 51, 92, 34, 62, 69, 120, 97, 109, 112, 108, 101, 115, 32,
  111, 102, 32, 117, 115, 101, 60, 47, 97, 62, 60, 47, 108, 105, 62, 10,
  92, 110, 60, 47, 117, 108, 62, 10, 92, 110, 60, 97, 32, 105, 100, 61,
  92, 34, 115, 101, 99, 116, 105, 111, 110, 48, 92, 34, 62, 60, 104, 50,
  62, 60, 102, 111, 110, 116, 32, 99, 111, 108, 111, 114, 61, 92, 34, 98,
  114, 111, 119, 110, 92, 34, 62, 60, 117, 62, 86, 101, 114, 115, 105, 111,
  110, 60, 47, 117, 62, 60, 47, 102, 111, 110, 116, 62, 60, 47, 104, 50,
  62, 60, 47, 97, 62, 10, 92, 110, 60, 112, 114, 101, 62, 60, 102, 111,
  110, 116, 32, 99, 111, 108, 111, 114, 61, 92, 34, 98, 108, 117, 101, 92,
  34, 62, 103, 109, 105, 99, 60, 47, 102, 111, 110, 116, 62, 58, 32, 71,
  82, 69, 89, 67, 39, 115, 32, 77, 97, 103, 105, 99, 32, 102, 111, 114,
  32, 73, 109, 97, 103, 101, 32, 67, 111, 109, 112, 117, 116, 105, 110, 103,
  46, 10, 92, 110, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 86, 101,
  114, 115, 105, 111, 110, 32, 34, 36, 115, 116, 114, 118, 101, 114, 36, 115,
  116, 114, 98, 101, 116, 97, 34, 44, 32, 67, 111, 112, 121, 114, 105, 103,
  104, 116, 32, 40, 99, 41, 32, 50, 48, 48, 56, 45, 50, 48, 49, 52,
  44, 32, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101,
  114, 108, 101, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 40, 60, 97,
  32, 104, 114, 101, 102, 61, 92, 34, 104, 116, 116, 112, 58, 47, 47, 103,
  109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46,
  110, 101, 116, 92, 34, 62, 104, 116, 116, 112, 58, 47, 47, 103, 109, 105,
  99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101,
  116, 60, 47, 97, 62, 41, 10, 92, 110, 60, 47, 112, 114, 101, 62, 10,
  34, 10, 45, 118, 32, 45, 10, 45, 95, 104, 101, 108, 112, 95, 115, 101,
  99, 116, 105, 111, 110, 32, 34, 85, 115, 97, 103, 101, 34, 10, 95, 104,
  101, 108, 112, 95, 115, 101, 99, 116, 105, 111, 110, 95, 104, 116, 109, 108,
  32, 58, 10, 95, 115, 101, 99, 116, 105, 111, 110, 61, 123, 36, 95, 115,
  101, 99, 116, 105, 111, 110, 43, 49, 125, 10, 45, 118, 32, 43, 10, 45,
  101, 91, 93, 32, 34, 60, 104, 50, 62, 60, 97, 32, 105, 100, 61, 92,
  34, 115, 101, 99, 116, 105, 111, 110, 34, 36, 95, 115, 101, 99, 116, 105,
  111, 110, 34, 92, 34, 62, 60, 102, 111, 110, 116, 32, 99, 111, 108, 111,
  114, 61, 92, 34, 98, 114, 111, 119, 110, 92, 34, 62, 60, 117, 62, 36,
  49, 60, 47, 117, 62, 60, 47, 102, 111, 110, 116, 62, 60, 47, 97, 62,
  34, 92, 10, 34, 38, 110, 98, 115, 112, 59, 38, 110, 98, 115, 112, 59,
  60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 116, 111, 99, 92, 34,
  62, 60, 105, 109, 103, 32, 115, 114, 99, 61, 92, 34, 105, 109, 103, 47,
  98, 97, 99, 107, 95, 116, 111, 112, 46, 112, 110, 103, 92, 34, 62, 60,
  47, 105, 109, 103, 62, 60, 47, 97, 62, 60, 47, 104, 50, 62, 34, 10,
  45, 118, 32, 45, 10, 95, 104, 101, 108, 112, 95, 112, 97, 114, 97, 103,
  114, 97, 112, 104, 95, 104, 116, 109, 108, 32, 58, 10, 45, 118, 32, 43,
  10, 45, 101, 91, 93, 32, 34, 60, 112, 114, 101, 62, 36, 42, 60, 47,
  112, 114, 101, 62, 34, 10, 45, 118, 32, 45, 10, 95, 104, 101, 108, 112,
  95, 102, 111, 111, 116, 101, 114, 95, 104, 116, 109, 108, 32, 58, 10, 45,
  118, 32, 43, 10, 45, 101, 91, 93, 32, 34, 10, 92, 110, 60, 98, 114,
  47, 62, 60, 98, 62, 60, 102, 111, 110, 116, 32, 99, 111, 108, 111, 114,
  61, 92, 34, 98, 114, 111, 119, 110, 92, 34, 62, 42, 42, 32, 71, 39,
  77, 73, 67, 32, 99, 111, 109, 101, 115, 32, 119, 105, 116, 104, 32, 65,
  66, 83, 79, 76, 85, 84, 69, 76, 89, 32, 78, 79, 32, 87, 65, 82,
  82, 65, 78, 84, 89, 59, 32, 102, 111, 114, 32, 100, 101, 116, 97, 105,
  108, 115, 32, 118, 105, 115, 105, 116, 32, 60, 97, 32, 104, 114, 101, 102,
  61, 92, 34, 104, 116, 116, 112, 58, 47, 47, 103, 109, 105, 99, 46, 115,
  111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 92, 34,
  62, 104, 116, 116, 112, 58, 47, 47, 103, 109, 105, 99, 46, 115, 111, 117,
  114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 32, 42, 42, 60,
  47, 97, 62, 60, 47, 102, 111, 110, 116, 62, 60, 47, 98, 62, 10, 92,
  110, 60, 47, 116, 116, 62, 10, 92, 110, 60, 47, 100, 105, 118, 62, 10,
  92, 110, 60, 47, 100, 105, 118, 62, 10, 92, 110, 60, 100, 105, 118, 32,
  105, 100, 61, 92, 34, 102, 111, 111, 116, 101, 114, 92, 34, 62, 60, 105,
  109, 103, 32, 115, 114, 99, 61, 92, 34, 105, 109, 97, 103, 101, 115, 47,
  102, 111, 111, 116, 101, 114, 46, 106, 112, 103, 92, 34, 32, 47, 62, 60,
  47, 100, 105, 118, 62, 10, 92, 110, 60, 47, 100, 105, 118, 62, 10, 92,
  110, 60, 33, 45, 45, 35, 105, 110, 99, 108, 117, 100, 101, 32, 102, 105,
  108, 101, 61, 92, 34, 99, 111, 112, 121, 114, 105, 103, 104, 116, 46, 104,
  116, 109, 108, 92, 34, 32, 45, 45, 62, 10, 92, 110, 60, 33, 45, 45,
  35, 105, 110, 99, 108, 117, 100, 101, 32, 102, 105, 108, 101, 61, 92, 34,
  102, 111, 111, 116, 101, 114, 46, 104, 116, 109, 108, 92, 34, 32, 45, 45,
  62, 10, 34, 10, 45, 118, 32, 45, 10, 95, 104, 101, 108, 112, 95, 104,
  101, 97, 100, 101, 114, 95, 97, 115, 99, 105, 105, 32, 58, 10, 45, 95,
  95, 104, 101, 108, 112, 95, 104, 101, 97, 100, 101, 114, 95, 97, 115, 99,
  105, 105, 10, 95, 115, 101, 99, 116, 105, 111, 110, 61, 48, 32, 95, 115,
  112, 97, 99, 101, 49, 61, 34, 34, 32, 95, 115, 112, 97, 99, 101, 50,
  61, 34, 32, 34, 10, 45, 95, 104, 101, 108, 112, 95, 115, 101, 99, 116,
  105, 111, 110, 32, 34, 85, 115, 97, 103, 101, 34, 10, 95, 95, 104, 101,
  108, 112, 95, 104, 101, 97, 100, 101, 114, 95, 97, 115, 99, 105, 105, 32,
  58, 10, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40, 36, 95, 103, 109,
  105, 99, 95, 105, 115, 95, 98, 101, 116, 97, 41, 125, 32, 115, 116, 114,
  98, 101, 116, 97, 61, 34, 32, 40, 98, 101, 116, 97, 41, 34, 32, 45,
  101, 108, 115, 101, 32, 115, 116, 114, 98, 101, 116, 97, 61, 34, 34, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 110, 97, 114, 103,
  40, 36, 95, 103, 109, 105, 99, 95, 118, 101, 114, 115, 105, 111, 110, 41,
  125, 32, 115, 116, 114, 118, 101, 114, 61, 36, 95, 103, 109, 105, 99, 95,
  118, 101, 114, 115, 105, 111, 110, 32, 45, 101, 108, 115, 101, 32, 115, 116,
  114, 118, 101, 114, 61, 64, 123, 45, 115, 116, 114, 118, 101, 114, 125, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 45, 101, 91, 93,
  32, 34, 10, 92, 110, 32, 103, 109, 105, 99, 58, 32, 71, 82, 69, 89,
  67, 39, 115, 32, 77, 97, 103, 105, 99, 32, 102, 111, 114, 32, 73, 109,
  97, 103, 101, 32, 67, 111, 109, 112, 117, 116, 105, 110, 103, 46, 10, 92,
  110, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 86, 101, 114, 115,
  105, 111, 110, 32, 34, 36, 115, 116, 114, 118, 101, 114, 36, 115, 116, 114,
  98, 101, 116, 97, 34, 44, 32, 67, 111, 112, 121, 114, 105, 103, 104, 116,
  32, 40, 99, 41, 32, 50, 48, 48, 56, 45, 50, 48, 49, 52, 44, 32,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  101, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 40, 104, 116,
  116, 112, 58, 47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101,
  102, 111, 114, 103, 101, 46, 110, 101, 116, 41, 34, 10, 45, 118, 32, 45,
  10, 95, 104, 101, 108, 112, 95, 115, 101, 99, 116, 105, 111, 110, 95, 97,
  115, 99, 105, 105, 32, 58, 10, 95, 115, 101, 99, 116, 105, 111, 110, 61,
  123, 36, 95, 115, 101, 99, 116, 105, 111, 110, 43, 49, 125, 10, 123, 110,
  97, 114, 103, 40, 123, 39, 34, 36, 49, 34, 39, 125, 41, 125, 44, 49,
  44, 49, 44, 49, 44, 123, 39, 45, 39, 125, 10, 45, 118, 32, 43, 10,
  45, 101, 91, 93, 32, 34, 92, 110, 32, 34, 36, 95, 115, 101, 99, 116,
  105, 111, 110, 34, 46, 32, 36, 49, 34, 10, 45, 101, 91, 93, 32, 34,
  32, 32, 32, 32, 34, 36, 123, 95, 115, 112, 97, 99, 101, 123, 110, 97,
  114, 103, 40, 123, 39, 36, 95, 115, 101, 99, 116, 105, 111, 110, 39, 125,
  41, 125, 125, 64, 123, 45, 49, 44, 116, 125, 34, 92, 110, 34, 10, 45,
  118, 32, 45, 10, 45, 114, 109, 91, 45, 49, 93, 10, 95, 104, 101, 108,
  112, 95, 112, 97, 114, 97, 103, 114, 97, 112, 104, 95, 97, 115, 99, 105,
  105, 32, 58, 10, 45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 34, 36,
  42, 34, 10, 45, 118, 32, 45, 10, 95, 104, 101, 108, 112, 95, 102, 111,
  111, 116, 101, 114, 95, 97, 115, 99, 105, 105, 32, 58, 10, 45, 118, 32,
  43, 10, 45, 101, 91, 93, 32, 34, 32, 42, 42, 32, 71, 39, 77, 73,
  67, 32, 99, 111, 109, 101, 115, 32, 119, 105, 116, 104, 32, 65, 66, 83,
  79, 76, 85, 84, 69, 76, 89, 32, 78, 79, 32, 87, 65, 82, 82, 65,
  78, 84, 89, 59, 32, 102, 111, 114, 32, 100, 101, 116, 97, 105, 108, 115,
  32, 118, 105, 115, 105, 116, 32, 104, 116, 116, 112, 58, 47, 47, 103, 109,
  105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110,
  101, 116, 32, 42, 42, 34, 10, 45, 118, 32, 45, 10, 95, 104, 101, 108,
  112, 95, 117, 115, 97, 103, 101, 32, 58, 10, 45, 95, 104, 101, 108, 112,
  95, 112, 97, 114, 97, 103, 114, 97, 112, 104, 32, 34, 32, 103, 109, 105,
  99, 32, 91, 99, 111, 109, 109, 97, 110, 100, 49, 32, 91, 97, 114, 103,
  49, 95, 49, 44, 97, 114, 103, 49, 95, 50, 44, 46, 46, 93, 93, 32,
  46, 46, 32, 91, 99, 111, 109, 109, 97, 110, 100, 78, 32, 91, 97, 114,
  103, 78, 95, 49, 44, 97, 114, 103, 78, 95, 50, 44, 46, 46, 93, 93,
  10, 92, 110, 10, 92, 110, 32, 39, 103, 109, 105, 99, 39, 32, 105, 115,
  32, 97, 110, 32, 111, 112, 101, 110, 45, 115, 111, 117, 114, 99, 101, 32,
  105, 110, 116, 101, 114, 112, 114, 101, 116, 101, 114, 32, 111, 102, 32, 116,
  104, 101, 32, 71, 39, 77, 73, 67, 32, 108, 97, 110, 103, 117, 97, 103,
  101, 44, 32, 97, 32, 115, 99, 114, 105, 112, 116, 45, 98, 97, 115, 101,
  100, 32, 112, 114, 111, 103, 114, 97, 109, 109, 105, 110, 103, 10, 92, 110,
  32, 32, 108, 97, 110, 103, 117, 97, 103, 101, 32, 100, 101, 100, 105, 99,
  97, 116, 101, 100, 32, 116, 111, 32, 100, 101, 115, 105, 103, 110, 32, 105,
  109, 97, 103, 101, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32,
  112, 105, 112, 101, 108, 105, 110, 101, 115, 46, 32, 73, 116, 32, 99, 97,
  110, 32, 98, 101, 32, 117, 115, 101, 100, 32, 116, 111, 32, 99, 111, 110,
  118, 101, 114, 116, 44, 10, 92, 110, 32, 32, 109, 97, 110, 105, 112, 117,
  108, 97, 116, 101, 44, 32, 102, 105, 108, 116, 101, 114, 32, 97, 110, 100,
  32, 118, 105, 115, 117, 97, 108, 105, 122, 101, 32, 100, 97, 116, 97, 115,
  101, 116, 115, 32, 109, 97, 100, 101, 32, 111, 102, 32, 111, 110, 101, 32,
  111, 114, 32, 115, 101, 118, 101, 114, 97, 108, 32, 49, 100, 47, 50, 100,
  32, 111, 114, 32, 51, 100, 32, 109, 117, 108, 116, 105, 45, 10, 92, 110,
  32, 32, 115, 112, 101, 99, 116, 114, 97, 108, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 92, 110, 10, 92, 110, 32, 84, 104, 105, 115, 32, 100, 111,
  99, 117, 109, 101, 110, 116, 97, 116, 105, 111, 110, 32, 112, 114, 111, 112,
  111, 115, 101, 115, 32, 97, 32, 99, 111, 109, 112, 108, 101, 116, 101, 32,
  100, 101, 115, 99, 114, 105, 112, 116, 105, 111, 110, 32, 111, 102, 32, 116,
  104, 101, 32, 71, 39, 77, 73, 67, 32, 108, 97, 110, 103, 117, 97, 103,
  101, 32, 98, 97, 115, 105, 99, 115, 32, 97, 110, 100, 32, 114, 117, 108,
  101, 115, 46, 34, 10, 45, 95, 104, 101, 108, 112, 95, 115, 101, 99, 116,
  105, 111, 110, 32, 34, 79, 118, 101, 114, 97, 108, 108, 32, 99, 111, 110,
  116, 101, 120, 116, 34, 10, 45, 95, 104, 101, 108, 112, 95, 112, 97, 114,
  97, 103, 114, 97, 112, 104, 32, 34, 32, 32, 45, 32, 65, 116, 32, 97,
  110, 121, 32, 116, 105, 109, 101, 44, 32, 71, 39, 77, 73, 67, 32, 109,
  97, 110, 97, 103, 101, 115, 32, 111, 110, 101, 32, 108, 105, 115, 116, 32,
  111, 102, 32, 110, 117, 109, 98, 101, 114, 101, 100, 32, 40, 97, 110, 100,
  32, 111, 112, 116, 105, 111, 110, 97, 108, 108, 121, 32, 110, 97, 109, 101,
  100, 41, 32, 112, 105, 120, 101, 108, 45, 98, 97, 115, 101, 100, 10, 92,
  110, 32, 32, 32, 32, 32, 105, 109, 97, 103, 101, 115, 44, 32, 101, 110,
  116, 105, 114, 101, 108, 121, 32, 115, 116, 111, 114, 101, 100, 32, 105, 110,
  32, 99, 111, 109, 112, 117, 116, 101, 114, 32, 109, 101, 109, 111, 114, 121,
  46, 10, 92, 110, 32, 32, 45, 32, 84, 104, 101, 32, 102, 105, 114, 115,
  116, 32, 105, 109, 97, 103, 101, 32, 111, 102, 32, 116, 104, 101, 32, 108,
  105, 115, 116, 32, 104, 97, 115, 32, 105, 110, 100, 105, 99, 101, 32, 39,
  48, 39, 32, 97, 110, 100, 32, 105, 115, 32, 100, 101, 110, 111, 116, 101,
  100, 32, 98, 121, 32, 39, 91, 48, 93, 39, 46, 32, 84, 104, 101, 32,
  115, 101, 99, 111, 110, 100, 32, 105, 109, 97, 103, 101, 32, 111, 102, 10,
  92, 110, 32, 32, 32, 32, 32, 116, 104, 101, 32, 108, 105, 115, 116, 32,
  105, 115, 32, 100, 101, 110, 111, 116, 101, 100, 32, 98, 121, 32, 39, 91,
  49, 93, 39, 44, 32, 116, 104, 101, 32, 116, 104, 105, 114, 100, 32, 98,
  121, 32, 39, 91, 50, 93, 39, 32, 97, 110, 100, 32, 115, 111, 32, 111,
  110, 46, 10, 92, 110, 32, 32, 45, 32, 78, 101, 103, 97, 116, 105, 118,
  101, 32, 105, 110, 100, 105, 99, 101, 115, 32, 97, 114, 101, 32, 116, 114,
  101, 97, 116, 101, 100, 32, 105, 110, 32, 97, 32, 99, 121, 99, 108, 105,
  99, 32, 119, 97, 121, 58, 32, 39, 91, 45, 49, 93, 39, 32, 114, 101,
  102, 101, 114, 115, 32, 116, 111, 32, 116, 104, 101, 32, 108, 97, 115, 116,
  32, 105, 109, 97, 103, 101, 32, 111, 102, 32, 116, 104, 101, 10, 92, 110,
  32, 32, 32, 32, 32, 108, 105, 115, 116, 44, 32, 39, 91, 45, 50, 93,
  39, 32, 116, 111, 32, 116, 104, 101, 32, 112, 101, 110, 117, 108, 116, 105,
  109, 97, 116, 101, 32, 111, 110, 101, 44, 32, 101, 116, 99, 46, 32, 84,
  104, 117, 115, 44, 32, 105, 102, 32, 116, 104, 101, 32, 108, 105, 115, 116,
  32, 104, 97, 115, 32, 52, 32, 105, 109, 97, 103, 101, 115, 44, 32, 39,
  91, 49, 93, 39, 32, 97, 110, 100, 32, 39, 91, 45, 51, 93, 39, 10,
  92, 110, 32, 32, 32, 32, 32, 98, 111, 116, 104, 32, 100, 101, 115, 105,
  103, 110, 97, 116, 101, 32, 116, 104, 101, 32, 115, 101, 99, 111, 110, 100,
  32, 105, 109, 97, 103, 101, 32, 111, 102, 32, 116, 104, 101, 32, 108, 105,
  115, 116, 46, 10, 92, 110, 32, 32, 45, 32, 65, 32, 110, 97, 109, 101,
  100, 32, 105, 109, 97, 103, 101, 32, 109, 97, 121, 32, 98, 101, 32, 100,
  101, 110, 111, 116, 101, 100, 32, 98, 121, 32, 39, 91, 110, 97, 109, 101,
  93, 39, 32, 105, 102, 32, 39, 110, 97, 109, 101, 39, 32, 117, 115, 101,
  115, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 115, 32, 115, 101, 116,
  32, 91, 97, 45, 122, 65, 45, 90, 48, 45, 57, 95, 93, 32, 97, 110,
  100, 10, 92, 110, 32, 32, 32, 32, 32, 100, 111, 101, 115, 32, 110, 111,
  116, 32, 115, 116, 97, 114, 116, 32, 119, 105, 116, 104, 32, 97, 32, 110,
  117, 109, 98, 101, 114, 46, 32, 73, 109, 97, 103, 101, 32, 110, 97, 109,
  101, 115, 32, 99, 97, 110, 32, 98, 101, 32, 115, 101, 116, 32, 111, 114,
  32, 114, 101, 97, 115, 115, 105, 103, 110, 101, 100, 32, 97, 116, 32, 97,
  110, 121, 32, 109, 111, 109, 101, 110, 116, 32, 100, 117, 114, 105, 110, 103,
  10, 92, 110, 32, 32, 32, 32, 32, 116, 104, 101, 32, 112, 114, 111, 99,
  101, 115, 115, 105, 110, 103, 32, 112, 105, 112, 101, 108, 105, 110, 101, 32,
  40, 115, 101, 101, 32, 99, 111, 109, 109, 97, 110, 100, 115, 32, 39, 45,
  110, 97, 109, 101, 39, 32, 97, 110, 100, 32, 39, 45, 105, 110, 112, 117,
  116, 39, 41, 46, 10, 92, 110, 32, 32, 45, 32, 71, 39, 77, 73, 67,
  32, 100, 101, 102, 105, 110, 101, 115, 32, 97, 32, 115, 101, 116, 32, 111,
  102, 32, 118, 97, 114, 105, 111, 117, 115, 32, 99, 111, 109, 109, 97, 110,
  100, 115, 32, 97, 110, 100, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116,
  105, 111, 110, 32, 109, 101, 99, 104, 97, 110, 105, 115, 109, 115, 32, 116,
  111, 32, 97, 108, 108, 111, 119, 32, 116, 104, 101, 32, 100, 101, 115, 105,
  103, 110, 10, 92, 110, 32, 32, 32, 32, 32, 111, 102, 32, 99, 111, 109,
  112, 108, 101, 120, 32, 112, 105, 112, 101, 108, 105, 110, 101, 115, 32, 109,
  97, 110, 97, 103, 105, 110, 103, 32, 116, 104, 105, 115, 32, 108, 105, 115,
  116, 32, 111, 102, 32, 105, 109, 97, 103, 101, 115, 44, 32, 105, 110, 32,
  97, 32, 118, 101, 114, 121, 32, 102, 108, 101, 120, 105, 98, 108, 101, 32,
  119, 97, 121, 58, 10, 92, 110, 32, 32, 32, 32, 32, 89, 111, 117, 32,
  99, 97, 110, 32, 105, 110, 115, 101, 114, 116, 32, 111, 114, 32, 114, 101,
  109, 111, 118, 101, 32, 105, 109, 97, 103, 101, 115, 32, 105, 110, 32, 116,
  104, 101, 32, 108, 105, 115, 116, 44, 32, 114, 101, 97, 114, 114, 97, 110,
  103, 101, 32, 105, 109, 97, 103, 101, 32, 105, 110, 100, 105, 99, 101, 115,
  44, 32, 112, 114, 111, 99, 101, 115, 115, 32, 105, 109, 97, 103, 101, 115,
  10, 92, 110, 32, 32, 32, 32, 32, 40, 105, 110, 100, 105, 118, 105, 100,
  117, 97, 108, 108, 121, 32, 111, 114, 32, 97, 115, 32, 97, 32, 103, 114,
  111, 117, 112, 41, 44, 32, 109, 101, 114, 103, 101, 32, 105, 109, 97, 103,
  101, 32, 100, 97, 116, 97, 32, 116, 111, 103, 101, 116, 104, 101, 114, 32,
  97, 110, 100, 32, 111, 117, 116, 112, 117, 116, 32, 105, 109, 97, 103, 101,
  32, 102, 105, 108, 101, 115, 46, 10, 92, 110, 32, 32, 45, 32, 83, 117,
  99, 104, 32, 97, 32, 112, 105, 112, 101, 108, 105, 110, 101, 32, 99, 97,
  110, 32, 98, 101, 32, 119, 114, 105, 116, 116, 101, 110, 32, 105, 116, 115,
  101, 108, 102, 32, 97, 115, 32, 97, 32, 99, 117, 115, 116, 111, 109, 32,
  71, 39, 77, 73, 67, 32, 99, 111, 109, 109, 97, 110, 100, 32, 115, 116,
  111, 114, 97, 98, 108, 101, 32, 105, 110, 32, 97, 32, 99, 117, 115, 116,
  111, 109, 10, 92, 110, 32, 32, 32, 32, 32, 99, 111, 109, 109, 97, 110,
  100, 115, 32, 102, 105, 108, 101, 44, 32, 119, 104, 105, 99, 104, 32, 99,
  97, 110, 32, 98, 101, 32, 114, 101, 45, 117, 115, 101, 100, 32, 97, 102,
  116, 101, 114, 119, 97, 114, 100, 115, 32, 105, 110, 32, 97, 110, 111, 116,
  104, 101, 114, 32, 98, 105, 103, 103, 101, 114, 32, 112, 105, 112, 101, 108,
  105, 110, 101, 32, 105, 102, 32, 110, 101, 99, 101, 115, 115, 97, 114, 121,
  46, 34, 10, 45, 95, 104, 101, 108, 112, 95, 115, 101, 99, 116, 105, 111,
  110, 32, 34, 73, 109, 97, 103, 101, 32, 100, 101, 102, 105, 110, 105, 116,
  105, 111, 110, 32, 97, 110, 100, 32, 116, 101, 114, 109, 105, 110, 111, 108,
  111, 103, 121, 34, 10, 45, 95, 104, 101, 108, 112, 95, 112, 97, 114, 97,
  103, 114, 97, 112, 104, 32, 34, 32, 32, 45, 32, 73, 110, 32, 71, 39,
  77, 73, 67, 44, 32, 97, 110, 32, 105, 109, 97, 103, 101, 32, 105, 115,
  32, 109, 111, 100, 101, 108, 101, 100, 32, 97, 115, 32, 97, 32, 49, 100,
  44, 32, 50, 100, 44, 32, 51, 100, 32, 111, 114, 32, 52, 100, 32, 97,
  114, 114, 97, 121, 32, 111, 102, 32, 115, 99, 97, 108, 97, 114, 32, 118,
  97, 108, 117, 101, 115, 44, 32, 117, 110, 105, 102, 111, 114, 109, 108, 121,
  10, 92, 110, 32, 32, 32, 32, 32, 100, 105, 115, 99, 114, 101, 116, 105,
  122, 101, 100, 32, 111, 110, 32, 97, 32, 114, 101, 99, 116, 97, 110, 103,
  117, 108, 97, 114, 47, 112, 97, 114, 97, 108, 108, 101, 108, 101, 112, 105,
  112, 101, 100, 105, 99, 32, 100, 111, 109, 97, 105, 110, 46, 10, 92, 110,
  32, 32, 45, 32, 84, 104, 101, 32, 102, 111, 117, 114, 32, 100, 105, 109,
  101, 110, 115, 105, 111, 110, 115, 32, 111, 102, 32, 116, 104, 101, 115, 101,
  32, 97, 114, 114, 97, 121, 115, 32, 97, 114, 101, 32, 114, 101, 115, 112,
  101, 99, 116, 105, 118, 101, 108, 121, 32, 100, 101, 110, 111, 116, 101, 100,
  32, 98, 121, 58, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 119, 105,
  100, 116, 104, 39, 44, 32, 116, 104, 101, 32, 110, 117, 109, 98, 101, 114,
  32, 111, 102, 32, 105, 109, 97, 103, 101, 32, 99, 111, 108, 117, 109, 110,
  115, 32, 40, 115, 105, 122, 101, 32, 97, 108, 111, 110, 103, 32, 116, 104,
  101, 32, 39, 120, 39, 45, 97, 120, 105, 115, 41, 46, 10, 92, 110, 32,
  32, 32, 32, 46, 32, 39, 104, 101, 105, 103, 104, 116, 39, 44, 32, 116,
  104, 101, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 105, 109, 97,
  103, 101, 32, 114, 111, 119, 115, 32, 40, 115, 105, 122, 101, 32, 97, 108,
  111, 110, 103, 32, 116, 104, 101, 32, 39, 121, 39, 45, 97, 120, 105, 115,
  41, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 100, 101, 112, 116,
  104, 39, 44, 32, 116, 104, 101, 32, 110, 117, 109, 98, 101, 114, 32, 111,
  102, 32, 105, 109, 97, 103, 101, 32, 115, 108, 105, 99, 101, 115, 32, 40,
  115, 105, 122, 101, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 39,
  122, 39, 45, 97, 120, 105, 115, 41, 46, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 32, 84, 104, 101, 32, 100, 101, 112, 116, 104, 32, 105, 115,
  32, 101, 113, 117, 97, 108, 32, 116, 111, 32, 49, 32, 102, 111, 114, 32,
  117, 115, 117, 97, 108, 32, 50, 100, 32, 99, 111, 108, 111, 114, 32, 111,
  114, 32, 103, 114, 97, 121, 115, 99, 97, 108, 101, 32, 105, 109, 97, 103,
  101, 115, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 115, 112, 101,
  99, 116, 114, 117, 109, 39, 44, 32, 116, 104, 101, 32, 110, 117, 109, 98,
  101, 114, 32, 111, 102, 32, 105, 109, 97, 103, 101, 32, 99, 104, 97, 110,
  110, 101, 108, 115, 32, 40, 115, 105, 122, 101, 32, 97, 108, 111, 110, 103,
  32, 116, 104, 101, 32, 39, 99, 39, 45, 97, 120, 105, 115, 41, 46, 10,
  92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 84, 104, 101, 32, 115, 112,
  101, 99, 116, 114, 117, 109, 32, 105, 115, 32, 114, 101, 115, 112, 101, 99,
  116, 105, 118, 101, 108, 121, 32, 101, 113, 117, 97, 108, 32, 116, 111, 32,
  51, 32, 97, 110, 100, 32, 52, 32, 102, 111, 114, 32, 117, 115, 117, 97,
  108, 32, 82, 71, 66, 32, 97, 110, 100, 32, 82, 71, 66, 65, 32, 99,
  111, 108, 111, 114, 32, 105, 109, 97, 103, 101, 115, 46, 10, 92, 110, 32,
  32, 45, 32, 84, 104, 101, 114, 101, 32, 97, 114, 101, 32, 110, 111, 32,
  115, 105, 122, 101, 32, 108, 105, 109, 105, 116, 97, 116, 105, 111, 110, 115,
  32, 111, 110, 32, 101, 97, 99, 104, 32, 105, 109, 97, 103, 101, 32, 100,
  105, 109, 101, 110, 115, 105, 111, 110, 115, 46, 32, 80, 97, 114, 116, 105,
  99, 117, 108, 97, 114, 108, 121, 44, 32, 116, 104, 101, 32, 110, 117, 109,
  98, 101, 114, 32, 111, 102, 32, 105, 109, 97, 103, 101, 10, 92, 110, 32,
  32, 32, 32, 32, 115, 108, 105, 99, 101, 115, 32, 111, 114, 32, 99, 104,
  97, 110, 110, 101, 108, 115, 32, 99, 97, 110, 32, 98, 101, 32, 111, 102,
  32, 97, 114, 98, 105, 116, 114, 97, 114, 121, 32, 115, 105, 122, 101, 32,
  119, 105, 116, 104, 105, 110, 32, 116, 104, 101, 32, 108, 105, 109, 105, 116,
  115, 32, 111, 102, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 32, 109,
  101, 109, 111, 114, 121, 46, 10, 92, 110, 32, 32, 45, 32, 84, 104, 101,
  32, 119, 105, 100, 116, 104, 44, 32, 104, 101, 105, 103, 104, 116, 32, 97,
  110, 100, 32, 100, 101, 112, 116, 104, 32, 111, 102, 32, 97, 110, 32, 105,
  109, 97, 103, 101, 32, 97, 114, 101, 32, 99, 111, 110, 115, 105, 100, 101,
  114, 101, 100, 32, 97, 115, 32, 39, 115, 112, 97, 116, 105, 97, 108, 39,
  32, 100, 105, 109, 101, 110, 115, 105, 111, 110, 115, 44, 32, 119, 104, 105,
  108, 101, 32, 116, 104, 101, 10, 92, 110, 32, 32, 32, 32, 32, 115, 112,
  101, 99, 116, 114, 117, 109, 32, 104, 97, 115, 32, 97, 32, 39, 109, 117,
  108, 116, 105, 45, 115, 112, 101, 99, 116, 114, 97, 108, 39, 32, 109, 101,
  97, 110, 105, 110, 103, 46, 32, 84, 104, 117, 115, 44, 32, 97, 32, 52,
  100, 32, 105, 109, 97, 103, 101, 32, 105, 110, 32, 71, 39, 77, 73, 67,
  32, 115, 104, 111, 117, 108, 100, 32, 98, 101, 32, 109, 111, 115, 116, 32,
  111, 102, 116, 101, 110, 10, 92, 110, 32, 32, 32, 32, 32, 114, 101, 103,
  97, 114, 100, 101, 100, 32, 97, 115, 32, 97, 32, 51, 100, 32, 100, 97,
  116, 97, 115, 101, 116, 32, 111, 102, 32, 109, 117, 108, 116, 105, 45, 115,
  112, 101, 99, 116, 114, 97, 108, 32, 118, 111, 120, 101, 108, 115, 46, 32,
  77, 111, 115, 116, 32, 111, 102, 32, 116, 104, 101, 32, 71, 39, 77, 73,
  67, 32, 99, 111, 109, 109, 97, 110, 100, 115, 32, 119, 105, 108, 108, 32,
  115, 116, 105, 99, 107, 10, 92, 110, 32, 32, 32, 32, 32, 119, 105, 116,
  104, 32, 116, 104, 105, 115, 32, 105, 100, 101, 97, 32, 40, 101, 46, 103,
  46, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 45, 98, 108, 117, 114,
  39, 32, 119, 105, 108, 108, 32, 98, 108, 117, 114, 32, 105, 109, 97, 103,
  101, 115, 32, 111, 110, 108, 121, 32, 97, 108, 111, 110, 103, 32, 116, 104,
  101, 32, 39, 120, 121, 122, 39, 32, 97, 120, 101, 115, 41, 46, 10, 92,
  110, 32, 32, 45, 32, 65, 108, 108, 32, 112, 105, 120, 101, 108, 32, 118,
  97, 108, 117, 101, 115, 32, 111, 102, 32, 97, 108, 108, 32, 105, 109, 97,
  103, 101, 115, 32, 111, 102, 32, 116, 104, 101, 32, 108, 105, 115, 116, 32,
  104, 97, 118, 101, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 100, 97,
  116, 97, 116, 121, 112, 101, 46, 32, 73, 116, 32, 99, 97, 110, 32, 98,
  101, 32, 111, 110, 101, 32, 97, 109, 111, 110, 103, 58, 10, 92, 110, 32,
  32, 32, 32, 46, 32, 39, 98, 111, 111, 108, 39, 58, 32, 83, 116, 97,
  110, 100, 115, 32, 102, 111, 114, 32, 39, 98, 111, 111, 108, 101, 97, 110,
  39, 46, 32, 86, 97, 108, 117, 101, 32, 114, 97, 110, 103, 101, 32, 105,
  115, 32, 123, 32, 48, 61, 102, 97, 108, 115, 101, 32, 124, 32, 49, 61,
  116, 114, 117, 101, 32, 125, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32,
  39, 117, 99, 104, 97, 114, 39, 58, 32, 83, 116, 97, 110, 100, 115, 32,
  102, 111, 114, 32, 39, 117, 110, 115, 105, 103, 110, 101, 100, 32, 99, 104,
  97, 114, 39, 46, 32, 86, 97, 108, 117, 101, 32, 114, 97, 110, 103, 101,
  32, 105, 115, 32, 91, 48, 44, 50, 53, 53, 93, 32, 40, 56, 98, 105,
  116, 115, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 84,
  104, 105, 115, 32, 116, 121, 112, 101, 32, 111, 102, 32, 112, 105, 120, 101,
  108, 32, 99, 111, 100, 105, 110, 103, 32, 105, 115, 32, 99, 111, 109, 109,
  111, 110, 108, 121, 32, 117, 115, 101, 100, 32, 116, 111, 32, 115, 116, 111,
  114, 101, 32, 56, 98, 105, 116, 115, 47, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 82, 71, 66, 91, 65, 93, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 99, 104, 97, 114, 39, 58,
  32, 86, 97, 108, 117, 101, 32, 114, 97, 110, 103, 101, 32, 105, 115, 32,
  91, 45, 49, 50, 56, 44, 49, 50, 55, 93, 32, 40, 56, 98, 105, 116,
  115, 41, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 117, 115, 104,
  111, 114, 116, 39, 58, 32, 83, 116, 97, 110, 100, 115, 32, 102, 111, 114,
  32, 39, 117, 110, 115, 105, 103, 110, 101, 100, 32, 115, 104, 111, 114, 116,
  39, 46, 32, 86, 97, 108, 117, 101, 32, 114, 97, 110, 103, 101, 32, 105,
  115, 32, 91, 48, 44, 54, 53, 53, 51, 53, 93, 32, 40, 49, 54, 98,
  105, 116, 115, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32,
  84, 104, 105, 115, 32, 116, 121, 112, 101, 32, 111, 102, 32, 112, 105, 120,
  101, 108, 32, 99, 111, 100, 105, 110, 103, 32, 105, 115, 32, 99, 111, 109,
  109, 111, 110, 108, 121, 32, 117, 115, 101, 100, 32, 116, 111, 32, 115, 116,
  111, 114, 101, 32, 49, 54, 98, 105, 116, 115, 47, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 82, 71, 66, 91, 65, 93, 32, 105, 109, 97, 103, 101,
  115, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 115, 104, 111, 114,
  116, 39, 58, 32, 86, 97, 108, 117, 101, 32, 114, 97, 110, 103, 101, 32,
  105, 115, 32, 91, 45, 51, 50, 55, 54, 56, 44, 51, 50, 55, 54, 55,
  93, 32, 40, 49, 54, 98, 105, 116, 115, 41, 46, 10, 92, 110, 32, 32,
  32, 32, 46, 32, 39, 117, 105, 110, 116, 39, 58, 32, 83, 116, 97, 110,
  100, 115, 32, 102, 111, 114, 32, 39, 117, 110, 115, 105, 103, 110, 101, 100,
  32, 105, 110, 116, 39, 46, 32, 86, 97, 108, 117, 101, 32, 114, 97, 110,
  103, 101, 32, 105, 115, 32, 91, 48, 44, 50, 94, 51, 50, 45, 49, 93,
  32, 40, 51, 50, 98, 105, 116, 115, 41, 46, 10, 92, 110, 32, 32, 32,
  32, 46, 32, 39, 105, 110, 116, 39, 58, 32, 86, 97, 108, 117, 101, 32,
  114, 97, 110, 103, 101, 32, 105, 115, 32, 91, 45, 50, 94, 51, 49, 44,
  50, 94, 51, 49, 45, 49, 93, 32, 40, 51, 50, 32, 98, 105, 116, 115,
  41, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 102, 108, 111, 97,
  116, 39, 58, 32, 86, 97, 108, 117, 101, 32, 114, 97, 110, 103, 101, 32,
  105, 115, 32, 91, 45, 51, 46, 52, 69, 51, 56, 44, 43, 51, 46, 52,
  69, 51, 56, 93, 32, 40, 51, 50, 98, 105, 116, 115, 41, 46, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 32, 84, 104, 105, 115, 32, 116, 121,
  112, 101, 32, 111, 102, 32, 99, 111, 100, 105, 110, 103, 32, 105, 115, 32,
  97, 98, 108, 101, 32, 116, 111, 32, 115, 116, 111, 114, 101, 32, 112, 105,
  120, 101, 108, 115, 32, 97, 115, 32, 51, 50, 32, 98, 105, 116, 115, 32,
  102, 108, 111, 97, 116, 45, 118, 97, 108, 117, 101, 100, 32, 110, 117, 109,
  98, 101, 114, 115, 46, 32, 84, 104, 105, 115, 32, 105, 115, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 32, 116, 104, 101, 32, 100, 101, 102, 97,
  117, 108, 116, 32, 100, 97, 116, 97, 116, 121, 112, 101, 32, 117, 115, 101,
  100, 32, 98, 121, 32, 71, 39, 77, 73, 67, 32, 105, 109, 97, 103, 101,
  32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 111, 112, 101, 114,
  97, 116, 105, 111, 110, 115, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32,
  39, 100, 111, 117, 98, 108, 101, 39, 58, 32, 86, 97, 108, 117, 101, 32,
  114, 97, 110, 103, 101, 32, 105, 115, 32, 91, 45, 49, 46, 55, 69, 51,
  48, 56, 44, 49, 46, 55, 69, 51, 48, 56, 93, 32, 40, 54, 52, 98,
  105, 116, 115, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32,
  84, 104, 105, 115, 32, 116, 121, 112, 101, 32, 111, 102, 32, 99, 111, 100,
  105, 110, 103, 32, 105, 115, 32, 97, 98, 108, 101, 32, 116, 111, 32, 115,
  116, 111, 114, 101, 32, 112, 105, 120, 101, 108, 115, 32, 97, 115, 32, 54,
  52, 32, 98, 105, 116, 115, 32, 102, 108, 111, 97, 116, 45, 118, 97, 108,
  117, 101, 100, 32, 110, 117, 109, 98, 101, 114, 115, 46, 10, 92, 110, 32,
  32, 45, 32, 67, 111, 110, 115, 105, 100, 101, 114, 105, 110, 103, 32, 112,
  105, 120, 101, 108, 32, 100, 97, 116, 97, 116, 121, 112, 101, 115, 32, 100,
  105, 102, 102, 101, 114, 101, 110, 116, 32, 116, 104, 97, 110, 32, 39, 102,
  108, 111, 97, 116, 39, 32, 105, 115, 32, 103, 101, 110, 101, 114, 97, 108,
  108, 121, 32, 117, 115, 101, 108, 101, 115, 115, 44, 32, 101, 120, 99, 101,
  112, 116, 32, 116, 111, 32, 102, 111, 114, 99, 101, 10, 92, 110, 32, 32,
  32, 32, 32, 116, 104, 101, 32, 105, 110, 112, 117, 116, 47, 111, 117, 116,
  112, 117, 116, 32, 111, 102, 32, 105, 109, 97, 103, 101, 32, 100, 97, 116,
  97, 32, 116, 111, 32, 97, 32, 112, 114, 101, 115, 99, 114, 105, 98, 101,
  100, 32, 98, 105, 110, 97, 114, 121, 32, 102, 111, 114, 109, 97, 116, 46,
  32, 72, 101, 110, 99, 101, 44, 32, 109, 111, 115, 116, 32, 71, 39, 77,
  73, 67, 32, 105, 109, 97, 103, 101, 10, 92, 110, 32, 32, 32, 32, 32,
  105, 109, 97, 103, 101, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103,
  32, 99, 111, 109, 109, 97, 110, 100, 115, 32, 97, 114, 101, 32, 97, 118,
  97, 105, 108, 97, 98, 108, 101, 32, 111, 110, 108, 121, 32, 102, 111, 114,
  32, 116, 104, 101, 32, 100, 101, 102, 97, 117, 108, 116, 32, 39, 102, 108,
  111, 97, 116, 39, 32, 112, 105, 120, 101, 108, 32, 100, 97, 116, 97, 116,
  121, 112, 101, 10, 92, 110, 32, 32, 32, 32, 32, 40, 115, 101, 101, 32,
  99, 111, 109, 109, 97, 110, 100, 32, 39, 45, 116, 121, 112, 101, 39, 32,
  105, 102, 32, 121, 111, 117, 32, 110, 101, 101, 100, 32, 116, 111, 32, 115,
  119, 105, 116, 99, 104, 32, 116, 111, 32, 97, 110, 111, 116, 104, 101, 114,
  32, 112, 105, 120, 101, 108, 32, 100, 97, 116, 97, 116, 121, 112, 101, 41,
  46, 34, 10, 45, 95, 104, 101, 108, 112, 95, 115, 101, 99, 116, 105, 111,
  110, 32, 34, 73, 116, 101, 109, 115, 32, 111, 102, 32, 97, 32, 112, 114,
  111, 99, 101, 115, 115, 105, 110, 103, 32, 112, 105, 112, 101, 108, 105, 110,
  101, 34, 10, 45, 95, 104, 101, 108, 112, 95, 112, 97, 114, 97, 103, 114,
  97, 112, 104, 32, 34, 32, 32, 45, 32, 73, 110, 32, 71, 39, 77, 73,
  67, 44, 32, 97, 110, 32, 105, 109, 97, 103, 101, 32, 112, 114, 111, 99,
  101, 115, 115, 105, 110, 103, 32, 112, 105, 112, 101, 108, 105, 110, 101, 32,
  105, 115, 32, 100, 101, 115, 99, 114, 105, 98, 101, 100, 32, 97, 115, 32,
  97, 32, 115, 101, 113, 117, 101, 110, 99, 101, 32, 111, 102, 32, 105, 116,
  101, 109, 115, 32, 115, 101, 112, 97, 114, 97, 116, 101, 100, 32, 98, 121,
  10, 92, 110, 32, 32, 32, 32, 32, 116, 104, 101, 32, 115, 112, 97, 99,
  101, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 39, 32, 39, 46,
  32, 83, 117, 99, 104, 32, 105, 116, 101, 109, 115, 32, 97, 114, 101, 32,
  105, 110, 116, 101, 114, 112, 114, 101, 116, 101, 100, 32, 97, 110, 100, 32,
  101, 120, 101, 99, 117, 116, 101, 100, 32, 102, 114, 111, 109, 32, 116, 104,
  101, 32, 108, 101, 102, 116, 32, 116, 111, 32, 116, 104, 101, 10, 92, 110,
  32, 32, 32, 32, 32, 114, 105, 103, 104, 116, 46, 32, 70, 111, 114, 32,
  105, 110, 115, 116, 97, 110, 99, 101, 44, 32, 116, 104, 101, 32, 101, 120,
  112, 114, 101, 115, 115, 105, 111, 110, 58, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 39, 105, 110, 112, 117, 116, 46, 106, 112, 103, 32, 45, 98,
  108, 117, 114, 32, 51, 44, 48, 32, 45, 115, 104, 97, 114, 112, 101, 110,
  32, 49, 48, 32, 45, 114, 101, 115, 105, 122, 101, 32, 50, 48, 48, 37,
  44, 50, 48, 48, 37, 32, 45, 111, 117, 116, 112, 117, 116, 32, 111, 117,
  116, 112, 117, 116, 46, 106, 112, 103, 39, 10, 92, 110, 32, 32, 32, 32,
  32, 100, 101, 102, 105, 110, 101, 115, 32, 97, 32, 118, 97, 108, 105, 100,
  32, 112, 105, 112, 101, 108, 105, 110, 101, 32, 99, 111, 109, 112, 111, 115,
  101, 100, 32, 111, 102, 32, 110, 105, 110, 101, 32, 71, 39, 77, 73, 67,
  32, 105, 116, 101, 109, 115, 46, 10, 92, 110, 32, 32, 45, 32, 65, 32,
  71, 39, 77, 73, 67, 32, 105, 116, 101, 109, 32, 105, 115, 32, 97, 32,
  115, 116, 114, 105, 110, 103, 32, 119, 104, 105, 99, 104, 32, 114, 101, 112,
  114, 101, 115, 101, 110, 116, 115, 32, 101, 105, 116, 104, 101, 114, 32, 97,
  32, 99, 111, 109, 109, 97, 110, 100, 44, 32, 97, 32, 115, 101, 116, 32,
  111, 102, 32, 99, 111, 109, 109, 97, 110, 100, 32, 97, 114, 103, 117, 109,
  101, 110, 116, 115, 44, 10, 92, 110, 32, 32, 32, 32, 32, 97, 32, 102,
  105, 108, 101, 110, 97, 109, 101, 44, 32, 111, 114, 32, 97, 32, 115, 112,
  101, 99, 105, 97, 108, 32, 105, 110, 112, 117, 116, 32, 115, 116, 114, 105,
  110, 103, 46, 10, 92, 110, 32, 32, 45, 32, 69, 115, 99, 97, 112, 101,
  32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 115, 32, 39, 92, 92, 39,
  32, 97, 110, 100, 32, 100, 111, 117, 98, 108, 101, 32, 113, 117, 111, 116,
  101, 115, 32, 39, 92, 34, 39, 32, 99, 97, 110, 32, 98, 101, 32, 117,
  115, 101, 100, 32, 40, 97, 115, 32, 117, 115, 117, 97, 108, 41, 32, 116,
  111, 32, 100, 101, 102, 105, 110, 101, 32, 105, 116, 101, 109, 115, 10, 92,
  110, 32, 32, 32, 32, 32, 99, 111, 110, 116, 97, 105, 110, 105, 110, 103,
  32, 115, 112, 97, 99, 101, 115, 44, 32, 111, 114, 32, 97, 110, 121, 32,
  111, 116, 104, 101, 114, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32,
  115, 101, 113, 117, 101, 110, 99, 101, 115, 46, 32, 70, 111, 114, 32, 105,
  110, 115, 116, 97, 110, 99, 101, 44, 32, 116, 104, 101, 32, 115, 116, 114,
  105, 110, 103, 115, 10, 92, 110, 32, 32, 32, 32, 32, 39, 115, 105, 110,
  103, 108, 101, 92, 92, 32, 105, 116, 101, 109, 39, 32, 97, 110, 100, 32,
  39, 92, 34, 115, 105, 110, 103, 108, 101, 32, 105, 116, 101, 109, 92, 34,
  39, 32, 100, 101, 102, 105, 110, 101, 32, 116, 104, 101, 32, 115, 97, 109,
  101, 32, 115, 116, 114, 105, 110, 103, 32, 105, 116, 101, 109, 44, 32, 119,
  105, 116, 104, 32, 97, 32, 115, 112, 97, 99, 101, 32, 105, 110, 32, 105,
  116, 46, 34, 10, 45, 95, 104, 101, 108, 112, 95, 115, 101, 99, 116, 105,
  111, 110, 32, 34, 73, 110, 112, 117, 116, 32, 100, 97, 116, 97, 32, 105,
  116, 101, 109, 115, 34, 10, 45, 95, 104, 101, 108, 112, 95, 112, 97, 114,
  97, 103, 114, 97, 112, 104, 32, 34, 32, 32, 45, 32, 73, 102, 32, 97,
  32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 71, 39, 77, 73, 67,
  32, 105, 116, 101, 109, 32, 97, 112, 112, 101, 97, 114, 115, 32, 116, 111,
  32, 98, 101, 32, 97, 110, 32, 101, 120, 105, 115, 116, 105, 110, 103, 32,
  102, 105, 108, 101, 110, 97, 109, 101, 44, 32, 116, 104, 101, 32, 99, 111,
  114, 114, 101, 115, 112, 111, 110, 100, 105, 110, 103, 32, 105, 109, 97, 103,
  101, 10, 92, 110, 32, 32, 32, 32, 32, 100, 97, 116, 97, 32, 97, 114,
  101, 32, 108, 111, 97, 100, 101, 100, 32, 97, 110, 100, 32, 105, 110, 115,
  101, 114, 116, 101, 100, 32, 97, 116, 32, 116, 104, 101, 32, 101, 110, 100,
  32, 111, 102, 32, 116, 104, 101, 32, 105, 109, 97, 103, 101, 32, 108, 105,
  115, 116, 46, 10, 92, 110, 32, 32, 45, 32, 83, 112, 101, 99, 105, 97,
  108, 32, 102, 105, 108, 101, 110, 97, 109, 101, 115, 32, 39, 45, 39, 32,
  97, 110, 100, 32, 39, 45, 46, 101, 120, 116, 39, 32, 115, 116, 97, 110,
  100, 32, 102, 111, 114, 32, 116, 104, 101, 32, 115, 116, 97, 110, 100, 97,
  114, 100, 32, 105, 110, 112, 117, 116, 47, 111, 117, 116, 112, 117, 116, 32,
  115, 116, 114, 101, 97, 109, 115, 44, 32, 111, 112, 116, 105, 111, 110, 97,
  108, 108, 121, 10, 92, 110, 32, 32, 32, 32, 32, 102, 111, 114, 99, 101,
  100, 32, 116, 111, 32, 98, 101, 32, 105, 110, 32, 97, 32, 115, 112, 101,
  99, 105, 102, 105, 99, 32, 39, 101, 120, 116, 39, 32, 102, 105, 108, 101,
  32, 102, 111, 114, 109, 97, 116, 32, 40, 101, 46, 103, 46, 32, 39, 45,
  46, 106, 112, 103, 39, 32, 111, 114, 32, 39, 45, 46, 112, 110, 103, 39,
  41, 46, 10, 92, 110, 32, 32, 45, 32, 84, 104, 101, 32, 102, 111, 108,
  108, 111, 119, 105, 110, 103, 32, 115, 112, 101, 99, 105, 97, 108, 32, 105,
  110, 112, 117, 116, 32, 115, 116, 114, 105, 110, 103, 115, 32, 109, 97, 121,
  32, 98, 101, 32, 117, 115, 101, 100, 32, 97, 115, 32, 71, 39, 77, 73,
  67, 32, 105, 116, 101, 109, 115, 32, 116, 111, 32, 99, 114, 101, 97, 116,
  101, 32, 97, 110, 100, 32, 105, 110, 115, 101, 114, 116, 32, 110, 101, 119,
  10, 92, 110, 32, 32, 32, 32, 32, 105, 109, 97, 103, 101, 115, 32, 119,
  105, 116, 104, 32, 112, 114, 101, 115, 99, 114, 105, 98, 101, 100, 32, 118,
  97, 108, 117, 101, 115, 44, 32, 97, 116, 32, 116, 104, 101, 32, 101, 110,
  100, 32, 111, 102, 32, 116, 104, 101, 32, 105, 109, 97, 103, 101, 32, 108,
  105, 115, 116, 58, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 91, 115,
  101, 108, 101, 99, 116, 105, 111, 110, 93, 39, 32, 111, 114, 32, 39, 91,
  115, 101, 108, 101, 99, 116, 105, 111, 110, 93, 120, 78, 39, 58, 32, 73,
  110, 115, 101, 114, 116, 32, 49, 32, 111, 114, 32, 78, 32, 99, 111, 112,
  105, 101, 115, 32, 111, 102, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32,
  101, 120, 105, 115, 116, 105, 110, 103, 32, 105, 109, 97, 103, 101, 115, 46,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 39, 115, 101, 108, 101, 99,
  116, 105, 111, 110, 39, 32, 109, 97, 121, 32, 99, 111, 110, 116, 97, 105,
  110, 32, 111, 110, 101, 32, 111, 114, 32, 115, 101, 118, 101, 114, 97, 108,
  32, 105, 109, 97, 103, 101, 115, 32, 40, 115, 101, 101, 32, 110, 101, 120,
  116, 32, 115, 101, 99, 116, 105, 111, 110, 32, 102, 111, 114, 32, 100, 101,
  116, 97, 105, 108, 115, 41, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32,
  39, 119, 105, 100, 116, 104, 91, 37, 93, 44, 95, 104, 101, 105, 103, 104,
  116, 91, 37, 93, 44, 95, 100, 101, 112, 116, 104, 91, 37, 93, 44, 95,
  115, 112, 101, 99, 116, 114, 117, 109, 91, 37, 93, 44, 95, 118, 97, 108,
  117, 101, 115, 39, 58, 32, 73, 110, 115, 101, 114, 116, 32, 97, 32, 110,
  101, 119, 32, 105, 109, 97, 103, 101, 32, 119, 105, 116, 104, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100,
  32, 115, 105, 122, 101, 32, 97, 110, 100, 32, 118, 97, 108, 117, 101, 115,
  32, 40, 97, 100, 100, 105, 110, 103, 32, 39, 37, 39, 32, 116, 111, 32,
  97, 32, 100, 105, 109, 101, 110, 115, 105, 111, 110, 32, 109, 101, 97, 110,
  115, 32, 39, 112, 101, 114, 99, 101, 110, 116, 97, 103, 101, 32, 111, 102,
  32, 116, 104, 101, 32, 115, 105, 122, 101, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 115, 97, 109,
  101, 32, 97, 120, 105, 115, 44, 32, 116, 97, 107, 101, 110, 32, 102, 114,
  111, 109, 32, 116, 104, 101, 32, 108, 97, 115, 116, 32, 105, 109, 97, 103,
  101, 32, 39, 91, 45, 49, 93, 39, 39, 41, 46, 32, 65, 110, 121, 32,
  115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 100, 105, 109, 101, 110, 115,
  105, 111, 110, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 99, 97, 110,
  32, 98, 101, 32, 97, 108, 115, 111, 32, 119, 114, 105, 116, 116, 101, 110,
  32, 97, 115, 32, 39, 91, 105, 109, 97, 103, 101, 93, 39, 44, 32, 97,
  110, 100, 32, 105, 115, 32, 116, 104, 101, 110, 32, 115, 101, 116, 32, 116,
  111, 32, 116, 104, 101, 32, 115, 105, 122, 101, 32, 40, 97, 108, 111, 110,
  103, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 97, 120, 105, 115, 41,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 111, 102, 32, 116, 104, 101,
  32, 101, 120, 105, 115, 116, 105, 110, 103, 32, 115, 112, 101, 99, 105, 102,
  105, 101, 100, 32, 105, 109, 97, 103, 101, 32, 91, 105, 109, 97, 103, 101,
  93, 46, 32, 39, 118, 97, 108, 117, 101, 115, 39, 32, 99, 97, 110, 32,
  98, 101, 32, 101, 105, 116, 104, 101, 114, 32, 97, 32, 115, 101, 113, 117,
  101, 110, 99, 101, 32, 111, 102, 32, 110, 117, 109, 98, 101, 114, 115, 10,
  92, 110, 32, 32, 32, 32, 32, 32, 32, 115, 101, 112, 97, 114, 97, 116,
  101, 100, 32, 98, 121, 32, 99, 111, 109, 109, 97, 115, 32, 39, 44, 39,
  44, 32, 111, 114, 32, 97, 32, 109, 97, 116, 104, 101, 109, 97, 116, 105,
  99, 97, 108, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 44, 32,
  97, 115, 32, 101, 46, 103, 46, 32, 105, 110, 32, 105, 110, 112, 117, 116,
  32, 105, 116, 101, 109, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 39,
  50, 53, 54, 44, 50, 53, 54, 44, 49, 44, 51, 44, 105, 102, 40, 99,
  61, 61, 48, 44, 120, 44, 105, 102, 40, 99, 61, 61, 49, 44, 121, 44,
  48, 41, 41, 39, 32, 119, 104, 105, 99, 104, 32, 99, 114, 101, 97, 116,
  101, 115, 32, 97, 32, 50, 53, 54, 120, 50, 53, 54, 32, 82, 71, 66,
  32, 99, 111, 108, 111, 114, 32, 105, 109, 97, 103, 101, 32, 119, 105, 116,
  104, 32, 97, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 115, 112, 97,
  116, 105, 97, 108, 32, 115, 104, 97, 100, 105, 110, 103, 32, 111, 110, 32,
  116, 104, 101, 32, 114, 101, 100, 32, 97, 110, 100, 32, 103, 114, 101, 101,
  110, 32, 99, 104, 97, 110, 110, 101, 108, 115, 46, 10, 92, 110, 32, 32,
  32, 32, 46, 32, 39, 40, 118, 49, 44, 118, 50, 44, 46, 46, 41, 39,
  58, 32, 73, 110, 115, 101, 114, 116, 32, 97, 32, 110, 101, 119, 32, 105,
  109, 97, 103, 101, 32, 102, 114, 111, 109, 32, 115, 112, 101, 99, 105, 102,
  105, 101, 100, 32, 112, 114, 101, 115, 99, 114, 105, 98, 101, 100, 32, 118,
  97, 108, 117, 101, 115, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  86, 97, 108, 117, 101, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 32,
  105, 110, 115, 105, 100, 101, 32, 112, 97, 114, 101, 110, 116, 104, 101, 115,
  101, 115, 32, 99, 97, 110, 32, 98, 101, 32, 39, 44, 39, 32, 40, 99,
  111, 108, 117, 109, 110, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 46,
  41, 44, 32, 39, 59, 39, 32, 40, 114, 111, 119, 32, 115, 101, 112, 46,
  41, 44, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 39, 47, 39, 32,
  40, 115, 108, 105, 99, 101, 32, 115, 101, 112, 46, 41, 32, 111, 114, 32,
  39, 94, 39, 32, 40, 99, 104, 97, 110, 110, 101, 108, 32, 115, 101, 112,
  46, 41, 46, 32, 70, 111, 114, 32, 105, 110, 115, 116, 97, 110, 99, 101,
  44, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 39, 40, 49, 44, 50, 44, 51, 59, 52, 44,
  53, 44, 54, 59, 55, 44, 56, 44, 57, 41, 39, 32, 99, 114, 101, 97,
  116, 101, 115, 32, 97, 32, 51, 120, 51, 32, 109, 97, 116, 114, 105, 120,
  32, 40, 115, 99, 97, 108, 97, 114, 32, 105, 109, 97, 103, 101, 41, 44,
  32, 119, 105, 116, 104, 32, 118, 97, 108, 117, 101, 115, 32, 102, 114, 111,
  109, 32, 49, 32, 116, 111, 32, 57, 46, 10, 92, 110, 32, 32, 32, 32,
  46, 32, 39, 48, 39, 58, 32, 73, 110, 115, 101, 114, 116, 32, 97, 32,
  110, 101, 119, 32, 39, 101, 109, 112, 116, 121, 39, 32, 105, 109, 97, 103,
  101, 44, 32, 99, 111, 110, 116, 97, 105, 110, 105, 110, 103, 32, 110, 111,
  32, 112, 105, 120, 101, 108, 32, 100, 97, 116, 97, 46, 32, 69, 109, 112,
  116, 121, 32, 105, 109, 97, 103, 101, 115, 32, 97, 114, 101, 32, 117, 115,
  101, 100, 32, 111, 110, 108, 121, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 105, 110, 32, 114, 97, 114, 101, 32, 111, 99, 99, 97, 115, 105, 111,
  110, 115, 46, 10, 92, 110, 32, 32, 45, 32, 73, 110, 112, 117, 116, 32,
  105, 116, 101, 109, 32, 39, 110, 97, 109, 101, 61, 118, 97, 108, 117, 101,
  39, 32, 100, 101, 99, 108, 97, 114, 101, 115, 32, 97, 32, 110, 101, 119,
  32, 108, 111, 99, 97, 108, 32, 111, 114, 32, 103, 108, 111, 98, 97, 108,
  32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 39, 110, 97, 109, 101, 39,
  44, 32, 111, 114, 32, 97, 115, 115, 105, 103, 110, 32, 97, 32, 110, 101,
  119, 10, 92, 110, 32, 32, 32, 32, 32, 118, 97, 108, 117, 101, 32, 116,
  111, 32, 97, 110, 32, 101, 120, 105, 115, 116, 105, 110, 103, 32, 118, 97,
  114, 105, 97, 98, 108, 101, 46, 32, 86, 97, 114, 105, 97, 98, 108, 101,
  32, 110, 97, 109, 101, 115, 32, 117, 115, 101, 32, 99, 104, 97, 114, 97,
  99, 116, 101, 114, 115, 32, 115, 101, 116, 32, 91, 97, 45, 122, 65, 45,
  90, 48, 45, 57, 95, 93, 32, 97, 110, 100, 32, 99, 97, 110, 110, 111,
  116, 10, 92, 110, 32, 32, 32, 32, 32, 115, 116, 97, 114, 116, 32, 119,
  105, 116, 104, 32, 97, 32, 110, 117, 109, 98, 101, 114, 46, 32, 65, 32,
  118, 97, 114, 105, 97, 98, 108, 101, 32, 100, 101, 102, 105, 110, 105, 116,
  105, 111, 110, 32, 105, 115, 32, 97, 108, 119, 97, 121, 115, 32, 108, 111,
  99, 97, 108, 32, 116, 111, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101,
  110, 116, 32, 99, 111, 109, 109, 97, 110, 100, 32, 101, 120, 99, 101, 112,
  116, 10, 92, 110, 32, 32, 32, 32, 32, 119, 104, 101, 110, 32, 105, 116,
  32, 115, 116, 97, 114, 116, 115, 32, 98, 121, 32, 116, 104, 101, 32, 117,
  110, 100, 101, 114, 115, 99, 111, 114, 101, 32, 99, 104, 97, 114, 97, 99,
  116, 101, 114, 32, 39, 95, 39, 46, 32, 73, 110, 32, 116, 104, 97, 116,
  32, 99, 97, 115, 101, 44, 32, 105, 116, 32, 98, 101, 99, 111, 109, 101,
  115, 32, 97, 108, 115, 111, 32, 97, 99, 99, 101, 115, 115, 105, 98, 108,
  101, 10, 92, 110, 32, 32, 32, 32, 32, 98, 121, 32, 97, 110, 121, 32,
  99, 111, 109, 109, 97, 110, 100, 32, 105, 110, 118, 111, 107, 101, 100, 32,
  111, 117, 116, 115, 105, 100, 101, 32, 116, 104, 101, 32, 99, 117, 114, 114,
  101, 110, 116, 32, 99, 111, 109, 109, 97, 110, 100, 32, 115, 99, 111, 112,
  101, 46, 34, 10, 45, 95, 104, 101, 108, 112, 95, 115, 101, 99, 116, 105,
  111, 110, 32, 34, 67, 111, 109, 109, 97, 110, 100, 32, 105, 116, 101, 109,
  115, 32, 97, 110, 100, 32, 115, 101, 108, 101, 99, 116, 105, 111, 110, 115,
  34, 10, 45, 95, 104, 101, 108, 112, 95, 112, 97, 114, 97, 103, 114, 97,
  112, 104, 32, 34, 32, 32, 45, 32, 65, 32, 71, 39, 77, 73, 67, 32,
  105, 116, 101, 109, 32, 115, 116, 97, 114, 116, 105, 110, 103, 32, 98, 121,
  32, 39, 45, 39, 32, 100, 101, 115, 105, 103, 110, 97, 116, 101, 115, 32,
  97, 32, 99, 111, 109, 109, 97, 110, 100, 44, 32, 109, 111, 115, 116, 32,
  111, 102, 32, 116, 104, 101, 32, 116, 105, 109, 101, 46, 32, 71, 101, 110,
  101, 114, 97, 108, 108, 121, 44, 32, 99, 111, 109, 109, 97, 110, 100, 115,
  10, 92, 110, 32, 32, 32, 32, 32, 112, 101, 114, 102, 111, 114, 109, 32,
  105, 109, 97, 103, 101, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103,
  32, 111, 112, 101, 114, 97, 116, 105, 111, 110, 115, 32, 111, 110, 32, 111,
  110, 101, 32, 111, 114, 32, 115, 101, 118, 101, 114, 97, 108, 32, 97, 118,
  97, 105, 108, 97, 98, 108, 101, 32, 105, 109, 97, 103, 101, 115, 32, 111,
  102, 32, 116, 104, 101, 32, 108, 105, 115, 116, 46, 10, 92, 110, 32, 32,
  45, 32, 67, 111, 109, 109, 111, 110, 32, 99, 111, 109, 109, 97, 110, 100,
  115, 32, 104, 97, 118, 101, 32, 116, 119, 111, 32, 101, 113, 117, 105, 118,
  97, 108, 101, 110, 116, 32, 110, 97, 109, 101, 115, 32, 40, 114, 101, 103,
  117, 108, 97, 114, 32, 97, 110, 100, 32, 115, 104, 111, 114, 116, 41, 46,
  32, 70, 111, 114, 32, 105, 110, 115, 116, 97, 110, 99, 101, 44, 32, 99,
  111, 109, 109, 97, 110, 100, 10, 92, 110, 32, 32, 32, 32, 32, 110, 97,
  109, 101, 115, 32, 39, 45, 114, 101, 115, 105, 122, 101, 39, 32, 97, 110,
  100, 32, 39, 45, 114, 39, 32, 114, 101, 102, 101, 114, 32, 116, 111, 32,
  116, 104, 101, 32, 115, 97, 109, 101, 32, 105, 109, 97, 103, 101, 32, 114,
  101, 115, 105, 122, 105, 110, 103, 32, 97, 99, 116, 105, 111, 110, 46, 10,
  92, 110, 32, 32, 45, 32, 65, 32, 71, 39, 77, 73, 67, 32, 99, 111,
  109, 109, 97, 110, 100, 32, 109, 97, 121, 32, 104, 97, 118, 101, 32, 109,
  97, 110, 100, 97, 116, 111, 114, 121, 32, 111, 114, 32, 111, 112, 116, 105,
  111, 110, 97, 108, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 46, 32,
  67, 111, 109, 109, 97, 110, 100, 32, 97, 114, 103, 117, 109, 101, 110, 116,
  115, 32, 109, 117, 115, 116, 32, 98, 101, 10, 92, 110, 32, 32, 32, 32,
  32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 105, 110, 32, 116, 104,
  101, 32, 110, 101, 120, 116, 32, 105, 116, 101, 109, 32, 111, 110, 32, 116,
  104, 101, 32, 99, 111, 109, 109, 97, 110, 100, 32, 108, 105, 110, 101, 46,
  32, 67, 111, 109, 109, 97, 115, 32, 39, 44, 39, 32, 97, 114, 101, 32,
  117, 115, 101, 100, 32, 116, 111, 32, 115, 101, 112, 97, 114, 97, 116, 101,
  32, 109, 117, 108, 116, 105, 112, 108, 101, 10, 92, 110, 32, 32, 32, 32,
  32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 44, 32, 105, 102, 32, 97,
  110, 121, 32, 114, 101, 113, 117, 105, 114, 101, 100, 46, 10, 92, 110, 32,
  32, 45, 32, 84, 104, 101, 32, 101, 120, 101, 99, 117, 116, 105, 111, 110,
  32, 111, 102, 32, 97, 32, 71, 39, 77, 73, 67, 32, 99, 111, 109, 109,
  97, 110, 100, 32, 109, 97, 121, 32, 98, 101, 32, 114, 101, 115, 116, 114,
  105, 99, 116, 101, 100, 32, 111, 110, 108, 121, 32, 116, 111, 32, 97, 32,
  115, 117, 98, 115, 101, 116, 32, 111, 102, 32, 116, 104, 101, 32, 105, 109,
  97, 103, 101, 32, 108, 105, 115, 116, 44, 32, 98, 121, 10, 92, 110, 32,
  32, 32, 32, 32, 97, 112, 112, 101, 110, 100, 105, 110, 103, 32, 39, 91,
  115, 117, 98, 115, 101, 116, 93, 39, 32, 116, 111, 32, 116, 104, 101, 32,
  99, 111, 109, 109, 97, 110, 100, 32, 110, 97, 109, 101, 46, 32, 69, 120,
  97, 109, 112, 108, 101, 115, 32, 111, 102, 32, 118, 97, 108, 105, 100, 32,
  115, 121, 110, 116, 97, 120, 101, 115, 32, 102, 111, 114, 32, 39, 115, 117,
  98, 115, 101, 116, 39, 32, 97, 114, 101, 58, 10, 92, 110, 32, 32, 32,
  32, 46, 32, 39, 45, 99, 111, 109, 91, 48, 44, 49, 44, 51, 93, 39,
  58, 32, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100, 32,
  111, 110, 108, 121, 32, 111, 110, 32, 105, 109, 97, 103, 101, 115, 32, 91,
  48, 93, 44, 91, 49, 93, 32, 97, 110, 100, 32, 91, 51, 93, 46, 10,
  92, 110, 32, 32, 32, 32, 46, 32, 39, 45, 99, 111, 109, 91, 51, 45,
  53, 93, 39, 58, 32, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97,
  110, 100, 32, 111, 110, 108, 121, 32, 111, 110, 32, 105, 109, 97, 103, 101,
  115, 32, 91, 51, 93, 32, 116, 111, 32, 91, 53, 93, 32, 40, 105, 46,
  101, 44, 32, 91, 51, 93, 44, 91, 52, 93, 32, 97, 110, 100, 32, 91,
  53, 93, 41, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 45, 99,
  111, 109, 91, 53, 48, 37, 45, 49, 48, 48, 37, 93, 39, 58, 32, 65,
  112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100, 32, 111, 110, 108,
  121, 32, 111, 110, 32, 116, 104, 101, 32, 115, 101, 99, 111, 110, 100, 32,
  104, 97, 108, 102, 32, 111, 102, 32, 116, 104, 101, 32, 105, 109, 97, 103,
  101, 32, 108, 105, 115, 116, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32,
  39, 45, 99, 111, 109, 91, 48, 44, 45, 52, 45, 45, 49, 93, 39, 58,
  32, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100, 32, 111,
  110, 108, 121, 32, 111, 110, 32, 116, 104, 101, 32, 102, 105, 114, 115, 116,
  32, 97, 110, 100, 32, 116, 104, 101, 32, 102, 111, 117, 114, 32, 108, 97,
  116, 101, 115, 116, 32, 105, 109, 97, 103, 101, 115, 46, 10, 92, 110, 32,
  32, 32, 32, 46, 32, 39, 45, 99, 111, 109, 91, 48, 45, 57, 58, 51,
  93, 39, 58, 32, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110,
  100, 32, 111, 110, 108, 121, 32, 111, 110, 32, 105, 109, 97, 103, 101, 115,
  32, 91, 48, 93, 32, 116, 111, 32, 91, 57, 93, 44, 32, 119, 105, 116,
  104, 32, 97, 32, 115, 116, 101, 112, 32, 111, 102, 32, 51, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 40, 105, 46, 101, 46, 32, 111, 110, 32, 105,
  109, 97, 103, 101, 115, 32, 91, 48, 93, 44, 32, 91, 51, 93, 44, 32,
  91, 54, 93, 32, 97, 110, 100, 32, 91, 57, 93, 41, 46, 10, 92, 110,
  32, 32, 32, 32, 46, 32, 39, 45, 99, 111, 109, 91, 48, 45, 45, 49,
  58, 50, 93, 39, 58, 32, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109,
  97, 110, 100, 32, 111, 110, 108, 121, 32, 111, 110, 32, 105, 109, 97, 103,
  101, 115, 32, 111, 102, 32, 116, 104, 101, 32, 108, 105, 115, 116, 32, 119,
  105, 116, 104, 32, 101, 118, 101, 110, 32, 105, 110, 100, 105, 99, 101, 115,
  46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 45, 99, 111, 109, 91,
  48, 44, 50, 45, 52, 44, 53, 48, 37, 45, 45, 49, 93, 39, 58, 32,
  65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100, 32, 111, 110,
  32, 105, 109, 97, 103, 101, 115, 32, 91, 48, 93, 44, 91, 50, 93, 44,
  91, 51, 93, 44, 91, 52, 93, 32, 97, 110, 100, 32, 111, 110, 32, 116,
  104, 101, 32, 115, 101, 99, 111, 110, 100, 32, 104, 97, 108, 102, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 111, 102,
  32, 116, 104, 101, 32, 105, 109, 97, 103, 101, 32, 108, 105, 115, 116, 46,
  10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 45, 99, 111, 109, 91, 94,
  48, 44, 49, 93, 39, 58, 32, 65, 112, 112, 108, 121, 32, 99, 111, 109,
  109, 97, 110, 100, 32, 111, 110, 32, 97, 108, 108, 32, 105, 109, 97, 103,
  101, 115, 32, 101, 120, 99, 101, 112, 116, 32, 116, 104, 101, 32, 102, 105,
  114, 115, 116, 32, 116, 119, 111, 46, 10, 92, 110, 32, 32, 32, 32, 46,
  32, 39, 45, 99, 111, 109, 91, 110, 97, 109, 101, 49, 44, 110, 97, 109,
  101, 50, 93, 39, 58, 32, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109,
  97, 110, 100, 32, 111, 110, 32, 110, 97, 109, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 32, 39, 110, 97, 109, 101, 49, 39, 32, 97, 110, 100, 32,
  39, 110, 97, 109, 101, 50, 39, 46, 10, 92, 110, 32, 32, 45, 32, 73,
  110, 100, 105, 99, 101, 115, 32, 105, 110, 32, 115, 101, 108, 101, 99, 116,
  105, 111, 110, 115, 32, 97, 114, 101, 32, 97, 108, 119, 97, 121, 115, 32,
  115, 111, 114, 116, 101, 100, 32, 105, 110, 32, 105, 110, 99, 114, 101, 97,
  115, 105, 110, 103, 32, 111, 114, 100, 101, 114, 44, 32, 97, 110, 100, 32,
  100, 117, 112, 108, 105, 99, 97, 116, 101, 32, 105, 110, 100, 105, 99, 101,
  115, 32, 97, 114, 101, 10, 92, 110, 32, 32, 32, 32, 32, 100, 105, 115,
  99, 97, 114, 100, 101, 100, 46, 32, 70, 111, 114, 32, 105, 110, 115, 116,
  97, 110, 99, 101, 44, 32, 115, 101, 108, 101, 99, 116, 105, 111, 110, 115,
  32, 39, 91, 51, 45, 49, 44, 49, 45, 51, 93, 39, 32, 97, 110, 100,
  32, 39, 91, 49, 44, 49, 44, 49, 44, 51, 44, 50, 93, 39, 32, 97,
  114, 101, 32, 98, 111, 116, 104, 32, 101, 113, 117, 105, 118, 97, 108, 101,
  110, 116, 32, 116, 111, 10, 92, 110, 32, 32, 32, 32, 32, 39, 91, 49,
  45, 51, 93, 39, 46, 32, 73, 102, 32, 121, 111, 117, 32, 119, 97, 110,
  116, 32, 116, 111, 32, 114, 101, 112, 101, 97, 116, 32, 97, 32, 115, 105,
  110, 103, 108, 101, 32, 99, 111, 109, 109, 97, 110, 100, 32, 109, 117, 108,
  116, 105, 112, 108, 101, 32, 116, 105, 109, 101, 115, 32, 111, 110, 32, 97,
  110, 32, 105, 109, 97, 103, 101, 44, 32, 117, 115, 101, 32, 97, 10, 92,
  110, 32, 32, 32, 32, 32, 39, 45, 114, 101, 112, 101, 97, 116, 46, 46,
  45, 100, 111, 110, 101, 39, 32, 108, 111, 111, 112, 46, 32, 73, 110, 118,
  101, 114, 116, 105, 110, 103, 32, 116, 104, 101, 32, 111, 114, 100, 101, 114,
  32, 111, 102, 32, 105, 109, 97, 103, 101, 115, 32, 105, 110, 32, 97, 32,
  115, 101, 108, 101, 99, 116, 105, 111, 110, 32, 99, 97, 110, 32, 98, 101,
  32, 97, 99, 104, 105, 101, 118, 101, 100, 32, 98, 121, 10, 92, 110, 32,
  32, 32, 32, 32, 105, 110, 118, 101, 114, 116, 105, 110, 103, 32, 102, 105,
  114, 115, 116, 32, 116, 104, 101, 32, 111, 114, 100, 101, 114, 32, 111, 102,
  32, 116, 104, 101, 32, 105, 109, 97, 103, 101, 115, 32, 105, 110, 32, 116,
  104, 101, 32, 108, 105, 115, 116, 44, 32, 119, 105, 116, 104, 32, 99, 111,
  109, 109, 97, 110, 100, 32, 39, 45, 114, 101, 118, 101, 114, 115, 101, 91,
  115, 101, 108, 101, 99, 116, 105, 111, 110, 93, 39, 46, 10, 92, 110, 32,
  32, 45, 32, 71, 39, 77, 73, 67, 32, 99, 111, 109, 109, 97, 110, 100,
  115, 32, 105, 110, 118, 111, 107, 101, 100, 32, 119, 105, 116, 104, 111, 117,
  116, 32, 39, 91, 115, 117, 98, 115, 101, 116, 93, 39, 32, 97, 114, 101,
  32, 97, 112, 112, 108, 105, 101, 100, 32, 111, 110, 32, 97, 108, 108, 32,
  105, 109, 97, 103, 101, 115, 32, 111, 102, 32, 116, 104, 101, 32, 108, 105,
  115, 116, 46, 10, 92, 110, 32, 32, 45, 32, 65, 32, 71, 39, 77, 73,
  67, 32, 99, 111, 109, 109, 97, 110, 100, 32, 115, 116, 97, 114, 116, 105,
  110, 103, 32, 119, 105, 116, 104, 32, 39, 45, 45, 39, 32, 105, 110, 115,
  116, 101, 97, 100, 32, 111, 102, 32, 39, 45, 39, 32, 100, 111, 101, 115,
  32, 110, 111, 116, 32, 97, 99, 116, 32, 39, 105, 110, 45, 112, 108, 97,
  99, 101, 39, 32, 98, 117, 116, 32, 105, 110, 115, 101, 114, 116, 115, 32,
  105, 116, 115, 10, 92, 110, 32, 32, 32, 32, 32, 114, 101, 115, 117, 108,
  116, 32, 97, 115, 32, 111, 110, 101, 32, 111, 114, 32, 115, 101, 118, 101,
  114, 97, 108, 32, 110, 101, 119, 32, 105, 109, 97, 103, 101, 115, 32, 97,
  116, 32, 116, 104, 101, 32, 101, 110, 100, 32, 111, 102, 32, 116, 104, 101,
  32, 105, 109, 97, 103, 101, 32, 108, 105, 115, 116, 46, 10, 92, 110, 32,
  32, 45, 32, 84, 104, 101, 114, 101, 32, 97, 114, 101, 32, 116, 119, 111,
  32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32, 116, 121, 112, 101, 115,
  32, 111, 102, 32, 99, 111, 109, 109, 97, 110, 100, 115, 32, 116, 104, 97,
  116, 32, 99, 97, 110, 32, 98, 101, 32, 114, 117, 110, 32, 98, 121, 32,
  116, 104, 101, 32, 71, 39, 77, 73, 67, 32, 105, 110, 116, 101, 114, 112,
  114, 101, 116, 101, 114, 58, 10, 92, 110, 32, 32, 32, 32, 46, 32, 78,
  97, 116, 105, 118, 101, 32, 99, 111, 109, 109, 97, 110, 100, 115, 44, 32,
  97, 114, 101, 32, 104, 97, 114, 100, 45, 99, 111, 100, 101, 100, 32, 102,
  117, 110, 99, 116, 105, 111, 110, 97, 108, 105, 116, 105, 101, 115, 32, 105,
  110, 32, 116, 104, 101, 32, 105, 110, 116, 101, 114, 112, 114, 101, 116, 101,
  114, 32, 99, 111, 114, 101, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 84, 104, 101, 121, 32, 97, 114, 101, 32, 116, 104, 117, 115, 32, 99,
  111, 109, 112, 105, 108, 101, 100, 32, 97, 115, 32, 109, 97, 99, 104, 105,
  110, 101, 32, 99, 111, 100, 101, 32, 97, 110, 100, 32, 114, 117, 110, 32,
  113, 117, 105, 99, 107, 108, 121, 44, 32, 109, 111, 115, 116, 32, 111, 102,
  32, 116, 104, 101, 32, 116, 105, 109, 101, 46, 10, 92, 110, 32, 32, 32,
  32, 32, 32, 32, 79, 109, 105, 116, 116, 105, 110, 103, 32, 97, 110, 32,
  97, 114, 103, 117, 109, 101, 110, 116, 32, 119, 104, 101, 110, 32, 105, 110,
  118, 111, 107, 105, 110, 103, 32, 97, 32, 110, 97, 116, 105, 118, 101, 32,
  99, 111, 109, 109, 97, 110, 100, 32, 105, 115, 32, 110, 111, 116, 32, 112,
  101, 114, 109, 105, 116, 116, 101, 100, 44, 32, 101, 120, 99, 101, 112, 116,
  32, 105, 102, 32, 97, 108, 108, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 102, 111, 108, 108, 111, 119, 105, 110, 103, 32, 97, 114, 103, 117, 109,
  101, 110, 116, 115, 32, 97, 114, 101, 32, 97, 108, 115, 111, 32, 111, 109,
  105, 116, 116, 101, 100, 46, 32, 70, 111, 114, 32, 105, 110, 115, 116, 97,
  110, 99, 101, 44, 32, 99, 97, 108, 108, 32, 116, 111, 32, 39, 45, 112,
  108, 97, 115, 109, 97, 32, 49, 48, 44, 44, 53, 39, 32, 105, 115, 32,
  105, 110, 118, 97, 108, 105, 100, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 98, 117, 116, 32, 39, 45, 112, 108, 97, 115, 109, 97, 32, 49, 48,
  39, 32, 105, 115, 32, 99, 111, 114, 114, 101, 99, 116, 46, 10, 92, 110,
  32, 32, 32, 32, 46, 32, 67, 117, 115, 116, 111, 109, 32, 99, 111, 109,
  109, 97, 110, 100, 115, 44, 32, 97, 114, 101, 32, 100, 101, 102, 105, 110,
  101, 100, 32, 97, 115, 32, 71, 39, 77, 73, 67, 32, 112, 105, 112, 101,
  108, 105, 110, 101, 115, 32, 111, 102, 32, 110, 97, 116, 105, 118, 101, 32,
  111, 114, 32, 99, 117, 115, 116, 111, 109, 32, 99, 111, 109, 109, 97, 110,
  100, 115, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 84, 104, 101,
  121, 32, 97, 114, 101, 32, 105, 110, 116, 101, 114, 112, 114, 101, 116, 101,
  100, 32, 98, 121, 32, 116, 104, 101, 32, 71, 39, 77, 73, 67, 32, 105,
  110, 116, 101, 114, 112, 114, 101, 116, 101, 114, 44, 32, 97, 110, 100, 32,
  114, 117, 110, 32, 115, 108, 111, 119, 101, 114, 32, 116, 104, 97, 110, 32,
  110, 97, 116, 105, 118, 101, 32, 99, 111, 109, 109, 97, 110, 100, 115, 46,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 66, 117, 116, 32, 111, 109,
  105, 116, 116, 105, 110, 103, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115,
  32, 119, 104, 101, 110, 32, 105, 110, 118, 111, 107, 105, 110, 103, 32, 97,
  32, 99, 117, 115, 116, 111, 109, 32, 99, 111, 109, 109, 97, 110, 100, 32,
  105, 115, 32, 112, 101, 114, 109, 105, 116, 116, 101, 100, 46, 32, 70, 111,
  114, 32, 105, 110, 115, 116, 97, 110, 99, 101, 44, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 115,
  32, 39, 45, 102, 108, 111, 119, 101, 114, 32, 44, 44, 44, 49, 48, 48,
  44, 44, 50, 39, 32, 111, 114, 32, 39, 45, 102, 108, 111, 119, 101, 114,
  32, 44, 39, 32, 97, 114, 101, 32, 99, 111, 114, 114, 101, 99, 116, 46,
  10, 92, 110, 32, 32, 45, 32, 65, 32, 117, 115, 101, 114, 32, 109, 97,
  121, 32, 101, 97, 115, 105, 108, 121, 32, 97, 100, 100, 32, 105, 116, 115,
  32, 111, 119, 110, 32, 99, 117, 115, 116, 111, 109, 32, 99, 111, 109, 109,
  97, 110, 100, 115, 32, 116, 111, 32, 116, 104, 101, 32, 71, 39, 77, 73,
  67, 32, 105, 110, 116, 101, 114, 112, 114, 101, 116, 101, 114, 32, 40, 115,
  101, 101, 32, 115, 101, 99, 116, 105, 111, 110, 10, 92, 110, 32, 32, 32,
  32, 32, 39, 65, 100, 100, 105, 110, 103, 32, 99, 117, 115, 116, 111, 109,
  32, 99, 111, 109, 109, 97, 110, 100, 115, 39, 41, 46, 32, 78, 97, 116,
  105, 118, 101, 32, 99, 111, 109, 109, 97, 110, 100, 115, 32, 99, 97, 110,
  110, 111, 116, 32, 98, 101, 32, 97, 100, 100, 101, 100, 32, 117, 110, 108,
  101, 115, 115, 32, 121, 111, 117, 32, 109, 111, 100, 105, 102, 121, 32, 116,
  104, 101, 32, 71, 39, 77, 73, 67, 10, 92, 110, 32, 32, 32, 32, 32,
  105, 110, 116, 101, 114, 112, 114, 101, 116, 101, 114, 32, 115, 111, 117, 114,
  99, 101, 32, 99, 111, 100, 101, 46, 34, 10, 45, 95, 104, 101, 108, 112,
  95, 115, 101, 99, 116, 105, 111, 110, 32, 34, 73, 110, 112, 117, 116, 115,
  47, 111, 117, 116, 112, 117, 116, 115, 32, 112, 114, 111, 112, 101, 114, 116,
  105, 101, 115, 34, 10, 45, 95, 104, 101, 108, 112, 95, 112, 97, 114, 97,
  103, 114, 97, 112, 104, 32, 34, 32, 32, 45, 32, 71, 39, 77, 73, 67,
  32, 105, 115, 32, 97, 98, 108, 101, 32, 116, 111, 32, 114, 101, 97, 100,
  47, 119, 114, 105, 116, 101, 32, 109, 111, 115, 116, 32, 111, 102, 32, 116,
  104, 101, 32, 99, 108, 97, 115, 115, 105, 99, 97, 108, 32, 105, 109, 97,
  103, 101, 32, 102, 105, 108, 101, 32, 102, 111, 114, 109, 97, 116, 115, 44,
  32, 105, 110, 99, 108, 117, 100, 105, 110, 103, 58, 10, 92, 110, 32, 32,
  32, 32, 46, 32, 50, 100, 32, 103, 114, 97, 121, 115, 99, 97, 108, 101,
  47, 99, 111, 108, 111, 114, 32, 102, 105, 108, 101, 115, 58, 32, 46, 112,
  110, 103, 44, 32, 46, 106, 112, 101, 103, 44, 32, 46, 103, 105, 102, 44,
  32, 46, 112, 110, 109, 44, 32, 46, 116, 105, 102, 44, 32, 46, 98, 109,
  112, 44, 32, 46, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 51, 100,
  32, 118, 111, 108, 117, 109, 101, 116, 114, 105, 99, 32, 102, 105, 108, 101,
  115, 58, 32, 46, 100, 99, 109, 44, 32, 46, 104, 100, 114, 44, 32, 46,
  110, 105, 105, 44, 32, 46, 112, 97, 110, 44, 32, 46, 105, 110, 114, 44,
  32, 46, 112, 110, 107, 44, 32, 46, 46, 10, 92, 110, 32, 32, 32, 32,
  46, 32, 73, 109, 97, 103, 101, 32, 115, 101, 113, 117, 101, 110, 99, 101,
  115, 58, 32, 46, 109, 112, 101, 103, 44, 32, 46, 97, 118, 105, 44, 32,
  46, 109, 111, 118, 44, 32, 46, 111, 103, 103, 44, 32, 46, 102, 108, 118,
  44, 32, 46, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 71, 101, 110,
  101, 114, 105, 99, 32, 97, 115, 99, 105, 105, 32, 111, 114, 32, 98, 105,
  110, 97, 114, 121, 32, 100, 97, 116, 97, 32, 102, 105, 108, 101, 115, 58,
  32, 46, 99, 105, 109, 103, 44, 32, 46, 99, 105, 109, 103, 122, 44, 32,
  46, 100, 108, 109, 44, 32, 46, 97, 115, 99, 44, 32, 46, 112, 102, 109,
  44, 32, 46, 114, 97, 119, 44, 32, 46, 116, 120, 116, 44, 32, 46, 104,
  46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 51, 100, 32, 111, 98, 106,
  101, 99, 116, 32, 102, 105, 108, 101, 115, 58, 32, 46, 111, 102, 102, 46,
  10, 92, 110, 32, 32, 45, 32, 87, 104, 101, 110, 32, 100, 101, 97, 108,
  105, 110, 103, 32, 119, 105, 116, 104, 32, 99, 111, 108, 111, 114, 32, 105,
  109, 97, 103, 101, 115, 44, 32, 71, 39, 77, 73, 67, 32, 103, 101, 110,
  101, 114, 97, 108, 108, 121, 32, 114, 101, 97, 100, 115, 44, 32, 119, 114,
  105, 116, 101, 115, 32, 97, 110, 100, 32, 100, 105, 115, 112, 108, 97, 121,
  115, 32, 100, 97, 116, 97, 32, 117, 115, 105, 110, 103, 32, 116, 104, 101,
  10, 92, 110, 32, 32, 32, 32, 32, 117, 115, 117, 97, 108, 32, 82, 71,
  66, 32, 99, 111, 108, 111, 114, 32, 115, 112, 97, 99, 101, 46, 10, 92,
  110, 32, 32, 45, 32, 71, 39, 77, 73, 67, 32, 105, 115, 32, 97, 98,
  108, 101, 32, 116, 111, 32, 109, 97, 110, 97, 103, 101, 32, 51, 100, 32,
  111, 98, 106, 101, 99, 116, 115, 32, 116, 104, 97, 116, 32, 109, 97, 121,
  32, 98, 101, 32, 114, 101, 97, 100, 32, 102, 114, 111, 109, 32, 102, 105,
  108, 101, 115, 32, 111, 114, 32, 103, 101, 110, 101, 114, 97, 116, 101, 100,
  32, 98, 121, 32, 71, 39, 77, 73, 67, 10, 92, 110, 32, 32, 32, 32,
  32, 99, 111, 109, 109, 97, 110, 100, 115, 46, 32, 84, 104, 101, 121, 32,
  97, 114, 101, 32, 115, 116, 111, 114, 101, 100, 32, 97, 115, 32, 111, 110,
  101, 45, 99, 111, 108, 117, 109, 110, 32, 115, 99, 97, 108, 97, 114, 32,
  105, 109, 97, 103, 101, 115, 32, 99, 111, 110, 116, 97, 105, 110, 105, 110,
  103, 32, 116, 104, 101, 32, 111, 98, 106, 101, 99, 116, 32, 100, 97, 116,
  97, 44, 32, 105, 110, 32, 116, 104, 101, 10, 92, 110, 32, 32, 32, 32,
  32, 102, 111, 108, 108, 111, 119, 105, 110, 103, 32, 111, 114, 100, 101, 114,
  58, 32, 123, 32, 109, 97, 103, 105, 99, 95, 110, 117, 109, 98, 101, 114,
  59, 32, 115, 105, 122, 101, 115, 59, 32, 118, 101, 114, 116, 105, 99, 101,
  115, 59, 32, 112, 114, 105, 109, 105, 116, 105, 118, 101, 115, 59, 32, 99,
  111, 108, 111, 114, 115, 59, 32, 111, 112, 97, 99, 105, 116, 105, 101, 115,
  32, 125, 46, 10, 92, 110, 32, 32, 32, 32, 32, 84, 104, 101, 115, 101,
  32, 51, 100, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 97, 116, 105,
  111, 110, 115, 32, 99, 97, 110, 32, 98, 101, 32, 112, 114, 111, 99, 101,
  115, 115, 101, 100, 32, 97, 115, 32, 114, 101, 103, 117, 108, 97, 114, 32,
  102, 108, 111, 97, 116, 45, 118, 97, 108, 117, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 46, 10, 92, 110, 32, 32, 32, 32, 32, 40, 115, 101, 101,
  32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 45, 115, 112, 108, 105, 116,
  51, 100, 39, 32, 102, 111, 114, 32, 97, 99, 99, 101, 115, 115, 105, 110,
  103, 32, 101, 97, 99, 104, 32, 111, 102, 32, 116, 104, 101, 115, 101, 32,
  51, 100, 32, 111, 98, 106, 101, 99, 116, 32, 100, 97, 116, 97, 32, 115,
  101, 112, 97, 114, 97, 116, 101, 108, 121, 41, 46, 10, 92, 110, 32, 32,
  45, 32, 66, 101, 32, 97, 119, 97, 114, 101, 32, 116, 104, 97, 116, 32,
  117, 115, 117, 97, 108, 32, 102, 105, 108, 101, 32, 102, 111, 114, 109, 97,
  116, 115, 32, 109, 97, 121, 32, 98, 101, 32, 115, 111, 109, 101, 116, 105,
  109, 101, 115, 32, 110, 111, 116, 32, 97, 100, 97, 112, 116, 101, 100, 32,
  116, 111, 32, 115, 116, 111, 114, 101, 32, 97, 108, 108, 32, 116, 104, 101,
  32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 10, 92, 110, 32, 32, 32,
  32, 32, 105, 109, 97, 103, 101, 32, 100, 97, 116, 97, 44, 32, 115, 105,
  110, 99, 101, 32, 71, 39, 77, 73, 67, 32, 117, 115, 101, 115, 32, 102,
  108, 111, 97, 116, 45, 118, 97, 108, 117, 101, 100, 32, 99, 111, 100, 105,
  110, 103, 32, 111, 102, 32, 105, 109, 97, 103, 101, 32, 112, 105, 120, 101,
  108, 115, 46, 32, 70, 111, 114, 32, 105, 110, 115, 116, 97, 110, 99, 101,
  44, 32, 115, 97, 118, 105, 110, 103, 10, 92, 110, 32, 32, 32, 32, 32,
  97, 110, 32, 105, 109, 97, 103, 101, 32, 116, 104, 97, 116, 32, 119, 97,
  115, 32, 105, 110, 105, 116, 105, 97, 108, 108, 121, 32, 108, 111, 97, 100,
  101, 100, 32, 97, 115, 32, 97, 32, 49, 54, 98, 105, 116, 115, 47, 99,
  104, 97, 110, 110, 101, 108, 32, 105, 109, 97, 103, 101, 44, 32, 97, 115,
  32, 97, 32, 46, 106, 112, 103, 32, 102, 105, 108, 101, 32, 119, 105, 108,
  108, 32, 114, 101, 115, 117, 108, 116, 10, 92, 110, 32, 32, 32, 32, 32,
  105, 110, 32, 108, 111, 115, 115, 32, 111, 102, 32, 105, 110, 102, 111, 114,
  109, 97, 116, 105, 111, 110, 46, 32, 85, 115, 101, 32, 116, 104, 101, 32,
  46, 99, 105, 109, 103, 32, 102, 105, 108, 101, 32, 101, 120, 116, 101, 110,
  115, 105, 111, 110, 32, 40, 111, 114, 32, 46, 99, 105, 109, 103, 122, 44,
  32, 105, 116, 115, 32, 99, 111, 109, 112, 114, 101, 115, 115, 101, 100, 10,
  92, 110, 32, 32, 32, 32, 32, 118, 101, 114, 115, 105, 111, 110, 41, 32,
  116, 111, 32, 101, 110, 115, 117, 114, 101, 32, 116, 104, 97, 116, 32, 97,
  108, 108, 32, 100, 97, 116, 97, 32, 112, 114, 101, 99, 105, 115, 105, 111,
  110, 32, 119, 105, 108, 108, 32, 98, 101, 32, 112, 114, 101, 115, 101, 114,
  118, 101, 100, 32, 119, 104, 101, 110, 32, 115, 97, 118, 105, 110, 103, 32,
  105, 109, 97, 103, 101, 115, 46, 10, 92, 110, 32, 32, 45, 32, 70, 105,
  108, 101, 32, 111, 112, 116, 105, 111, 110, 115, 32, 99, 97, 110, 47, 109,
  117, 115, 116, 32, 98, 101, 32, 115, 101, 116, 32, 102, 111, 114, 32, 116,
  104, 101, 115, 101, 32, 115, 112, 101, 99, 105, 102, 105, 99, 32, 102, 105,
  108, 101, 32, 102, 111, 114, 109, 97, 116, 115, 58, 10, 92, 110, 32, 32,
  32, 32, 46, 32, 86, 105, 100, 101, 111, 32, 102, 105, 108, 101, 115, 58,
  32, 79, 110, 108, 121, 32, 115, 117, 98, 45, 102, 114, 97, 109, 101, 115,
  32, 111, 102, 32, 97, 110, 32, 105, 109, 97, 103, 101, 32, 115, 101, 113,
  117, 101, 110, 99, 101, 32, 109, 97, 121, 32, 98, 101, 32, 108, 111, 97,
  100, 101, 100, 44, 32, 117, 115, 105, 110, 103, 32, 116, 104, 101, 32, 105,
  110, 112, 117, 116, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 101, 120,
  112, 114, 101, 115, 115, 105, 111, 110, 32, 39, 102, 105, 108, 101, 110, 97,
  109, 101, 46, 101, 120, 116, 44, 91, 102, 105, 114, 115, 116, 95, 102, 114,
  97, 109, 101, 91, 37, 93, 91, 44, 108, 97, 115, 116, 95, 102, 114, 97,
  109, 101, 91, 37, 93, 91, 44, 115, 116, 101, 112, 93, 93, 93, 39, 46,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 79, 117, 116, 112, 117, 116,
  32, 102, 114, 97, 109, 101, 114, 97, 116, 101, 32, 97, 110, 100, 32, 98,
  105, 116, 114, 97, 116, 101, 32, 40, 105, 110, 32, 75, 98, 47, 115, 41,
  32, 99, 97, 110, 32, 98, 101, 32, 97, 108, 115, 111, 32, 115, 101, 116,
  32, 98, 121, 32, 117, 115, 105, 110, 103, 32, 116, 104, 101, 32, 111, 117,
  116, 112, 117, 116, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 10,
  92, 110, 32, 32, 32, 32, 32, 32, 32, 39, 102, 105, 108, 101, 46, 109,
  112, 103, 44, 95, 102, 112, 115, 44, 95, 98, 105, 116, 114, 97, 116, 101,
  39, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 46, 99, 105, 109, 103,
  32, 102, 105, 108, 101, 115, 32, 58, 32, 79, 110, 108, 121, 32, 99, 114,
  111, 112, 115, 32, 97, 110, 100, 32, 115, 117, 98, 45, 105, 109, 97, 103,
  101, 115, 32, 111, 102, 32, 46, 99, 105, 109, 103, 32, 102, 105, 108, 101,
  115, 32, 99, 97, 110, 32, 98, 101, 32, 108, 111, 97, 100, 101, 100, 44,
  32, 117, 115, 105, 110, 103, 32, 116, 104, 101, 32, 105, 110, 112, 117, 116,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 101, 120, 112, 114, 101, 115, 115,
  105, 111, 110, 115, 32, 39, 102, 105, 108, 101, 110, 97, 109, 101, 46, 99,
  105, 109, 103, 44, 78, 48, 44, 78, 49, 39, 44, 32, 39, 102, 105, 108,
  101, 110, 97, 109, 101, 46, 99, 105, 109, 103, 44, 78, 48, 44, 78, 49,
  44, 120, 48, 44, 120, 49, 39, 44, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 39, 102, 105, 108, 101, 110, 97, 109, 101, 46, 99, 105, 109, 103, 44,
  78, 48, 44, 78, 49, 44, 120, 48, 44, 121, 48, 44, 120, 49, 44, 121,
  49, 39, 44, 32, 39, 102, 105, 108, 101, 110, 97, 109, 101, 46, 99, 105,
  109, 103, 44, 78, 48, 44, 78, 49, 44, 120, 48, 44, 121, 48, 44, 122,
  48, 44, 120, 49, 44, 121, 49, 44, 122, 49, 39, 44, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 39, 102, 105, 108, 101, 110, 97, 109, 101, 46, 99,
  105, 109, 103, 44, 78, 48, 44, 78, 49, 44, 120, 48, 44, 121, 48, 44,
  122, 48, 44, 99, 48, 44, 120, 49, 44, 121, 49, 44, 122, 49, 44, 99,
  49, 39, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 83, 112, 101, 99,
  105, 102, 121, 105, 110, 103, 32, 39, 45, 49, 39, 32, 102, 111, 114, 32,
  111, 110, 101, 32, 99, 111, 111, 114, 100, 105, 110, 97, 116, 101, 115, 32,
  115, 116, 97, 110, 100, 115, 32, 102, 111, 114, 32, 116, 104, 101, 32, 109,
  97, 120, 105, 109, 117, 109, 32, 112, 111, 115, 115, 105, 98, 108, 101, 32,
  118, 97, 108, 117, 101, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 46,
  114, 97, 119, 32, 98, 105, 110, 97, 114, 121, 32, 102, 105, 108, 101, 115,
  58, 32, 73, 109, 97, 103, 101, 32, 100, 105, 109, 101, 110, 115, 105, 111,
  110, 115, 32, 97, 110, 100, 32, 105, 110, 112, 117, 116, 32, 112, 105, 120,
  101, 108, 32, 116, 121, 112, 101, 32, 109, 97, 121, 32, 98, 101, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 119, 104, 101, 110, 32, 108, 111,
  97, 100, 105, 110, 103, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 46,
  114, 97, 119, 32, 102, 105, 108, 101, 115, 32, 119, 105, 116, 104, 32, 105,
  110, 112, 117, 116, 32, 101, 120, 112, 114, 101, 115, 115, 115, 105, 111, 110,
  32, 39, 102, 105, 108, 101, 110, 97, 109, 101, 46, 114, 97, 119, 91, 44,
  116, 121, 112, 101, 93, 91, 44, 119, 105, 100, 116, 104, 93, 91, 44, 104,
  101, 105, 103, 104, 116, 91, 44, 100, 101, 112, 116, 104, 91, 44, 100, 105,
  109, 93, 93, 93, 93, 39, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 73, 102, 32, 110, 111, 32, 100, 105, 109, 101, 110, 115, 105, 111, 110,
  115, 32, 97, 114, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 44,
  32, 116, 104, 101, 32, 114, 101, 115, 117, 108, 116, 105, 110, 103, 32, 105,
  109, 97, 103, 101, 32, 105, 115, 32, 97, 32, 111, 110, 101, 45, 99, 111,
  108, 117, 109, 110, 32, 118, 101, 99, 116, 111, 114, 32, 119, 105, 116, 104,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 109, 97, 120, 105, 109, 117,
  109, 32, 112, 111, 115, 115, 105, 98, 108, 101, 32, 104, 101, 105, 103, 104,
  116, 46, 32, 80, 105, 120, 101, 108, 32, 116, 121, 112, 101, 32, 99, 97,
  110, 32, 97, 108, 115, 111, 32, 98, 101, 32, 115, 112, 101, 99, 105, 102,
  105, 101, 100, 32, 119, 105, 116, 104, 32, 116, 104, 101, 32, 111, 117, 116,
  112, 117, 116, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 101, 120, 112,
  114, 101, 115, 115, 105, 111, 110, 32, 39, 102, 105, 108, 101, 46, 114, 97,
  119, 91, 44, 116, 121, 112, 101, 93, 39, 46, 10, 92, 110, 32, 32, 32,
  32, 32, 32, 32, 39, 116, 121, 112, 101, 39, 32, 99, 97, 110, 32, 98,
  101, 32, 123, 32, 98, 111, 111, 108, 32, 124, 32, 117, 99, 104, 97, 114,
  32, 124, 32, 99, 104, 97, 114, 32, 124, 32, 117, 115, 104, 111, 114, 116,
  32, 124, 32, 115, 104, 111, 114, 116, 32, 124, 32, 117, 105, 110, 116, 32,
  124, 32, 105, 110, 116, 32, 124, 32, 102, 108, 111, 97, 116, 32, 124, 32,
  100, 111, 117, 98, 108, 101, 32, 125, 46, 10, 92, 110, 32, 32, 32, 32,
  46, 32, 46, 121, 117, 118, 32, 102, 105, 108, 101, 115, 58, 32, 73, 109,
  97, 103, 101, 32, 100, 105, 109, 101, 110, 115, 105, 111, 110, 115, 32, 109,
  117, 115, 116, 32, 98, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100,
  44, 32, 97, 110, 100, 32, 111, 110, 108, 121, 32, 115, 117, 98, 45, 102,
  114, 97, 109, 101, 115, 32, 111, 102, 32, 97, 110, 32, 105, 109, 97, 103,
  101, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 115, 101, 113, 117, 101,
  110, 99, 101, 32, 109, 97, 121, 32, 98, 101, 32, 108, 111, 97, 100, 101,
  100, 44, 32, 117, 115, 105, 110, 103, 32, 116, 104, 101, 32, 105, 110, 112,
  117, 116, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 39, 102, 105, 108, 101, 110, 97, 109, 101, 46,
  121, 117, 118, 44, 119, 105, 100, 116, 104, 44, 104, 101, 105, 103, 104, 116,
  91, 44, 102, 105, 114, 115, 116, 95, 102, 114, 97, 109, 101, 91, 44, 108,
  97, 115, 116, 95, 102, 114, 97, 109, 101, 91, 44, 115, 116, 101, 112, 93,
  93, 93, 39, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 46, 116, 105,
  102, 102, 32, 102, 105, 108, 101, 115, 58, 32, 79, 110, 108, 121, 32, 115,
  117, 98, 45, 105, 109, 97, 103, 101, 115, 32, 111, 102, 32, 109, 117, 108,
  116, 105, 45, 112, 97, 103, 101, 115, 32, 116, 105, 102, 102, 32, 102, 105,
  108, 101, 115, 32, 99, 97, 110, 32, 98, 101, 32, 108, 111, 97, 100, 101,
  100, 44, 32, 117, 115, 105, 110, 103, 32, 116, 104, 101, 32, 105, 110, 112,
  117, 116, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 101, 120, 112, 114,
  101, 115, 115, 105, 111, 110, 32, 39, 102, 105, 108, 101, 110, 97, 109, 101,
  46, 116, 105, 102, 44, 91, 102, 105, 114, 115, 116, 95, 102, 114, 97, 109,
  101, 44, 91, 108, 97, 115, 116, 95, 102, 114, 97, 109, 101, 44, 91, 115,
  116, 101, 112, 93, 93, 93, 39, 46, 10, 92, 110, 32, 32, 32, 32, 46,
  32, 46, 103, 105, 102, 32, 102, 105, 108, 101, 115, 58, 32, 65, 110, 105,
  109, 97, 116, 101, 100, 32, 103, 105, 102, 32, 102, 105, 108, 101, 115, 32,
  99, 97, 110, 32, 98, 101, 32, 115, 97, 118, 101, 100, 44, 32, 117, 115,
  105, 110, 103, 32, 116, 104, 101, 32, 105, 110, 112, 117, 116, 32, 101, 120,
  112, 114, 101, 115, 115, 105, 111, 110, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 39, 102, 105, 108, 101, 110, 97, 109, 101, 46, 103, 105, 102, 44, 102,
  112, 115, 44, 110, 98, 95, 108, 111, 111, 112, 115, 39, 46, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 83, 112, 101, 99, 105, 102, 121, 32, 39, 110,
  98, 95, 108, 111, 111, 112, 115, 61, 48, 39, 32, 116, 111, 32, 103, 101,
  116, 32, 97, 110, 32, 105, 110, 102, 105, 110, 105, 116, 101, 32, 110, 117,
  109, 98, 101, 114, 32, 111, 102, 32, 97, 110, 105, 109, 97, 116, 105, 111,
  110, 32, 108, 111, 111, 112, 115, 46, 10, 92, 110, 32, 32, 32, 32, 46,
  32, 46, 106, 112, 101, 103, 32, 102, 105, 108, 101, 115, 58, 32, 84, 104,
  101, 32, 111, 117, 116, 112, 117, 116, 32, 113, 117, 97, 108, 105, 116, 121,
  32, 109, 97, 121, 32, 98, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101,
  100, 32, 40, 105, 110, 32, 37, 41, 44, 32, 117, 115, 105, 110, 103, 32,
  116, 104, 101, 32, 111, 117, 116, 112, 117, 116, 32, 101, 120, 112, 114, 101,
  115, 115, 105, 111, 110, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 39,
  102, 105, 108, 101, 110, 97, 109, 101, 46, 106, 112, 103, 44, 51, 48, 39,
  32, 40, 104, 101, 114, 101, 44, 32, 116, 111, 32, 103, 101, 116, 32, 97,
  32, 51, 48, 37, 32, 113, 117, 97, 108, 105, 116, 121, 32, 111, 117, 116,
  112, 117, 116, 41, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 46, 109,
  110, 99, 32, 102, 105, 108, 101, 115, 58, 32, 84, 104, 101, 32, 111, 117,
  116, 112, 117, 116, 32, 104, 101, 97, 100, 101, 114, 32, 99, 97, 110, 32,
  115, 101, 116, 32, 102, 114, 111, 109, 32, 97, 110, 111, 116, 104, 101, 114,
  32, 102, 105, 108, 101, 44, 32, 117, 115, 105, 110, 103, 32, 116, 104, 101,
  32, 111, 117, 116, 112, 117, 116, 32, 101, 120, 112, 114, 101, 115, 115, 105,
  111, 110, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 39, 102, 105, 108,
  101, 110, 97, 109, 101, 46, 109, 110, 99, 44, 104, 101, 97, 100, 101, 114,
  95, 116, 101, 109, 112, 108, 97, 116, 101, 46, 109, 110, 99, 39, 46, 10,
  92, 110, 32, 32, 32, 32, 46, 32, 46, 103, 109, 105, 99, 32, 102, 105,
  108, 101, 115, 58, 32, 84, 104, 101, 115, 101, 32, 102, 105, 108, 101, 110,
  97, 109, 101, 115, 32, 97, 114, 101, 32, 97, 115, 115, 117, 109, 101, 100,
  32, 116, 111, 32, 98, 101, 32, 71, 39, 77, 73, 67, 32, 99, 117, 115,
  116, 111, 109, 32, 99, 111, 109, 109, 97, 110, 100, 115, 32, 102, 105, 108,
  101, 115, 46, 32, 76, 111, 97, 100, 105, 110, 103, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 115, 117, 99, 104, 32, 97, 32, 102, 105, 108, 101,
  32, 119, 105, 108, 108, 32, 97, 100, 100, 32, 116, 104, 101, 32, 99, 111,
  109, 109, 97, 110, 100, 115, 32, 105, 116, 32, 100, 101, 102, 105, 110, 101,
  115, 32, 116, 111, 32, 116, 104, 101, 32, 105, 110, 116, 101, 114, 112, 114,
  101, 116, 101, 114, 46, 32, 68, 101, 98, 117, 103, 32, 105, 110, 102, 111,
  115, 32, 99, 97, 110, 32, 98, 101, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 101, 110, 97, 98, 108, 101, 100, 47, 100, 105, 115, 97, 98, 108,
  101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 105, 110, 112, 117, 116, 32,
  101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 39, 102, 105, 108, 101,
  110, 97, 109, 101, 46, 103, 109, 105, 99, 44, 97, 100, 100, 95, 100, 101,
  98, 117, 103, 95, 105, 110, 102, 111, 115, 61, 123, 32, 48, 32, 124, 32,
  49, 32, 125, 39, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 73, 110,
  115, 101, 114, 116, 105, 110, 103, 32, 39, 101, 120, 116, 58, 39, 32, 111,
  110, 32, 116, 104, 101, 32, 98, 101, 103, 105, 110, 110, 105, 110, 103, 32,
  111, 102, 32, 97, 32, 102, 105, 108, 101, 110, 97, 109, 101, 32, 40, 101,
  46, 103, 46, 32, 39, 106, 112, 103, 58, 102, 105, 108, 101, 110, 97, 109,
  101, 39, 41, 32, 102, 111, 114, 99, 101, 115, 32, 71, 39, 77, 73, 67,
  32, 116, 111, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 114, 101, 97,
  100, 47, 119, 114, 105, 116, 101, 32, 116, 104, 101, 32, 102, 105, 108, 101,
  32, 97, 115, 32, 105, 116, 32, 119, 111, 117, 108, 100, 32, 104, 97, 118,
  101, 32, 98, 101, 101, 110, 32, 100, 111, 110, 101, 32, 105, 102, 32, 105,
  116, 32, 104, 97, 100, 32, 116, 104, 101, 32, 115, 112, 101, 99, 105, 102,
  105, 101, 100, 32, 101, 120, 116, 101, 110, 115, 105, 111, 110, 46, 10, 92,
  110, 32, 32, 45, 32, 83, 111, 109, 101, 32, 105, 110, 112, 117, 116, 47,
  111, 117, 116, 112, 117, 116, 32, 102, 111, 114, 109, 97, 116, 115, 32, 97,
  110, 100, 32, 111, 112, 116, 105, 111, 110, 115, 32, 109, 97, 121, 32, 110,
  111, 116, 32, 98, 101, 32, 115, 117, 112, 112, 111, 114, 116, 101, 100, 32,
  98, 121, 32, 121, 111, 117, 114, 32, 99, 117, 114, 114, 101, 110, 116, 32,
  118, 101, 114, 115, 105, 111, 110, 32, 111, 102, 10, 92, 110, 32, 32, 32,
  32, 32, 39, 103, 109, 105, 99, 39, 44, 32, 100, 101, 112, 101, 110, 100,
  105, 110, 103, 32, 111, 110, 32, 116, 104, 101, 32, 99, 111, 110, 102, 105,
  103, 117, 114, 97, 116, 105, 111, 110, 32, 102, 108, 97, 103, 115, 32, 115,
  101, 116, 32, 102, 111, 114, 32, 116, 104, 101, 32, 98, 117, 105, 108, 100,
  32, 111, 102, 32, 116, 104, 101, 32, 39, 103, 109, 105, 99, 39, 32, 98,
  105, 110, 97, 114, 105, 101, 115, 46, 34, 10, 45, 95, 104, 101, 108, 112,
  95, 115, 101, 99, 116, 105, 111, 110, 32, 34, 83, 117, 98, 115, 116, 105,
  116, 117, 116, 105, 111, 110, 32, 114, 117, 108, 101, 115, 34, 10, 45, 95,
  104, 101, 108, 112, 95, 112, 97, 114, 97, 103, 114, 97, 112, 104, 32, 34,
  32, 32, 45, 32, 71, 39, 77, 73, 67, 32, 105, 116, 101, 109, 115, 32,
  99, 111, 110, 116, 97, 105, 110, 105, 110, 103, 32, 39, 64, 39, 44, 32,
  39, 36, 39, 32, 111, 114, 32, 39, 123, 125, 39, 32, 109, 97, 121, 32,
  98, 101, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98,
  101, 102, 111, 114, 101, 32, 98, 101, 105, 110, 103, 32, 105, 110, 116, 101,
  114, 112, 114, 101, 116, 101, 100, 46, 32, 85, 115, 101, 10, 92, 110, 32,
  32, 32, 32, 32, 116, 104, 101, 32, 115, 117, 98, 115, 116, 105, 116, 117,
  116, 105, 110, 103, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 115,
  32, 98, 101, 108, 111, 119, 32, 116, 111, 32, 97, 99, 99, 101, 115, 115,
  32, 100, 97, 116, 97, 32, 102, 114, 111, 109, 32, 116, 104, 101, 32, 105,
  110, 116, 101, 114, 112, 114, 101, 116, 101, 114, 32, 101, 110, 118, 105, 114,
  111, 110, 109, 101, 110, 116, 58, 10, 92, 110, 32, 32, 32, 32, 46, 32,
  39, 64, 35, 39, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117,
  116, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101,
  110, 116, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 105, 109, 97,
  103, 101, 115, 32, 105, 110, 32, 116, 104, 101, 32, 108, 105, 115, 116, 46,
  10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 64, 42, 39, 32, 105, 115,
  32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32,
  116, 104, 101, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 97, 118,
  97, 105, 108, 97, 98, 108, 101, 32, 99, 112, 117, 115, 46, 10, 92, 110,
  32, 32, 32, 32, 46, 32, 39, 64, 46, 39, 32, 105, 115, 32, 115, 117,
  98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 116, 104, 101,
  32, 99, 117, 114, 114, 101, 110, 116, 32, 118, 101, 114, 115, 105, 111, 110,
  32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 116, 104, 101, 32, 71,
  39, 77, 73, 67, 32, 105, 110, 116, 101, 114, 112, 114, 101, 116, 101, 114,
  10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 64, 94, 39, 32, 105, 115,
  32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32,
  116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 118, 101, 114, 98,
  111, 115, 105, 116, 121, 32, 108, 101, 118, 101, 108, 46, 10, 92, 110, 32,
  32, 32, 32, 46, 32, 39, 64, 37, 39, 32, 105, 115, 32, 115, 117, 98,
  115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32,
  112, 105, 100, 32, 111, 102, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101,
  110, 116, 32, 112, 114, 111, 99, 101, 115, 115, 46, 10, 92, 110, 32, 32,
  32, 32, 46, 32, 39, 64, 124, 39, 32, 105, 115, 32, 115, 117, 98, 115,
  116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 99,
  117, 114, 114, 101, 110, 116, 32, 118, 97, 108, 117, 101, 32, 40, 101, 120,
  112, 114, 101, 115, 115, 101, 100, 32, 105, 110, 32, 115, 101, 99, 111, 110,
  100, 115, 41, 32, 111, 102, 32, 97, 32, 109, 105, 108, 108, 105, 115, 101,
  99, 111, 110, 100, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 112, 114,
  101, 99, 105, 115, 105, 111, 110, 32, 116, 105, 109, 101, 114, 46, 10, 92,
  110, 32, 32, 32, 32, 46, 32, 39, 64, 63, 39, 32, 105, 115, 32, 115,
  117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 116, 104,
  101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 100, 97, 116, 97, 32, 116,
  121, 112, 101, 32, 111, 102, 32, 105, 109, 97, 103, 101, 32, 112, 105, 120,
  101, 108, 115, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 64, 47,
  39, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100,
  32, 98, 121, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32,
  110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 108, 101, 118, 101, 108, 115,
  32, 105, 110, 32, 116, 104, 101, 32, 99, 111, 109, 109, 97, 110, 100, 32,
  115, 99, 111, 112, 101, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39,
  64, 123, 47, 125, 39, 32, 111, 114, 32, 39, 64, 123, 47, 44, 115, 117,
  98, 115, 101, 116, 125, 39, 32, 97, 114, 101, 32, 115, 117, 98, 115, 116,
  105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 99, 111,
  110, 116, 101, 110, 116, 32, 111, 102, 32, 116, 104, 101, 32, 103, 108, 111,
  98, 97, 108, 32, 115, 99, 111, 112, 101, 44, 32, 111, 114, 32, 97, 10,
  92, 110, 32, 32, 32, 32, 32, 32, 32, 115, 117, 98, 115, 101, 116, 32,
  111, 102, 32, 105, 116, 46, 32, 73, 102, 32, 115, 112, 101, 99, 105, 102,
  105, 101, 100, 32, 115, 117, 98, 115, 101, 116, 32, 114, 101, 102, 101, 114,
  115, 32, 116, 111, 32, 109, 117, 108, 116, 105, 112, 108, 101, 32, 115, 99,
  111, 112, 101, 32, 105, 116, 101, 109, 115, 44, 32, 116, 104, 101, 121, 32,
  97, 114, 101, 32, 115, 101, 112, 97, 114, 97, 116, 101, 100, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 98, 121, 32, 115, 108, 97, 115, 104, 101,
  115, 32, 39, 47, 39, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39,
  64, 62, 39, 32, 97, 110, 100, 32, 39, 64, 60, 39, 32, 97, 114, 101,
  32, 101, 113, 117, 105, 118, 97, 108, 101, 110, 116, 46, 32, 84, 104, 101,
  121, 32, 97, 114, 101, 32, 98, 111, 116, 104, 32, 115, 117, 98, 115, 116,
  105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 110, 117,
  109, 98, 101, 114, 32, 111, 102, 32, 110, 101, 115, 116, 101, 100, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 39, 114, 101, 112, 101, 97, 116, 45,
  100, 111, 110, 101, 39, 32, 108, 111, 111, 112, 115, 32, 116, 104, 97, 116,
  32, 97, 114, 101, 32, 99, 117, 114, 114, 101, 110, 116, 108, 121, 32, 114,
  117, 110, 110, 105, 110, 103, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32,
  39, 64, 123, 62, 125, 39, 32, 111, 114, 32, 39, 64, 123, 62, 44, 115,
  117, 98, 115, 101, 116, 125, 39, 32, 97, 114, 101, 32, 115, 117, 98, 115,
  116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 105,
  110, 100, 105, 99, 101, 32, 118, 97, 108, 117, 101, 115, 32, 40, 111, 114,
  32, 97, 32, 115, 117, 98, 115, 101, 116, 32, 111, 102, 32, 116, 104, 101,
  109, 41, 32, 111, 102, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 116,
  104, 101, 32, 114, 117, 110, 110, 105, 110, 103, 32, 39, 114, 101, 112, 101,
  97, 116, 45, 100, 111, 110, 101, 39, 32, 108, 111, 111, 112, 115, 44, 32,
  101, 120, 112, 114, 101, 115, 115, 101, 100, 32, 105, 110, 32, 116, 104, 101,
  32, 97, 115, 99, 101, 110, 100, 105, 110, 103, 32, 111, 114, 100, 101, 114,
  44, 32, 115, 116, 97, 114, 116, 105, 110, 103, 32, 102, 114, 111, 109, 32,
  48, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 73, 102, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 115, 117, 98, 115, 101, 116, 32,
  114, 101, 102, 101, 114, 115, 32, 116, 111, 32, 109, 117, 108, 116, 105, 112,
  108, 101, 32, 105, 110, 100, 105, 99, 101, 115, 44, 32, 116, 104, 101, 121,
  32, 97, 114, 101, 32, 115, 101, 112, 97, 114, 97, 116, 101, 100, 32, 98,
  121, 32, 99, 111, 109, 109, 97, 115, 32, 39, 44, 39, 46, 10, 92, 110,
  32, 32, 32, 32, 46, 32, 39, 64, 123, 60, 125, 39, 32, 111, 114, 32,
  39, 64, 123, 60, 44, 115, 117, 98, 115, 101, 116, 125, 39, 32, 100, 111,
  32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 98, 117, 116, 32, 105, 110,
  32, 100, 101, 115, 99, 101, 110, 100, 105, 110, 103, 32, 111, 114, 100, 101,
  114, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 64, 105, 110, 100,
  105, 99, 101, 39, 32, 111, 114, 32, 39, 64, 123, 105, 110, 100, 105, 99,
  101, 44, 102, 101, 97, 116, 117, 114, 101, 125, 39, 32, 97, 114, 101, 32,
  115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 116,
  104, 101, 32, 108, 105, 115, 116, 32, 111, 102, 32, 112, 105, 120, 101, 108,
  32, 118, 97, 108, 117, 101, 115, 32, 111, 102, 32, 116, 104, 101, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 105, 109, 97, 103, 101, 32, 91, 105,
  110, 100, 105, 99, 101, 93, 32, 40, 115, 101, 112, 97, 114, 97, 116, 101,
  100, 32, 98, 121, 32, 99, 111, 109, 109, 97, 115, 41, 44, 32, 111, 114,
  32, 98, 121, 32, 97, 32, 115, 112, 101, 99, 105, 102, 105, 99, 32, 102,
  101, 97, 116, 117, 114, 101, 32, 40, 111, 114, 32, 115, 117, 98, 115, 101,
  116, 41, 32, 111, 102, 32, 105, 116, 46, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 39, 105, 110, 100, 105, 99, 101, 39, 32, 99, 97, 110, 32,
  98, 101, 32, 97, 110, 32, 105, 110, 100, 105, 99, 101, 32, 111, 114, 32,
  97, 110, 32, 105, 109, 97, 103, 101, 32, 110, 97, 109, 101, 46, 32, 82,
  101, 113, 117, 101, 115, 116, 101, 100, 32, 39, 102, 101, 97, 116, 117, 114,
  101, 100, 39, 32, 99, 97, 110, 32, 98, 101, 32, 111, 110, 101, 32, 111,
  102, 58, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32,
  39, 119, 39, 58, 32, 105, 109, 97, 103, 101, 32, 119, 105, 100, 116, 104,
  32, 40, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 105, 109, 97, 103,
  101, 32, 99, 111, 108, 117, 109, 110, 115, 41, 46, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 104, 39, 58, 32, 105, 109,
  97, 103, 101, 32, 104, 101, 105, 103, 104, 116, 32, 40, 110, 117, 109, 98,
  101, 114, 32, 111, 102, 32, 105, 109, 97, 103, 101, 32, 114, 111, 119, 115,
  41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32,
  39, 100, 39, 58, 32, 105, 109, 97, 103, 101, 32, 100, 101, 112, 116, 104,
  32, 40, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 105, 109, 97, 103,
  101, 32, 115, 108, 105, 99, 101, 115, 41, 46, 10, 92, 110, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 46, 32, 39, 115, 39, 58, 32, 105, 109, 97,
  103, 101, 32, 115, 112, 101, 99, 116, 114, 117, 109, 32, 40, 110, 117, 109,
  98, 101, 114, 32, 111, 102, 32, 105, 109, 97, 103, 101, 32, 99, 104, 97,
  110, 110, 101, 108, 115, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 46, 32, 39, 119, 104, 39, 58, 32, 105, 109, 97, 103, 101,
  32, 119, 105, 100, 116, 104, 32, 120, 32, 105, 109, 97, 103, 101, 32, 104,
  101, 105, 103, 104, 116, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 46, 32, 39, 119, 104, 100, 39, 58, 32, 105, 109, 97, 103, 101,
  32, 119, 105, 100, 116, 104, 32, 120, 32, 105, 109, 97, 103, 101, 32, 104,
  101, 105, 103, 104, 116, 32, 120, 32, 105, 109, 97, 103, 101, 32, 100, 101,
  112, 116, 104, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  46, 32, 39, 119, 104, 100, 115, 39, 58, 32, 105, 109, 97, 103, 101, 32,
  119, 105, 100, 116, 104, 32, 120, 32, 105, 109, 97, 103, 101, 32, 104, 101,
  105, 103, 104, 116, 32, 120, 32, 105, 109, 97, 103, 101, 32, 100, 101, 112,
  116, 104, 32, 120, 32, 105, 109, 97, 103, 101, 32, 115, 112, 101, 99, 116,
  114, 117, 109, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 40, 105, 46, 101, 46, 32,
  110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 118, 97, 108, 117, 101, 115,
  32, 105, 110, 32, 116, 104, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101,
  100, 32, 105, 109, 97, 103, 101, 44, 32, 101, 113, 46, 32, 116, 111, 32,
  39, 35, 39, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 46, 32, 39, 114, 39, 58, 32, 105, 109, 97, 103, 101, 32, 115, 104,
  97, 114, 101, 100, 32, 115, 116, 97, 116, 101, 32, 40, 49, 44, 32, 105,
  102, 32, 116, 104, 101, 32, 112, 105, 120, 101, 108, 32, 98, 117, 102, 102,
  101, 114, 32, 105, 115, 32, 115, 104, 97, 114, 101, 100, 44, 32, 48, 32,
  111, 116, 104, 101, 114, 119, 105, 115, 101, 41, 46, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 110, 39, 58, 32, 105, 109,
  97, 103, 101, 32, 110, 97, 109, 101, 32, 111, 114, 32, 102, 105, 108, 101,
  110, 97, 109, 101, 32, 40, 105, 102, 32, 116, 104, 101, 32, 105, 109, 97,
  103, 101, 32, 104, 97, 115, 32, 98, 101, 101, 110, 32, 114, 101, 97, 100,
  32, 102, 114, 111, 109, 32, 97, 32, 102, 105, 108, 101, 41, 46, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 98, 39, 58,
  32, 105, 109, 97, 103, 101, 32, 98, 97, 115, 101, 110, 97, 109, 101, 32,
  40, 105, 46, 101, 46, 32, 102, 105, 108, 101, 110, 97, 109, 101, 32, 119,
  105, 116, 104, 111, 117, 116, 32, 116, 104, 101, 32, 102, 111, 108, 100, 101,
  114, 32, 112, 97, 116, 104, 32, 110, 111, 114, 32, 101, 120, 116, 101, 110,
  115, 105, 111, 110, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 46, 32, 39, 120, 39, 58, 32, 105, 109, 97, 103, 101, 32, 101,
  120, 116, 101, 110, 115, 105, 111, 110, 32, 40, 105, 46, 101, 32, 108, 97,
  115, 116, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 115, 32, 97, 102,
  116, 101, 114, 32, 116, 104, 101, 32, 108, 97, 115, 116, 32, 39, 46, 39,
  32, 105, 110, 32, 116, 104, 101, 32, 102, 105, 108, 101, 110, 97, 109, 101,
  41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32,
  39, 102, 39, 58, 32, 105, 109, 97, 103, 101, 32, 102, 111, 108, 100, 101,
  114, 32, 110, 97, 109, 101, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 46, 32, 39, 35, 39, 58, 32, 110, 117, 109, 98, 101, 114,
  32, 111, 102, 32, 105, 109, 97, 103, 101, 32, 118, 97, 108, 117, 101, 115,
  32, 40, 105, 46, 101, 46, 32, 119, 105, 100, 116, 104, 32, 120, 32, 104,
  101, 105, 103, 104, 116, 32, 120, 32, 100, 101, 112, 116, 104, 32, 120, 32,
  115, 112, 101, 99, 116, 114, 117, 109, 41, 46, 10, 92, 110, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 46, 32, 39, 43, 39, 58, 32, 115, 117, 109,
  32, 111, 102, 32, 97, 108, 108, 32, 112, 105, 120, 101, 108, 32, 118, 97,
  108, 117, 101, 115, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 46, 32, 39, 45, 39, 58, 32, 100, 105, 102, 102, 101, 114, 101, 110,
  99, 101, 32, 111, 102, 32, 97, 108, 108, 32, 112, 105, 120, 101, 108, 32,
  118, 97, 108, 117, 101, 115, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 46, 32, 39, 42, 39, 58, 32, 112, 114, 111, 100, 117, 99,
  116, 32, 111, 102, 32, 97, 108, 108, 32, 112, 105, 120, 101, 108, 32, 118,
  97, 108, 117, 101, 115, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 46, 32, 39, 47, 39, 58, 32, 113, 117, 111, 116, 105, 101, 110,
  116, 32, 111, 102, 32, 97, 108, 108, 32, 112, 105, 120, 101, 108, 32, 118,
  97, 108, 117, 101, 115, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 46, 32, 39, 109, 39, 58, 32, 109, 105, 110, 105, 109, 117, 109,
  32, 112, 105, 120, 101, 108, 32, 118, 97, 108, 117, 101, 46, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 77, 39, 58, 32,
  109, 97, 120, 105, 109, 117, 109, 32, 112, 105, 120, 101, 108, 32, 118, 97,
  108, 117, 101, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  46, 32, 39, 97, 39, 58, 32, 97, 118, 101, 114, 97, 103, 101, 32, 112,
  105, 120, 101, 108, 32, 118, 97, 108, 117, 101, 46, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 118, 39, 58, 32, 118, 97,
  114, 105, 97, 110, 99, 101, 32, 111, 102, 32, 112, 105, 120, 101, 108, 32,
  118, 97, 108, 117, 101, 115, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 46, 32, 39, 116, 39, 58, 32, 116, 101, 120, 116, 32, 115,
  116, 114, 105, 110, 103, 32, 98, 117, 105, 108, 116, 32, 102, 114, 111, 109,
  32, 116, 104, 101, 32, 105, 109, 97, 103, 101, 32, 118, 97, 108, 117, 101,
  115, 44, 32, 114, 101, 103, 97, 114, 100, 101, 100, 32, 97, 115, 32, 97,
  115, 99, 105, 105, 32, 99, 111, 100, 101, 115, 46, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 99, 39, 58, 32, 40, 120,
  44, 121, 44, 122, 44, 99, 41, 32, 99, 111, 111, 114, 100, 105, 110, 97,
  116, 101, 115, 32, 111, 102, 32, 116, 104, 101, 32, 109, 105, 110, 105, 109,
  117, 109, 32, 118, 97, 108, 117, 101, 44, 32, 115, 101, 112, 97, 114, 97,
  116, 101, 100, 32, 98, 121, 32, 99, 111, 109, 109, 97, 115, 32, 39, 44,
  39, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32,
  39, 67, 39, 58, 32, 40, 120, 44, 121, 44, 122, 44, 99, 41, 32, 99,
  111, 111, 114, 100, 105, 110, 97, 116, 101, 115, 32, 111, 102, 32, 116, 104,
  101, 32, 109, 97, 120, 105, 109, 117, 109, 32, 118, 97, 108, 117, 101, 44,
  32, 115, 101, 112, 97, 114, 97, 116, 101, 100, 32, 98, 121, 32, 99, 111,
  109, 109, 97, 115, 32, 39, 44, 39, 46, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 46, 32, 39, 40, 120, 91, 37, 93, 44, 95, 121,
  91, 37, 93, 44, 95, 122, 91, 37, 93, 44, 95, 99, 91, 37, 93, 44,
  95, 98, 111, 117, 110, 100, 97, 114, 121, 41, 39, 58, 32, 112, 105, 120,
  101, 108, 32, 118, 97, 108, 117, 101, 32, 97, 116, 32, 40, 120, 91, 37,
  93, 44, 121, 91, 37, 93, 44, 122, 91, 37, 93, 44, 99, 91, 37, 93,
  41, 44, 32, 119, 105, 116, 104, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  98, 111, 117, 110, 100, 97, 114, 121, 32, 99, 111, 110, 100, 105, 116, 105,
  111, 110, 115, 32, 123, 32, 48, 61, 100, 105, 114, 105, 99, 104, 108, 101,
  116, 32, 124, 32, 49, 61, 110, 101, 117, 109, 97, 110, 110, 32, 124, 32,
  50, 61, 99, 121, 99, 108, 105, 99, 32, 125, 46, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 46, 32, 65, 110, 121, 32, 111, 116, 104,
  101, 114, 32, 39, 102, 101, 97, 116, 117, 114, 101, 39, 32, 105, 115, 32,
  99, 111, 110, 115, 105, 100, 101, 114, 101, 100, 32, 101, 105, 116, 104, 101,
  114, 32, 97, 115, 32, 97, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100,
  32, 115, 117, 98, 115, 101, 116, 32, 111, 102, 32, 105, 109, 97, 103, 101,
  32, 118, 97, 108, 117, 101, 115, 44, 32, 111, 114, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 97, 115, 32, 97, 32, 109,
  97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 32, 101, 120, 112, 114,
  101, 115, 115, 105, 111, 110, 32, 116, 111, 32, 101, 118, 97, 108, 117, 97,
  116, 101, 32, 40, 97, 115, 115, 111, 99, 105, 97, 116, 101, 100, 32, 116,
  111, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109, 97, 103, 101,
  41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 70, 111, 114, 32, 105, 110, 115, 116, 97, 110, 99, 101, 44, 32, 39,
  64, 123, 45, 49, 44, 48, 45, 53, 48, 37, 125, 39, 32, 105, 115, 32,
  115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 116,
  104, 101, 32, 115, 101, 113, 117, 101, 110, 99, 101, 32, 111, 102, 32, 110,
  117, 109, 101, 114, 105, 99, 97, 108, 32, 118, 97, 108, 117, 101, 115, 10,
  92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 99, 111,
  109, 105, 110, 103, 32, 102, 114, 111, 109, 32, 116, 104, 101, 32, 102, 105,
  114, 115, 116, 32, 104, 97, 108, 102, 32, 100, 97, 116, 97, 32, 111, 102,
  32, 116, 104, 101, 32, 108, 97, 115, 116, 32, 105, 109, 97, 103, 101, 44,
  32, 115, 101, 112, 97, 114, 97, 116, 101, 100, 32, 98, 121, 32, 99, 111,
  109, 109, 97, 115, 32, 39, 44, 39, 46, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 69, 120, 112, 114, 101, 115, 115, 105,
  111, 110, 32, 39, 64, 123, 48, 44, 119, 43, 104, 125, 39, 32, 105, 115,
  32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32,
  116, 104, 101, 32, 115, 117, 109, 32, 111, 102, 32, 116, 104, 101, 32, 119,
  105, 100, 116, 104, 32, 97, 110, 100, 32, 104, 101, 105, 103, 104, 116, 32,
  111, 102, 32, 116, 104, 101, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 102, 105, 114, 115, 116, 32, 105, 109, 97, 103, 101,
  46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 64, 33, 39, 32, 105,
  115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121,
  32, 116, 104, 101, 32, 118, 105, 115, 105, 98, 105, 108, 105, 116, 121, 32,
  115, 116, 97, 116, 101, 32, 111, 102, 32, 116, 104, 101, 32, 105, 110, 115,
  116, 97, 110, 116, 32, 100, 105, 115, 112, 108, 97, 121, 32, 119, 105, 110,
  100, 111, 119, 32, 91, 48, 93, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 40, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61, 99, 108, 111,
  115, 101, 100, 32, 124, 32, 49, 61, 118, 105, 115, 105, 98, 108, 101, 32,
  125, 41, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 64, 123, 33,
  44, 102, 101, 97, 116, 117, 114, 101, 125, 39, 32, 111, 114, 32, 39, 64,
  123, 33, 105, 110, 100, 105, 99, 101, 44, 102, 101, 97, 116, 117, 114, 101,
  125, 39, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101,
  100, 32, 98, 121, 32, 97, 32, 115, 112, 101, 99, 105, 102, 105, 99, 32,
  102, 101, 97, 116, 117, 114, 101, 32, 111, 102, 32, 116, 104, 101, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 105, 110, 115, 116, 97, 110, 116, 32,
  100, 105, 115, 112, 108, 97, 121, 32, 119, 105, 110, 100, 111, 119, 32, 91,
  48, 93, 32, 40, 111, 114, 32, 91, 105, 110, 100, 105, 99, 101, 93, 44,
  32, 105, 102, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 41, 46, 32,
  82, 101, 113, 117, 101, 115, 116, 101, 100, 32, 39, 102, 101, 97, 116, 117,
  114, 101, 39, 32, 99, 97, 110, 32, 98, 101, 58, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 119, 39, 58, 32, 100, 105,
  115, 112, 108, 97, 121, 32, 119, 105, 100, 116, 104, 32, 40, 105, 46, 101,
  46, 32, 119, 105, 100, 116, 104, 32, 111, 102, 32, 116, 104, 101, 32, 100,
  105, 115, 112, 108, 97, 121, 32, 97, 114, 101, 97, 32, 109, 97, 110, 97,
  103, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 119, 105, 110, 100, 111,
  119, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46,
  32, 39, 104, 39, 58, 32, 100, 105, 115, 112, 108, 97, 121, 32, 104, 101,
  105, 103, 104, 116, 32, 40, 105, 46, 101, 46, 32, 104, 101, 105, 103, 104,
  116, 32, 111, 102, 32, 116, 104, 101, 32, 100, 105, 115, 112, 108, 97, 121,
  32, 97, 114, 101, 97, 32, 109, 97, 110, 97, 103, 101, 100, 32, 98, 121,
  32, 116, 104, 101, 32, 119, 105, 110, 100, 111, 119, 41, 46, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 119, 104, 39, 58,
  32, 100, 105, 115, 112, 108, 97, 121, 32, 119, 105, 100, 116, 104, 32, 120,
  32, 100, 105, 115, 112, 108, 97, 121, 32, 104, 101, 105, 103, 104, 116, 46,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 100,
  39, 58, 32, 119, 105, 110, 100, 111, 119, 32, 119, 105, 100, 116, 104, 32,
  40, 105, 46, 101, 46, 32, 119, 105, 100, 116, 104, 32, 111, 102, 32, 116,
  104, 101, 32, 119, 105, 110, 100, 111, 119, 32, 119, 105, 100, 103, 101, 116,
  41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32,
  39, 101, 39, 58, 32, 119, 105, 110, 100, 111, 119, 32, 104, 101, 105, 103,
  104, 116, 32, 40, 105, 46, 101, 46, 32, 104, 101, 105, 103, 104, 116, 32,
  111, 102, 32, 116, 104, 101, 32, 119, 105, 110, 100, 111, 119, 32, 119, 105,
  100, 103, 101, 116, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 46, 32, 39, 100, 101, 39, 58, 32, 119, 105, 110, 100, 111, 119,
  32, 119, 105, 100, 116, 104, 32, 120, 32, 119, 105, 110, 100, 111, 119, 32,
  104, 101, 105, 103, 104, 116, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 46, 32, 39, 117, 39, 58, 32, 115, 99, 114, 101, 101, 110,
  32, 119, 105, 100, 116, 104, 32, 40, 97, 99, 116, 117, 97, 108, 108, 121,
  32, 105, 110, 100, 101, 112, 101, 110, 100, 101, 110, 116, 32, 111, 110, 32,
  116, 104, 101, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 41,
  46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 39, 32,
  118, 39, 58, 32, 115, 99, 114, 101, 101, 110, 32, 104, 101, 105, 103, 104,
  116, 32, 40, 97, 99, 116, 117, 97, 108, 108, 121, 32, 105, 110, 100, 101,
  112, 101, 110, 100, 101, 110, 116, 32, 111, 110, 32, 116, 104, 101, 32, 119,
  105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 41, 46, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 117, 118, 39, 58, 32,
  115, 99, 114, 101, 101, 110, 32, 119, 105, 100, 116, 104, 32, 120, 32, 115,
  99, 114, 101, 101, 110, 32, 104, 101, 105, 103, 104, 116, 46, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 120, 39, 58, 32,
  88, 45, 99, 111, 111, 114, 100, 105, 110, 97, 116, 101, 32, 111, 102, 32,
  116, 104, 101, 32, 109, 111, 117, 115, 101, 32, 112, 111, 115, 105, 116, 105,
  111, 110, 32, 40, 111, 114, 32, 45, 49, 44, 32, 105, 102, 32, 111, 117,
  116, 115, 105, 100, 101, 32, 116, 104, 101, 32, 100, 105, 115, 112, 108, 97,
  121, 32, 97, 114, 101, 97, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 46, 32, 39, 121, 39, 58, 32, 89, 45, 99, 111, 111,
  114, 100, 105, 110, 97, 116, 101, 32, 111, 102, 32, 116, 104, 101, 32, 109,
  111, 117, 115, 101, 32, 112, 111, 115, 105, 116, 105, 111, 110, 32, 40, 111,
  114, 32, 45, 49, 44, 32, 105, 102, 32, 111, 117, 116, 115, 105, 100, 101,
  32, 116, 104, 101, 32, 100, 105, 115, 112, 108, 97, 121, 32, 97, 114, 101,
  97, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46,
  32, 39, 98, 39, 58, 32, 115, 116, 97, 116, 101, 32, 111, 102, 32, 116,
  104, 101, 32, 109, 111, 117, 115, 101, 32, 98, 117, 116, 116, 111, 110, 115,
  32, 123, 32, 49, 61, 108, 101, 102, 116, 45, 98, 117, 116, 46, 32, 124,
  32, 50, 61, 114, 105, 103, 104, 116, 45, 98, 117, 116, 46, 32, 124, 32,
  52, 61, 109, 105, 100, 100, 108, 101, 45, 98, 117, 116, 46, 32, 125, 46,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 111,
  39, 58, 32, 115, 116, 97, 116, 101, 32, 111, 102, 32, 116, 104, 101, 32,
  109, 111, 117, 115, 101, 32, 119, 104, 101, 101, 108, 46, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 107, 39, 58, 32, 100,
  101, 99, 105, 109, 97, 108, 32, 99, 111, 100, 101, 32, 111, 102, 32, 116,
  104, 101, 32, 112, 114, 101, 115, 115, 101, 100, 32, 107, 101, 121, 32, 105,
  102, 32, 97, 110, 121, 44, 32, 48, 32, 111, 116, 104, 101, 114, 119, 105,
  115, 101, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46,
  32, 39, 110, 39, 58, 32, 99, 117, 114, 114, 101, 110, 116, 32, 110, 111,
  114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110, 32, 116, 121, 112, 101,
  32, 111, 102, 32, 116, 104, 101, 32, 105, 110, 115, 116, 97, 110, 116, 32,
  100, 105, 115, 112, 108, 97, 121, 46, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 46, 32, 39, 99, 39, 58, 32, 98, 111, 111, 108, 101,
  97, 110, 32, 40, 48, 32, 111, 114, 32, 49, 41, 32, 116, 101, 108, 108,
  105, 110, 103, 32, 105, 102, 32, 116, 104, 101, 32, 105, 110, 115, 116, 97,
  110, 116, 32, 100, 105, 115, 112, 108, 97, 121, 32, 104, 97, 115, 32, 98,
  101, 101, 110, 32, 99, 108, 111, 115, 101, 100, 32, 114, 101, 99, 101, 110,
  116, 108, 121, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  46, 32, 39, 114, 39, 58, 32, 98, 111, 111, 108, 101, 97, 110, 32, 116,
  101, 108, 108, 105, 110, 103, 32, 105, 102, 32, 116, 104, 101, 32, 105, 110,
  115, 116, 97, 110, 116, 32, 100, 105, 115, 112, 108, 97, 121, 32, 104, 97,
  115, 32, 98, 101, 101, 110, 32, 114, 101, 115, 105, 122, 101, 100, 32, 114,
  101, 99, 101, 110, 116, 108, 121, 46, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 46, 32, 39, 109, 39, 58, 32, 98, 111, 111, 108, 101,
  97, 110, 32, 116, 101, 108, 108, 105, 110, 103, 32, 105, 102, 32, 116, 104,
  101, 32, 105, 110, 115, 116, 97, 110, 116, 32, 100, 105, 115, 112, 108, 97,
  121, 32, 104, 97, 115, 32, 98, 101, 101, 110, 32, 109, 111, 118, 101, 100,
  32, 114, 101, 99, 101, 110, 116, 108, 121, 46, 10, 92, 110, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 46, 32, 65, 110, 121, 32, 111, 116, 104, 101,
  114, 32, 39, 102, 101, 97, 116, 117, 114, 101, 39, 32, 115, 116, 97, 110,
  100, 115, 32, 102, 111, 114, 32, 97, 32, 107, 101, 121, 99, 111, 100, 101,
  32, 110, 97, 109, 101, 32, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108,
  32, 108, 101, 116, 116, 101, 114, 115, 44, 32, 97, 110, 100, 32, 105, 115,
  32, 115, 117, 98, 115, 116, 105, 45, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 116, 117, 116, 101, 100, 32, 98, 121, 32,
  97, 32, 98, 111, 111, 108, 101, 97, 110, 32, 100, 101, 115, 99, 114, 105,
  98, 105, 110, 103, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116,
  32, 107, 101, 121, 32, 115, 116, 97, 116, 101, 32, 123, 32, 48, 61, 112,
  114, 101, 115, 115, 101, 100, 32, 124, 32, 49, 61, 114, 101, 108, 101, 97,
  115, 101, 100, 32, 125, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39,
  64, 123, 92, 34, 99, 111, 109, 109, 97, 110, 100, 32, 108, 105, 110, 101,
  92, 34, 125, 39, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117,
  116, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 115, 116, 97, 116, 117,
  115, 32, 118, 97, 108, 117, 101, 32, 115, 101, 116, 32, 98, 121, 32, 116,
  104, 101, 32, 101, 120, 101, 99, 117, 116, 105, 111, 110, 32, 111, 102, 32,
  116, 104, 101, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 115, 112, 101,
  99, 105, 102, 105, 101, 100, 32, 99, 111, 109, 109, 97, 110, 100, 32, 108,
  105, 110, 101, 32, 40, 115, 101, 101, 32, 99, 111, 109, 109, 97, 110, 100,
  32, 39, 45, 115, 116, 97, 116, 117, 115, 39, 41, 46, 10, 92, 110, 32,
  32, 32, 32, 46, 32, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32,
  39, 64, 123, 125, 39, 32, 115, 116, 97, 110, 100, 115, 32, 116, 104, 117,
  115, 32, 102, 111, 114, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110,
  116, 32, 115, 116, 97, 116, 117, 115, 32, 118, 97, 108, 117, 101, 46, 10,
  92, 110, 32, 32, 45, 32, 39, 36, 110, 97, 109, 101, 39, 32, 97, 110,
  100, 32, 39, 36, 123, 110, 97, 109, 101, 125, 39, 32, 97, 114, 101, 32,
  98, 111, 116, 104, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100,
  32, 98, 121, 32, 116, 104, 101, 32, 118, 97, 108, 117, 101, 32, 111, 102,
  32, 116, 104, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 110,
  97, 109, 101, 100, 32, 118, 97, 114, 105, 97, 98, 108, 101, 10, 92, 110,
  32, 32, 32, 32, 32, 40, 115, 101, 116, 32, 112, 114, 101, 118, 105, 111,
  117, 115, 108, 121, 32, 98, 121, 32, 105, 116, 101, 109, 32, 39, 110, 97,
  109, 101, 61, 118, 97, 108, 117, 101, 39, 41, 44, 32, 111, 114, 32, 98,
  121, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 112, 111,
  115, 105, 116, 105, 118, 101, 32, 105, 110, 100, 105, 99, 101, 32, 111, 102,
  32, 116, 104, 101, 32, 110, 97, 109, 101, 100, 10, 92, 110, 32, 32, 32,
  32, 32, 105, 109, 97, 103, 101, 32, 39, 91, 110, 97, 109, 101, 93, 39,
  44, 32, 111, 114, 32, 98, 121, 32, 116, 104, 101, 32, 118, 97, 108, 117,
  101, 32, 111, 102, 32, 116, 104, 101, 32, 110, 97, 109, 101, 100, 32, 79,
  83, 32, 101, 110, 118, 105, 114, 111, 110, 109, 101, 110, 116, 32, 118, 97,
  114, 105, 97, 98, 108, 101, 32, 40, 105, 110, 32, 116, 104, 105, 115, 32,
  111, 114, 100, 101, 114, 41, 46, 10, 92, 110, 32, 32, 45, 32, 39, 36,
  62, 39, 32, 97, 110, 100, 32, 39, 36, 60, 39, 32, 40, 114, 101, 115,
  112, 46, 32, 39, 36, 123, 62, 125, 39, 32, 97, 110, 100, 32, 39, 36,
  123, 60, 125, 39, 41, 32, 97, 114, 101, 32, 115, 104, 111, 114, 116, 99,
  117, 116, 115, 32, 114, 101, 115, 112, 101, 99, 116, 105, 118, 101, 108, 121,
  32, 102, 111, 114, 32, 39, 64, 123, 62, 44, 45, 49, 125, 39, 32, 97,
  110, 100, 10, 92, 110, 32, 32, 32, 32, 32, 39, 64, 123, 60, 44, 45,
  49, 125, 39, 46, 32, 84, 104, 101, 121, 32, 114, 101, 102, 101, 114, 32,
  116, 111, 32, 116, 104, 101, 32, 105, 110, 99, 114, 101, 97, 115, 105, 110,
  103, 47, 100, 101, 99, 114, 101, 97, 115, 105, 110, 103, 32, 105, 110, 100,
  105, 99, 101, 32, 111, 102, 32, 116, 104, 101, 32, 108, 97, 116, 101, 115,
  116, 32, 40, 99, 117, 114, 114, 101, 110, 116, 108, 121, 10, 92, 110, 32,
  32, 32, 32, 32, 114, 117, 110, 110, 105, 110, 103, 41, 32, 39, 114, 101,
  112, 101, 97, 116, 46, 46, 100, 111, 110, 101, 39, 32, 108, 111, 111, 112,
  46, 10, 92, 110, 32, 32, 45, 32, 65, 110, 121, 32, 111, 116, 104, 101,
  114, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 105, 110, 115,
  105, 100, 101, 32, 98, 114, 97, 99, 101, 115, 32, 40, 97, 115, 32, 105,
  110, 32, 39, 123, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 125, 39,
  41, 32, 105, 115, 32, 99, 111, 110, 115, 105, 100, 101, 114, 101, 100, 32,
  97, 115, 32, 97, 32, 109, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97,
  108, 10, 92, 110, 32, 32, 32, 32, 32, 101, 120, 112, 114, 101, 115, 115,
  105, 111, 110, 44, 32, 97, 110, 100, 32, 105, 115, 32, 101, 118, 97, 108,
  117, 97, 116, 101, 100, 44, 32, 101, 120, 99, 101, 112, 116, 32, 102, 111,
  114, 32, 116, 104, 101, 32, 116, 104, 114, 101, 101, 32, 102, 111, 108, 108,
  111, 119, 105, 110, 103, 32, 99, 97, 115, 101, 115, 58, 10, 92, 110, 32,
  32, 32, 32, 46, 32, 73, 102, 32, 101, 120, 112, 114, 101, 115, 115, 105,
  111, 110, 32, 115, 116, 97, 114, 116, 115, 32, 97, 110, 100, 32, 101, 110,
  100, 115, 32, 98, 121, 32, 115, 105, 110, 103, 108, 101, 32, 113, 117, 111,
  116, 101, 115, 44, 32, 105, 116, 32, 105, 115, 32, 115, 117, 98, 115, 116,
  105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 115, 101,
  113, 117, 101, 110, 99, 101, 32, 111, 102, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 97, 115, 99, 105, 105, 32, 99, 111, 100, 101, 115, 32, 116,
  104, 97, 116, 32, 99, 111, 109, 112, 111, 115, 101, 115, 32, 116, 104, 101,
  32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 115, 116, 114, 105, 110,
  103, 44, 32, 115, 101, 112, 97, 114, 97, 116, 101, 100, 32, 98, 121, 32,
  99, 111, 109, 109, 97, 115, 32, 39, 44, 39, 46, 32, 70, 111, 114, 32,
  105, 110, 115, 116, 97, 110, 99, 101, 44, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 105, 116, 101, 109, 32, 39, 123, 39, 102, 111, 111, 39, 125,
  39, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100,
  32, 98, 121, 32, 39, 49, 48, 50, 44, 49, 49, 49, 44, 49, 49, 49,
  39, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 73, 102, 32, 101, 120,
  112, 114, 101, 115, 115, 105, 111, 110, 32, 115, 116, 97, 114, 116, 115, 32,
  97, 110, 100, 32, 101, 110, 100, 115, 32, 119, 105, 116, 104, 32, 98, 97,
  99, 107, 113, 117, 111, 116, 101, 115, 32, 39, 96, 39, 44, 32, 105, 116,
  32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32,
  98, 121, 32, 116, 104, 101, 32, 115, 116, 114, 105, 110, 103, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 119, 104, 111, 115, 101, 32, 97, 115, 99,
  105, 105, 32, 99, 111, 100, 101, 115, 32, 97, 114, 101, 32, 103, 105, 118,
  101, 110, 32, 98, 121, 32, 116, 104, 101, 32, 108, 105, 115, 116, 32, 111,
  102, 32, 118, 97, 108, 117, 101, 115, 32, 105, 110, 32, 98, 101, 116, 119,
  101, 101, 110, 32, 116, 104, 101, 32, 98, 97, 99, 107, 113, 117, 111, 116,
  101, 115, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 70, 111, 114,
  32, 105, 110, 115, 116, 97, 110, 99, 101, 44, 32, 105, 116, 101, 109, 32,
  39, 123, 96, 49, 48, 50, 44, 49, 49, 49, 44, 49, 49, 49, 96, 125,
  39, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100,
  32, 98, 121, 32, 39, 102, 111, 111, 39, 46, 10, 92, 110, 32, 32, 32,
  32, 46, 32, 73, 102, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110,
  32, 99, 111, 110, 116, 97, 105, 110, 115, 32, 111, 112, 101, 114, 97, 116,
  111, 114, 32, 39, 39, 61, 61, 39, 39, 32, 111, 114, 32, 39, 39, 33,
  61, 39, 39, 44, 32, 105, 116, 32, 105, 115, 32, 115, 117, 98, 115, 116,
  105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 48, 32, 111, 114, 32, 49,
  44, 32, 119, 104, 101, 116, 104, 101, 114, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 116, 104, 101, 32, 115, 116, 114, 105, 110, 103, 115, 32, 98,
  101, 115, 105, 100, 101, 32, 116, 104, 101, 32, 111, 112, 101, 114, 97, 116,
  111, 114, 32, 97, 114, 101, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32,
  111, 114, 32, 110, 111, 116, 32, 40, 99, 97, 115, 101, 45, 115, 101, 110,
  115, 105, 116, 105, 118, 101, 41, 46, 32, 70, 111, 114, 32, 105, 110, 115,
  116, 97, 110, 99, 101, 44, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  98, 111, 116, 104, 32, 105, 116, 101, 109, 115, 32, 39, 123, 102, 111, 111,
  39, 61, 61, 39, 102, 111, 111, 125, 39, 32, 97, 110, 100, 32, 39, 123,
  102, 111, 111, 39, 33, 61, 39, 70, 79, 79, 125, 39, 32, 97, 114, 101,
  32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32,
  39, 49, 39, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 73, 102, 32,
  101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 115, 116, 97, 114, 116,
  115, 32, 119, 105, 116, 104, 32, 97, 110, 32, 117, 110, 100, 101, 114, 115,
  99, 111, 114, 101, 32, 39, 95, 39, 44, 32, 105, 116, 32, 105, 115, 32,
  115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 116,
  104, 101, 32, 109, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 10,
  92, 110, 32, 32, 32, 32, 32, 32, 32, 101, 118, 97, 108, 117, 97, 116,
  105, 111, 110, 32, 111, 102, 32, 116, 104, 101, 32, 101, 120, 112, 114, 101,
  115, 115, 105, 111, 110, 44, 32, 116, 114, 117, 110, 99, 97, 116, 101, 100,
  32, 116, 111, 32, 97, 32, 114, 101, 97, 100, 97, 98, 108, 101, 32, 102,
  111, 114, 109, 97, 116, 46, 10, 92, 110, 32, 32, 45, 32, 73, 116, 101,
  109, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 105, 111, 110, 32, 105,
  115, 32, 110, 101, 118, 101, 114, 32, 100, 111, 110, 101, 32, 105, 110, 32,
  105, 116, 101, 109, 115, 32, 98, 101, 116, 119, 101, 101, 110, 32, 100, 111,
  117, 98, 108, 101, 32, 113, 117, 111, 116, 101, 115, 46, 32, 79, 110, 101,
  32, 109, 117, 115, 116, 32, 98, 114, 101, 97, 107, 32, 116, 104, 101, 32,
  113, 117, 111, 116, 101, 115, 10, 92, 110, 32, 32, 32, 32, 116, 111, 32,
  101, 110, 97, 98, 108, 101, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116,
  105, 111, 110, 32, 105, 102, 32, 110, 101, 101, 100, 101, 100, 44, 32, 97,
  115, 32, 105, 110, 32, 92, 34, 51, 43, 56, 32, 107, 103, 32, 61, 32,
  92, 34, 123, 51, 43, 56, 125, 92, 34, 32, 107, 103, 92, 34, 46, 32,
  85, 115, 105, 110, 103, 32, 100, 111, 117, 98, 108, 101, 32, 113, 117, 111,
  116, 101, 115, 10, 92, 110, 32, 32, 32, 32, 105, 115, 32, 116, 104, 101,
  110, 32, 97, 32, 99, 111, 110, 118, 101, 110, 105, 101, 110, 116, 32, 119,
  97, 121, 32, 116, 111, 32, 100, 105, 115, 97, 98, 108, 101, 32, 116, 104,
  101, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 105, 111, 110, 115, 32,
  109, 101, 99, 104, 97, 110, 105, 115, 109, 32, 105, 110, 32, 105, 116, 101,
  109, 115, 44, 32, 119, 104, 101, 110, 32, 110, 101, 99, 101, 115, 115, 97,
  114, 121, 46, 10, 92, 110, 32, 32, 45, 32, 79, 110, 101, 32, 99, 97,
  110, 32, 97, 108, 115, 111, 32, 100, 105, 115, 97, 98, 108, 101, 32, 116,
  104, 101, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 105, 111, 110, 32,
  109, 101, 99, 104, 97, 110, 105, 115, 109, 32, 111, 110, 32, 105, 116, 101,
  109, 115, 32, 111, 117, 116, 115, 105, 100, 101, 32, 100, 111, 117, 98, 108,
  101, 32, 113, 117, 111, 116, 101, 115, 44, 32, 98, 121, 10, 92, 110, 32,
  32, 32, 32, 32, 101, 115, 99, 97, 112, 105, 110, 103, 32, 116, 104, 101,
  32, 39, 64, 39, 44, 39, 123, 39, 44, 39, 125, 39, 32, 111, 114, 32,
  39, 36, 39, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 115, 44, 32,
  97, 115, 32, 105, 110, 32, 39, 92, 92, 123, 51, 43, 52, 92, 92, 125,
  92, 92, 32, 100, 111, 101, 115, 110, 39, 116, 92, 92, 32, 101, 118, 97,
  108, 117, 97, 116, 101, 39, 46, 34, 10, 45, 95, 104, 101, 108, 112, 95,
  115, 101, 99, 116, 105, 111, 110, 32, 34, 77, 97, 116, 104, 101, 109, 97,
  116, 105, 99, 97, 108, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110,
  115, 34, 10, 45, 95, 104, 101, 108, 112, 95, 112, 97, 114, 97, 103, 114,
  97, 112, 104, 32, 34, 32, 32, 45, 32, 71, 39, 77, 73, 67, 32, 104,
  97, 115, 32, 97, 110, 32, 101, 109, 98, 101, 100, 100, 101, 100, 32, 109,
  97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 32, 112, 97, 114, 115,
  101, 114, 46, 32, 73, 116, 32, 105, 115, 32, 117, 115, 101, 100, 32, 116,
  111, 32, 101, 118, 97, 108, 117, 97, 116, 101, 32, 101, 120, 112, 114, 101,
  115, 115, 105, 111, 110, 115, 32, 105, 110, 115, 105, 100, 101, 10, 92, 110,
  32, 32, 32, 32, 32, 98, 114, 97, 99, 101, 115, 32, 39, 123, 125, 39,
  44, 32, 111, 114, 32, 102, 111, 114, 109, 117, 108, 97, 115, 32, 105, 110,
  32, 99, 111, 109, 109, 97, 110, 100, 115, 32, 116, 104, 97, 116, 32, 109,
  97, 121, 32, 116, 97, 107, 101, 32, 111, 110, 101, 32, 97, 115, 32, 97,
  110, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 40, 101, 46, 103, 46,
  32, 39, 45, 102, 105, 108, 108, 39, 41, 46, 10, 92, 110, 32, 32, 45,
  32, 87, 104, 101, 110, 32, 117, 115, 101, 100, 32, 105, 110, 32, 99, 111,
  109, 109, 97, 110, 100, 115, 44, 32, 97, 32, 102, 111, 114, 109, 117, 108,
  97, 32, 105, 115, 32, 101, 118, 97, 108, 117, 97, 116, 101, 100, 32, 102,
  111, 114, 32, 101, 97, 99, 104, 32, 112, 105, 120, 101, 108, 32, 111, 102,
  32, 116, 104, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 105, 109,
  97, 103, 101, 115, 46, 10, 92, 110, 32, 32, 45, 32, 84, 104, 101, 32,
  109, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 32, 112, 97, 114,
  115, 101, 114, 32, 117, 110, 100, 101, 114, 115, 116, 97, 110, 100, 115, 32,
  116, 104, 101, 32, 102, 111, 108, 108, 111, 119, 105, 110, 103, 32, 115, 101,
  116, 32, 111, 102, 32, 102, 117, 110, 99, 116, 105, 111, 110, 115, 44, 32,
  111, 112, 101, 114, 97, 116, 111, 114, 115, 32, 97, 110, 100, 32, 118, 97,
  114, 105, 97, 98, 108, 101, 115, 58, 10, 92, 110, 32, 32, 32, 32, 95,
  32, 85, 115, 117, 97, 108, 32, 111, 112, 101, 114, 97, 116, 111, 114, 115,
  58, 32, 124, 124, 32, 40, 108, 111, 103, 105, 99, 97, 108, 32, 111, 114,
  41, 44, 32, 38, 38, 32, 40, 108, 111, 103, 105, 99, 97, 108, 32, 97,
  110, 100, 41, 44, 32, 124, 32, 40, 98, 105, 116, 119, 105, 115, 101, 32,
  111, 114, 41, 44, 32, 38, 32, 40, 98, 105, 116, 119, 105, 115, 101, 32,
  97, 110, 100, 41, 44, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 33,
  61, 44, 32, 61, 61, 44, 32, 60, 61, 44, 32, 62, 61, 44, 32, 60,
  44, 32, 62, 44, 32, 60, 60, 32, 40, 108, 101, 102, 116, 32, 98, 105,
  116, 119, 105, 115, 101, 32, 115, 104, 105, 102, 116, 41, 44, 32, 62, 62,
  32, 40, 114, 105, 103, 104, 116, 32, 98, 105, 116, 119, 105, 115, 101, 32,
  115, 104, 105, 102, 116, 41, 44, 32, 45, 44, 32, 43, 44, 32, 42, 44,
  32, 47, 44, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 37, 32, 40,
  109, 111, 100, 117, 108, 111, 41, 44, 32, 94, 32, 40, 112, 111, 119, 101,
  114, 41, 44, 32, 33, 32, 40, 108, 111, 103, 105, 99, 97, 108, 32, 110,
  111, 116, 41, 44, 32, 126, 32, 40, 98, 105, 116, 119, 105, 115, 101, 32,
  110, 111, 116, 41, 46, 10, 92, 110, 32, 32, 32, 32, 95, 32, 85, 115,
  117, 97, 108, 32, 102, 117, 110, 99, 116, 105, 111, 110, 115, 58, 32, 115,
  105, 110, 40, 41, 44, 32, 99, 111, 115, 40, 41, 44, 32, 116, 97, 110,
  40, 41, 44, 32, 97, 115, 105, 110, 40, 41, 44, 32, 97, 99, 111, 115,
  40, 41, 44, 32, 97, 116, 97, 110, 40, 41, 44, 32, 115, 105, 110, 104,
  40, 41, 44, 32, 99, 111, 115, 104, 40, 41, 44, 32, 116, 97, 110, 104,
  40, 41, 44, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 108, 111, 103,
  40, 41, 44, 32, 108, 111, 103, 50, 40, 41, 44, 32, 108, 111, 103, 49,
  48, 40, 41, 44, 32, 101, 120, 112, 40, 41, 44, 32, 115, 105, 103, 110,
  40, 41, 44, 32, 97, 98, 115, 40, 41, 44, 32, 97, 116, 97, 110, 50,
  40, 41, 44, 32, 114, 111, 117, 110, 100, 40, 41, 44, 32, 110, 97, 114,
  103, 40, 41, 44, 32, 97, 114, 103, 40, 41, 44, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 105, 115, 118, 97, 108, 40, 41, 44, 32, 105, 115,
  110, 97, 110, 40, 41, 44, 32, 105, 115, 105, 110, 102, 40, 41, 44, 32,
  105, 115, 105, 110, 116, 40, 41, 44, 32, 105, 115, 98, 111, 111, 108, 40,
  41, 44, 32, 114, 111, 108, 40, 41, 32, 40, 108, 101, 102, 116, 32, 98,
  105, 116, 32, 114, 111, 116, 97, 116, 105, 111, 110, 41, 44, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 114, 111, 114, 40, 41, 32, 40, 114, 105,
  103, 104, 116, 32, 98, 105, 116, 32, 114, 111, 116, 97, 116, 105, 111, 110,
  41, 44, 32, 109, 105, 110, 40, 41, 44, 32, 109, 97, 120, 40, 41, 44,
  32, 115, 105, 110, 99, 40, 41, 44, 32, 105, 110, 116, 40, 41, 46, 10,
  92, 110, 32, 32, 32, 32, 32, 32, 32, 70, 117, 110, 99, 116, 105, 111,
  110, 32, 39, 97, 116, 97, 110, 50, 40, 41, 39, 32, 105, 115, 32, 116,
  104, 101, 32, 118, 101, 114, 115, 105, 111, 110, 32, 111, 102, 32, 97, 116,
  97, 110, 40, 41, 32, 119, 105, 116, 104, 32, 116, 119, 111, 32, 97, 114,
  103, 117, 109, 101, 110, 116, 115, 32, 39, 121, 44, 120, 39, 32, 40, 97,
  115, 32, 105, 110, 32, 67, 47, 67, 43, 43, 41, 46, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 70, 117, 110, 99, 116, 105, 111, 110, 32, 39,
  110, 97, 114, 103, 40, 41, 39, 32, 114, 101, 116, 117, 114, 110, 115, 32,
  116, 104, 101, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 97, 114, 103, 117, 109, 101, 110, 116,
  115, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 70, 117, 110, 99,
  116, 105, 111, 110, 32, 39, 97, 114, 103, 40, 105, 44, 97, 95, 49, 44,
  46, 46, 44, 97, 95, 110, 41, 39, 32, 114, 101, 116, 117, 114, 110, 115,
  32, 116, 104, 101, 32, 105, 116, 104, 32, 97, 114, 103, 117, 109, 101, 110,
  116, 32, 97, 95, 105, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  70, 117, 110, 99, 116, 105, 111, 110, 115, 32, 39, 109, 105, 110, 40, 41,
  39, 32, 97, 110, 100, 32, 39, 109, 97, 120, 40, 41, 39, 32, 99, 97,
  110, 32, 98, 101, 32, 99, 97, 108, 108, 101, 100, 32, 119, 105, 116, 104,
  32, 97, 110, 32, 97, 114, 98, 105, 116, 114, 97, 114, 121, 32, 110, 117,
  109, 98, 101, 114, 32, 111, 102, 32, 97, 114, 103, 117, 109, 101, 110, 116,
  115, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 70, 117, 110, 99,
  116, 105, 111, 110, 115, 32, 39, 105, 115, 118, 97, 108, 40, 41, 39, 44,
  32, 39, 105, 115, 110, 97, 110, 40, 41, 39, 44, 32, 39, 105, 115, 105,
  110, 102, 40, 41, 39, 44, 32, 39, 105, 115, 98, 111, 111, 108, 40, 41,
  39, 32, 99, 97, 110, 32, 98, 101, 32, 117, 115, 101, 100, 32, 116, 111,
  32, 116, 101, 115, 116, 32, 116, 104, 101, 32, 116, 121, 112, 101, 32, 111,
  102, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 97, 32, 103, 105, 118,
  101, 110, 32, 110, 117, 109, 98, 101, 114, 32, 111, 114, 32, 101, 120, 112,
  114, 101, 115, 115, 105, 111, 110, 46, 10, 92, 110, 32, 32, 32, 32, 95,
  32, 84, 104, 101, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 110, 97,
  109, 101, 115, 32, 98, 101, 108, 111, 119, 32, 97, 114, 101, 32, 112, 114,
  101, 45, 100, 101, 102, 105, 110, 101, 100, 46, 32, 84, 104, 101, 121, 32,
  99, 97, 110, 32, 98, 101, 32, 111, 118, 101, 114, 108, 111, 97, 100, 101,
  100, 32, 105, 102, 32, 110, 101, 99, 101, 115, 115, 97, 114, 121, 46, 10,
  92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 119, 39,
  58, 32, 119, 105, 100, 116, 104, 32, 111, 102, 32, 116, 104, 101, 32, 97,
  115, 115, 111, 99, 105, 97, 116, 101, 100, 32, 105, 109, 97, 103, 101, 44,
  32, 105, 102, 32, 97, 110, 121, 32, 40, 48, 32, 111, 116, 104, 101, 114,
  119, 105, 115, 101, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 46, 32, 39, 104, 39, 58, 32, 104, 101, 105, 103, 104, 116, 32,
  111, 102, 32, 116, 104, 101, 32, 97, 115, 115, 111, 99, 105, 97, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 44, 32, 105, 102, 32, 97, 110, 121, 32,
  40, 48, 32, 111, 116, 104, 101, 114, 119, 105, 115, 101, 41, 46, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 100, 39, 58,
  32, 100, 101, 112, 116, 104, 32, 111, 102, 32, 116, 104, 101, 32, 97, 115,
  115, 111, 99, 105, 97, 116, 101, 100, 32, 105, 109, 97, 103, 101, 44, 32,
  105, 102, 32, 97, 110, 121, 32, 40, 48, 32, 111, 116, 104, 101, 114, 119,
  105, 115, 101, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 46, 32, 39, 115, 39, 58, 32, 115, 112, 101, 99, 116, 114, 117, 109,
  32, 111, 102, 32, 116, 104, 101, 32, 97, 115, 115, 111, 99, 105, 97, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 44, 32, 105, 102, 32, 97, 110, 121,
  32, 40, 48, 32, 111, 116, 104, 101, 114, 119, 105, 115, 101, 41, 46, 10,
  92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 120, 39,
  58, 32, 99, 117, 114, 114, 101, 110, 116, 32, 112, 114, 111, 99, 101, 115,
  115, 101, 100, 32, 99, 111, 108, 117, 109, 110, 32, 111, 102, 32, 116, 104,
  101, 32, 97, 115, 115, 111, 99, 105, 97, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 44, 32, 105, 102, 32, 97, 110, 121, 32, 40, 48, 32, 111, 116,
  104, 101, 114, 119, 105, 115, 101, 41, 46, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 46, 32, 39, 121, 39, 58, 32, 99, 117, 114, 114,
  101, 110, 116, 32, 112, 114, 111, 99, 101, 115, 115, 101, 100, 32, 114, 111,
  119, 32, 111, 102, 32, 116, 104, 101, 32, 97, 115, 115, 111, 99, 105, 97,
  116, 101, 100, 32, 105, 109, 97, 103, 101, 44, 32, 105, 102, 32, 97, 110,
  121, 32, 40, 48, 32, 111, 116, 104, 101, 114, 119, 105, 115, 101, 41, 46,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 122,
  39, 58, 32, 99, 117, 114, 114, 101, 110, 116, 32, 112, 114, 111, 99, 101,
  115, 115, 101, 100, 32, 115, 108, 105, 99, 101, 32, 111, 102, 32, 116, 104,
  101, 32, 97, 115, 115, 111, 99, 105, 97, 116, 101, 100, 32, 105, 109, 97,
  103, 101, 44, 32, 105, 102, 32, 97, 110, 121, 32, 40, 48, 32, 111, 116,
  104, 101, 114, 119, 105, 115, 101, 41, 46, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 46, 32, 39, 99, 39, 58, 32, 99, 117, 114, 114,
  101, 110, 116, 32, 112, 114, 111, 99, 101, 115, 115, 101, 100, 32, 99, 104,
  97, 110, 110, 101, 108, 32, 111, 102, 32, 116, 104, 101, 32, 97, 115, 115,
  111, 99, 105, 97, 116, 101, 100, 32, 105, 109, 97, 103, 101, 44, 32, 105,
  102, 32, 97, 110, 121, 32, 40, 48, 32, 111, 116, 104, 101, 114, 119, 105,
  115, 101, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  46, 32, 39, 101, 39, 58, 32, 118, 97, 108, 117, 101, 32, 111, 102, 32,
  101, 44, 32, 105, 46, 101, 46, 32, 50, 46, 55, 49, 56, 50, 56, 46,
  46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39,
  112, 105, 39, 58, 32, 118, 97, 108, 117, 101, 32, 111, 102, 32, 112, 105,
  44, 32, 105, 46, 101, 46, 32, 51, 46, 49, 52, 49, 53, 57, 50, 54,
  46, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32,
  39, 63, 39, 32, 111, 114, 32, 39, 117, 39, 58, 32, 97, 32, 114, 97,
  110, 100, 111, 109, 32, 118, 97, 108, 117, 101, 32, 98, 101, 116, 119, 101,
  101, 110, 32, 91, 48, 44, 49, 93, 44, 32, 102, 111, 108, 108, 111, 119,
  105, 110, 103, 32, 97, 32, 117, 110, 105, 102, 111, 114, 109, 32, 100, 105,
  115, 116, 114, 105, 98, 117, 116, 105, 111, 110, 46, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 103, 39, 58, 32, 97, 32,
  114, 97, 110, 100, 111, 109, 32, 118, 97, 108, 117, 101, 44, 32, 102, 111,
  108, 108, 111, 119, 105, 110, 103, 32, 97, 32, 103, 97, 117, 115, 115, 105,
  97, 110, 32, 100, 105, 115, 116, 114, 105, 98, 117, 116, 105, 111, 110, 32,
  111, 102, 32, 118, 97, 114, 105, 97, 110, 99, 101, 32, 49, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 40, 114, 111, 117,
  103, 104, 108, 121, 32, 105, 110, 32, 91, 45, 53, 44, 53, 93, 41, 46,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 105,
  39, 58, 32, 99, 117, 114, 114, 101, 110, 116, 32, 112, 114, 111, 99, 101,
  115, 115, 101, 100, 32, 112, 105, 120, 101, 108, 32, 118, 97, 108, 117, 101,
  32, 40, 105, 46, 101, 46, 32, 118, 97, 108, 117, 101, 32, 108, 111, 99,
  97, 116, 101, 100, 32, 97, 116, 32, 40, 120, 44, 121, 44, 122, 44, 99,
  41, 41, 32, 111, 102, 32, 116, 104, 101, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 97, 115, 115, 111, 99, 105, 97, 116,
  101, 100, 32, 105, 109, 97, 103, 101, 44, 32, 105, 102, 32, 97, 110, 121,
  32, 40, 48, 32, 111, 116, 104, 101, 114, 119, 105, 115, 101, 41, 46, 10,
  92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 105, 109,
  39, 44, 39, 105, 77, 39, 44, 39, 105, 97, 39, 44, 39, 105, 118, 39,
  58, 32, 82, 101, 115, 112, 101, 99, 116, 105, 118, 101, 108, 121, 32, 116,
  104, 101, 32, 109, 105, 110, 105, 109, 117, 109, 44, 32, 109, 97, 120, 105,
  109, 117, 109, 44, 32, 97, 118, 101, 114, 97, 103, 101, 32, 118, 97, 108,
  117, 101, 115, 32, 97, 110, 100, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 118, 97, 114, 105, 97, 110, 99, 101, 32, 111,
  102, 32, 116, 104, 101, 32, 97, 115, 115, 111, 99, 105, 97, 116, 101, 100,
  32, 105, 109, 97, 103, 101, 44, 32, 105, 102, 32, 97, 110, 121, 32, 40,
  48, 32, 111, 116, 104, 101, 114, 119, 105, 115, 101, 41, 46, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 120, 109, 39, 44,
  39, 121, 109, 39, 44, 39, 122, 109, 39, 44, 39, 99, 109, 39, 58, 32,
  84, 104, 101, 32, 112, 105, 120, 101, 108, 32, 99, 111, 111, 114, 100, 105,
  110, 97, 116, 101, 115, 32, 111, 102, 32, 116, 104, 101, 32, 109, 105, 110,
  105, 109, 117, 109, 32, 118, 97, 108, 117, 101, 32, 105, 110, 32, 116, 104,
  101, 32, 97, 115, 115, 111, 99, 105, 97, 116, 101, 100, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 105, 109, 97, 103, 101,
  44, 32, 105, 102, 32, 97, 110, 121, 32, 40, 48, 32, 111, 116, 104, 101,
  114, 119, 105, 115, 101, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 46, 32, 39, 120, 77, 39, 44, 39, 121, 77, 39, 44, 39,
  122, 77, 39, 44, 39, 99, 77, 39, 58, 32, 84, 104, 101, 32, 112, 105,
  120, 101, 108, 32, 99, 111, 111, 114, 100, 105, 110, 97, 116, 101, 115, 32,
  111, 102, 32, 116, 104, 101, 32, 109, 97, 120, 105, 109, 117, 109, 32, 118,
  97, 108, 117, 101, 32, 105, 110, 32, 116, 104, 101, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 97, 115, 115, 111, 99, 105,
  97, 116, 101, 100, 32, 105, 109, 97, 103, 101, 44, 32, 105, 102, 32, 97,
  110, 121, 32, 40, 48, 32, 111, 116, 104, 101, 114, 119, 105, 115, 101, 41,
  46, 10, 92, 110, 32, 32, 32, 32, 95, 32, 84, 104, 101, 115, 101, 32,
  115, 112, 101, 99, 105, 97, 108, 32, 111, 112, 101, 114, 97, 116, 111, 114,
  115, 32, 99, 97, 110, 32, 98, 101, 32, 117, 115, 101, 100, 58, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 59, 39, 58,
  32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 46, 32, 84, 104, 101, 32, 114, 101, 116, 117, 114,
  110, 101, 100, 32, 118, 97, 108, 117, 101, 32, 105, 115, 32, 97, 108, 119,
  97, 121, 115, 32, 116, 104, 101, 32, 108, 97, 115, 116, 32, 101, 110, 99,
  111, 117, 110, 116, 101, 114, 101, 100, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111,
  110, 46, 32, 70, 111, 114, 32, 105, 110, 115, 116, 97, 110, 99, 101, 32,
  101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 39, 49, 59, 50, 59,
  112, 105, 39, 32, 105, 115, 32, 101, 118, 97, 108, 117, 97, 116, 101, 100,
  32, 97, 115, 32, 39, 112, 105, 39, 46, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 46, 32, 39, 61, 39, 58, 32, 118, 97, 114, 105,
  97, 98, 108, 101, 32, 97, 115, 115, 105, 103, 110, 109, 101, 110, 116, 46,
  32, 86, 97, 114, 105, 97, 98, 108, 101, 115, 32, 105, 110, 32, 109, 97,
  116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 32, 112, 97, 114, 115, 101,
  114, 32, 99, 97, 110, 32, 111, 110, 108, 121, 32, 114, 101, 102, 101, 114,
  32, 116, 111, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 110, 117, 109, 101, 114, 105, 99, 97, 108, 32, 118, 97, 108,
  117, 101, 115, 46, 32, 86, 97, 114, 105, 97, 98, 108, 101, 32, 110, 97,
  109, 101, 115, 32, 97, 114, 101, 32, 99, 97, 115, 101, 45, 115, 101, 110,
  115, 105, 116, 105, 118, 101, 46, 32, 85, 115, 101, 32, 116, 104, 105, 115,
  32, 111, 112, 101, 114, 97, 116, 111, 114, 32, 105, 110, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 99, 111, 110, 106, 117,
  110, 99, 116, 105, 111, 110, 32, 119, 105, 116, 104, 32, 39, 59, 39, 32,
  116, 111, 32, 100, 101, 102, 105, 110, 101, 32, 99, 111, 109, 112, 108, 101,
  120, 32, 101, 118, 97, 108, 117, 97, 98, 108, 101, 32, 101, 120, 112, 114,
  101, 115, 115, 105, 111, 110, 115, 44, 32, 115, 117, 99, 104, 32, 97, 115,
  10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  39, 116, 61, 99, 111, 115, 40, 120, 41, 59, 51, 42, 116, 94, 50, 43,
  50, 42, 116, 43, 49, 39, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 84, 104, 101, 115, 101, 32, 118, 97, 114, 105,
  97, 98, 108, 101, 115, 32, 114, 101, 109, 97, 105, 110, 32, 108, 111, 99,
  97, 108, 32, 116, 111, 32, 116, 104, 101, 32, 109, 97, 116, 104, 101, 109,
  97, 116, 105, 99, 97, 108, 32, 112, 97, 114, 115, 101, 114, 32, 97, 110,
  100, 32, 99, 97, 110, 110, 111, 116, 32, 98, 101, 32, 97, 99, 99, 101,
  115, 115, 101, 100, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 111, 117, 116, 115, 105, 100, 101, 32, 116, 104, 101, 32, 101,
  118, 97, 108, 117, 97, 116, 101, 100, 32, 101, 120, 112, 114, 101, 115, 115,
  105, 111, 110, 46, 10, 92, 110, 32, 32, 32, 32, 95, 32, 84, 104, 101,
  32, 102, 111, 108, 108, 111, 119, 105, 110, 103, 32, 115, 112, 101, 99, 105,
  102, 105, 99, 32, 102, 117, 110, 99, 116, 105, 111, 110, 115, 32, 97, 114,
  101, 32, 97, 108, 115, 111, 32, 100, 101, 102, 105, 110, 101, 100, 58, 10,
  92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 105, 102,
  40, 101, 120, 112, 114, 95, 99, 111, 110, 100, 44, 101, 120, 112, 114, 95,
  116, 104, 101, 110, 44, 101, 120, 112, 114, 95, 101, 108, 115, 101, 41, 39,
  58, 32, 114, 101, 116, 117, 114, 110, 32, 118, 97, 108, 117, 101, 32, 111,
  102, 32, 39, 101, 120, 112, 114, 95, 116, 104, 101, 110, 39, 32, 111, 114,
  32, 39, 101, 120, 112, 114, 95, 101, 108, 115, 101, 39, 44, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 100, 101, 112, 101,
  110, 100, 105, 110, 103, 32, 111, 110, 32, 116, 104, 101, 32, 118, 97, 108,
  117, 101, 32, 111, 102, 32, 39, 101, 120, 112, 114, 95, 99, 111, 110, 100,
  39, 32, 40, 48, 61, 102, 97, 108, 115, 101, 44, 32, 111, 116, 104, 101,
  114, 61, 116, 114, 117, 101, 41, 46, 32, 70, 111, 114, 32, 105, 110, 115,
  116, 97, 110, 99, 101, 44, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 71, 39, 77, 73, 67, 32, 99, 111, 109, 109, 97,
  110, 100, 32, 39, 45, 102, 105, 108, 108, 32, 105, 102, 40, 120, 37, 49,
  48, 61, 61, 48, 44, 50, 53, 53, 44, 105, 41, 39, 32, 119, 105, 108,
  108, 32, 100, 114, 97, 119, 32, 98, 108, 97, 110, 107, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 32, 108, 105, 110, 101, 115, 32, 111, 110, 32, 101,
  118, 101, 114, 121, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 49, 48, 116, 104, 32, 99, 111, 108, 117, 109, 110, 32, 111,
  102, 32, 97, 110, 32, 105, 109, 97, 103, 101, 46, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 63, 40, 109, 97, 120, 41,
  39, 32, 111, 114, 32, 39, 63, 40, 109, 105, 110, 44, 109, 97, 120, 41,
  39, 58, 32, 114, 101, 116, 117, 114, 110, 32, 97, 32, 114, 97, 110, 100,
  111, 109, 32, 118, 97, 108, 117, 101, 32, 98, 101, 116, 119, 101, 101, 110,
  32, 91, 48, 44, 109, 97, 120, 93, 32, 111, 114, 32, 91, 109, 105, 110,
  44, 109, 97, 120, 93, 44, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 102, 111, 108, 108, 111, 119, 105, 110, 103, 32, 97,
  32, 117, 110, 105, 102, 111, 114, 109, 32, 100, 105, 115, 116, 114, 105, 98,
  117, 116, 105, 111, 110, 46, 32, 39, 117, 40, 109, 97, 120, 41, 39, 32,
  97, 110, 100, 32, 39, 117, 40, 48, 44, 109, 97, 120, 41, 39, 32, 109,
  101, 97, 110, 32, 116, 104, 101, 32, 115, 97, 109, 101, 46, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39, 105, 40, 95, 97,
  44, 95, 98, 44, 95, 99, 44, 95, 100, 44, 95, 105, 110, 116, 101, 114,
  112, 111, 108, 97, 116, 105, 111, 110, 44, 95, 98, 111, 117, 110, 100, 97,
  114, 121, 41, 39, 58, 32, 114, 101, 116, 117, 114, 110, 32, 116, 104, 101,
  32, 118, 97, 108, 117, 101, 32, 111, 102, 32, 116, 104, 101, 32, 112, 105,
  120, 101, 108, 32, 108, 111, 99, 97, 116, 101, 100, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 97, 116, 32, 112, 111, 115,
  105, 116, 105, 111, 110, 32, 40, 97, 44, 98, 44, 99, 44, 100, 41, 32,
  105, 110, 32, 116, 104, 101, 32, 97, 115, 115, 111, 99, 105, 97, 116, 101,
  100, 32, 105, 109, 97, 103, 101, 44, 32, 105, 102, 32, 97, 110, 121, 32,
  40, 48, 32, 111, 116, 104, 101, 114, 119, 105, 115, 101, 41, 46, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 73, 110, 116,
  101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 32, 112, 97, 114, 97, 109,
  101, 116, 101, 114, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61,
  110, 101, 97, 114, 101, 115, 116, 32, 110, 101, 105, 103, 104, 98, 111, 114,
  32, 124, 32, 111, 116, 104, 101, 114, 61, 108, 105, 110, 101, 97, 114, 32,
  125, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 66, 111, 117, 110, 100, 97, 114, 121, 32, 99, 111, 110, 100, 105, 116,
  105, 111, 110, 115, 32, 99, 97, 110, 32, 98, 101, 32, 123, 32, 48, 61,
  100, 105, 114, 105, 99, 104, 108, 101, 116, 32, 124, 32, 49, 61, 110, 101,
  117, 109, 97, 110, 110, 32, 124, 32, 50, 61, 99, 121, 99, 108, 105, 99,
  32, 125, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 79, 109, 105, 116, 116, 101, 100, 32, 99, 111, 111, 114, 100, 105,
  110, 97, 116, 101, 115, 32, 97, 114, 101, 32, 114, 101, 112, 108, 97, 99,
  101, 100, 32, 98, 121, 32, 116, 104, 101, 105, 114, 32, 100, 101, 102, 97,
  117, 108, 116, 32, 118, 97, 108, 117, 101, 115, 32, 119, 104, 105, 99, 104,
  32, 97, 114, 101, 32, 114, 101, 115, 112, 101, 99, 116, 105, 118, 101, 108,
  121, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  120, 44, 32, 121, 44, 32, 122, 44, 32, 99, 32, 97, 110, 100, 32, 48,
  46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32, 39,
  106, 40, 95, 100, 120, 44, 95, 100, 121, 44, 95, 100, 122, 44, 95, 100,
  99, 44, 95, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110,
  44, 95, 98, 111, 117, 110, 100, 97, 114, 121, 41, 39, 58, 32, 100, 111,
  101, 115, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 102, 111, 114, 32,
  116, 104, 101, 32, 112, 105, 120, 101, 108, 32, 108, 111, 99, 97, 116, 101,
  100, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  97, 116, 32, 112, 111, 115, 105, 116, 105, 111, 110, 32, 40, 120, 43, 100,
  120, 44, 121, 43, 100, 121, 44, 122, 43, 100, 122, 44, 99, 43, 100, 99,
  41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 46, 32,
  39, 105, 91, 111, 102, 102, 115, 101, 116, 93, 39, 58, 32, 114, 101, 116,
  117, 114, 110, 32, 116, 104, 101, 32, 118, 97, 108, 117, 101, 32, 111, 102,
  32, 116, 104, 101, 32, 112, 105, 120, 101, 108, 32, 108, 111, 99, 97, 116,
  101, 100, 32, 97, 116, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  111, 102, 102, 115, 101, 116, 32, 105, 110, 32, 116, 104, 101, 32, 97, 115,
  115, 111, 99, 105, 97, 116, 101, 100, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 105, 109, 97, 103, 101, 32, 98, 117, 102,
  102, 101, 114, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  46, 32, 39, 106, 91, 111, 102, 102, 115, 101, 116, 93, 39, 58, 32, 100,
  111, 101, 115, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 102, 111, 114,
  32, 97, 110, 32, 111, 102, 102, 115, 101, 116, 32, 114, 101, 108, 97, 116,
  105, 118, 101, 32, 116, 111, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101,
  110, 116, 32, 112, 105, 120, 101, 108, 32, 40, 120, 44, 121, 44, 122, 44,
  99, 41, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 70, 111, 114, 32, 105, 110, 115, 116, 97, 110, 99, 101, 32, 99,
  111, 109, 109, 97, 110, 100, 32, 39, 45, 102, 105, 108, 108, 32, 48, 46,
  53, 42, 40, 105, 40, 120, 43, 49, 41, 45, 105, 40, 120, 45, 49, 41,
  41, 39, 32, 119, 105, 108, 108, 32, 101, 115, 116, 105, 109, 97, 116, 101,
  32, 116, 104, 101, 32, 88, 45, 100, 101, 114, 105, 118, 97, 116, 105, 118,
  101, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  111, 102, 32, 97, 110, 32, 105, 109, 97, 103, 101, 32, 119, 105, 116, 104,
  32, 97, 32, 99, 108, 97, 115, 115, 105, 99, 97, 108, 32, 102, 105, 110,
  105, 116, 101, 32, 100, 105, 102, 102, 101, 114, 101, 110, 99, 101, 32, 115,
  99, 104, 101, 109, 101, 46, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 46, 32, 73, 102, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100,
  32, 102, 111, 114, 109, 117, 108, 97, 32, 115, 116, 97, 114, 116, 115, 32,
  119, 105, 116, 104, 32, 39, 62, 39, 32, 111, 114, 32, 39, 60, 39, 44,
  32, 116, 104, 101, 32, 111, 112, 101, 114, 97, 116, 111, 114, 115, 32, 39,
  105, 40, 46, 46, 41, 39, 32, 97, 110, 100, 32, 39, 106, 40, 46, 46,
  41, 39, 32, 119, 105, 108, 108, 32, 114, 101, 116, 117, 114, 110, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 118, 97, 108,
  117, 101, 115, 32, 111, 102, 32, 116, 104, 101, 32, 105, 109, 97, 103, 101,
  32, 99, 117, 114, 114, 101, 110, 116, 108, 121, 32, 98, 101, 105, 110, 103,
  32, 109, 111, 100, 105, 102, 105, 101, 100, 44, 32, 105, 110, 32, 102, 111,
  114, 119, 97, 114, 100, 32, 40, 39, 62, 39, 41, 32, 111, 114, 32, 98,
  97, 99, 107, 119, 97, 114, 100, 32, 40, 39, 60, 39, 41, 32, 111, 114,
  100, 101, 114, 46, 10, 92, 110, 32, 32, 45, 32, 84, 104, 101, 32, 108,
  97, 115, 116, 32, 105, 109, 97, 103, 101, 32, 111, 102, 32, 116, 104, 101,
  32, 108, 105, 115, 116, 32, 105, 115, 32, 97, 108, 119, 97, 121, 115, 32,
  97, 115, 115, 111, 99, 105, 97, 116, 101, 100, 32, 116, 111, 32, 116, 104,
  101, 32, 101, 118, 97, 108, 117, 97, 116, 105, 111, 110, 115, 32, 111, 102,
  32, 39, 123, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 115, 125, 39,
  44, 10, 92, 110, 32, 32, 32, 32, 32, 101, 46, 103, 46, 32, 71, 39,
  77, 73, 67, 32, 115, 101, 113, 117, 101, 110, 99, 101, 32, 39, 50, 53,
  54, 44, 49, 50, 56, 32, 45, 102, 32, 123, 119, 125, 39, 32, 119, 105,
  108, 108, 32, 99, 114, 101, 97, 116, 101, 32, 97, 32, 50, 53, 54, 120,
  49, 50, 56, 32, 105, 109, 97, 103, 101, 32, 102, 105, 108, 108, 101, 100,
  32, 119, 105, 116, 104, 32, 118, 97, 108, 117, 101, 32, 50, 53, 54, 46,
  34, 10, 45, 95, 104, 101, 108, 112, 95, 115, 101, 99, 116, 105, 111, 110,
  32, 34, 73, 109, 97, 103, 101, 32, 97, 110, 100, 32, 100, 97, 116, 97,
  32, 118, 105, 101, 119, 101, 114, 115, 34, 10, 45, 95, 104, 101, 108, 112,
  95, 112, 97, 114, 97, 103, 114, 97, 112, 104, 32, 34, 32, 32, 45, 32,
  71, 39, 77, 73, 67, 32, 104, 97, 115, 32, 115, 111, 109, 101, 32, 118,
  101, 114, 121, 32, 104, 97, 110, 100, 121, 32, 101, 109, 98, 101, 100, 100,
  101, 100, 32, 118, 105, 115, 117, 97, 108, 105, 122, 97, 116, 105, 111, 110,
  32, 109, 111, 100, 117, 108, 101, 115, 44, 32, 102, 111, 114, 32, 49, 100,
  32, 115, 105, 103, 110, 97, 108, 115, 10, 92, 110, 32, 32, 32, 32, 32,
  40, 99, 111, 109, 109, 97, 110, 100, 32, 39, 45, 112, 108, 111, 116, 39,
  41, 44, 32, 49, 100, 47, 50, 100, 47, 51, 100, 32, 105, 109, 97, 103,
  101, 115, 32, 40, 99, 111, 109, 109, 97, 110, 100, 32, 39, 45, 100, 105,
  115, 112, 108, 97, 121, 39, 41, 32, 97, 110, 100, 32, 51, 100, 32, 111,
  98, 106, 101, 99, 116, 115, 10, 92, 110, 32, 32, 32, 32, 32, 40, 99,
  111, 109, 109, 97, 110, 100, 32, 39, 45, 100, 105, 115, 112, 108, 97, 121,
  51, 100, 39, 41, 46, 32, 73, 116, 32, 101, 110, 97, 98, 108, 101, 115,
  32, 97, 110, 32, 105, 110, 116, 101, 114, 97, 99, 116, 105, 118, 101, 32,
  118, 105, 101, 119, 32, 111, 102, 32, 116, 104, 101, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 105, 109, 97, 103, 101, 32, 100, 97, 116, 97, 46,
  10, 92, 110, 32, 32, 45, 32, 84, 104, 101, 32, 102, 111, 108, 108, 111,
  119, 105, 110, 103, 32, 107, 101, 121, 98, 111, 97, 114, 100, 32, 115, 104,
  111, 114, 116, 99, 117, 116, 115, 32, 97, 114, 101, 32, 97, 118, 97, 105,
  108, 97, 98, 108, 101, 32, 105, 110, 32, 116, 104, 101, 32, 105, 110, 116,
  101, 114, 97, 99, 116, 105, 118, 101, 32, 118, 105, 101, 119, 101, 114, 115,
  58, 10, 92, 110, 32, 32, 32, 32, 46, 32, 67, 84, 82, 76, 43, 68,
  58, 32, 73, 110, 99, 114, 101, 97, 115, 101, 32, 119, 105, 110, 100, 111,
  119, 32, 115, 105, 122, 101, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32,
  67, 84, 82, 76, 43, 67, 58, 32, 68, 101, 99, 114, 101, 97, 115, 101,
  32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 10, 92, 110,
  32, 32, 32, 32, 46, 32, 67, 84, 82, 76, 43, 82, 58, 32, 82, 101,
  115, 101, 116, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46,
  10, 92, 110, 32, 32, 32, 32, 46, 32, 67, 84, 82, 76, 43, 70, 58,
  32, 84, 111, 103, 103, 108, 101, 32, 102, 117, 108, 108, 115, 99, 114, 101,
  101, 110, 32, 109, 111, 100, 101, 46, 10, 92, 110, 32, 32, 32, 32, 46,
  32, 67, 84, 82, 76, 43, 83, 58, 32, 83, 97, 118, 101, 32, 99, 117,
  114, 114, 101, 110, 116, 32, 119, 105, 110, 100, 111, 119, 32, 115, 110, 97,
  112, 115, 104, 111, 116, 32, 97, 115, 32, 110, 117, 109, 98, 101, 114, 101,
  100, 32, 102, 105, 108, 101, 32, 39, 103, 109, 105, 99, 95, 120, 120, 120,
  120, 46, 98, 109, 112, 39, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32,
  67, 84, 82, 76, 43, 79, 58, 32, 83, 97, 118, 101, 32, 99, 117, 114,
  114, 101, 110, 116, 32, 105, 110, 115, 116, 97, 110, 99, 101, 32, 111, 102,
  32, 116, 104, 101, 32, 118, 105, 101, 119, 101, 100, 32, 100, 97, 116, 97,
  44, 32, 97, 115, 32, 110, 117, 109, 98, 101, 114, 101, 100, 32, 102, 105,
  108, 101, 32, 39, 103, 109, 105, 99, 95, 120, 120, 120, 120, 46, 99, 105,
  109, 103, 122, 39, 46, 10, 92, 110, 32, 32, 45, 32, 83, 104, 111, 114,
  116, 99, 117, 116, 115, 32, 115, 112, 101, 99, 105, 102, 105, 99, 32, 116,
  111, 32, 116, 104, 101, 32, 49, 100, 47, 50, 100, 47, 51, 100, 32, 105,
  109, 97, 103, 101, 32, 118, 105, 101, 119, 101, 114, 32, 97, 114, 101, 58,
  10, 92, 110, 32, 32, 32, 32, 46, 32, 67, 84, 82, 76, 43, 65, 58,
  32, 83, 119, 105, 116, 99, 104, 32, 99, 117, 114, 115, 111, 114, 32, 109,
  111, 100, 101, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 67, 84, 82,
  76, 43, 80, 58, 32, 80, 108, 97, 121, 32, 122, 45, 115, 116, 97, 99,
  107, 32, 111, 102, 32, 102, 114, 97, 109, 101, 115, 32, 97, 115, 32, 97,
  32, 109, 111, 118, 105, 101, 32, 40, 102, 111, 114, 32, 118, 111, 108, 117,
  109, 101, 116, 114, 105, 99, 32, 51, 100, 32, 105, 109, 97, 103, 101, 115,
  41, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 67, 84, 82, 76, 43,
  86, 58, 32, 83, 104, 111, 119, 47, 104, 105, 100, 101, 32, 51, 68, 32,
  118, 105, 101, 119, 32, 40, 102, 111, 114, 32, 118, 111, 108, 117, 109, 101,
  116, 114, 105, 99, 32, 51, 100, 32, 105, 109, 97, 103, 101, 115, 41, 46,
  10, 92, 110, 32, 32, 32, 32, 46, 32, 67, 84, 82, 76, 43, 40, 109,
  111, 117, 115, 101, 119, 104, 101, 101, 108, 41, 58, 32, 90, 111, 111, 109,
  32, 105, 110, 47, 111, 117, 116, 46, 10, 92, 110, 32, 32, 32, 32, 46,
  32, 83, 72, 73, 70, 84, 43, 40, 109, 111, 117, 115, 101, 119, 104, 101,
  101, 108, 41, 58, 32, 71, 111, 32, 108, 101, 102, 116, 47, 114, 105, 103,
  104, 116, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 65, 76, 84, 43,
  40, 109, 111, 117, 115, 101, 119, 104, 101, 101, 108, 41, 58, 32, 71, 111,
  32, 117, 112, 47, 100, 111, 119, 110, 46, 10, 92, 110, 32, 32, 32, 32,
  46, 32, 78, 117, 109, 101, 114, 105, 99, 32, 80, 65, 68, 58, 32, 90,
  111, 111, 109, 32, 105, 110, 47, 111, 117, 116, 32, 40, 43, 47, 45, 41,
  32, 97, 110, 100, 32, 109, 111, 118, 101, 32, 116, 104, 114, 111, 117, 103,
  104, 32, 122, 111, 111, 109, 101, 100, 32, 105, 109, 97, 103, 101, 32, 40,
  100, 105, 103, 105, 116, 115, 41, 46, 10, 92, 110, 32, 32, 32, 32, 46,
  32, 66, 65, 67, 75, 83, 80, 65, 67, 69, 58, 32, 82, 101, 115, 101,
  116, 32, 122, 111, 111, 109, 32, 115, 99, 97, 108, 101, 46, 10, 92, 110,
  32, 32, 45, 32, 83, 104, 111, 114, 116, 99, 117, 116, 115, 32, 115, 112,
  101, 99, 105, 102, 105, 99, 32, 116, 111, 32, 116, 104, 101, 32, 51, 100,
  32, 111, 98, 106, 101, 99, 116, 32, 118, 105, 101, 119, 101, 114, 32, 97,
  114, 101, 58, 10, 92, 110, 32, 32, 32, 32, 46, 32, 40, 109, 111, 117,
  115, 101, 41, 43, 40, 108, 101, 102, 116, 32, 109, 111, 117, 115, 101, 32,
  98, 117, 116, 116, 111, 110, 41, 58, 32, 82, 111, 116, 97, 116, 101, 32,
  51, 100, 32, 111, 98, 106, 101, 99, 116, 46, 10, 92, 110, 32, 32, 32,
  32, 46, 32, 40, 109, 111, 117, 115, 101, 41, 43, 40, 114, 105, 103, 104,
  116, 32, 109, 111, 117, 115, 101, 32, 98, 117, 116, 116, 111, 110, 41, 58,
  32, 90, 111, 111, 109, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 46,
  10, 92, 110, 32, 32, 32, 32, 46, 32, 40, 109, 111, 117, 115, 101, 41,
  43, 40, 109, 105, 100, 100, 108, 101, 32, 109, 111, 117, 115, 101, 32, 98,
  117, 116, 116, 111, 110, 41, 58, 32, 83, 104, 105, 102, 116, 32, 51, 100,
  32, 111, 98, 106, 101, 99, 116, 46, 10, 92, 110, 32, 32, 32, 32, 46,
  32, 40, 109, 111, 117, 115, 101, 119, 104, 101, 101, 108, 41, 58, 32, 90,
  111, 111, 109, 32, 105, 110, 47, 111, 117, 116, 46, 10, 92, 110, 32, 32,
  32, 32, 46, 32, 67, 84, 82, 76, 43, 70, 49, 32, 46, 46, 32, 67,
  84, 82, 76, 43, 70, 54, 58, 32, 83, 119, 105, 116, 99, 104, 32, 98,
  101, 116, 119, 101, 101, 110, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116,
  32, 51, 100, 32, 114, 101, 110, 100, 101, 114, 105, 110, 103, 32, 109, 111,
  100, 101, 115, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 67, 84, 82,
  76, 43, 90, 58, 32, 69, 110, 97, 98, 108, 101, 47, 100, 105, 115, 97,
  98, 108, 101, 32, 122, 45, 98, 117, 102, 102, 101, 114, 101, 100, 32, 114,
  101, 110, 100, 101, 114, 105, 110, 103, 46, 10, 92, 110, 32, 32, 32, 32,
  46, 32, 67, 84, 82, 76, 43, 65, 58, 32, 83, 104, 111, 119, 47, 104,
  105, 100, 101, 32, 51, 100, 32, 97, 120, 101, 115, 46, 10, 92, 110, 32,
  32, 32, 32, 46, 32, 67, 84, 82, 76, 43, 71, 58, 32, 83, 97, 118,
  101, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 44, 32, 97, 115, 32,
  110, 117, 109, 98, 101, 114, 101, 100, 32, 102, 105, 108, 101, 32, 39, 103,
  109, 105, 99, 95, 120, 120, 120, 120, 46, 111, 102, 102, 39, 46, 10, 92,
  110, 32, 32, 32, 32, 46, 32, 67, 84, 82, 76, 43, 84, 58, 32, 83,
  119, 105, 116, 99, 104, 32, 98, 101, 116, 119, 101, 101, 110, 32, 115, 105,
  110, 103, 108, 101, 47, 100, 111, 117, 98, 108, 101, 45, 115, 105, 100, 101,
  100, 32, 51, 100, 32, 109, 111, 100, 101, 115, 46, 34, 10, 45, 95, 104,
  101, 108, 112, 95, 115, 101, 99, 116, 105, 111, 110, 32, 34, 65, 100, 100,
  105, 110, 103, 32, 99, 117, 115, 116, 111, 109, 32, 99, 111, 109, 109, 97,
  110, 100, 115, 34, 10, 45, 95, 104, 101, 108, 112, 95, 112, 97, 114, 97,
  103, 114, 97, 112, 104, 32, 34, 32, 32, 45, 32, 67, 117, 115, 116, 111,
  109, 32, 99, 111, 109, 109, 97, 110, 100, 115, 32, 99, 97, 110, 32, 98,
  101, 32, 100, 101, 102, 105, 110, 101, 100, 32, 98, 121, 32, 97, 32, 117,
  115, 101, 114, 44, 32, 116, 104, 114, 111, 117, 103, 104, 32, 116, 104, 101,
  32, 117, 115, 101, 32, 111, 102, 32, 71, 39, 77, 73, 67, 32, 99, 117,
  115, 116, 111, 109, 32, 99, 111, 109, 109, 97, 110, 100, 115, 32, 102, 105,
  108, 101, 115, 46, 10, 92, 110, 32, 32, 45, 32, 65, 32, 99, 111, 109,
  109, 97, 110, 100, 32, 102, 105, 108, 101, 32, 105, 115, 32, 97, 32, 115,
  105, 109, 112, 108, 101, 32, 97, 115, 99, 105, 105, 32, 116, 101, 120, 116,
  32, 102, 105, 108, 101, 44, 32, 119, 104, 101, 114, 101, 32, 101, 97, 99,
  104, 32, 108, 105, 110, 101, 32, 115, 116, 97, 114, 116, 115, 32, 101, 105,
  116, 104, 101, 114, 32, 98, 121, 10, 92, 110, 32, 32, 32, 32, 32, 39,
  99, 111, 109, 109, 97, 110, 100, 95, 110, 97, 109, 101, 58, 32, 99, 111,
  109, 109, 97, 110, 100, 95, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110,
  39, 32, 111, 114, 32, 39, 99, 111, 109, 109, 97, 110, 100, 95, 100, 101,
  102, 105, 110, 105, 116, 105, 111, 110, 32, 40, 99, 111, 110, 116, 105, 110,
  117, 97, 116, 105, 111, 110, 41, 39, 46, 10, 92, 110, 32, 32, 45, 32,
  67, 117, 115, 116, 111, 109, 32, 99, 111, 109, 109, 97, 110, 100, 32, 110,
  97, 109, 101, 115, 32, 109, 117, 115, 116, 32, 117, 115, 101, 32, 99, 104,
  97, 114, 97, 99, 116, 101, 114, 115, 32, 91, 97, 45, 122, 65, 45, 90,
  48, 45, 57, 95, 93, 32, 97, 110, 100, 32, 99, 97, 110, 110, 111, 116,
  32, 115, 116, 97, 114, 116, 32, 119, 105, 116, 104, 32, 97, 32, 110, 117,
  109, 98, 101, 114, 46, 10, 92, 110, 32, 32, 45, 32, 65, 110, 121, 32,
  39, 32, 92, 35, 32, 99, 111, 109, 109, 101, 110, 116, 39, 32, 101, 120,
  112, 114, 101, 115, 115, 105, 111, 110, 32, 102, 111, 117, 110, 100, 32, 105,
  110, 32, 97, 32, 99, 117, 115, 116, 111, 109, 32, 99, 111, 109, 109, 97,
  110, 100, 115, 32, 102, 105, 108, 101, 32, 105, 115, 32, 100, 105, 115, 99,
  97, 114, 100, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 71, 39, 77,
  73, 67, 10, 92, 110, 32, 32, 32, 32, 32, 105, 110, 116, 101, 114, 112,
  114, 101, 116, 101, 114, 44, 32, 119, 104, 101, 114, 101, 118, 101, 114, 32,
  105, 116, 32, 105, 115, 32, 108, 111, 99, 97, 116, 101, 100, 32, 105, 110,
  32, 97, 32, 108, 105, 110, 101, 46, 10, 92, 110, 32, 32, 45, 32, 73,
  110, 32, 99, 117, 115, 116, 111, 109, 32, 99, 111, 109, 109, 97, 110, 100,
  115, 44, 32, 116, 104, 101, 32, 102, 111, 108, 108, 111, 119, 105, 110, 103,
  32, 36, 45, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 115, 32, 97,
  114, 101, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 58, 10,
  92, 110, 32, 32, 32, 32, 46, 32, 39, 36, 34, 34, 42, 39, 32, 105,
  115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121,
  32, 97, 32, 99, 111, 112, 121, 32, 111, 102, 32, 116, 104, 101, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 115, 116, 114, 105, 110, 103, 32,
  111, 102, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 46, 10, 92, 110,
  32, 32, 32, 32, 46, 32, 39, 36, 92, 34, 42, 92, 34, 39, 32, 105,
  115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121,
  32, 97, 32, 99, 111, 112, 121, 32, 111, 102, 32, 116, 104, 101, 32, 115,
  112, 101, 99, 105, 102, 105, 101, 100, 32, 115, 116, 114, 105, 110, 103, 32,
  111, 102, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 44, 32, 101, 97,
  99, 104, 32, 98, 101, 105, 110, 103, 32, 97, 114, 111, 117, 110, 100, 32,
  100, 111, 117, 98, 108, 101, 32, 113, 117, 111, 116, 101, 115, 46, 10, 92,
  110, 32, 32, 32, 32, 46, 32, 39, 36, 34, 34, 35, 39, 32, 105, 115,
  32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32,
  116, 104, 101, 32, 109, 97, 120, 105, 109, 117, 109, 32, 105, 110, 100, 105,
  99, 101, 32, 111, 102, 32, 107, 110, 111, 119, 110, 32, 97, 114, 103, 117,
  109, 101, 110, 116, 115, 32, 40, 101, 105, 116, 104, 101, 114, 32, 115, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 98, 121, 32, 116, 104, 101, 10, 92,
  110, 32, 32, 32, 32, 32, 32, 32, 117, 115, 101, 114, 32, 111, 114, 32,
  115, 101, 116, 32, 116, 111, 32, 97, 32, 100, 101, 102, 97, 117, 108, 116,
  32, 118, 97, 108, 117, 101, 32, 105, 110, 32, 116, 104, 101, 32, 99, 117,
  115, 116, 111, 109, 32, 99, 111, 109, 109, 97, 110, 100, 41, 46, 10, 92,
  110, 32, 32, 32, 32, 46, 32, 39, 36, 34, 34, 63, 39, 32, 105, 115,
  32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32,
  97, 32, 115, 116, 114, 105, 110, 103, 32, 116, 101, 108, 108, 105, 110, 103,
  32, 97, 98, 111, 117, 116, 32, 116, 104, 101, 32, 99, 111, 109, 109, 97,
  110, 100, 32, 115, 117, 98, 115, 101, 116, 32, 114, 101, 115, 116, 114, 105,
  99, 116, 105, 111, 110, 32, 40, 111, 110, 108, 121, 10, 92, 110, 32, 32,
  32, 32, 32, 32, 32, 117, 115, 101, 102, 117, 108, 32, 119, 104, 101, 110,
  32, 99, 117, 115, 116, 111, 109, 32, 99, 111, 109, 109, 97, 110, 100, 115,
  32, 110, 101, 101, 100, 32, 116, 111, 32, 111, 117, 116, 112, 117, 116, 32,
  100, 101, 115, 99, 114, 105, 112, 116, 105, 118, 101, 32, 109, 101, 115, 115,
  97, 103, 101, 115, 41, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39,
  36, 105, 39, 32, 97, 110, 100, 32, 39, 36, 123, 105, 125, 39, 32, 97,
  114, 101, 32, 98, 111, 116, 104, 32, 115, 117, 98, 115, 116, 105, 116, 117,
  116, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 105, 45, 116, 104, 32,
  115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 97, 114, 103, 117, 109, 101,
  110, 116, 46, 32, 78, 101, 103, 97, 116, 105, 118, 101, 32, 105, 110, 100,
  105, 99, 101, 115, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32, 115, 117,
  99, 104, 32, 97, 115, 32, 39, 36, 123, 45, 106, 125, 39, 32, 97, 114,
  101, 32, 97, 108, 108, 111, 119, 101, 100, 32, 97, 110, 100, 32, 114, 101,
  102, 101, 114, 32, 116, 111, 32, 116, 104, 101, 32, 106, 94, 116, 104, 32,
  108, 97, 116, 101, 115, 116, 32, 97, 114, 103, 117, 109, 101, 110, 116, 46,
  32, 39, 36, 34, 34, 48, 39, 32, 105, 115, 32, 115, 117, 98, 115, 116,
  105, 116, 117, 116, 101, 100, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  98, 121, 32, 116, 104, 101, 32, 99, 117, 115, 116, 111, 109, 32, 99, 111,
  109, 109, 97, 110, 100, 32, 110, 97, 109, 101, 46, 10, 92, 110, 32, 32,
  32, 32, 46, 32, 39, 36, 123, 105, 61, 100, 101, 102, 97, 117, 108, 116,
  125, 39, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101,
  100, 32, 98, 121, 32, 116, 104, 101, 32, 118, 97, 108, 117, 101, 32, 111,
  102, 32, 36, 105, 32, 40, 105, 102, 32, 100, 101, 102, 105, 110, 101, 100,
  41, 32, 111, 114, 32, 98, 121, 32, 105, 116, 115, 32, 110, 101, 119, 32,
  118, 97, 108, 117, 101, 32, 115, 101, 116, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 32, 116, 111, 32, 39, 100, 101, 102, 97, 117, 108, 116, 39,
  32, 111, 116, 104, 101, 114, 119, 105, 115, 101, 32, 40, 39, 100, 101, 102,
  97, 117, 108, 116, 39, 32, 109, 97, 121, 32, 98, 101, 32, 97, 32, 36,
  45, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 97, 115, 32, 119,
  101, 108, 108, 41, 46, 10, 92, 110, 32, 32, 32, 32, 46, 32, 39, 36,
  123, 115, 117, 98, 115, 101, 116, 125, 39, 32, 105, 115, 32, 115, 117, 98,
  115, 116, 105, 116, 117, 116, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32,
  97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 118, 97, 108, 117, 101, 115,
  32, 40, 115, 101, 112, 97, 114, 97, 116, 101, 100, 32, 98, 121, 32, 99,
  111, 109, 109, 97, 115, 32, 39, 44, 39, 41, 32, 111, 102, 32, 97, 10,
  92, 110, 32, 32, 32, 32, 32, 32, 32, 115, 112, 101, 99, 105, 102, 105,
  101, 100, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 115, 117, 98, 115,
  101, 116, 46, 32, 70, 111, 114, 32, 105, 110, 115, 116, 97, 110, 99, 101,
  32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 39, 36, 34, 34,
  123, 50, 45, 45, 50, 125, 39, 32, 105, 115, 32, 115, 117, 98, 115, 116,
  105, 116, 117, 101, 100, 32, 98, 121, 32, 97, 108, 108, 10, 92, 110, 32,
  32, 32, 32, 32, 32, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32,
  97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 101, 120, 99, 101, 112, 116,
  32, 116, 104, 101, 32, 102, 105, 114, 115, 116, 32, 97, 110, 100, 32, 116,
  104, 101, 32, 108, 97, 115, 116, 32, 111, 110, 101, 46, 32, 69, 120, 112,
  114, 101, 115, 115, 105, 111, 110, 32, 39, 36, 34, 34, 123, 94, 48, 125,
  39, 32, 105, 115, 32, 116, 104, 101, 110, 10, 92, 110, 32, 32, 32, 32,
  32, 32, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100, 32, 98,
  121, 32, 97, 108, 108, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 32,
  111, 102, 32, 116, 104, 101, 32, 105, 110, 118, 111, 107, 101, 100, 32, 99,
  111, 109, 109, 97, 110, 100, 32, 40, 101, 113, 46, 32, 116, 111, 32, 39,
  36, 34, 34, 42, 39, 32, 105, 102, 32, 97, 108, 108, 32, 115, 112, 101,
  99, 105, 102, 105, 101, 100, 10, 92, 110, 32, 32, 32, 32, 32, 32, 32,
  97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 104, 97, 118, 101, 32, 105,
  110, 100, 101, 101, 100, 32, 97, 32, 118, 97, 108, 117, 101, 41, 46, 10,
  92, 110, 32, 32, 32, 32, 46, 32, 39, 36, 34, 34, 61, 118, 97, 114,
  39, 32, 105, 115, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 100,
  32, 98, 121, 32, 116, 104, 101, 32, 115, 101, 116, 32, 111, 102, 32, 105,
  110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115, 32, 116, 104, 97, 116,
  32, 119, 105, 108, 108, 32, 97, 115, 115, 105, 103, 110, 32, 101, 97, 99,
  104, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 36, 105, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 116, 111, 32, 116, 104, 101, 32, 110, 97,
  109, 101, 100, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 39, 118, 97,
  114, 36, 105, 39, 32, 40, 102, 111, 114, 32, 105, 32, 105, 110, 32, 91,
  48, 46, 46, 36, 34, 34, 35, 93, 41, 46, 32, 84, 104, 105, 115, 32,
  105, 115, 32, 112, 97, 114, 116, 105, 99, 117, 108, 97, 114, 108, 121, 32,
  117, 115, 101, 102, 117, 108, 32, 119, 104, 101, 110, 32, 97, 10, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 99, 117, 115, 116, 111, 109, 32, 99, 111,
  109, 109, 97, 110, 100, 32, 119, 97, 110, 116, 32, 116, 111, 32, 109, 97,
  110, 97, 103, 101, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 110, 117,
  109, 98, 101, 114, 115, 32, 111, 102, 32, 97, 114, 103, 117, 109, 101, 110,
  116, 115, 46, 32, 86, 97, 114, 105, 97, 98, 108, 101, 115, 32, 110, 97,
  109, 101, 115, 32, 109, 117, 115, 116, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 32, 117, 115, 101, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 115,
  32, 91, 97, 45, 122, 65, 45, 90, 48, 45, 57, 95, 93, 32, 97, 110,
  100, 32, 99, 97, 110, 110, 111, 116, 32, 115, 116, 97, 114, 116, 32, 119,
  105, 116, 104, 32, 97, 32, 110, 117, 109, 98, 101, 114, 46, 10, 92, 110,
  32, 32, 45, 32, 84, 104, 101, 115, 101, 32, 112, 97, 114, 116, 105, 99,
  117, 108, 97, 114, 32, 36, 45, 101, 120, 112, 114, 101, 115, 115, 105, 111,
  110, 115, 32, 97, 114, 101, 32, 97, 108, 119, 97, 121, 115, 32, 115, 117,
  98, 115, 116, 105, 116, 117, 116, 101, 100, 44, 32, 101, 118, 101, 110, 32,
  105, 110, 32, 100, 111, 117, 98, 108, 101, 32, 113, 117, 111, 116, 101, 100,
  32, 105, 116, 101, 109, 115, 32, 111, 114, 10, 92, 110, 32, 32, 32, 32,
  32, 119, 104, 101, 110, 32, 116, 104, 101, 32, 100, 111, 108, 108, 97, 114,
  32, 115, 105, 103, 110, 32, 39, 36, 39, 32, 105, 115, 32, 101, 115, 99,
  97, 112, 101, 100, 32, 119, 105, 116, 104, 32, 97, 32, 98, 97, 99, 107,
  115, 108, 97, 115, 104, 32, 39, 92, 92, 39, 46, 32, 84, 111, 32, 97,
  118, 111, 105, 100, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 105, 111,
  110, 44, 32, 112, 108, 97, 99, 101, 10, 92, 110, 32, 32, 32, 32, 32,
  97, 110, 32, 101, 109, 112, 116, 121, 32, 100, 111, 117, 98, 108, 101, 32,
  113, 117, 111, 116, 101, 100, 32, 115, 116, 114, 105, 110, 103, 32, 106, 117,
  115, 116, 32, 97, 102, 116, 101, 114, 32, 116, 104, 101, 32, 39, 36, 39,
  32, 40, 97, 115, 32, 105, 110, 32, 39, 36, 92, 34, 92, 34, 49, 39,
  41, 46, 10, 92, 110, 32, 32, 45, 32, 83, 112, 101, 99, 105, 102, 121,
  105, 110, 103, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 109, 97,
  121, 32, 98, 101, 32, 115, 107, 105, 112, 112, 101, 100, 32, 119, 104, 101,
  110, 32, 105, 110, 118, 111, 107, 105, 110, 103, 32, 97, 32, 99, 117, 115,
  116, 111, 109, 32, 99, 111, 109, 109, 97, 110, 100, 44, 32, 98, 121, 32,
  114, 101, 112, 108, 97, 99, 105, 110, 103, 32, 116, 104, 101, 109, 32, 98,
  121, 10, 92, 110, 32, 32, 32, 32, 32, 99, 111, 109, 109, 97, 115, 32,
  39, 44, 39, 32, 97, 115, 32, 105, 110, 32, 101, 120, 112, 114, 101, 115,
  115, 105, 111, 110, 32, 39, 45, 102, 108, 111, 119, 101, 114, 32, 44, 44,
  51, 39, 46, 32, 79, 109, 105, 116, 116, 101, 100, 32, 97, 114, 103, 117,
  109, 101, 110, 116, 115, 32, 97, 114, 101, 32, 115, 101, 116, 32, 116, 111,
  32, 116, 104, 101, 105, 114, 32, 100, 101, 102, 97, 117, 108, 116, 10, 92,
  110, 32, 32, 32, 32, 32, 118, 97, 108, 117, 101, 115, 44, 32, 119, 104,
  105, 99, 104, 32, 109, 117, 115, 116, 32, 98, 101, 32, 116, 104, 117, 115,
  32, 101, 120, 112, 108, 105, 99, 105, 116, 108, 121, 32, 100, 101, 102, 105,
  110, 101, 100, 32, 105, 110, 32, 116, 104, 101, 32, 99, 111, 100, 101, 32,
  111, 102, 32, 116, 104, 101, 32, 99, 111, 114, 114, 101, 115, 112, 111, 110,
  100, 105, 110, 103, 32, 99, 117, 115, 116, 111, 109, 10, 92, 110, 32, 32,
  32, 32, 32, 99, 111, 109, 109, 97, 110, 100, 32, 40, 117, 115, 105, 110,
  103, 32, 100, 101, 102, 97, 117, 108, 116, 32, 97, 114, 103, 117, 109, 101,
  110, 116, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 115, 32, 97,
  115, 32, 39, 36, 34, 34, 123, 49, 61, 100, 101, 102, 97, 117, 108, 116,
  125, 39, 41, 46, 10, 92, 110, 32, 32, 45, 32, 73, 102, 32, 111, 110,
  101, 32, 110, 117, 109, 98, 101, 114, 101, 100, 32, 97, 114, 103, 117, 109,
  101, 110, 116, 32, 114, 101, 113, 117, 101, 115, 116, 101, 100, 32, 105, 110,
  32, 97, 32, 99, 117, 115, 116, 111, 109, 32, 99, 111, 109, 109, 97, 110,
  100, 32, 104, 97, 115, 32, 110, 111, 32, 118, 97, 108, 117, 101, 44, 32,
  97, 110, 32, 101, 114, 114, 111, 114, 32, 105, 115, 32, 116, 104, 114, 111,
  119, 110, 10, 92, 110, 32, 32, 32, 32, 32, 98, 121, 32, 116, 104, 101,
  32, 105, 110, 116, 101, 114, 112, 114, 101, 116, 101, 114, 46, 34, 10, 45,
  95, 104, 101, 108, 112, 95, 115, 101, 99, 116, 105, 111, 110, 32, 34, 76,
  105, 115, 116, 32, 111, 102, 32, 99, 111, 109, 109, 97, 110, 100, 115, 34,
  10, 45, 95, 104, 101, 108, 112, 95, 112, 97, 114, 97, 103, 114, 97, 112,
  104, 32, 34, 32, 65, 108, 108, 32, 97, 118, 97, 105, 108, 97, 98, 108,
  101, 32, 71, 39, 77, 73, 67, 32, 99, 111, 109, 109, 97, 110, 100, 115,
  32, 97, 114, 101, 32, 108, 105, 115, 116, 101, 100, 32, 98, 101, 108, 111,
  119, 44, 32, 99, 108, 97, 115, 115, 105, 102, 105, 101, 100, 32, 98, 121,
  32, 116, 104, 101, 109, 101, 115, 46, 10, 92, 110, 32, 87, 104, 101, 110,
  32, 115, 101, 118, 101, 114, 97, 108, 32, 99, 104, 111, 105, 99, 101, 115,
  32, 111, 102, 32, 99, 111, 109, 109, 97, 110, 100, 32, 97, 114, 103, 117,
  109, 101, 110, 116, 115, 32, 97, 114, 101, 32, 112, 111, 115, 115, 105, 98,
  108, 101, 44, 32, 116, 104, 101, 121, 32, 97, 112, 112, 101, 97, 114, 32,
  115, 101, 112, 97, 114, 97, 116, 101, 100, 32, 98, 121, 32, 39, 124, 39,
  46, 10, 92, 110, 32, 65, 110, 32, 97, 114, 103, 117, 109, 101, 110, 116,
  32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 105, 110, 115, 105, 100,
  101, 32, 39, 91, 93, 39, 32, 111, 114, 32, 115, 116, 97, 114, 116, 105,
  110, 103, 32, 98, 121, 32, 39, 95, 39, 32, 105, 115, 32, 111, 112, 116,
  105, 111, 110, 97, 108, 32, 101, 120, 99, 101, 112, 116, 32, 119, 104, 101,
  110, 32, 115, 116, 97, 110, 100, 105, 110, 103, 32, 102, 111, 114, 32, 97,
  110, 10, 92, 110, 32, 101, 120, 105, 115, 116, 105, 110, 103, 32, 105, 109,
  97, 103, 101, 32, 91, 105, 109, 97, 103, 101, 93, 44, 32, 119, 104, 101,
  114, 101, 32, 39, 105, 109, 97, 103, 101, 39, 32, 99, 97, 110, 32, 98,
  101, 32, 101, 105, 116, 104, 101, 114, 32, 97, 110, 32, 105, 110, 100, 105,
  99, 101, 32, 110, 117, 109, 98, 101, 114, 32, 111, 114, 32, 97, 110, 32,
  105, 109, 97, 103, 101, 32, 110, 97, 109, 101, 46, 10, 92, 110, 32, 73,
  110, 32, 116, 104, 105, 115, 32, 99, 97, 115, 101, 44, 32, 116, 104, 101,
  32, 39, 91, 93, 39, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 115,
  32, 97, 114, 101, 32, 109, 97, 110, 100, 97, 116, 111, 114, 121, 32, 119,
  104, 101, 110, 32, 119, 114, 105, 116, 105, 110, 103, 32, 116, 104, 101, 32,
  105, 116, 101, 109, 46, 32, 65, 32, 99, 111, 109, 109, 97, 110, 100, 32,
  109, 97, 114, 107, 101, 100, 32, 119, 105, 116, 104, 10, 92, 110, 32, 39,
  40, 42, 41, 39, 32, 111, 114, 32, 39, 40, 43, 41, 39, 32, 105, 115,
  32, 97, 32, 110, 97, 116, 105, 118, 101, 32, 99, 111, 109, 109, 97, 110,
  100, 46, 32, 39, 40, 42, 41, 39, 32, 109, 101, 97, 110, 115, 32, 116,
  104, 101, 32, 99, 111, 109, 109, 97, 110, 100, 32, 105, 115, 32, 97, 118,
  97, 105, 108, 97, 98, 108, 101, 32, 102, 111, 114, 32, 97, 108, 108, 32,
  112, 105, 120, 101, 108, 32, 116, 121, 112, 101, 115, 44, 10, 92, 110, 32,
  111, 116, 104, 101, 114, 119, 105, 115, 101, 32, 111, 110, 108, 121, 32, 102,
  111, 114, 32, 116, 104, 101, 32, 100, 101, 102, 97, 117, 108, 116, 32, 39,
  102, 108, 111, 97, 116, 39, 32, 112, 105, 120, 101, 108, 32, 116, 121, 112,
  101, 46, 10, 92, 110, 32, 82, 101, 109, 101, 109, 98, 101, 114, 32, 116,
  104, 97, 116, 32, 110, 97, 116, 105, 118, 101, 32, 99, 111, 109, 109, 97,
  110, 100, 115, 32, 114, 117, 110, 32, 102, 97, 115, 116, 101, 114, 32, 116,
  104, 97, 110, 32, 99, 117, 115, 116, 111, 109, 32, 99, 111, 109, 109, 97,
  110, 100, 115, 44, 32, 115, 111, 32, 117, 115, 101, 32, 116, 104, 101, 110,
  32, 119, 104, 101, 110, 32, 112, 111, 115, 115, 105, 98, 108, 101, 46, 10,
  92, 110, 32, 78, 111, 116, 101, 32, 97, 108, 115, 111, 32, 116, 104, 97,
  116, 32, 97, 108, 108, 32, 105, 109, 97, 103, 101, 115, 32, 105, 110, 32,
  116, 104, 105, 115, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 100,
  111, 99, 117, 109, 101, 110, 116, 97, 116, 105, 111, 110, 32, 97, 114, 101,
  32, 110, 111, 114, 109, 97, 108, 105, 122, 101, 100, 32, 105, 110, 32, 91,
  48, 44, 50, 53, 53, 93, 32, 98, 101, 102, 111, 114, 101, 10, 92, 110,
  32, 98, 101, 105, 110, 103, 32, 100, 105, 115, 112, 108, 97, 121, 101, 100,
  46, 32, 89, 111, 117, 32, 109, 97, 121, 32, 110, 101, 101, 100, 32, 116,
  111, 32, 100, 111, 32, 116, 104, 105, 115, 32, 109, 97, 110, 117, 97, 108,
  108, 121, 32, 40, 99, 111, 109, 109, 97, 110, 100, 32, 39, 45, 110, 111,
  114, 109, 97, 108, 105, 122, 101, 32, 48, 44, 50, 53, 53, 39, 41, 32,
  105, 102, 32, 121, 111, 117, 32, 119, 97, 110, 116, 10, 92, 110, 32, 115,
  97, 118, 101, 32, 105, 109, 97, 103, 101, 32, 102, 105, 108, 101, 115, 32,
  104, 97, 118, 105, 110, 103, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32,
  97, 115, 112, 101, 99, 116, 32, 116, 104, 97, 110, 32, 116, 104, 111, 115,
  101, 32, 100, 105, 115, 112, 108, 97, 121, 101, 100, 46, 34, 10, 95, 104,
  101, 108, 112, 95, 101, 120, 97, 109, 112, 108, 101, 115, 32, 58, 10, 45,
  95, 104, 101, 108, 112, 95, 115, 101, 99, 116, 105, 111, 110, 32, 34, 69,
  120, 97, 109, 112, 108, 101, 115, 32, 111, 102, 32, 117, 115, 101, 34, 10,
  45, 95, 104, 101, 108, 112, 95, 112, 97, 114, 97, 103, 114, 97, 112, 104,
  32, 34, 32, 39, 103, 109, 105, 99, 39, 32, 105, 115, 32, 97, 32, 103,
  101, 110, 101, 114, 105, 99, 32, 105, 109, 97, 103, 101, 32, 112, 114, 111,
  99, 101, 115, 115, 105, 110, 103, 32, 116, 111, 111, 108, 32, 119, 104, 105,
  99, 104, 32, 99, 97, 110, 32, 98, 101, 32, 117, 115, 101, 100, 32, 105,
  110, 32, 97, 32, 119, 105, 100, 101, 32, 118, 97, 114, 105, 101, 116, 121,
  32, 111, 102, 32, 115, 105, 116, 117, 97, 116, 105, 111, 110, 115, 46, 10,
  92, 110, 32, 84, 104, 101, 32, 102, 101, 119, 32, 101, 120, 97, 109, 112,
  108, 101, 115, 32, 98, 101, 108, 111, 119, 32, 105, 108, 108, 117, 115, 116,
  114, 97, 116, 101, 32, 112, 111, 115, 115, 105, 98, 108, 101, 32, 117, 115,
  101, 115, 32, 111, 102, 32, 116, 104, 105, 115, 32, 116, 111, 111, 108, 58,
  10, 92, 110, 10, 92, 110, 32, 32, 45, 32, 86, 105, 101, 119, 32, 97,
  32, 108, 105, 115, 116, 32, 111, 102, 32, 105, 109, 97, 103, 101, 115, 58,
  10, 92, 110, 32, 32, 32, 32, 32, 103, 109, 105, 99, 32, 102, 105, 108,
  101, 49, 46, 98, 109, 112, 32, 102, 105, 108, 101, 50, 46, 106, 112, 101,
  103, 10, 92, 110, 10, 92, 110, 32, 32, 45, 32, 67, 111, 110, 118, 101,
  114, 116, 32, 97, 110, 32, 105, 109, 97, 103, 101, 32, 102, 105, 108, 101,
  58, 10, 92, 110, 32, 32, 32, 32, 32, 103, 109, 105, 99, 32, 105, 110,
  112, 117, 116, 46, 98, 109, 112, 32, 45, 111, 32, 111, 117, 116, 112, 117,
  116, 46, 106, 112, 103, 10, 92, 110, 10, 92, 110, 32, 32, 45, 32, 67,
  114, 101, 97, 116, 101, 32, 97, 32, 118, 111, 108, 117, 109, 101, 116, 114,
  105, 99, 32, 105, 109, 97, 103, 101, 32, 102, 114, 111, 109, 32, 97, 32,
  109, 111, 118, 105, 101, 32, 115, 101, 113, 117, 101, 110, 99, 101, 58, 10,
  92, 110, 32, 32, 32, 32, 32, 103, 109, 105, 99, 32, 105, 110, 112, 117,
  116, 46, 109, 112, 103, 32, 45, 97, 32, 122, 32, 45, 111, 32, 111, 117,
  116, 112, 117, 116, 46, 104, 100, 114, 10, 92, 110, 10, 92, 110, 32, 32,
  45, 32, 67, 111, 109, 112, 117, 116, 101, 32, 105, 109, 97, 103, 101, 32,
  103, 114, 97, 100, 105, 101, 110, 116, 32, 110, 111, 114, 109, 58, 10, 92,
  110, 32, 32, 32, 32, 32, 103, 109, 105, 99, 32, 105, 110, 112, 117, 116,
  46, 98, 109, 112, 32, 45, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110,
  111, 114, 109, 10, 92, 110, 10, 92, 110, 32, 32, 45, 32, 68, 101, 110,
  111, 105, 115, 101, 32, 97, 32, 99, 111, 108, 111, 114, 32, 105, 109, 97,
  103, 101, 58, 10, 92, 110, 32, 32, 32, 32, 32, 103, 109, 105, 99, 32,
  105, 109, 97, 103, 101, 46, 106, 112, 103, 32, 45, 100, 101, 110, 111, 105,
  115, 101, 32, 51, 48, 44, 49, 48, 32, 45, 111, 32, 100, 101, 110, 111,
  105, 115, 101, 100, 46, 106, 112, 103, 10, 92, 110, 10, 92, 110, 32, 32,
  45, 32, 67, 111, 109, 112, 111, 115, 101, 32, 116, 119, 111, 32, 105, 109,
  97, 103, 101, 115, 32, 117, 115, 105, 110, 103, 32, 111, 118, 101, 114, 108,
  97, 121, 32, 108, 97, 121, 101, 114, 32, 98, 108, 101, 110, 100, 105, 110,
  103, 58, 10, 92, 110, 32, 32, 32, 32, 32, 103, 109, 105, 99, 32, 105,
  109, 97, 103, 101, 49, 46, 106, 112, 103, 32, 105, 109, 97, 103, 101, 50,
  46, 106, 112, 103, 32, 45, 98, 108, 101, 110, 100, 32, 111, 118, 101, 114,
  108, 97, 121, 32, 45, 111, 32, 98, 108, 101, 110, 100, 101, 100, 46, 106,
  112, 103, 10, 92, 110, 10, 92, 110, 32, 32, 45, 32, 69, 118, 97, 108,
  117, 97, 116, 101, 32, 97, 32, 109, 97, 116, 104, 101, 109, 97, 116, 105,
  99, 97, 108, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 58, 10,
  92, 110, 32, 32, 32, 32, 32, 103, 109, 105, 99, 32, 45, 101, 32, 92,
  34, 99, 111, 115, 40, 112, 105, 47, 52, 41, 94, 50, 43, 115, 105, 110,
  40, 112, 105, 47, 52, 41, 94, 50, 61, 123, 99, 111, 115, 40, 112, 105,
  47, 52, 41, 94, 50, 43, 115, 105, 110, 40, 112, 105, 47, 52, 41, 94,
  50, 125, 92, 34, 10, 92, 110, 10, 92, 110, 32, 32, 45, 32, 80, 108,
  111, 116, 32, 97, 32, 50, 100, 32, 102, 117, 110, 99, 116, 105, 111, 110,
  58, 10, 92, 110, 32, 32, 32, 32, 32, 103, 109, 105, 99, 32, 49, 48,
  48, 48, 44, 49, 44, 49, 44, 50, 32, 45, 102, 32, 92, 34, 88, 61,
  51, 42, 40, 120, 45, 53, 48, 48, 41, 47, 53, 48, 48, 59, 88, 94,
  50, 42, 115, 105, 110, 40, 51, 42, 88, 94, 50, 41, 43, 105, 102, 40,
  99, 61, 61, 48, 44, 117, 40, 48, 44, 45, 49, 41, 44, 99, 111, 115,
  40, 88, 42, 49, 48, 41, 41, 92, 34, 32, 45, 112, 108, 111, 116, 10,
  92, 110, 10, 92, 110, 32, 32, 45, 32, 80, 108, 111, 116, 32, 97, 32,
  51, 100, 32, 101, 108, 101, 118, 97, 116, 101, 100, 32, 102, 117, 110, 99,
  116, 105, 111, 110, 32, 105, 110, 32, 114, 97, 110, 100, 111, 109, 32, 99,
  111, 108, 111, 114, 115, 58, 10, 92, 110, 32, 32, 32, 32, 32, 103, 109,
  105, 99, 32, 49, 50, 56, 44, 49, 50, 56, 44, 49, 44, 51, 44, 92,
  34, 63, 40, 48, 44, 50, 53, 53, 41, 92, 34, 32, 45, 112, 108, 97,
  115, 109, 97, 32, 49, 48, 44, 51, 32, 45, 98, 108, 117, 114, 32, 52,
  32, 45, 115, 104, 97, 114, 112, 101, 110, 32, 49, 48, 48, 48, 48, 32,
  92, 92, 10, 92, 110, 32, 32, 32, 32, 32, 32, 45, 101, 108, 101, 118,
  97, 116, 105, 111, 110, 51, 100, 91, 45, 49, 93, 32, 92, 34, 39, 88,
  61, 40, 120, 45, 54, 52, 41, 47, 54, 59, 89, 61, 40, 121, 45, 54,
  52, 41, 47, 54, 59, 49, 48, 48, 42, 101, 120, 112, 40, 45, 40, 88,
  94, 50, 43, 89, 94, 50, 41, 47, 51, 48, 41, 42, 97, 98, 115, 40,
  99, 111, 115, 40, 88, 41, 42, 115, 105, 110, 40, 89, 41, 41, 39, 92,
  34, 10, 92, 110, 10, 92, 110, 32, 32, 45, 32, 80, 108, 111, 116, 32,
  116, 104, 101, 32, 105, 115, 111, 115, 117, 114, 102, 97, 99, 101, 32, 111,
  102, 32, 97, 32, 51, 100, 32, 118, 111, 108, 117, 109, 101, 58, 10, 92,
  110, 32, 32, 32, 32, 32, 103, 109, 105, 99, 32, 45, 109, 51, 100, 32,
  53, 32, 45, 109, 100, 51, 100, 32, 53, 32, 45, 100, 98, 51, 100, 32,
  48, 32, 45, 105, 115, 111, 115, 117, 114, 102, 97, 99, 101, 51, 100, 32,
  92, 34, 39, 120, 94, 50, 43, 121, 94, 50, 43, 97, 98, 115, 40, 122,
  41, 94, 97, 98, 115, 40, 52, 42, 99, 111, 115, 40, 120, 42, 121, 42,
  122, 42, 51, 41, 41, 39, 92, 34, 44, 51, 10, 92, 110, 10, 92, 110,
  32, 32, 45, 32, 82, 101, 110, 100, 101, 114, 32, 97, 32, 71, 39, 77,
  73, 67, 32, 51, 100, 32, 108, 111, 103, 111, 58, 10, 92, 110, 32, 32,
  32, 32, 32, 103, 109, 105, 99, 32, 49, 32, 45, 116, 101, 120, 116, 32,
  71, 92, 92, 39, 77, 73, 67, 44, 48, 44, 48, 44, 53, 55, 44, 49,
  44, 49, 44, 49, 44, 49, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120,
  121, 32, 49, 48, 44, 48, 32, 45, 98, 108, 117, 114, 32, 50, 32, 45,
  110, 32, 48, 44, 49, 48, 48, 32, 45, 45, 112, 108, 97, 115, 109, 97,
  32, 48, 46, 52, 32, 45, 43, 32, 92, 92, 10, 92, 110, 32, 32, 32,
  32, 32, 32, 45, 98, 108, 117, 114, 32, 49, 32, 45, 101, 108, 101, 118,
  97, 116, 105, 111, 110, 51, 100, 32, 45, 48, 46, 49, 32, 45, 109, 100,
  51, 100, 32, 52, 10, 92, 110, 10, 92, 110, 32, 32, 45, 32, 71, 101,
  110, 101, 114, 97, 116, 101, 32, 97, 32, 51, 100, 32, 114, 105, 110, 103,
  32, 111, 102, 32, 116, 111, 114, 105, 105, 58, 10, 92, 110, 32, 32, 32,
  32, 32, 103, 109, 105, 99, 32, 45, 114, 101, 112, 101, 97, 116, 32, 50,
  48, 32, 45, 116, 111, 114, 117, 115, 51, 100, 32, 49, 53, 44, 50, 32,
  45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 92, 34, 123, 63, 40,
  54, 48, 44, 50, 53, 53, 41, 125, 44, 123, 63, 40, 54, 48, 44, 50,
  53, 53, 41, 125, 44, 123, 63, 40, 54, 48, 44, 50, 53, 53, 41, 125,
  92, 34, 32, 92, 92, 10, 92, 110, 32, 32, 32, 32, 32, 32, 45, 42,
  51, 100, 91, 45, 49, 93, 32, 48, 46, 53, 44, 49, 32, 45, 105, 102,
  32, 92, 34, 123, 36, 62, 37, 50, 125, 92, 34, 32, 45, 114, 51, 100,
  91, 45, 49, 93, 32, 48, 44, 49, 44, 48, 44, 57, 48, 32, 45, 101,
  110, 100, 105, 102, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 55, 48,
  32, 45, 43, 51, 100, 32, 92, 92, 10, 92, 110, 32, 32, 32, 32, 32,
  32, 45, 114, 51, 100, 32, 48, 44, 48, 44, 49, 44, 49, 56, 32, 45,
  100, 111, 110, 101, 32, 45, 109, 100, 51, 100, 32, 51, 32, 45, 109, 51,
  100, 32, 53, 32, 45, 100, 98, 51, 100, 32, 48, 10, 92, 110, 10, 92,
  110, 32, 32, 45, 32, 67, 114, 101, 97, 116, 101, 32, 97, 32, 118, 97,
  115, 101, 32, 102, 114, 111, 109, 32, 97, 32, 51, 100, 32, 105, 115, 111,
  115, 117, 114, 102, 97, 99, 101, 58, 10, 92, 110, 32, 32, 32, 32, 32,
  103, 109, 105, 99, 32, 45, 109, 100, 51, 100, 32, 52, 32, 45, 105, 115,
  111, 115, 117, 114, 102, 97, 99, 101, 51, 100, 32, 92, 34, 39, 120, 94,
  50, 43, 50, 42, 97, 98, 115, 40, 121, 47, 50, 41, 42, 115, 105, 110,
  40, 50, 42, 121, 41, 94, 50, 43, 122, 94, 50, 45, 51, 39, 44, 48,
  92, 34, 32, 45, 115, 112, 104, 101, 114, 101, 51, 100, 32, 49, 46, 53,
  32, 92, 92, 10, 92, 110, 32, 32, 32, 32, 32, 32, 45, 45, 51, 100,
  91, 45, 49, 93, 32, 48, 44, 53, 32, 45, 112, 108, 97, 110, 101, 51,
  100, 32, 49, 53, 44, 49, 53, 32, 45, 114, 51, 100, 91, 45, 49, 93,
  32, 49, 44, 48, 44, 48, 44, 57, 48, 32, 45, 99, 51, 100, 91, 45,
  49, 93, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 48, 44, 51, 46,
  50, 32, 92, 92, 10, 92, 110, 32, 32, 32, 32, 32, 32, 45, 99, 111,
  108, 51, 100, 91, 45, 49, 93, 32, 49, 56, 48, 44, 49, 53, 48, 44,
  50, 53, 53, 32, 45, 99, 111, 108, 51, 100, 91, 45, 50, 93, 32, 49,
  50, 56, 44, 50, 53, 53, 44, 48, 32, 45, 99, 111, 108, 51, 100, 91,
  45, 51, 93, 32, 50, 53, 53, 44, 49, 50, 56, 44, 48, 32, 45, 43,
  51, 100, 10, 92, 110, 10, 92, 110, 32, 32, 45, 32, 68, 105, 115, 112,
  108, 97, 121, 32, 102, 105, 108, 116, 101, 114, 101, 100, 32, 119, 101, 98,
  99, 97, 109, 32, 115, 116, 114, 101, 97, 109, 58, 10, 92, 110, 32, 32,
  32, 32, 32, 103, 109, 105, 99, 32, 45, 97, 112, 112, 108, 121, 95, 99,
  97, 109, 101, 114, 97, 32, 92, 92, 92, 34, 45, 45, 109, 105, 114, 114,
  111, 114, 32, 120, 32, 45, 45, 109, 105, 114, 114, 111, 114, 32, 121, 32,
  45, 43, 32, 45, 47, 32, 52, 92, 92, 92, 34, 10, 92, 110, 10, 92,
  110, 32, 32, 45, 32, 76, 97, 117, 110, 99, 104, 32, 97, 32, 115, 101,
  116, 32, 111, 102, 32, 71, 39, 77, 73, 67, 32, 105, 110, 116, 101, 114,
  97, 99, 116, 105, 118, 101, 32, 100, 101, 109, 111, 115, 58, 10, 92, 110,
  32, 32, 32, 32, 32, 103, 109, 105, 99, 32, 45, 100, 101, 109, 111, 10,
  92, 110, 34, 10, 118, 101, 114, 115, 105, 111, 110, 32, 58, 10, 45, 118,
  32, 45, 32, 45, 95, 95, 104, 101, 108, 112, 95, 104, 101, 97, 100, 101,
  114, 95, 97, 115, 99, 105, 105, 91, 93, 32, 45, 118, 32, 43, 10, 45,
  101, 91, 93, 32, 34, 34, 10, 97, 112, 112, 108, 121, 95, 99, 97, 109,
  101, 114, 97, 32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36, 123, 49,
  61, 125, 44, 36, 123, 52, 61, 125, 34, 32, 45, 99, 104, 101, 99, 107,
  32, 34, 36, 123, 50, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36,
  123, 51, 61, 48, 125, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100,
  32, 39, 36, 49, 39, 32, 111, 110, 32, 99, 97, 109, 101, 114, 97, 32,
  115, 116, 114, 101, 97, 109, 32, 92, 35, 36, 50, 44, 32, 119, 105, 116,
  104, 32, 36, 51, 32, 102, 114, 97, 109, 101, 115, 32, 115, 107, 105, 112,
  32, 97, 110, 100, 32, 102, 105, 108, 101, 110, 97, 109, 101, 32, 39, 36,
  52, 39, 46, 34, 32, 45, 118, 32, 45, 10, 45, 108, 91, 93, 32, 102,
  114, 97, 109, 101, 61, 48, 32, 45, 100, 111, 10, 45, 99, 97, 109, 101,
  114, 97, 32, 36, 50, 44, 49, 44, 36, 51, 32, 36, 49, 32, 45, 119,
  91, 45, 49, 93, 32, 45, 49, 44, 45, 49, 44, 34, 40, 67, 97, 109,
  101, 114, 97, 32, 34, 36, 115, 116, 114, 101, 97, 109, 34, 44, 32, 34,
  123, 119, 125, 120, 123, 104, 125, 34, 41, 34, 10, 45, 105, 102, 32, 123,
  110, 97, 114, 103, 40, 34, 36, 52, 34, 41, 125, 32, 45, 111, 91, 45,
  49, 93, 32, 64, 123, 45, 102, 105, 108, 101, 110, 97, 109, 101, 92, 32,
  34, 36, 52, 34, 44, 36, 102, 114, 97, 109, 101, 125, 32, 102, 114, 97,
  109, 101, 61, 123, 36, 102, 114, 97, 109, 101, 43, 49, 125, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 64, 123, 33, 44, 83, 125, 32,
  45, 111, 91, 45, 49, 93, 32, 103, 109, 105, 99, 95, 99, 97, 109, 101,
  114, 97, 46, 112, 110, 103, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 40, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84,
  125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 44, 67, 84, 82, 76, 82,
  73, 71, 72, 84, 125, 41, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44,
  68, 125, 125, 32, 45, 119, 91, 93, 32, 123, 64, 123, 33, 44, 119, 125,
  42, 49, 46, 53, 125, 44, 123, 64, 123, 33, 44, 104, 125, 42, 49, 46,
  53, 125, 32, 45, 119, 97, 105, 116, 32, 45, 49, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 40, 64, 123, 33, 44, 67, 84, 82,
  76, 76, 69, 70, 84, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 44,
  67, 84, 82, 76, 82, 73, 71, 72, 84, 125, 41, 34, 32, 38, 38, 32,
  34, 64, 123, 33, 44, 67, 125, 125, 32, 45, 119, 91, 93, 32, 123, 64,
  123, 33, 44, 119, 125, 47, 49, 46, 53, 125, 44, 123, 64, 123, 33, 44,
  104, 125, 47, 49, 46, 53, 125, 32, 45, 119, 97, 105, 116, 32, 45, 49,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 40, 64, 123,
  33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 34, 32, 124, 124, 32,
  34, 64, 123, 33, 44, 67, 84, 82, 76, 82, 73, 71, 72, 84, 125, 41,
  34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 82, 125, 125, 32, 45, 119,
  91, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125,
  32, 45, 119, 97, 105, 116, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 119, 104, 105, 108, 101, 32,
  123, 64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83,
  67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125,
  32, 45, 101, 110, 100, 108, 32, 45, 118, 32, 43, 10, 97, 112, 112, 108,
  121, 95, 102, 105, 108, 101, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32,
  34, 36, 123, 51, 61, 103, 109, 105, 99, 95, 125, 34, 44, 36, 123, 52,
  61, 48, 125, 10, 45, 118, 32, 45, 10, 40, 123, 39, 34, 36, 50, 34,
  39, 125, 41, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49,
  93, 32, 51, 50, 32, 45, 114, 101, 112, 108, 97, 99, 101, 91, 45, 49,
  93, 32, 51, 50, 44, 123, 39, 44, 39, 125, 32, 102, 105, 108, 101, 115,
  61, 64, 123, 45, 49, 44, 116, 125, 10, 45, 105, 102, 32, 123, 119, 62,
  49, 50, 56, 125, 32, 45, 122, 91, 45, 49, 93, 32, 48, 44, 49, 50,
  55, 32, 115, 95, 102, 105, 108, 101, 115, 61, 64, 123, 45, 49, 44, 116,
  125, 46, 46, 46, 32, 45, 101, 108, 115, 101, 32, 115, 95, 102, 105, 108,
  101, 115, 61, 36, 102, 105, 108, 101, 115, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 109, 32, 34, 95, 97, 112,
  112, 108, 121, 95, 102, 105, 108, 101, 115, 32, 58, 32, 36, 34, 34, 61,
  95, 102, 105, 108, 101, 32, 95, 110, 98, 95, 102, 105, 108, 101, 115, 61,
  36, 34, 34, 35, 34, 32, 45, 95, 97, 112, 112, 108, 121, 95, 102, 105,
  108, 101, 115, 32, 36, 102, 105, 108, 101, 115, 32, 45, 117, 110, 99, 111,
  109, 109, 97, 110, 100, 32, 95, 97, 112, 112, 108, 121, 95, 102, 105, 108,
  101, 115, 10, 45, 109, 32, 34, 95, 97, 112, 112, 108, 121, 95, 102, 105,
  108, 101, 115, 32, 58, 32, 36, 49, 34, 10, 45, 118, 32, 43, 32, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111,
  109, 109, 97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110, 32, 102, 105,
  108, 101, 115, 32, 39, 34, 36, 115, 95, 102, 105, 108, 101, 115, 34, 39,
  32, 97, 110, 100, 32, 115, 97, 118, 101, 32, 114, 101, 115, 117, 108, 116,
  32, 119, 105, 116, 104, 32, 112, 114, 101, 102, 105, 120, 32, 39, 36, 51,
  39, 46, 92, 110, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 36, 95, 110, 98, 95, 102, 105, 108, 101, 115, 32, 45, 108,
  91, 93, 10, 102, 105, 108, 101, 61, 36, 123, 95, 102, 105, 108, 101, 123,
  36, 62, 43, 49, 125, 125, 10, 95, 102, 105, 108, 101, 61, 64, 123, 45,
  98, 97, 115, 101, 110, 97, 109, 101, 92, 32, 36, 102, 105, 108, 101, 125,
  10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 114, 32, 45,
  32, 73, 109, 97, 103, 101, 32, 34, 123, 49, 43, 36, 62, 125, 47, 36,
  95, 110, 98, 95, 102, 105, 108, 101, 115, 34, 32, 91, 34, 36, 95, 102,
  105, 108, 101, 34, 93, 32, 32, 32, 32, 32, 32, 32, 32, 34, 32, 45,
  118, 32, 45, 10, 36, 102, 105, 108, 101, 32, 45, 95, 97, 112, 112, 108,
  121, 95, 102, 105, 108, 101, 115, 10, 45, 111, 32, 34, 36, 51, 34, 36,
  95, 102, 105, 108, 101, 10, 45, 105, 102, 32, 36, 52, 32, 45, 119, 91,
  45, 49, 93, 32, 64, 123, 45, 102, 105, 116, 115, 99, 114, 101, 101, 110,
  92, 32, 123, 119, 125, 44, 123, 104, 125, 44, 123, 100, 125, 125, 44, 49,
  44, 48, 44, 45, 49, 44, 45, 49, 44, 36, 95, 102, 105, 108, 101, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 10, 45, 111, 110, 102, 97,
  105, 108, 32, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 110,
  32, 45, 32, 69, 114, 114, 111, 114, 32, 111, 99, 99, 117, 114, 101, 100,
  32, 111, 110, 32, 102, 105, 108, 101, 32, 39, 34, 36, 102, 105, 108, 101,
  34, 39, 46, 92, 110, 34, 32, 45, 118, 32, 45, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 117, 110, 99, 111, 109, 109, 97,
  110, 100, 32, 95, 97, 112, 112, 108, 121, 95, 102, 105, 108, 101, 115, 32,
  45, 118, 32, 43, 10, 99, 117, 112, 105, 100, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 36, 123, 49, 61, 52, 56, 48, 125, 62, 61, 49,
  34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116,
  32, 36, 49, 120, 36, 49, 32, 99, 117, 112, 105, 100, 32, 98, 105, 110,
  97, 114, 121, 32, 109, 97, 115, 107, 46, 34, 32, 45, 118, 32, 45, 10,
  45, 108, 91, 93, 10, 40, 52, 56, 48, 44, 52, 56, 48, 44, 49, 44,
  49, 44, 48, 44, 45, 52, 54, 52, 48, 44, 45, 56, 44, 49, 44, 45,
  55, 44, 45, 57, 44, 49, 44, 45, 52, 53, 53, 44, 45, 49, 49, 44,
  49, 44, 45, 51, 44, 45, 49, 50, 44, 49, 44, 45, 52, 53, 51, 44,
  45, 49, 51, 44, 49, 44, 48, 44, 45, 49, 52, 44, 49, 44, 45, 52,
  53, 50, 44, 45, 50, 56, 44, 49, 44, 45, 52, 53, 50, 44, 45, 50,
  57, 44, 49, 44, 45, 52, 53, 48, 44, 45, 51, 48, 44, 49, 44, 45,
  52, 53, 48, 44, 45, 51, 48, 44, 49, 44, 45, 52, 53, 48, 44, 45,
  51, 48, 44, 49, 44, 45, 52, 53, 48, 44, 45, 51, 48, 44, 49, 44,
  45, 52, 53, 48, 44, 45, 51, 48, 44, 49, 44, 45, 52, 53, 48, 44,
  45, 51, 48, 44, 49, 44, 45, 52, 53, 48, 44, 45, 51, 48, 44, 49,
  44, 45, 52, 53, 49, 44, 45, 50, 57, 44, 49, 44, 45, 52, 53, 49,
  44, 45, 50, 56, 44, 49, 44, 45, 52, 53, 50, 44, 45, 50, 56, 44,
  49, 44, 45, 52, 53, 51, 44, 45, 50, 54, 44, 49, 44, 45, 52, 53,
  52, 44, 45, 50, 54, 44, 49, 44, 45, 52, 53, 53, 44, 45, 50, 52,
  44, 49, 44, 45, 52, 53, 54, 44, 45, 50, 52, 44, 49, 44, 45, 52,
  53, 55, 44, 45, 50, 50, 44, 49, 44, 45, 52, 53, 57, 44, 45, 50,
  48, 44, 49, 44, 45, 52, 54, 49, 44, 45, 49, 56, 44, 49, 44, 45,
  52, 54, 50, 44, 45, 49, 55, 44, 49, 44, 45, 52, 54, 52, 44, 45,
  49, 53, 44, 49, 44, 45, 52, 54, 54, 44, 45, 49, 51, 44, 49, 44,
  45, 52, 54, 57, 44, 45, 49, 48, 44, 49, 44, 45, 52, 55, 49, 44,
  45, 56, 44, 49, 44, 45, 52, 55, 51, 44, 45, 54, 44, 49, 44, 45,
  52, 55, 54, 44, 45, 50, 44, 49, 44, 45, 49, 48, 49, 50, 54, 44,
  45, 51, 44, 49, 44, 45, 49, 55, 44, 45, 49, 49, 44, 49, 44, 45,
  52, 52, 53, 44, 45, 49, 49, 44, 49, 44, 45, 49, 49, 44, 45, 49,
  53, 44, 49, 44, 45, 51, 48, 53, 44, 45, 53, 44, 49, 44, 45, 49,
  51, 49, 44, 45, 49, 53, 44, 49, 44, 45, 56, 44, 45, 49, 55, 44,
  49, 44, 45, 51, 48, 51, 44, 45, 57, 44, 49, 44, 45, 49, 53, 44,
  45, 50, 44, 49, 44, 45, 49, 49, 48, 44, 45, 49, 55, 44, 49, 44,
  45, 54, 44, 45, 49, 57, 44, 49, 44, 45, 51, 48, 50, 44, 45, 49,
  49, 44, 49, 44, 45, 49, 50, 44, 45, 52, 44, 49, 44, 45, 49, 48,
  56, 44, 45, 50, 48, 44, 49, 44, 45, 50, 44, 45, 50, 50, 44, 49,
  44, 45, 51, 48, 50, 44, 45, 49, 50, 44, 49, 44, 45, 57, 44, 45,
  53, 44, 49, 44, 45, 49, 52, 44, 45, 50, 44, 49, 44, 45, 57, 50,
  44, 45, 52, 52, 44, 49, 44, 45, 51, 48, 50, 44, 45, 49, 51, 44,
  49, 44, 45, 56, 44, 45, 53, 44, 49, 44, 45, 49, 51, 44, 45, 52,
  44, 49, 44, 45, 57, 48, 44, 45, 52, 54, 44, 49, 44, 45, 51, 48,
  50, 44, 45, 49, 51, 44, 49, 44, 45, 53, 44, 45, 55, 44, 49, 44,
  45, 49, 51, 44, 45, 52, 44, 49, 44, 45, 57, 48, 44, 45, 52, 54,
  44, 49, 44, 45, 51, 48, 50, 44, 45, 49, 52, 44, 49, 44, 45, 51,
  44, 45, 56, 44, 49, 44, 45, 49, 51, 44, 45, 53, 44, 49, 44, 45,
  56, 57, 44, 45, 52, 54, 44, 49, 44, 45, 51, 48, 50, 44, 45, 50,
  53, 44, 49, 44, 45, 49, 51, 44, 45, 55, 44, 49, 44, 45, 56, 54,
  44, 45, 52, 56, 44, 49, 44, 45, 51, 48, 50, 44, 45, 50, 52, 44,
  49, 44, 45, 49, 51, 44, 45, 57, 44, 49, 44, 48, 44, 45, 53, 44,
  49, 44, 45, 55, 56, 44, 45, 52, 56, 44, 49, 44, 45, 51, 48, 50,
  44, 45, 50, 53, 44, 49, 44, 45, 49, 50, 44, 45, 49, 53, 44, 49,
  44, 45, 55, 56, 44, 45, 52, 56, 44, 49, 44, 45, 50, 57, 48, 44,
  45, 50, 44, 49, 44, 45, 49, 48, 44, 45, 50, 53, 44, 49, 44, 45,
  49, 50, 44, 45, 49, 53, 44, 49, 44, 45, 55, 56, 44, 45, 52, 56,
  44, 49, 44, 45, 50, 56, 54, 44, 45, 49, 49, 44, 49, 44, 45, 52,
  44, 45, 51, 51, 44, 49, 44, 45, 52, 44, 45, 49, 54, 44, 49, 44,
  45, 55, 56, 44, 45, 52, 56, 44, 49, 44, 45, 50, 56, 52, 44, 45,
  53, 50, 44, 49, 44, 45, 50, 44, 45, 49, 54, 44, 49, 44, 45, 55,
  56, 44, 45, 52, 56, 44, 49, 44, 45, 50, 56, 50, 44, 45, 55, 50,
  44, 49, 44, 45, 55, 56, 44, 45, 52, 56, 44, 49, 44, 45, 50, 56,
  49, 44, 45, 55, 51, 44, 49, 44, 45, 55, 56, 44, 45, 52, 56, 44,
  49, 44, 45, 50, 56, 48, 44, 45, 55, 52, 44, 49, 44, 45, 55, 56,
  44, 45, 52, 56, 44, 49, 44, 45, 50, 55, 57, 44, 45, 55, 53, 44,
  49, 44, 45, 55, 56, 44, 45, 52, 55, 44, 49, 44, 45, 50, 55, 57,
  44, 45, 55, 55, 44, 49, 44, 45, 55, 55, 44, 45, 52, 55, 44, 49,
  44, 45, 50, 55, 56, 44, 45, 55, 56, 44, 49, 44, 45, 55, 56, 44,
  45, 52, 54, 44, 49, 44, 45, 50, 55, 55, 44, 45, 55, 57, 44, 49,
  44, 45, 55, 56, 44, 45, 52, 53, 44, 49, 44, 45, 50, 55, 55, 44,
  45, 56, 49, 44, 49, 44, 45, 55, 55, 44, 45, 52, 53, 44, 49, 44,
  45, 50, 55, 54, 44, 45, 56, 50, 44, 49, 44, 45, 55, 56, 44, 45,
  52, 52, 44, 49, 44, 45, 50, 55, 53, 44, 45, 56, 52, 44, 49, 44,
  45, 55, 55, 44, 45, 52, 51, 44, 49, 44, 45, 50, 55, 52, 44, 45,
  56, 55, 44, 49, 44, 45, 55, 55, 44, 45, 52, 50, 44, 49, 44, 45,
  50, 55, 50, 44, 45, 57, 48, 44, 49, 44, 45, 55, 54, 44, 45, 52,
  49, 44, 49, 44, 45, 50, 55, 49, 44, 45, 57, 50, 44, 49, 44, 45,
  55, 54, 44, 45, 52, 48, 44, 49, 44, 45, 50, 55, 49, 44, 45, 57,
  52, 44, 49, 44, 45, 55, 54, 44, 45, 51, 57, 44, 49, 44, 45, 50,
  55, 48, 44, 45, 57, 53, 44, 49, 44, 45, 55, 55, 44, 45, 51, 55,
  44, 49, 44, 45, 50, 55, 48, 44, 45, 49, 48, 55, 44, 49, 44, 45,
  54, 54, 44, 45, 51, 55, 44, 49, 44, 45, 50, 54, 57, 44, 45, 49,
  49, 48, 44, 49, 44, 45, 54, 53, 44, 45, 51, 53, 44, 49, 44, 45,
  50, 54, 57, 44, 45, 49, 49, 49, 44, 49, 44, 45, 54, 54, 44, 45,
  51, 51, 44, 49, 44, 45, 50, 54, 56, 44, 45, 49, 49, 53, 44, 49,
  44, 45, 54, 53, 44, 45, 51, 49, 44, 49, 44, 45, 50, 54, 55, 44,
  45, 49, 49, 55, 44, 49, 44, 45, 54, 53, 44, 45, 51, 48, 44, 49,
  44, 45, 50, 54, 54, 44, 45, 49, 50, 48, 44, 49, 44, 45, 54, 53,
  44, 45, 50, 57, 44, 49, 44, 45, 50, 54, 54, 44, 45, 49, 50, 48,
  44, 49, 44, 45, 54, 54, 44, 45, 50, 55, 44, 49, 44, 45, 50, 54,
  54, 44, 45, 49, 50, 49, 44, 49, 44, 45, 54, 55, 44, 45, 50, 53,
  44, 49, 44, 45, 50, 54, 54, 44, 45, 49, 50, 49, 44, 49, 44, 45,
  54, 57, 44, 45, 50, 51, 44, 49, 44, 45, 50, 54, 55, 44, 45, 49,
  49, 50, 44, 49, 44, 45, 55, 57, 44, 45, 50, 49, 44, 49, 44, 45,
  50, 54, 55, 44, 45, 49, 49, 50, 44, 49, 44, 45, 56, 49, 44, 45,
  49, 57, 44, 49, 44, 45, 49, 54, 56, 44, 45, 54, 44, 49, 44, 45,
  57, 52, 44, 45, 49, 49, 49, 44, 49, 44, 45, 56, 52, 44, 45, 49,
  54, 44, 49, 44, 45, 49, 54, 57, 44, 45, 55, 44, 49, 44, 45, 57,
  51, 44, 45, 49, 49, 48, 44, 49, 44, 45, 56, 54, 44, 45, 49, 51,
  44, 49, 44, 45, 49, 55, 48, 44, 45, 57, 44, 49, 44, 45, 57, 50,
  44, 45, 49, 48, 57, 44, 49, 44, 45, 56, 56, 44, 45, 49, 49, 44,
  49, 44, 45, 49, 55, 49, 44, 45, 49, 49, 44, 49, 44, 45, 57, 48,
  44, 45, 49, 48, 57, 44, 49, 44, 45, 56, 57, 44, 45, 57, 44, 49,
  44, 45, 49, 55, 50, 44, 45, 49, 50, 44, 49, 44, 45, 56, 57, 44,
  45, 49, 48, 57, 44, 49, 44, 45, 57, 49, 44, 45, 54, 44, 49, 44,
  45, 49, 55, 51, 44, 45, 49, 51, 44, 49, 44, 45, 56, 56, 44, 45,
  49, 48, 57, 44, 49, 44, 45, 50, 55, 48, 44, 45, 49, 52, 44, 49,
  44, 45, 56, 55, 44, 45, 49, 48, 57, 44, 49, 44, 45, 50, 55, 48,
  44, 45, 49, 53, 44, 49, 44, 45, 56, 54, 44, 45, 49, 49, 48, 44,
  49, 44, 45, 50, 54, 57, 44, 45, 49, 54, 44, 49, 44, 45, 56, 53,
  44, 45, 49, 49, 48, 44, 49, 44, 45, 50, 54, 57, 44, 45, 49, 55,
  44, 49, 44, 45, 56, 52, 44, 45, 49, 49, 48, 44, 49, 44, 45, 50,
  54, 57, 44, 45, 49, 56, 44, 49, 44, 45, 56, 51, 44, 45, 49, 49,
  49, 44, 49, 44, 45, 50, 54, 57, 44, 45, 49, 56, 44, 49, 44, 45,
  56, 50, 44, 45, 49, 49, 49, 44, 49, 44, 45, 50, 54, 57, 44, 45,
  50, 48, 44, 49, 44, 45, 56, 48, 44, 45, 49, 49, 50, 44, 49, 44,
  45, 50, 54, 57, 44, 45, 50, 48, 44, 49, 44, 45, 55, 57, 44, 45,
  49, 49, 50, 44, 49, 44, 45, 50, 54, 57, 44, 45, 50, 49, 44, 49,
  44, 45, 55, 56, 44, 45, 49, 49, 50, 44, 49, 44, 45, 50, 55, 48,
  44, 45, 50, 50, 44, 49, 44, 45, 55, 54, 44, 45, 49, 49, 51, 44,
  49, 44, 45, 50, 54, 57, 44, 45, 50, 51, 44, 49, 44, 45, 55, 53,
  44, 45, 49, 49, 51, 44, 49, 44, 45, 50, 55, 48, 44, 45, 50, 51,
  44, 49, 44, 45, 55, 52, 44, 45, 49, 49, 51, 44, 49, 44, 45, 50,
  55, 49, 44, 45, 50, 51, 44, 49, 44, 45, 55, 51, 44, 45, 49, 49,
  51, 44, 49, 44, 45, 50, 55, 49, 44, 45, 50, 53, 44, 49, 44, 45,
  55, 48, 44, 45, 49, 49, 52, 44, 49, 44, 45, 50, 55, 50, 44, 45,
  50, 54, 44, 49, 44, 45, 54, 55, 44, 45, 49, 49, 53, 44, 49, 44,
  45, 50, 55, 50, 44, 45, 50, 56, 44, 49, 44, 45, 54, 53, 44, 45,
  49, 49, 53, 44, 49, 44, 45, 50, 55, 51, 44, 45, 50, 57, 44, 49,
  44, 45, 54, 50, 44, 45, 49, 49, 54, 44, 49, 44, 45, 50, 55, 51,
  44, 45, 51, 50, 44, 49, 44, 45, 53, 56, 44, 45, 49, 49, 55, 44,
  49, 44, 45, 50, 55, 52, 44, 45, 51, 51, 44, 49, 44, 45, 53, 54,
  44, 45, 49, 49, 55, 44, 49, 44, 45, 50, 55, 53, 44, 45, 51, 52,
  44, 49, 44, 45, 53, 51, 44, 45, 49, 49, 56, 44, 49, 44, 45, 50,
  55, 54, 44, 45, 51, 53, 44, 49, 44, 45, 53, 49, 44, 45, 49, 49,
  56, 44, 49, 44, 45, 50, 55, 55, 44, 45, 51, 55, 44, 49, 44, 45,
  52, 56, 44, 45, 49, 49, 56, 44, 49, 44, 45, 50, 55, 55, 44, 45,
  52, 48, 44, 49, 44, 45, 52, 53, 44, 45, 49, 49, 56, 44, 49, 44,
  45, 50, 55, 56, 44, 45, 52, 49, 44, 49, 44, 45, 52, 51, 44, 45,
  49, 49, 56, 44, 49, 44, 45, 50, 54, 56, 44, 45, 54, 44, 49, 44,
  45, 53, 44, 45, 52, 51, 44, 49, 44, 45, 52, 48, 44, 45, 49, 49,
  55, 44, 49, 44, 45, 50, 54, 56, 44, 45, 49, 48, 44, 49, 44, 45,
  51, 44, 45, 52, 53, 44, 49, 44, 45, 51, 55, 44, 45, 49, 49, 55,
  44, 49, 44, 45, 53, 49, 44, 48, 44, 49, 44, 45, 50, 49, 54, 44,
  45, 49, 49, 44, 49, 44, 45, 51, 44, 45, 52, 55, 44, 49, 44, 45,
  51, 52, 44, 45, 49, 49, 55, 44, 49, 44, 45, 53, 48, 44, 45, 51,
  44, 49, 44, 45, 50, 49, 52, 44, 45, 54, 54, 44, 49, 44, 45, 51,
  48, 44, 45, 49, 49, 55, 44, 49, 44, 45, 52, 57, 44, 45, 52, 44,
  49, 44, 45, 50, 49, 52, 44, 45, 54, 57, 44, 49, 44, 45, 50, 55,
  44, 45, 49, 49, 55, 44, 49, 44, 45, 52, 57, 44, 45, 51, 44, 49,
  44, 45, 50, 49, 53, 44, 45, 55, 49, 44, 49, 44, 45, 50, 54, 44,
  45, 49, 49, 53, 44, 49, 44, 45, 52, 57, 44, 45, 52, 44, 49, 44,
  45, 50, 49, 53, 44, 45, 55, 51, 44, 49, 44, 45, 50, 51, 44, 45,
  49, 49, 54, 44, 49, 44, 45, 52, 57, 44, 45, 52, 44, 49, 44, 45,
  50, 49, 54, 44, 45, 55, 52, 44, 49, 44, 45, 50, 49, 44, 45, 49,
  49, 54, 44, 49, 44, 45, 52, 57, 44, 45, 52, 44, 49, 44, 45, 50,
  49, 54, 44, 45, 55, 53, 44, 49, 44, 45, 50, 48, 44, 45, 49, 49,
  53, 44, 49, 44, 45, 53, 48, 44, 45, 52, 44, 49, 44, 45, 50, 49,
  54, 44, 45, 55, 54, 44, 49, 44, 45, 49, 57, 44, 45, 49, 49, 53,
  44, 49, 44, 45, 53, 48, 44, 45, 52, 44, 49, 44, 45, 50, 49, 55,
  44, 45, 55, 54, 44, 49, 44, 45, 49, 56, 44, 45, 49, 49, 52, 44,
  49, 44, 45, 53, 49, 44, 45, 52, 44, 49, 44, 45, 50, 49, 56, 44,
  45, 55, 54, 44, 49, 44, 45, 49, 55, 44, 45, 49, 49, 52, 44, 49,
  44, 45, 53, 48, 44, 45, 54, 44, 49, 44, 45, 50, 49, 55, 44, 45,
  55, 55, 44, 49, 44, 45, 49, 54, 44, 45, 49, 49, 51, 44, 49, 44,
  45, 53, 49, 44, 45, 54, 44, 49, 44, 45, 50, 49, 57, 44, 45, 55,
  53, 44, 49, 44, 45, 49, 54, 44, 45, 49, 49, 51, 44, 49, 44, 45,
  53, 49, 44, 45, 55, 44, 49, 44, 45, 50, 49, 57, 44, 45, 55, 53,
  44, 49, 44, 45, 49, 53, 44, 45, 49, 49, 51, 44, 49, 44, 45, 53,
  49, 44, 45, 57, 44, 49, 44, 45, 50, 49, 55, 44, 45, 55, 54, 44,
  49, 44, 45, 49, 53, 44, 45, 49, 49, 49, 44, 49, 44, 45, 53, 49,
  44, 45, 49, 49, 44, 49, 44, 45, 50, 49, 55, 44, 45, 55, 53, 44,
  49, 44, 45, 49, 53, 44, 45, 49, 49, 49, 44, 49, 44, 45, 53, 49,
  44, 45, 49, 50, 44, 49, 44, 45, 50, 49, 56, 44, 45, 55, 52, 44,
  49, 44, 45, 49, 53, 44, 45, 49, 49, 48, 44, 49, 44, 45, 53, 48,
  44, 45, 53, 44, 49, 44, 45, 52, 44, 45, 54, 44, 49, 44, 45, 49,
  55, 48, 44, 45, 54, 44, 49, 44, 45, 52, 49, 44, 45, 55, 51, 44,
  49, 44, 45, 49, 54, 44, 45, 49, 48, 56, 44, 49, 44, 45, 53, 48,
  44, 45, 52, 44, 49, 44, 45, 55, 44, 45, 54, 44, 49, 44, 45, 49,
  54, 56, 44, 45, 57, 44, 49, 44, 45, 52, 48, 44, 45, 55, 51, 44,
  49, 44, 45, 49, 53, 44, 45, 49, 48, 56, 44, 49, 44, 45, 52, 57,
  44, 45, 53, 44, 49, 44, 45, 56, 44, 45, 53, 44, 49, 44, 45, 49,
  54, 55, 44, 45, 49, 50, 44, 49, 44, 45, 52, 48, 44, 45, 55, 49,
  44, 49, 44, 45, 49, 53, 44, 45, 49, 48, 55, 44, 49, 44, 45, 52,
  57, 44, 45, 53, 44, 49, 44, 45, 49, 48, 44, 45, 53, 44, 49, 44,
  45, 49, 54, 54, 44, 45, 49, 51, 44, 49, 44, 45, 52, 48, 44, 45,
  55, 48, 44, 49, 44, 45, 49, 54, 44, 45, 49, 48, 54, 44, 49, 44,
  45, 52, 57, 44, 45, 52, 44, 49, 44, 45, 49, 50, 44, 45, 53, 44,
  49, 44, 45, 49, 54, 53, 44, 45, 49, 52, 44, 49, 44, 45, 52, 49,
  44, 45, 54, 57, 44, 49, 44, 45, 49, 53, 44, 45, 49, 48, 53, 44,
  49, 44, 45, 52, 57, 44, 45, 53, 44, 49, 44, 45, 49, 50, 44, 45,
  54, 44, 49, 44, 45, 49, 54, 52, 44, 45, 49, 54, 44, 49, 44, 45,
  51, 48, 44, 45, 55, 44, 49, 44, 45, 51, 44, 45, 54, 56, 44, 49,
  44, 45, 49, 52, 44, 45, 49, 48, 53, 44, 49, 44, 45, 52, 57, 44,
  45, 53, 44, 49, 44, 45, 49, 52, 44, 45, 54, 44, 49, 44, 45, 49,
  54, 51, 44, 45, 49, 56, 44, 49, 44, 45, 50, 54, 44, 45, 56, 48,
  44, 49, 44, 45, 49, 52, 44, 45, 49, 48, 53, 44, 49, 44, 45, 52,
  56, 44, 45, 54, 44, 49, 44, 45, 49, 53, 44, 45, 53, 44, 49, 44,
  45, 49, 54, 51, 44, 45, 50, 48, 44, 49, 44, 45, 50, 52, 44, 45,
  56, 48, 44, 49, 44, 45, 49, 52, 44, 45, 49, 48, 52, 44, 49, 44,
  45, 52, 57, 44, 45, 53, 44, 49, 44, 45, 49, 55, 44, 45, 54, 44,
  49, 44, 45, 49, 54, 50, 44, 45, 50, 49, 44, 49, 44, 45, 50, 49,
  44, 45, 56, 49, 44, 49, 44, 45, 49, 51, 44, 45, 49, 48, 52, 44,
  49, 44, 45, 53, 48, 44, 45, 52, 44, 49, 44, 45, 49, 56, 44, 45,
  55, 44, 49, 44, 45, 49, 54, 49, 44, 45, 50, 51, 44, 49, 44, 45,
  49, 57, 44, 45, 56, 50, 44, 49, 44, 45, 49, 50, 44, 45, 49, 48,
  52, 44, 49, 44, 45, 52, 57, 44, 45, 53, 44, 49, 44, 45, 49, 57,
  44, 45, 55, 44, 49, 44, 45, 49, 54, 48, 44, 45, 50, 53, 44, 49,
  44, 45, 49, 55, 44, 45, 56, 50, 44, 49, 44, 45, 49, 50, 44, 45,
  49, 48, 52, 44, 49, 44, 45, 52, 56, 44, 45, 53, 44, 49, 44, 45,
  50, 49, 44, 45, 55, 44, 49, 44, 45, 49, 54, 48, 44, 45, 50, 54,
  44, 49, 44, 45, 49, 53, 44, 45, 56, 50, 44, 49, 44, 45, 49, 50,
  44, 45, 49, 48, 52, 44, 49, 44, 45, 52, 55, 44, 45, 54, 44, 49,
  44, 45, 50, 50, 44, 45, 55, 44, 49, 44, 45, 49, 53, 57, 44, 45,
  50, 55, 44, 49, 44, 45, 49, 53, 44, 45, 56, 49, 44, 49, 44, 45,
  49, 50, 44, 45, 49, 48, 52, 44, 49, 44, 45, 52, 55, 44, 45, 53,
  44, 49, 44, 45, 50, 51, 44, 45, 56, 44, 49, 44, 45, 49, 53, 57,
  44, 45, 50, 56, 44, 49, 44, 45, 49, 51, 44, 45, 56, 49, 44, 49,
  44, 45, 49, 50, 44, 45, 49, 48, 53, 44, 49, 44, 45, 52, 53, 44,
  45, 53, 44, 49, 44, 45, 50, 53, 44, 45, 55, 44, 49, 44, 45, 49,
  54, 48, 44, 45, 51, 49, 44, 49, 44, 45, 49, 49, 44, 45, 55, 57,
  44, 49, 44, 45, 49, 51, 44, 45, 49, 48, 52, 44, 49, 44, 45, 52,
  53, 44, 45, 53, 44, 49, 44, 45, 50, 54, 44, 45, 55, 44, 49, 44,
  45, 49, 53, 57, 44, 45, 51, 52, 44, 49, 44, 45, 57, 44, 45, 55,
  57, 44, 49, 44, 45, 49, 52, 44, 45, 49, 48, 51, 44, 49, 44, 45,
  52, 51, 44, 45, 53, 44, 49, 44, 45, 50, 56, 44, 45, 54, 44, 49,
  44, 45, 49, 54, 48, 44, 45, 51, 54, 44, 49, 44, 45, 55, 44, 45,
  55, 56, 44, 49, 44, 45, 49, 56, 44, 45, 57, 57, 44, 49, 44, 45,
  52, 50, 44, 45, 53, 44, 49, 44, 45, 51, 48, 44, 45, 54, 44, 49,
  44, 45, 49, 54, 49, 44, 45, 51, 57, 44, 49, 44, 45, 52, 44, 45,
  55, 54, 44, 49, 44, 45, 50, 49, 44, 45, 57, 55, 44, 49, 44, 45,
  52, 48, 44, 45, 53, 44, 49, 44, 45, 51, 50, 44, 45, 54, 44, 49,
  44, 45, 49, 54, 48, 44, 45, 49, 49, 57, 44, 49, 44, 45, 50, 50,
  44, 45, 57, 54, 44, 49, 44, 45, 51, 57, 44, 45, 54, 44, 49, 44,
  45, 51, 51, 44, 45, 54, 44, 49, 44, 45, 49, 54, 48, 44, 45, 49,
  49, 56, 44, 49, 44, 45, 50, 51, 44, 45, 57, 53, 44, 49, 44, 45,
  51, 57, 44, 45, 53, 44, 49, 44, 45, 51, 52, 44, 45, 55, 44, 49,
  44, 45, 49, 54, 48, 44, 45, 49, 49, 56, 44, 49, 44, 45, 50, 51,
  44, 45, 57, 53, 44, 49, 44, 45, 51, 55, 44, 45, 53, 44, 49, 44,
  45, 51, 54, 44, 45, 54, 44, 49, 44, 45, 49, 54, 49, 44, 45, 49,
  49, 55, 44, 49, 44, 45, 50, 51, 44, 45, 57, 53, 44, 49, 44, 45,
  51, 54, 44, 45, 54, 44, 49, 44, 45, 51, 55, 44, 45, 54, 44, 49,
  44, 45, 49, 54, 49, 44, 45, 49, 49, 54, 44, 49, 44, 45, 50, 52,
  44, 45, 57, 52, 44, 49, 44, 45, 51, 54, 44, 45, 53, 44, 49, 44,
  45, 51, 57, 44, 45, 53, 44, 49, 44, 45, 49, 54, 49, 44, 45, 49,
  49, 54, 44, 49, 44, 45, 50, 53, 44, 45, 57, 50, 44, 49, 44, 45,
  51, 54, 44, 45, 53, 44, 49, 44, 45, 52, 48, 44, 45, 54, 44, 49,
  44, 45, 49, 54, 50, 44, 45, 49, 49, 53, 44, 49, 44, 45, 50, 52,
  44, 45, 57, 50, 44, 49, 44, 45, 51, 54, 44, 45, 53, 44, 49, 44,
  45, 52, 49, 44, 45, 54, 44, 49, 44, 45, 49, 54, 50, 44, 45, 49,
  49, 52, 44, 49, 44, 45, 50, 52, 44, 45, 57, 50, 44, 49, 44, 45,
  51, 53, 44, 45, 53, 44, 49, 44, 45, 52, 50, 44, 45, 55, 44, 49,
  44, 45, 49, 54, 49, 44, 45, 49, 49, 52, 44, 49, 44, 45, 50, 53,
  44, 45, 57, 49, 44, 49, 44, 45, 51, 53, 44, 45, 52, 44, 49, 44,
  45, 52, 52, 44, 45, 54, 44, 49, 44, 45, 49, 54, 51, 44, 45, 49,
  49, 51, 44, 49, 44, 45, 50, 52, 44, 45, 57, 48, 44, 49, 44, 45,
  51, 52, 44, 45, 54, 44, 49, 44, 45, 52, 52, 44, 45, 55, 44, 49,
  44, 45, 49, 54, 51, 44, 45, 49, 49, 50, 44, 49, 44, 45, 50, 52,
  44, 45, 57, 48, 44, 49, 44, 45, 51, 52, 44, 45, 53, 44, 49, 44,
  45, 52, 54, 44, 45, 54, 44, 49, 44, 45, 49, 54, 53, 44, 45, 49,
  49, 48, 44, 49, 44, 45, 50, 52, 44, 45, 56, 57, 44, 49, 44, 45,
  51, 52, 44, 45, 54, 44, 49, 44, 45, 52, 55, 44, 45, 53, 44, 49,
  44, 45, 49, 54, 55, 44, 45, 49, 48, 57, 44, 49, 44, 45, 50, 51,
  44, 45, 56, 57, 44, 49, 44, 45, 51, 51, 44, 45, 54, 44, 49, 44,
  45, 52, 56, 44, 45, 54, 44, 49, 44, 45, 49, 53, 55, 44, 45, 51,
  44, 49, 44, 45, 55, 44, 45, 49, 48, 56, 44, 49, 44, 45, 50, 51,
  44, 45, 56, 56, 44, 49, 44, 45, 51, 52, 44, 45, 53, 44, 49, 44,
  45, 53, 48, 44, 45, 54, 44, 49, 44, 45, 49, 53, 52, 44, 45, 57,
  44, 49, 44, 45, 52, 44, 45, 49, 48, 55, 44, 49, 44, 45, 50, 50,
  44, 45, 56, 57, 44, 49, 44, 45, 51, 51, 44, 45, 54, 44, 49, 44,
  45, 53, 48, 44, 45, 54, 44, 49, 44, 45, 49, 53, 51, 44, 45, 49,
  50, 50, 44, 49, 44, 45, 50, 49, 44, 45, 56, 57, 44, 49, 44, 45,
  51, 50, 44, 45, 54, 44, 49, 44, 45, 53, 50, 44, 45, 54, 44, 49,
  44, 45, 49, 53, 49, 44, 45, 49, 50, 51, 44, 49, 44, 45, 50, 48,
  44, 45, 56, 57, 44, 49, 44, 45, 51, 51, 44, 45, 53, 44, 49, 44,
  45, 53, 51, 44, 45, 54, 44, 49, 44, 45, 49, 53, 49, 44, 45, 49,
  50, 51, 44, 49, 44, 45, 49, 57, 44, 45, 56, 57, 44, 49, 44, 45,
  51, 51, 44, 45, 54, 44, 49, 44, 45, 53, 52, 44, 45, 54, 44, 49,
  44, 45, 49, 53, 48, 44, 45, 49, 50, 52, 44, 49, 44, 45, 49, 55,
  44, 45, 57, 48, 44, 49, 44, 45, 51, 50, 44, 45, 54, 44, 49, 44,
  45, 53, 53, 44, 45, 54, 44, 49, 44, 45, 49, 53, 48, 44, 45, 49,
  50, 52, 44, 49, 44, 45, 49, 55, 44, 45, 56, 57, 44, 49, 44, 45,
  51, 51, 44, 45, 53, 44, 49, 44, 45, 53, 54, 44, 45, 55, 44, 49,
  44, 45, 49, 52, 57, 44, 45, 49, 50, 52, 44, 49, 44, 45, 49, 54,
  44, 45, 56, 57, 44, 49, 44, 45, 51, 51, 44, 45, 53, 44, 49, 44,
  45, 53, 56, 44, 45, 54, 44, 49, 44, 45, 49, 52, 57, 44, 45, 49,
  50, 52, 44, 49, 44, 45, 49, 53, 44, 45, 56, 57, 44, 49, 44, 45,
  51, 51, 44, 45, 54, 44, 49, 44, 45, 53, 56, 44, 45, 54, 44, 49,
  44, 45, 49, 52, 57, 44, 45, 49, 50, 53, 44, 49, 44, 45, 49, 53,
  44, 45, 56, 55, 44, 49, 44, 45, 51, 52, 44, 45, 53, 44, 49, 44,
  45, 54, 48, 44, 45, 54, 44, 49, 44, 45, 49, 52, 57, 44, 45, 49,
  50, 52, 44, 49, 44, 45, 49, 53, 44, 45, 54, 44, 49, 44, 45, 55,
  44, 45, 55, 51, 44, 49, 44, 45, 51, 52, 44, 45, 53, 44, 49, 44,
  45, 54, 49, 44, 45, 54, 44, 49, 44, 45, 49, 53, 48, 44, 45, 49,
  50, 52, 44, 49, 44, 45, 51, 55, 44, 45, 54, 50, 44, 49, 44, 45,
  51, 52, 44, 45, 54, 44, 49, 44, 45, 54, 49, 44, 45, 54, 44, 49,
  44, 45, 49, 53, 49, 44, 45, 49, 50, 51, 44, 49, 44, 45, 51, 55,
  44, 45, 54, 49, 44, 49, 44, 45, 51, 52, 44, 45, 54, 44, 49, 44,
  45, 54, 51, 44, 45, 54, 44, 49, 44, 45, 49, 53, 49, 44, 45, 49,
  50, 51, 44, 49, 44, 45, 51, 55, 44, 45, 53, 56, 44, 49, 44, 45,
  51, 54, 44, 45, 53, 44, 49, 44, 45, 54, 52, 44, 45, 54, 44, 49,
  44, 45, 49, 53, 51, 44, 45, 49, 50, 51, 44, 49, 44, 45, 51, 53,
  44, 45, 53, 55, 44, 49, 44, 45, 51, 54, 44, 45, 54, 44, 49, 44,
  45, 54, 52, 44, 45, 54, 44, 49, 44, 45, 49, 53, 52, 44, 45, 49,
  51, 49, 44, 49, 44, 45, 50, 54, 44, 45, 53, 54, 44, 49, 44, 45,
  51, 54, 44, 45, 54, 44, 49, 44, 45, 54, 53, 44, 45, 55, 44, 49,
  44, 45, 49, 53, 53, 44, 45, 49, 51, 51, 44, 49, 44, 45, 50, 50,
  44, 45, 53, 53, 44, 49, 44, 45, 51, 54, 44, 45, 54, 44, 49, 44,
  45, 54, 55, 44, 45, 54, 44, 49, 44, 45, 49, 53, 54, 44, 45, 49,
  51, 52, 44, 49, 44, 45, 50, 48, 44, 45, 53, 53, 44, 49, 44, 45,
  51, 54, 44, 45, 54, 44, 49, 44, 45, 54, 55, 44, 45, 54, 44, 49,
  44, 45, 49, 53, 56, 44, 45, 49, 51, 54, 44, 49, 44, 45, 49, 53,
  44, 45, 53, 53, 44, 49, 44, 45, 51, 54, 44, 45, 54, 44, 49, 44,
  45, 54, 56, 44, 45, 54, 44, 49, 44, 45, 49, 54, 48, 44, 45, 49,
  51, 55, 44, 49, 44, 45, 49, 50, 44, 45, 53, 53, 44, 49, 44, 45,
  51, 54, 44, 45, 53, 44, 49, 44, 45, 54, 57, 44, 45, 55, 44, 49,
  44, 45, 49, 54, 49, 44, 45, 49, 51, 55, 44, 49, 44, 45, 57, 44,
  45, 53, 53, 44, 49, 44, 45, 51, 54, 44, 45, 54, 44, 49, 44, 45,
  54, 57, 44, 45, 55, 44, 49, 44, 45, 49, 54, 52, 44, 45, 49, 51,
  54, 44, 49, 44, 45, 55, 44, 45, 53, 53, 44, 49, 44, 45, 51, 53,
  44, 45, 54, 44, 49, 44, 45, 55, 49, 44, 45, 54, 44, 49, 44, 45,
  49, 54, 55, 44, 45, 49, 51, 53, 44, 49, 44, 45, 51, 44, 45, 53,
  54, 44, 49, 44, 45, 51, 54, 44, 45, 54, 44, 49, 44, 45, 55, 49,
  44, 45, 54, 44, 49, 44, 45, 49, 54, 57, 44, 45, 49, 57, 50, 44,
  49, 44, 45, 51, 53, 44, 45, 54, 44, 49, 44, 45, 55, 50, 44, 45,
  54, 44, 49, 44, 45, 49, 53, 55, 44, 45, 50, 48, 51, 44, 49, 44,
  45, 51, 53, 44, 45, 54, 44, 49, 44, 45, 55, 51, 44, 45, 54, 44,
  49, 44, 45, 49, 53, 54, 44, 45, 50, 48, 51, 44, 49, 44, 45, 51,
  54, 44, 45, 54, 44, 49, 44, 45, 55, 51, 44, 45, 55, 44, 49, 44,
  45, 49, 53, 52, 44, 45, 49, 57, 48, 44, 49, 44, 45, 54, 44, 45,
  55, 44, 49, 44, 45, 51, 54, 44, 45, 54, 44, 49, 44, 45, 55, 52,
  44, 45, 55, 44, 49, 44, 45, 49, 53, 51, 44, 45, 49, 57, 48, 44,
  49, 44, 45, 52, 57, 44, 45, 54, 44, 49, 44, 45, 55, 53, 44, 45,
  55, 44, 49, 44, 45, 49, 53, 51, 44, 45, 49, 56, 57, 44, 49, 44,
  45, 53, 48, 44, 45, 53, 44, 49, 44, 45, 55, 54, 44, 45, 55, 44,
  49, 44, 45, 49, 53, 51, 44, 45, 49, 56, 56, 44, 49, 44, 45, 53,
  48, 44, 45, 54, 44, 49, 44, 45, 55, 54, 44, 45, 55, 44, 49, 44,
  45, 49, 53, 51, 44, 45, 49, 56, 56, 44, 49, 44, 45, 52, 57, 44,
  45, 54, 44, 49, 44, 45, 55, 55, 44, 45, 55, 44, 49, 44, 45, 49,
  53, 51, 44, 45, 49, 56, 55, 44, 49, 44, 45, 52, 57, 44, 45, 54,
  44, 49, 44, 45, 55, 56, 44, 45, 55, 44, 49, 44, 45, 49, 53, 52,
  44, 45, 49, 56, 54, 44, 49, 44, 45, 52, 57, 44, 45, 53, 44, 49,
  44, 45, 55, 57, 44, 45, 55, 44, 49, 44, 45, 49, 53, 53, 44, 45,
  49, 56, 53, 44, 49, 44, 45, 52, 56, 44, 45, 54, 44, 49, 44, 45,
  55, 57, 44, 45, 55, 44, 49, 44, 45, 49, 53, 54, 44, 45, 49, 56,
  51, 44, 49, 44, 45, 52, 56, 44, 45, 54, 44, 49, 44, 45, 55, 57,
  44, 45, 56, 44, 49, 44, 45, 49, 53, 56, 44, 45, 49, 56, 49, 44,
  49, 44, 45, 52, 56, 44, 45, 54, 44, 49, 44, 45, 55, 57, 44, 45,
  55, 44, 49, 44, 45, 49, 54, 50, 44, 45, 49, 55, 56, 44, 49, 44,
  45, 52, 55, 44, 45, 54, 44, 49, 44, 45, 56, 48, 44, 45, 55, 44,
  49, 44, 45, 49, 54, 52, 44, 45, 49, 55, 54, 44, 49, 44, 45, 52,
  54, 44, 45, 54, 44, 49, 44, 45, 56, 49, 44, 45, 55, 44, 49, 44,
  45, 49, 54, 56, 44, 45, 49, 55, 51, 44, 49, 44, 45, 52, 53, 44,
  45, 54, 44, 49, 44, 45, 56, 49, 44, 45, 55, 44, 49, 44, 45, 49,
  55, 52, 44, 45, 49, 54, 56, 44, 49, 44, 45, 52, 51, 44, 45, 54,
  44, 49, 44, 45, 56, 49, 44, 45, 56, 44, 49, 44, 45, 49, 55, 49,
  44, 45, 49, 55, 54, 44, 49, 44, 45, 51, 55, 44, 45, 55, 44, 49,
  44, 45, 56, 49, 44, 45, 55, 44, 49, 44, 45, 49, 54, 57, 44, 45,
  49, 56, 51, 44, 49, 44, 45, 51, 50, 44, 45, 55, 44, 49, 44, 45,
  56, 50, 44, 45, 55, 44, 49, 44, 45, 49, 54, 56, 44, 45, 49, 56,
  54, 44, 49, 44, 45, 51, 48, 44, 45, 54, 44, 49, 44, 45, 56, 50,
  44, 45, 56, 44, 49, 44, 45, 49, 54, 55, 44, 45, 49, 56, 56, 44,
  49, 44, 45, 50, 56, 44, 45, 55, 44, 49, 44, 45, 56, 50, 44, 45,
  56, 44, 49, 44, 45, 49, 54, 54, 44, 45, 49, 57, 49, 44, 49, 44,
  45, 50, 53, 44, 45, 55, 44, 49, 44, 45, 56, 51, 44, 45, 55, 44,
  49, 44, 45, 49, 54, 55, 44, 45, 49, 57, 51, 44, 49, 44, 45, 50,
  51, 44, 45, 54, 44, 49, 44, 45, 56, 51, 44, 45, 56, 44, 49, 44,
  45, 49, 54, 56, 44, 45, 49, 57, 52, 44, 49, 44, 45, 50, 49, 44,
  45, 53, 44, 49, 44, 45, 56, 52, 44, 45, 56, 44, 49, 44, 45, 49,
  54, 56, 44, 45, 49, 57, 57, 44, 49, 44, 45, 49, 53, 44, 45, 54,
  44, 49, 44, 45, 56, 51, 44, 45, 56, 44, 49, 44, 45, 49, 54, 57,
  44, 45, 50, 48, 50, 44, 49, 44, 45, 49, 49, 44, 45, 54, 44, 49,
  44, 45, 56, 51, 44, 45, 56, 44, 49, 44, 45, 49, 55, 49, 44, 45,
  50, 48, 51, 44, 49, 44, 45, 57, 44, 45, 53, 44, 49, 44, 45, 56,
  52, 44, 45, 56, 44, 49, 44, 45, 49, 55, 50, 44, 45, 50, 48, 51,
  44, 49, 44, 45, 55, 44, 45, 53, 44, 49, 44, 45, 56, 52, 44, 45,
  56, 44, 49, 44, 45, 49, 55, 53, 44, 45, 50, 48, 51, 44, 49, 44,
  45, 52, 44, 45, 53, 44, 49, 44, 45, 56, 52, 44, 45, 57, 44, 49,
  44, 45, 49, 55, 55, 44, 45, 50, 48, 51, 44, 49, 44, 48, 44, 45,
  54, 44, 49, 44, 45, 56, 51, 44, 45, 57, 44, 49, 44, 45, 49, 56,
  54, 44, 45, 50, 48, 49, 44, 49, 44, 45, 56, 51, 44, 45, 57, 44,
  49, 44, 45, 49, 56, 55, 44, 45, 50, 48, 49, 44, 49, 44, 45, 56,
  50, 44, 45, 57, 44, 49, 44, 45, 49, 56, 56, 44, 45, 50, 48, 48,
  44, 49, 44, 45, 56, 51, 44, 45, 56, 44, 49, 44, 45, 49, 56, 56,
  44, 45, 50, 48, 49, 44, 49, 44, 45, 56, 50, 44, 45, 56, 44, 49,
  44, 45, 49, 56, 57, 44, 45, 50, 48, 49, 44, 49, 44, 45, 56, 49,
  44, 45, 56, 44, 49, 44, 45, 49, 56, 57, 44, 45, 50, 48, 50, 44,
  49, 44, 45, 56, 48, 44, 45, 57, 44, 49, 44, 45, 49, 56, 57, 44,
  45, 50, 48, 50, 44, 49, 44, 45, 55, 57, 44, 45, 57, 44, 49, 44,
  45, 49, 57, 48, 44, 45, 50, 48, 50, 44, 49, 44, 45, 55, 56, 44,
  45, 49, 48, 44, 49, 44, 45, 49, 57, 49, 44, 45, 50, 48, 50, 44,
  49, 44, 45, 55, 55, 44, 45, 57, 44, 49, 44, 45, 49, 57, 51, 44,
  45, 50, 48, 49, 44, 49, 44, 45, 55, 54, 44, 45, 57, 44, 49, 44,
  45, 49, 57, 54, 44, 45, 50, 48, 48, 44, 49, 44, 45, 55, 52, 44,
  45, 57, 44, 49, 44, 45, 50, 48, 51, 44, 45, 49, 57, 53, 44, 49,
  44, 45, 55, 50, 44, 45, 49, 48, 44, 49, 44, 45, 50, 48, 53, 44,
  45, 49, 57, 52, 44, 49, 44, 45, 55, 49, 44, 45, 57, 44, 49, 44,
  45, 50, 48, 53, 44, 45, 49, 57, 55, 44, 49, 44, 45, 54, 56, 44,
  45, 57, 44, 49, 44, 45, 50, 48, 53, 44, 45, 49, 57, 57, 44, 49,
  44, 45, 54, 54, 44, 45, 49, 48, 44, 49, 44, 45, 50, 48, 53, 44,
  45, 50, 48, 50, 44, 49, 44, 45, 54, 50, 44, 45, 49, 49, 44, 49,
  44, 45, 50, 48, 53, 44, 45, 50, 50, 53, 44, 49, 44, 45, 51, 56,
  44, 45, 49, 49, 44, 49, 44, 45, 50, 48, 53, 44, 45, 50, 51, 50,
  44, 49, 44, 45, 51, 49, 44, 45, 49, 50, 44, 49, 44, 45, 50, 48,
  54, 44, 45, 50, 51, 52, 44, 49, 44, 45, 50, 55, 44, 45, 49, 51,
  44, 49, 44, 45, 50, 48, 54, 44, 45, 50, 51, 55, 44, 49, 44, 45,
  50, 50, 44, 45, 49, 53, 44, 49, 44, 45, 50, 48, 56, 44, 45, 50,
  51, 56, 44, 49, 44, 45, 49, 55, 44, 45, 49, 56, 44, 49, 44, 45,
  50, 49, 53, 44, 45, 50, 51, 53, 44, 49, 44, 45, 57, 44, 45, 50,
  49, 44, 49, 44, 45, 50, 49, 53, 44, 45, 50, 54, 54, 44, 49, 44,
  45, 50, 49, 52, 44, 45, 50, 54, 55, 44, 49, 44, 45, 51, 55, 44,
  45, 52, 44, 49, 44, 45, 49, 55, 49, 44, 45, 50, 54, 57, 44, 49,
  44, 45, 51, 52, 44, 45, 57, 44, 49, 44, 45, 49, 54, 56, 44, 45,
  50, 55, 55, 44, 49, 44, 45, 50, 53, 44, 45, 49, 49, 44, 49, 44,
  45, 49, 54, 55, 44, 45, 50, 56, 56, 44, 49, 44, 45, 49, 51, 44,
  45, 49, 52, 44, 49, 44, 45, 49, 54, 53, 44, 45, 50, 57, 52, 44,
  49, 44, 45, 53, 44, 45, 49, 55, 44, 49, 44, 45, 49, 54, 54, 44,
  45, 51, 49, 53, 44, 49, 44, 45, 49, 55, 51, 44, 45, 50, 54, 48,
  44, 49, 44, 45, 49, 48, 44, 45, 51, 56, 44, 49, 44, 45, 49, 55,
  51, 44, 45, 50, 53, 56, 44, 49, 44, 45, 49, 56, 44, 45, 51, 50,
  44, 49, 44, 45, 49, 55, 50, 44, 45, 50, 53, 56, 44, 49, 44, 45,
  50, 57, 44, 45, 50, 49, 44, 49, 44, 45, 49, 55, 51, 44, 45, 50,
  53, 55, 44, 49, 44, 45, 51, 48, 44, 45, 50, 48, 44, 49, 44, 45,
  49, 55, 51, 44, 45, 50, 53, 55, 44, 49, 44, 45, 51, 49, 44, 45,
  49, 56, 44, 49, 44, 45, 49, 55, 54, 44, 45, 50, 53, 53, 44, 49,
  44, 45, 51, 50, 44, 45, 49, 53, 44, 49, 44, 45, 49, 56, 53, 44,
  45, 50, 52, 56, 44, 49, 44, 45, 51, 51, 44, 45, 49, 51, 44, 49,
  44, 45, 49, 56, 55, 44, 45, 50, 52, 55, 44, 49, 44, 45, 51, 52,
  44, 45, 49, 48, 44, 49, 44, 45, 49, 56, 57, 44, 45, 50, 52, 54,
  44, 49, 44, 45, 51, 55, 44, 45, 53, 44, 49, 44, 45, 49, 57, 50,
  44, 45, 50, 52, 54, 44, 49, 44, 45, 50, 51, 52, 44, 45, 50, 52,
  54, 44, 49, 44, 45, 50, 51, 53, 44, 45, 50, 52, 52, 44, 49, 44,
  45, 50, 51, 57, 44, 45, 50, 52, 48, 44, 49, 44, 45, 50, 52, 55,
  44, 45, 50, 51, 50, 44, 49, 44, 45, 50, 52, 56, 44, 45, 50, 51,
  48, 44, 49, 44, 45, 50, 53, 48, 44, 45, 50, 50, 57, 44, 49, 44,
  45, 50, 53, 50, 44, 45, 50, 50, 55, 44, 49, 44, 45, 50, 53, 51,
  44, 45, 50, 50, 55, 44, 49, 44, 45, 50, 53, 53, 44, 45, 50, 50,
  52, 44, 49, 44, 45, 50, 54, 51, 44, 45, 50, 49, 55, 44, 49, 44,
  45, 50, 54, 53, 44, 45, 50, 48, 48, 44, 49, 44, 45, 50, 44, 45,
  49, 51, 44, 49, 44, 45, 50, 54, 54, 44, 45, 49, 50, 50, 44, 49,
  44, 45, 52, 44, 45, 57, 44, 49, 44, 45, 50, 49, 44, 45, 51, 57,
  44, 49, 44, 45, 56, 44, 45, 49, 49, 44, 49, 44, 45, 50, 54, 56,
  44, 45, 49, 49, 57, 44, 49, 44, 45, 55, 44, 45, 53, 44, 49, 44,
  45, 50, 55, 44, 45, 51, 50, 44, 49, 44, 45, 49, 49, 44, 45, 49,
  49, 44, 49, 44, 45, 50, 55, 48, 44, 45, 53, 44, 49, 44, 45, 52,
  44, 45, 49, 55, 44, 49, 44, 45, 51, 44, 45, 56, 56, 44, 49, 44,
  45, 56, 44, 45, 51, 44, 49, 44, 45, 52, 48, 44, 45, 49, 54, 44,
  49, 44, 45, 49, 54, 44, 45, 49, 48, 44, 49, 44, 45, 50, 56, 49,
  44, 45, 49, 52, 44, 49, 44, 45, 54, 44, 45, 56, 54, 44, 49, 44,
  45, 56, 44, 45, 50, 44, 49, 44, 45, 55, 51, 44, 45, 49, 48, 44,
  49, 44, 45, 50, 56, 50, 44, 45, 49, 49, 44, 49, 44, 45, 56, 44,
  45, 56, 54, 44, 49, 44, 45, 57, 44, 48, 44, 49, 44, 45, 55, 52,
  44, 45, 49, 48, 44, 49, 44, 45, 50, 56, 51, 44, 45, 56, 44, 49,
  44, 45, 57, 44, 45, 56, 54, 44, 49, 44, 45, 57, 44, 48, 44, 49,
  44, 45, 55, 52, 44, 45, 49, 48, 44, 49, 44, 45, 51, 48, 48, 44,
  45, 56, 55, 44, 49, 44, 45, 56, 44, 45, 50, 44, 49, 44, 45, 55,
  51, 44, 45, 49, 48, 44, 49, 44, 45, 51, 48, 48, 44, 45, 56, 55,
  44, 49, 44, 45, 56, 44, 45, 50, 44, 49, 44, 45, 55, 51, 44, 45,
  49, 48, 44, 49, 44, 45, 51, 48, 48, 44, 45, 56, 55, 44, 49, 44,
  45, 56, 44, 45, 50, 44, 49, 44, 45, 55, 52, 44, 45, 57, 44, 49,
  44, 45, 50, 57, 57, 44, 45, 56, 56, 44, 49, 44, 45, 57, 44, 48,
  44, 49, 44, 45, 55, 52, 44, 45, 57, 44, 49, 44, 45, 50, 57, 56,
  44, 45, 57, 48, 44, 49, 44, 45, 56, 44, 45, 50, 44, 49, 44, 45,
  55, 51, 44, 45, 57, 44, 49, 44, 45, 50, 57, 55, 44, 45, 57, 49,
  44, 49, 44, 45, 56, 44, 45, 50, 44, 49, 44, 45, 55, 51, 44, 45,
  49, 48, 44, 49, 44, 45, 50, 57, 51, 44, 45, 57, 52, 44, 49, 44,
  45, 56, 44, 45, 50, 44, 49, 44, 45, 55, 52, 44, 45, 57, 44, 49,
  44, 45, 50, 57, 49, 44, 45, 57, 54, 44, 49, 44, 45, 56, 44, 45,
  51, 44, 49, 44, 45, 55, 51, 44, 45, 57, 44, 49, 44, 45, 50, 57,
  48, 44, 45, 57, 55, 44, 49, 44, 45, 57, 44, 45, 50, 44, 49, 44,
  45, 55, 51, 44, 45, 57, 44, 49, 44, 45, 50, 56, 57, 44, 45, 57,
  56, 44, 49, 44, 45, 57, 44, 45, 50, 44, 49, 44, 45, 55, 52, 44,
  45, 57, 44, 49, 44, 45, 50, 56, 55, 44, 45, 57, 57, 44, 49, 44,
  45, 57, 44, 45, 51, 44, 49, 44, 45, 55, 51, 44, 45, 57, 44, 49,
  44, 45, 50, 56, 54, 44, 45, 49, 48, 48, 44, 49, 44, 45, 49, 48,
  44, 45, 50, 44, 49, 44, 45, 55, 52, 44, 45, 56, 44, 49, 44, 45,
  50, 56, 53, 44, 45, 49, 48, 49, 44, 49, 44, 45, 49, 48, 44, 45,
  50, 44, 49, 44, 45, 55, 52, 44, 45, 57, 44, 49, 44, 45, 50, 56,
  51, 44, 45, 49, 48, 50, 44, 49, 44, 45, 49, 48, 44, 45, 50, 44,
  49, 44, 45, 55, 52, 44, 45, 57, 44, 49, 44, 45, 50, 56, 50, 44,
  45, 49, 48, 51, 44, 49, 44, 45, 49, 48, 44, 45, 51, 44, 49, 44,
  45, 55, 52, 44, 45, 56, 44, 49, 44, 45, 50, 56, 50, 44, 45, 49,
  48, 51, 44, 49, 44, 45, 49, 49, 44, 45, 50, 44, 49, 44, 45, 55,
  52, 44, 45, 57, 44, 49, 44, 45, 50, 56, 48, 44, 45, 49, 48, 52,
  44, 49, 44, 45, 49, 49, 44, 45, 50, 44, 49, 44, 45, 55, 52, 44,
  45, 57, 44, 49, 44, 45, 50, 55, 57, 44, 45, 49, 48, 53, 44, 49,
  44, 45, 49, 49, 44, 45, 50, 44, 49, 44, 45, 55, 53, 44, 45, 56,
  44, 49, 44, 45, 50, 55, 56, 44, 45, 49, 48, 54, 44, 49, 44, 45,
  49, 49, 44, 45, 51, 44, 49, 44, 45, 55, 52, 44, 45, 57, 44, 49,
  44, 45, 50, 55, 55, 44, 45, 49, 48, 54, 44, 49, 44, 45, 49, 49,
  44, 45, 51, 44, 49, 44, 45, 55, 52, 44, 45, 57, 44, 49, 44, 45,
  50, 55, 54, 44, 45, 49, 48, 55, 44, 49, 44, 45, 49, 50, 44, 45,
  50, 44, 49, 44, 45, 55, 52, 44, 45, 57, 44, 49, 44, 45, 50, 55,
  54, 44, 45, 49, 48, 55, 44, 49, 44, 45, 49, 50, 44, 45, 50, 44,
  49, 44, 45, 55, 52, 44, 45, 57, 44, 49, 44, 45, 50, 55, 54, 44,
  45, 49, 48, 55, 44, 49, 44, 45, 49, 50, 44, 45, 50, 44, 49, 44,
  45, 55, 52, 44, 45, 57, 44, 49, 44, 45, 50, 55, 53, 44, 45, 49,
  48, 56, 44, 49, 44, 45, 49, 50, 44, 45, 51, 44, 49, 44, 45, 55,
  51, 44, 45, 57, 44, 49, 44, 45, 50, 55, 53, 44, 45, 49, 48, 56,
  44, 49, 44, 45, 49, 51, 44, 45, 50, 44, 49, 44, 45, 55, 51, 44,
  45, 57, 44, 49, 44, 45, 50, 55, 53, 44, 45, 49, 48, 55, 44, 49,
  44, 45, 49, 52, 44, 45, 50, 44, 49, 44, 45, 55, 51, 44, 45, 57,
  44, 49, 44, 45, 50, 55, 53, 44, 45, 49, 48, 55, 44, 49, 44, 45,
  49, 52, 44, 45, 50, 44, 49, 44, 45, 55, 51, 44, 45, 57, 44, 49,
  44, 45, 50, 55, 52, 44, 45, 49, 48, 56, 44, 49, 44, 45, 49, 52,
  44, 45, 51, 44, 49, 44, 45, 55, 50, 44, 45, 57, 44, 49, 44, 45,
  50, 55, 52, 44, 45, 49, 48, 56, 44, 49, 44, 45, 49, 53, 44, 45,
  50, 44, 49, 44, 45, 55, 50, 44, 45, 57, 44, 49, 44, 45, 50, 55,
  52, 44, 45, 49, 48, 56, 44, 49, 44, 45, 49, 53, 44, 45, 50, 44,
  49, 44, 45, 55, 49, 44, 45, 49, 48, 44, 49, 44, 45, 50, 55, 51,
  44, 45, 49, 48, 56, 44, 49, 44, 45, 49, 54, 44, 45, 50, 44, 49,
  44, 45, 55, 49, 44, 45, 57, 44, 49, 44, 45, 49, 57, 49, 44, 45,
  55, 44, 49, 44, 45, 55, 54, 44, 45, 49, 48, 56, 44, 49, 44, 45,
  49, 54, 44, 45, 51, 44, 49, 44, 45, 55, 48, 44, 45, 57, 44, 49,
  44, 45, 49, 56, 55, 44, 45, 49, 52, 44, 49, 44, 45, 55, 51, 44,
  45, 49, 48, 56, 44, 49, 44, 45, 49, 55, 44, 45, 50, 44, 49, 44,
  45, 55, 48, 44, 45, 57, 44, 49, 44, 45, 49, 56, 53, 44, 45, 49,
  56, 44, 49, 44, 45, 55, 49, 44, 45, 49, 48, 56, 44, 49, 44, 45,
  49, 55, 44, 45, 50, 44, 49, 44, 45, 54, 57, 44, 45, 49, 48, 44,
  49, 44, 45, 49, 56, 51, 44, 45, 50, 49, 44, 49, 44, 45, 55, 48,
  44, 45, 49, 48, 55, 44, 49, 44, 45, 49, 56, 44, 45, 51, 44, 49,
  44, 45, 54, 56, 44, 45, 57, 44, 49, 44, 45, 49, 56, 50, 44, 45,
  50, 52, 44, 49, 44, 45, 54, 57, 44, 45, 49, 48, 55, 44, 49, 44,
  45, 49, 56, 44, 45, 51, 44, 49, 44, 45, 54, 56, 44, 45, 57, 44,
  49, 44, 45, 49, 55, 57, 44, 45, 50, 56, 44, 49, 44, 45, 54, 56,
  44, 45, 49, 48, 55, 44, 49, 44, 45, 49, 57, 44, 45, 50, 44, 49,
  44, 45, 54, 55, 44, 45, 49, 48, 44, 49, 44, 45, 49, 54, 53, 44,
  45, 52, 50, 44, 49, 44, 45, 54, 56, 44, 45, 49, 48, 55, 44, 49,
  44, 45, 49, 57, 44, 45, 50, 44, 49, 44, 45, 54, 55, 44, 45, 57,
  44, 49, 44, 45, 49, 54, 52, 44, 45, 52, 53, 44, 49, 44, 45, 54,
  55, 44, 45, 49, 48, 54, 44, 49, 44, 45, 50, 48, 44, 45, 51, 44,
  49, 44, 45, 54, 54, 44, 45, 57, 44, 49, 44, 45, 49, 54, 51, 44,
  45, 52, 54, 44, 49, 44, 45, 54, 55, 44, 45, 49, 48, 54, 44, 49,
  44, 45, 50, 48, 44, 45, 51, 44, 49, 44, 45, 54, 53, 44, 45, 49,
  48, 44, 49, 44, 45, 49, 54, 50, 44, 45, 52, 55, 44, 49, 44, 45,
  54, 55, 44, 45, 49, 48, 54, 44, 49, 44, 45, 50, 48, 44, 45, 51,
  44, 49, 44, 45, 54, 53, 44, 45, 57, 44, 49, 44, 45, 49, 54, 50,
  44, 45, 52, 57, 44, 49, 44, 45, 54, 54, 44, 45, 49, 48, 53, 44,
  49, 44, 45, 50, 50, 44, 45, 50, 44, 49, 44, 45, 54, 52, 44, 45,
  49, 48, 44, 49, 44, 45, 49, 54, 49, 44, 45, 53, 48, 44, 49, 44,
  45, 54, 54, 44, 45, 49, 48, 53, 44, 49, 44, 45, 50, 50, 44, 45,
  51, 44, 49, 44, 45, 54, 51, 44, 45, 57, 44, 49, 44, 45, 49, 54,
  50, 44, 45, 53, 48, 44, 49, 44, 45, 54, 54, 44, 45, 49, 48, 52,
  44, 49, 44, 45, 50, 51, 44, 45, 51, 44, 49, 44, 45, 54, 50, 44,
  45, 49, 48, 44, 49, 44, 45, 49, 54, 49, 44, 45, 53, 49, 44, 49,
  44, 45, 54, 54, 44, 45, 49, 48, 51, 44, 49, 44, 45, 50, 53, 44,
  45, 50, 44, 49, 44, 45, 54, 50, 44, 45, 57, 44, 49, 44, 45, 49,
  54, 50, 44, 45, 53, 49, 44, 49, 44, 45, 54, 54, 44, 45, 49, 48,
  51, 44, 49, 44, 45, 50, 53, 44, 45, 50, 44, 49, 44, 45, 54, 49,
  44, 45, 49, 48, 44, 49, 44, 45, 49, 54, 49, 44, 45, 53, 50, 44,
  49, 44, 45, 54, 53, 44, 45, 49, 48, 51, 44, 49, 44, 45, 50, 54,
  44, 45, 51, 44, 49, 44, 45, 54, 48, 44, 45, 57, 44, 49, 44, 45,
  49, 54, 50, 44, 45, 53, 50, 44, 49, 44, 45, 54, 52, 44, 45, 49,
  48, 51, 44, 49, 44, 45, 50, 55, 44, 45, 51, 44, 49, 44, 45, 53,
  57, 44, 45, 57, 44, 49, 44, 45, 49, 54, 51, 44, 45, 53, 51, 44,
  49, 44, 45, 54, 48, 44, 45, 49, 48, 53, 44, 49, 44, 45, 50, 57,
  44, 45, 50, 44, 49, 44, 45, 53, 57, 44, 45, 57, 44, 49, 44, 45,
  49, 54, 51, 44, 45, 53, 51, 44, 49, 44, 45, 53, 54, 44, 45, 49,
  48, 56, 44, 49, 44, 45, 51, 48, 44, 45, 50, 44, 49, 44, 45, 53,
  56, 44, 45, 57, 44, 49, 44, 45, 49, 54, 52, 44, 45, 53, 52, 44,
  49, 44, 45, 53, 51, 44, 45, 49, 49, 48, 44, 49, 44, 45, 51, 48,
  44, 45, 50, 44, 49, 44, 45, 53, 55, 44, 45, 57, 44, 49, 44, 45,
  49, 54, 53, 44, 45, 53, 54, 44, 49, 44, 45, 53, 48, 44, 45, 49,
  48, 57, 44, 49, 44, 45, 51, 50, 44, 45, 51, 44, 49, 44, 45, 53,
  53, 44, 45, 49, 48, 44, 49, 44, 45, 49, 54, 53, 44, 45, 54, 56,
  44, 49, 44, 45, 51, 55, 44, 45, 49, 49, 48, 44, 49, 44, 45, 51,
  50, 44, 45, 51, 44, 49, 44, 45, 53, 52, 44, 45, 49, 48, 44, 49,
  44, 45, 49, 54, 55, 44, 45, 55, 48, 44, 49, 44, 45, 51, 50, 44,
  45, 49, 49, 50, 44, 49, 44, 45, 51, 51, 44, 45, 50, 44, 49, 44,
  45, 53, 52, 44, 45, 57, 44, 49, 44, 45, 49, 54, 56, 44, 45, 55,
  50, 44, 49, 44, 45, 50, 57, 44, 45, 49, 49, 50, 44, 49, 44, 45,
  51, 52, 44, 45, 50, 44, 49, 44, 45, 53, 51, 44, 45, 57, 44, 49,
  44, 45, 49, 55, 49, 44, 45, 53, 44, 49, 44, 45, 53, 44, 45, 54,
  51, 44, 49, 44, 45, 50, 52, 44, 45, 49, 49, 52, 44, 49, 44, 45,
  51, 52, 44, 45, 51, 44, 49, 44, 45, 53, 49, 44, 45, 49, 48, 44,
  49, 44, 45, 49, 56, 52, 44, 45, 54, 50, 44, 49, 44, 45, 50, 48,
  44, 45, 49, 49, 54, 44, 49, 44, 45, 51, 52, 44, 45, 51, 44, 49,
  44, 45, 53, 48, 44, 45, 49, 48, 44, 49, 44, 45, 49, 56, 54, 44,
  45, 54, 50, 44, 49, 44, 45, 49, 56, 44, 45, 49, 49, 55, 44, 49,
  44, 45, 51, 53, 44, 45, 50, 44, 49, 44, 45, 52, 57, 44, 45, 49,
  48, 44, 49, 44, 45, 49, 56, 56, 44, 45, 54, 51, 44, 49, 44, 45,
  49, 53, 44, 45, 49, 49, 57, 44, 49, 44, 45, 51, 52, 44, 45, 50,
  44, 49, 44, 45, 52, 56, 44, 45, 49, 48, 44, 49, 44, 45, 49, 57,
  50, 44, 45, 54, 49, 44, 49, 44, 45, 49, 51, 44, 45, 49, 50, 48,
  44, 49, 44, 45, 51, 52, 44, 45, 51, 44, 49, 44, 45, 52, 54, 44,
  45, 49, 48, 44, 49, 44, 45, 49, 57, 53, 44, 45, 53, 57, 44, 49,
  44, 45, 49, 50, 44, 45, 49, 50, 50, 44, 49, 44, 45, 51, 51, 44,
  45, 51, 44, 49, 44, 45, 52, 53, 44, 45, 49, 48, 44, 49, 44, 45,
  50, 48, 49, 44, 45, 53, 53, 44, 49, 44, 45, 49, 48, 44, 45, 49,
  50, 51, 44, 49, 44, 45, 51, 52, 44, 45, 50, 44, 49, 44, 45, 52,
  52, 44, 45, 49, 48, 44, 49, 44, 45, 50, 48, 54, 44, 45, 53, 50,
  44, 49, 44, 45, 56, 44, 45, 49, 50, 52, 44, 49, 44, 45, 51, 52,
  44, 45, 51, 44, 49, 44, 45, 52, 50, 44, 45, 49, 48, 44, 49, 44,
  45, 50, 48, 56, 44, 45, 53, 50, 44, 49, 44, 45, 55, 44, 45, 49,
  50, 53, 44, 49, 44, 45, 51, 51, 44, 45, 51, 44, 49, 44, 45, 52,
  48, 44, 45, 49, 49, 44, 49, 44, 45, 50, 49, 48, 44, 45, 53, 50,
  44, 49, 44, 45, 53, 44, 45, 49, 50, 55, 44, 49, 44, 45, 51, 50,
  44, 45, 51, 44, 49, 44, 45, 51, 57, 44, 45, 49, 49, 44, 49, 44,
  45, 50, 49, 50, 44, 45, 53, 50, 44, 49, 44, 45, 51, 44, 45, 49,
  50, 56, 44, 49, 44, 45, 51, 51, 44, 45, 50, 44, 49, 44, 45, 51,
  56, 44, 45, 49, 49, 44, 49, 44, 45, 50, 49, 52, 44, 45, 49, 56,
  50, 44, 49, 44, 45, 51, 51, 44, 45, 51, 44, 49, 44, 45, 51, 53,
  44, 45, 49, 50, 44, 49, 44, 45, 50, 49, 54, 44, 45, 49, 56, 50,
  44, 49, 44, 45, 51, 50, 44, 45, 51, 44, 49, 44, 45, 51, 52, 44,
  45, 49, 50, 44, 49, 44, 45, 50, 49, 56, 44, 45, 49, 56, 49, 44,
  49, 44, 45, 51, 50, 44, 45, 51, 44, 49, 44, 45, 51, 51, 44, 45,
  49, 49, 44, 49, 44, 45, 50, 50, 48, 44, 45, 49, 56, 49, 44, 49,
  44, 45, 51, 51, 44, 45, 50, 44, 49, 44, 45, 51, 49, 44, 45, 49,
  50, 44, 49, 44, 45, 50, 50, 50, 44, 45, 49, 56, 48, 44, 49, 44,
  45, 51, 51, 44, 45, 50, 44, 49, 44, 45, 50, 57, 44, 45, 49, 51,
  44, 49, 44, 45, 50, 50, 52, 44, 45, 49, 56, 48, 44, 49, 44, 45,
  51, 50, 44, 45, 51, 44, 49, 44, 45, 50, 55, 44, 45, 49, 50, 44,
  49, 44, 45, 50, 50, 55, 44, 45, 49, 55, 57, 44, 49, 44, 45, 51,
  50, 44, 45, 51, 44, 49, 44, 45, 50, 53, 44, 45, 49, 50, 44, 49,
  44, 45, 50, 50, 57, 44, 45, 49, 55, 57, 44, 49, 44, 45, 51, 51,
  44, 45, 50, 44, 49, 44, 45, 50, 51, 44, 45, 49, 51, 44, 49, 44,
  45, 50, 51, 49, 44, 45, 49, 55, 56, 44, 49, 44, 45, 51, 51, 44,
  45, 50, 44, 49, 44, 45, 50, 50, 44, 45, 49, 51, 44, 49, 44, 45,
  50, 51, 51, 44, 45, 49, 55, 55, 44, 49, 44, 45, 51, 51, 44, 45,
  50, 44, 49, 44, 45, 50, 48, 44, 45, 49, 51, 44, 49, 44, 45, 50,
  51, 54, 44, 45, 49, 55, 55, 44, 49, 44, 45, 51, 50, 44, 45, 51,
  44, 49, 44, 45, 49, 55, 44, 45, 49, 52, 44, 49, 44, 45, 50, 51,
  56, 44, 45, 49, 55, 54, 44, 49, 44, 45, 51, 51, 44, 45, 50, 44,
  49, 44, 45, 49, 53, 44, 45, 49, 52, 44, 49, 44, 45, 50, 52, 49,
  44, 45, 49, 55, 53, 44, 49, 44, 45, 51, 51, 44, 45, 50, 44, 49,
  44, 45, 49, 51, 44, 45, 49, 53, 44, 49, 44, 45, 50, 52, 51, 44,
  45, 49, 55, 52, 44, 49, 44, 45, 51, 51, 44, 45, 50, 44, 49, 44,
  45, 49, 50, 44, 45, 49, 52, 44, 49, 44, 45, 50, 52, 54, 44, 45,
  49, 55, 52, 44, 49, 44, 45, 51, 51, 44, 45, 50, 44, 49, 44, 45,
  57, 44, 45, 49, 51, 44, 49, 44, 45, 50, 53, 48, 44, 45, 49, 55,
  51, 44, 49, 44, 45, 51, 51, 44, 45, 50, 44, 49, 44, 45, 55, 44,
  45, 49, 51, 44, 49, 44, 45, 50, 53, 51, 44, 45, 49, 55, 50, 44,
  49, 44, 45, 51, 51, 44, 45, 51, 44, 49, 44, 45, 52, 44, 45, 49,
  51, 44, 49, 44, 45, 50, 53, 54, 44, 45, 49, 55, 49, 44, 49, 44,
  45, 51, 51, 44, 45, 49, 57, 44, 49, 44, 45, 50, 53, 56, 44, 45,
  49, 55, 48, 44, 49, 44, 45, 51, 51, 44, 45, 49, 55, 44, 49, 44,
  45, 50, 54, 49, 44, 45, 49, 54, 57, 44, 49, 44, 45, 51, 51, 44,
  45, 49, 52, 44, 49, 44, 45, 50, 54, 53, 44, 45, 49, 54, 56, 44,
  49, 44, 45, 51, 51, 44, 45, 49, 48, 44, 49, 44, 45, 50, 55, 49,
  44, 45, 49, 54, 54, 44, 49, 44, 45, 51, 51, 44, 45, 56, 44, 49,
  44, 45, 50, 55, 52, 44, 45, 49, 54, 53, 44, 49, 44, 45, 51, 51,
  44, 45, 54, 44, 49, 44, 45, 50, 55, 54, 44, 45, 49, 54, 53, 44,
  49, 44, 45, 51, 51, 44, 45, 53, 44, 49, 44, 45, 50, 55, 57, 44,
  45, 49, 54, 51, 44, 49, 44, 45, 51, 51, 44, 45, 52, 44, 49, 44,
  45, 50, 56, 49, 44, 45, 49, 48, 49, 44, 49, 44, 45, 53, 44, 45,
  53, 54, 44, 49, 44, 45, 51, 51, 44, 45, 52, 44, 49, 44, 45, 50,
  56, 51, 44, 45, 57, 55, 44, 49, 44, 45, 57, 44, 45, 53, 52, 44,
  49, 44, 45, 51, 51, 44, 45, 51, 44, 49, 44, 45, 50, 56, 53, 44,
  45, 57, 53, 44, 49, 44, 45, 49, 49, 44, 45, 53, 51, 44, 49, 44,
  45, 51, 51, 44, 45, 51, 44, 49, 44, 45, 50, 56, 55, 44, 45, 57,
  49, 44, 49, 44, 45, 49, 52, 44, 45, 53, 51, 44, 49, 44, 45, 51,
  50, 44, 45, 50, 44, 49, 44, 45, 50, 57, 48, 44, 45, 56, 55, 44,
  49, 44, 45, 49, 55, 44, 45, 53, 50, 44, 49, 44, 45, 51, 50, 54,
  44, 45, 56, 51, 44, 49, 44, 45, 50, 48, 44, 45, 53, 49, 44, 49,
  44, 45, 51, 50, 56, 44, 45, 55, 55, 44, 49, 44, 45, 50, 53, 44,
  45, 53, 48, 44, 49, 44, 45, 51, 51, 48, 44, 45, 55, 51, 44, 49,
  44, 45, 50, 56, 44, 45, 52, 57, 44, 49, 44, 45, 51, 51, 52, 44,
  45, 54, 53, 44, 49, 44, 45, 51, 51, 44, 45, 52, 56, 44, 49, 44,
  45, 51, 51, 55, 44, 45, 53, 56, 44, 49, 44, 45, 51, 56, 44, 45,
  52, 55, 44, 49, 44, 45, 51, 51, 57, 44, 45, 52, 55, 44, 49, 44,
  45, 52, 57, 44, 45, 52, 54, 44, 49, 44, 45, 51, 52, 48, 44, 45,
  51, 54, 44, 49, 44, 45, 53, 57, 44, 45, 52, 53, 44, 49, 44, 45,
  51, 52, 49, 44, 45, 50, 51, 44, 49, 44, 45, 55, 50, 44, 45, 52,
  52, 44, 49, 44, 45, 51, 52, 51, 44, 45, 49, 56, 44, 49, 44, 45,
  55, 54, 44, 45, 52, 51, 44, 49, 44, 45, 51, 52, 52, 44, 45, 49,
  52, 44, 49, 44, 45, 56, 48, 44, 45, 52, 51, 44, 49, 44, 45, 51,
  52, 53, 44, 45, 49, 48, 44, 49, 44, 45, 56, 51, 44, 45, 52, 50,
  44, 49, 44, 45, 51, 52, 56, 44, 45, 52, 44, 49, 44, 45, 56, 54,
  44, 45, 52, 50, 44, 49, 44, 45, 52, 51, 53, 44, 45, 52, 53, 44,
  49, 44, 45, 55, 55, 44, 45, 51, 44, 49, 44, 45, 51, 53, 48, 44,
  45, 53, 48, 44, 49, 44, 45, 54, 48, 44, 45, 55, 44, 49, 44, 45,
  55, 44, 45, 57, 44, 49, 44, 45, 51, 52, 53, 44, 45, 53, 50, 44,
  49, 44, 45, 53, 57, 44, 45, 49, 48, 44, 49, 44, 45, 52, 44, 45,
  49, 49, 44, 49, 44, 45, 51, 52, 51, 44, 45, 53, 51, 44, 49, 44,
  45, 53, 56, 44, 45, 49, 50, 44, 49, 44, 48, 44, 45, 49, 52, 44,
  49, 44, 45, 51, 52, 49, 44, 45, 53, 52, 44, 49, 44, 45, 53, 55,
  44, 45, 50, 57, 44, 49, 44, 45, 51, 51, 57, 44, 45, 53, 53, 44,
  49, 44, 45, 53, 55, 44, 45, 50, 57, 44, 49, 44, 45, 51, 51, 55,
  44, 45, 53, 54, 44, 49, 44, 45, 53, 56, 44, 45, 50, 57, 44, 49,
  44, 45, 51, 51, 54, 44, 45, 53, 55, 44, 49, 44, 45, 53, 55, 44,
  45, 51, 49, 44, 49, 44, 45, 51, 51, 52, 44, 45, 53, 56, 44, 49,
  44, 45, 53, 55, 44, 45, 51, 49, 44, 49, 44, 45, 51, 51, 52, 44,
  45, 53, 55, 44, 49, 44, 45, 53, 56, 44, 45, 51, 49, 44, 49, 44,
  45, 51, 51, 50, 44, 45, 53, 57, 44, 49, 44, 45, 53, 56, 44, 45,
  51, 49, 44, 49, 44, 45, 51, 51, 50, 44, 45, 53, 56, 44, 49, 44,
  45, 53, 57, 44, 45, 51, 48, 44, 49, 44, 45, 51, 51, 50, 44, 45,
  53, 56, 44, 49, 44, 45, 54, 49, 44, 45, 50, 57, 44, 49, 44, 45,
  51, 51, 49, 44, 45, 53, 56, 44, 49, 44, 45, 54, 50, 44, 45, 50,
  57, 44, 49, 44, 45, 51, 51, 49, 44, 45, 53, 56, 44, 49, 44, 45,
  54, 50, 44, 45, 50, 57, 44, 49, 44, 45, 51, 51, 48, 44, 45, 53,
  56, 44, 49, 44, 45, 54, 51, 44, 45, 50, 56, 44, 49, 44, 45, 51,
  51, 49, 44, 45, 53, 55, 44, 49, 44, 45, 54, 53, 44, 45, 50, 55,
  44, 49, 44, 45, 51, 51, 48, 44, 45, 53, 55, 44, 49, 44, 45, 54,
  54, 44, 45, 50, 54, 44, 49, 44, 45, 51, 51, 49, 44, 45, 53, 54,
  44, 49, 44, 45, 54, 56, 44, 45, 50, 53, 44, 49, 44, 45, 51, 51,
  48, 44, 45, 53, 53, 44, 49, 44, 45, 55, 48, 44, 45, 50, 52, 44,
  49, 44, 45, 51, 51, 49, 44, 45, 53, 52, 44, 49, 44, 45, 55, 50,
  44, 45, 50, 50, 44, 49, 44, 45, 51, 51, 49, 44, 45, 53, 52, 44,
  49, 44, 45, 55, 52, 44, 45, 50, 48, 44, 49, 44, 45, 51, 51, 49,
  44, 45, 53, 51, 44, 49, 44, 45, 55, 55, 44, 45, 49, 56, 44, 49,
  44, 45, 51, 51, 50, 44, 45, 53, 50, 44, 49, 44, 45, 55, 56, 44,
  45, 49, 56, 44, 49, 44, 45, 51, 51, 49, 44, 45, 53, 50, 44, 49,
  44, 45, 56, 48, 44, 45, 49, 54, 44, 49, 44, 45, 51, 51, 49, 44,
  45, 53, 50, 44, 49, 44, 45, 56, 50, 44, 45, 49, 52, 44, 49, 44,
  45, 51, 51, 49, 44, 45, 53, 49, 44, 49, 44, 45, 56, 53, 44, 45,
  49, 50, 44, 49, 44, 45, 51, 51, 48, 44, 45, 53, 49, 44, 49, 44,
  45, 56, 57, 44, 45, 56, 44, 49, 44, 45, 51, 51, 50, 44, 45, 52,
  57, 44, 49, 44, 45, 57, 50, 44, 45, 54, 44, 49, 44, 45, 51, 51,
  48, 44, 45, 53, 49, 44, 49, 44, 45, 57, 52, 44, 45, 52, 44, 49,
  44, 45, 51, 50, 57, 44, 45, 53, 49, 44, 49, 44, 45, 52, 50, 54,
  44, 45, 53, 50, 44, 49, 44, 45, 52, 50, 55, 44, 45, 53, 50, 44,
  49, 44, 45, 52, 50, 54, 44, 45, 53, 50, 44, 49, 44, 45, 52, 50,
  55, 44, 45, 53, 49, 44, 49, 44, 45, 52, 50, 56, 44, 45, 53, 49,
  44, 49, 44, 45, 52, 50, 56, 44, 45, 52, 57, 44, 49, 44, 45, 52,
  51, 49, 44, 45, 52, 56, 44, 49, 44, 45, 52, 51, 49, 44, 45, 52,
  55, 44, 49, 44, 45, 52, 51, 51, 44, 45, 52, 53, 44, 49, 44, 45,
  52, 51, 53, 44, 45, 52, 51, 44, 49, 44, 45, 52, 51, 55, 44, 45,
  52, 49, 44, 49, 44, 45, 52, 51, 57, 44, 45, 51, 57, 44, 49, 44,
  45, 52, 52, 49, 44, 45, 51, 55, 44, 49, 44, 45, 52, 52, 51, 44,
  45, 51, 53, 44, 49, 44, 45, 52, 52, 53, 44, 45, 51, 51, 44, 49,
  44, 45, 52, 52, 55, 44, 45, 51, 51, 44, 49, 44, 45, 52, 52, 56,
  44, 45, 51, 49, 44, 49, 44, 45, 52, 52, 57, 44, 45, 51, 49, 44,
  49, 44, 45, 52, 53, 48, 44, 45, 51, 49, 44, 49, 44, 45, 52, 52,
  57, 44, 45, 51, 49, 44, 49, 44, 45, 52, 53, 48, 44, 45, 51, 48,
  44, 49, 44, 45, 52, 53, 49, 44, 45, 50, 57, 44, 49, 44, 45, 52,
  53, 50, 44, 45, 50, 56, 44, 49, 44, 45, 52, 53, 51, 44, 45, 50,
  55, 44, 49, 44, 45, 52, 53, 52, 44, 45, 50, 54, 44, 49, 44, 45,
  52, 53, 54, 44, 45, 50, 52, 44, 49, 44, 45, 52, 53, 55, 44, 45,
  50, 51, 44, 49, 44, 45, 52, 53, 55, 44, 45, 50, 51, 44, 49, 44,
  45, 52, 53, 56, 44, 45, 50, 50, 44, 49, 44, 45, 52, 53, 56, 44,
  45, 50, 50, 44, 49, 44, 45, 52, 53, 56, 44, 45, 50, 51, 44, 49,
  44, 45, 52, 53, 55, 44, 45, 50, 51, 44, 49, 44, 45, 52, 53, 56,
  44, 45, 50, 50, 44, 49, 44, 45, 52, 53, 56, 44, 45, 50, 51, 44,
  49, 44, 45, 52, 53, 55, 44, 45, 50, 52, 44, 49, 44, 45, 52, 53,
  54, 44, 45, 50, 52, 44, 49, 44, 45, 52, 53, 54, 44, 45, 50, 53,
  44, 49, 44, 45, 52, 53, 54, 44, 45, 50, 52, 44, 49, 44, 45, 52,
  53, 54, 44, 45, 50, 53, 44, 49, 44, 45, 52, 53, 55, 44, 45, 50,
  51, 44, 49, 44, 45, 52, 53, 55, 44, 45, 50, 51, 44, 49, 44, 45,
  52, 53, 57, 44, 45, 50, 48, 44, 49, 44, 45, 52, 54, 51, 44, 45,
  49, 55, 44, 49, 44, 45, 52, 54, 55, 44, 45, 49, 48, 44, 49, 44,
  45, 53, 48, 53, 56, 44, 48, 41, 10, 45, 117, 110, 99, 111, 109, 112,
  114, 101, 115, 115, 95, 114, 108, 101, 32, 45, 114, 32, 36, 49, 44, 36,
  49, 44, 49, 44, 49, 44, 53, 32, 45, 105, 102, 32, 123, 36, 49, 62,
  52, 56, 48, 125, 32, 45, 98, 91, 45, 49, 93, 32, 48, 46, 50, 37,
  32, 45, 101, 110, 100, 105, 102, 32, 45, 103, 101, 32, 52, 48, 37, 10,
  45, 110, 109, 32, 34, 91, 67, 117, 112, 105, 100, 32, 98, 105, 110, 97,
  114, 121, 32, 109, 97, 115, 107, 93, 34, 10, 45, 101, 110, 100, 108, 32,
  45, 118, 32, 43, 10, 100, 48, 32, 58, 10, 45, 95, 100, 105, 115, 112,
  108, 97, 121, 48, 10, 100, 105, 115, 112, 108, 97, 121, 48, 32, 58, 10,
  45, 95, 36, 48, 10, 95, 100, 105, 115, 112, 108, 97, 121, 48, 32, 58,
  10, 45, 118, 32, 45, 10, 119, 61, 48, 32, 104, 61, 48, 32, 100, 61,
  48, 32, 115, 61, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 119, 61, 123, 36, 119, 43, 119, 125,
  32, 104, 61, 123, 109, 97, 120, 40, 36, 104, 44, 104, 41, 125, 32, 100,
  61, 123, 109, 97, 120, 40, 36, 100, 44, 100, 41, 125, 32, 115, 61, 123,
  109, 97, 120, 40, 36, 115, 44, 115, 41, 125, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 64, 35, 61, 61,
  49, 125, 32, 45, 119, 32, 45, 49, 44, 45, 49, 44, 48, 44, 48, 44,
  45, 49, 44, 45, 49, 44, 64, 123, 48, 44, 110, 125, 92, 32, 40, 36,
  119, 120, 36, 104, 120, 36, 100, 120, 36, 115, 41, 10, 45, 101, 108, 105,
  102, 32, 123, 64, 35, 61, 61, 50, 125, 32, 45, 119, 32, 45, 49, 44,
  45, 49, 44, 48, 44, 48, 44, 45, 49, 44, 45, 49, 44, 64, 123, 48,
  44, 110, 125, 44, 64, 123, 45, 49, 44, 110, 125, 92, 32, 40, 36, 119,
  120, 36, 104, 120, 36, 100, 120, 36, 115, 41, 10, 45, 101, 108, 115, 101,
  32, 45, 119, 32, 45, 49, 44, 45, 49, 44, 48, 44, 48, 44, 45, 49,
  44, 45, 49, 44, 64, 123, 48, 44, 110, 125, 44, 46, 46, 44, 64, 123,
  45, 49, 44, 110, 125, 92, 32, 40, 36, 119, 120, 36, 104, 120, 36, 100,
  120, 36, 115, 41, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43,
  32, 45, 100, 10, 45, 118, 32, 45, 32, 45, 119, 91, 93, 32, 48, 32,
  45, 118, 32, 43, 10, 100, 97, 32, 58, 10, 45, 118, 32, 45, 32, 95,
  95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 100,
  105, 115, 112, 108, 97, 121, 95, 97, 114, 114, 97, 121, 32, 36, 42, 10,
  100, 105, 115, 112, 108, 97, 121, 95, 97, 114, 114, 97, 121, 32, 58, 10,
  45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118,
  32, 43, 10, 45, 95, 36, 48, 32, 36, 42, 10, 95, 100, 105, 115, 112,
  108, 97, 121, 95, 97, 114, 114, 97, 121, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 36, 123, 49, 61, 49, 51, 125, 62, 48, 34, 32, 38, 38,
  32, 34, 36, 123, 50, 61, 36, 49, 125, 62, 48, 10, 45, 101, 91, 48,
  45, 45, 51, 93, 32, 34, 68, 105, 115, 112, 108, 97, 121, 32, 36, 49,
  120, 36, 50, 32, 97, 114, 114, 97, 121, 32, 111, 102, 32, 112, 105, 120,
  101, 108, 32, 118, 97, 108, 117, 101, 115, 32, 102, 111, 114, 32, 105, 109,
  97, 103, 101, 34, 36, 95, 95, 115, 34, 46, 34, 10, 45, 118, 32, 45,
  10, 100, 120, 98, 61, 123, 114, 111, 117, 110, 100, 40, 36, 49, 47, 50,
  44, 49, 44, 49, 41, 125, 32, 100, 120, 102, 61, 123, 36, 49, 45, 49,
  45, 36, 100, 120, 98, 125, 10, 100, 121, 98, 61, 123, 114, 111, 117, 110,
  100, 40, 36, 50, 47, 50, 44, 49, 44, 49, 41, 125, 32, 100, 121, 102,
  61, 123, 36, 50, 45, 49, 45, 36, 100, 121, 98, 125, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45,
  105, 102, 32, 123, 119, 60, 49, 50, 56, 34, 32, 38, 38, 32, 34, 104,
  60, 49, 50, 56, 125, 32, 45, 114, 32, 49, 50, 56, 44, 49, 50, 56,
  44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48, 44, 48, 44, 48,
  46, 53, 44, 48, 46, 53, 32, 45, 101, 110, 100, 105, 102, 10, 120, 48,
  61, 48, 32, 121, 48, 61, 48, 32, 119, 61, 123, 119, 125, 32, 104, 61,
  123, 104, 125, 10, 119, 109, 97, 120, 61, 123, 48, 46, 57, 42, 64, 123,
  33, 44, 117, 125, 125, 32, 104, 109, 97, 120, 61, 123, 48, 46, 57, 42,
  64, 123, 33, 44, 118, 125, 125, 10, 45, 100, 111, 10, 45, 105, 102, 32,
  123, 119, 62, 61, 36, 119, 109, 97, 120, 124, 124, 104, 62, 61, 36, 104,
  109, 97, 120, 125, 10, 110, 61, 64, 123, 45, 49, 44, 110, 125, 32, 45,
  110, 109, 91, 45, 49, 93, 32, 34, 73, 109, 97, 103, 101, 32, 34, 39,
  64, 123, 45, 49, 44, 98, 125, 46, 64, 123, 45, 49, 44, 120, 125, 39,
  34, 32, 105, 115, 32, 116, 111, 111, 32, 108, 97, 114, 103, 101, 44, 32,
  112, 108, 101, 97, 115, 101, 32, 115, 101, 108, 101, 99, 116, 32, 97, 32,
  115, 117, 98, 45, 105, 109, 97, 103, 101, 46, 34, 10, 45, 45, 115, 101,
  108, 101, 99, 116, 91, 45, 49, 93, 32, 50, 32, 120, 48, 61, 123, 105,
  91, 48, 93, 125, 32, 121, 48, 61, 123, 105, 91, 49, 93, 125, 32, 119,
  61, 123, 49, 43, 105, 91, 51, 93, 45, 105, 91, 48, 93, 125, 32, 104,
  61, 123, 49, 43, 105, 91, 52, 93, 45, 105, 91, 49, 93, 125, 10, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 110, 109, 91, 45, 49, 93, 32, 36,
  110, 10, 45, 101, 110, 100, 105, 102, 10, 45, 45, 122, 91, 45, 49, 93,
  32, 36, 120, 48, 44, 36, 121, 48, 44, 48, 44, 123, 36, 120, 48, 43,
  36, 119, 45, 49, 125, 44, 123, 36, 121, 48, 43, 36, 104, 45, 49, 125,
  44, 48, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 49, 32,
  45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 119, 104,
  105, 108, 101, 32, 123, 119, 62, 61, 36, 119, 109, 97, 120, 124, 124, 104,
  62, 61, 36, 104, 109, 97, 120, 125, 10, 120, 49, 61, 45, 49, 32, 121,
  49, 61, 45, 49, 32, 99, 49, 61, 48, 32, 111, 120, 49, 61, 45, 49,
  32, 111, 121, 49, 61, 45, 49, 32, 111, 99, 49, 61, 45, 49, 10, 120,
  50, 61, 45, 49, 32, 121, 50, 61, 45, 49, 32, 99, 50, 61, 48, 32,
  111, 120, 50, 61, 45, 49, 32, 111, 121, 50, 61, 45, 49, 32, 111, 99,
  50, 61, 45, 49, 10, 120, 51, 61, 45, 49, 32, 121, 51, 61, 45, 49,
  32, 99, 51, 61, 48, 32, 111, 120, 51, 61, 45, 49, 32, 111, 121, 51,
  61, 45, 49, 32, 111, 99, 51, 61, 45, 49, 10, 99, 48, 61, 48, 32,
  111, 120, 109, 61, 45, 49, 32, 111, 121, 109, 61, 45, 49, 10, 45, 119,
  91, 45, 49, 93, 32, 45, 49, 44, 45, 49, 44, 48, 44, 48, 44, 45,
  49, 44, 45, 49, 44, 64, 123, 45, 50, 44, 98, 125, 46, 64, 123, 45,
  50, 44, 120, 125, 10, 45, 100, 111, 10, 45, 119, 97, 105, 116, 91, 48,
  45, 51, 93, 10, 111, 99, 48, 61, 36, 99, 48, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 52, 10, 45, 105, 102, 32, 123, 36, 62, 34, 32, 38,
  38, 32, 34, 33, 64, 123, 33, 36, 62, 125, 34, 32, 38, 38, 32, 34,
  36, 123, 120, 36, 62, 125, 62, 61, 48, 125, 32, 45, 119, 36, 62, 32,
  48, 32, 120, 36, 62, 61, 45, 49, 32, 121, 36, 62, 61, 45, 49, 32,
  99, 36, 62, 61, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 64, 123, 33, 36, 62, 44, 111, 125, 32, 99, 36, 62, 61, 123, 40,
  36, 123, 99, 36, 62, 125, 43, 115, 105, 103, 110, 40, 64, 123, 33, 36,
  62, 44, 111, 125, 41, 41, 37, 115, 125, 32, 45, 119, 97, 105, 116, 91,
  36, 62, 93, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 64, 123, 33, 36, 62, 44, 83, 80, 65, 67, 69, 125, 34,
  32, 124, 124, 32, 34, 64, 123, 33, 36, 62, 44, 69, 78, 84, 69, 82,
  125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 36, 62, 44, 65, 82, 82,
  79, 87, 82, 73, 71, 72, 84, 125, 34, 32, 124, 124, 32, 34, 64, 123,
  33, 36, 62, 44, 65, 82, 82, 79, 87, 68, 79, 87, 78, 125, 125, 32,
  99, 36, 62, 61, 123, 40, 36, 123, 99, 36, 62, 125, 43, 49, 41, 37,
  115, 125, 32, 45, 119, 97, 105, 116, 91, 36, 62, 93, 32, 45, 49, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64, 123, 33, 36,
  62, 44, 66, 65, 67, 75, 83, 80, 65, 67, 69, 125, 34, 32, 124, 124,
  32, 34, 64, 123, 33, 36, 62, 44, 65, 82, 82, 79, 87, 76, 69, 70,
  84, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 36, 62, 44, 65, 82,
  82, 79, 87, 85, 80, 125, 125, 32, 99, 36, 62, 61, 123, 40, 36, 123,
  99, 36, 62, 125, 45, 49, 41, 37, 115, 125, 32, 45, 119, 97, 105, 116,
  91, 36, 62, 93, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 111, 99, 48, 33, 61,
  36, 99, 48, 125, 32, 99, 49, 61, 36, 99, 48, 32, 99, 50, 61, 36,
  99, 48, 32, 99, 51, 61, 36, 99, 48, 32, 45, 101, 110, 100, 105, 102,
  10, 120, 109, 61, 64, 123, 33, 44, 120, 125, 32, 121, 109, 61, 64, 123,
  33, 44, 121, 125, 10, 45, 105, 102, 32, 123, 36, 120, 109, 62, 61, 48,
  34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 98, 125, 38, 49, 125, 32,
  120, 49, 61, 36, 120, 109, 32, 121, 49, 61, 36, 121, 109, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 120, 109, 62, 61, 48,
  34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 98, 125, 38, 50, 125, 32,
  120, 50, 61, 36, 120, 109, 32, 121, 50, 61, 36, 121, 109, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 120, 109, 62, 61, 48,
  34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 98, 125, 38, 52, 125, 32,
  120, 51, 61, 36, 120, 109, 32, 121, 51, 61, 36, 121, 109, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 120, 109, 62, 61, 48,
  34, 32, 38, 38, 32, 34, 40, 36, 111, 120, 109, 33, 61, 36, 120, 109,
  34, 32, 124, 124, 32, 34, 36, 111, 121, 109, 33, 61, 36, 121, 109, 41,
  125, 32, 45, 119, 91, 93, 32, 45, 49, 44, 45, 49, 44, 45, 49, 44,
  45, 49, 44, 45, 49, 44, 45, 49, 44, 64, 123, 45, 50, 44, 98, 125,
  46, 64, 123, 45, 50, 44, 120, 125, 34, 32, 45, 32, 40, 34, 36, 120,
  109, 44, 36, 121, 109, 34, 41, 34, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 120, 49, 33, 61, 36, 111, 120, 49, 34, 32,
  124, 124, 32, 34, 36, 121, 49, 33, 61, 36, 111, 121, 49, 34, 32, 124,
  124, 32, 34, 36, 120, 50, 33, 61, 36, 111, 120, 50, 34, 32, 124, 124,
  32, 34, 36, 121, 50, 33, 61, 36, 111, 121, 50, 34, 32, 124, 124, 32,
  34, 36, 120, 51, 33, 61, 36, 111, 120, 51, 34, 32, 124, 124, 32, 34,
  36, 121, 51, 33, 61, 36, 111, 121, 51, 125, 10, 91, 45, 49, 93, 10,
  45, 105, 102, 32, 123, 36, 120, 49, 62, 61, 48, 125, 10, 120, 98, 61,
  123, 36, 120, 49, 45, 36, 100, 120, 98, 125, 32, 121, 98, 61, 123, 36,
  121, 49, 45, 36, 100, 121, 98, 125, 32, 120, 101, 61, 123, 36, 120, 49,
  43, 36, 100, 120, 102, 125, 32, 121, 101, 61, 123, 36, 121, 49, 43, 36,
  100, 121, 102, 125, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91,
  45, 49, 93, 32, 36, 120, 98, 44, 36, 121, 98, 44, 36, 120, 101, 44,
  36, 121, 101, 44, 48, 46, 50, 44, 48, 44, 50, 53, 53, 44, 50, 53,
  53, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93,
  32, 36, 120, 98, 44, 36, 121, 98, 44, 36, 120, 101, 44, 36, 121, 101,
  44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 44,
  50, 53, 53, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 120, 50, 62, 61, 48, 125, 10, 120, 98, 61, 123,
  36, 120, 50, 45, 36, 100, 120, 98, 125, 32, 121, 98, 61, 123, 36, 121,
  50, 45, 36, 100, 121, 98, 125, 32, 120, 101, 61, 123, 36, 120, 50, 43,
  36, 100, 120, 102, 125, 32, 121, 101, 61, 123, 36, 121, 50, 43, 36, 100,
  121, 102, 125, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45,
  49, 93, 32, 36, 120, 98, 44, 36, 121, 98, 44, 36, 120, 101, 44, 36,
  121, 101, 44, 48, 46, 50, 44, 50, 53, 53, 44, 51, 50, 44, 50, 53,
  53, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93,
  32, 36, 120, 98, 44, 36, 121, 98, 44, 36, 120, 101, 44, 36, 121, 101,
  44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 50, 53,
  53, 44, 51, 50, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 120, 51, 62, 61, 48, 125, 10, 120, 98, 61,
  123, 36, 120, 51, 45, 36, 100, 120, 98, 125, 32, 121, 98, 61, 123, 36,
  121, 51, 45, 36, 100, 121, 98, 125, 32, 120, 101, 61, 123, 36, 120, 51,
  43, 36, 100, 120, 102, 125, 32, 121, 101, 61, 123, 36, 121, 51, 43, 36,
  100, 121, 102, 125, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91,
  45, 49, 93, 32, 36, 120, 98, 44, 36, 121, 98, 44, 36, 120, 101, 44,
  36, 121, 101, 44, 48, 46, 50, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  48, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93,
  32, 36, 120, 98, 44, 36, 121, 98, 44, 36, 120, 101, 44, 36, 121, 101,
  44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  119, 91, 45, 49, 93, 32, 64, 123, 45, 50, 44, 119, 125, 44, 64, 123,
  45, 50, 44, 104, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 111, 120,
  109, 61, 36, 120, 109, 32, 111, 121, 109, 61, 36, 121, 109, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 120, 49, 62, 61, 48,
  34, 32, 38, 38, 32, 34, 40, 36, 111, 120, 49, 33, 61, 36, 120, 49,
  34, 32, 124, 124, 32, 34, 36, 111, 121, 49, 33, 61, 36, 121, 49, 34,
  32, 124, 124, 32, 34, 36, 111, 99, 49, 33, 61, 36, 99, 49, 41, 125,
  10, 45, 45, 122, 91, 45, 50, 93, 32, 123, 36, 120, 49, 45, 36, 100,
  120, 98, 125, 44, 123, 36, 121, 49, 45, 36, 100, 121, 98, 125, 44, 48,
  44, 36, 99, 49, 44, 123, 36, 120, 49, 43, 36, 100, 120, 102, 125, 44,
  123, 36, 121, 49, 43, 36, 100, 121, 102, 125, 44, 48, 44, 36, 99, 49,
  10, 45, 45, 122, 91, 45, 50, 93, 32, 123, 36, 120, 49, 45, 36, 100,
  120, 98, 125, 44, 123, 36, 121, 49, 45, 36, 100, 121, 98, 125, 44, 48,
  44, 123, 36, 120, 49, 43, 36, 100, 120, 102, 125, 44, 123, 36, 121, 49,
  43, 36, 100, 121, 102, 125, 44, 48, 10, 45, 95, 95, 100, 105, 115, 112,
  108, 97, 121, 95, 97, 114, 114, 97, 121, 91, 45, 50, 44, 45, 49, 93,
  32, 36, 49, 44, 36, 50, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53,
  10, 45, 119, 49, 91, 45, 49, 93, 32, 123, 119, 125, 44, 123, 104, 125,
  44, 48, 44, 48, 44, 45, 49, 44, 45, 49, 44, 64, 123, 45, 51, 44,
  98, 125, 34, 32, 45, 32, 40, 34, 36, 120, 49, 44, 36, 121, 49, 44,
  99, 61, 36, 99, 49, 34, 41, 34, 10, 45, 114, 109, 91, 45, 49, 93,
  32, 111, 120, 49, 61, 36, 120, 49, 32, 111, 121, 49, 61, 36, 121, 49,
  32, 111, 99, 49, 61, 36, 99, 49, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 120, 50, 62, 61, 48, 34, 32, 38, 38, 32,
  34, 40, 36, 111, 120, 50, 33, 61, 36, 120, 50, 34, 32, 124, 124, 32,
  34, 36, 111, 121, 50, 33, 61, 36, 121, 50, 34, 32, 124, 124, 32, 34,
  36, 111, 99, 50, 33, 61, 36, 99, 50, 41, 125, 10, 45, 45, 122, 91,
  45, 50, 93, 32, 123, 36, 120, 50, 45, 36, 100, 120, 98, 125, 44, 123,
  36, 121, 50, 45, 36, 100, 121, 98, 125, 44, 48, 44, 36, 99, 50, 44,
  123, 36, 120, 50, 43, 36, 100, 120, 102, 125, 44, 123, 36, 121, 50, 43,
  36, 100, 121, 102, 125, 44, 48, 44, 36, 99, 50, 10, 45, 45, 122, 91,
  45, 50, 93, 32, 123, 36, 120, 50, 45, 36, 100, 120, 98, 125, 44, 123,
  36, 121, 50, 45, 36, 100, 121, 98, 125, 44, 48, 44, 123, 36, 120, 50,
  43, 36, 100, 120, 102, 125, 44, 123, 36, 121, 50, 43, 36, 100, 121, 102,
  125, 44, 48, 10, 45, 95, 95, 100, 105, 115, 112, 108, 97, 121, 95, 97,
  114, 114, 97, 121, 91, 45, 50, 44, 45, 49, 93, 32, 36, 49, 44, 36,
  50, 44, 50, 53, 53, 44, 51, 50, 44, 50, 53, 53, 10, 45, 119, 50,
  91, 45, 49, 93, 32, 123, 119, 125, 44, 123, 104, 125, 44, 48, 44, 48,
  44, 45, 49, 44, 45, 49, 44, 64, 123, 45, 51, 44, 98, 125, 34, 32,
  45, 32, 40, 34, 36, 120, 50, 44, 36, 121, 50, 44, 99, 61, 36, 99,
  50, 34, 41, 34, 10, 45, 114, 109, 91, 45, 49, 93, 32, 111, 120, 50,
  61, 36, 120, 50, 32, 111, 121, 50, 61, 36, 121, 50, 32, 111, 99, 50,
  61, 36, 99, 50, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 120, 51, 62, 61, 48, 34, 32, 38, 38, 32, 34, 40, 36, 111,
  120, 51, 33, 61, 36, 120, 51, 34, 32, 124, 124, 32, 34, 36, 111, 121,
  51, 33, 61, 36, 121, 51, 34, 32, 124, 124, 32, 34, 36, 111, 99, 51,
  33, 61, 36, 99, 51, 41, 125, 10, 45, 45, 122, 91, 45, 50, 93, 32,
  123, 36, 120, 51, 45, 36, 100, 120, 98, 125, 44, 123, 36, 121, 51, 45,
  36, 100, 121, 98, 125, 44, 48, 44, 36, 99, 51, 44, 123, 36, 120, 51,
  43, 36, 100, 120, 102, 125, 44, 123, 36, 121, 51, 43, 36, 100, 121, 102,
  125, 44, 48, 44, 36, 99, 51, 10, 45, 45, 122, 91, 45, 50, 93, 32,
  123, 36, 120, 51, 45, 36, 100, 120, 98, 125, 44, 123, 36, 121, 51, 45,
  36, 100, 121, 98, 125, 44, 48, 44, 123, 36, 120, 51, 43, 36, 100, 120,
  102, 125, 44, 123, 36, 121, 51, 43, 36, 100, 121, 102, 125, 44, 48, 10,
  45, 95, 95, 100, 105, 115, 112, 108, 97, 121, 95, 97, 114, 114, 97, 121,
  91, 45, 50, 44, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 48, 10, 45, 119, 51, 91, 45, 49, 93, 32,
  123, 119, 125, 44, 123, 104, 125, 44, 48, 44, 48, 44, 45, 49, 44, 45,
  49, 44, 64, 123, 45, 51, 44, 98, 125, 34, 32, 45, 32, 40, 34, 36,
  120, 51, 44, 36, 121, 51, 44, 99, 61, 36, 99, 51, 34, 41, 34, 10,
  45, 114, 109, 91, 45, 49, 93, 32, 111, 120, 51, 61, 36, 120, 51, 32,
  111, 121, 51, 61, 36, 121, 51, 32, 111, 99, 51, 61, 36, 99, 51, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64,
  33, 34, 32, 38, 38, 32, 34, 92, 10, 33, 64, 123, 33, 44, 69, 83,
  67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 34,
  32, 38, 38, 32, 34, 92, 10, 33, 64, 123, 33, 49, 44, 69, 83, 67,
  125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 49, 44, 81, 125, 34,
  32, 38, 38, 32, 34, 92, 10, 33, 64, 123, 33, 50, 44, 69, 83, 67,
  125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 50, 44, 81, 125, 34,
  32, 38, 38, 32, 34, 92, 10, 33, 64, 123, 33, 51, 44, 69, 83, 67,
  125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 51, 44, 81, 125, 125,
  10, 45, 107, 91, 48, 93, 32, 45, 119, 32, 48, 32, 45, 119, 49, 32,
  48, 32, 45, 119, 50, 32, 48, 32, 45, 119, 51, 32, 48, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 95,
  95, 100, 105, 115, 112, 108, 97, 121, 95, 97, 114, 114, 97, 121, 32, 58,
  10, 45, 114, 111, 117, 110, 100, 91, 45, 50, 93, 32, 49, 32, 45, 99,
  91, 45, 50, 93, 32, 48, 44, 57, 57, 57, 32, 45, 114, 91, 45, 49,
  93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 51, 44,
  123, 105, 102, 40, 115, 61, 61, 49, 44, 49, 44, 48, 41, 125, 10, 45,
  45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 45, 49, 93, 32, 45,
  114, 91, 45, 50, 93, 32, 123, 36, 49, 42, 50, 52, 125, 44, 123, 36,
  50, 42, 50, 52, 125, 32, 45, 103, 114, 105, 100, 91, 45, 50, 93, 32,
  123, 49, 48, 48, 47, 36, 49, 125, 37, 44, 123, 49, 48, 48, 47, 36,
  50, 125, 37, 44, 48, 44, 48, 44, 49, 44, 48, 10, 120, 98, 61, 123,
  50, 52, 42, 105, 110, 116, 40, 36, 49, 47, 50, 41, 125, 32, 121, 98,
  61, 123, 50, 52, 42, 105, 110, 116, 40, 36, 50, 47, 50, 41, 125, 32,
  120, 101, 61, 123, 36, 120, 98, 43, 50, 52, 125, 32, 121, 101, 61, 123,
  36, 121, 98, 43, 50, 52, 125, 10, 45, 114, 101, 99, 116, 97, 110, 103,
  108, 101, 91, 45, 50, 93, 32, 36, 120, 98, 44, 36, 121, 98, 44, 36,
  120, 101, 44, 36, 121, 101, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70,
  70, 70, 70, 44, 36, 51, 44, 36, 52, 44, 36, 53, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 36, 50, 32, 121, 103, 61, 36, 62, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 49, 32, 120, 103, 61, 36, 62, 10, 45,
  116, 91, 45, 50, 93, 32, 64, 123, 45, 51, 44, 40, 36, 120, 103, 44,
  36, 121, 103, 41, 125, 44, 123, 53, 43, 36, 120, 103, 42, 50, 52, 125,
  44, 123, 53, 43, 36, 121, 103, 42, 50, 52, 125, 44, 49, 51, 44, 48,
  46, 56, 44, 123, 105, 102, 40, 64, 123, 45, 49, 44, 40, 36, 120, 103,
  44, 36, 121, 103, 41, 125, 62, 49, 50, 56, 44, 48, 44, 50, 53, 53,
  41, 125, 10, 45, 100, 111, 110, 101, 10, 45, 100, 111, 110, 101, 10, 45,
  114, 109, 91, 45, 51, 44, 45, 49, 93, 10, 100, 102, 102, 116, 32, 58,
  10, 45, 95, 100, 105, 115, 112, 108, 97, 121, 95, 102, 102, 116, 10, 100,
  105, 115, 112, 108, 97, 121, 95, 102, 102, 116, 32, 58, 10, 45, 95, 36,
  48, 10, 95, 100, 105, 115, 112, 108, 97, 121, 95, 102, 102, 116, 32, 58,
  10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 82, 101, 110, 100, 101,
  114, 32, 102, 111, 117, 114, 105, 101, 114, 32, 116, 114, 97, 110, 115, 102,
  111, 114, 109, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 32, 119,
  105, 116, 104, 32, 99, 101, 110, 116, 101, 114, 101, 100, 32, 108, 111, 103,
  45, 109, 111, 100, 117, 108, 101, 32, 97, 110, 100, 32, 97, 114, 103, 117,
  109, 101, 110, 116, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 102,
  102, 116, 112, 111, 108, 97, 114, 32, 45, 43, 91, 45, 50, 93, 32, 49,
  32, 45, 108, 111, 103, 91, 45, 50, 93, 32, 45, 110, 32, 48, 44, 50,
  53, 53, 32, 45, 97, 32, 120, 32, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 115, 32, 120, 44, 50, 32, 45, 118, 32, 43, 10,
  100, 103, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49,
  61, 54, 52, 48, 125, 62, 51, 50, 32, 38, 38, 32, 36, 123, 50, 61,
  52, 56, 48, 125, 62, 51, 50, 34, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 51, 61, 49, 125, 44, 36, 123, 52, 61, 48, 125, 44, 36, 123, 53,
  61, 48, 125, 44, 36, 123, 54, 61, 48, 125, 44, 36, 123, 55, 61, 48,
  125, 44, 36, 123, 56, 61, 48, 125, 44, 34, 36, 123, 57, 61, 120, 45,
  97, 120, 105, 115, 125, 34, 44, 34, 36, 123, 49, 48, 61, 121, 45, 97,
  120, 105, 115, 125, 34, 10, 45, 95, 100, 105, 115, 112, 108, 97, 121, 95,
  103, 114, 97, 112, 104, 32, 36, 123, 49, 45, 56, 125, 44, 34, 36, 57,
  34, 44, 34, 36, 49, 48, 34, 10, 100, 105, 115, 112, 108, 97, 121, 95,
  103, 114, 97, 112, 104, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  36, 123, 49, 61, 54, 52, 48, 125, 62, 51, 50, 32, 38, 38, 32, 36,
  123, 50, 61, 52, 56, 48, 125, 62, 51, 50, 34, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 51, 61, 49, 125, 44, 36, 123, 52, 61, 48, 125, 44,
  36, 123, 53, 61, 48, 125, 44, 36, 123, 54, 61, 48, 125, 44, 36, 123,
  55, 61, 48, 125, 44, 36, 123, 56, 61, 48, 125, 44, 34, 36, 123, 57,
  61, 120, 45, 97, 120, 105, 115, 125, 34, 44, 34, 36, 123, 49, 48, 61,
  121, 45, 97, 120, 105, 115, 125, 34, 10, 45, 95, 100, 105, 115, 112, 108,
  97, 121, 95, 103, 114, 97, 112, 104, 32, 36, 123, 49, 45, 56, 125, 44,
  34, 36, 57, 34, 44, 34, 36, 49, 48, 34, 10, 95, 100, 105, 115, 112,
  108, 97, 121, 95, 103, 114, 97, 112, 104, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 36, 123, 49, 61, 54, 52, 48, 125, 62, 51, 50, 32,
  38, 38, 32, 36, 123, 50, 61, 52, 56, 48, 125, 62, 51, 50, 34, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 49, 125, 44, 36, 123, 52,
  61, 48, 125, 44, 36, 123, 53, 61, 48, 125, 44, 36, 123, 54, 61, 48,
  125, 44, 36, 123, 55, 61, 48, 125, 44, 36, 123, 56, 61, 48, 125, 44,
  34, 36, 123, 57, 61, 120, 45, 97, 120, 105, 115, 125, 34, 44, 34, 36,
  123, 49, 48, 61, 121, 45, 97, 120, 105, 115, 125, 34, 10, 45, 101, 91,
  48, 45, 45, 51, 93, 32, 34, 82, 101, 110, 100, 101, 114, 32, 36, 49,
  120, 36, 50, 32, 103, 114, 97, 112, 104, 32, 112, 108, 111, 116, 32, 102,
  114, 111, 109, 32, 100, 97, 116, 97, 32, 111, 102, 32, 105, 109, 97, 103,
  101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61,
  64, 123, 48, 44, 110, 125, 10, 111, 110, 101, 61, 123, 36, 51, 33, 61,
  51, 125, 32, 115, 105, 122, 61, 123, 119, 42, 104, 42, 100, 125, 10, 45,
  105, 102, 32, 123, 36, 53, 61, 61, 36, 54, 125, 32, 120, 109, 105, 110,
  61, 48, 32, 120, 109, 97, 120, 61, 123, 36, 115, 105, 122, 45, 36, 111,
  110, 101, 125, 32, 45, 101, 108, 115, 101, 32, 120, 109, 105, 110, 61, 123,
  109, 105, 110, 40, 36, 53, 44, 36, 54, 41, 125, 32, 120, 109, 97, 120,
  61, 123, 109, 97, 120, 40, 36, 53, 44, 36, 54, 41, 125, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 55, 61, 61, 36, 56,
  125, 32, 121, 109, 105, 110, 61, 123, 105, 109, 45, 40, 105, 77, 45, 105,
  109, 41, 47, 50, 48, 125, 32, 121, 109, 97, 120, 61, 123, 105, 77, 43,
  40, 105, 77, 45, 105, 109, 41, 47, 50, 48, 125, 32, 45, 101, 108, 115,
  101, 32, 121, 109, 105, 110, 61, 123, 109, 105, 110, 40, 36, 55, 44, 36,
  56, 41, 125, 32, 121, 109, 97, 120, 61, 123, 109, 97, 120, 40, 36, 55,
  44, 36, 56, 41, 125, 32, 45, 101, 110, 100, 105, 102, 10, 103, 119, 61,
  123, 36, 49, 45, 51, 50, 125, 32, 103, 104, 61, 123, 36, 50, 45, 51,
  50, 125, 32, 103, 103, 61, 123, 40, 36, 103, 119, 45, 36, 111, 110, 101,
  41, 47, 40, 36, 115, 105, 122, 45, 36, 111, 110, 101, 41, 125, 10, 36,
  103, 119, 44, 36, 103, 104, 44, 49, 44, 51, 44, 50, 53, 53, 10, 45,
  105, 102, 32, 123, 36, 115, 105, 122, 60, 51, 50, 125, 32, 45, 103, 114,
  105, 100, 91, 45, 49, 93, 32, 36, 103, 103, 44, 36, 103, 103, 44, 48,
  44, 48, 44, 48, 46, 50, 53, 44, 48, 120, 67, 67, 67, 67, 67, 67,
  67, 67, 44, 48, 10, 45, 101, 108, 115, 101, 32, 45, 103, 114, 105, 100,
  91, 45, 49, 93, 32, 49, 48, 37, 44, 49, 48, 37, 44, 48, 44, 48,
  44, 48, 46, 50, 53, 44, 48, 120, 67, 67, 67, 67, 67, 67, 67, 67,
  44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64,
  123, 45, 50, 44, 115, 125, 61, 61, 49, 125, 32, 40, 49, 50, 48, 44,
  49, 50, 48, 44, 50, 48, 48, 41, 10, 45, 101, 108, 105, 102, 32, 123,
  64, 123, 45, 50, 44, 115, 125, 60, 61, 51, 125, 32, 40, 50, 50, 48,
  44, 49, 48, 44, 49, 48, 59, 49, 48, 44, 50, 50, 48, 44, 49, 48,
  59, 49, 48, 44, 49, 48, 44, 50, 50, 48, 41, 10, 45, 101, 108, 115,
  101, 10, 40, 48, 44, 50, 53, 53, 41, 32, 45, 114, 91, 45, 49, 93,
  32, 50, 53, 54, 44, 49, 44, 49, 44, 49, 44, 51, 32, 45, 109, 97,
  112, 91, 45, 49, 93, 32, 50, 32, 45, 122, 91, 45, 49, 93, 32, 50,
  44, 49, 48, 48, 37, 32, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45,
  49, 93, 32, 99, 120, 121, 122, 32, 45, 114, 91, 45, 49, 93, 32, 51,
  44, 123, 109, 97, 120, 40, 51, 44, 64, 123, 45, 51, 44, 115, 125, 41,
  125, 44, 49, 44, 49, 44, 48, 44, 50, 10, 45, 115, 104, 91, 45, 49,
  93, 32, 48, 44, 50, 44, 48, 44, 48, 32, 45, 102, 91, 45, 49, 93,
  32, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 48,
  44, 48, 44, 48, 44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 123, 45, 51, 44, 115, 125, 32, 45, 115, 104, 91, 45, 51, 93, 32,
  36, 62, 44, 36, 62, 32, 45, 103, 114, 97, 112, 104, 91, 45, 51, 93,
  32, 91, 45, 49, 93, 44, 36, 51, 44, 36, 52, 44, 36, 121, 109, 97,
  120, 44, 36, 121, 109, 105, 110, 44, 49, 44, 64, 123, 45, 50, 44, 48,
  45, 50, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 115, 104, 105,
  102, 116, 91, 45, 49, 93, 32, 48, 44, 45, 49, 32, 45, 100, 111, 110,
  101, 10, 45, 114, 109, 91, 45, 51, 44, 45, 49, 93, 10, 45, 108, 105,
  110, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 49, 48, 48, 37, 44,
  48, 44, 49, 44, 49, 49, 48, 32, 45, 108, 105, 110, 101, 91, 45, 49,
  93, 32, 49, 48, 48, 37, 44, 48, 44, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 44, 49, 49, 48, 10, 45, 108, 105, 110, 101, 91, 45,
  49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48, 44, 49,
  48, 48, 37, 44, 49, 44, 50, 53, 53, 32, 45, 108, 105, 110, 101, 91,
  45, 49, 93, 32, 48, 44, 49, 48, 48, 37, 44, 48, 44, 48, 44, 49,
  44, 50, 53, 53, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 49, 44, 50, 53, 53, 10, 120, 109, 97, 120, 95, 61, 123, 36, 120,
  109, 105, 110, 43, 40, 36, 120, 109, 97, 120, 45, 36, 120, 109, 105, 110,
  41, 42, 40, 36, 115, 105, 122, 45, 36, 111, 110, 101, 41, 47, 40, 36,
  115, 105, 122, 45, 49, 41, 125, 10, 45, 97, 120, 101, 115, 91, 45, 49,
  93, 32, 36, 120, 109, 105, 110, 44, 36, 120, 109, 97, 120, 95, 44, 36,
  121, 109, 97, 120, 44, 36, 121, 109, 105, 110, 44, 49, 51, 44, 49, 44,
  48, 10, 45, 105, 102, 32, 123, 36, 120, 109, 105, 110, 62, 48, 125, 32,
  45, 97, 120, 101, 115, 91, 45, 49, 93, 32, 48, 44, 48, 44, 36, 121,
  109, 97, 120, 44, 36, 121, 109, 105, 110, 44, 49, 51, 44, 49, 44, 49,
  54, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  120, 109, 97, 120, 60, 48, 125, 32, 45, 97, 120, 101, 115, 91, 45, 49,
  93, 32, 123, 119, 45, 49, 125, 44, 123, 119, 45, 49, 125, 44, 36, 121,
  109, 97, 120, 44, 36, 121, 109, 105, 110, 44, 49, 51, 44, 49, 44, 49,
  54, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  121, 109, 105, 110, 62, 48, 125, 32, 45, 97, 120, 101, 115, 91, 45, 49,
  93, 32, 36, 120, 109, 105, 110, 44, 36, 120, 109, 97, 120, 95, 44, 123,
  104, 45, 49, 125, 44, 123, 104, 45, 49, 125, 44, 49, 51, 44, 49, 44,
  49, 54, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 121, 109, 97, 120, 60, 48, 125, 32, 45, 97, 120, 101, 115, 91, 45,
  49, 93, 32, 36, 120, 109, 105, 110, 44, 36, 120, 109, 97, 120, 95, 44,
  48, 44, 48, 44, 49, 51, 44, 49, 44, 49, 54, 48, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 45, 101, 114, 111, 100, 101, 91, 45, 49, 93, 32,
  51, 32, 45, 110, 101, 113, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45,
  114, 91, 45, 50, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  49, 44, 51, 32, 45, 106, 91, 45, 51, 93, 32, 91, 45, 50, 93, 44,
  48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 44, 49,
  32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 102, 114, 97,
  109, 101, 91, 45, 49, 93, 32, 49, 54, 44, 49, 54, 44, 50, 50, 48,
  10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 36, 57, 34, 44, 48,
  44, 48, 44, 49, 51, 44, 49, 44, 45, 50, 50, 48, 44, 45, 50, 50,
  48, 44, 45, 50, 50, 48, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 44, 123, 40, 64, 123, 45, 50, 44, 119, 125, 45, 119, 41, 47,
  50, 125, 44, 123, 64, 123, 45, 50, 44, 104, 125, 45, 49, 54, 125, 44,
  48, 44, 48, 44, 45, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 48,
  32, 45, 116, 91, 45, 49, 93, 32, 34, 36, 49, 48, 34, 44, 48, 44,
  48, 44, 49, 51, 44, 49, 44, 45, 50, 50, 48, 44, 45, 50, 50, 48,
  44, 45, 50, 50, 48, 32, 45, 114, 111, 116, 97, 116, 101, 91, 45, 49,
  93, 32, 45, 57, 48, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 50, 44, 123, 40, 64, 123, 45, 50, 44, 104, 125, 45, 104, 41,
  47, 50, 125, 44, 48, 44, 48, 44, 45, 49, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 99, 32, 48, 44, 50, 53,
  53, 32, 45, 118, 32, 43, 10, 100, 104, 32, 58, 10, 45, 118, 32, 45,
  32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45,
  95, 100, 105, 115, 112, 108, 97, 121, 95, 104, 105, 115, 116, 111, 103, 114,
  97, 109, 32, 36, 42, 10, 100, 105, 115, 112, 108, 97, 121, 95, 104, 105,
  115, 116, 111, 103, 114, 97, 109, 32, 58, 10, 45, 118, 32, 45, 32, 95,
  95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 36,
  48, 32, 36, 42, 10, 95, 100, 105, 115, 112, 108, 97, 121, 95, 104, 105,
  115, 116, 111, 103, 114, 97, 109, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 34, 36, 123, 49, 61, 53, 49, 50, 125, 62, 48, 32, 38, 38, 32,
  36, 123, 50, 61, 51, 48, 48, 125, 62, 48, 32, 38, 38, 32, 36, 123,
  51, 61, 50, 53, 54, 125, 62, 48, 34, 32, 45, 115, 107, 105, 112, 32,
  36, 123, 52, 61, 48, 37, 125, 44, 36, 123, 53, 61, 49, 48, 48, 37,
  125, 44, 36, 123, 54, 61, 49, 125, 44, 36, 123, 55, 61, 45, 49, 125,
  10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 82, 101, 110, 100, 101,
  114, 32, 36, 49, 120, 36, 50, 32, 99, 104, 97, 110, 110, 101, 108, 45,
  98, 121, 45, 99, 104, 97, 110, 110, 101, 108, 32, 104, 105, 115, 116, 111,
  103, 114, 97, 109, 32, 111, 102, 32, 105, 109, 97, 103, 101, 34, 36, 95,
  95, 115, 34, 44, 32, 119, 105, 116, 104, 32, 36, 51, 32, 99, 108, 117,
  115, 116, 101, 114, 115, 44, 32, 109, 105, 110, 105, 109, 117, 109, 32, 118,
  97, 108, 117, 101, 32, 36, 52, 32, 97, 110, 100, 32, 109, 97, 120, 105,
  109, 117, 109, 32, 118, 97, 108, 117, 101, 32, 36, 53, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10,
  45, 105, 102, 32, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110,
  116, 92, 32, 36, 52, 125, 32, 109, 61, 123, 105, 109, 43, 40, 105, 77,
  45, 105, 109, 41, 42, 36, 52, 125, 32, 45, 101, 108, 115, 101, 32, 109,
  61, 36, 52, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 64,
  123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 53,
  125, 32, 77, 61, 123, 105, 109, 43, 40, 105, 77, 45, 105, 109, 41, 42,
  36, 53, 125, 32, 45, 101, 108, 115, 101, 32, 77, 61, 36, 53, 32, 45,
  101, 110, 100, 105, 102, 10, 115, 61, 123, 115, 125, 32, 45, 115, 32, 99,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 115, 32, 45, 108, 91, 123,
  45, 49, 45, 36, 62, 125, 93, 32, 45, 115, 32, 122, 32, 45, 104, 105,
  115, 116, 111, 103, 114, 97, 109, 32, 36, 51, 44, 36, 109, 44, 36, 77,
  32, 45, 97, 32, 122, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 45, 97, 32, 99, 32, 118, 77, 61, 123, 105, 102, 40, 36, 55,
  62, 61, 48, 44, 36, 55, 44, 105, 77, 41, 125, 32, 45, 115, 32, 122,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 36, 49, 44, 36, 50, 44, 49, 44, 123, 115, 125, 44, 45,
  50, 53, 53, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 115, 125, 32,
  45, 115, 104, 91, 45, 50, 44, 45, 49, 93, 32, 36, 62, 44, 36, 62,
  32, 45, 103, 114, 97, 112, 104, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  44, 51, 44, 48, 44, 36, 118, 77, 44, 48, 44, 49, 44, 48, 32, 45,
  114, 109, 91, 45, 50, 44, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10,
  45, 114, 109, 91, 45, 50, 93, 32, 45, 43, 32, 50, 53, 53, 10, 45,
  105, 102, 32, 36, 54, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32,
  45, 97, 120, 101, 115, 91, 45, 49, 93, 32, 36, 109, 44, 36, 77, 44,
  36, 118, 77, 44, 48, 44, 49, 51, 44, 49, 44, 50, 53, 53, 32, 45,
  45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51, 32, 45, 114,
  91, 45, 50, 93, 32, 91, 45, 51, 93, 32, 45, 106, 91, 45, 51, 93,
  32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44,
  91, 45, 49, 93, 44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 45, 97, 32, 122, 32, 45, 110, 109, 32,
  36, 110, 109, 44, 49, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 100, 105, 115, 112, 108, 97, 121, 95, 112,
  97, 114, 97, 109, 101, 116, 114, 105, 99, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 36, 123, 49, 61, 53, 49, 50, 125, 62, 48, 32, 38,
  38, 32, 36, 123, 50, 61, 36, 49, 125, 62, 48, 32, 38, 38, 32, 36,
  123, 52, 61, 48, 125, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32,
  36, 123, 51, 61, 51, 125, 44, 36, 123, 53, 61, 49, 125, 44, 36, 123,
  54, 61, 49, 125, 44, 34, 36, 123, 55, 61, 120, 45, 97, 120, 105, 115,
  125, 34, 44, 34, 36, 123, 56, 61, 121, 45, 97, 120, 105, 115, 125, 34,
  10, 45, 118, 32, 45, 32, 115, 48, 61, 34, 110, 111, 32, 34, 32, 115,
  49, 61, 34, 34, 32, 111, 48, 61, 34, 34, 32, 111, 49, 61, 34, 99,
  111, 108, 111, 114, 101, 100, 32, 34, 10, 45, 118, 32, 43, 32, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 82, 101, 110, 100, 101, 114, 32, 36, 49,
  120, 36, 50, 32, 112, 97, 114, 97, 109, 101, 116, 114, 105, 99, 32, 103,
  114, 97, 112, 104, 32, 112, 108, 111, 116, 32, 102, 114, 111, 109, 32, 100,
  97, 116, 97, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32,
  119, 105, 116, 104, 32, 34, 36, 123, 111, 123, 36, 51, 62, 49, 125, 125,
  34, 111, 117, 116, 108, 105, 110, 101, 32, 111, 112, 97, 99, 105, 116, 121,
  32, 34, 123, 105, 102, 40, 36, 51, 62, 49, 44, 36, 51, 45, 49, 44,
  36, 51, 41, 125, 92, 10, 34, 44, 32, 118, 101, 114, 116, 101, 120, 32,
  114, 97, 100, 105, 117, 115, 32, 36, 52, 44, 32, 34, 36, 123, 115, 123,
  36, 53, 33, 61, 48, 125, 125, 34, 97, 110, 116, 105, 97, 108, 105, 97,
  115, 105, 110, 103, 32, 97, 110, 100, 32, 34, 36, 123, 115, 123, 36, 54,
  33, 61, 48, 125, 125, 34, 100, 101, 99, 111, 114, 97, 116, 105, 111, 110,
  46, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 110, 109, 61, 64, 123, 48,
  44, 110, 125, 32, 78, 61, 123, 119, 42, 104, 42, 100, 125, 10, 45, 105,
  91, 48, 93, 32, 40, 123, 39, 67, 73, 109, 103, 51, 100, 39, 125, 41,
  32, 45, 43, 91, 48, 93, 32, 48, 46, 53, 32, 45, 105, 91, 49, 93,
  32, 40, 36, 78, 59, 36, 78, 41, 10, 45, 105, 102, 32, 123, 115, 61,
  61, 52, 125, 32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45,
  49, 93, 32, 51, 44, 51, 32, 45, 114, 91, 45, 49, 93, 32, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 50, 32, 45, 97, 91, 45,
  50, 44, 45, 49, 93, 32, 99, 32, 105, 115, 95, 103, 114, 97, 121, 115,
  99, 97, 108, 101, 61, 49, 10, 45, 101, 108, 115, 101, 32, 105, 115, 95,
  103, 114, 97, 121, 115, 99, 97, 108, 101, 61, 123, 115, 60, 52, 125, 32,
  45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 44,
  53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 115, 104, 91, 45, 49, 93,
  32, 48, 44, 48, 32, 120, 109, 61, 123, 105, 109, 125, 32, 120, 77, 61,
  123, 105, 77, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104,
  91, 45, 49, 93, 32, 49, 44, 49, 32, 121, 109, 61, 123, 105, 109, 125,
  32, 121, 77, 61, 123, 105, 77, 125, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 115, 104, 91, 45, 49, 93, 32, 50, 44, 50, 32, 122, 109, 61,
  123, 105, 109, 125, 32, 122, 77, 61, 123, 105, 77, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 49,
  93, 32, 99, 120, 121, 122, 32, 45, 115, 91, 45, 49, 93, 32, 120, 44,
  50, 10, 45, 105, 91, 45, 50, 93, 32, 40, 49, 44, 48, 59, 49, 44,
  123, 36, 78, 45, 49, 125, 41, 32, 45, 114, 91, 45, 50, 93, 32, 50,
  44, 36, 78, 44, 49, 44, 49, 44, 51, 32, 45, 114, 111, 117, 110, 100,
  91, 45, 50, 93, 32, 49, 44, 36, 78, 44, 49, 44, 49, 44, 49, 10,
  45, 121, 32, 45, 97, 32, 121, 32, 45, 99, 51, 100, 32, 45, 110, 51,
  100, 32, 45, 42, 51, 100, 32, 49, 44, 45, 49, 44, 49, 10, 123, 105,
  102, 40, 36, 54, 44, 109, 97, 120, 40, 49, 44, 36, 49, 45, 51, 50,
  41, 44, 36, 49, 41, 125, 44, 123, 105, 102, 40, 36, 54, 44, 109, 97,
  120, 40, 49, 44, 36, 50, 45, 51, 50, 41, 44, 36, 50, 41, 125, 44,
  49, 44, 123, 105, 102, 40, 36, 105, 115, 95, 103, 114, 97, 121, 115, 99,
  97, 108, 101, 44, 49, 44, 51, 41, 125, 44, 50, 53, 53, 10, 45, 42,
  51, 100, 91, 48, 93, 32, 123, 48, 46, 57, 54, 42, 109, 105, 110, 40,
  119, 44, 104, 41, 125, 10, 45, 105, 102, 32, 36, 54, 32, 76, 61, 123,
  48, 46, 49, 42, 109, 97, 120, 40, 36, 49, 44, 36, 50, 41, 125, 32,
  45, 103, 114, 105, 100, 91, 49, 93, 32, 36, 76, 44, 36, 76, 44, 48,
  44, 48, 44, 48, 46, 50, 53, 44, 48, 120, 67, 67, 67, 67, 67, 67,
  67, 67, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  36, 53, 10, 45, 114, 91, 49, 93, 32, 50, 48, 48, 37, 44, 50, 48,
  48, 37, 44, 49, 44, 49, 48, 48, 37, 44, 49, 32, 45, 42, 51, 100,
  91, 48, 93, 32, 50, 10, 45, 105, 102, 32, 36, 52, 32, 45, 45, 99,
  105, 114, 99, 108, 101, 115, 51, 100, 91, 48, 93, 32, 123, 50, 42, 36,
  52, 125, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 49, 93, 32,
  91, 50, 93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 49, 44,
  51, 44, 48, 44, 48, 32, 45, 114, 109, 91, 50, 93, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 108, 105, 102, 32, 36, 52, 10, 45, 45, 99,
  105, 114, 99, 108, 101, 115, 51, 100, 91, 48, 93, 32, 36, 52, 32, 45,
  111, 98, 106, 101, 99, 116, 51, 100, 91, 49, 93, 32, 91, 50, 93, 44,
  53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 49, 44, 51, 44, 48, 44,
  48, 32, 45, 114, 109, 91, 50, 93, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 36, 51, 32, 45, 108, 91, 48, 93, 32, 45, 115, 51,
  100, 32, 45, 102, 91, 49, 93, 32, 39, 105, 45, 121, 39, 32, 45, 114,
  109, 91, 51, 93, 32, 45, 105, 91, 51, 93, 32, 40, 50, 44, 48, 44,
  49, 59, 50, 44, 123, 36, 78, 45, 50, 125, 44, 123, 36, 78, 45, 49,
  125, 41, 32, 45, 114, 91, 51, 93, 32, 51, 44, 123, 36, 78, 45, 49,
  125, 44, 49, 44, 49, 44, 51, 32, 45, 114, 111, 117, 110, 100, 91, 51,
  93, 10, 45, 114, 91, 53, 93, 32, 49, 44, 123, 104, 45, 49, 125, 44,
  49, 44, 49, 44, 48, 10, 45, 105, 102, 32, 123, 36, 51, 62, 49, 125,
  32, 45, 114, 91, 52, 93, 32, 51, 44, 64, 123, 52, 44, 104, 47, 51,
  125, 44, 49, 44, 49, 44, 45, 49, 32, 45, 114, 91, 52, 93, 32, 51,
  44, 64, 123, 52, 44, 104, 45, 49, 125, 44, 49, 44, 49, 44, 50, 32,
  45, 101, 108, 115, 101, 32, 45, 114, 109, 91, 52, 93, 32, 45, 105, 91,
  52, 93, 32, 51, 44, 123, 36, 78, 45, 49, 125, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 121, 32, 45, 97, 32, 121, 32, 45, 101, 110, 100, 108,
  32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 49, 93, 32, 91, 48,
  93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 123, 105, 102, 40,
  36, 51, 62, 49, 44, 36, 51, 45, 49, 44, 36, 51, 41, 125, 44, 50,
  44, 48, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91,
  48, 93, 10, 45, 105, 102, 32, 36, 53, 32, 45, 114, 91, 45, 49, 93,
  32, 53, 48, 37, 44, 53, 48, 37, 44, 49, 44, 49, 48, 48, 37, 44,
  50, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 54, 10,
  120, 99, 61, 123, 48, 46, 53, 42, 40, 36, 120, 109, 43, 36, 120, 77,
  41, 125, 32, 121, 99, 61, 123, 48, 46, 53, 42, 40, 36, 121, 109, 43,
  36, 121, 77, 41, 125, 32, 100, 120, 61, 123, 48, 46, 53, 42, 40, 36,
  120, 77, 45, 36, 120, 109, 41, 47, 48, 46, 57, 54, 125, 32, 100, 121,
  61, 123, 48, 46, 53, 42, 40, 36, 121, 77, 45, 36, 121, 109, 41, 47,
  48, 46, 57, 54, 125, 10, 120, 109, 61, 123, 36, 120, 99, 45, 36, 100,
  120, 125, 32, 120, 77, 61, 123, 36, 120, 99, 43, 36, 100, 120, 125, 32,
  121, 109, 61, 123, 36, 121, 99, 45, 36, 100, 121, 125, 32, 121, 77, 61,
  123, 36, 121, 99, 43, 36, 100, 121, 125, 10, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 32, 45, 97, 120, 101, 115, 91, 45, 49, 93, 32, 36, 120,
  109, 44, 36, 120, 77, 44, 36, 121, 77, 44, 36, 121, 109, 44, 49, 51,
  44, 49, 44, 49, 10, 45, 105, 102, 32, 123, 36, 120, 109, 62, 48, 125,
  32, 45, 97, 120, 101, 115, 91, 45, 49, 93, 32, 48, 44, 48, 44, 36,
  121, 77, 44, 36, 121, 109, 44, 49, 51, 44, 49, 44, 49, 54, 48, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 120, 77, 60,
  48, 125, 32, 45, 97, 120, 101, 115, 91, 45, 49, 93, 32, 123, 119, 45,
  49, 125, 44, 123, 119, 45, 49, 125, 44, 36, 121, 77, 44, 36, 121, 109,
  44, 49, 51, 44, 49, 44, 49, 54, 48, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 121, 109, 62, 48, 125, 32, 45, 97, 120,
  101, 115, 91, 45, 49, 93, 32, 36, 120, 109, 44, 36, 120, 77, 44, 123,
  104, 45, 49, 125, 44, 123, 104, 45, 49, 125, 44, 49, 51, 44, 49, 44,
  49, 54, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 121, 77, 60, 48, 125, 32, 45, 97, 120, 101, 115, 91, 45, 49, 93,
  32, 36, 120, 109, 44, 36, 120, 77, 44, 48, 44, 48, 44, 49, 51, 44,
  49, 44, 49, 54, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 100,
  105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51, 32, 45, 45, 91, 45,
  49, 93, 32, 91, 45, 50, 93, 32, 45, 42, 91, 45, 49, 93, 32, 50,
  48, 48, 32, 45, 101, 113, 91, 45, 50, 93, 32, 48, 10, 45, 42, 91,
  45, 51, 44, 45, 50, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 102,
  114, 97, 109, 101, 32, 49, 44, 49, 44, 49, 50, 56, 32, 45, 102, 114,
  97, 109, 101, 32, 49, 53, 44, 49, 53, 44, 50, 50, 48, 10, 48, 32,
  45, 116, 91, 45, 49, 93, 32, 34, 36, 55, 34, 44, 48, 44, 48, 44,
  49, 51, 44, 49, 44, 45, 50, 50, 48, 44, 45, 50, 50, 48, 44, 45,
  50, 50, 48, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44,
  123, 40, 64, 123, 45, 50, 44, 119, 125, 45, 119, 41, 47, 50, 125, 44,
  123, 64, 123, 45, 50, 44, 104, 125, 45, 49, 54, 125, 44, 48, 44, 48,
  44, 45, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 48, 32, 45, 116,
  91, 45, 49, 93, 32, 34, 36, 56, 34, 44, 48, 44, 48, 44, 49, 51,
  44, 49, 44, 45, 50, 50, 48, 44, 45, 50, 50, 48, 44, 45, 50, 50,
  48, 32, 45, 114, 111, 116, 97, 116, 101, 91, 45, 49, 93, 32, 45, 57,
  48, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 50, 44,
  123, 40, 64, 123, 45, 50, 44, 104, 125, 45, 104, 41, 47, 50, 125, 44,
  48, 44, 48, 44, 45, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 110, 109, 91, 45, 49, 93, 32, 36, 110,
  109, 44, 49, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 100, 112, 32, 58, 10, 45, 118, 32, 45, 32, 95,
  95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 100,
  105, 115, 112, 108, 97, 121, 95, 112, 111, 108, 97, 114, 32, 36, 42, 10,
  100, 105, 115, 112, 108, 97, 121, 95, 112, 111, 108, 97, 114, 32, 58, 10,
  45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118,
  32, 43, 10, 45, 95, 36, 48, 32, 36, 42, 10, 95, 100, 105, 115, 112,
  108, 97, 121, 95, 112, 111, 108, 97, 114, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 36, 123, 49, 61, 53, 48, 48, 125, 62, 51, 50, 32,
  38, 38, 32, 36, 123, 50, 61, 36, 49, 125, 62, 51, 50, 34, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 51, 61, 49, 125, 44, 36, 123, 52, 61,
  50, 48, 48, 125, 44, 36, 123, 53, 61, 36, 52, 125, 44, 36, 123, 54,
  61, 36, 53, 125, 44, 36, 123, 55, 61, 48, 125, 44, 36, 123, 56, 61,
  51, 54, 48, 125, 44, 34, 36, 123, 57, 61, 120, 45, 97, 120, 105, 115,
  125, 34, 44, 34, 36, 123, 49, 48, 61, 121, 45, 97, 120, 105, 115, 125,
  34, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 82, 101, 110, 100,
  101, 114, 32, 36, 49, 120, 36, 50, 32, 112, 111, 108, 97, 114, 32, 103,
  114, 97, 112, 104, 32, 112, 108, 111, 116, 32, 102, 114, 111, 109, 32, 100,
  97, 116, 97, 32, 111, 102, 32, 105, 109, 97, 103, 101, 34, 36, 95, 95,
  115, 34, 44, 32, 119, 105, 116, 104, 32, 111, 117, 116, 108, 105, 110, 101,
  32, 36, 52, 32, 97, 110, 100, 32, 102, 105, 108, 108, 32, 99, 111, 108,
  111, 114, 32, 40, 36, 52, 44, 36, 53, 44, 36, 54, 41, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125,
  10, 77, 61, 123, 109, 97, 120, 40, 97, 98, 115, 40, 105, 77, 41, 44,
  97, 98, 115, 40, 105, 109, 41, 41, 125, 10, 45, 42, 32, 123, 48, 46,
  52, 56, 42, 109, 105, 110, 40, 36, 49, 44, 36, 50, 41, 47, 36, 77,
  125, 10, 45, 121, 32, 40, 123, 36, 55, 42, 112, 105, 47, 49, 56, 48,
  125, 59, 123, 45, 36, 56, 42, 112, 105, 47, 49, 56, 48, 125, 41, 32,
  45, 114, 91, 45, 49, 93, 32, 49, 44, 91, 45, 50, 93, 44, 49, 44,
  49, 44, 51, 10, 45, 45, 115, 105, 110, 91, 45, 49, 93, 32, 45, 99,
  111, 115, 91, 45, 50, 93, 32, 45, 42, 91, 45, 49, 93, 32, 91, 45,
  51, 93, 32, 45, 42, 91, 45, 51, 44, 45, 50, 93, 10, 45, 97, 91,
  45, 50, 44, 45, 49, 93, 32, 120, 32, 78, 61, 123, 104, 125, 10, 45,
  110, 109, 91, 45, 49, 93, 32, 99, 111, 111, 114, 100, 115, 10, 45, 105,
  102, 32, 36, 51, 10, 40, 123, 39, 67, 73, 109, 103, 51, 100, 39, 125,
  41, 32, 45, 43, 91, 45, 49, 93, 32, 48, 46, 53, 32, 40, 36, 78,
  44, 36, 78, 41, 10, 45, 45, 122, 91, 99, 111, 111, 114, 100, 115, 93,
  32, 48, 44, 50, 10, 49, 44, 36, 78, 44, 49, 44, 49, 44, 50, 32,
  49, 44, 36, 78, 44, 49, 44, 49, 44, 39, 121, 39, 32, 45, 45, 43,
  91, 45, 49, 93, 32, 49, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93,
  32, 120, 32, 45, 61, 91, 45, 49, 93, 32, 48, 44, 50, 44, 49, 48,
  48, 37, 10, 51, 44, 36, 78, 44, 49, 44, 49, 44, 48, 32, 49, 44,
  36, 78, 44, 49, 44, 49, 44, 49, 32, 45, 121, 91, 45, 54, 45, 45,
  49, 93, 32, 45, 97, 91, 45, 54, 45, 45, 49, 93, 32, 121, 10, 45,
  110, 109, 91, 45, 49, 93, 32, 95, 112, 108, 111, 116, 95, 112, 111, 108,
  97, 114, 95, 111, 117, 116, 108, 105, 110, 101, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 34, 36, 52, 62, 61, 48, 32, 38, 38,
  32, 36, 53, 62, 61, 48, 32, 38, 38, 32, 36, 54, 62, 61, 48, 34,
  125, 10, 40, 123, 39, 67, 73, 109, 103, 51, 100, 39, 125, 41, 32, 45,
  43, 91, 45, 49, 93, 32, 48, 46, 53, 32, 40, 123, 36, 78, 43, 49,
  125, 44, 36, 78, 41, 10, 45, 45, 122, 91, 99, 111, 111, 114, 100, 115,
  93, 32, 48, 44, 45, 49, 44, 50, 44, 49, 48, 48, 37, 32, 45, 122,
  91, 45, 49, 93, 32, 48, 44, 50, 10, 49, 44, 36, 78, 44, 49, 44,
  49, 44, 51, 32, 49, 44, 36, 78, 32, 49, 44, 36, 78, 44, 49, 44,
  49, 44, 39, 49, 43, 121, 39, 32, 45, 45, 43, 91, 45, 49, 93, 32,
  49, 32, 45, 97, 91, 45, 52, 45, 45, 49, 93, 32, 120, 32, 45, 61,
  91, 45, 49, 93, 32, 49, 44, 51, 44, 49, 48, 48, 37, 10, 51, 44,
  36, 78, 44, 49, 44, 49, 44, 36, 52, 44, 36, 53, 44, 36, 54, 32,
  49, 44, 36, 78, 44, 49, 44, 49, 44, 49, 10, 45, 121, 91, 45, 54,
  45, 45, 49, 93, 32, 45, 97, 91, 45, 54, 45, 45, 49, 93, 32, 121,
  10, 45, 110, 109, 91, 45, 49, 93, 32, 95, 112, 108, 111, 116, 95, 112,
  111, 108, 97, 114, 95, 102, 105, 108, 108, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 114, 109, 91, 99, 111, 111, 114, 100, 115, 93, 10, 123, 36, 49,
  45, 51, 50, 125, 44, 123, 36, 50, 45, 51, 50, 125, 44, 49, 44, 51,
  44, 50, 53, 53, 10, 76, 61, 123, 48, 46, 49, 42, 109, 97, 120, 40,
  36, 49, 44, 36, 50, 41, 125, 32, 45, 103, 114, 105, 100, 91, 45, 49,
  93, 32, 36, 76, 44, 36, 76, 44, 48, 44, 48, 44, 48, 46, 50, 53,
  44, 48, 120, 67, 67, 67, 67, 67, 67, 67, 67, 44, 48, 10, 45, 105,
  102, 32, 123, 34, 36, 52, 62, 61, 48, 32, 38, 38, 32, 36, 53, 62,
  61, 48, 32, 38, 38, 32, 36, 54, 62, 61, 48, 34, 125, 10, 45, 111,
  98, 106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 95, 112, 108,
  111, 116, 95, 112, 111, 108, 97, 114, 95, 102, 105, 108, 108, 93, 44, 53,
  48, 37, 44, 53, 48, 37, 44, 48, 44, 49, 44, 50, 44, 49, 44, 48,
  10, 45, 114, 109, 91, 95, 112, 108, 111, 116, 95, 112, 111, 108, 97, 114,
  95, 102, 105, 108, 108, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 36, 51, 10, 45, 105, 102, 32, 123, 36, 51, 62, 61, 48, 125,
  10, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91,
  95, 112, 108, 111, 116, 95, 112, 111, 108, 97, 114, 95, 111, 117, 116, 108,
  105, 110, 101, 93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 49,
  44, 49, 44, 48, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 51, 33, 61, 48, 125, 10, 45, 105, 102, 32, 123, 97,
  98, 115, 40, 36, 51, 41, 62, 49, 125, 32, 45, 99, 105, 114, 99, 108,
  101, 115, 51, 100, 91, 95, 112, 108, 111, 116, 95, 112, 111, 108, 97, 114,
  95, 111, 117, 116, 108, 105, 110, 101, 93, 32, 123, 97, 98, 115, 40, 36,
  51, 41, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 111, 98, 106, 101,
  99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 95, 112, 108, 111, 116, 95,
  112, 111, 108, 97, 114, 95, 111, 117, 116, 108, 105, 110, 101, 93, 44, 53,
  48, 37, 44, 53, 48, 37, 44, 48, 44, 48, 46, 50, 44, 50, 44, 48,
  44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 95, 112,
  108, 111, 116, 95, 112, 111, 108, 97, 114, 95, 111, 117, 116, 108, 105, 110,
  101, 93, 10, 45, 101, 110, 100, 105, 102, 10, 110, 77, 61, 123, 36, 77,
  47, 48, 46, 57, 54, 125, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  32, 45, 97, 120, 101, 115, 91, 45, 49, 93, 32, 123, 45, 36, 110, 77,
  125, 44, 36, 110, 77, 44, 36, 110, 77, 44, 123, 45, 36, 110, 77, 125,
  44, 49, 51, 44, 49, 44, 49, 10, 45, 45, 100, 105, 108, 97, 116, 101,
  91, 45, 49, 93, 32, 51, 32, 45, 45, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 32, 45, 42, 91, 45, 49, 93, 32, 50, 48, 48, 32, 45, 101,
  113, 91, 45, 50, 93, 32, 48, 10, 45, 42, 91, 45, 51, 44, 45, 50,
  93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 99, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 102, 114, 97, 109, 101, 91,
  45, 49, 93, 32, 49, 44, 49, 44, 49, 50, 56, 32, 45, 102, 114, 97,
  109, 101, 91, 45, 49, 93, 32, 49, 53, 44, 49, 53, 44, 50, 50, 48,
  10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 36, 57, 34, 44, 48,
  44, 48, 44, 49, 51, 44, 49, 44, 45, 50, 50, 48, 44, 45, 50, 50,
  48, 44, 45, 50, 50, 48, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 44, 123, 40, 64, 123, 45, 50, 44, 119, 125, 45, 119, 41, 47,
  50, 125, 44, 123, 64, 123, 45, 50, 44, 104, 125, 45, 49, 54, 125, 44,
  48, 44, 48, 44, 45, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 48,
  32, 45, 116, 91, 45, 49, 93, 32, 34, 36, 49, 48, 34, 44, 48, 44,
  48, 44, 49, 51, 44, 49, 44, 45, 50, 50, 48, 44, 45, 50, 50, 48,
  44, 45, 50, 50, 48, 32, 45, 114, 111, 116, 97, 116, 101, 91, 45, 49,
  93, 32, 45, 57, 48, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 50, 44, 123, 40, 64, 123, 45, 50, 44, 104, 125, 45, 104, 41,
  47, 50, 125, 44, 48, 44, 48, 44, 45, 49, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 100, 114,
  103, 98, 97, 32, 58, 10, 45, 95, 100, 105, 115, 112, 108, 97, 121, 95,
  114, 103, 98, 97, 10, 100, 105, 115, 112, 108, 97, 121, 95, 114, 103, 98,
  97, 32, 58, 10, 45, 95, 36, 48, 10, 95, 100, 105, 115, 112, 108, 97,
  121, 95, 114, 103, 98, 97, 32, 58, 10, 45, 101, 91, 48, 45, 45, 51,
  93, 32, 34, 82, 101, 110, 100, 101, 114, 32, 82, 71, 66, 65, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 111, 118, 101, 114, 32, 97, 32, 99, 104,
  101, 99, 107, 101, 114, 98, 111, 97, 114, 100, 32, 98, 97, 99, 107, 103,
  114, 111, 117, 110, 100, 46, 34, 10, 45, 118, 32, 45, 32, 45, 116, 111,
  95, 97, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 105, 91, 48, 93, 32, 40, 49, 54, 48, 44,
  49, 50, 56, 59, 49, 50, 56, 44, 49, 54, 48, 41, 32, 45, 110, 109,
  91, 48, 93, 32, 64, 123, 49, 44, 110, 125, 32, 45, 114, 91, 48, 93,
  32, 49, 54, 44, 49, 54, 32, 45, 114, 91, 48, 93, 32, 91, 49, 93,
  44, 91, 49, 93, 44, 49, 44, 123, 115, 45, 49, 125, 44, 48, 44, 50,
  32, 45, 98, 108, 101, 110, 100, 32, 97, 108, 112, 104, 97, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 100,
  116, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63,
  34, 32, 45, 118, 32, 43, 10, 45, 95, 100, 105, 115, 112, 108, 97, 121,
  95, 116, 101, 110, 115, 111, 114, 115, 32, 36, 42, 10, 100, 105, 115, 112,
  108, 97, 121, 95, 116, 101, 110, 115, 111, 114, 115, 32, 58, 10, 45, 118,
  32, 45, 32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43,
  10, 45, 95, 36, 48, 32, 36, 42, 10, 95, 100, 105, 115, 112, 108, 97,
  121, 95, 116, 101, 110, 115, 111, 114, 115, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 36, 123, 49, 61, 49, 54, 125, 62, 48, 32, 38, 38,
  32, 36, 123, 50, 61, 48, 46, 57, 50, 125, 62, 61, 48, 34, 32, 45,
  115, 107, 105, 112, 32, 34, 36, 123, 51, 61, 49, 125, 34, 10, 45, 101,
  91, 48, 45, 45, 51, 93, 32, 34, 82, 101, 110, 100, 101, 114, 32, 102,
  105, 101, 108, 100, 32, 111, 102, 32, 50, 120, 50, 32, 116, 101, 110, 115,
  111, 114, 115, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 34, 36,
  95, 95, 115, 34, 44, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101, 32,
  102, 97, 99, 116, 111, 114, 32, 36, 49, 44, 32, 101, 108, 108, 105, 112,
  115, 101, 32, 102, 97, 99, 116, 111, 114, 32, 36, 50, 32, 105, 110, 32,
  34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 33, 36, 51, 44, 99,
  111, 108, 111, 114, 101, 100, 44, 109, 97, 115, 107, 101, 100, 125, 34, 32,
  109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32,
  123, 36, 51, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 45, 95, 100, 105, 115, 112, 108, 97,
  121, 95, 116, 101, 110, 115, 111, 114, 115, 32, 36, 49, 44, 36, 50, 44,
  48, 10, 45, 115, 91, 48, 93, 32, 99, 32, 45, 45, 109, 105, 110, 91,
  48, 44, 50, 93, 32, 45, 42, 91, 49, 93, 32, 45, 49, 32, 45, 43,
  91, 49, 44, 45, 49, 93, 32, 45, 97, 91, 48, 45, 50, 93, 32, 99,
  10, 45, 114, 91, 48, 93, 32, 91, 45, 49, 93, 44, 91, 45, 49, 93,
  32, 45, 110, 91, 48, 93, 32, 48, 44, 50, 53, 53, 32, 45, 42, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 101, 108, 115,
  101, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 10,
  45, 42, 32, 123, 40, 36, 50, 42, 36, 49, 47, 50, 41, 94, 50, 47,
  109, 97, 120, 40, 97, 98, 115, 40, 105, 109, 41, 44, 97, 98, 115, 40,
  105, 77, 41, 41, 125, 10, 45, 115, 32, 99, 32, 45, 105, 91, 45, 50,
  93, 32, 91, 45, 50, 93, 32, 45, 97, 32, 99, 32, 45, 115, 32, 121,
  120, 32, 45, 114, 32, 50, 44, 50, 44, 49, 44, 49, 44, 45, 49, 10,
  40, 48, 46, 53, 44, 48, 59, 48, 44, 48, 46, 53, 41, 32, 45, 43,
  91, 94, 45, 49, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 105, 110, 118, 101, 114, 116, 32, 45, 121, 32, 99, 32,
  45, 114, 32, 36, 49, 44, 36, 49, 10, 36, 49, 44, 36, 49, 44, 49,
  44, 49, 44, 39, 120, 39, 32, 45, 45, 91, 45, 49, 93, 32, 123, 119,
  47, 50, 125, 10, 36, 49, 44, 36, 49, 44, 49, 44, 49, 44, 39, 121,
  39, 32, 45, 45, 91, 45, 49, 93, 32, 123, 104, 47, 50, 125, 10, 45,
  45, 115, 113, 114, 91, 45, 49, 93, 32, 45, 42, 91, 45, 50, 93, 32,
  91, 45, 51, 93, 32, 45, 115, 113, 114, 91, 45, 51, 93, 32, 45, 105,
  91, 45, 50, 93, 32, 91, 45, 50, 93, 32, 45, 97, 91, 45, 52, 45,
  45, 49, 93, 32, 99, 10, 45, 42, 91, 94, 45, 49, 93, 32, 91, 45,
  49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 99, 111, 109, 112,
  111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 43, 32, 45,
  108, 101, 32, 49, 10, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108,
  101, 115, 32, 36, 119, 44, 36, 104, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43,
  10, 100, 119, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34,
  36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 100, 105, 115, 112, 108,
  97, 121, 95, 119, 97, 114, 112, 32, 36, 42, 10, 100, 105, 115, 112, 108,
  97, 121, 95, 119, 97, 114, 112, 32, 58, 10, 45, 118, 32, 45, 32, 95,
  95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 36,
  48, 32, 36, 42, 10, 95, 100, 105, 115, 112, 108, 97, 121, 95, 119, 97,
  114, 112, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49,
  61, 49, 53, 125, 62, 48, 34, 10, 45, 101, 91, 48, 45, 45, 51, 93,
  32, 34, 82, 101, 110, 100, 101, 114, 32, 50, 100, 32, 119, 97, 114, 112,
  105, 110, 103, 32, 102, 105, 101, 108, 100, 34, 36, 95, 95, 115, 34, 44,
  32, 119, 105, 116, 104, 32, 99, 101, 108, 108, 32, 115, 105, 122, 101, 32,
  36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32,
  123, 100, 33, 61, 49, 124, 124, 115, 33, 61, 50, 125, 10, 45, 101, 114,
  114, 111, 114, 91, 48, 45, 45, 51, 93, 32, 34, 73, 110, 118, 97, 108,
  105, 100, 32, 105, 109, 97, 103, 101, 32, 91, 34, 123, 64, 35, 45, 36,
  62, 45, 49, 125, 34, 93, 58, 32, 68, 105, 109, 101, 110, 115, 105, 111,
  110, 115, 32, 34, 123, 119, 125, 34, 44, 34, 123, 104, 125, 34, 44, 34,
  123, 100, 125, 34, 44, 34, 123, 115, 125, 34, 32, 100, 111, 101, 115, 32,
  110, 111, 116, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 32, 97, 32,
  50, 100, 32, 102, 105, 101, 108, 100, 32, 111, 102, 32, 50, 100, 32, 118,
  101, 99, 116, 111, 114, 115, 46, 34, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 91, 48, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  49, 44, 49, 44, 49, 32, 45, 103, 114, 105, 100, 91, 48, 93, 32, 36,
  49, 44, 36, 49, 32, 45, 110, 109, 91, 48, 93, 32, 64, 123, 49, 44,
  110, 125, 10, 45, 119, 97, 114, 112, 91, 48, 93, 32, 91, 49, 93, 44,
  49, 44, 49, 44, 48, 32, 45, 114, 109, 91, 49, 93, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 42, 32, 50, 53, 53, 32,
  45, 118, 32, 43, 10, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109,
  105, 99, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 34,
  97, 115, 99, 105, 105, 34, 125, 44, 36, 123, 50, 61, 34, 34, 125, 44,
  36, 123, 51, 61, 49, 125, 10, 45, 105, 102, 32, 123, 33, 64, 35, 125,
  32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 118, 32, 45, 49, 10, 95, 110, 97, 109, 101, 61, 64, 123, 48, 44,
  98, 125, 10, 45, 105, 102, 32, 123, 64, 35, 62, 49, 125, 32, 45, 105,
  91, 49, 45, 45, 50, 93, 32, 40, 49, 48, 41, 32, 45, 101, 110, 100,
  105, 102, 32, 45, 97, 32, 121, 32, 45, 109, 32, 64, 123, 45, 49, 44,
  116, 125, 32, 45, 115, 32, 45, 44, 49, 48, 10, 45, 95, 100, 111, 99,
  117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 104, 101, 97, 100, 101,
  114, 95, 36, 49, 91, 93, 32, 36, 51, 10, 95, 115, 117, 98, 115, 101,
  99, 116, 105, 111, 110, 61, 48, 10, 95, 101, 120, 97, 109, 112, 108, 101,
  61, 48, 10, 95, 99, 111, 109, 109, 97, 110, 100, 61, 48, 10, 95, 112,
  97, 116, 104, 61, 34, 36, 50, 34, 10, 107, 115, 48, 61, 34, 48, 34,
  32, 107, 115, 49, 61, 34, 45, 107, 91, 48, 93, 34, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45,
  105, 102, 32, 123, 104, 62, 55, 34, 32, 38, 38, 32, 34, 123, 64, 123,
  45, 49, 44, 48, 45, 53, 125, 39, 61, 61, 39, 123, 39, 34, 35, 64,
  103, 109, 105, 99, 34, 39, 125, 125, 34, 32, 38, 38, 32, 34, 40, 105,
  91, 54, 93, 61, 61, 123, 39, 34, 32, 34, 39, 125, 34, 32, 124, 124,
  32, 34, 105, 91, 54, 93, 61, 61, 123, 39, 58, 39, 125, 41, 125, 10,
  45, 114, 111, 119, 115, 32, 55, 44, 49, 48, 48, 37, 32, 45, 97, 117,
  116, 111, 99, 114, 111, 112, 32, 123, 39, 34, 32, 34, 39, 125, 10, 45,
  105, 102, 32, 123, 105, 33, 61, 123, 39, 58, 39, 125, 125, 10, 95, 99,
  111, 109, 109, 97, 110, 100, 61, 123, 36, 95, 99, 111, 109, 109, 97, 110,
  100, 43, 49, 125, 10, 45, 115, 32, 45, 44, 123, 39, 34, 58, 32, 34,
  39, 125, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 123, 39, 34,
  32, 34, 39, 125, 10, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95,
  103, 109, 105, 99, 95, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110,
  95, 36, 49, 10, 45, 101, 108, 115, 101, 10, 45, 114, 111, 119, 115, 32,
  49, 44, 49, 48, 48, 37, 10, 45, 105, 102, 32, 123, 105, 61, 61, 123,
  39, 58, 39, 125, 125, 10, 95, 115, 117, 98, 115, 101, 99, 116, 105, 111,
  110, 61, 123, 36, 95, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 43,
  49, 125, 10, 45, 114, 111, 119, 115, 32, 49, 44, 49, 48, 48, 37, 32,
  45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 123, 39, 34, 32, 34, 39,
  125, 10, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105,
  99, 95, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 95, 36, 49, 10,
  45, 101, 108, 115, 101, 10, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32,
  123, 39, 34, 32, 34, 39, 125, 10, 45, 105, 102, 32, 123, 105, 61, 61,
  123, 39, 36, 39, 125, 125, 10, 95, 101, 120, 97, 109, 112, 108, 101, 61,
  123, 36, 95, 101, 120, 97, 109, 112, 108, 101, 43, 49, 125, 10, 45, 114,
  111, 119, 115, 32, 49, 44, 49, 48, 48, 37, 32, 45, 97, 117, 116, 111,
  99, 114, 111, 112, 32, 123, 39, 34, 32, 34, 39, 125, 10, 95, 102, 105,
  108, 101, 110, 97, 109, 101, 61, 36, 95, 112, 97, 116, 104, 36, 95, 110,
  97, 109, 101, 36, 95, 101, 120, 97, 109, 112, 108, 101, 46, 106, 112, 103,
  10, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99,
  95, 101, 120, 97, 109, 112, 108, 101, 95, 36, 49, 10, 45, 101, 108, 115,
  101, 10, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105,
  99, 95, 100, 101, 115, 99, 114, 105, 112, 116, 105, 111, 110, 95, 36, 49,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 32, 36, 123, 107,
  115, 123, 64, 35, 33, 61, 48, 125, 125, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 45, 114, 109, 10, 45, 95, 100, 111, 99, 117,
  109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 102, 111, 111, 116, 101, 114,
  95, 36, 49, 91, 93, 32, 36, 51, 10, 95, 100, 111, 99, 117, 109, 101,
  110, 116, 95, 103, 109, 105, 99, 95, 104, 101, 97, 100, 101, 114, 95, 104,
  116, 109, 108, 32, 58, 10, 45, 105, 102, 32, 36, 49, 32, 45, 118, 32,
  43, 32, 45, 101, 91, 93, 32, 34, 60, 33, 68, 79, 67, 84, 89, 80,
  69, 32, 104, 116, 109, 108, 32, 80, 85, 66, 76, 73, 67, 32, 92, 34,
  45, 47, 47, 87, 51, 67, 47, 47, 68, 84, 68, 32, 88, 72, 84, 77,
  76, 32, 49, 46, 48, 32, 84, 114, 97, 110, 115, 105, 116, 105, 111, 110,
  97, 108, 47, 47, 69, 78, 92, 34, 32, 92, 34, 104, 116, 116, 112, 58,
  47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 84, 82, 47,
  120, 104, 116, 109, 108, 49, 47, 68, 84, 68, 47, 120, 104, 116, 109, 108,
  49, 45, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 97, 108, 46, 100,
  116, 100, 92, 34, 62, 10, 92, 110, 60, 104, 101, 97, 100, 62, 10, 92,
  110, 60, 115, 99, 114, 105, 112, 116, 32, 116, 121, 112, 101, 61, 92, 34,
  116, 101, 120, 116, 47, 106, 97, 118, 97, 115, 99, 114, 105, 112, 116, 92,
  34, 32, 115, 114, 99, 61, 92, 34, 104, 105, 103, 104, 115, 108, 105, 100,
  101, 47, 104, 105, 103, 104, 115, 108, 105, 100, 101, 46, 106, 115, 92, 34,
  62, 60, 47, 115, 99, 114, 105, 112, 116, 62, 10, 92, 110, 60, 108, 105,
  110, 107, 32, 114, 101, 108, 61, 92, 34, 115, 116, 121, 108, 101, 115, 104,
  101, 101, 116, 92, 34, 32, 116, 121, 112, 101, 61, 92, 34, 116, 101, 120,
  116, 47, 99, 115, 115, 92, 34, 32, 104, 114, 101, 102, 61, 92, 34, 104,
  105, 103, 104, 115, 108, 105, 100, 101, 47, 104, 105, 103, 104, 115, 108, 105,
  100, 101, 46, 99, 115, 115, 92, 34, 32, 47, 62, 10, 92, 110, 60, 115,
  99, 114, 105, 112, 116, 32, 116, 121, 112, 101, 61, 92, 34, 116, 101, 120,
  116, 47, 106, 97, 118, 97, 115, 99, 114, 105, 112, 116, 92, 34, 62, 10,
  92, 110, 104, 115, 46, 103, 114, 97, 112, 104, 105, 99, 115, 68, 105, 114,
  32, 61, 32, 39, 104, 105, 103, 104, 115, 108, 105, 100, 101, 47, 103, 114,
  97, 112, 104, 105, 99, 115, 47, 39, 59, 10, 92, 110, 104, 115, 46, 119,
  114, 97, 112, 112, 101, 114, 67, 108, 97, 115, 115, 78, 97, 109, 101, 32,
  61, 32, 39, 119, 105, 100, 101, 45, 98, 111, 114, 100, 101, 114, 39, 59,
  10, 92, 110, 60, 47, 115, 99, 114, 105, 112, 116, 62, 10, 92, 110, 60,
  47, 104, 101, 97, 100, 62, 10, 92, 110, 60, 98, 111, 100, 121, 62, 10,
  92, 110, 34, 10, 45, 118, 32, 45, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 109, 32, 34, 100, 111, 110, 32, 58, 32, 45, 95, 100, 111, 99, 117,
  109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 100, 101, 115, 99, 95, 111,
  110, 95, 104, 116, 109, 108, 34, 10, 45, 109, 32, 34, 100, 111, 102, 102,
  32, 58, 32, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109,
  105, 99, 95, 100, 101, 115, 99, 95, 111, 102, 102, 95, 104, 116, 109, 108,
  34, 10, 45, 109, 32, 34, 101, 111, 110, 32, 58, 32, 45, 95, 100, 111,
  99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 101, 120, 95, 111,
  110, 95, 104, 116, 109, 108, 34, 10, 45, 109, 32, 34, 101, 111, 102, 102,
  32, 58, 32, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109,
  105, 99, 95, 101, 120, 95, 111, 102, 102, 95, 104, 116, 109, 108, 34, 10,
  95, 105, 115, 95, 100, 101, 115, 99, 61, 48, 10, 95, 105, 115, 95, 101,
  120, 61, 48, 10, 95, 115, 104, 111, 114, 116, 99, 117, 116, 61, 48, 10,
  95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 100,
  101, 115, 99, 95, 111, 110, 95, 104, 116, 109, 108, 32, 58, 10, 45, 118,
  32, 45, 10, 45, 105, 102, 32, 36, 95, 105, 115, 95, 100, 101, 115, 99,
  10, 45, 117, 32, 34, 60, 98, 114, 47, 62, 34, 10, 45, 101, 108, 115,
  101, 10, 45, 117, 32, 34, 60, 112, 32, 115, 116, 121, 108, 101, 61, 92,
  34, 109, 97, 114, 103, 105, 110, 45, 108, 101, 102, 116, 58, 49, 48, 48,
  112, 120, 92, 34, 62, 60, 116, 116, 62, 34, 10, 95, 105, 115, 95, 100,
  101, 115, 99, 61, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32,
  43, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99,
  95, 100, 101, 115, 99, 95, 111, 102, 102, 95, 104, 116, 109, 108, 32, 58,
  10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 36, 95, 105, 115, 95, 100,
  101, 115, 99, 10, 45, 117, 32, 34, 60, 47, 116, 116, 62, 60, 47, 112,
  62, 34, 10, 95, 105, 115, 95, 100, 101, 115, 99, 61, 48, 10, 45, 101,
  108, 115, 101, 32, 45, 117, 32, 34, 34, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 118, 32, 43, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95,
  103, 109, 105, 99, 95, 101, 120, 95, 111, 110, 95, 104, 116, 109, 108, 32,
  58, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 36, 95, 105, 115, 95,
  101, 120, 10, 45, 117, 32, 34, 34, 10, 45, 101, 108, 115, 101, 10, 45,
  117, 32, 34, 60, 98, 114, 47, 62, 60, 116, 97, 98, 108, 101, 32, 115,
  116, 121, 108, 101, 61, 92, 34, 109, 97, 114, 103, 105, 110, 45, 108, 101,
  102, 116, 58, 49, 48, 48, 112, 120, 92, 34, 32, 119, 105, 100, 116, 104,
  61, 92, 34, 55, 53, 37, 92, 34, 32, 98, 103, 99, 111, 108, 111, 114,
  61, 92, 34, 35, 69, 69, 69, 69, 69, 69, 92, 34, 32, 98, 111, 114,
  100, 101, 114, 99, 111, 108, 111, 114, 61, 92, 34, 98, 108, 97, 99, 107,
  92, 34, 32, 98, 111, 114, 100, 101, 114, 61, 92, 34, 49, 92, 34, 32,
  99, 101, 108, 108, 112, 97, 100, 100, 105, 110, 103, 61, 92, 34, 52, 92,
  34, 32, 99, 101, 108, 108, 115, 112, 97, 99, 105, 110, 103, 61, 92, 34,
  48, 92, 34, 62, 34, 92, 10, 34, 60, 116, 114, 62, 60, 116, 100, 32,
  99, 111, 108, 115, 112, 97, 110, 61, 92, 34, 50, 92, 34, 32, 98, 103,
  99, 111, 108, 111, 114, 61, 92, 34, 35, 55, 55, 55, 55, 55, 55, 92,
  34, 62, 60, 102, 111, 110, 116, 32, 99, 111, 108, 111, 114, 61, 92, 34,
  119, 104, 105, 116, 101, 92, 34, 62, 60, 98, 62, 69, 120, 97, 109, 112,
  108, 101, 40, 115, 41, 32, 111, 102, 32, 117, 115, 101, 58, 60, 47, 98,
  62, 60, 47, 102, 111, 110, 116, 62, 60, 47, 116, 100, 62, 60, 47, 116,
  114, 62, 34, 10, 95, 105, 115, 95, 101, 120, 61, 49, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 118, 32, 43, 10, 95, 100, 111, 99, 117, 109, 101,
  110, 116, 95, 103, 109, 105, 99, 95, 101, 120, 95, 111, 102, 102, 95, 104,
  116, 109, 108, 32, 58, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 36,
  95, 105, 115, 95, 101, 120, 10, 45, 117, 32, 34, 60, 47, 116, 97, 98,
  108, 101, 62, 34, 10, 95, 105, 115, 95, 101, 120, 61, 48, 10, 45, 101,
  108, 115, 101, 10, 45, 117, 32, 34, 34, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 118, 32, 43, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95,
  103, 109, 105, 99, 95, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 95,
  104, 116, 109, 108, 32, 58, 10, 45, 118, 32, 43, 10, 45, 101, 91, 93,
  32, 64, 123, 45, 101, 111, 102, 102, 125, 64, 123, 45, 100, 111, 102, 102,
  125, 34, 60, 98, 114, 47, 62, 60, 104, 51, 62, 60, 97, 32, 105, 100,
  61, 92, 34, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 34, 36, 95,
  115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 34, 92, 34, 62, 60, 102,
  111, 110, 116, 32, 99, 111, 108, 111, 114, 61, 92, 34, 112, 117, 114, 112,
  108, 101, 92, 34, 62, 42, 42, 32, 60, 117, 62, 34, 64, 123, 48, 44,
  116, 125, 34, 60, 47, 117, 62, 60, 47, 102, 111, 110, 116, 62, 60, 47,
  97, 62, 34, 92, 10, 34, 38, 110, 98, 115, 112, 59, 38, 110, 98, 115,
  112, 59, 60, 97, 32, 104, 114, 101, 102, 61, 92, 34, 35, 116, 111, 99,
  92, 34, 62, 60, 105, 109, 103, 32, 115, 114, 99, 61, 92, 34, 105, 109,
  103, 47, 98, 97, 99, 107, 95, 116, 111, 112, 46, 112, 110, 103, 92, 34,
  62, 60, 47, 105, 109, 103, 62, 60, 47, 97, 62, 60, 47, 104, 51, 62,
  34, 10, 45, 118, 32, 45, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116,
  95, 103, 109, 105, 99, 95, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111,
  110, 95, 104, 116, 109, 108, 32, 58, 10, 45, 105, 102, 32, 123, 123, 64,
  123, 45, 49, 44, 116, 125, 39, 61, 61, 39, 34, 40, 42, 41, 34, 125,
  34, 32, 124, 124, 32, 34, 123, 64, 123, 45, 49, 44, 116, 125, 39, 61,
  61, 39, 34, 40, 43, 41, 34, 125, 125, 32, 113, 117, 97, 108, 105, 102,
  105, 101, 114, 61, 34, 32, 34, 64, 123, 45, 49, 44, 116, 125, 32, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 101, 108, 115, 101, 32, 113, 117, 97,
  108, 105, 102, 105, 101, 114, 61, 34, 34, 32, 45, 101, 110, 100, 105, 102,
  10, 115, 49, 61, 34, 92, 110, 34, 32, 115, 48, 61, 34, 32, 124, 60,
  98, 114, 47, 62, 34, 10, 45, 105, 102, 32, 123, 64, 35, 62, 49, 34,
  32, 38, 38, 32, 34, 123, 64, 123, 45, 49, 44, 48, 45, 54, 125, 39,
  61, 61, 39, 123, 39, 34, 101, 113, 46, 32, 116, 111, 32, 34, 39, 125,
  125, 125, 10, 45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 55, 44, 49,
  48, 48, 37, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49,
  93, 32, 123, 39, 46, 39, 125, 32, 45, 97, 117, 116, 111, 99, 114, 111,
  112, 91, 45, 49, 93, 32, 123, 39, 34, 32, 34, 39, 125, 32, 45, 97,
  117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 51, 57, 10, 95,
  115, 104, 111, 114, 116, 99, 117, 116, 36, 95, 115, 104, 111, 114, 116, 99,
  117, 116, 61, 64, 123, 48, 44, 116, 125, 10, 95, 115, 104, 111, 114, 116,
  99, 117, 116, 108, 105, 110, 107, 36, 95, 115, 104, 111, 114, 116, 99, 117,
  116, 61, 64, 123, 45, 49, 44, 116, 125, 10, 95, 115, 104, 111, 114, 116,
  99, 117, 116, 113, 117, 97, 108, 105, 102, 105, 101, 114, 36, 95, 115, 104,
  111, 114, 116, 99, 117, 116, 61, 36, 113, 117, 97, 108, 105, 102, 105, 101,
  114, 10, 95, 115, 104, 111, 114, 116, 99, 117, 116, 61, 123, 36, 95, 115,
  104, 111, 114, 116, 99, 117, 116, 43, 49, 125, 10, 45, 101, 108, 115, 101,
  10, 45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 64, 123, 45, 101, 111,
  102, 102, 125, 64, 123, 45, 100, 111, 102, 102, 125, 34, 60, 112, 32, 115,
  116, 121, 108, 101, 61, 92, 34, 109, 97, 114, 103, 105, 110, 45, 108, 101,
  102, 116, 58, 50, 48, 112, 120, 92, 34, 62, 60, 102, 111, 110, 116, 32,
  99, 111, 108, 111, 114, 61, 92, 34, 103, 114, 101, 101, 110, 92, 34, 62,
  38, 110, 98, 115, 112, 59, 38, 110, 98, 115, 112, 59, 60, 98, 62, 45,
  34, 64, 123, 48, 44, 116, 125, 36, 113, 117, 97, 108, 105, 102, 105, 101,
  114, 34, 60, 47, 98, 62, 58, 60, 47, 102, 111, 110, 116, 62, 34, 10,
  45, 105, 102, 32, 123, 64, 35, 62, 49, 125, 10, 45, 101, 91, 93, 32,
  34, 60, 112, 32, 115, 116, 121, 108, 101, 61, 92, 34, 109, 97, 114, 103,
  105, 110, 45, 108, 101, 102, 116, 58, 49, 53, 48, 112, 120, 92, 34, 62,
  60, 116, 116, 62, 60, 105, 62, 60, 102, 111, 110, 116, 32, 99, 111, 108,
  111, 114, 61, 92, 34, 112, 117, 114, 112, 108, 101, 92, 34, 62, 34, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 10, 45,
  101, 91, 93, 32, 64, 123, 123, 49, 43, 36, 62, 125, 44, 116, 125, 36,
  123, 115, 123, 36, 60, 61, 61, 48, 125, 125, 10, 45, 100, 111, 110, 101,
  10, 45, 101, 91, 93, 32, 34, 60, 47, 102, 111, 110, 116, 62, 60, 47,
  105, 62, 60, 47, 116, 116, 62, 60, 47, 112, 62, 34, 10, 45, 101, 108,
  115, 101, 32, 45, 101, 91, 93, 32, 34, 34, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 118, 32, 45, 10, 45, 101, 110, 100, 105, 102, 10, 95, 100,
  111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 100, 101, 115,
  99, 114, 105, 112, 116, 105, 111, 110, 95, 104, 116, 109, 108, 32, 58, 10,
  45, 105, 102, 32, 123, 64, 123, 45, 49, 44, 48, 45, 49, 50, 125, 39,
  61, 61, 39, 123, 39, 34, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97,
  108, 117, 101, 34, 39, 125, 125, 10, 45, 115, 32, 43, 44, 123, 39, 58,
  39, 125, 32, 45, 108, 91, 94, 48, 93, 32, 45, 97, 32, 121, 32, 45,
  101, 110, 100, 108, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 123,
  39, 58, 39, 125, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 123,
  39, 34, 32, 34, 39, 125, 10, 45, 118, 32, 43, 10, 45, 105, 102, 32,
  123, 64, 35, 62, 49, 125, 32, 45, 101, 91, 93, 32, 64, 123, 45, 100,
  111, 110, 125, 34, 60, 98, 114, 47, 62, 60, 98, 62, 34, 64, 123, 48,
  44, 116, 125, 34, 60, 47, 98, 62, 58, 32, 34, 64, 123, 45, 49, 44,
  116, 125, 10, 45, 101, 108, 115, 101, 32, 45, 101, 91, 93, 32, 64, 123,
  45, 100, 111, 110, 125, 34, 60, 98, 114, 47, 62, 34, 64, 123, 48, 44,
  116, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 10, 45,
  101, 108, 105, 102, 32, 123, 64, 123, 45, 49, 44, 48, 45, 55, 125, 39,
  61, 61, 39, 123, 39, 34, 40, 101, 113, 46, 32, 116, 111, 32, 34, 39,
  125, 125, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 64, 123, 45,
  100, 111, 110, 125, 34, 60, 105, 62, 60, 102, 111, 110, 116, 32, 99, 111,
  108, 111, 114, 61, 92, 34, 98, 108, 117, 101, 92, 34, 62, 34, 64, 123,
  45, 49, 44, 116, 125, 34, 60, 47, 102, 111, 110, 116, 62, 60, 47, 105,
  62, 34, 32, 45, 118, 32, 45, 10, 45, 101, 108, 115, 101, 10, 45, 105,
  102, 32, 123, 40, 105, 60, 123, 39, 65, 39, 125, 34, 32, 124, 124, 32,
  34, 105, 62, 123, 39, 90, 39, 125, 41, 34, 32, 38, 38, 32, 34, 105,
  33, 61, 52, 48, 34, 32, 38, 38, 32, 34, 105, 33, 61, 51, 57, 125,
  32, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 64, 123, 45, 100, 111,
  110, 125, 34, 38, 110, 98, 115, 112, 59, 34, 64, 123, 45, 49, 44, 116,
  125, 32, 45, 118, 32, 45, 10, 45, 101, 108, 115, 101, 32, 45, 118, 32,
  43, 32, 45, 101, 91, 93, 32, 64, 123, 45, 100, 111, 110, 125, 64, 123,
  45, 49, 44, 116, 125, 32, 45, 118, 32, 45, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 105, 102, 10, 95, 100, 111, 99, 117, 109, 101,
  110, 116, 95, 103, 109, 105, 99, 95, 101, 120, 97, 109, 112, 108, 101, 95,
  104, 116, 109, 108, 32, 58, 10, 45, 105, 102, 32, 36, 95, 102, 105, 108,
  101, 110, 97, 109, 101, 32, 45, 101, 108, 115, 101, 10, 45, 109, 32, 34,
  102, 111, 111, 32, 58, 32, 34, 64, 123, 45, 49, 44, 116, 125, 10, 45,
  108, 91, 93, 32, 45, 118, 32, 45, 57, 57, 32, 45, 114, 101, 115, 101,
  116, 32, 45, 102, 111, 111, 32, 45, 118, 32, 45, 49, 32, 45, 95, 100,
  111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 32, 45, 111, 32,
  36, 95, 102, 105, 108, 101, 110, 97, 109, 101, 44, 56, 53, 32, 45, 114,
  109, 32, 45, 101, 110, 100, 108, 10, 45, 117, 110, 99, 111, 109, 109, 97,
  110, 100, 32, 102, 111, 111, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118,
  32, 43, 10, 45, 101, 91, 93, 32, 64, 123, 45, 101, 111, 110, 125, 34,
  60, 116, 114, 62, 60, 116, 100, 32, 119, 105, 100, 116, 104, 61, 92, 34,
  52, 48, 92, 34, 62, 60, 100, 105, 118, 62, 60, 97, 32, 104, 114, 101,
  102, 61, 92, 34, 34, 36, 95, 102, 105, 108, 101, 110, 97, 109, 101, 34,
  92, 34, 32, 99, 108, 97, 115, 115, 61, 92, 34, 104, 105, 103, 104, 115,
  108, 105, 100, 101, 92, 34, 32, 111, 110, 99, 108, 105, 99, 107, 61, 92,
  34, 114, 101, 116, 117, 114, 110, 32, 104, 115, 46, 101, 120, 112, 97, 110,
  100, 40, 116, 104, 105, 115, 41, 92, 34, 62, 34, 92, 10, 34, 60, 102,
  111, 110, 116, 32, 99, 111, 108, 111, 114, 61, 92, 34, 98, 108, 117, 101,
  92, 34, 62, 40, 118, 105, 101, 119, 41, 60, 47, 102, 111, 110, 116, 62,
  60, 47, 97, 62, 60, 100, 105, 118, 32, 99, 108, 97, 115, 115, 61, 92,
  34, 104, 105, 103, 104, 115, 108, 105, 100, 101, 45, 99, 97, 112, 116, 105,
  111, 110, 92, 34, 62, 34, 64, 123, 45, 49, 44, 116, 125, 34, 60, 47,
  100, 105, 118, 62, 60, 47, 100, 105, 118, 62, 60, 47, 116, 100, 62, 60,
  116, 100, 62, 60, 116, 116, 62, 34, 64, 123, 45, 49, 44, 116, 125, 34,
  60, 47, 116, 116, 62, 60, 47, 116, 100, 62, 60, 47, 116, 114, 62, 34,
  10, 45, 118, 32, 45, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95,
  103, 109, 105, 99, 95, 102, 111, 111, 116, 101, 114, 95, 104, 116, 109, 108,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 49, 10, 45, 105, 102, 32,
  36, 95, 115, 104, 111, 114, 116, 99, 117, 116, 10, 95, 115, 117, 98, 115,
  101, 99, 116, 105, 111, 110, 61, 123, 36, 95, 115, 117, 98, 115, 101, 99,
  116, 105, 111, 110, 43, 49, 125, 10, 40, 123, 39, 34, 67, 111, 109, 109,
  97, 110, 100, 115, 32, 115, 104, 111, 114, 116, 99, 117, 116, 115, 34, 39,
  125, 41, 32, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109,
  105, 99, 95, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 95, 104, 116,
  109, 108, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 60, 112, 32, 115, 116, 121,
  108, 101, 61, 92, 34, 109, 97, 114, 103, 105, 110, 45, 108, 101, 102, 116,
  58, 50, 48, 112, 120, 92, 34, 62, 34, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 36, 95, 115, 104, 111, 114, 116, 99, 117, 116, 10, 45, 101, 91,
  93, 32, 34, 60, 102, 111, 110, 116, 32, 99, 111, 108, 111, 114, 61, 92,
  34, 103, 114, 101, 101, 110, 92, 34, 62, 60, 98, 62, 38, 110, 98, 115,
  112, 59, 38, 110, 98, 115, 112, 59, 45, 34, 36, 123, 95, 115, 104, 111,
  114, 116, 99, 117, 116, 36, 62, 125, 34, 32, 34, 36, 123, 95, 115, 104,
  111, 114, 116, 99, 117, 116, 113, 117, 97, 108, 105, 102, 105, 101, 114, 36,
  62, 125, 34, 60, 47, 98, 62, 58, 60, 47, 102, 111, 110, 116, 62, 34,
  10, 45, 101, 91, 93, 32, 34, 60, 102, 111, 110, 116, 32, 99, 111, 108,
  111, 114, 61, 92, 34, 98, 108, 117, 101, 92, 34, 62, 60, 105, 62, 101,
  113, 46, 32, 116, 111, 32, 39, 34, 36, 123, 95, 115, 104, 111, 114, 116,
  99, 117, 116, 108, 105, 110, 107, 36, 62, 125, 34, 39, 60, 47, 105, 62,
  60, 47, 102, 111, 110, 116, 62, 60, 98, 114, 47, 62, 34, 10, 45, 100,
  111, 110, 101, 10, 45, 101, 91, 93, 32, 34, 60, 47, 112, 62, 34, 32,
  45, 118, 32, 45, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43,
  10, 45, 101, 91, 93, 32, 64, 123, 45, 101, 111, 102, 102, 125, 64, 123,
  45, 100, 111, 102, 102, 125, 34, 60, 112, 32, 115, 116, 121, 108, 101, 61,
  92, 34, 109, 97, 114, 103, 105, 110, 45, 108, 101, 102, 116, 58, 49, 48,
  48, 112, 120, 92, 34, 62, 60, 102, 111, 110, 116, 32, 99, 111, 108, 111,
  114, 61, 92, 34, 98, 108, 117, 101, 92, 34, 62, 60, 98, 62, 91, 32,
  84, 111, 116, 97, 108, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32,
  99, 111, 109, 109, 97, 110, 100, 115, 58, 32, 34, 36, 95, 99, 111, 109,
  109, 97, 110, 100, 34, 32, 93, 60, 47, 98, 62, 60, 47, 102, 111, 110,
  116, 62, 34, 10, 45, 118, 32, 45, 10, 45, 117, 110, 99, 111, 109, 109,
  97, 110, 100, 32, 100, 111, 110, 10, 45, 117, 110, 99, 111, 109, 109, 97,
  110, 100, 32, 100, 111, 102, 102, 10, 45, 117, 110, 99, 111, 109, 109, 97,
  110, 100, 32, 101, 111, 110, 10, 45, 117, 110, 99, 111, 109, 109, 97, 110,
  100, 32, 101, 111, 102, 102, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116,
  95, 103, 109, 105, 99, 95, 104, 101, 97, 100, 101, 114, 95, 120, 109, 108,
  32, 58, 10, 45, 105, 102, 32, 36, 49, 32, 45, 118, 32, 43, 10, 45,
  101, 91, 93, 32, 34, 60, 63, 120, 109, 108, 32, 118, 101, 114, 115, 105,
  111, 110, 61, 92, 34, 49, 46, 48, 92, 34, 32, 101, 110, 99, 111, 100,
  105, 110, 103, 61, 92, 34, 85, 84, 70, 45, 56, 92, 34, 32, 115, 116,
  97, 110, 100, 97, 108, 111, 110, 101, 61, 92, 34, 121, 101, 115, 92, 34,
  63, 62, 10, 92, 110, 60, 63, 120, 109, 108, 45, 115, 116, 121, 108, 101,
  115, 104, 101, 101, 116, 32, 104, 114, 101, 102, 61, 92, 34, 103, 109, 105,
  99, 95, 100, 111, 99, 46, 120, 115, 108, 92, 34, 32, 116, 121, 112, 101,
  61, 92, 34, 116, 101, 120, 116, 47, 120, 115, 108, 92, 34, 63, 62, 34,
  10, 45, 118, 32, 45, 32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32,
  43, 10, 45, 101, 91, 93, 32, 34, 60, 103, 109, 105, 99, 45, 112, 97,
  99, 107, 97, 103, 101, 32, 120, 109, 108, 110, 115, 58, 120, 115, 105, 61,
  92, 34, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46,
  111, 114, 103, 47, 50, 48, 48, 49, 47, 88, 77, 76, 83, 99, 104, 101,
  109, 97, 45, 105, 110, 115, 116, 97, 110, 99, 101, 92, 34, 32, 120, 115,
  105, 58, 110, 111, 78, 97, 109, 101, 115, 112, 97, 99, 101, 83, 99, 104,
  101, 109, 97, 76, 111, 99, 97, 116, 105, 111, 110, 61, 92, 34, 103, 109,
  105, 99, 95, 100, 111, 99, 46, 120, 115, 100, 92, 34, 62, 10, 92, 110,
  60, 110, 97, 109, 101, 62, 34, 36, 95, 110, 97, 109, 101, 34, 60, 47,
  110, 97, 109, 101, 62, 10, 92, 110, 60, 115, 101, 99, 116, 105, 111, 110,
  62, 10, 92, 110, 32, 32, 60, 110, 97, 109, 101, 62, 76, 105, 115, 116,
  32, 111, 102, 32, 99, 111, 109, 109, 97, 110, 100, 115, 60, 47, 110, 97,
  109, 101, 62, 34, 10, 45, 118, 32, 45, 10, 45, 109, 32, 34, 100, 111,
  110, 32, 58, 32, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103,
  109, 105, 99, 95, 100, 101, 115, 99, 95, 111, 110, 95, 120, 109, 108, 34,
  10, 45, 109, 32, 34, 100, 111, 102, 102, 32, 58, 32, 45, 95, 100, 111,
  99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 100, 101, 115, 99,
  95, 111, 102, 102, 95, 120, 109, 108, 34, 10, 95, 105, 115, 95, 115, 117,
  98, 115, 101, 99, 116, 105, 111, 110, 61, 48, 10, 95, 105, 115, 95, 99,
  111, 109, 109, 97, 110, 100, 61, 48, 10, 95, 105, 115, 95, 100, 101, 115,
  99, 61, 48, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109,
  105, 99, 95, 100, 101, 115, 99, 95, 111, 110, 95, 120, 109, 108, 32, 58,
  10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 36, 95, 105, 115, 95, 100,
  101, 115, 99, 10, 45, 117, 32, 34, 34, 10, 45, 101, 108, 115, 101, 10,
  45, 117, 32, 34, 32, 32, 32, 32, 60, 100, 101, 115, 99, 114, 105, 112,
  116, 105, 111, 110, 62, 92, 110, 34, 10, 95, 105, 115, 95, 100, 101, 115,
  99, 61, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10,
  95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 100,
  101, 115, 99, 95, 111, 102, 102, 95, 120, 109, 108, 32, 58, 10, 45, 118,
  32, 45, 10, 45, 105, 102, 32, 36, 95, 105, 115, 95, 100, 101, 115, 99,
  10, 45, 117, 32, 34, 32, 32, 32, 32, 60, 47, 100, 101, 115, 99, 114,
  105, 112, 116, 105, 111, 110, 62, 92, 110, 34, 10, 95, 105, 115, 95, 100,
  101, 115, 99, 61, 48, 10, 45, 101, 108, 115, 101, 32, 45, 117, 32, 34,
  34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 95, 100,
  111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 115, 117, 98,
  115, 101, 99, 116, 105, 111, 110, 95, 120, 109, 108, 32, 58, 10, 45, 118,
  32, 43, 10, 45, 105, 102, 32, 36, 95, 105, 115, 95, 115, 117, 98, 115,
  101, 99, 116, 105, 111, 110, 10, 45, 105, 102, 32, 36, 95, 105, 115, 95,
  99, 111, 109, 109, 97, 110, 100, 32, 45, 101, 91, 93, 32, 64, 123, 45,
  100, 111, 102, 102, 125, 34, 32, 32, 60, 47, 102, 117, 110, 99, 116, 105,
  111, 110, 62, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 91, 93,
  32, 64, 123, 45, 100, 111, 102, 102, 125, 34, 60, 47, 115, 117, 98, 115,
  101, 99, 116, 105, 111, 110, 62, 34, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 91, 93, 32, 64, 123, 45, 100, 111, 102, 102, 125, 34, 60, 115,
  117, 98, 115, 101, 99, 116, 105, 111, 110, 62, 10, 92, 110, 32, 32, 60,
  110, 97, 109, 101, 62, 34, 64, 123, 48, 44, 116, 125, 34, 60, 47, 110,
  97, 109, 101, 62, 34, 10, 45, 118, 32, 45, 10, 95, 105, 115, 95, 115,
  117, 98, 115, 101, 99, 116, 105, 111, 110, 61, 49, 10, 95, 105, 115, 95,
  99, 111, 109, 109, 97, 110, 100, 61, 48, 10, 95, 100, 111, 99, 117, 109,
  101, 110, 116, 95, 103, 109, 105, 99, 95, 100, 101, 99, 108, 97, 114, 97,
  116, 105, 111, 110, 95, 120, 109, 108, 32, 58, 10, 45, 95, 100, 111, 99,
  117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 114, 101, 112, 108, 97,
  99, 101, 95, 120, 109, 108, 10, 45, 118, 32, 43, 10, 45, 105, 102, 32,
  36, 95, 105, 115, 95, 99, 111, 109, 109, 97, 110, 100, 32, 45, 101, 91,
  93, 32, 64, 123, 45, 100, 111, 102, 102, 125, 34, 32, 32, 60, 47, 102,
  117, 110, 99, 116, 105, 111, 110, 62, 34, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 91, 93, 32, 64, 123, 45, 100, 111, 102, 102, 125, 34, 32,
  32, 60, 102, 117, 110, 99, 116, 105, 111, 110, 62, 34, 10, 45, 118, 32,
  45, 10, 95, 105, 115, 95, 99, 111, 109, 109, 97, 110, 100, 61, 49, 10,
  45, 105, 102, 32, 123, 123, 64, 123, 45, 49, 44, 116, 125, 39, 61, 61,
  39, 34, 40, 42, 41, 34, 125, 34, 32, 124, 124, 32, 34, 123, 64, 123,
  45, 49, 44, 116, 125, 39, 61, 61, 39, 34, 40, 43, 41, 34, 125, 125,
  32, 113, 117, 97, 108, 105, 102, 105, 101, 114, 61, 34, 32, 34, 64, 123,
  45, 49, 44, 116, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101,
  108, 115, 101, 32, 113, 117, 97, 108, 105, 102, 105, 101, 114, 61, 34, 34,
  32, 45, 101, 110, 100, 105, 102, 10, 115, 49, 61, 34, 34, 32, 115, 48,
  61, 34, 32, 124, 34, 10, 45, 118, 32, 43, 10, 45, 101, 91, 93, 32,
  34, 32, 32, 32, 32, 60, 110, 97, 109, 101, 62, 34, 64, 123, 48, 44,
  116, 125, 34, 60, 47, 110, 97, 109, 101, 62, 34, 10, 45, 105, 102, 32,
  123, 64, 35, 62, 49, 125, 10, 45, 101, 91, 93, 32, 34, 32, 32, 32,
  32, 60, 97, 114, 103, 117, 109, 101, 110, 116, 115, 62, 34, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 10, 45, 101, 91,
  93, 32, 34, 32, 32, 32, 32, 32, 32, 34, 64, 123, 123, 49, 43, 36,
  62, 125, 44, 116, 125, 36, 123, 115, 123, 36, 60, 61, 61, 48, 125, 125,
  10, 45, 100, 111, 110, 101, 10, 45, 101, 91, 93, 32, 34, 32, 32, 32,
  32, 60, 47, 97, 114, 103, 117, 109, 101, 110, 116, 115, 62, 34, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 10, 95, 100, 111, 99, 117,
  109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 100, 101, 115, 99, 114, 105,
  112, 116, 105, 111, 110, 95, 120, 109, 108, 32, 58, 10, 45, 95, 100, 111,
  99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 114, 101, 112, 108,
  97, 99, 101, 95, 120, 109, 108, 10, 45, 118, 32, 43, 10, 45, 101, 91,
  93, 32, 64, 123, 45, 100, 111, 110, 125, 34, 32, 32, 32, 32, 32, 32,
  34, 64, 123, 48, 44, 116, 125, 10, 45, 118, 32, 45, 10, 95, 100, 111,
  99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 101, 120, 97, 109,
  112, 108, 101, 95, 120, 109, 108, 32, 58, 10, 45, 95, 100, 111, 99, 117,
  109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 114, 101, 112, 108, 97, 99,
  101, 95, 120, 109, 108, 10, 45, 105, 102, 32, 36, 95, 102, 105, 108, 101,
  110, 97, 109, 101, 32, 45, 101, 108, 115, 101, 10, 45, 109, 32, 34, 102,
  111, 111, 32, 58, 32, 34, 64, 123, 45, 49, 44, 116, 125, 10, 45, 108,
  91, 93, 32, 45, 118, 32, 45, 57, 57, 32, 45, 114, 101, 115, 101, 116,
  32, 45, 102, 111, 111, 32, 45, 118, 32, 45, 49, 32, 45, 95, 100, 111,
  99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 32, 45, 111, 32, 36,
  95, 102, 105, 108, 101, 110, 97, 109, 101, 44, 56, 53, 32, 45, 114, 109,
  32, 45, 101, 110, 100, 108, 10, 45, 117, 110, 99, 111, 109, 109, 97, 110,
  100, 32, 102, 111, 111, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32,
  43, 10, 45, 101, 91, 93, 32, 64, 123, 45, 100, 111, 102, 102, 125, 34,
  32, 32, 32, 32, 60, 101, 120, 97, 109, 112, 108, 101, 62, 34, 10, 45,
  101, 91, 93, 32, 34, 32, 32, 32, 32, 32, 32, 60, 99, 111, 109, 109,
  97, 110, 100, 62, 34, 64, 123, 48, 44, 116, 125, 34, 60, 47, 99, 111,
  109, 109, 97, 110, 100, 62, 34, 10, 45, 101, 91, 93, 32, 34, 32, 32,
  32, 32, 32, 32, 60, 114, 101, 115, 117, 108, 116, 62, 34, 36, 95, 102,
  105, 108, 101, 110, 97, 109, 101, 34, 60, 47, 114, 101, 115, 117, 108, 116,
  62, 34, 10, 45, 101, 91, 93, 32, 34, 32, 32, 32, 32, 60, 47, 101,
  120, 97, 109, 112, 108, 101, 62, 34, 10, 45, 118, 32, 45, 10, 95, 100,
  111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 102, 111, 111,
  116, 101, 114, 95, 120, 109, 108, 32, 58, 32, 45, 115, 107, 105, 112, 32,
  36, 49, 10, 45, 118, 32, 43, 10, 45, 105, 102, 32, 36, 95, 105, 115,
  95, 99, 111, 109, 109, 97, 110, 100, 32, 45, 101, 91, 93, 32, 64, 123,
  45, 100, 111, 102, 102, 125, 34, 60, 47, 102, 117, 110, 99, 116, 105, 111,
  110, 62, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36,
  95, 105, 115, 95, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 32, 45,
  101, 91, 93, 32, 64, 123, 45, 100, 111, 102, 102, 125, 34, 60, 47, 115,
  117, 98, 115, 101, 99, 116, 105, 111, 110, 62, 34, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 91, 93, 32, 64, 123, 45, 100, 111, 102, 102, 125,
  34, 60, 47, 115, 101, 99, 116, 105, 111, 110, 62, 10, 92, 110, 60, 47,
  103, 109, 105, 99, 45, 112, 97, 99, 107, 97, 103, 101, 62, 34, 10, 45,
  118, 32, 45, 10, 45, 117, 110, 99, 111, 109, 109, 97, 110, 100, 32, 100,
  111, 110, 10, 45, 117, 110, 99, 111, 109, 109, 97, 110, 100, 32, 100, 111,
  102, 102, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105,
  99, 95, 114, 101, 112, 108, 97, 99, 101, 95, 120, 109, 108, 32, 58, 10,
  45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 123, 39, 38,
  39, 125, 44, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 38,
  97, 109, 112, 59, 39, 125, 125, 10, 45, 114, 101, 112, 108, 97, 99, 101,
  95, 115, 101, 113, 32, 123, 39, 60, 39, 125, 44, 64, 123, 45, 113, 117,
  111, 116, 101, 92, 32, 123, 39, 38, 108, 116, 59, 39, 125, 125, 10, 45,
  114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 123, 39, 62, 39,
  125, 44, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 38, 103,
  116, 59, 39, 125, 125, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95,
  103, 109, 105, 99, 95, 104, 101, 97, 100, 101, 114, 95, 108, 97, 116, 101,
  120, 32, 58, 10, 45, 105, 102, 32, 36, 49, 32, 45, 118, 32, 43, 10,
  45, 101, 91, 93, 32, 34, 92, 92, 100, 111, 99, 117, 109, 101, 110, 116,
  99, 108, 97, 115, 115, 91, 97, 52, 112, 97, 112, 101, 114, 44, 49, 48,
  112, 116, 44, 116, 119, 111, 115, 105, 100, 101, 93, 123, 98, 111, 111, 107,
  125, 10, 92, 110, 92, 92, 117, 115, 101, 112, 97, 99, 107, 97, 103, 101,
  123, 104, 121, 112, 101, 114, 114, 101, 102, 44, 102, 97, 110, 99, 121, 104,
  100, 114, 44, 103, 114, 97, 112, 104, 105, 99, 120, 44, 97, 109, 115, 115,
  121, 109, 98, 44, 97, 109, 115, 109, 97, 116, 104, 44, 116, 105, 109, 101,
  115, 44, 109, 97, 107, 101, 105, 100, 120, 125, 10, 92, 110, 92, 92, 103,
  114, 97, 112, 104, 105, 99, 115, 112, 97, 116, 104, 123, 123, 34, 36, 95,
  112, 97, 116, 104, 34, 125, 125, 10, 92, 110, 92, 92, 112, 97, 103, 101,
  115, 116, 121, 108, 101, 123, 102, 97, 110, 99, 121, 112, 108, 97, 105, 110,
  125, 10, 92, 110, 92, 92, 108, 104, 101, 97, 100, 91, 92, 92, 102, 97,
  110, 99, 121, 112, 108, 97, 105, 110, 123, 125, 123, 92, 92, 116, 101, 120,
  116, 98, 102, 92, 92, 116, 104, 101, 112, 97, 103, 101, 125, 93, 123, 92,
  92, 102, 97, 110, 99, 121, 112, 108, 97, 105, 110, 123, 125, 123, 92, 92,
  114, 105, 103, 104, 116, 109, 97, 114, 107, 125, 125, 10, 92, 110, 92, 92,
  114, 104, 101, 97, 100, 91, 92, 92, 102, 97, 110, 99, 121, 112, 108, 97,
  105, 110, 123, 125, 123, 92, 92, 108, 101, 102, 116, 109, 97, 114, 107, 125,
  93, 123, 92, 92, 102, 97, 110, 99, 121, 112, 108, 97, 105, 110, 123, 125,
  123, 92, 92, 116, 101, 120, 116, 98, 102, 92, 92, 116, 104, 101, 112, 97,
  103, 101, 125, 125, 10, 92, 110, 92, 92, 99, 102, 111, 111, 116, 123, 125,
  10, 92, 110, 92, 92, 115, 101, 116, 108, 101, 110, 103, 116, 104, 123, 92,
  92, 116, 101, 120, 116, 119, 105, 100, 116, 104, 125, 123, 53, 46, 56, 55,
  53, 105, 110, 125, 10, 92, 110, 92, 92, 115, 101, 116, 108, 101, 110, 103,
  116, 104, 123, 92, 92, 112, 97, 114, 105, 110, 100, 101, 110, 116, 125, 123,
  48, 112, 99, 125, 10, 92, 110, 92, 92, 115, 101, 116, 108, 101, 110, 103,
  116, 104, 123, 92, 92, 104, 111, 102, 102, 115, 101, 116, 125, 123, 45, 48,
  46, 56, 99, 109, 125, 10, 92, 110, 92, 92, 115, 101, 116, 99, 111, 117,
  110, 116, 101, 114, 123, 116, 111, 99, 100, 101, 112, 116, 104, 125, 123, 49,
  125, 10, 92, 110, 92, 92, 115, 108, 111, 112, 112, 121, 123, 125, 10, 92,
  110, 92, 92, 114, 101, 110, 101, 119, 99, 111, 109, 109, 97, 110, 100, 92,
  92, 105, 110, 100, 101, 120, 110, 97, 109, 101, 123, 73, 110, 100, 101, 120,
  32, 111, 102, 32, 99, 111, 109, 109, 97, 110, 100, 115, 125, 10, 92, 110,
  92, 92, 109, 97, 107, 101, 105, 110, 100, 101, 120, 10, 92, 110, 92, 92,
  98, 101, 103, 105, 110, 123, 100, 111, 99, 117, 109, 101, 110, 116, 125, 10,
  92, 110, 92, 92, 116, 97, 98, 108, 101, 111, 102, 99, 111, 110, 116, 101,
  110, 116, 115, 34, 10, 45, 118, 32, 45, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 110, 92, 92,
  99, 104, 97, 112, 116, 101, 114, 123, 76, 105, 115, 116, 32, 111, 102, 32,
  99, 111, 109, 109, 97, 110, 100, 115, 125, 34, 32, 45, 118, 32, 45, 10,
  45, 109, 32, 34, 101, 111, 110, 32, 58, 32, 45, 95, 100, 111, 99, 117,
  109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 101, 120, 95, 111, 110, 95,
  108, 97, 116, 101, 120, 34, 10, 45, 109, 32, 34, 101, 111, 102, 102, 32,
  58, 32, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105,
  99, 95, 101, 120, 95, 111, 102, 102, 95, 108, 97, 116, 101, 120, 34, 10,
  95, 105, 115, 95, 100, 101, 115, 99, 61, 48, 10, 95, 105, 115, 95, 101,
  120, 61, 48, 10, 95, 115, 104, 111, 114, 116, 99, 117, 116, 61, 48, 10,
  95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 101,
  120, 95, 111, 110, 95, 108, 97, 116, 101, 120, 32, 58, 10, 45, 118, 32,
  45, 10, 45, 105, 102, 32, 36, 95, 105, 115, 95, 101, 120, 10, 45, 117,
  32, 34, 92, 92, 92, 92, 34, 10, 45, 101, 108, 115, 101, 10, 45, 117,
  32, 34, 92, 92, 98, 101, 103, 105, 110, 123, 99, 101, 110, 116, 101, 114,
  125, 34, 10, 95, 105, 115, 95, 101, 120, 61, 49, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 118, 32, 43, 10, 95, 100, 111, 99, 117, 109, 101, 110,
  116, 95, 103, 109, 105, 99, 95, 101, 120, 95, 111, 102, 102, 95, 108, 97,
  116, 101, 120, 32, 58, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 36,
  95, 105, 115, 95, 101, 120, 10, 45, 117, 32, 34, 92, 92, 101, 110, 100,
  123, 99, 101, 110, 116, 101, 114, 125, 34, 10, 95, 105, 115, 95, 101, 120,
  61, 48, 10, 45, 101, 108, 115, 101, 10, 45, 117, 32, 34, 34, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 95, 100, 111, 99, 117,
  109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 115, 117, 98, 115, 101, 99,
  116, 105, 111, 110, 95, 108, 97, 116, 101, 120, 32, 58, 10, 95, 105, 115,
  95, 100, 101, 115, 99, 61, 48, 10, 45, 95, 100, 111, 99, 117, 109, 101,
  110, 116, 95, 103, 109, 105, 99, 95, 114, 101, 112, 108, 97, 99, 101, 95,
  108, 97, 116, 101, 120, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32,
  64, 123, 45, 101, 111, 102, 102, 125, 34, 92, 110, 92, 92, 115, 101, 99,
  116, 105, 111, 110, 123, 34, 64, 123, 48, 44, 116, 125, 34, 125, 34, 32,
  45, 118, 32, 45, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103,
  109, 105, 99, 95, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 95,
  108, 97, 116, 101, 120, 32, 58, 10, 95, 105, 115, 95, 100, 101, 115, 99,
  61, 48, 10, 45, 105, 102, 32, 123, 123, 64, 123, 45, 49, 44, 116, 125,
  39, 61, 61, 39, 34, 40, 42, 41, 34, 125, 34, 32, 124, 124, 32, 34,
  123, 64, 123, 45, 49, 44, 116, 125, 39, 61, 61, 39, 34, 40, 43, 41,
  34, 125, 125, 32, 113, 117, 97, 108, 105, 102, 105, 101, 114, 61, 64, 123,
  45, 49, 44, 116, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101,
  108, 115, 101, 32, 113, 117, 97, 108, 105, 102, 105, 101, 114, 61, 34, 34,
  32, 45, 101, 110, 100, 105, 102, 10, 101, 49, 61, 34, 92, 92, 92, 92,
  126, 92, 92, 92, 92, 34, 32, 101, 48, 61, 34, 126, 126, 126, 36, 124,
  36, 92, 92, 92, 92, 34, 10, 115, 49, 61, 34, 92, 92, 104, 115, 112,
  97, 99, 101, 42, 123, 50, 46, 50, 99, 109, 125, 34, 32, 115, 48, 61,
  34, 34, 10, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109,
  105, 99, 95, 114, 101, 112, 108, 97, 99, 101, 95, 108, 97, 116, 101, 120,
  10, 45, 105, 102, 32, 123, 64, 35, 62, 49, 34, 32, 38, 38, 32, 34,
  123, 64, 123, 45, 49, 44, 48, 45, 54, 125, 39, 61, 61, 39, 123, 39,
  34, 101, 113, 46, 32, 116, 111, 32, 34, 39, 125, 125, 125, 10, 45, 114,
  111, 119, 115, 91, 45, 49, 93, 32, 55, 44, 49, 48, 48, 37, 32, 45,
  97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 123, 39, 46,
  39, 125, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93,
  32, 123, 39, 34, 32, 34, 39, 125, 32, 45, 97, 117, 116, 111, 99, 114,
  111, 112, 91, 45, 49, 93, 32, 51, 57, 10, 95, 115, 104, 111, 114, 116,
  99, 117, 116, 36, 95, 115, 104, 111, 114, 116, 99, 117, 116, 61, 64, 123,
  48, 44, 116, 125, 10, 95, 115, 104, 111, 114, 116, 99, 117, 116, 108, 105,
  110, 107, 36, 95, 115, 104, 111, 114, 116, 99, 117, 116, 61, 64, 123, 45,
  49, 44, 116, 125, 10, 95, 115, 104, 111, 114, 116, 99, 117, 116, 113, 117,
  97, 108, 105, 102, 105, 101, 114, 36, 95, 115, 104, 111, 114, 116, 99, 117,
  116, 61, 36, 113, 117, 97, 108, 105, 102, 105, 101, 114, 10, 95, 115, 104,
  111, 114, 116, 99, 117, 116, 61, 123, 36, 95, 115, 104, 111, 114, 116, 99,
  117, 116, 43, 49, 125, 10, 45, 101, 108, 115, 101, 10, 45, 118, 32, 43,
  10, 45, 101, 91, 93, 32, 64, 123, 45, 101, 111, 102, 102, 125, 34, 92,
  110, 92, 110, 92, 92, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 123,
  92, 92, 101, 109, 112, 104, 123, 45, 34, 64, 123, 48, 44, 116, 125, 34,
  92, 92, 105, 110, 100, 101, 120, 123, 45, 34, 64, 123, 48, 44, 116, 125,
  34, 125, 125, 32, 34, 36, 113, 117, 97, 108, 105, 102, 105, 101, 114, 34,
  125, 92, 92, 118, 115, 112, 97, 99, 101, 42, 123, 45, 48, 46, 53, 101,
  109, 125, 34, 10, 45, 105, 102, 32, 123, 64, 35, 62, 49, 125, 10, 45,
  101, 91, 93, 32, 34, 126, 92, 92, 92, 92, 92, 92, 116, 101, 120, 116,
  98, 102, 123, 65, 114, 103, 117, 109, 101, 110, 116, 115, 58, 32, 125, 32,
  34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125,
  10, 45, 101, 91, 93, 32, 36, 123, 115, 123, 36, 62, 33, 61, 48, 125,
  125, 34, 123, 92, 92, 115, 109, 97, 108, 108, 32, 92, 92, 116, 101, 120,
  116, 116, 116, 123, 34, 64, 123, 123, 49, 43, 36, 62, 125, 44, 116, 125,
  34, 125, 125, 34, 36, 123, 101, 123, 36, 60, 61, 61, 48, 125, 125, 10,
  45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32,
  45, 10, 45, 101, 110, 100, 105, 102, 10, 95, 100, 111, 99, 117, 109, 101,
  110, 116, 95, 103, 109, 105, 99, 95, 100, 101, 115, 99, 114, 105, 112, 116,
  105, 111, 110, 95, 108, 97, 116, 101, 120, 32, 58, 10, 115, 48, 61, 34,
  34, 32, 115, 49, 61, 34, 126, 92, 92, 92, 92, 34, 32, 115, 61, 36,
  123, 115, 36, 95, 105, 115, 95, 100, 101, 115, 99, 125, 10, 45, 95, 100,
  111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 114, 101, 112,
  108, 97, 99, 101, 95, 108, 97, 116, 101, 120, 10, 45, 105, 102, 32, 123,
  64, 123, 45, 49, 44, 48, 45, 49, 50, 125, 39, 61, 61, 39, 123, 39,
  34, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 34, 39,
  125, 125, 10, 45, 115, 32, 43, 44, 123, 39, 58, 39, 125, 32, 45, 108,
  91, 94, 48, 93, 32, 45, 97, 32, 121, 32, 45, 101, 110, 100, 108, 32,
  45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 123, 39, 58, 39, 125, 32,
  45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 123, 39, 34, 32, 34, 39,
  125, 10, 45, 105, 102, 32, 123, 64, 35, 62, 49, 125, 10, 45, 114, 101,
  112, 108, 97, 99, 101, 95, 115, 101, 113, 91, 49, 93, 32, 64, 123, 45,
  113, 117, 111, 116, 101, 92, 32, 123, 39, 34, 32, 97, 110, 100, 32, 34,
  39, 125, 125, 44, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 123, 39,
  34, 125, 32, 97, 110, 100, 32, 92, 92, 92, 92, 116, 101, 120, 116, 116,
  116, 123, 34, 39, 125, 125, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93,
  32, 64, 123, 45, 101, 111, 102, 102, 125, 36, 115, 34, 126, 92, 92, 92,
  92, 92, 92, 116, 101, 120, 116, 98, 102, 123, 34, 64, 123, 48, 44, 116,
  125, 34, 125, 58, 32, 123, 92, 92, 115, 109, 97, 108, 108, 32, 92, 92,
  116, 101, 120, 116, 116, 116, 123, 34, 64, 123, 45, 49, 44, 116, 125, 34,
  125, 125, 34, 32, 45, 118, 32, 45, 10, 45, 101, 108, 115, 101, 32, 45,
  118, 32, 43, 32, 45, 101, 91, 93, 32, 64, 123, 45, 101, 111, 102, 102,
  125, 36, 115, 34, 126, 92, 92, 92, 92, 34, 64, 123, 48, 44, 116, 125,
  32, 45, 118, 32, 45, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108,
  105, 102, 32, 123, 64, 123, 45, 49, 44, 48, 45, 55, 125, 39, 61, 61,
  39, 123, 39, 34, 40, 101, 113, 46, 32, 116, 111, 32, 34, 39, 125, 125,
  10, 45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 56, 44, 49, 48, 48,
  37, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32,
  123, 39, 46, 39, 125, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91,
  45, 49, 93, 32, 123, 39, 41, 39, 125, 32, 45, 97, 117, 116, 111, 99,
  114, 111, 112, 91, 45, 49, 93, 32, 123, 39, 34, 32, 34, 39, 125, 10,
  45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 64, 123, 45, 101, 111, 102,
  102, 125, 36, 115, 34, 40, 92, 92, 101, 109, 112, 104, 123, 101, 113, 46,
  32, 116, 111, 125, 32, 123, 92, 92, 115, 109, 97, 108, 108, 32, 92, 92,
  116, 101, 120, 116, 116, 116, 123, 34, 64, 123, 45, 49, 44, 116, 125, 34,
  125, 125, 41, 46, 34, 32, 45, 118, 32, 45, 10, 45, 101, 108, 115, 101,
  10, 45, 105, 102, 32, 123, 40, 105, 60, 123, 39, 65, 39, 125, 34, 32,
  124, 124, 32, 34, 105, 62, 123, 39, 90, 39, 125, 41, 34, 32, 38, 38,
  32, 34, 105, 33, 61, 52, 48, 34, 32, 38, 38, 32, 34, 105, 33, 61,
  51, 57, 125, 32, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 64, 123,
  45, 101, 111, 102, 102, 125, 64, 123, 45, 49, 44, 116, 125, 32, 45, 118,
  32, 45, 10, 45, 101, 108, 115, 101, 32, 45, 118, 32, 43, 32, 45, 101,
  91, 93, 32, 64, 123, 45, 101, 111, 102, 102, 125, 36, 115, 64, 123, 45,
  49, 44, 116, 125, 32, 45, 118, 32, 45, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 105, 102, 10, 95, 105, 115, 95, 100, 101, 115, 99,
  61, 49, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105,
  99, 95, 101, 120, 97, 109, 112, 108, 101, 95, 108, 97, 116, 101, 120, 32,
  58, 10, 95, 105, 115, 95, 100, 101, 115, 99, 61, 48, 10, 45, 105, 102,
  32, 36, 95, 102, 105, 108, 101, 110, 97, 109, 101, 32, 45, 101, 108, 115,
  101, 10, 45, 109, 32, 34, 102, 111, 111, 32, 58, 32, 34, 64, 123, 45,
  49, 44, 116, 125, 10, 45, 108, 91, 93, 32, 45, 118, 32, 45, 57, 57,
  32, 45, 114, 101, 115, 101, 116, 32, 45, 102, 111, 111, 32, 45, 118, 32,
  45, 49, 32, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109,
  105, 99, 32, 45, 111, 32, 36, 95, 102, 105, 108, 101, 110, 97, 109, 101,
  44, 56, 53, 32, 45, 114, 109, 32, 45, 101, 110, 100, 108, 10, 45, 117,
  110, 99, 111, 109, 109, 97, 110, 100, 32, 102, 111, 111, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103,
  109, 105, 99, 95, 114, 101, 112, 108, 97, 99, 101, 95, 108, 97, 116, 101,
  120, 10, 45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 64, 123, 45, 101,
  111, 110, 125, 34, 92, 92, 105, 110, 99, 108, 117, 100, 101, 103, 114, 97,
  112, 104, 105, 99, 115, 91, 107, 101, 101, 112, 97, 115, 112, 101, 99, 116,
  114, 97, 116, 105, 111, 61, 116, 114, 117, 101, 44, 104, 101, 105, 103, 104,
  116, 61, 55, 99, 109, 44, 119, 105, 100, 116, 104, 61, 92, 92, 116, 101,
  120, 116, 119, 105, 100, 116, 104, 93, 123, 34, 36, 95, 102, 105, 108, 101,
  110, 97, 109, 101, 34, 125, 92, 92, 92, 92, 34, 10, 45, 101, 91, 93,
  32, 34, 123, 92, 92, 102, 111, 111, 116, 110, 111, 116, 101, 115, 105, 122,
  101, 32, 92, 92, 116, 101, 120, 116, 98, 102, 123, 69, 120, 97, 109, 112,
  108, 101, 32, 34, 36, 95, 101, 120, 97, 109, 112, 108, 101, 34, 126, 58,
  125, 32, 92, 92, 116, 101, 120, 116, 116, 116, 123, 34, 64, 123, 45, 49,
  44, 116, 125, 34, 125, 125, 34, 10, 45, 118, 32, 45, 10, 95, 100, 111,
  99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 102, 111, 111, 116,
  101, 114, 95, 108, 97, 116, 101, 120, 32, 58, 10, 45, 105, 102, 32, 36,
  95, 115, 104, 111, 114, 116, 99, 117, 116, 10, 40, 123, 39, 34, 67, 111,
  109, 109, 97, 110, 100, 115, 32, 115, 104, 111, 114, 116, 99, 117, 116, 115,
  34, 39, 125, 41, 32, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95,
  103, 109, 105, 99, 95, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 95,
  108, 97, 116, 101, 120, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 118, 32, 43, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36,
  95, 115, 104, 111, 114, 116, 99, 117, 116, 10, 45, 101, 91, 93, 32, 34,
  36, 92, 92, 98, 117, 108, 108, 101, 116, 36, 126, 39, 92, 92, 116, 101,
  120, 116, 116, 116, 123, 45, 34, 36, 123, 95, 115, 104, 111, 114, 116, 99,
  117, 116, 36, 62, 125, 34, 125, 39, 32, 34, 36, 123, 95, 115, 104, 111,
  114, 116, 99, 117, 116, 113, 117, 97, 108, 105, 102, 105, 101, 114, 36, 62,
  125, 34, 126, 105, 115, 32, 101, 113, 117, 105, 118, 97, 108, 101, 110, 116,
  32, 116, 111, 126, 126, 39, 92, 92, 116, 101, 120, 116, 116, 116, 123, 34,
  36, 123, 95, 115, 104, 111, 114, 116, 99, 117, 116, 108, 105, 110, 107, 36,
  62, 125, 34, 125, 39, 46, 92, 92, 92, 92, 34, 10, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 45, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 36, 49, 10, 45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 34,
  10, 92, 110, 92, 92, 112, 114, 105, 110, 116, 105, 110, 100, 101, 120, 10,
  92, 110, 126, 92, 92, 92, 92, 36, 92, 92, 115, 113, 117, 97, 114, 101,
  36, 126, 69, 110, 100, 32, 111, 102, 32, 100, 111, 99, 117, 109, 101, 110,
  116, 46, 10, 92, 110, 92, 110, 92, 92, 101, 110, 100, 123, 100, 111, 99,
  117, 109, 101, 110, 116, 125, 34, 10, 45, 118, 32, 45, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 117, 110, 99, 111, 109, 109, 97, 110, 100, 32, 101,
  111, 110, 10, 45, 117, 110, 99, 111, 109, 109, 97, 110, 100, 32, 101, 111,
  102, 102, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105,
  99, 95, 114, 101, 112, 108, 97, 99, 101, 95, 108, 97, 116, 101, 120, 32,
  58, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 123,
  39, 92, 92, 39, 125, 44, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32,
  123, 39, 34, 92, 92, 92, 92, 116, 101, 120, 116, 98, 97, 99, 107, 115,
  108, 97, 115, 104, 32, 34, 39, 125, 125, 10, 45, 114, 101, 112, 108, 97,
  99, 101, 95, 115, 101, 113, 32, 123, 39, 95, 39, 125, 44, 64, 123, 45,
  113, 117, 111, 116, 101, 92, 32, 123, 39, 92, 92, 92, 92, 95, 39, 125,
  125, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 123,
  39, 37, 39, 125, 44, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 123,
  39, 92, 92, 92, 92, 37, 39, 125, 125, 10, 45, 114, 101, 112, 108, 97,
  99, 101, 95, 115, 101, 113, 32, 123, 39, 35, 39, 125, 44, 64, 123, 45,
  113, 117, 111, 116, 101, 92, 32, 123, 39, 92, 92, 92, 92, 37, 39, 125,
  125, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 123,
  39, 94, 39, 125, 44, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 123,
  39, 34, 92, 92, 92, 92, 116, 101, 120, 116, 97, 115, 99, 105, 105, 99,
  105, 114, 99, 117, 109, 32, 34, 39, 125, 125, 10, 45, 114, 101, 112, 108,
  97, 99, 101, 95, 115, 101, 113, 32, 123, 39, 36, 39, 125, 44, 64, 123,
  45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 92, 92, 92, 92, 36, 39,
  125, 125, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32,
  123, 39, 92, 123, 39, 125, 44, 64, 123, 45, 113, 117, 111, 116, 101, 92,
  32, 123, 39, 92, 92, 92, 92, 92, 123, 39, 125, 125, 10, 45, 114, 101,
  112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 123, 39, 92, 125, 39, 125,
  44, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 92, 92, 92,
  92, 92, 125, 39, 125, 125, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95,
  115, 101, 113, 32, 123, 39, 38, 39, 125, 44, 64, 123, 45, 113, 117, 111,
  116, 101, 92, 32, 123, 39, 92, 92, 92, 92, 38, 39, 125, 125, 10, 45,
  114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 123, 39, 124, 39,
  125, 44, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 126, 36,
  124, 36, 126, 39, 125, 125, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95,
  115, 101, 113, 32, 123, 39, 60, 39, 125, 44, 64, 123, 45, 113, 117, 111,
  116, 101, 92, 32, 123, 39, 36, 92, 60, 36, 39, 125, 125, 10, 45, 114,
  101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 123, 39, 62, 39, 125,
  44, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 36, 92, 62,
  36, 39, 125, 125, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103,
  109, 105, 99, 95, 104, 101, 97, 100, 101, 114, 95, 105, 109, 97, 103, 101,
  115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 49, 10, 45, 118, 32,
  43, 10, 45, 101, 91, 93, 32, 34, 92, 110, 32, 45, 32, 71, 101, 110,
  101, 114, 97, 116, 101, 32, 101, 120, 97, 109, 112, 108, 101, 32, 105, 109,
  97, 103, 101, 115, 32, 102, 114, 111, 109, 32, 115, 101, 116, 32, 111, 102,
  32, 99, 111, 109, 109, 97, 110, 100, 115, 32, 39, 34, 36, 95, 110, 97,
  109, 101, 34, 39, 46, 92, 110, 34, 10, 45, 118, 32, 45, 10, 95, 100,
  111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 115, 117, 98,
  115, 101, 99, 116, 105, 111, 110, 95, 105, 109, 97, 103, 101, 115, 32, 58,
  32, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99,
  95, 115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 95, 97, 115, 99, 105,
  105, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99,
  95, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 95, 105, 109, 97,
  103, 101, 115, 32, 58, 32, 95, 99, 111, 109, 109, 97, 110, 100, 95, 110,
  97, 109, 101, 61, 64, 123, 48, 44, 116, 125, 10, 95, 100, 111, 99, 117,
  109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 100, 101, 115, 99, 114, 105,
  112, 116, 105, 111, 110, 95, 105, 109, 97, 103, 101, 115, 32, 58, 10, 95,
  100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 101, 120,
  97, 109, 112, 108, 101, 95, 105, 109, 97, 103, 101, 115, 32, 58, 10, 45,
  118, 32, 43, 10, 45, 101, 91, 93, 32, 34, 32, 32, 32, 32, 46, 32,
  67, 111, 109, 109, 97, 110, 100, 32, 39, 45, 34, 36, 95, 99, 111, 109,
  109, 97, 110, 100, 95, 110, 97, 109, 101, 34, 39, 58, 32, 36, 32, 34,
  64, 123, 45, 49, 44, 116, 125, 10, 45, 118, 32, 45, 10, 45, 105, 102,
  32, 36, 95, 102, 105, 108, 101, 110, 97, 109, 101, 32, 45, 101, 108, 115,
  101, 10, 45, 109, 32, 34, 102, 111, 111, 32, 58, 32, 34, 64, 123, 45,
  49, 44, 116, 125, 10, 45, 108, 91, 93, 32, 45, 118, 32, 45, 49, 32,
  45, 114, 101, 115, 101, 116, 32, 45, 118, 32, 45, 57, 57, 32, 45, 102,
  111, 111, 32, 45, 118, 32, 45, 49, 32, 45, 95, 100, 111, 99, 117, 109,
  101, 110, 116, 95, 103, 109, 105, 99, 32, 45, 111, 32, 36, 95, 102, 105,
  108, 101, 110, 97, 109, 101, 44, 56, 53, 32, 45, 114, 109, 32, 45, 101,
  110, 100, 108, 10, 45, 117, 110, 99, 111, 109, 109, 97, 110, 100, 32, 102,
  111, 111, 10, 45, 101, 110, 100, 105, 102, 10, 95, 100, 111, 99, 117, 109,
  101, 110, 116, 95, 103, 109, 105, 99, 95, 102, 111, 111, 116, 101, 114, 95,
  105, 109, 97, 103, 101, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  49, 10, 45, 118, 32, 43, 10, 45, 101, 91, 93, 32, 34, 92, 110, 32,
  45, 32, 91, 32, 65, 108, 108, 32, 100, 111, 110, 101, 33, 32, 93, 92,
  110, 92, 110, 34, 10, 45, 118, 32, 45, 10, 95, 100, 111, 99, 117, 109,
  101, 110, 116, 95, 103, 109, 105, 99, 95, 104, 101, 97, 100, 101, 114, 95,
  97, 115, 99, 105, 105, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 49,
  10, 95, 115, 104, 111, 114, 116, 99, 117, 116, 61, 48, 10, 95, 100, 111,
  99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 115, 117, 98, 115,
  101, 99, 116, 105, 111, 110, 95, 97, 115, 99, 105, 105, 32, 58, 10, 45,
  118, 32, 43, 10, 45, 101, 91, 93, 32, 34, 92, 110, 32, 42, 42, 32,
  34, 64, 123, 48, 44, 116, 125, 34, 58, 34, 10, 45, 118, 32, 45, 10,
  95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 100,
  101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 95, 97, 115, 99, 105, 105,
  32, 58, 10, 45, 105, 102, 32, 123, 123, 64, 123, 45, 49, 44, 116, 125,
  39, 61, 61, 39, 34, 40, 42, 41, 34, 125, 34, 32, 124, 124, 32, 34,
  123, 64, 123, 45, 49, 44, 116, 125, 39, 61, 61, 39, 34, 40, 43, 41,
  34, 125, 125, 32, 113, 117, 97, 108, 105, 102, 105, 101, 114, 61, 34, 32,
  34, 64, 123, 45, 49, 44, 116, 125, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 101, 108, 115, 101, 32, 113, 117, 97, 108, 105, 102, 105, 101, 114,
  61, 34, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  64, 35, 62, 49, 34, 32, 38, 38, 32, 34, 123, 64, 123, 45, 49, 44,
  48, 45, 54, 125, 39, 61, 61, 39, 123, 39, 34, 101, 113, 46, 32, 116,
  111, 32, 34, 39, 125, 125, 125, 10, 45, 114, 111, 119, 115, 91, 45, 49,
  93, 32, 55, 44, 49, 48, 48, 37, 32, 45, 97, 117, 116, 111, 99, 114,
  111, 112, 91, 45, 49, 93, 32, 123, 39, 46, 39, 125, 32, 45, 97, 117,
  116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 123, 39, 34, 32, 34,
  39, 125, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93,
  32, 51, 57, 10, 95, 115, 104, 111, 114, 116, 99, 117, 116, 36, 95, 115,
  104, 111, 114, 116, 99, 117, 116, 61, 64, 123, 48, 44, 116, 125, 10, 95,
  115, 104, 111, 114, 116, 99, 117, 116, 108, 105, 110, 107, 36, 95, 115, 104,
  111, 114, 116, 99, 117, 116, 61, 64, 123, 45, 49, 44, 116, 125, 10, 95,
  115, 104, 111, 114, 116, 99, 117, 116, 113, 117, 97, 108, 105, 102, 105, 101,
  114, 36, 95, 115, 104, 111, 114, 116, 99, 117, 116, 61, 36, 113, 117, 97,
  108, 105, 102, 105, 101, 114, 10, 95, 115, 104, 111, 114, 116, 99, 117, 116,
  61, 123, 36, 95, 115, 104, 111, 114, 116, 99, 117, 116, 43, 49, 125, 10,
  45, 101, 108, 115, 101, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32,
  34, 92, 110, 32, 32, 32, 32, 45, 34, 64, 123, 48, 44, 116, 125, 36,
  123, 113, 117, 97, 108, 105, 102, 105, 101, 114, 125, 34, 58, 34, 32, 45,
  118, 32, 45, 32, 45, 114, 109, 91, 48, 93, 10, 45, 105, 102, 32, 64,
  35, 10, 115, 61, 34, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 34, 10, 45,
  121, 32, 120, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45,
  49, 125, 32, 40, 123, 39, 34, 32, 124, 34, 39, 125, 41, 32, 45, 97,
  91, 36, 62, 44, 45, 49, 93, 32, 120, 32, 45, 100, 111, 110, 101, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 32, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105,
  99, 95, 115, 112, 108, 105, 116, 95, 97, 115, 99, 105, 105, 32, 56, 48,
  44, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49,
  125, 32, 40, 123, 39, 92, 110, 36, 115, 34, 32, 32, 34, 39, 125, 41,
  32, 45, 97, 91, 36, 62, 44, 45, 49, 93, 32, 120, 32, 45, 100, 111,
  110, 101, 10, 45, 97, 32, 120, 32, 45, 118, 32, 43, 32, 45, 101, 91,
  93, 32, 36, 115, 64, 123, 48, 44, 116, 125, 32, 45, 118, 32, 45, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 34, 32,
  45, 118, 32, 45, 10, 45, 101, 110, 100, 105, 102, 10, 95, 100, 111, 99,
  117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 100, 101, 115, 99, 114,
  105, 112, 116, 105, 111, 110, 95, 97, 115, 99, 105, 105, 32, 58, 10, 115,
  61, 34, 32, 32, 32, 32, 32, 32, 32, 32, 34, 32, 98, 115, 48, 61,
  34, 92, 110, 34, 32, 98, 115, 49, 61, 34, 92, 92, 92, 92, 92, 110,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 34, 10, 45, 121,
  32, 120, 32, 45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109,
  105, 99, 95, 115, 112, 108, 105, 116, 95, 97, 115, 99, 105, 105, 32, 57,
  54, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125,
  32, 40, 123, 39, 36, 123, 98, 115, 36, 95, 105, 115, 95, 101, 120, 97,
  109, 112, 108, 101, 125, 36, 115, 34, 32, 32, 34, 39, 125, 41, 32, 45,
  97, 91, 36, 62, 44, 45, 49, 93, 32, 120, 32, 45, 100, 111, 110, 101,
  32, 45, 97, 32, 120, 10, 45, 118, 32, 43, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 101, 91, 93, 32, 36, 115, 64, 123, 36,
  62, 44, 116, 125, 32, 45, 118, 32, 45, 32, 45, 100, 111, 110, 101, 10,
  95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 101,
  120, 97, 109, 112, 108, 101, 95, 97, 115, 99, 105, 105, 32, 58, 10, 95,
  100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 102, 111,
  111, 116, 101, 114, 95, 97, 115, 99, 105, 105, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 49, 10, 45, 105, 102, 32, 36, 95, 115, 104, 111, 114,
  116, 99, 117, 116, 10, 40, 123, 39, 34, 67, 111, 109, 109, 97, 110, 100,
  115, 32, 115, 104, 111, 114, 116, 99, 117, 116, 115, 34, 39, 125, 41, 32,
  45, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95,
  115, 117, 98, 115, 101, 99, 116, 105, 111, 110, 95, 97, 115, 99, 105, 105,
  91, 45, 49, 93, 32, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34,
  34, 32, 45, 118, 32, 45, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  118, 32, 43, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 95, 115, 104,
  111, 114, 116, 99, 117, 116, 10, 45, 101, 91, 93, 32, 34, 32, 32, 32,
  32, 45, 34, 36, 123, 95, 115, 104, 111, 114, 116, 99, 117, 116, 36, 62,
  125, 34, 32, 34, 36, 123, 95, 115, 104, 111, 114, 116, 99, 117, 116, 113,
  117, 97, 108, 105, 102, 105, 101, 114, 36, 62, 125, 34, 58, 32, 101, 113,
  46, 32, 116, 111, 32, 39, 34, 36, 123, 95, 115, 104, 111, 114, 116, 99,
  117, 116, 108, 105, 110, 107, 36, 62, 125, 34, 39, 46, 34, 10, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 45, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 110, 32, 32, 32,
  91, 32, 84, 111, 116, 97, 108, 32, 110, 117, 109, 98, 101, 114, 32, 111,
  102, 32, 99, 111, 109, 109, 97, 110, 100, 115, 58, 32, 34, 36, 95, 99,
  111, 109, 109, 97, 110, 100, 34, 32, 93, 34, 32, 45, 118, 32, 45, 10,
  95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 115,
  112, 108, 105, 116, 95, 97, 115, 99, 105, 105, 32, 58, 10, 45, 100, 111,
  32, 45, 105, 102, 32, 123, 119, 62, 36, 49, 125, 10, 105, 61, 123, 36,
  49, 45, 49, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 49,
  47, 50, 125, 32, 45, 105, 102, 32, 123, 67, 61, 105, 40, 36, 49, 45,
  49, 45, 36, 62, 41, 59, 67, 61, 61, 51, 50, 124, 124, 67, 61, 61,
  51, 56, 124, 124, 67, 61, 61, 52, 50, 124, 124, 67, 61, 61, 52, 51,
  124, 124, 67, 61, 61, 52, 52, 124, 124, 67, 61, 61, 52, 54, 124, 124,
  67, 61, 61, 52, 55, 124, 124, 67, 61, 61, 53, 56, 124, 124, 67, 61,
  61, 53, 57, 124, 124, 67, 61, 61, 54, 51, 124, 124, 67, 61, 61, 57,
  50, 124, 124, 67, 61, 61, 49, 50, 52, 125, 32, 105, 61, 123, 36, 49,
  45, 49, 45, 36, 62, 125, 32, 45, 98, 114, 101, 97, 107, 10, 45, 101,
  110, 100, 105, 102, 32, 45, 100, 111, 110, 101, 10, 45, 45, 122, 91, 45,
  49, 93, 32, 123, 36, 105, 43, 49, 125, 44, 49, 48, 48, 37, 32, 45,
  122, 91, 45, 50, 93, 32, 48, 44, 36, 105, 10, 45, 101, 110, 100, 105,
  102, 32, 45, 119, 104, 105, 108, 101, 32, 123, 119, 62, 36, 49, 125, 10,
  95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 104,
  101, 97, 100, 101, 114, 95, 98, 97, 115, 104, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 49, 10, 45, 118, 32, 43, 10, 45, 101, 91, 93, 32,
  34, 92, 35, 10, 92, 110, 92, 35, 32, 32, 66, 97, 115, 104, 32, 99,
  111, 109, 112, 108, 101, 116, 105, 111, 110, 32, 114, 117, 108, 101, 115, 32,
  102, 111, 114, 32, 39, 103, 109, 105, 99, 39, 46, 10, 92, 110, 92, 35,
  10, 92, 110, 92, 35, 32, 84, 104, 105, 115, 32, 102, 105, 108, 101, 32,
  104, 97, 115, 32, 98, 101, 101, 110, 32, 103, 101, 110, 101, 114, 97, 116,
  101, 100, 32, 97, 117, 116, 111, 109, 97, 116, 105, 99, 97, 108, 108, 121,
  46, 10, 92, 110, 92, 35, 32, 68, 111, 32, 110, 111, 116, 32, 101, 100,
  105, 116, 33, 10, 92, 110, 92, 35, 10, 92, 110, 92, 35, 32, 84, 104,
  105, 115, 32, 102, 105, 108, 101, 32, 115, 104, 111, 117, 108, 100, 32, 98,
  101, 32, 99, 111, 112, 105, 101, 100, 47, 114, 101, 110, 97, 109, 101, 100,
  32, 105, 110, 32, 39, 47, 101, 116, 99, 47, 98, 97, 115, 104, 95, 99,
  111, 109, 112, 108, 101, 116, 105, 111, 110, 46, 100, 47, 103, 109, 105, 99,
  39, 46, 10, 92, 110, 92, 35, 10, 92, 110, 10, 92, 110, 95, 34, 36,
  95, 110, 97, 109, 101, 34, 40, 41, 10, 92, 110, 123, 10, 92, 110, 92,
  116, 108, 111, 99, 97, 108, 32, 99, 117, 114, 32, 112, 114, 101, 118, 32,
  111, 112, 116, 115, 32, 99, 111, 109, 115, 10, 92, 110, 92, 116, 67, 79,
  77, 80, 82, 69, 80, 76, 89, 61, 40, 41, 10, 92, 110, 92, 116, 99,
  117, 114, 61, 92, 34, 36, 123, 67, 79, 77, 80, 95, 87, 79, 82, 68,
  83, 91, 67, 79, 77, 80, 95, 67, 87, 79, 82, 68, 93, 125, 92, 34,
  10, 92, 110, 92, 116, 112, 114, 101, 118, 61, 92, 34, 36, 123, 67, 79,
  77, 80, 95, 87, 79, 82, 68, 83, 91, 67, 79, 77, 80, 95, 67, 87,
  79, 82, 68, 45, 49, 93, 125, 92, 34, 10, 34, 10, 45, 118, 32, 45,
  10, 95, 111, 112, 116, 115, 61, 10, 95, 99, 111, 109, 115, 61, 10, 95,
  97, 114, 103, 99, 111, 109, 109, 97, 110, 100, 61, 48, 10, 95, 115, 104,
  111, 114, 116, 99, 117, 116, 61, 48, 10, 95, 110, 98, 111, 112, 116, 115,
  61, 48, 10, 95, 110, 98, 99, 111, 109, 115, 61, 48, 10, 95, 100, 111,
  99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 115, 117, 98, 115,
  101, 99, 116, 105, 111, 110, 95, 98, 97, 115, 104, 32, 58, 10, 95, 100,
  111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 100, 101, 115,
  99, 114, 105, 112, 116, 105, 111, 110, 95, 98, 97, 115, 104, 32, 58, 10,
  95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 101,
  120, 97, 109, 112, 108, 101, 95, 98, 97, 115, 104, 32, 58, 10, 95, 100,
  111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99, 95, 100, 101, 99,
  108, 97, 114, 97, 116, 105, 111, 110, 95, 98, 97, 115, 104, 32, 58, 10,
  95, 111, 112, 116, 115, 36, 95, 110, 98, 111, 112, 116, 115, 61, 45, 64,
  123, 48, 44, 116, 125, 34, 32, 34, 45, 45, 64, 123, 48, 44, 116, 125,
  10, 95, 110, 98, 111, 112, 116, 115, 61, 123, 36, 95, 110, 98, 111, 112,
  116, 115, 43, 49, 125, 10, 95, 99, 111, 109, 115, 36, 95, 110, 98, 99,
  111, 109, 115, 61, 64, 123, 48, 44, 116, 125, 10, 95, 110, 98, 99, 111,
  109, 115, 61, 123, 36, 95, 110, 98, 99, 111, 109, 115, 43, 49, 125, 10,
  45, 105, 102, 32, 123, 123, 64, 123, 48, 44, 116, 125, 39, 61, 61, 39,
  34, 105, 110, 112, 117, 116, 34, 125, 34, 32, 124, 124, 32, 34, 123, 64,
  123, 48, 44, 116, 125, 39, 61, 61, 39, 34, 105, 34, 125, 34, 32, 124,
  124, 32, 34, 92, 10, 123, 64, 123, 48, 44, 116, 125, 39, 61, 61, 39,
  34, 111, 117, 116, 112, 117, 116, 34, 125, 34, 32, 124, 124, 32, 34, 123,
  64, 123, 48, 44, 116, 125, 39, 61, 61, 39, 34, 111, 34, 125, 34, 32,
  124, 124, 32, 34, 92, 10, 123, 64, 123, 48, 44, 116, 125, 39, 61, 61,
  39, 34, 99, 111, 109, 109, 97, 110, 100, 34, 125, 34, 32, 124, 124, 32,
  34, 123, 64, 123, 48, 44, 116, 125, 39, 61, 61, 39, 34, 109, 34, 125,
  125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 105, 102, 32,
  123, 123, 64, 123, 36, 60, 44, 116, 125, 39, 61, 61, 39, 34, 40, 42,
  41, 34, 125, 124, 124, 123, 64, 123, 36, 60, 44, 116, 125, 39, 61, 61,
  39, 34, 40, 43, 41, 34, 125, 125, 32, 45, 114, 109, 91, 36, 60, 93,
  32, 45, 101, 110, 100, 105, 102, 32, 45, 100, 111, 110, 101, 10, 45, 105,
  102, 32, 123, 64, 35, 61, 61, 50, 34, 32, 38, 38, 32, 34, 123, 64,
  123, 45, 49, 44, 48, 45, 54, 125, 39, 61, 61, 39, 123, 39, 34, 101,
  113, 46, 32, 116, 111, 32, 34, 39, 125, 125, 125, 10, 45, 114, 111, 119,
  115, 91, 45, 49, 93, 32, 55, 44, 49, 48, 48, 37, 32, 45, 97, 117,
  116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 123, 39, 46, 39, 125,
  32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 123,
  39, 34, 32, 34, 39, 125, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112,
  91, 45, 49, 93, 32, 51, 57, 32, 45, 97, 117, 116, 111, 99, 114, 111,
  112, 91, 45, 49, 93, 32, 123, 39, 45, 39, 125, 10, 95, 115, 104, 111,
  114, 116, 99, 117, 116, 36, 95, 115, 104, 111, 114, 116, 99, 117, 116, 61,
  64, 123, 48, 44, 116, 125, 10, 95, 115, 104, 111, 114, 116, 99, 117, 116,
  108, 105, 110, 107, 36, 95, 115, 104, 111, 114, 116, 99, 117, 116, 61, 64,
  123, 45, 115, 116, 114, 50, 104, 101, 120, 92, 32, 64, 123, 49, 44, 116,
  125, 125, 10, 45, 114, 109, 91, 45, 49, 93, 10, 95, 115, 104, 111, 114,
  116, 99, 117, 116, 61, 123, 36, 95, 115, 104, 111, 114, 116, 99, 117, 116,
  43, 49, 125, 10, 45, 101, 108, 105, 102, 32, 123, 64, 35, 62, 49, 125,
  10, 95, 99, 111, 109, 109, 97, 110, 100, 36, 95, 97, 114, 103, 99, 111,
  109, 109, 97, 110, 100, 61, 64, 123, 48, 44, 116, 125, 10, 45, 105, 102,
  32, 123, 64, 123, 48, 44, 116, 125, 39, 61, 61, 39, 34, 104, 101, 108,
  112, 34, 125, 32, 95, 97, 114, 103, 117, 109, 101, 110, 116, 36, 95, 97,
  114, 103, 99, 111, 109, 109, 97, 110, 100, 61, 34, 36, 99, 111, 109, 115,
  92, 34, 32, 45, 45, 32, 92, 34, 36, 99, 117, 114, 34, 10, 45, 101,
  108, 115, 101, 10, 45, 105, 102, 32, 123, 64, 35, 61, 61, 50, 125, 32,
  40, 123, 39, 62, 39, 125, 41, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  100, 105, 115, 99, 97, 114, 100, 91, 94, 48, 93, 32, 123, 39, 34, 32,
  34, 39, 125, 32, 45, 105, 91, 50, 45, 45, 50, 93, 32, 40, 123, 39,
  34, 32, 34, 39, 125, 41, 32, 45, 97, 91, 94, 48, 93, 32, 121, 10,
  95, 97, 114, 103, 117, 109, 101, 110, 116, 36, 95, 97, 114, 103, 99, 111,
  109, 109, 97, 110, 100, 61, 64, 123, 49, 44, 116, 125, 10, 45, 101, 110,
  100, 105, 102, 10, 95, 97, 114, 103, 117, 109, 101, 110, 116, 108, 105, 110,
  107, 64, 123, 45, 115, 116, 114, 50, 104, 101, 120, 92, 32, 64, 123, 48,
  44, 116, 125, 125, 61, 36, 123, 95, 97, 114, 103, 117, 109, 101, 110, 116,
  36, 95, 97, 114, 103, 99, 111, 109, 109, 97, 110, 100, 125, 10, 95, 97,
  114, 103, 99, 111, 109, 109, 97, 110, 100, 61, 123, 36, 95, 97, 114, 103,
  99, 111, 109, 109, 97, 110, 100, 43, 49, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 95, 100, 111, 99, 117, 109, 101, 110, 116, 95, 103, 109, 105, 99,
  95, 102, 111, 111, 116, 101, 114, 95, 98, 97, 115, 104, 32, 58, 32, 45,
  115, 107, 105, 112, 32, 36, 49, 10, 45, 118, 32, 43, 10, 45, 101, 91,
  93, 32, 34, 92, 116, 111, 112, 116, 115, 61, 92, 34, 92, 92, 34, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 36, 95, 110, 98, 111, 112, 116, 115,
  32, 45, 101, 91, 93, 32, 34, 92, 116, 32, 32, 32, 32, 32, 32, 34,
  36, 123, 95, 111, 112, 116, 115, 36, 62, 125, 92, 92, 32, 45, 100, 111,
  110, 101, 32, 45, 101, 91, 93, 32, 34, 92, 116, 32, 32, 32, 32, 32,
  92, 34, 34, 10, 45, 101, 91, 93, 32, 34, 92, 110, 92, 116, 99, 111,
  109, 115, 61, 92, 34, 92, 92, 34, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 36, 95, 110, 98, 99, 111, 109, 115, 32, 45, 101, 91, 93, 32, 34,
  92, 116, 32, 32, 32, 32, 32, 32, 34, 36, 123, 95, 99, 111, 109, 115,
  36, 62, 125, 92, 92, 32, 45, 100, 111, 110, 101, 32, 45, 101, 91, 93,
  32, 34, 92, 116, 32, 32, 32, 32, 32, 92, 34, 34, 10, 45, 101, 91,
  93, 32, 34, 92, 110, 92, 116, 99, 97, 115, 101, 32, 92, 34, 36, 123,
  112, 114, 101, 118, 125, 92, 34, 32, 105, 110, 34, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 36, 95, 97, 114, 103, 99, 111, 109, 109, 97, 110, 100,
  10, 45, 101, 91, 93, 32, 34, 92, 116, 92, 116, 92, 34, 45, 34, 36,
  123, 95, 99, 111, 109, 109, 97, 110, 100, 36, 62, 125, 34, 92, 34, 32,
  124, 32, 92, 34, 45, 45, 34, 36, 123, 95, 99, 111, 109, 109, 97, 110,
  100, 36, 62, 125, 34, 92, 34, 41, 34, 10, 45, 101, 91, 93, 32, 34,
  92, 116, 92, 116, 67, 79, 77, 80, 82, 69, 80, 76, 89, 61, 40, 32,
  36, 40, 99, 111, 109, 112, 103, 101, 110, 32, 45, 87, 32, 92, 34, 34,
  36, 123, 95, 97, 114, 103, 117, 109, 101, 110, 116, 36, 62, 125, 34, 92,
  34, 41, 32, 41, 92, 110, 92, 116, 92, 116, 114, 101, 116, 117, 114, 110,
  32, 48, 92, 110, 92, 116, 92, 116, 59, 59, 34, 10, 45, 100, 111, 110,
  101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 95, 115, 104, 111, 114,
  116, 99, 117, 116, 10, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40, 36,
  123, 95, 97, 114, 103, 117, 109, 101, 110, 116, 108, 105, 110, 107, 36, 123,
  95, 115, 104, 111, 114, 116, 99, 117, 116, 108, 105, 110, 107, 36, 62, 125,
  125, 41, 125, 10, 45, 101, 91, 93, 32, 34, 92, 116, 92, 116, 92, 34,
  45, 34, 36, 123, 95, 115, 104, 111, 114, 116, 99, 117, 116, 36, 62, 125,
  34, 92, 34, 32, 124, 32, 92, 34, 45, 45, 34, 36, 123, 95, 115, 104,
  111, 114, 116, 99, 117, 116, 36, 62, 125, 34, 92, 34, 41, 34, 10, 45,
  101, 91, 93, 32, 34, 92, 116, 92, 116, 67, 79, 77, 80, 82, 69, 80,
  76, 89, 61, 40, 32, 36, 40, 99, 111, 109, 112, 103, 101, 110, 32, 45,
  87, 32, 92, 34, 34, 36, 123, 95, 97, 114, 103, 117, 109, 101, 110, 116,
  108, 105, 110, 107, 36, 123, 95, 115, 104, 111, 114, 116, 99, 117, 116, 108,
  105, 110, 107, 36, 62, 125, 125, 34, 92, 34, 41, 32, 41, 92, 110, 92,
  116, 92, 116, 114, 101, 116, 117, 114, 110, 32, 48, 92, 110, 92, 116, 92,
  116, 59, 59, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110,
  101, 10, 45, 101, 91, 93, 32, 34, 92, 116, 101, 115, 97, 99, 34, 10,
  45, 101, 91, 93, 32, 34, 92, 110, 92, 116, 105, 102, 32, 91, 91, 32,
  92, 34, 36, 99, 117, 114, 92, 34, 32, 61, 61, 32, 45, 42, 32, 93,
  93, 32, 59, 32, 116, 104, 101, 110, 10, 92, 110, 92, 116, 92, 116, 67,
  79, 77, 80, 82, 69, 80, 76, 89, 61, 40, 32, 36, 40, 99, 111, 109,
  112, 103, 101, 110, 32, 45, 87, 32, 92, 34, 36, 111, 112, 116, 115, 92,
  34, 32, 45, 45, 32, 92, 34, 36, 99, 117, 114, 92, 34, 41, 32, 41,
  10, 92, 110, 92, 116, 101, 108, 115, 101, 10, 92, 110, 92, 116, 92, 116,
  95, 102, 105, 108, 101, 100, 105, 114, 10, 92, 110, 92, 116, 102, 105, 10,
  92, 110, 10, 92, 110, 125, 10, 92, 110, 10, 99, 111, 109, 112, 108, 101,
  116, 101, 32, 45, 70, 32, 95, 34, 36, 95, 110, 97, 109, 101, 34, 32,
  45, 111, 32, 102, 105, 108, 101, 110, 97, 109, 101, 115, 32, 103, 109, 105,
  99, 34, 10, 45, 118, 32, 45, 10, 95, 100, 111, 99, 117, 109, 101, 110,
  116, 95, 103, 109, 105, 99, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 87, 36, 62, 61, 123,
  119, 125, 32, 72, 36, 62, 61, 123, 104, 125, 32, 68, 36, 62, 61, 123,
  100, 125, 32, 83, 36, 62, 61, 123, 115, 125, 32, 73, 83, 95, 51, 68,
  36, 62, 61, 64, 123, 45, 105, 115, 95, 51, 100, 125, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 105, 102, 32, 64,
  123, 45, 105, 115, 95, 51, 100, 125, 32, 45, 114, 51, 100, 32, 49, 44,
  49, 44, 48, 44, 45, 56, 48, 32, 45, 114, 51, 100, 32, 48, 44, 49,
  44, 48, 44, 56, 48, 32, 45, 115, 110, 97, 112, 115, 104, 111, 116, 51,
  100, 32, 52, 48, 48, 32, 45, 101, 108, 115, 101, 32, 45, 110, 32, 48,
  44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 45, 45, 97, 112, 112, 101, 110, 100,
  95, 116, 105, 108, 101, 115, 32, 44, 32, 45, 105, 102, 32, 123, 119, 62,
  57, 48, 48, 125, 32, 114, 61, 123, 114, 111, 117, 110, 100, 40, 57, 48,
  48, 42, 49, 48, 48, 47, 119, 44, 48, 46, 49, 41, 125, 32, 45, 114,
  91, 94, 45, 49, 93, 32, 36, 114, 37, 44, 36, 114, 37, 44, 49, 44,
  49, 48, 48, 37, 44, 50, 32, 45, 101, 110, 100, 105, 102, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 115, 61, 61,
  49, 125, 32, 45, 114, 32, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44,
  51, 32, 45, 101, 108, 115, 101, 32, 45, 114, 32, 123, 119, 125, 44, 123,
  104, 125, 44, 49, 44, 51, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 119, 60, 61, 104, 38, 38, 104, 60, 50, 53, 54,
  125, 32, 45, 114, 50, 100, 121, 32, 50, 53, 54, 44, 50, 32, 45, 101,
  108, 105, 102, 32, 123, 104, 60, 61, 119, 38, 38, 119, 60, 50, 53, 54,
  125, 32, 45, 114, 50, 100, 120, 32, 50, 53, 54, 44, 50, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 119, 60, 61, 104, 38, 38,
  104, 62, 53, 49, 50, 125, 32, 45, 114, 50, 100, 121, 32, 53, 49, 50,
  44, 50, 32, 45, 101, 108, 105, 102, 32, 123, 104, 60, 61, 119, 38, 38,
  119, 62, 53, 49, 50, 125, 32, 45, 114, 50, 100, 120, 32, 53, 49, 50,
  44, 50, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 104,
  60, 52, 56, 125, 32, 45, 114, 32, 49, 48, 48, 37, 44, 52, 56, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 119, 60, 52, 56,
  125, 32, 45, 114, 32, 52, 56, 44, 49, 48, 48, 37, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 102, 114, 97, 109, 101, 32, 49, 44, 49, 44, 48,
  32, 45, 102, 114, 97, 109, 101, 32, 52, 44, 52, 44, 50, 53, 53, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 78, 61, 64, 35,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 78, 32, 45, 108, 91, 36,
  62, 93, 10, 123, 119, 125, 44, 50, 52, 44, 49, 44, 51, 44, 50, 53,
  53, 10, 45, 105, 102, 32, 123, 119, 62, 55, 53, 125, 10, 45, 105, 102,
  32, 123, 36, 78, 62, 49, 125, 32, 45, 105, 102, 32, 123, 119, 62, 49,
  49, 48, 125, 32, 45, 116, 91, 45, 49, 93, 32, 73, 109, 97, 103, 101,
  92, 32, 91, 36, 62, 93, 58, 44, 51, 44, 51, 44, 49, 55, 32, 45,
  101, 108, 115, 101, 32, 45, 116, 91, 45, 49, 93, 32, 91, 36, 62, 93,
  58, 44, 51, 44, 51, 44, 49, 55, 32, 45, 101, 110, 100, 105, 102, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 123, 73, 83, 95,
  51, 68, 36, 62, 125, 32, 48, 32, 45, 116, 91, 45, 49, 93, 32, 40,
  51, 100, 92, 32, 111, 98, 106, 101, 99, 116, 41, 44, 48, 44, 48, 44,
  49, 51, 44, 49, 44, 50, 53, 53, 10, 45, 101, 108, 115, 101, 32, 48,
  32, 45, 116, 91, 45, 49, 93, 32, 40, 36, 123, 87, 36, 62, 125, 120,
  36, 123, 72, 36, 62, 125, 120, 36, 123, 68, 36, 62, 125, 120, 36, 123,
  83, 36, 62, 125, 41, 44, 48, 44, 48, 44, 49, 51, 44, 49, 44, 50,
  53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 110, 101, 103, 97, 116,
  105, 118, 101, 91, 45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 32, 45, 43, 91, 45, 49, 93, 32, 49, 54, 52, 32,
  45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 116, 111,
  95, 114, 103, 98, 91, 45, 49, 93, 10, 45, 106, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 123, 64, 123, 45, 50, 44, 119, 125, 45, 119, 45,
  53, 125, 44, 123, 64, 123, 45, 50, 44, 104, 125, 45, 104, 45, 53, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 115, 101, 32, 45,
  116, 91, 45, 49, 93, 32, 91, 36, 62, 93, 58, 44, 51, 44, 51, 44,
  49, 55, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 118, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 45, 32,
  50, 53, 53, 32, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101,
  115, 32, 44, 32, 45, 43, 32, 50, 53, 53, 10, 45, 105, 102, 32, 123,
  119, 60, 50, 53, 54, 125, 32, 45, 45, 32, 50, 53, 53, 32, 45, 114,
  32, 50, 53, 54, 44, 49, 48, 48, 37, 44, 49, 44, 51, 44, 48, 44,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 43, 32, 50, 53, 53,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 104, 60, 50,
  53, 54, 125, 32, 45, 45, 32, 50, 53, 53, 32, 45, 114, 32, 49, 48,
  48, 37, 44, 50, 53, 54, 44, 49, 44, 51, 44, 48, 44, 48, 44, 48,
  46, 53, 44, 48, 46, 53, 32, 45, 43, 32, 50, 53, 53, 32, 45, 101,
  110, 100, 105, 102, 10, 101, 99, 104, 111, 95, 102, 105, 108, 101, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 39, 92, 110, 39, 125,
  10, 45, 118, 32, 45, 32, 40, 123, 34, 39, 36, 123, 50, 45, 45, 49,
  125, 92, 110, 39, 34, 125, 41, 32, 45, 111, 91, 45, 49, 93, 32, 114,
  97, 119, 58, 36, 49, 44, 117, 99, 104, 97, 114, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 118, 32, 43, 10, 101, 99, 104, 111, 95, 115, 116,
  100, 111, 117, 116, 32, 58, 10, 45, 118, 32, 45, 32, 40, 123, 39, 34,
  36, 42, 34, 92, 110, 39, 125, 41, 32, 45, 111, 91, 45, 49, 93, 32,
  45, 46, 114, 97, 119, 44, 117, 99, 104, 97, 114, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 118, 32, 43, 10, 102, 117, 110, 99, 116, 105, 111,
  110, 49, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123,
  49, 61, 49, 125, 62, 61, 48, 32, 38, 38, 32, 36, 49, 60, 61, 49,
  34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 48, 125, 44, 36,
  123, 51, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73,
  110, 112, 117, 116, 32, 99, 111, 110, 116, 105, 110, 117, 111, 117, 115, 32,
  49, 100, 32, 102, 117, 110, 99, 116, 105, 111, 110, 44, 32, 119, 105, 116,
  104, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 49, 32,
  97, 110, 100, 32, 107, 101, 121, 112, 111, 105, 110, 116, 115, 32, 40, 36,
  123, 50, 45, 45, 49, 125, 41, 46, 34, 10, 45, 118, 32, 45, 10, 45,
  105, 102, 32, 123, 36, 35, 60, 53, 125, 32, 123, 109, 97, 120, 40, 48,
  44, 36, 50, 41, 43, 49, 125, 44, 49, 44, 49, 44, 49, 44, 36, 51,
  32, 45, 118, 32, 43, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101,
  110, 100, 105, 102, 10, 40, 36, 123, 50, 45, 45, 49, 125, 41, 32, 45,
  114, 91, 45, 49, 93, 32, 50, 44, 123, 119, 47, 50, 125, 44, 49, 44,
  49, 44, 45, 49, 32, 45, 115, 111, 114, 116, 91, 45, 49, 93, 32, 43,
  44, 121, 32, 45, 115, 91, 45, 49, 93, 32, 120, 44, 50, 32, 45, 114,
  111, 117, 110, 100, 91, 45, 50, 93, 32, 49, 32, 45, 97, 91, 45, 50,
  44, 45, 49, 93, 32, 120, 10, 45, 45, 115, 104, 105, 102, 116, 91, 45,
  49, 93, 32, 48, 44, 49, 44, 48, 44, 48, 44, 49, 32, 45, 45, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 42, 91, 45, 49, 93, 32,
  45, 49, 10, 45, 45, 115, 104, 105, 102, 116, 91, 45, 50, 93, 32, 48,
  44, 45, 49, 44, 48, 44, 48, 44, 49, 32, 45, 45, 91, 45, 49, 93,
  32, 91, 45, 51, 93, 10, 45, 45, 42, 91, 45, 50, 93, 32, 123, 36,
  49, 47, 50, 125, 32, 45, 45, 42, 91, 45, 50, 93, 32, 123, 49, 45,
  36, 49, 47, 50, 125, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10,
  45, 42, 91, 45, 51, 93, 32, 123, 49, 45, 36, 49, 47, 50, 125, 32,
  45, 42, 91, 45, 50, 93, 32, 123, 36, 49, 47, 50, 125, 32, 45, 43,
  91, 45, 51, 44, 45, 50, 93, 10, 45, 115, 91, 45, 50, 44, 45, 49,
  93, 32, 120, 32, 45, 43, 91, 45, 52, 44, 45, 50, 93, 32, 49, 101,
  45, 49, 48, 10, 45, 47, 91, 45, 51, 93, 32, 91, 45, 52, 93, 32,
  45, 47, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 114, 109, 91,
  45, 52, 44, 45, 50, 93, 10, 45, 97, 91, 45, 51, 45, 45, 49, 93,
  32, 120, 10, 123, 64, 123, 45, 49, 44, 40, 48, 44, 123, 104, 45, 49,
  125, 41, 125, 43, 49, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  64, 123, 45, 50, 44, 104, 125, 45, 49, 125, 10, 120, 115, 116, 97, 114,
  116, 61, 123, 105, 102, 40, 36, 62, 44, 64, 123, 45, 50, 44, 48, 125,
  44, 48, 41, 125, 10, 45, 95, 102, 117, 110, 99, 116, 105, 111, 110, 49,
  100, 32, 64, 123, 45, 50, 44, 48, 45, 49, 125, 44, 64, 123, 45, 50,
  44, 51, 125, 44, 64, 123, 45, 50, 44, 52, 45, 54, 125, 44, 36, 120,
  115, 116, 97, 114, 116, 44, 64, 123, 45, 50, 44, 52, 125, 32, 45, 106,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 120, 115, 116, 97, 114,
  116, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 105, 102, 116,
  91, 45, 50, 93, 32, 48, 44, 45, 49, 32, 45, 100, 111, 110, 101, 10,
  45, 114, 109, 91, 45, 50, 93, 32, 45, 110, 109, 91, 45, 49, 93, 32,
  34, 91, 49, 100, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 40, 36,
  123, 50, 45, 45, 49, 125, 41, 93, 34, 10, 45, 118, 32, 43, 10, 95,
  102, 117, 110, 99, 116, 105, 111, 110, 49, 100, 32, 58, 10, 40, 123, 36,
  49, 94, 51, 125, 44, 123, 36, 49, 94, 50, 125, 44, 36, 49, 44, 49,
  59, 92, 10, 123, 51, 42, 36, 49, 94, 50, 125, 44, 123, 50, 42, 36,
  49, 125, 44, 49, 44, 48, 59, 92, 10, 123, 36, 52, 94, 51, 125, 44,
  123, 36, 52, 94, 50, 125, 44, 36, 52, 44, 49, 59, 92, 10, 123, 51,
  42, 36, 52, 94, 50, 125, 44, 123, 50, 42, 36, 52, 125, 44, 49, 44,
  48, 41, 10, 40, 36, 50, 59, 36, 51, 59, 36, 53, 59, 36, 54, 41,
  32, 45, 115, 111, 108, 118, 101, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  32, 45, 114, 109, 91, 45, 50, 93, 32, 45, 116, 114, 97, 110, 115, 112,
  111, 115, 101, 91, 45, 49, 93, 10, 40, 36, 55, 44, 36, 56, 41, 32,
  45, 114, 91, 45, 49, 93, 32, 123, 49, 43, 36, 56, 45, 36, 55, 125,
  44, 49, 44, 49, 44, 49, 44, 51, 32, 45, 45, 94, 91, 45, 49, 93,
  32, 51, 32, 45, 45, 94, 91, 45, 50, 93, 32, 50, 32, 45, 45, 102,
  91, 45, 49, 93, 32, 49, 32, 45, 109, 118, 91, 45, 52, 93, 32, 45,
  49, 32, 45, 97, 91, 45, 52, 45, 45, 49, 93, 32, 121, 10, 45, 42,
  42, 91, 45, 50, 44, 45, 49, 93, 10, 103, 109, 105, 99, 107, 121, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 76, 111, 97, 100, 32,
  105, 109, 97, 103, 101, 32, 111, 102, 32, 116, 104, 101, 32, 71, 39, 77,
  73, 67, 32, 109, 97, 115, 99, 111, 116, 32, 39, 71, 109, 105, 99, 107,
  121, 39, 46, 34, 10, 45, 118, 32, 45, 32, 45, 105, 32, 104, 116, 116,
  112, 58, 47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102,
  111, 114, 103, 101, 46, 110, 101, 116, 47, 105, 109, 103, 47, 103, 109, 105,
  99, 107, 121, 95, 108, 97, 114, 103, 101, 46, 99, 105, 109, 103, 122, 32,
  45, 110, 109, 91, 45, 49, 93, 32, 91, 103, 109, 105, 99, 107, 121, 93,
  32, 45, 118, 32, 43, 10, 103, 109, 105, 99, 107, 121, 95, 119, 105, 108,
  98, 101, 114, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 76,
  111, 97, 100, 32, 105, 109, 97, 103, 101, 32, 111, 102, 32, 116, 104, 101,
  32, 71, 39, 77, 73, 67, 32, 109, 97, 115, 99, 111, 116, 32, 39, 71,
  109, 105, 99, 107, 121, 39, 32, 116, 111, 103, 101, 116, 104, 101, 114, 32,
  119, 105, 116, 104, 32, 71, 73, 77, 80, 32, 109, 97, 115, 99, 111, 116,
  32, 39, 87, 105, 108, 98, 101, 114, 39, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 105, 32, 104, 116, 116, 112, 58, 47, 47, 103, 109, 105, 99, 46,
  115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47,
  105, 109, 103, 47, 103, 109, 105, 99, 107, 121, 95, 119, 105, 108, 98, 101,
  114, 95, 108, 97, 114, 103, 101, 46, 99, 105, 109, 103, 122, 32, 45, 110,
  109, 91, 45, 49, 93, 32, 91, 103, 109, 105, 99, 107, 121, 95, 119, 105,
  108, 98, 101, 114, 93, 32, 45, 118, 32, 43, 10, 104, 101, 97, 114, 116,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 53,
  49, 50, 125, 62, 61, 49, 32, 38, 38, 32, 36, 123, 50, 61, 36, 49,
  125, 62, 61, 49, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73,
  110, 112, 117, 116, 32, 36, 49, 120, 36, 50, 32, 104, 101, 97, 114, 116,
  32, 98, 105, 110, 97, 114, 121, 32, 109, 97, 115, 107, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 108, 91, 93, 10, 50, 48, 52, 56, 44, 49, 44,
  49, 44, 49, 44, 39, 116, 61, 50, 42, 112, 105, 42, 120, 47, 119, 59,
  49, 54, 42, 115, 105, 110, 40, 116, 41, 94, 51, 39, 10, 50, 48, 52,
  56, 44, 49, 44, 49, 44, 49, 44, 39, 116, 61, 50, 42, 112, 105, 42,
  120, 47, 119, 59, 49, 51, 42, 99, 111, 115, 40, 116, 41, 45, 53, 42,
  99, 111, 115, 40, 50, 42, 116, 41, 45, 50, 42, 99, 111, 115, 40, 51,
  42, 116, 41, 45, 99, 111, 115, 40, 52, 42, 116, 41, 39, 10, 45, 97,
  32, 99, 32, 45, 100, 105, 115, 112, 108, 97, 121, 95, 112, 97, 114, 97,
  109, 101, 116, 114, 105, 99, 32, 36, 49, 44, 36, 50, 44, 49, 44, 48,
  44, 48, 44, 48, 10, 45, 102, 108, 111, 111, 100, 32, 53, 48, 37, 44,
  53, 48, 37, 44, 48, 44, 48, 44, 48, 44, 49, 44, 48, 32, 45, 101,
  113, 91, 45, 49, 93, 32, 48, 10, 45, 110, 109, 32, 34, 91, 72, 101,
  97, 114, 116, 32, 98, 105, 110, 97, 114, 121, 32, 109, 97, 115, 107, 93,
  34, 10, 45, 101, 110, 100, 108, 32, 45, 118, 32, 43, 10, 111, 117, 116,
  112, 117, 116, 95, 103, 103, 114, 32, 58, 32, 45, 115, 107, 105, 112, 32,
  34, 36, 123, 50, 61, 125, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 79, 117, 116, 112, 117, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  97, 115, 32, 71, 73, 77, 80, 32, 103, 114, 97, 100, 105, 101, 110, 116,
  32, 102, 105, 108, 101, 32, 39, 36, 49, 39, 46, 34, 10, 45, 118, 32,
  45, 32, 78, 61, 64, 35, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36,
  78, 32, 45, 45, 108, 91, 36, 62, 93, 32, 45, 114, 32, 49, 44, 123,
  119, 42, 104, 42, 100, 125, 44, 49, 44, 49, 48, 48, 37, 44, 45, 49,
  32, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 47, 32, 50, 53, 53,
  10, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40, 34, 36, 50, 34, 41,
  125, 32, 110, 97, 109, 101, 61, 34, 36, 50, 34, 10, 45, 101, 108, 115,
  101, 32, 45, 108, 91, 93, 32, 49, 32, 45, 110, 109, 91, 45, 49, 93,
  32, 34, 36, 49, 34, 32, 40, 123, 39, 64, 123, 45, 49, 44, 98, 125,
  39, 125, 41, 32, 45, 102, 32, 34, 105, 102, 40, 120, 61, 61, 48, 38,
  38, 105, 62, 61, 34, 123, 39, 97, 39, 125, 34, 38, 38, 105, 60, 61,
  34, 123, 39, 122, 39, 125, 34, 44, 105, 45, 34, 123, 39, 97, 39, 125,
  34, 43, 34, 123, 39, 65, 39, 125, 34, 44, 105, 41, 34, 32, 110, 97,
  109, 101, 61, 64, 123, 45, 49, 44, 116, 125, 32, 45, 114, 109, 32, 45,
  101, 110, 100, 108, 10, 45, 101, 110, 100, 105, 102, 10, 40, 123, 39, 34,
  71, 73, 77, 80, 32, 71, 114, 97, 100, 105, 101, 110, 116, 92, 110, 78,
  97, 109, 101, 58, 32, 34, 36, 110, 97, 109, 101, 92, 110, 64, 123, 48,
  44, 104, 125, 92, 110, 39, 125, 41, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 123, 48, 44, 104, 125, 10, 115, 116, 97, 114, 116, 61, 123, 95,
  36, 62, 47, 64, 123, 48, 44, 104, 125, 125, 10, 101, 110, 100, 61, 123,
  95, 40, 36, 62, 43, 49, 41, 47, 64, 123, 48, 44, 104, 125, 125, 10,
  109, 105, 100, 61, 123, 95, 48, 46, 53, 42, 40, 36, 115, 116, 97, 114,
  116, 43, 36, 101, 110, 100, 41, 125, 10, 114, 103, 98, 97, 61, 64, 123,
  45, 97, 116, 91, 48, 93, 92, 32, 48, 44, 36, 62, 125, 10, 114, 61,
  123, 97, 114, 103, 40, 49, 44, 36, 114, 103, 98, 97, 41, 125, 32, 103,
  61, 123, 97, 114, 103, 40, 50, 44, 36, 114, 103, 98, 97, 41, 125, 32,
  98, 61, 123, 97, 114, 103, 40, 51, 44, 36, 114, 103, 98, 97, 41, 125,
  32, 97, 61, 123, 97, 114, 103, 40, 52, 44, 36, 114, 103, 98, 97, 41,
  125, 10, 40, 123, 39, 36, 115, 116, 97, 114, 116, 34, 32, 34, 36, 109,
  105, 100, 34, 32, 34, 36, 101, 110, 100, 34, 32, 34, 36, 114, 34, 32,
  34, 36, 103, 34, 32, 34, 36, 98, 34, 32, 34, 36, 97, 34, 32, 34,
  36, 114, 34, 32, 34, 36, 103, 34, 32, 34, 36, 98, 34, 32, 34, 36,
  97, 34, 32, 48, 32, 48, 92, 110, 34, 39, 125, 41, 10, 45, 100, 111,
  110, 101, 10, 45, 114, 109, 91, 48, 93, 32, 45, 97, 32, 120, 10, 45,
  105, 102, 32, 123, 36, 78, 62, 49, 125, 32, 45, 111, 32, 114, 97, 119,
  58, 64, 123, 34, 45, 102, 105, 108, 101, 110, 97, 109, 101, 32, 92, 34,
  36, 49, 92, 34, 44, 36, 62, 34, 125, 44, 117, 99, 104, 97, 114, 32,
  45, 101, 108, 115, 101, 32, 45, 111, 32, 114, 97, 119, 58, 34, 36, 49,
  34, 44, 117, 99, 104, 97, 114, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 109, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 111, 110, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95,
  115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 111, 117,
  116, 112, 117, 116, 110, 32, 36, 42, 10, 111, 117, 116, 112, 117, 116, 110,
  32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63, 34,
  32, 45, 118, 32, 43, 10, 45, 95, 36, 48, 32, 36, 42, 10, 95, 111,
  117, 116, 112, 117, 116, 110, 32, 58, 10, 45, 118, 32, 45, 32, 102, 105,
  108, 101, 110, 97, 109, 101, 61, 64, 123, 45, 102, 105, 108, 101, 110, 97,
  109, 101, 92, 32, 34, 36, 49, 34, 44, 64, 123, 62, 125, 125, 32, 45,
  118, 32, 43, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 79, 117,
  116, 112, 117, 116, 32, 105, 109, 97, 103, 101, 34, 36, 95, 95, 115, 34,
  32, 97, 115, 32, 102, 105, 108, 101, 32, 39, 34, 36, 102, 105, 108, 101,
  110, 97, 109, 101, 34, 39, 46, 34, 10, 45, 118, 32, 45, 32, 45, 111,
  32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 32, 45, 118, 32, 43, 10,
  111, 112, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36,
  63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 111, 117, 116, 112, 117, 116,
  112, 32, 36, 42, 10, 111, 117, 116, 112, 117, 116, 112, 32, 58, 10, 45,
  118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32,
  43, 10, 45, 95, 36, 48, 32, 36, 42, 10, 95, 111, 117, 116, 112, 117,
  116, 112, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 34,
  95, 34, 125, 10, 45, 105, 102, 32, 123, 64, 35, 62, 49, 125, 32, 45,
  101, 91, 48, 45, 45, 52, 93, 32, 34, 79, 117, 116, 112, 117, 116, 32,
  105, 109, 97, 103, 101, 34, 36, 95, 95, 115, 34, 32, 97, 115, 32, 116,
  104, 101, 105, 114, 32, 105, 110, 105, 116, 105, 97, 108, 32, 108, 111, 99,
  97, 116, 105, 111, 110, 115, 44, 32, 112, 114, 101, 102, 105, 120, 101, 100,
  32, 98, 121, 32, 39, 36, 49, 39, 46, 34, 10, 45, 101, 108, 115, 101,
  32, 45, 101, 91, 48, 45, 45, 52, 93, 32, 34, 79, 117, 116, 112, 117,
  116, 32, 105, 109, 97, 103, 101, 34, 36, 95, 95, 115, 34, 32, 97, 115,
  32, 105, 116, 115, 32, 105, 110, 105, 116, 105, 97, 108, 32, 108, 111, 99,
  97, 116, 105, 111, 110, 44, 32, 112, 114, 101, 102, 105, 120, 101, 100, 32,
  98, 121, 32, 39, 36, 49, 39, 46, 34, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 111, 91, 36, 62, 93, 32, 64, 123, 36, 62, 44, 102, 125, 36,
  49, 64, 123, 36, 62, 44, 98, 125, 46, 64, 123, 36, 62, 44, 120, 125,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 111, 119, 32, 58,
  10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45,
  118, 32, 43, 10, 45, 95, 111, 117, 116, 112, 117, 116, 119, 32, 36, 42,
  10, 111, 117, 116, 112, 117, 116, 119, 32, 58, 10, 45, 118, 32, 45, 32,
  95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95,
  36, 48, 32, 36, 42, 10, 95, 111, 117, 116, 112, 117, 116, 119, 32, 58,
  10, 45, 105, 102, 32, 123, 64, 35, 62, 49, 125, 32, 45, 101, 91, 48,
  45, 45, 52, 93, 32, 34, 79, 117, 116, 112, 117, 116, 32, 105, 109, 97,
  103, 101, 34, 36, 95, 95, 115, 34, 32, 97, 115, 32, 116, 104, 101, 105,
  114, 32, 105, 110, 105, 116, 105, 97, 108, 32, 108, 111, 99, 97, 116, 105,
  111, 110, 46, 34, 10, 45, 101, 108, 115, 101, 32, 45, 101, 91, 48, 45,
  45, 52, 93, 32, 34, 79, 117, 116, 112, 117, 116, 32, 105, 109, 97, 103,
  101, 34, 36, 95, 95, 115, 34, 32, 97, 115, 32, 105, 116, 115, 32, 105,
  110, 105, 116, 105, 97, 108, 32, 108, 111, 99, 97, 116, 105, 111, 110, 46,
  34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 111, 91, 36, 62, 93, 32,
  64, 123, 36, 62, 44, 110, 125, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 114, 97, 105, 110, 98, 111, 119, 95, 108, 117, 116, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32,
  82, 71, 66, 32, 99, 111, 108, 111, 114, 109, 97, 112, 32, 111, 102, 32,
  50, 53, 54, 32, 114, 97, 105, 110, 98, 111, 119, 32, 99, 111, 108, 111,
  114, 115, 46, 34, 10, 45, 118, 32, 45, 10, 40, 50, 44, 49, 48, 44,
  49, 51, 44, 49, 51, 44, 49, 53, 44, 49, 54, 44, 49, 53, 44, 49,
  53, 44, 49, 56, 44, 50, 51, 44, 50, 54, 44, 51, 49, 44, 51, 51,
  44, 51, 55, 44, 51, 56, 44, 51, 57, 44, 52, 50, 44, 52, 50, 44,
  52, 52, 44, 52, 53, 44, 52, 52, 44, 52, 52, 44, 52, 53, 44, 52,
  53, 44, 52, 52, 44, 52, 50, 44, 52, 52, 44, 52, 53, 44, 52, 53,
  44, 52, 57, 44, 53, 48, 44, 53, 50, 44, 53, 52, 44, 53, 53, 44,
  53, 54, 44, 53, 55, 44, 92, 10, 53, 54, 44, 53, 54, 44, 53, 55,
  44, 53, 55, 44, 53, 56, 44, 53, 55, 44, 53, 56, 44, 53, 56, 44,
  53, 57, 44, 53, 56, 44, 54, 48, 44, 53, 57, 44, 53, 56, 44, 53,
  57, 44, 53, 57, 44, 53, 57, 44, 53, 57, 44, 53, 57, 44, 54, 48,
  44, 54, 48, 44, 53, 57, 44, 53, 57, 44, 53, 57, 44, 53, 57, 44,
  54, 48, 44, 53, 57, 44, 53, 57, 44, 53, 57, 44, 53, 57, 44, 53,
  57, 44, 53, 57, 44, 53, 57, 44, 53, 56, 44, 53, 56, 44, 53, 56,
  44, 53, 54, 44, 92, 10, 53, 54, 44, 53, 52, 44, 53, 49, 44, 52,
  56, 44, 52, 52, 44, 51, 57, 44, 51, 51, 44, 50, 48, 44, 53, 44,
  48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44,
  49, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 92, 10, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 53, 44, 50, 53,
  44, 53, 48, 44, 54, 54, 44, 56, 49, 44, 57, 48, 44, 49, 48, 50,
  44, 49, 48, 57, 44, 49, 49, 56, 44, 49, 50, 57, 44, 49, 51, 55,
  44, 49, 52, 52, 44, 49, 53, 50, 44, 49, 53, 56, 44, 49, 54, 56,
  44, 49, 55, 56, 44, 49, 56, 51, 44, 49, 57, 48, 44, 49, 57, 57,
  44, 50, 48, 55, 44, 92, 10, 50, 49, 51, 44, 50, 50, 48, 44, 50,
  50, 55, 44, 50, 51, 48, 44, 50, 51, 54, 44, 50, 52, 50, 44, 50,
  52, 54, 44, 50, 53, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 51, 44, 50, 53, 51, 44, 50, 53, 51, 44, 50, 53, 50, 44, 50,
  53, 49, 44, 50, 53, 48, 44, 50, 53, 48, 44, 50, 52, 57, 44, 50,
  52, 56, 44, 50, 52, 56, 44, 50, 52, 55, 44, 50, 52, 56, 44, 50,
  52, 54, 44, 50, 52, 54, 44, 50, 52, 54, 44, 50, 52, 53, 44, 50,
  52, 54, 44, 92, 10, 50, 52, 53, 44, 50, 52, 53, 44, 50, 52, 53,
  44, 50, 52, 54, 44, 50, 52, 54, 44, 50, 52, 54, 44, 50, 52, 54,
  44, 50, 52, 54, 44, 50, 52, 54, 44, 50, 52, 54, 44, 50, 52, 54,
  44, 50, 52, 53, 44, 50, 52, 53, 44, 50, 52, 53, 44, 50, 52, 53,
  44, 50, 52, 53, 44, 50, 52, 52, 44, 50, 52, 53, 44, 50, 52, 52,
  44, 50, 52, 53, 44, 50, 52, 53, 44, 50, 52, 53, 44, 50, 52, 53,
  44, 50, 52, 53, 44, 50, 52, 53, 44, 50, 52, 53, 44, 50, 52, 53,
  44, 92, 10, 50, 52, 53, 44, 50, 52, 52, 44, 50, 52, 52, 44, 50,
  52, 53, 44, 50, 52, 53, 44, 50, 52, 51, 44, 50, 51, 57, 44, 50,
  51, 53, 44, 50, 51, 48, 44, 50, 50, 54, 44, 50, 50, 48, 44, 50,
  49, 54, 44, 50, 49, 49, 44, 50, 48, 52, 44, 50, 48, 49, 44, 49,
  57, 52, 44, 49, 57, 48, 44, 49, 56, 52, 44, 49, 55, 54, 44, 49,
  55, 49, 44, 49, 54, 52, 44, 49, 54, 48, 44, 49, 53, 50, 44, 49,
  52, 52, 44, 49, 51, 56, 44, 49, 51, 48, 44, 49, 50, 50, 44, 92,
  10, 49, 49, 52, 44, 49, 48, 55, 44, 57, 54, 44, 56, 55, 44, 55,
  56, 44, 54, 57, 44, 53, 55, 44, 53, 48, 44, 52, 54, 44, 51, 56,
  44, 51, 49, 44, 49, 57, 44, 53, 94, 51, 44, 49, 48, 44, 49, 52,
  44, 49, 53, 44, 49, 55, 44, 49, 56, 44, 49, 57, 44, 49, 56, 44,
  49, 57, 44, 50, 51, 44, 50, 53, 44, 51, 48, 44, 51, 49, 44, 51,
  53, 44, 51, 55, 44, 51, 57, 44, 52, 50, 44, 52, 52, 44, 52, 53,
  44, 52, 56, 44, 52, 57, 44, 53, 48, 44, 53, 49, 44, 92, 10, 53,
  50, 44, 53, 51, 44, 53, 54, 44, 53, 57, 44, 54, 51, 44, 54, 54,
  44, 54, 54, 44, 54, 56, 44, 54, 57, 44, 55, 49, 44, 55, 51, 44,
  55, 52, 44, 55, 53, 44, 55, 54, 44, 55, 54, 44, 55, 55, 44, 55,
  56, 44, 55, 57, 44, 55, 57, 44, 56, 48, 44, 56, 49, 44, 56, 49,
  44, 56, 50, 44, 56, 50, 44, 56, 51, 44, 56, 52, 44, 56, 52, 44,
  56, 52, 44, 56, 52, 44, 56, 52, 44, 56, 53, 44, 56, 53, 44, 56,
  54, 44, 56, 54, 44, 56, 54, 44, 56, 54, 44, 92, 10, 56, 55, 44,
  56, 56, 44, 56, 55, 44, 56, 54, 44, 56, 54, 44, 56, 54, 44, 56,
  54, 44, 56, 56, 44, 56, 57, 44, 56, 57, 44, 57, 48, 44, 57, 50,
  44, 57, 50, 44, 57, 52, 44, 57, 54, 44, 57, 57, 44, 49, 48, 50,
  44, 49, 48, 52, 44, 49, 48, 55, 44, 49, 49, 49, 44, 49, 49, 55,
  44, 49, 50, 48, 44, 49, 50, 54, 44, 49, 51, 48, 44, 49, 51, 54,
  44, 49, 52, 50, 44, 49, 52, 57, 44, 49, 53, 53, 44, 49, 54, 49,
  44, 49, 54, 55, 44, 49, 55, 50, 44, 92, 10, 49, 55, 54, 44, 49,
  55, 56, 44, 49, 55, 57, 44, 49, 55, 57, 44, 49, 55, 56, 44, 49,
  55, 56, 44, 49, 55, 56, 44, 49, 55, 56, 44, 49, 55, 55, 44, 49,
  55, 55, 44, 49, 55, 55, 44, 49, 55, 54, 44, 49, 55, 54, 44, 49,
  55, 54, 44, 49, 55, 54, 44, 49, 55, 53, 44, 49, 55, 51, 44, 49,
  55, 51, 44, 49, 55, 52, 44, 49, 55, 51, 44, 49, 55, 50, 44, 49,
  55, 49, 44, 49, 55, 49, 44, 49, 55, 49, 44, 49, 55, 49, 44, 49,
  55, 49, 44, 49, 55, 49, 44, 92, 10, 49, 55, 49, 44, 49, 55, 49,
  44, 49, 55, 49, 44, 49, 55, 49, 44, 49, 55, 49, 44, 49, 55, 49,
  44, 49, 55, 49, 44, 49, 55, 49, 44, 49, 55, 49, 44, 49, 55, 49,
  44, 49, 55, 49, 44, 49, 55, 49, 44, 49, 55, 49, 44, 49, 55, 49,
  44, 49, 55, 49, 44, 49, 55, 49, 44, 49, 55, 51, 44, 49, 55, 51,
  44, 49, 55, 51, 44, 49, 55, 53, 44, 49, 55, 54, 44, 49, 55, 56,
  44, 49, 55, 56, 44, 49, 55, 56, 44, 49, 56, 49, 44, 49, 56, 50,
  44, 49, 56, 52, 44, 92, 10, 49, 56, 54, 44, 49, 56, 54, 44, 49,
  57, 48, 44, 49, 57, 50, 44, 49, 57, 51, 44, 49, 57, 53, 44, 49,
  57, 56, 44, 50, 48, 48, 44, 50, 48, 49, 44, 50, 48, 52, 44, 50,
  48, 54, 44, 50, 48, 57, 44, 50, 49, 49, 44, 50, 48, 56, 44, 50,
  48, 54, 44, 50, 48, 50, 44, 49, 57, 55, 44, 49, 57, 52, 44, 49,
  57, 48, 44, 49, 56, 53, 44, 49, 56, 50, 44, 49, 55, 56, 44, 49,
  55, 50, 44, 49, 54, 55, 44, 49, 54, 50, 44, 49, 53, 55, 44, 49,
  53, 50, 44, 92, 10, 49, 52, 52, 44, 49, 51, 57, 44, 49, 51, 50,
  44, 49, 50, 55, 44, 49, 50, 49, 44, 49, 49, 53, 44, 49, 48, 56,
  44, 49, 48, 50, 44, 57, 56, 44, 57, 50, 44, 56, 55, 44, 55, 57,
  44, 55, 53, 44, 54, 57, 44, 54, 52, 44, 54, 50, 44, 53, 56, 44,
  53, 53, 44, 53, 50, 44, 53, 48, 44, 52, 57, 44, 52, 55, 44, 52,
  55, 44, 52, 55, 44, 52, 55, 44, 52, 55, 44, 52, 55, 44, 52, 55,
  44, 52, 55, 44, 52, 54, 44, 52, 54, 44, 52, 54, 44, 52, 54, 44,
  92, 10, 52, 53, 44, 52, 52, 44, 52, 52, 44, 52, 50, 44, 52, 50,
  44, 52, 49, 44, 52, 49, 44, 52, 48, 44, 51, 57, 44, 51, 56, 44,
  51, 55, 44, 51, 54, 44, 51, 52, 44, 51, 49, 44, 51, 48, 44, 50,
  57, 44, 51, 48, 44, 51, 48, 44, 51, 49, 44, 51, 50, 44, 51, 50,
  44, 51, 50, 44, 51, 51, 44, 51, 51, 44, 51, 52, 44, 51, 52, 44,
  51, 51, 44, 51, 52, 44, 51, 51, 44, 51, 50, 44, 51, 49, 44, 51,
  49, 44, 51, 48, 44, 50, 57, 44, 50, 54, 44, 50, 53, 44, 92, 10,
  50, 51, 44, 50, 49, 44, 49, 57, 44, 49, 53, 44, 49, 51, 44, 49,
  51, 44, 49, 54, 44, 49, 56, 44, 49, 56, 44, 49, 56, 44, 49, 55,
  44, 49, 53, 44, 49, 51, 44, 49, 50, 44, 57, 44, 50, 94, 54, 44,
  49, 57, 44, 50, 53, 44, 51, 50, 44, 52, 49, 44, 52, 57, 44, 53,
  53, 44, 54, 53, 44, 55, 49, 44, 55, 57, 44, 56, 52, 44, 57, 48,
  44, 57, 54, 44, 49, 48, 50, 44, 49, 48, 54, 44, 49, 49, 49, 44,
  49, 49, 55, 44, 49, 50, 49, 44, 49, 50, 56, 44, 92, 10, 49, 51,
  50, 44, 49, 51, 52, 44, 49, 51, 57, 44, 49, 52, 51, 44, 49, 52,
  54, 44, 49, 52, 57, 44, 49, 53, 50, 44, 49, 53, 53, 44, 49, 53,
  54, 44, 49, 53, 55, 44, 49, 53, 57, 44, 49, 53, 57, 44, 49, 54,
  48, 44, 49, 54, 49, 44, 49, 54, 50, 44, 49, 54, 51, 44, 49, 54,
  52, 44, 49, 54, 52, 44, 49, 54, 53, 44, 49, 54, 54, 44, 49, 54,
  55, 44, 49, 54, 54, 44, 49, 54, 53, 44, 49, 54, 54, 44, 49, 54,
  54, 44, 49, 54, 55, 44, 49, 54, 55, 44, 92, 10, 49, 54, 56, 44,
  49, 54, 56, 44, 49, 54, 56, 44, 49, 54, 57, 44, 49, 54, 57, 44,
  49, 54, 57, 44, 49, 54, 57, 44, 49, 55, 48, 44, 49, 55, 48, 44,
  49, 55, 48, 44, 49, 55, 48, 44, 49, 55, 48, 44, 49, 55, 48, 44,
  49, 55, 48, 44, 49, 55, 49, 44, 49, 55, 48, 44, 49, 55, 48, 44,
  49, 55, 48, 44, 49, 55, 48, 44, 49, 55, 48, 44, 49, 55, 49, 44,
  49, 55, 49, 44, 49, 55, 50, 44, 49, 55, 51, 44, 49, 55, 51, 44,
  49, 55, 51, 44, 49, 55, 53, 44, 92, 10, 49, 55, 55, 44, 49, 55,
  57, 44, 49, 56, 48, 44, 49, 56, 51, 44, 49, 56, 53, 44, 49, 56,
  55, 44, 49, 57, 48, 44, 49, 57, 51, 44, 49, 57, 56, 44, 50, 48,
  49, 44, 50, 48, 54, 44, 50, 49, 51, 44, 50, 49, 57, 44, 50, 50,
  53, 44, 50, 50, 55, 44, 50, 50, 55, 44, 50, 50, 51, 44, 50, 49,
  56, 44, 50, 49, 52, 44, 50, 48, 52, 44, 49, 57, 57, 44, 49, 57,
  50, 44, 49, 56, 52, 44, 49, 55, 57, 44, 49, 55, 50, 44, 49, 54,
  56, 44, 49, 54, 50, 44, 92, 10, 49, 53, 54, 44, 49, 53, 49, 44,
  49, 52, 53, 44, 49, 51, 57, 44, 49, 51, 51, 44, 49, 50, 54, 44,
  49, 50, 48, 44, 49, 49, 51, 44, 49, 48, 54, 44, 57, 56, 44, 57,
  48, 44, 56, 53, 44, 56, 50, 44, 56, 50, 44, 56, 50, 44, 56, 50,
  44, 56, 50, 44, 56, 50, 44, 56, 50, 44, 56, 50, 44, 56, 50, 44,
  56, 50, 44, 56, 50, 44, 56, 50, 44, 56, 50, 44, 56, 50, 44, 56,
  50, 44, 56, 50, 44, 56, 52, 44, 56, 52, 44, 56, 50, 44, 56, 50,
  44, 56, 50, 44, 92, 10, 56, 50, 44, 56, 50, 44, 56, 51, 44, 56,
  51, 44, 56, 49, 44, 56, 49, 44, 56, 49, 44, 56, 48, 44, 56, 48,
  44, 55, 56, 44, 55, 56, 44, 55, 56, 44, 55, 54, 44, 55, 52, 44,
  55, 51, 44, 55, 51, 44, 55, 49, 44, 55, 50, 44, 54, 57, 44, 54,
  56, 44, 54, 55, 44, 54, 53, 44, 54, 50, 44, 53, 57, 44, 53, 56,
  44, 53, 54, 44, 53, 49, 44, 53, 48, 44, 52, 57, 44, 52, 53, 44,
  52, 51, 44, 52, 48, 44, 51, 56, 44, 51, 55, 44, 51, 53, 44, 51,
  50, 44, 92, 10, 51, 49, 44, 51, 50, 44, 51, 50, 44, 51, 51, 44,
  51, 51, 44, 51, 52, 44, 51, 52, 44, 51, 53, 44, 51, 54, 44, 51,
  54, 44, 51, 55, 44, 51, 56, 44, 51, 57, 44, 52, 50, 44, 52, 52,
  44, 52, 53, 44, 52, 54, 44, 52, 54, 44, 52, 55, 44, 52, 56, 44,
  52, 57, 44, 52, 56, 44, 52, 56, 44, 52, 56, 44, 52, 56, 44, 52,
  56, 44, 52, 56, 44, 52, 56, 44, 52, 56, 44, 52, 56, 44, 52, 56,
  44, 52, 55, 44, 52, 55, 44, 52, 55, 44, 52, 55, 44, 52, 54, 44,
  92, 10, 52, 53, 44, 52, 53, 44, 52, 51, 44, 52, 51, 44, 52, 50,
  44, 52, 49, 44, 52, 48, 44, 51, 57, 44, 51, 56, 44, 51, 55, 44,
  51, 56, 44, 51, 56, 44, 51, 55, 44, 51, 55, 44, 51, 56, 44, 51,
  56, 44, 51, 56, 44, 51, 56, 44, 51, 57, 44, 52, 48, 44, 51, 57,
  44, 52, 48, 44, 51, 57, 44, 52, 48, 44, 52, 48, 44, 51, 57, 44,
  51, 57, 44, 51, 56, 44, 51, 56, 44, 51, 55, 44, 51, 53, 44, 51,
  52, 44, 51, 50, 44, 51, 48, 44, 50, 56, 44, 50, 54, 44, 92, 10,
  50, 51, 44, 50, 48, 44, 49, 54, 44, 49, 52, 44, 49, 50, 44, 49,
  54, 44, 49, 54, 44, 49, 56, 44, 49, 56, 44, 49, 55, 44, 49, 54,
  44, 49, 52, 44, 49, 51, 44, 57, 44, 50, 41, 10, 45, 110, 109, 91,
  45, 49, 93, 32, 91, 114, 97, 105, 110, 98, 111, 119, 92, 32, 108, 117,
  116, 93, 10, 45, 118, 32, 43, 10, 114, 111, 100, 100, 121, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 76, 111, 97, 100, 32, 105, 109,
  97, 103, 101, 32, 111, 102, 32, 116, 104, 101, 32, 71, 39, 77, 73, 67,
  32, 82, 111, 100, 105, 108, 105, 117, 115, 32, 109, 97, 115, 99, 111, 116,
  32, 39, 82, 111, 100, 100, 121, 39, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 105, 32, 104, 116, 116, 112, 58, 47, 47, 103, 109, 105, 99, 46, 115,
  111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 105,
  109, 103, 47, 114, 111, 100, 100, 121, 95, 108, 97, 114, 103, 101, 46, 99,
  105, 109, 103, 122, 32, 45, 110, 109, 91, 45, 49, 93, 32, 91, 114, 111,
  100, 100, 121, 93, 32, 45, 118, 32, 43, 10, 114, 101, 109, 111, 118, 101,
  95, 100, 117, 112, 108, 105, 99, 97, 116, 101, 115, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 82, 101, 109, 111, 118, 101, 32, 100, 117,
  112, 108, 105, 99, 97, 116, 101, 115, 32, 105, 109, 97, 103, 101, 115, 32,
  105, 110, 32, 115, 101, 108, 101, 99, 116, 101, 100, 32, 108, 105, 115, 116,
  32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 98, 97,
  115, 101, 61, 36, 62, 32, 111, 102, 102, 61, 48, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 64, 35, 45, 36, 62, 45, 49, 125, 10, 99, 111,
  109, 112, 61, 123, 36, 98, 97, 115, 101, 43, 49, 43, 36, 62, 45, 36,
  111, 102, 102, 125, 10, 45, 105, 102, 32, 123, 36, 99, 111, 109, 112, 62,
  61, 64, 35, 125, 32, 45, 98, 114, 101, 97, 107, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 45, 45, 91, 36, 98, 97, 115, 101, 44, 36, 99, 111,
  109, 112, 93, 32, 45, 97, 98, 115, 91, 45, 49, 93, 32, 105, 115, 95,
  100, 117, 112, 108, 105, 99, 97, 116, 101, 61, 123, 33, 64, 123, 45, 49,
  44, 43, 125, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 105, 102,
  32, 36, 105, 115, 95, 100, 117, 112, 108, 105, 99, 97, 116, 101, 32, 45,
  114, 109, 91, 36, 99, 111, 109, 112, 93, 32, 111, 102, 102, 61, 123, 36,
  111, 102, 102, 43, 49, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 100,
  111, 110, 101, 10, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 114,
  101, 109, 111, 118, 101, 95, 101, 109, 112, 116, 121, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 82, 101, 109, 111, 118, 101, 32, 101, 109,
  112, 116, 121, 32, 105, 109, 97, 103, 101, 115, 32, 105, 110, 32, 115, 101,
  108, 101, 99, 116, 101, 100, 32, 108, 105, 115, 116, 32, 111, 102, 32, 105,
  109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 105, 102, 32, 123, 33, 64,
  123, 36, 60, 44, 119, 104, 100, 115, 125, 125, 32, 45, 114, 109, 91, 36,
  60, 93, 32, 45, 101, 110, 100, 105, 102, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 116, 101, 115, 116, 105, 109, 97, 103, 101, 50, 100,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 53,
  49, 50, 125, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 36, 49, 125,
  62, 48, 32, 38, 38, 32, 36, 123, 51, 61, 51, 125, 62, 48, 34, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 50,
  100, 32, 115, 121, 110, 116, 104, 101, 116, 105, 99, 32, 105, 109, 97, 103,
  101, 32, 111, 102, 32, 115, 105, 122, 101, 32, 36, 49, 120, 36, 50, 120,
  36, 51, 46, 34, 10, 45, 118, 32, 45, 10, 68, 109, 97, 120, 50, 61,
  123, 48, 46, 49, 53, 42, 109, 105, 110, 40, 36, 49, 44, 36, 50, 41,
  94, 50, 125, 10, 36, 49, 44, 36, 50, 44, 49, 44, 36, 51, 44, 39,
  88, 61, 120, 45, 119, 47, 50, 59, 89, 61, 121, 45, 104, 47, 50, 59,
  97, 61, 97, 116, 97, 110, 50, 40, 89, 44, 88, 41, 59, 105, 102, 40,
  88, 94, 50, 43, 89, 94, 50, 60, 61, 36, 68, 109, 97, 120, 50, 44,
  50, 53, 53, 42, 97, 98, 115, 40, 99, 111, 115, 40, 99, 43, 50, 48,
  48, 42, 40, 120, 47, 119, 45, 48, 46, 53, 41, 42, 40, 121, 47, 104,
  45, 48, 46, 53, 41, 41, 41, 44, 56, 53, 48, 42, 40, 97, 37, 40,
  48, 46, 49, 42, 40, 99, 43, 49, 41, 41, 41, 41, 39, 10, 45, 112,
  111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 52, 44, 50, 48, 37,
  44, 50, 48, 37, 44, 54, 48, 37, 44, 50, 48, 37, 44, 55, 48, 37,
  44, 55, 48, 37, 44, 51, 53, 37, 44, 52, 53, 37, 44, 48, 46, 57,
  44, 48, 44, 50, 53, 53, 44, 48, 10, 45, 116, 111, 114, 117, 115, 51,
  100, 32, 123, 36, 49, 47, 55, 125, 44, 123, 36, 49, 47, 50, 48, 125,
  32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 49, 44, 49, 44,
  56, 48, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 49, 50,
  56, 44, 50, 48, 48, 44, 50, 53, 53, 10, 45, 111, 98, 106, 101, 99,
  116, 51, 100, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 51, 48, 37,
  44, 55, 48, 37, 44, 48, 44, 49, 44, 53, 44, 48, 44, 48, 32, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49,
  93, 32, 49, 10, 45, 110, 109, 91, 45, 49, 93, 32, 34, 91, 50, 100,
  32, 116, 101, 115, 116, 32, 105, 109, 97, 103, 101, 93, 34, 10, 45, 118,
  32, 43, 10, 116, 101, 120, 116, 50, 105, 109, 103, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 34, 36, 123, 50, 61, 32, 125, 34, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 105, 109, 97, 103,
  101, 32, 102, 114, 111, 109, 32, 116, 101, 120, 116, 32, 92, 34, 36, 49,
  92, 34, 44, 32, 119, 105, 116, 104, 32, 108, 105, 110, 101, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 32, 39, 36, 50, 39, 46, 34, 10, 45,
  118, 32, 45, 32, 40, 123, 39, 34, 36, 49, 34, 39, 125, 41, 32, 45,
  108, 91, 45, 49, 93, 32, 45, 115, 32, 45, 44, 123, 39, 34, 36, 50,
  34, 39, 125, 32, 45, 121, 32, 120, 32, 45, 97, 32, 121, 32, 45, 110,
  109, 32, 34, 91, 92, 34, 36, 49, 92, 34, 93, 34, 32, 45, 101, 110,
  100, 108, 32, 45, 118, 32, 43, 10, 117, 110, 105, 102, 111, 114, 109, 95,
  100, 105, 115, 116, 114, 105, 98, 117, 116, 105, 111, 110, 32, 58, 32, 45,
  99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 49, 41,
  32, 38, 38, 32, 36, 49, 62, 48, 32, 38, 38, 32, 105, 115, 105, 110,
  116, 40, 36, 50, 41, 32, 38, 38, 32, 36, 50, 62, 48, 34, 10, 45,
  101, 91, 94, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 115, 101, 116,
  32, 111, 102, 32, 36, 49, 32, 117, 110, 105, 102, 111, 114, 109, 108, 121,
  32, 100, 105, 115, 116, 114, 105, 98, 117, 116, 101, 100, 32, 36, 50, 45,
  100, 32, 112, 111, 105, 110, 116, 115, 32, 105, 110, 32, 91, 48, 44, 49,
  93, 94, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 110, 61, 123, 114,
  111, 117, 110, 100, 40, 36, 49, 94, 40, 49, 47, 36, 50, 41, 44, 49,
  44, 49, 41, 125, 10, 40, 48, 44, 49, 41, 32, 45, 114, 91, 45, 49,
  93, 32, 36, 110, 44, 49, 44, 49, 44, 49, 44, 51, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 36, 50, 45, 49, 125, 32, 45, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 49, 48, 48, 37, 32,
  45, 114, 91, 45, 49, 93, 32, 123, 36, 110, 42, 119, 125, 44, 49, 44,
  49, 44, 49, 44, 49, 32, 45, 114, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 49, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44, 50, 32, 45,
  97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 100, 111, 110, 101,
  10, 45, 114, 91, 45, 49, 93, 32, 36, 49, 44, 49, 44, 49, 44, 36,
  50, 44, 49, 32, 45, 110, 109, 91, 45, 49, 93, 32, 34, 91, 117, 110,
  105, 102, 111, 114, 109, 32, 36, 50, 100, 32, 100, 105, 115, 116, 114, 105,
  98, 117, 116, 105, 111, 110, 93, 34, 32, 45, 118, 32, 43, 10, 117, 112,
  32, 58, 10, 45, 95, 117, 112, 100, 97, 116, 101, 10, 117, 112, 100, 97,
  116, 101, 32, 58, 10, 45, 95, 36, 48, 10, 95, 117, 112, 100, 97, 116,
  101, 32, 58, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 85, 112,
  100, 97, 116, 101, 32, 99, 111, 109, 109, 97, 110, 100, 115, 32, 102, 114,
  111, 109, 32, 116, 104, 101, 32, 108, 97, 116, 101, 115, 116, 32, 100, 101,
  102, 105, 110, 105, 116, 105, 111, 110, 32, 102, 105, 108, 101, 32, 111, 110,
  32, 116, 104, 101, 32, 71, 39, 77, 73, 67, 32, 115, 101, 114, 118, 101,
  114, 46, 34, 10, 45, 118, 32, 45, 32, 45, 109, 32, 104, 116, 116, 112,
  58, 47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111,
  114, 103, 101, 46, 110, 101, 116, 47, 117, 112, 100, 97, 116, 101, 64, 46,
  46, 103, 109, 105, 99, 32, 45, 118, 32, 43, 10, 115, 111, 114, 116, 95,
  108, 105, 115, 116, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49,
  61, 43, 125, 44, 36, 123, 50, 61, 105, 125, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 83, 111, 114, 116, 32, 108, 105, 115, 116, 32, 111, 102,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 105, 110, 32, 34, 64, 123, 45,
  97, 114, 103, 92, 32, 49, 43, 123, 36, 49, 39, 61, 61, 39, 43, 125,
  44, 100, 101, 115, 99, 101, 110, 100, 105, 110, 103, 44, 97, 115, 99, 101,
  110, 100, 105, 110, 103, 125, 34, 32, 111, 114, 100, 101, 114, 44, 32, 34,
  92, 10, 34, 97, 99, 99, 111, 114, 100, 105, 110, 103, 32, 116, 111, 32,
  116, 104, 101, 32, 105, 109, 97, 103, 101, 32, 99, 114, 105, 116, 101, 114,
  105, 111, 110, 32, 39, 36, 50, 39, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 105, 102, 32, 64, 35, 10, 105, 61, 64, 35, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 40, 64, 123, 36, 62, 44, 36, 50, 125,
  41, 32, 45, 100, 111, 110, 101, 32, 45, 97, 91, 36, 105, 45, 45, 49,
  93, 32, 121, 32, 45, 45, 102, 91, 45, 49, 93, 32, 39, 121, 39, 32,
  45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 115, 111, 114,
  116, 91, 45, 49, 93, 32, 36, 49, 44, 121, 32, 45, 122, 91, 45, 49,
  93, 32, 49, 44, 49, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 104,
  125, 32, 110, 109, 36, 62, 61, 64, 123, 36, 62, 44, 110, 125, 32, 45,
  110, 109, 91, 36, 62, 93, 32, 115, 111, 114, 116, 108, 105, 115, 116, 36,
  62, 32, 45, 100, 111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 104, 125, 32, 45, 109, 118, 91, 115, 111, 114, 116, 108, 105, 115, 116,
  123, 105, 40, 48, 44, 36, 62, 41, 125, 93, 32, 45, 49, 32, 45, 100,
  111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 104, 125, 32,
  45, 110, 109, 91, 36, 62, 93, 32, 36, 123, 110, 109, 123, 105, 40, 48,
  44, 36, 62, 41, 125, 125, 32, 45, 100, 111, 110, 101, 10, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 32, 45, 118, 32, 43,
  10, 115, 111, 114, 116, 95, 115, 116, 114, 32, 58, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 83, 111, 114, 116, 32, 105, 109, 97, 103, 101, 36,
  63, 32, 105, 110, 32, 108, 101, 120, 105, 99, 111, 103, 114, 97, 112, 104,
  105, 99, 32, 111, 114, 100, 101, 114, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 121, 32, 45, 97, 32, 120, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 114, 111, 117, 110, 100, 40, 104, 47, 52, 44, 49, 44, 49, 41, 125,
  32, 121, 61, 123, 52, 42, 36, 62, 125, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 60, 93, 10, 45, 45, 114, 111,
  119, 115, 32, 36, 121, 44, 123, 36, 121, 43, 51, 125, 32, 45, 102, 91,
  49, 93, 32, 39, 105, 102, 40, 105, 62, 61, 57, 55, 38, 38, 105, 60,
  61, 49, 50, 50, 44, 105, 45, 51, 50, 44, 105, 41, 39, 32, 45, 45,
  91, 45, 49, 93, 32, 51, 50, 32, 45, 99, 91, 45, 49, 93, 32, 48,
  44, 54, 51, 32, 45, 115, 91, 45, 49, 93, 32, 121, 32, 45, 42, 91,
  45, 50, 93, 32, 54, 52, 32, 45, 42, 91, 45, 51, 93, 32, 52, 48,
  57, 54, 32, 45, 42, 91, 45, 52, 93, 32, 50, 54, 50, 49, 52, 52,
  32, 45, 43, 91, 45, 52, 45, 45, 49, 93, 10, 45, 114, 118, 32, 45,
  97, 32, 121, 32, 45, 115, 111, 114, 116, 32, 43, 44, 120, 32, 45, 45,
  114, 111, 119, 115, 32, 48, 32, 45, 114, 111, 119, 115, 91, 48, 93, 32,
  49, 44, 49, 48, 48, 37, 32, 45, 108, 97, 98, 101, 108, 91, 49, 93,
  32, 45, 37, 91, 49, 93, 32, 50, 10, 45, 115, 91, 49, 93, 32, 43,
  44, 48, 32, 78, 61, 123, 64, 35, 45, 49, 125, 10, 120, 48, 61, 48,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 32,
  120, 49, 61, 123, 36, 120, 48, 43, 64, 123, 123, 49, 43, 36, 62, 125,
  44, 104, 125, 125, 32, 45, 45, 122, 91, 48, 93, 32, 36, 120, 48, 44,
  123, 36, 120, 49, 45, 49, 125, 32, 120, 48, 61, 36, 120, 49, 32, 45,
  100, 111, 110, 101, 10, 45, 114, 109, 91, 48, 45, 36, 78, 93, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 100, 111, 110, 101,
  32, 45, 115, 32, 120, 32, 45, 118, 32, 43, 10, 97, 112, 112, 108, 121,
  95, 99, 117, 114, 118, 101, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 36, 123, 49, 61, 49, 125, 62, 61, 48, 32, 38, 38, 32, 36, 49,
  60, 61, 49, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 48,
  125, 44, 36, 123, 51, 61, 49, 48, 48, 125, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 105, 110, 116, 101, 110, 115,
  105, 116, 121, 32, 99, 117, 114, 118, 101, 32, 119, 105, 116, 104, 32, 115,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 49, 32, 97, 110, 100,
  32, 107, 101, 121, 112, 111, 105, 110, 116, 115, 32, 40, 36, 123, 50, 45,
  45, 49, 125, 41, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 102, 117, 110, 99, 116, 105, 111, 110,
  49, 100, 32, 36, 123, 94, 48, 125, 32, 45, 109, 97, 112, 91, 94, 45,
  49, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 118, 32, 43, 10, 97, 112, 112, 108, 121, 95, 103, 97, 109, 109, 97,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 49, 62, 61, 48, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 71,
  97, 109, 109, 97, 45, 99, 111, 114, 114, 101, 99, 116, 105, 111, 110, 32,
  116, 111, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104,
  32, 103, 97, 109, 109, 97, 32, 36, 49, 46, 34, 10, 45, 105, 102, 32,
  123, 36, 49, 61, 61, 49, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 109, 77,
  61, 123, 105, 109, 125, 44, 123, 105, 77, 125, 32, 45, 110, 32, 48, 44,
  49, 32, 45, 94, 32, 123, 49, 47, 36, 49, 125, 32, 45, 110, 32, 36,
  109, 77, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 98, 97, 108, 97, 110, 99, 101, 95, 103, 97, 109, 109,
  97, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 50,
  56, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108,
  121, 32, 99, 111, 108, 111, 114, 32, 98, 97, 108, 97, 110, 99, 101, 32,
  116, 114, 97, 110, 115, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 111,
  110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32,
  103, 97, 109, 109, 97, 32, 99, 117, 114, 118, 101, 32, 97, 110, 100, 32,
  114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 99, 111, 108, 111, 114, 32,
  40, 34, 36, 123, 94, 48, 125, 34, 41, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 40, 36, 123, 94, 48, 125, 41, 32, 45, 114, 91, 45, 49,
  93, 32, 64, 123, 45, 50, 44, 115, 125, 44, 49, 44, 49, 44, 49, 44,
  48, 44, 49, 32, 45, 115, 91, 45, 50, 93, 32, 99, 32, 45, 47, 91,
  45, 49, 93, 32, 50, 53, 53, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 64, 35, 45, 49, 125, 32, 45, 47, 91, 36, 62, 93, 32, 50, 53,
  53, 32, 45, 94, 91, 36, 62, 93, 32, 123, 108, 111, 103, 40, 64, 123,
  45, 49, 44, 36, 62, 125, 41, 47, 108, 111, 103, 40, 64, 123, 36, 62,
  44, 97, 125, 41, 125, 32, 45, 42, 91, 36, 62, 93, 32, 50, 53, 53,
  32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  97, 32, 99, 32, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 99, 111,
  109, 112, 108, 101, 120, 50, 112, 111, 108, 97, 114, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 99,
  111, 109, 112, 108, 101, 120, 32, 116, 111, 32, 112, 111, 108, 97, 114, 32,
  116, 114, 97, 110, 115, 102, 111, 114, 109, 115, 32, 111, 102, 32, 105, 109,
  97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125,
  32, 45, 108, 91, 123, 50, 42, 36, 62, 125, 44, 123, 50, 42, 36, 62,
  43, 49, 125, 93, 10, 45, 114, 91, 49, 93, 32, 91, 48, 93, 44, 51,
  32, 45, 45, 97, 116, 97, 110, 50, 91, 49, 93, 32, 91, 48, 93, 32,
  45, 110, 109, 91, 45, 49, 93, 32, 64, 123, 49, 44, 110, 125, 44, 49,
  32, 45, 115, 113, 114, 91, 45, 51, 44, 45, 50, 93, 32, 45, 43, 91,
  45, 51, 44, 45, 50, 93, 32, 45, 115, 113, 114, 116, 91, 45, 50, 93,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 99, 111, 109, 112, 114, 101, 115, 115, 95, 114, 108, 101, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 114, 101,
  115, 115, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 117, 115, 105, 110,
  103, 32, 82, 76, 69, 32, 97, 108, 103, 111, 114, 105, 116, 104, 109, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44,
  110, 125, 32, 105, 109, 61, 123, 105, 109, 125, 32, 119, 104, 100, 115, 61,
  123, 119, 125, 59, 123, 104, 125, 59, 123, 100, 125, 59, 123, 115, 125, 59,
  36, 105, 109, 10, 45, 45, 32, 36, 105, 109, 32, 45, 121, 32, 120, 32,
  40, 123, 64, 123, 48, 44, 45, 49, 125, 43, 49, 125, 41, 32, 45, 97,
  32, 120, 32, 45, 114, 32, 49, 48, 48, 37, 44, 51, 10, 45, 102, 91,
  45, 49, 93, 32, 39, 62, 105, 102, 40, 121, 61, 61, 48, 44, 105, 44,
  105, 102, 40, 121, 61, 61, 49, 44, 105, 102, 40, 105, 40, 120, 44, 48,
  41, 61, 61, 105, 40, 120, 43, 49, 44, 48, 41, 44, 45, 49, 44, 120,
  41, 44, 105, 102, 40, 105, 40, 120, 45, 49, 44, 49, 41, 61, 61, 45,
  49, 44, 105, 40, 120, 45, 49, 44, 50, 41, 43, 49, 44, 49, 41, 41,
  41, 39, 10, 45, 122, 32, 48, 44, 123, 119, 45, 50, 125, 32, 45, 115,
  32, 121, 44, 51, 32, 45, 100, 105, 115, 99, 97, 114, 100, 91, 49, 93,
  32, 45, 49, 32, 45, 119, 97, 114, 112, 91, 48, 44, 50, 93, 32, 91,
  49, 93, 44, 48, 44, 48, 32, 45, 114, 109, 91, 49, 93, 10, 45, 42,
  91, 45, 49, 93, 32, 45, 49, 32, 45, 114, 118, 32, 45, 97, 32, 120,
  32, 45, 121, 32, 45, 100, 105, 115, 99, 97, 114, 100, 32, 45, 49, 32,
  45, 102, 32, 39, 62, 105, 102, 40, 105, 40, 48, 44, 121, 45, 49, 41,
  60, 48, 38, 38, 105, 61, 61, 48, 38, 38, 105, 40, 48, 44, 121, 43,
  49, 41, 60, 48, 44, 45, 49, 44, 105, 41, 39, 32, 45, 100, 105, 115,
  99, 97, 114, 100, 32, 45, 49, 10, 45, 105, 91, 48, 93, 32, 40, 36,
  119, 104, 100, 115, 41, 32, 45, 97, 32, 121, 32, 45, 110, 109, 32, 36,
  110, 109, 44, 49, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 99, 117, 109, 117, 108, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 99,
  117, 109, 117, 108, 97, 116, 105, 118, 101, 32, 111, 102, 32, 102, 117, 110,
  99, 116, 105, 111, 110, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 100, 105, 109, 61, 123, 119, 125, 44, 123, 104, 125, 44, 123, 100, 125,
  44, 123, 115, 125, 32, 45, 121, 32, 120, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 114, 111, 117, 110, 100, 40, 108, 111, 103, 50, 40, 119, 41,
  44, 49, 44, 49, 41, 125, 32, 45, 45, 115, 104, 105, 102, 116, 91, 45,
  49, 93, 32, 123, 50, 94, 36, 62, 125, 32, 45, 43, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 114, 32, 36, 100, 105,
  109, 44, 45, 49, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 100, 105, 115, 99, 97, 114, 100, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 48, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 82, 101, 109, 111, 118, 101, 32, 118, 97, 108,
  117, 101, 32, 36, 49, 32, 105, 110, 32, 105, 109, 97, 103, 101, 36, 63,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 32, 45, 44, 36,
  49, 32, 45, 97, 32, 121, 10, 45, 105, 102, 32, 123, 33, 64, 35, 34,
  32, 38, 38, 32, 34, 33, 36, 50, 125, 32, 49, 44, 49, 44, 49, 44,
  49, 44, 36, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 101, 105, 103,
  101, 110, 50, 116, 101, 110, 115, 111, 114, 32, 58, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 82, 101, 99, 111, 109, 112, 111, 115, 101, 32, 112,
  97, 105, 114, 115, 32, 105, 110, 32, 101, 105, 103, 101, 110, 32, 102, 105,
  101, 108, 100, 36, 63, 32, 97, 115, 32, 50, 120, 50, 32, 111, 114, 32,
  51, 120, 51, 32, 116, 101, 110, 115, 111, 114, 32, 102, 105, 101, 108, 100,
  115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 123, 64, 35, 47, 50, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36,
  62, 43, 49, 125, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10,
  45, 105, 102, 32, 123, 115, 61, 61, 50, 125, 10, 45, 115, 91, 45, 49,
  93, 32, 99, 10, 45, 45, 115, 113, 114, 91, 45, 49, 93, 32, 45, 42,
  91, 45, 50, 93, 32, 91, 45, 51, 93, 32, 45, 115, 113, 114, 91, 45,
  51, 93, 10, 45, 115, 104, 91, 45, 49, 93, 32, 45, 45, 42, 91, 45,
  51, 93, 32, 45, 49, 10, 45, 115, 104, 91, 45, 53, 93, 10, 45, 97,
  91, 45, 51, 45, 45, 49, 93, 32, 99, 32, 45, 97, 91, 45, 52, 45,
  45, 50, 93, 32, 99, 10, 45, 115, 104, 91, 45, 51, 93, 32, 48, 44,
  48, 32, 45, 42, 91, 45, 51, 44, 45, 49, 93, 10, 45, 115, 104, 91,
  45, 51, 93, 32, 49, 44, 49, 32, 45, 42, 91, 45, 50, 44, 45, 49,
  93, 10, 45, 114, 109, 91, 45, 51, 93, 32, 45, 43, 91, 45, 50, 44,
  45, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123, 115, 61, 61, 54, 125,
  10, 45, 115, 91, 45, 49, 93, 32, 99, 10, 45, 108, 91, 45, 54, 45,
  45, 52, 93, 32, 45, 45, 115, 113, 114, 91, 45, 50, 93, 32, 45, 45,
  42, 91, 45, 50, 44, 45, 51, 93, 32, 45, 45, 115, 113, 114, 91, 45,
  51, 93, 32, 45, 42, 91, 45, 53, 93, 32, 91, 45, 54, 93, 32, 45,
  42, 91, 45, 52, 93, 32, 91, 45, 54, 93, 32, 45, 115, 113, 114, 91,
  45, 54, 93, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 10, 45,
  108, 91, 45, 51, 45, 45, 49, 93, 32, 45, 45, 115, 113, 114, 91, 45,
  50, 93, 32, 45, 45, 42, 91, 45, 50, 44, 45, 51, 93, 32, 45, 45,
  115, 113, 114, 91, 45, 51, 93, 32, 45, 42, 91, 45, 53, 93, 32, 91,
  45, 54, 93, 32, 45, 42, 91, 45, 52, 93, 32, 91, 45, 54, 93, 32,
  45, 115, 113, 114, 91, 45, 54, 93, 32, 45, 97, 32, 99, 32, 45, 101,
  110, 100, 108, 10, 45, 115, 91, 45, 51, 93, 32, 99, 10, 45, 45, 91,
  45, 53, 93, 32, 91, 45, 51, 93, 32, 45, 45, 91, 45, 52, 93, 32,
  91, 45, 51, 93, 32, 45, 42, 91, 45, 50, 93, 32, 91, 45, 53, 93,
  32, 45, 42, 91, 45, 49, 93, 32, 91, 45, 52, 93, 10, 40, 49, 94,
  48, 94, 48, 94, 49, 94, 48, 94, 49, 41, 32, 45, 114, 91, 45, 49,
  93, 32, 91, 45, 51, 93, 32, 45, 42, 91, 45, 49, 93, 32, 91, 45,
  52, 93, 32, 45, 114, 109, 91, 45, 54, 45, 45, 52, 93, 32, 45, 43,
  91, 45, 51, 45, 45, 49, 93, 10, 45, 101, 108, 115, 101, 32, 45, 101,
  114, 114, 111, 114, 91, 48, 45, 45, 51, 93, 32, 34, 73, 110, 118, 97,
  108, 105, 100, 32, 105, 109, 97, 103, 101, 32, 91, 34, 123, 64, 35, 45,
  36, 62, 45, 49, 125, 34, 93, 32, 58, 32, 68, 105, 109, 101, 110, 115,
  105, 111, 110, 115, 32, 34, 123, 119, 125, 34, 44, 34, 123, 104, 125, 34,
  44, 34, 123, 100, 125, 34, 44, 34, 123, 115, 125, 34, 32, 100, 111, 101,
  115, 32, 110, 111, 116, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 32,
  97, 32, 102, 105, 101, 108, 100, 32, 111, 102, 32, 50, 100, 32, 111, 114,
  32, 51, 100, 32, 101, 105, 103, 101, 110, 118, 101, 99, 116, 111, 114, 115,
  46, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 110, 109, 32, 36, 110,
  109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 102, 108, 111, 97, 116, 50, 105, 110, 116, 56, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101,
  114, 116, 32, 102, 108, 111, 97, 116, 45, 118, 97, 108, 117, 101, 100, 32,
  105, 109, 97, 103, 101, 36, 63, 32, 116, 111, 32, 56, 98, 105, 116, 115,
  32, 105, 110, 116, 101, 103, 101, 114, 32, 114, 101, 112, 114, 101, 115, 101,
  110, 116, 97, 116, 105, 111, 110, 115, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 115, 32, 99, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 109, 61, 123, 105, 109, 125, 32,
  77, 61, 123, 105, 77, 125, 32, 45, 113, 117, 97, 110, 116, 105, 122, 101,
  32, 49, 54, 55, 55, 55, 50, 49, 54, 44, 48, 44, 49, 10, 45, 45,
  62, 62, 32, 56, 32, 45, 97, 110, 100, 91, 45, 49, 93, 32, 50, 53,
  53, 32, 45, 45, 97, 110, 100, 91, 45, 50, 93, 32, 50, 53, 53, 32,
  45, 62, 62, 91, 45, 51, 93, 32, 49, 54, 10, 40, 123, 39, 36, 109,
  44, 36, 77, 39, 125, 41, 32, 45, 97, 32, 121, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 97, 32, 99, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 105, 110,
  116, 56, 50, 102, 108, 111, 97, 116, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 56, 98, 105, 116,
  115, 32, 105, 110, 116, 101, 103, 101, 114, 32, 114, 101, 112, 114, 101, 115,
  101, 110, 116, 97, 116, 105, 111, 110, 36, 63, 32, 116, 111, 32, 102, 108,
  111, 97, 116, 45, 118, 97, 108, 117, 101, 100, 32, 105, 109, 97, 103, 101,
  36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 32, 99,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 45, 115, 104, 91, 45, 49, 93, 32, 123, 104, 45, 49, 125,
  44, 123, 104, 45, 49, 125, 44, 48, 44, 48, 32, 109, 61, 64, 123, 45,
  49, 44, 116, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 114, 111,
  119, 115, 32, 48, 44, 123, 104, 45, 50, 125, 32, 45, 115, 32, 121, 44,
  51, 32, 45, 42, 91, 45, 51, 93, 32, 54, 53, 53, 51, 54, 32, 45,
  42, 91, 45, 50, 93, 32, 50, 53, 54, 32, 45, 111, 114, 32, 45, 110,
  32, 36, 109, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 105, 109, 97, 103, 101, 95, 105, 110, 116, 101,
  103, 114, 97, 108, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  67, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 105, 109, 97, 103,
  101, 32, 105, 110, 116, 101, 103, 114, 97, 108, 32, 111, 102, 32, 105, 109,
  97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 102, 32,
  39, 62, 105, 43, 105, 40, 120, 45, 49, 44, 121, 41, 39, 32, 45, 102,
  32, 39, 62, 105, 43, 105, 40, 120, 44, 121, 45, 49, 41, 39, 32, 45,
  118, 32, 43, 10, 109, 97, 112, 95, 99, 108, 117, 116, 32, 58, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 77, 97, 112, 32, 99, 111, 108, 111,
  114, 32, 76, 85, 84, 32, 105, 109, 97, 103, 101, 44, 32, 117, 115, 105,
  110, 103, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 105, 102,
  32, 123, 64, 35, 60, 50, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 32, 45, 116, 111, 95,
  99, 111, 108, 111, 114, 91, 48, 45, 45, 50, 93, 32, 45, 116, 111, 95,
  114, 103, 98, 91, 45, 49, 93, 10, 108, 61, 123, 114, 111, 117, 110, 100,
  40, 40, 119, 42, 104, 42, 100, 41, 94, 40, 49, 47, 51, 41, 41, 125,
  32, 45, 114, 91, 45, 49, 93, 32, 36, 108, 44, 36, 108, 44, 36, 108,
  44, 51, 44, 45, 49, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64,
  35, 45, 49, 125, 32, 45, 108, 91, 36, 62, 44, 45, 49, 93, 32, 45,
  115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 91, 48, 93,
  32, 45, 47, 91, 48, 93, 32, 123, 50, 53, 54, 47, 36, 108, 125, 10,
  45, 45, 119, 97, 114, 112, 91, 45, 49, 93, 32, 91, 48, 93, 44, 48,
  44, 49, 44, 49, 10, 45, 114, 109, 91, 48, 93, 32, 45, 109, 118, 91,
  45, 49, 93, 32, 48, 32, 45, 97, 91, 94, 45, 49, 93, 32, 99, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 118, 32, 43, 10, 109, 105, 120, 95, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 65, 112, 112, 108, 121, 32, 109, 97, 116, 114, 105, 120, 32, 36, 49,
  32, 116, 111, 32, 99, 104, 97, 110, 110, 101, 108, 115, 32, 111, 102, 32,
  105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 119, 104, 100, 61, 123,
  119, 125, 44, 123, 104, 125, 44, 123, 100, 125, 32, 45, 114, 32, 123, 119,
  42, 104, 42, 100, 125, 44, 123, 115, 125, 44, 49, 44, 49, 44, 45, 49,
  32, 45, 105, 91, 48, 93, 32, 36, 123, 94, 48, 125, 32, 45, 42, 42,
  32, 45, 114, 32, 36, 119, 104, 100, 44, 123, 104, 125, 44, 45, 49, 10,
  45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 110, 101, 103, 97, 116,
  105, 118, 101, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67,
  111, 109, 112, 117, 116, 101, 32, 110, 101, 103, 97, 116, 105, 118, 101, 32,
  111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 32, 45, 45, 32, 123, 105, 77, 125, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 42, 32, 45, 49, 32, 45, 118,
  32, 43, 10, 110, 111, 114, 109, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 112, 111, 105, 110, 116,
  119, 105, 115, 101, 32, 101, 117, 99, 108, 105, 100, 101, 97, 110, 32, 110,
  111, 114, 109, 32, 111, 102, 32, 118, 101, 99, 116, 111, 114, 115, 44, 32,
  105, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 115, 113, 114, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 43, 32, 45, 115, 113, 114, 116,
  32, 45, 118, 32, 43, 10, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95,
  115, 117, 109, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 78,
  111, 114, 109, 97, 108, 105, 122, 101, 32, 105, 109, 97, 103, 101, 36, 63,
  32, 119, 105, 116, 104, 32, 97, 32, 117, 110, 105, 116, 97, 114, 121, 32,
  115, 117, 109, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 115, 117, 109, 61, 64, 123, 36, 62, 44, 43,
  125, 32, 45, 105, 102, 32, 123, 36, 115, 117, 109, 33, 61, 48, 125, 32,
  45, 47, 91, 36, 62, 93, 32, 36, 115, 117, 109, 32, 45, 101, 110, 100,
  105, 102, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 111, 114,
  105, 101, 110, 116, 97, 116, 105, 111, 110, 32, 58, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 112, 111, 105,
  110, 116, 119, 105, 115, 101, 32, 111, 114, 105, 101, 110, 116, 97, 116, 105,
  111, 110, 32, 118, 101, 99, 116, 111, 114, 115, 44, 32, 105, 110, 32, 105,
  109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 45, 110, 111, 114, 109, 91,
  36, 62, 93, 32, 45, 114, 101, 112, 108, 97, 99, 101, 91, 45, 49, 93,
  32, 48, 44, 49, 32, 45, 47, 91, 36, 62, 44, 45, 49, 93, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 111, 116, 115, 117, 32, 58,
  32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36,
  123, 49, 61, 50, 53, 54, 125, 41, 32, 38, 38, 32, 36, 49, 62, 48,
  34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 72, 97, 114, 100, 45,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 105, 109, 97, 103, 101, 36,
  63, 32, 117, 115, 105, 110, 103, 32, 79, 116, 115, 117, 39, 115, 32, 109,
  101, 116, 104, 111, 100, 44, 32, 119, 105, 116, 104, 32, 36, 49, 32, 104,
  105, 115, 116, 111, 103, 114, 97, 109, 32, 108, 101, 118, 101, 108, 115, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 105, 109, 61, 123, 105, 109, 125,
  32, 105, 77, 61, 123, 105, 77, 125, 32, 45, 110, 32, 48, 44, 123, 36,
  49, 45, 49, 125, 10, 45, 45, 104, 105, 115, 116, 111, 103, 114, 97, 109,
  32, 36, 49, 32, 116, 111, 116, 97, 108, 61, 64, 123, 45, 49, 44, 43,
  125, 10, 45, 45, 42, 91, 45, 49, 93, 32, 39, 120, 39, 32, 115, 117,
  109, 61, 64, 123, 45, 49, 44, 43, 125, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 115, 117, 109, 66, 61, 48, 32, 119, 66, 61, 48, 32, 119, 70,
  61, 48, 32, 118, 97, 114, 77, 97, 120, 61, 48, 32, 116, 104, 114, 101,
  115, 104, 111, 108, 100, 61, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  36, 49, 10, 119, 66, 61, 123, 36, 119, 66, 43, 64, 123, 45, 49, 44,
  36, 62, 125, 125, 10, 45, 105, 102, 32, 123, 36, 119, 66, 61, 61, 48,
  125, 32, 45, 99, 111, 110, 116, 105, 110, 117, 101, 32, 45, 101, 110, 100,
  105, 102, 10, 119, 70, 61, 123, 36, 116, 111, 116, 97, 108, 45, 36, 119,
  66, 125, 10, 45, 105, 102, 32, 123, 36, 119, 70, 61, 61, 48, 125, 32,
  45, 98, 114, 101, 97, 107, 32, 45, 101, 110, 100, 105, 102, 10, 115, 117,
  109, 66, 61, 123, 36, 115, 117, 109, 66, 43, 36, 62, 42, 64, 123, 45,
  49, 44, 36, 62, 125, 125, 10, 109, 66, 61, 123, 36, 115, 117, 109, 66,
  47, 36, 119, 66, 125, 10, 109, 70, 61, 123, 40, 36, 115, 117, 109, 45,
  36, 115, 117, 109, 66, 41, 47, 36, 119, 70, 125, 10, 118, 97, 114, 66,
  101, 116, 119, 101, 101, 110, 61, 123, 36, 119, 66, 42, 36, 119, 70, 42,
  40, 36, 109, 66, 45, 36, 109, 70, 41, 94, 50, 125, 10, 45, 105, 102,
  32, 123, 36, 118, 97, 114, 66, 101, 116, 119, 101, 101, 110, 62, 36, 118,
  97, 114, 77, 97, 120, 125, 32, 118, 97, 114, 77, 97, 120, 61, 36, 118,
  97, 114, 66, 101, 116, 119, 101, 101, 110, 32, 116, 104, 114, 101, 115, 104,
  111, 108, 100, 61, 36, 62, 32, 45, 101, 110, 100, 105, 102, 10, 45, 100,
  111, 110, 101, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 103, 101, 91,
  45, 49, 93, 32, 36, 116, 104, 114, 101, 115, 104, 111, 108, 100, 10, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 61, 123, 36, 105, 109, 43, 36, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 42, 40, 36, 105, 77, 45, 36, 105,
  109, 41, 47, 40, 36, 49, 45, 49, 41, 125, 10, 45, 105, 102, 32, 36,
  62, 32, 45, 117, 32, 64, 123, 125, 44, 36, 116, 104, 114, 101, 115, 104,
  111, 108, 100, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 36, 116, 104,
  114, 101, 115, 104, 111, 108, 100, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  112, 111, 108, 97, 114, 50, 99, 111, 109, 112, 108, 101, 120, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101,
  32, 112, 111, 108, 97, 114, 32, 116, 111, 32, 99, 111, 109, 112, 108, 101,
  120, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 115, 32, 111, 102, 32,
  105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50,
  41, 125, 32, 45, 108, 91, 123, 50, 42, 36, 62, 125, 44, 123, 50, 42,
  36, 62, 43, 49, 125, 93, 10, 45, 114, 91, 49, 93, 32, 91, 48, 93,
  44, 51, 32, 45, 45, 115, 105, 110, 91, 45, 49, 93, 32, 45, 99, 111,
  115, 91, 45, 50, 93, 32, 45, 42, 91, 45, 49, 93, 32, 91, 45, 51,
  93, 32, 45, 42, 91, 45, 51, 44, 45, 50, 93, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 113, 117, 97,
  110, 116, 105, 122, 101, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  105, 115, 105, 110, 116, 40, 36, 49, 41, 32, 38, 38, 32, 36, 49, 62,
  61, 49, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 49, 125,
  44, 36, 123, 51, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 81, 117, 97, 110, 116, 105, 122, 101, 32, 105, 109, 97, 103, 101, 36,
  63, 32, 117, 115, 105, 110, 103, 32, 36, 49, 32, 108, 101, 118, 101, 108,
  115, 44, 32, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 33, 36,
  50, 44, 119, 105, 116, 104, 44, 119, 105, 116, 104, 111, 117, 116, 125, 34,
  32, 107, 101, 101, 112, 105, 110, 103, 32, 118, 97, 108, 117, 101, 32, 114,
  97, 110, 103, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105,
  102, 32, 36, 51, 10, 45, 105, 102, 32, 123, 115, 61, 61, 49, 125, 10,
  45, 105, 102, 32, 36, 50, 32, 109, 77, 61, 123, 105, 109, 125, 44, 123,
  105, 77, 125, 32, 45, 110, 32, 48, 44, 36, 49, 32, 45, 114, 111, 117,
  110, 100, 32, 49, 44, 45, 49, 32, 45, 109, 105, 110, 32, 123, 36, 49,
  45, 49, 125, 32, 45, 110, 32, 36, 109, 77, 10, 45, 101, 108, 115, 101,
  32, 45, 110, 32, 48, 44, 36, 49, 32, 45, 114, 111, 117, 110, 100, 32,
  49, 44, 45, 49, 32, 45, 109, 105, 110, 32, 123, 36, 49, 45, 49, 125,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101, 32, 109, 77,
  61, 123, 105, 109, 125, 44, 123, 105, 77, 125, 32, 45, 117, 110, 105, 102,
  111, 114, 109, 95, 100, 105, 115, 116, 114, 105, 98, 117, 116, 105, 111, 110,
  32, 36, 49, 44, 123, 115, 125, 32, 45, 110, 91, 45, 49, 93, 32, 36,
  109, 77, 32, 45, 105, 110, 100, 101, 120, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 44, 48, 44, 36, 50, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101, 32, 45, 45, 99,
  111, 108, 111, 114, 109, 97, 112, 32, 36, 49, 44, 48, 32, 45, 105, 110,
  100, 101, 120, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 36,
  50, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 114, 101, 112, 108, 97, 99, 101, 32, 58, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 82, 101, 112, 108, 97, 99, 101, 32, 112, 105, 120,
  101, 108, 32, 118, 97, 108, 117, 101, 115, 32, 36, 49, 32, 119, 105, 116,
  104, 32, 36, 50, 32, 105, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 45, 61, 61, 32, 36, 49,
  32, 45, 42, 91, 45, 49, 93, 32, 123, 36, 50, 45, 36, 49, 125, 32,
  45, 43, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 114, 101, 112, 108, 97, 99, 101, 95, 105, 110, 102, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 112, 108, 97,
  99, 101, 32, 97, 108, 108, 32, 105, 110, 102, 105, 110, 105, 116, 101, 32,
  118, 97, 108, 117, 101, 115, 32, 105, 110, 32, 105, 109, 97, 103, 101, 36,
  63, 32, 98, 121, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32,
  39, 36, 49, 39, 46, 34, 10, 45, 118, 32, 45, 32, 45, 102, 32, 34,
  105, 102, 40, 105, 61, 61, 105, 43, 49, 44, 36, 49, 44, 105, 41, 34,
  32, 45, 118, 32, 43, 10, 114, 101, 112, 108, 97, 99, 101, 95, 110, 97,
  110, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 112,
  108, 97, 99, 101, 32, 97, 108, 108, 32, 78, 97, 78, 32, 118, 97, 108,
  117, 101, 115, 32, 105, 110, 32, 105, 109, 97, 103, 101, 115, 36, 63, 32,
  98, 121, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 39, 36,
  49, 39, 46, 34, 10, 45, 118, 32, 45, 32, 45, 102, 32, 34, 105, 102,
  40, 105, 62, 61, 48, 32, 124, 124, 32, 105, 60, 61, 48, 44, 105, 44,
  36, 49, 41, 34, 32, 45, 118, 32, 43, 10, 114, 101, 112, 108, 97, 99,
  101, 95, 115, 101, 113, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 82, 101, 112, 108, 97, 99, 101, 32, 118, 97, 108, 117, 101, 32, 115,
  101, 113, 117, 101, 110, 99, 101, 32, 39, 36, 49, 39, 32, 98, 121, 32,
  118, 97, 108, 117, 101, 32, 115, 101, 113, 117, 101, 110, 99, 101, 32, 39,
  36, 50, 39, 32, 105, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34,
  10, 45, 118, 32, 45, 32, 40, 36, 49, 41, 32, 40, 36, 50, 41, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 50, 125, 32, 45,
  108, 91, 36, 62, 44, 45, 50, 44, 45, 49, 93, 10, 45, 115, 91, 48,
  93, 32, 43, 44, 36, 49, 32, 45, 115, 32, 121, 44, 45, 64, 123, 45,
  50, 44, 119, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35,
  45, 50, 125, 32, 45, 105, 102, 32, 123, 64, 123, 36, 62, 44, 116, 125,
  39, 61, 61, 39, 64, 123, 45, 50, 44, 116, 125, 125, 32, 45, 114, 111,
  119, 115, 91, 36, 62, 93, 32, 48, 44, 123, 119, 45, 49, 125, 32, 45,
  102, 91, 36, 62, 93, 32, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105,
  102, 32, 45, 100, 111, 110, 101, 10, 45, 97, 91, 48, 45, 45, 51, 93,
  32, 121, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  114, 109, 91, 45, 50, 44, 45, 49, 93, 32, 45, 118, 32, 43, 10, 114,
  111, 117, 110, 100, 105, 102, 121, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 36, 49, 62, 61, 48, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  82, 111, 117, 110, 100, 105, 102, 121, 32, 105, 109, 97, 103, 101, 36, 63,
  44, 32, 119, 105, 116, 104, 32, 103, 97, 109, 109, 97, 32, 36, 49, 46,
  34, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 32, 45, 114,
  101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32,
  45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 45, 114, 111, 117, 110, 100, 32, 49, 32, 45, 45,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 45, 42, 91, 45, 50,
  93, 32, 50, 32, 45, 97, 98, 115, 91, 45, 49, 93, 32, 45, 94, 91,
  45, 49, 93, 32, 36, 49, 32, 45, 115, 105, 103, 110, 91, 45, 51, 93,
  32, 45, 42, 91, 45, 51, 44, 45, 49, 93, 32, 45, 42, 91, 45, 50,
  93, 32, 48, 46, 53, 32, 45, 43, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 116, 50, 32, 58, 10, 45,
  118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32,
  43, 10, 45, 95, 116, 104, 114, 101, 115, 104, 111, 108, 100, 50, 32, 36,
  42, 10, 116, 104, 114, 101, 115, 104, 111, 108, 100, 50, 32, 58, 10, 45,
  118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32,
  43, 10, 45, 95, 36, 48, 32, 36, 42, 10, 95, 116, 104, 114, 101, 115,
  104, 111, 108, 100, 50, 32, 58, 10, 45, 101, 91, 48, 45, 45, 51, 93,
  32, 34, 72, 97, 114, 100, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100,
  32, 105, 109, 97, 103, 101, 34, 36, 95, 95, 115, 34, 32, 98, 101, 116,
  119, 101, 101, 110, 32, 118, 97, 108, 117, 101, 115, 32, 36, 49, 32, 97,
  110, 100, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 109,
  61, 36, 49, 32, 77, 61, 36, 50, 10, 45, 105, 102, 32, 64, 123, 45,
  105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 49, 125, 32,
  109, 61, 123, 105, 109, 43, 40, 105, 77, 45, 105, 109, 41, 42, 36, 109,
  125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 64, 123, 45,
  105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 50, 125, 32,
  77, 61, 123, 105, 109, 43, 40, 105, 77, 45, 105, 109, 41, 42, 36, 77,
  125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 32, 123, 48, 46, 53,
  42, 40, 36, 109, 43, 36, 77, 41, 125, 32, 45, 97, 98, 115, 32, 45,
  108, 101, 32, 123, 48, 46, 53, 42, 97, 98, 115, 40, 36, 77, 45, 36,
  109, 41, 125, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 117, 110, 99, 111, 109, 112, 114, 101, 115, 115, 95,
  114, 108, 101, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 85,
  110, 99, 111, 109, 112, 114, 101, 115, 115, 32, 100, 97, 116, 97, 32, 118,
  101, 99, 116, 111, 114, 36, 63, 44, 32, 117, 115, 105, 110, 103, 32, 82,
  76, 69, 32, 97, 108, 103, 111, 114, 105, 116, 104, 109, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 121, 32, 119, 104, 100, 115, 61, 64, 123,
  48, 44, 48, 45, 51, 125, 32, 105, 109, 61, 64, 123, 48, 44, 52, 125,
  32, 45, 114, 111, 119, 115, 32, 53, 44, 49, 48, 48, 37, 10, 45, 45,
  108, 116, 91, 45, 49, 93, 32, 48, 32, 40, 48, 59, 49, 59, 49, 41,
  32, 45, 101, 114, 111, 100, 101, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 45, 91, 45, 49,
  93, 32, 49, 32, 45, 97, 32, 120, 32, 45, 100, 105, 115, 99, 97, 114,
  100, 32, 45, 49, 10, 45, 45, 108, 116, 32, 48, 32, 40, 49, 59, 49,
  59, 48, 41, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 42, 91,
  45, 49, 93, 32, 45, 50, 32, 45, 43, 91, 45, 49, 93, 32, 49, 10,
  45, 114, 118, 32, 45, 97, 98, 115, 91, 45, 49, 93, 32, 45, 97, 32,
  120, 32, 45, 100, 105, 115, 99, 97, 114, 100, 32, 45, 49, 10, 45, 114,
  32, 50, 44, 123, 104, 47, 50, 125, 44, 49, 44, 49, 44, 45, 49, 32,
  45, 115, 32, 121, 44, 45, 50, 53, 54, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 91, 48,
  93, 32, 40, 123, 39, 67, 73, 109, 103, 51, 100, 39, 125, 41, 32, 45,
  43, 91, 48, 93, 32, 48, 46, 53, 10, 45, 105, 91, 49, 93, 32, 40,
  123, 50, 42, 104, 125, 59, 123, 104, 125, 41, 10, 45, 115, 91, 45, 49,
  93, 32, 120, 44, 50, 32, 45, 99, 117, 109, 117, 108, 91, 45, 50, 93,
  32, 115, 105, 122, 61, 64, 123, 45, 50, 44, 45, 49, 125, 10, 45, 45,
  115, 104, 105, 102, 116, 91, 45, 50, 93, 32, 48, 44, 49, 32, 45, 45,
  91, 45, 51, 93, 32, 49, 32, 45, 114, 118, 91, 45, 51, 44, 45, 49,
  93, 32, 45, 122, 91, 45, 51, 44, 45, 49, 93, 32, 48, 44, 50, 32,
  45, 97, 91, 45, 51, 44, 45, 49, 93, 32, 120, 10, 45, 105, 91, 51,
  93, 32, 40, 50, 44, 48, 44, 49, 59, 50, 44, 123, 50, 42, 104, 45,
  50, 125, 44, 123, 50, 42, 104, 45, 49, 125, 41, 32, 45, 114, 91, 51,
  93, 32, 51, 44, 123, 104, 125, 44, 49, 44, 49, 44, 51, 32, 45, 114,
  111, 117, 110, 100, 91, 51, 93, 10, 45, 114, 91, 52, 93, 32, 51, 32,
  49, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 49, 32, 45, 121, 32,
  45, 97, 32, 121, 10, 36, 115, 105, 122, 32, 45, 111, 98, 106, 101, 99,
  116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48,
  44, 48, 44, 49, 44, 50, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45,
  50, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45,
  97, 32, 120, 32, 45, 114, 32, 36, 119, 104, 100, 115, 44, 45, 49, 32,
  45, 43, 32, 36, 105, 109, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 117, 110, 114, 101, 112, 101, 97, 116,
  32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 109, 111,
  118, 101, 32, 114, 101, 112, 101, 116, 105, 116, 105, 111, 110, 32, 111, 102,
  32, 97, 100, 106, 97, 99, 101, 110, 116, 32, 118, 97, 108, 117, 101, 115,
  32, 105, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 45,
  121, 32, 120, 32, 40, 123, 64, 123, 48, 44, 45, 49, 125, 43, 49, 125,
  41, 32, 45, 97, 32, 120, 32, 45, 114, 32, 49, 48, 48, 37, 44, 50,
  10, 45, 102, 91, 45, 49, 93, 32, 39, 62, 105, 102, 40, 121, 61, 61,
  48, 44, 105, 44, 105, 102, 40, 105, 40, 120, 44, 48, 41, 61, 61, 105,
  40, 120, 43, 49, 44, 48, 41, 44, 45, 49, 44, 120, 41, 41, 39, 10,
  45, 122, 32, 48, 44, 123, 119, 45, 50, 125, 32, 45, 115, 32, 121, 44,
  50, 32, 45, 100, 105, 115, 99, 97, 114, 100, 91, 49, 93, 32, 45, 49,
  32, 45, 109, 97, 112, 91, 49, 93, 32, 91, 48, 93, 10, 45, 114, 109,
  91, 48, 93, 32, 45, 110, 109, 32, 36, 110, 109, 44, 49, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 118,
  101, 99, 116, 111, 114, 50, 116, 101, 110, 115, 111, 114, 32, 58, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32,
  118, 101, 99, 116, 111, 114, 32, 102, 105, 101, 108, 100, 36, 63, 32, 116,
  111, 32, 100, 105, 102, 102, 117, 115, 105, 111, 110, 32, 116, 101, 110, 115,
  111, 114, 32, 102, 105, 101, 108, 100, 36, 63, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 115, 32, 99, 10, 45, 105, 102, 32, 123, 64, 35,
  61, 61, 50, 125, 32, 45, 45, 115, 113, 114, 91, 45, 49, 93, 32, 45,
  42, 91, 45, 50, 93, 32, 91, 45, 51, 93, 32, 45, 115, 113, 114, 91,
  45, 51, 93, 10, 45, 101, 108, 105, 102, 32, 123, 64, 35, 61, 61, 51,
  125, 32, 45, 45, 115, 113, 114, 91, 45, 50, 93, 32, 45, 45, 42, 91,
  45, 51, 93, 32, 91, 45, 50, 93, 32, 45, 45, 115, 113, 114, 91, 45,
  51, 93, 32, 45, 42, 91, 45, 53, 44, 45, 52, 93, 32, 91, 45, 54,
  93, 32, 45, 115, 113, 114, 91, 45, 54, 93, 10, 45, 101, 108, 115, 101,
  32, 45, 101, 114, 114, 111, 114, 91, 48, 45, 45, 52, 93, 32, 34, 73,
  110, 118, 97, 108, 105, 100, 32, 105, 109, 97, 103, 101, 32, 91, 34, 123,
  64, 35, 45, 36, 62, 45, 49, 125, 34, 93, 32, 58, 32, 68, 105, 109,
  101, 110, 115, 105, 111, 110, 115, 32, 34, 123, 119, 125, 34, 44, 34, 123,
  104, 125, 34, 44, 34, 123, 100, 125, 34, 44, 34, 123, 115, 125, 34, 32,
  100, 111, 101, 115, 32, 110, 111, 116, 32, 114, 101, 112, 114, 101, 115, 101,
  110, 116, 32, 97, 32, 102, 105, 101, 108, 100, 32, 111, 102, 32, 50, 100,
  32, 111, 114, 32, 51, 100, 32, 118, 101, 99, 116, 111, 114, 115, 46, 34,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 97, 32, 99, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 97, 112,
  112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 58, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 51, 61, 48, 125, 10, 45, 105, 102, 32,
  123, 123, 36, 50, 39, 61, 61, 39, 97, 108, 108, 125, 34, 32, 124, 124,
  32, 34, 123, 36, 50, 39, 61, 61, 39, 48, 125, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109,
  97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110, 32, 105, 109, 97, 103,
  101, 36, 63, 46, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 95, 97,
  112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 36,
  49, 34, 10, 45, 105, 102, 32, 36, 51, 32, 45, 110, 32, 48, 44, 50,
  53, 53, 32, 45, 101, 108, 115, 101, 32, 45, 99, 32, 48, 44, 50, 53,
  53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32, 123, 123, 36, 50, 39,
  61, 61, 39, 114, 103, 98, 97, 125, 34, 32, 124, 124, 32, 34, 123, 36,
  50, 39, 61, 61, 39, 49, 125, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100, 32,
  39, 36, 49, 39, 32, 111, 110, 32, 82, 71, 66, 65, 32, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63,
  46, 34, 32, 45, 118, 32, 45, 10, 45, 116, 111, 95, 114, 103, 98, 97,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 45, 95, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 34, 36, 49, 34, 10, 45, 105, 102, 32, 36, 51, 32,
  45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 115, 101, 32, 45,
  99, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 105, 102,
  32, 123, 123, 36, 50, 39, 61, 61, 39, 114, 103, 98, 125, 34, 32, 124,
  124, 32, 34, 123, 36, 50, 39, 61, 61, 39, 50, 125, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111, 109,
  109, 97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110, 32, 82, 71, 66,
  32, 99, 104, 97, 110, 110, 101, 108, 115, 32, 111, 102, 32, 105, 109, 97,
  103, 101, 36, 63, 46, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115,
  112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 116, 111,
  95, 114, 103, 98, 91, 48, 93, 10, 45, 95, 97, 112, 112, 108, 121, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 91, 48, 93, 32, 34, 36, 49, 34,
  10, 45, 105, 102, 32, 36, 51, 32, 45, 110, 91, 48, 93, 32, 48, 44,
  50, 53, 53, 32, 45, 101, 108, 115, 101, 32, 45, 99, 91, 48, 93, 32,
  48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111,
  95, 114, 103, 98, 91, 48, 93, 10, 45, 97, 32, 99, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32, 123,
  123, 36, 50, 39, 61, 61, 39, 121, 125, 34, 32, 124, 124, 32, 34, 123,
  36, 50, 39, 61, 61, 39, 51, 125, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100,
  32, 39, 36, 49, 39, 32, 111, 110, 32, 108, 117, 109, 105, 110, 97, 110,
  99, 101, 32, 89, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46,
  34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 112, 108, 105, 116, 95,
  111, 112, 97, 99, 105, 116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91,
  48, 93, 32, 45, 114, 103, 98, 50, 121, 99, 98, 99, 114, 91, 48, 93,
  32, 45, 115, 91, 48, 93, 32, 99, 10, 45, 95, 97, 112, 112, 108, 121,
  95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48, 93, 32, 34, 36, 49,
  34, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48, 93, 32, 48,
  10, 45, 105, 102, 32, 36, 51, 32, 45, 110, 91, 48, 93, 32, 48, 44,
  50, 53, 53, 32, 45, 101, 108, 115, 101, 32, 45, 99, 91, 48, 93, 32,
  48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 91,
  48, 45, 50, 93, 32, 99, 32, 45, 121, 99, 98, 99, 114, 50, 114, 103,
  98, 91, 48, 93, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32, 123, 123, 36, 50,
  39, 61, 61, 39, 99, 98, 99, 114, 125, 34, 32, 124, 124, 32, 34, 123,
  36, 50, 39, 61, 61, 39, 52, 125, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100,
  32, 39, 36, 49, 39, 32, 111, 110, 32, 98, 108, 117, 101, 32, 97, 110,
  100, 32, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 115, 32, 67, 98, 67, 114, 32, 111, 102, 32, 105, 109, 97, 103, 101,
  36, 63, 46, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 112, 108,
  105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 116, 111, 95, 114,
  103, 98, 91, 48, 93, 32, 45, 114, 103, 98, 50, 121, 99, 98, 99, 114,
  91, 48, 93, 32, 45, 115, 91, 48, 93, 32, 99, 32, 45, 97, 91, 49,
  44, 50, 93, 32, 99, 10, 45, 95, 97, 112, 112, 108, 121, 95, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 49, 93, 32, 34, 36, 49, 34, 32, 45,
  99, 104, 97, 110, 110, 101, 108, 115, 91, 49, 93, 32, 48, 44, 49, 10,
  45, 105, 102, 32, 36, 51, 32, 45, 110, 91, 49, 93, 32, 48, 44, 50,
  53, 53, 32, 45, 101, 108, 115, 101, 32, 45, 99, 91, 49, 93, 32, 48,
  44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 91, 48,
  45, 49, 93, 32, 99, 32, 45, 121, 99, 98, 99, 114, 50, 114, 103, 98,
  91, 48, 93, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32, 123, 123, 36, 50, 39,
  61, 61, 39, 99, 98, 125, 34, 32, 124, 124, 32, 34, 123, 36, 50, 39,
  61, 61, 39, 53, 125, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36,
  49, 39, 32, 111, 110, 32, 98, 108, 117, 101, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 32, 67, 98, 32, 111, 102, 32, 105, 109, 97,
  103, 101, 36, 63, 46, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115,
  112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 116, 111,
  95, 114, 103, 98, 91, 48, 93, 32, 45, 114, 103, 98, 50, 121, 99, 98,
  99, 114, 91, 48, 93, 32, 45, 115, 91, 48, 93, 32, 99, 10, 45, 95,
  97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 49,
  93, 32, 34, 36, 49, 34, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115,
  91, 49, 93, 32, 48, 10, 45, 105, 102, 32, 36, 51, 32, 45, 110, 91,
  49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 115, 101, 32, 45,
  99, 91, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 97, 91, 48, 45, 50, 93, 32, 99, 32, 45, 121, 99, 98,
  99, 114, 50, 114, 103, 98, 91, 48, 93, 32, 45, 97, 32, 99, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 105, 102,
  32, 123, 123, 36, 50, 39, 61, 61, 39, 99, 114, 125, 34, 32, 124, 124,
  32, 34, 123, 36, 50, 39, 61, 61, 39, 54, 125, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109,
  97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110, 32, 114, 101, 100, 32,
  99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 32, 67, 114, 32, 111,
  102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 32, 45, 118, 32, 45,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116,
  121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 32, 45, 114, 103,
  98, 50, 121, 99, 98, 99, 114, 91, 48, 93, 32, 45, 115, 91, 48, 93,
  32, 99, 10, 45, 95, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110,
  101, 108, 115, 91, 50, 93, 32, 34, 36, 49, 34, 32, 45, 99, 104, 97,
  110, 110, 101, 108, 115, 91, 50, 93, 32, 48, 10, 45, 105, 102, 32, 36,
  51, 32, 45, 110, 91, 50, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101,
  108, 115, 101, 32, 45, 99, 91, 50, 93, 32, 48, 44, 50, 53, 53, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 97, 91, 48, 45, 50, 93, 32, 99,
  32, 45, 121, 99, 98, 99, 114, 50, 114, 103, 98, 91, 48, 93, 32, 45,
  97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  45, 101, 108, 105, 102, 32, 123, 123, 36, 50, 39, 61, 61, 39, 108, 125,
  34, 32, 124, 124, 32, 34, 123, 36, 50, 39, 61, 61, 39, 55, 125, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32,
  99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110, 32,
  108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 76, 32, 111, 102, 32, 105,
  109, 97, 103, 101, 36, 63, 46, 34, 32, 45, 118, 32, 45, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45,
  116, 111, 95, 114, 103, 98, 91, 48, 93, 32, 45, 114, 103, 98, 50, 108,
  97, 98, 91, 48, 93, 32, 45, 115, 91, 48, 93, 32, 99, 10, 45, 42,
  91, 48, 93, 32, 50, 46, 53, 53, 32, 45, 95, 97, 112, 112, 108, 121,
  95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48, 93, 32, 34, 36, 49,
  34, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48, 93, 32, 48,
  32, 45, 47, 91, 48, 93, 32, 50, 46, 53, 53, 10, 45, 105, 102, 32,
  36, 51, 32, 45, 110, 91, 48, 93, 32, 48, 44, 49, 48, 48, 32, 45,
  101, 108, 115, 101, 32, 45, 99, 91, 48, 93, 32, 48, 44, 49, 48, 48,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 91, 48, 45, 50, 93, 32,
  99, 32, 45, 108, 97, 98, 50, 114, 103, 98, 91, 48, 93, 32, 45, 97,
  32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45,
  101, 108, 105, 102, 32, 123, 123, 36, 50, 39, 61, 61, 39, 97, 98, 125,
  34, 32, 124, 124, 32, 34, 123, 36, 50, 39, 61, 61, 39, 56, 125, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32,
  99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110, 32,
  97, 45, 98, 32, 99, 104, 97, 110, 110, 101, 108, 115, 32, 111, 102, 32,
  105, 109, 97, 103, 101, 36, 63, 46, 34, 32, 45, 118, 32, 45, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32,
  45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 32, 45, 114, 103, 98, 50,
  108, 97, 98, 91, 48, 93, 32, 45, 115, 91, 48, 93, 32, 99, 10, 45,
  43, 91, 49, 93, 32, 56, 54, 32, 45, 42, 91, 49, 93, 32, 49, 46,
  51, 56, 53, 56, 55, 32, 45, 43, 91, 50, 93, 32, 49, 48, 56, 32,
  45, 42, 91, 50, 93, 32, 49, 46, 50, 53, 54, 49, 54, 10, 45, 97,
  91, 49, 44, 50, 93, 32, 99, 32, 45, 95, 97, 112, 112, 108, 121, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 91, 49, 93, 32, 34, 36, 49, 34,
  32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 49, 93, 32, 48, 44,
  49, 32, 45, 115, 91, 49, 93, 32, 99, 10, 45, 47, 91, 49, 93, 32,
  49, 46, 51, 56, 53, 56, 55, 32, 45, 45, 91, 49, 93, 32, 56, 54,
  32, 45, 47, 91, 50, 93, 32, 49, 46, 50, 53, 54, 49, 54, 32, 45,
  45, 91, 50, 93, 32, 49, 48, 56, 10, 45, 105, 102, 32, 36, 51, 32,
  45, 110, 91, 49, 93, 32, 45, 56, 54, 44, 57, 56, 32, 45, 110, 91,
  50, 93, 32, 45, 49, 48, 56, 44, 57, 53, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 97, 91, 48, 45, 50, 93, 32, 99, 32, 45, 108, 97, 98,
  50, 114, 103, 98, 91, 48, 93, 32, 45, 97, 32, 99, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32, 123,
  123, 36, 50, 39, 61, 61, 39, 97, 125, 34, 32, 124, 124, 32, 34, 123,
  36, 50, 39, 61, 61, 39, 57, 125, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100,
  32, 39, 36, 49, 39, 32, 111, 110, 32, 97, 45, 99, 104, 97, 110, 110,
  101, 108, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 32,
  45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 115, 112, 108, 105, 116, 95, 111, 112,
  97, 99, 105, 116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93,
  32, 45, 114, 103, 98, 50, 108, 97, 98, 91, 48, 93, 32, 45, 115, 91,
  48, 93, 32, 99, 10, 45, 43, 91, 49, 93, 32, 56, 54, 32, 45, 42,
  91, 49, 93, 32, 49, 46, 51, 56, 53, 56, 55, 32, 45, 95, 97, 112,
  112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 49, 93, 32,
  34, 36, 49, 34, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 49,
  93, 32, 48, 32, 45, 47, 91, 49, 93, 32, 49, 46, 51, 56, 53, 56,
  55, 32, 45, 45, 91, 49, 93, 32, 56, 54, 10, 45, 105, 102, 32, 36,
  51, 32, 45, 110, 91, 49, 93, 32, 45, 56, 54, 44, 57, 56, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 97, 91, 48, 45, 50, 93, 32, 99, 32,
  45, 108, 97, 98, 50, 114, 103, 98, 91, 48, 93, 32, 45, 97, 32, 99,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108,
  105, 102, 32, 123, 123, 36, 50, 39, 61, 61, 39, 98, 125, 34, 32, 124,
  124, 32, 34, 123, 36, 50, 39, 61, 61, 39, 49, 48, 125, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111,
  109, 109, 97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110, 32, 98, 45,
  99, 104, 97, 110, 110, 101, 108, 32, 111, 102, 32, 105, 109, 97, 103, 101,
  36, 63, 46, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 112, 108,
  105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 116, 111, 95, 114,
  103, 98, 91, 48, 93, 32, 45, 114, 103, 98, 50, 108, 97, 98, 91, 48,
  93, 32, 45, 115, 91, 48, 93, 32, 99, 10, 45, 43, 91, 50, 93, 32,
  49, 48, 56, 32, 45, 42, 91, 50, 93, 32, 49, 46, 50, 53, 54, 49,
  54, 32, 45, 95, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101,
  108, 115, 91, 50, 93, 32, 34, 36, 49, 34, 32, 45, 99, 104, 97, 110,
  110, 101, 108, 115, 91, 50, 93, 32, 48, 32, 45, 47, 91, 50, 93, 32,
  49, 46, 50, 53, 54, 49, 54, 32, 45, 45, 91, 50, 93, 32, 49, 48,
  56, 10, 45, 105, 102, 32, 36, 51, 32, 45, 110, 91, 49, 93, 32, 45,
  49, 48, 56, 44, 57, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97,
  91, 48, 45, 50, 93, 32, 99, 32, 45, 108, 97, 98, 50, 114, 103, 98,
  91, 48, 93, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32, 123, 123, 36, 50, 39,
  61, 61, 39, 104, 125, 34, 32, 124, 124, 32, 34, 123, 36, 50, 39, 61,
  61, 39, 49, 49, 125, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36,
  49, 39, 32, 111, 110, 32, 104, 117, 101, 32, 72, 32, 111, 102, 32, 105,
  109, 97, 103, 101, 36, 63, 46, 34, 32, 45, 118, 32, 45, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45,
  116, 111, 95, 114, 103, 98, 91, 48, 93, 32, 45, 114, 103, 98, 50, 104,
  115, 118, 91, 48, 93, 32, 45, 115, 91, 48, 93, 32, 99, 10, 45, 42,
  91, 48, 93, 32, 48, 46, 55, 48, 56, 51, 51, 51, 32, 45, 95, 97,
  112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48, 93,
  32, 34, 36, 49, 34, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91,
  48, 93, 32, 48, 32, 45, 47, 91, 48, 93, 32, 48, 46, 55, 48, 56,
  51, 51, 51, 10, 45, 105, 102, 32, 36, 51, 32, 45, 110, 91, 48, 93,
  32, 48, 44, 51, 54, 48, 32, 45, 101, 108, 115, 101, 32, 45, 37, 91,
  48, 93, 32, 51, 54, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97,
  91, 48, 45, 50, 93, 32, 99, 32, 45, 104, 115, 118, 50, 114, 103, 98,
  91, 48, 93, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32, 123, 123, 36, 50, 39,
  61, 61, 39, 115, 125, 34, 32, 124, 124, 32, 34, 123, 36, 50, 39, 61,
  61, 39, 49, 50, 125, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36,
  49, 39, 32, 111, 110, 32, 115, 97, 116, 117, 114, 97, 116, 105, 111, 110,
  32, 83, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 32,
  45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 115, 112, 108, 105, 116, 95, 111, 112,
  97, 99, 105, 116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93,
  32, 45, 114, 103, 98, 50, 104, 115, 118, 91, 48, 93, 32, 45, 115, 91,
  48, 93, 32, 99, 10, 45, 42, 91, 49, 93, 32, 50, 53, 53, 32, 45,
  95, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91,
  49, 93, 32, 34, 36, 49, 34, 32, 45, 99, 104, 97, 110, 110, 101, 108,
  115, 91, 49, 93, 32, 48, 32, 45, 47, 91, 49, 93, 32, 50, 53, 53,
  10, 45, 105, 102, 32, 36, 51, 32, 45, 110, 91, 49, 93, 32, 48, 44,
  49, 32, 45, 101, 108, 115, 101, 32, 45, 99, 91, 49, 93, 32, 48, 44,
  49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 91, 48, 45, 50, 93,
  32, 99, 32, 45, 104, 115, 118, 50, 114, 103, 98, 91, 48, 93, 32, 45,
  97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  45, 101, 108, 105, 102, 32, 123, 123, 36, 50, 39, 61, 61, 39, 118, 125,
  34, 32, 124, 124, 32, 34, 123, 36, 50, 39, 61, 61, 39, 49, 51, 125,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121,
  32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110,
  32, 118, 97, 108, 117, 101, 32, 86, 32, 111, 102, 32, 105, 109, 97, 103,
  101, 36, 63, 46, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 112,
  108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 116, 111, 95,
  114, 103, 98, 91, 48, 93, 32, 45, 114, 103, 98, 50, 104, 115, 118, 91,
  48, 93, 32, 45, 115, 91, 48, 93, 32, 99, 10, 45, 42, 91, 50, 93,
  32, 50, 53, 53, 32, 45, 95, 97, 112, 112, 108, 121, 95, 99, 104, 97,
  110, 110, 101, 108, 115, 91, 50, 93, 32, 34, 36, 49, 34, 32, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 91, 50, 93, 32, 48, 32, 45, 47, 91,
  50, 93, 32, 50, 53, 53, 10, 45, 105, 102, 32, 36, 51, 32, 45, 110,
  91, 50, 93, 32, 48, 44, 49, 32, 45, 101, 108, 115, 101, 32, 45, 99,
  91, 50, 93, 32, 48, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  97, 91, 48, 45, 50, 93, 32, 99, 32, 45, 104, 115, 118, 50, 114, 103,
  98, 91, 48, 93, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32, 123, 123, 36, 50,
  39, 61, 61, 39, 107, 34, 32, 124, 124, 32, 34, 123, 36, 50, 39, 61,
  61, 39, 49, 52, 125, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36,
  49, 39, 32, 111, 110, 32, 107, 101, 121, 32, 99, 104, 97, 110, 110, 101,
  108, 32, 75, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34,
  32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 112, 108, 105, 116, 95, 111,
  112, 97, 99, 105, 116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48,
  93, 32, 45, 114, 103, 98, 50, 99, 109, 121, 107, 91, 48, 93, 32, 45,
  115, 91, 48, 93, 32, 99, 10, 45, 95, 97, 112, 112, 108, 121, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 91, 51, 93, 32, 34, 36, 49, 34, 32,
  45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 51, 93, 32, 48, 10, 45,
  105, 102, 32, 36, 51, 32, 45, 110, 91, 51, 93, 32, 48, 44, 50, 53,
  53, 32, 45, 101, 108, 115, 101, 32, 45, 99, 91, 51, 93, 32, 48, 44,
  50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 91, 48, 45,
  51, 93, 32, 99, 32, 45, 99, 109, 121, 107, 50, 114, 103, 98, 91, 48,
  93, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 45, 101, 108, 105, 102, 32, 123, 123, 36, 50, 39, 61, 61,
  39, 99, 103, 125, 34, 32, 124, 124, 32, 34, 123, 36, 50, 39, 61, 61,
  39, 49, 53, 125, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65,
  112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100, 40, 115, 41, 32,
  39, 36, 49, 39, 32, 111, 110, 32, 103, 114, 101, 101, 110, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 32, 67, 103, 32, 111, 102, 32,
  105, 109, 97, 103, 101, 36, 63, 46, 34, 32, 45, 118, 32, 45, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32,
  45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 32, 45, 115, 91, 48, 93,
  32, 99, 32, 45, 114, 118, 91, 49, 44, 50, 93, 32, 45, 97, 91, 48,
  45, 50, 93, 32, 99, 32, 45, 114, 103, 98, 50, 121, 99, 98, 99, 114,
  91, 48, 93, 32, 45, 115, 91, 48, 93, 32, 99, 10, 45, 95, 97, 112,
  112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 49, 93, 32,
  34, 36, 49, 34, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 49,
  93, 32, 48, 10, 45, 105, 102, 32, 36, 51, 32, 45, 110, 91, 49, 93,
  32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 115, 101, 32, 45, 99, 91,
  49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 97, 91, 48, 45, 50, 93, 32, 99, 32, 45, 121, 99, 98, 99, 114,
  50, 114, 103, 98, 91, 48, 93, 32, 45, 115, 91, 48, 93, 32, 99, 32,
  45, 114, 118, 91, 49, 44, 50, 93, 32, 45, 97, 32, 99, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32,
  123, 123, 36, 50, 39, 61, 61, 39, 99, 104, 125, 34, 32, 124, 124, 32,
  34, 123, 36, 50, 39, 61, 61, 39, 49, 54, 125, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109,
  97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110, 32, 99, 45, 104, 32,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 111, 102, 32, 105, 109, 97, 103,
  101, 36, 63, 46, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 112,
  108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 116, 111, 95,
  114, 103, 98, 91, 48, 93, 32, 45, 114, 103, 98, 50, 108, 99, 104, 91,
  48, 93, 32, 45, 115, 91, 48, 93, 32, 99, 10, 45, 42, 91, 49, 93,
  32, 50, 46, 53, 53, 32, 45, 43, 91, 50, 93, 32, 123, 112, 105, 125,
  32, 45, 42, 91, 50, 93, 32, 123, 50, 53, 53, 47, 40, 50, 42, 112,
  105, 41, 125, 10, 45, 97, 91, 49, 44, 50, 93, 32, 99, 32, 45, 95,
  97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 49,
  93, 32, 34, 36, 49, 34, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115,
  91, 49, 93, 32, 48, 44, 49, 32, 45, 115, 91, 49, 93, 32, 99, 10,
  45, 47, 91, 49, 93, 32, 50, 46, 53, 53, 32, 45, 47, 91, 50, 93,
  32, 123, 50, 53, 53, 47, 40, 50, 42, 112, 105, 41, 125, 32, 45, 45,
  91, 50, 93, 32, 123, 112, 105, 125, 10, 45, 105, 102, 32, 36, 51, 32,
  45, 110, 91, 49, 93, 32, 48, 44, 49, 48, 48, 32, 45, 110, 91, 50,
  93, 32, 45, 123, 112, 105, 125, 44, 123, 112, 105, 125, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 97, 91, 48, 45, 50, 93, 32, 99, 32, 45, 108,
  99, 104, 50, 114, 103, 98, 91, 48, 93, 32, 45, 97, 32, 99, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 105, 102,
  32, 123, 123, 36, 50, 39, 61, 61, 39, 99, 125, 34, 32, 124, 124, 32,
  34, 123, 36, 50, 39, 61, 61, 39, 49, 55, 125, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109,
  97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110, 32, 99, 45, 99, 104,
  97, 110, 110, 101, 108, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63,
  46, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 112, 108, 105, 116,
  95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 116, 111, 95, 114, 103, 98,
  91, 48, 93, 32, 45, 114, 103, 98, 50, 108, 99, 104, 91, 48, 93, 32,
  45, 115, 91, 48, 93, 32, 99, 10, 45, 42, 91, 49, 93, 32, 50, 46,
  53, 53, 32, 45, 95, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110,
  101, 108, 115, 91, 49, 93, 32, 34, 36, 49, 34, 32, 45, 99, 104, 97,
  110, 110, 101, 108, 115, 91, 49, 93, 32, 48, 32, 45, 47, 91, 49, 93,
  32, 50, 46, 53, 53, 10, 45, 105, 102, 32, 36, 51, 32, 45, 110, 91,
  49, 93, 32, 48, 44, 49, 48, 48, 32, 45, 101, 108, 115, 101, 32, 45,
  99, 91, 49, 93, 32, 48, 44, 49, 48, 48, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 97, 91, 48, 45, 50, 93, 32, 99, 32, 45, 108, 99, 104,
  50, 114, 103, 98, 91, 48, 93, 32, 45, 97, 32, 99, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32, 123,
  123, 36, 50, 39, 61, 61, 39, 104, 125, 34, 32, 124, 124, 32, 34, 123,
  36, 50, 39, 61, 61, 39, 49, 56, 125, 125, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110,
  100, 32, 39, 36, 49, 39, 32, 111, 110, 32, 104, 45, 99, 104, 97, 110,
  110, 101, 108, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34,
  32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 112, 108, 105, 116, 95, 111,
  112, 97, 99, 105, 116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48,
  93, 32, 45, 114, 103, 98, 50, 108, 99, 104, 91, 48, 93, 32, 45, 115,
  91, 48, 93, 32, 99, 10, 45, 43, 91, 50, 93, 32, 123, 112, 105, 125,
  32, 45, 42, 91, 50, 93, 32, 123, 50, 53, 53, 47, 40, 50, 42, 112,
  105, 41, 125, 32, 45, 95, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 91, 50, 93, 32, 34, 36, 49, 34, 32, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 50, 93, 32, 48, 32, 45, 47, 91, 50,
  93, 32, 123, 50, 53, 53, 47, 40, 50, 42, 112, 105, 41, 125, 32, 45,
  45, 91, 50, 93, 32, 123, 112, 105, 125, 10, 45, 105, 102, 32, 36, 51,
  32, 45, 110, 91, 50, 93, 32, 45, 123, 112, 105, 125, 44, 123, 112, 105,
  125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 91, 48, 45, 50, 93,
  32, 99, 32, 45, 108, 99, 104, 50, 114, 103, 98, 91, 48, 93, 32, 45,
  97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  45, 101, 108, 105, 102, 32, 123, 123, 36, 50, 39, 61, 61, 39, 114, 125,
  34, 32, 124, 124, 32, 34, 123, 36, 50, 39, 61, 61, 39, 49, 57, 125,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121,
  32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110,
  32, 114, 101, 100, 32, 99, 104, 97, 110, 110, 101, 108, 32, 82, 32, 111,
  102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 32, 45, 118, 32, 45,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116,
  121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 32, 45, 115, 91,
  48, 93, 32, 99, 10, 45, 95, 97, 112, 112, 108, 121, 95, 99, 104, 97,
  110, 110, 101, 108, 115, 91, 48, 93, 32, 34, 36, 49, 34, 10, 45, 105,
  102, 32, 36, 51, 32, 45, 110, 91, 48, 93, 32, 48, 44, 50, 53, 53,
  32, 45, 101, 108, 115, 101, 32, 45, 99, 91, 48, 93, 32, 48, 44, 50,
  53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 103, 114,
  97, 121, 91, 48, 93, 10, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32, 123, 123, 36,
  50, 39, 61, 61, 39, 103, 125, 34, 32, 124, 124, 32, 34, 123, 36, 50,
  39, 61, 61, 39, 50, 48, 125, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 65, 112, 112, 108, 121, 32, 99, 111, 109, 109, 97, 110, 100, 32,
  39, 36, 49, 39, 32, 111, 110, 32, 103, 114, 101, 101, 110, 32, 99, 104,
  97, 110, 110, 101, 108, 32, 71, 32, 111, 102, 32, 105, 109, 97, 103, 101,
  36, 63, 46, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 112, 108,
  105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 116, 111, 95, 114,
  103, 98, 91, 48, 93, 32, 45, 115, 91, 48, 93, 32, 99, 10, 45, 95,
  97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 49,
  93, 32, 34, 36, 49, 34, 10, 45, 105, 102, 32, 36, 51, 32, 45, 110,
  91, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 115, 101, 32,
  45, 99, 91, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 116, 111, 95, 103, 114, 97, 121, 91, 49, 93, 10, 45,
  97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  45, 101, 108, 105, 102, 32, 123, 123, 36, 50, 39, 61, 61, 39, 98, 125,
  34, 32, 124, 124, 32, 34, 123, 36, 50, 39, 61, 61, 39, 50, 49, 125,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121,
  32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110,
  32, 98, 108, 117, 101, 32, 99, 104, 97, 110, 110, 101, 108, 32, 66, 32,
  111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 32, 45, 118, 32,
  45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105,
  116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 32, 45, 115,
  91, 48, 93, 32, 99, 10, 45, 95, 97, 112, 112, 108, 121, 95, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 50, 93, 32, 34, 36, 49, 34, 10, 45,
  105, 102, 32, 36, 51, 32, 45, 110, 91, 50, 93, 32, 48, 44, 50, 53,
  53, 32, 45, 101, 108, 115, 101, 32, 45, 99, 91, 50, 93, 32, 48, 44,
  50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 103,
  114, 97, 121, 91, 50, 93, 10, 45, 97, 32, 99, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32, 123, 123,
  36, 50, 39, 61, 61, 39, 97, 108, 112, 104, 97, 125, 34, 32, 124, 124,
  32, 34, 123, 36, 50, 39, 61, 61, 39, 50, 50, 125, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 111, 109,
  109, 97, 110, 100, 32, 39, 36, 49, 39, 32, 111, 110, 32, 97, 108, 112,
  104, 97, 32, 99, 104, 97, 110, 110, 101, 108, 32, 65, 32, 111, 102, 32,
  105, 109, 97, 103, 101, 36, 63, 46, 34, 32, 45, 118, 32, 45, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 115, 32, 99, 10, 45,
  95, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91,
  51, 93, 32, 34, 36, 49, 34, 10, 45, 105, 102, 32, 36, 51, 32, 45,
  110, 91, 51, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 115, 101,
  32, 45, 99, 91, 51, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 116, 111, 95, 103, 114, 97, 121, 91, 51, 93, 10,
  45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 95, 97, 112,
  112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 58, 10, 36,
  123, 49, 45, 45, 49, 125, 32, 45, 107, 91, 48, 93, 10, 97, 117, 116,
  111, 105, 110, 100, 101, 120, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 105, 115, 105, 110, 116, 40, 36, 49, 41, 32, 38, 38, 32, 36, 49,
  62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 48, 125, 62, 61, 48, 34,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 48, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 73, 110, 100, 101, 120, 32, 99, 111, 108,
  111, 114, 115, 32, 105, 110, 32, 105, 109, 97, 103, 101, 115, 36, 63, 32,
  98, 121, 32, 97, 100, 97, 112, 116, 101, 100, 32, 99, 111, 108, 111, 114,
  109, 97, 112, 32, 119, 105, 116, 104, 32, 36, 49, 32, 101, 110, 116, 114,
  105, 101, 115, 44, 32, 100, 105, 116, 104, 101, 114, 105, 110, 103, 32, 108,
  101, 118, 101, 108, 32, 36, 50, 32, 97, 110, 100, 32, 34, 92, 10, 64,
  123, 45, 97, 114, 103, 92, 32, 49, 43, 33, 36, 51, 44, 107, 45, 109,
  101, 97, 110, 115, 44, 109, 101, 100, 105, 97, 110, 45, 99, 117, 116, 125,
  34, 32, 109, 101, 116, 104, 111, 100, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 105, 102, 32, 123, 119, 62, 104, 125, 32, 45, 105, 102, 32,
  123, 119, 62, 50, 53, 54, 125, 32, 45, 45, 114, 50, 100, 120, 32, 50,
  53, 54, 32, 45, 101, 108, 115, 101, 32, 91, 48, 93, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 108, 115, 101, 32, 45, 105, 102, 32, 123, 104,
  62, 50, 53, 54, 125, 32, 45, 45, 114, 50, 100, 121, 32, 50, 53, 54,
  32, 45, 101, 108, 115, 101, 32, 91, 48, 93, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 99, 111, 108, 111, 114, 109,
  97, 112, 91, 49, 93, 32, 36, 49, 44, 36, 51, 44, 48, 10, 45, 105,
  110, 100, 101, 120, 91, 48, 93, 32, 91, 49, 93, 44, 36, 50, 44, 49,
  32, 45, 114, 109, 91, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 98, 97, 121, 101, 114, 50, 114,
  103, 98, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49,
  125, 44, 36, 123, 50, 61, 49, 125, 44, 36, 123, 51, 61, 48, 46, 53,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 84, 114, 97, 110, 115,
  102, 111, 114, 109, 32, 82, 71, 66, 45, 66, 97, 121, 101, 114, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 116, 111, 32, 99, 111, 108, 111, 114, 32,
  105, 109, 97, 103, 101, 115, 44, 32, 119, 105, 116, 104, 32, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 40, 36, 49, 44, 36, 50, 44, 36,
  51, 41, 46, 34, 10, 45, 118, 32, 45, 32, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 48, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 45, 101, 120, 112, 97, 110, 100, 95,
  120, 32, 123, 34, 50, 32, 43, 32, 52, 42, 36, 49, 34, 125, 44, 48,
  32, 45, 101, 120, 112, 97, 110, 100, 95, 121, 32, 123, 34, 50, 32, 43,
  32, 52, 42, 36, 49, 34, 125, 44, 48, 10, 40, 45, 49, 44, 49, 59,
  49, 44, 45, 49, 41, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50,
  93, 44, 91, 45, 50, 93, 44, 49, 44, 49, 44, 48, 44, 50, 10, 45,
  45, 42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 10, 40, 48, 46, 50,
  53, 44, 48, 46, 53, 44, 48, 46, 50, 53, 41, 32, 45, 99, 111, 110,
  118, 111, 108, 118, 101, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45,
  116, 114, 97, 110, 115, 112, 111, 115, 101, 91, 45, 49, 93, 32, 45, 99,
  111, 110, 118, 111, 108, 118, 101, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 98, 91, 45, 49, 93, 32,
  36, 49, 10, 45, 42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 10, 45,
  45, 91, 45, 51, 44, 45, 50, 93, 10, 40, 49, 44, 45, 49, 41, 32,
  45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93,
  44, 49, 44, 49, 44, 48, 44, 50, 10, 45, 42, 91, 45, 49, 93, 32,
  91, 45, 51, 93, 10, 40, 48, 46, 50, 53, 44, 48, 46, 53, 44, 48,
  46, 50, 53, 41, 32, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 32, 45, 116, 114, 97, 110, 115, 112, 111,
  115, 101, 91, 45, 49, 93, 32, 45, 99, 111, 110, 118, 111, 108, 118, 101,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 98, 108, 117, 114, 95, 121, 91, 45, 49, 93, 32, 36, 50,
  32, 45, 98, 108, 117, 114, 95, 120, 91, 45, 49, 93, 32, 36, 51, 10,
  40, 49, 59, 45, 49, 41, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 49, 44, 48, 44, 50, 10,
  45, 42, 91, 45, 49, 93, 32, 91, 45, 52, 93, 10, 40, 48, 46, 50,
  53, 44, 48, 46, 53, 44, 48, 46, 50, 53, 41, 32, 45, 99, 111, 110,
  118, 111, 108, 118, 101, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45,
  116, 114, 97, 110, 115, 112, 111, 115, 101, 91, 45, 49, 93, 32, 45, 99,
  111, 110, 118, 111, 108, 118, 101, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 98, 108, 117, 114, 95, 120,
  91, 45, 49, 93, 32, 36, 50, 32, 45, 98, 108, 117, 114, 95, 121, 91,
  45, 49, 93, 32, 36, 51, 10, 45, 43, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 47, 91, 45, 49, 93, 32, 50, 10, 40, 50, 44, 48, 59, 48,
  44, 45, 50, 41, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  44, 91, 45, 50, 93, 44, 49, 44, 49, 44, 48, 44, 50, 10, 45, 42,
  91, 45, 49, 93, 32, 91, 45, 50, 93, 10, 45, 45, 91, 45, 52, 44,
  45, 49, 93, 10, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 99, 10,
  45, 109, 105, 120, 95, 114, 103, 98, 91, 45, 49, 93, 32, 49, 44, 45,
  49, 44, 50, 44, 49, 44, 49, 44, 48, 44, 49, 44, 45, 49, 44, 45,
  50, 10, 45, 115, 104, 114, 105, 110, 107, 95, 120, 32, 123, 34, 50, 32,
  43, 32, 52, 42, 36, 49, 34, 125, 44, 48, 32, 45, 115, 104, 114, 105,
  110, 107, 95, 121, 32, 123, 34, 50, 32, 43, 32, 52, 42, 36, 49, 34,
  125, 44, 48, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 99, 109,
  121, 50, 114, 103, 98, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63,
  32, 102, 114, 111, 109, 32, 67, 77, 89, 32, 116, 111, 32, 82, 71, 66,
  32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 103, 98, 50, 99, 109, 121, 32, 45, 118, 32,
  43, 10, 99, 109, 121, 107, 50, 114, 103, 98, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 102, 114, 111, 109, 32, 67, 77, 89, 75, 32,
  116, 111, 32, 82, 71, 66, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115,
  101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 32, 99,
  32, 45, 45, 47, 91, 45, 49, 93, 32, 45, 50, 53, 53, 32, 45, 43,
  91, 45, 49, 93, 32, 49, 32, 45, 42, 91, 48, 45, 50, 93, 32, 91,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 43, 91, 48,
  45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 97, 32, 99, 32, 45, 99, 109, 121, 50, 114, 103, 98, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  99, 111, 108, 111, 114, 109, 97, 112, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 49, 41, 32, 38, 38, 32,
  36, 49, 62, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61,
  48, 125, 44, 36, 123, 51, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 69, 115, 116, 105, 109, 97, 116, 101, 32, 99, 111, 108, 111,
  114, 109, 97, 112, 32, 119, 105, 116, 104, 32, 36, 49, 32, 101, 110, 116,
  114, 105, 101, 115, 32, 102, 111, 114, 32, 105, 109, 97, 103, 101, 36, 63,
  44, 32, 98, 121, 32, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43,
  33, 36, 50, 44, 107, 45, 109, 101, 97, 110, 115, 44, 109, 101, 100, 105,
  97, 110, 45, 99, 117, 116, 125, 34, 32, 109, 101, 116, 104, 111, 100, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 114, 32, 123, 119, 42, 104,
  125, 44, 49, 44, 49, 44, 49, 48, 48, 37, 44, 45, 49, 10, 45, 105,
  102, 32, 123, 33, 36, 50, 125, 32, 45, 95, 99, 111, 108, 111, 114, 109,
  97, 112, 32, 36, 49, 10, 45, 101, 108, 115, 101, 10, 109, 61, 123, 105,
  109, 125, 32, 77, 61, 123, 105, 77, 125, 32, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 10, 45, 45, 95, 99, 111, 108, 111, 114, 109,
  97, 112, 32, 36, 49, 32, 45, 45, 105, 110, 100, 101, 120, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53,
  54, 32, 45, 43, 91, 45, 51, 44, 45, 49, 93, 10, 45, 100, 111, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 115, 125, 10, 45, 115, 104, 91,
  48, 93, 32, 36, 62, 44, 36, 62, 32, 45, 45, 104, 105, 115, 116, 111,
  103, 114, 97, 109, 91, 45, 49, 93, 32, 123, 36, 49, 42, 50, 53, 54,
  125, 44, 48, 44, 123, 36, 49, 42, 50, 53, 54, 45, 49, 125, 32, 45,
  114, 109, 91, 45, 50, 93, 10, 45, 105, 91, 45, 50, 93, 32, 50, 53,
  54, 44, 49, 44, 49, 44, 49, 44, 39, 120, 39, 32, 45, 114, 91, 45,
  50, 93, 32, 123, 119, 125, 44, 49, 44, 49, 44, 49, 44, 48, 44, 50,
  32, 45, 42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 91,
  45, 50, 44, 45, 49, 93, 32, 36, 49, 44, 49, 44, 49, 44, 49, 44,
  50, 32, 45, 109, 97, 120, 91, 45, 49, 93, 32, 48, 46, 48, 49, 32,
  45, 47, 91, 45, 50, 44, 45, 49, 93, 10, 45, 100, 111, 110, 101, 32,
  45, 97, 91, 50, 45, 45, 49, 93, 32, 99, 10, 45, 45, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 32, 45, 97, 98, 115, 91, 45, 50, 93, 32,
  100, 105, 102, 102, 61, 123, 64, 123, 45, 50, 44, 43, 125, 47, 119, 125,
  32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 97, 110, 100, 91, 45, 50,
  93, 32, 50, 53, 53, 32, 45, 45, 105, 110, 100, 101, 120, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 32, 45, 42, 91, 45, 49,
  93, 32, 50, 53, 54, 32, 45, 43, 91, 45, 51, 44, 45, 49, 93, 10,
  45, 119, 104, 105, 108, 101, 32, 123, 36, 100, 105, 102, 102, 62, 48, 46,
  53, 125, 10, 45, 114, 109, 91, 45, 50, 93, 32, 45, 42, 91, 45, 49,
  93, 32, 123, 40, 36, 77, 45, 36, 109, 41, 47, 50, 53, 53, 125, 32,
  45, 43, 91, 45, 49, 93, 32, 36, 109, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 36, 51, 32, 45, 45, 110, 111, 114, 109, 32, 45,
  114, 118, 32, 45, 97, 32, 121, 32, 45, 115, 111, 114, 116, 32, 43, 44,
  120, 32, 45, 114, 111, 119, 115, 32, 49, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 110, 109, 32, 34, 91, 99, 111, 108, 111, 114, 109, 97, 112, 32,
  111, 102, 32, 34, 64, 123, 45, 49, 44, 98, 125, 34, 93, 34, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  95, 99, 111, 108, 111, 114, 109, 97, 112, 32, 58, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 36, 49, 45, 49, 125, 10, 64, 35, 44, 123, 115,
  125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125,
  10, 110, 61, 36, 62, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 123,
  36, 110, 44, 115, 125, 32, 45, 115, 104, 91, 36, 110, 93, 32, 36, 62,
  44, 36, 62, 32, 45, 61, 91, 45, 50, 93, 32, 123, 105, 102, 40, 119,
  62, 49, 44, 105, 118, 44, 45, 49, 41, 125, 44, 36, 110, 44, 36, 62,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45,
  100, 111, 110, 101, 10, 99, 61, 64, 123, 45, 49, 44, 67, 125, 10, 98,
  61, 64, 123, 45, 97, 114, 103, 92, 32, 49, 44, 36, 99, 125, 10, 97,
  61, 64, 123, 45, 97, 114, 103, 92, 32, 50, 44, 36, 99, 125, 10, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 115, 104, 105, 102, 116, 91, 36, 98,
  93, 32, 48, 44, 48, 44, 48, 44, 123, 45, 36, 97, 125, 44, 50, 32,
  45, 115, 111, 114, 116, 91, 36, 98, 93, 32, 43, 44, 120, 32, 45, 115,
  104, 105, 102, 116, 91, 36, 98, 93, 32, 48, 44, 48, 44, 48, 44, 36,
  97, 44, 50, 32, 45, 115, 91, 36, 98, 93, 32, 120, 44, 50, 10, 45,
  100, 111, 110, 101, 10, 45, 114, 32, 49, 44, 49, 44, 49, 44, 49, 48,
  48, 37, 44, 50, 32, 45, 97, 32, 120, 10, 99, 111, 109, 112, 111, 115,
  101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 49, 61, 34, 43, 34, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 67, 111, 109, 112, 111, 115, 101, 32, 97, 108, 108,
  32, 99, 104, 97, 110, 110, 101, 108, 115, 32, 111, 102, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 111, 112, 101, 114, 97,
  116, 111, 114, 32, 39, 36, 49, 39, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 115, 104, 32, 48, 44, 48, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 64, 123, 45, 50, 44, 115, 125, 45, 49, 125, 32, 45, 115,
  104, 91, 45, 50, 93, 32, 123, 36, 62, 43, 49, 125, 44, 123, 36, 62,
  43, 49, 125, 32, 45, 108, 91, 45, 50, 44, 45, 49, 93, 32, 45, 36,
  49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 45, 49, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 100, 105,
  114, 101, 99, 116, 105, 111, 110, 50, 114, 103, 98, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 82,
  71, 66, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 97, 116, 105, 111,
  110, 32, 111, 102, 32, 50, 100, 32, 100, 105, 114, 101, 99, 116, 105, 111,
  110, 32, 102, 105, 101, 108, 100, 36, 63, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48, 44, 49, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 45, 115, 32, 99, 32,
  45, 99, 111, 109, 112, 108, 101, 120, 50, 112, 111, 108, 97, 114, 32, 45,
  114, 111, 117, 110, 100, 91, 45, 50, 93, 32, 48, 46, 48, 48, 49, 10,
  45, 42, 91, 45, 49, 93, 32, 123, 49, 56, 48, 47, 112, 105, 125, 32,
  45, 37, 91, 45, 49, 93, 32, 51, 54, 48, 32, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 44, 49, 44, 49, 44, 49, 32, 45, 109, 118, 91, 45,
  51, 93, 32, 64, 35, 10, 45, 105, 102, 32, 123, 105, 109, 33, 61, 105,
  77, 125, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 101,
  108, 115, 101, 32, 45, 102, 91, 45, 49, 93, 32, 49, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 97, 32, 99, 32, 45, 104, 115, 118, 50, 114, 103,
  98, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 100, 105, 116,
  104, 101, 114, 101, 100, 98, 119, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 114, 101, 97, 116, 101, 32, 100, 105, 116, 104, 101, 114,
  101, 100, 32, 66, 38, 87, 32, 118, 101, 114, 115, 105, 111, 110, 32, 111,
  102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116,
  121, 10, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 48, 93, 32,
  45, 110, 91, 48, 93, 32, 48, 44, 50, 53, 53, 32, 40, 48, 44, 50,
  53, 53, 41, 32, 45, 105, 110, 100, 101, 120, 91, 48, 93, 32, 91, 45,
  49, 93, 44, 49, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 102, 99, 32, 58, 10, 45, 118, 32, 45, 32, 95,
  95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 102,
  105, 108, 108, 95, 99, 111, 108, 111, 114, 32, 36, 42, 10, 102, 105, 108,
  108, 95, 99, 111, 108, 111, 114, 32, 58, 10, 45, 118, 32, 45, 32, 95,
  95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 36,
  48, 32, 36, 42, 10, 95, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114,
  32, 58, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 70, 105, 108,
  108, 32, 105, 109, 97, 103, 101, 34, 36, 95, 95, 115, 34, 32, 119, 105,
  116, 104, 32, 99, 111, 108, 111, 114, 32, 40, 36, 123, 94, 48, 125, 41,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 115, 125, 32, 45, 115, 104, 91, 45, 49, 93, 32, 36, 62,
  44, 36, 62, 32, 45, 102, 91, 45, 49, 93, 32, 123, 97, 114, 103, 40,
  49, 43, 36, 62, 44, 36, 123, 94, 48, 125, 41, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 110, 109, 32, 64,
  123, 45, 49, 44, 110, 125, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 103, 114, 97, 100, 105, 101,
  110, 116, 50, 114, 103, 98, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 105, 115, 98, 111, 111, 108, 40, 36, 123, 49, 61, 48, 125, 41, 34,
  10, 45, 97, 114, 103, 32, 49, 43, 33, 36, 49, 44, 34, 111, 114, 105,
  101, 110, 116, 97, 116, 105, 111, 110, 32, 34, 44, 34, 34, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 82,
  71, 66, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 97, 116, 105, 111,
  110, 32, 111, 102, 32, 50, 100, 32, 103, 114, 97, 100, 105, 101, 110, 116,
  32, 34, 64, 123, 125, 34, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 110, 111, 114, 109, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  45, 105, 102, 32, 36, 49, 32, 45, 103, 114, 97, 100, 105, 101, 110, 116,
  95, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 32, 50, 32, 45,
  101, 108, 115, 101, 32, 45, 103, 32, 120, 121, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 97, 32, 99, 32, 45, 100, 105, 114, 101, 99, 116, 105, 111,
  110, 50, 114, 103, 98, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 104, 115, 105, 56, 50, 114, 103, 98, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101,
  114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114, 111, 109, 32,
  72, 83, 73, 56, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111, 108, 111,
  114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  95, 104, 115, 120, 56, 50, 114, 103, 98, 32, 45, 104, 115, 105, 50, 114,
  103, 98, 32, 45, 118, 32, 43, 10, 104, 115, 108, 56, 50, 114, 103, 98,
  32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118,
  101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114, 111, 109,
  32, 72, 83, 76, 56, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111, 108,
  111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 95, 104, 115, 120, 56, 50, 114, 103, 98, 32, 45, 104, 115, 108, 50,
  114, 103, 98, 32, 45, 118, 32, 43, 10, 104, 115, 118, 56, 50, 114, 103,
  98, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110,
  118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114, 111,
  109, 32, 72, 83, 86, 56, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111,
  108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 95, 104, 115, 120, 56, 50, 114, 103, 98, 32, 45, 104, 115, 118,
  50, 114, 103, 98, 32, 45, 118, 32, 43, 10, 95, 104, 115, 120, 56, 50,
  114, 103, 98, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  10, 45, 115, 104, 91, 36, 62, 93, 32, 48, 44, 48, 32, 45, 47, 91,
  45, 49, 93, 32, 48, 46, 55, 48, 56, 51, 51, 51, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 115, 104, 91, 36, 62, 93, 32, 49, 44, 50,
  32, 45, 47, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 108,
  97, 98, 50, 108, 99, 104, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36,
  63, 32, 102, 114, 111, 109, 32, 76, 97, 98, 32, 116, 111, 32, 76, 99,
  104, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 51, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 32, 99, 32,
  45, 99, 111, 109, 112, 108, 101, 120, 50, 112, 111, 108, 97, 114, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 108, 97, 98, 56,
  50, 114, 103, 98, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  102, 114, 111, 109, 32, 76, 97, 98, 56, 32, 116, 111, 32, 82, 71, 66,
  32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45,
  115, 104, 91, 36, 62, 93, 32, 48, 44, 48, 32, 45, 47, 91, 45, 49,
  93, 32, 50, 46, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  115, 104, 91, 36, 62, 93, 32, 49, 44, 49, 32, 45, 47, 91, 45, 49,
  93, 32, 49, 46, 50, 55, 53, 32, 45, 45, 91, 45, 49, 93, 32, 49,
  48, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 36,
  62, 93, 32, 50, 44, 50, 32, 45, 47, 91, 45, 49, 93, 32, 49, 46,
  49, 53, 57, 48, 57, 32, 45, 45, 91, 45, 49, 93, 32, 49, 49, 48,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 100, 111, 110, 101, 32, 45,
  108, 97, 98, 50, 114, 103, 98, 32, 45, 118, 32, 43, 10, 108, 99, 104,
  50, 108, 97, 98, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  102, 114, 111, 109, 32, 76, 99, 104, 32, 116, 111, 32, 76, 97, 98, 32,
  99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 44, 51, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 32, 99, 32, 45, 112,
  111, 108, 97, 114, 50, 99, 111, 109, 112, 108, 101, 120, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 108, 99, 104, 50, 114, 103,
  98, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110,
  118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114, 111,
  109, 32, 76, 99, 104, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111, 108,
  111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 108, 99, 104, 50, 108, 97, 98, 32, 45, 108, 97, 98, 50, 114, 103,
  98, 32, 45, 118, 32, 43, 10, 108, 99, 104, 56, 50, 114, 103, 98, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101,
  114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114, 111, 109, 32,
  76, 99, 104, 56, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111, 108, 111,
  114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 115, 104, 91, 36, 62,
  93, 32, 48, 44, 48, 32, 45, 47, 91, 45, 49, 93, 32, 50, 46, 53,
  53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 36, 62,
  93, 32, 49, 44, 49, 32, 45, 47, 91, 45, 49, 93, 32, 49, 46, 56,
  56, 56, 56, 57, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104,
  91, 36, 62, 93, 32, 50, 44, 50, 32, 45, 47, 91, 45, 49, 93, 32,
  52, 48, 46, 53, 56, 52, 53, 32, 45, 45, 91, 45, 49, 93, 32, 51,
  46, 49, 52, 49, 53, 57, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  100, 111, 110, 101, 32, 45, 108, 99, 104, 50, 114, 103, 98, 32, 45, 118,
  32, 43, 10, 108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 58, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32,
  108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 111, 102, 32, 105, 109, 97,
  103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 109,
  111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 115, 114, 103,
  98, 50, 114, 103, 98, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 115, 61, 61,
  51, 125, 32, 45, 115, 104, 32, 48, 44, 48, 32, 45, 115, 104, 91, 48,
  93, 32, 49, 44, 49, 32, 45, 115, 104, 91, 48, 93, 32, 50, 44, 50,
  32, 45, 42, 91, 49, 93, 32, 48, 46, 50, 57, 57, 32, 45, 42, 91,
  50, 93, 32, 48, 46, 53, 56, 55, 32, 45, 42, 91, 51, 93, 32, 48,
  46, 49, 49, 52, 32, 45, 43, 91, 49, 45, 51, 93, 32, 45, 114, 109,
  91, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123, 115, 33, 61, 49, 125,
  32, 45, 110, 111, 114, 109, 32, 45, 110, 32, 48, 44, 50, 53, 53, 10,
  45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48, 32, 45,
  114, 103, 98, 50, 115, 114, 103, 98, 32, 45, 118, 32, 43, 10, 109, 105,
  120, 95, 114, 103, 98, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  49, 61, 49, 125, 44, 36, 123, 50, 61, 48, 125, 44, 36, 123, 51, 61,
  48, 125, 44, 36, 123, 52, 61, 48, 125, 44, 36, 123, 53, 61, 49, 125,
  44, 36, 123, 54, 61, 48, 125, 44, 36, 123, 55, 61, 48, 125, 44, 36,
  123, 56, 61, 48, 125, 44, 36, 123, 57, 61, 49, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 109, 97, 116, 114,
  105, 120, 32, 91, 32, 36, 49, 32, 36, 50, 32, 36, 51, 32, 59, 32,
  36, 52, 32, 36, 53, 32, 36, 54, 32, 59, 32, 36, 55, 32, 36, 56,
  32, 36, 57, 32, 93, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111, 108,
  111, 114, 115, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 44, 51, 44, 48, 44, 50, 32, 45, 109, 105, 120, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 40, 36, 49, 44, 36, 50, 44,
  36, 51, 59, 36, 52, 44, 36, 53, 44, 36, 54, 59, 36, 55, 44, 36,
  56, 44, 36, 57, 41, 32, 45, 118, 32, 43, 10, 112, 115, 101, 117, 100,
  111, 103, 114, 97, 121, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 53, 125, 41, 32, 38, 38,
  32, 36, 49, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 50, 46,
  51, 125, 62, 61, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36,
  123, 51, 61, 56, 125, 41, 32, 38, 38, 32, 36, 51, 62, 48, 34, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 71, 101, 110, 101, 114, 97, 116,
  101, 32, 112, 115, 101, 117, 100, 111, 103, 114, 97, 121, 32, 99, 111, 108,
  111, 114, 109, 97, 112, 32, 119, 105, 116, 104, 32, 105, 110, 99, 114, 101,
  109, 101, 110, 116, 32, 36, 49, 44, 32, 74, 78, 68, 32, 116, 104, 114,
  101, 115, 104, 111, 108, 100, 32, 36, 50, 32, 97, 110, 100, 32, 36, 51,
  32, 98, 105, 116, 115, 32, 100, 101, 112, 116, 104, 46, 34, 10, 45, 118,
  32, 45, 10, 123, 114, 111, 117, 110, 100, 40, 50, 94, 36, 51, 41, 125,
  44, 49, 44, 49, 44, 51, 44, 39, 120, 39, 10, 45, 105, 102, 32, 123,
  33, 36, 49, 125, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 32, 45, 118, 32, 43, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45,
  101, 110, 100, 105, 102, 10, 123, 36, 49, 43, 49, 125, 44, 123, 36, 49,
  43, 49, 125, 44, 123, 36, 49, 43, 49, 125, 44, 49, 44, 39, 120, 39,
  32, 45, 45, 102, 91, 45, 49, 93, 32, 39, 121, 39, 32, 45, 45, 102,
  91, 45, 49, 93, 32, 39, 122, 39, 32, 45, 97, 91, 45, 51, 45, 45,
  49, 93, 32, 99, 32, 45, 114, 91, 45, 49, 93, 32, 123, 119, 42, 104,
  42, 100, 125, 44, 49, 44, 49, 44, 51, 44, 45, 49, 10, 45, 102, 91,
  45, 49, 93, 32, 39, 82, 61, 105, 40, 120, 44, 48, 44, 48, 44, 48,
  41, 59, 71, 61, 105, 40, 120, 44, 48, 44, 48, 44, 49, 41, 59, 66,
  61, 105, 40, 120, 44, 48, 44, 48, 44, 50, 41, 59, 105, 102, 40, 109,
  105, 110, 40, 82, 44, 71, 44, 66, 41, 44, 45, 49, 44, 105, 41, 39,
  10, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 49, 93, 32, 99, 120,
  121, 122, 32, 45, 100, 105, 115, 99, 97, 114, 100, 91, 45, 49, 93, 32,
  45, 49, 32, 45, 114, 91, 45, 49, 93, 32, 51, 44, 123, 104, 47, 51,
  125, 44, 49, 44, 49, 44, 45, 49, 32, 45, 112, 101, 114, 109, 117, 116,
  101, 91, 45, 49, 93, 32, 121, 122, 99, 120, 10, 45, 114, 91, 45, 50,
  93, 32, 123, 119, 42, 49, 48, 48, 125, 37, 32, 45, 114, 91, 45, 49,
  93, 32, 91, 45, 50, 93, 44, 48, 44, 50, 32, 45, 43, 91, 45, 50,
  44, 45, 49, 93, 10, 45, 102, 91, 45, 49, 93, 32, 39, 82, 61, 105,
  40, 120, 44, 48, 44, 48, 44, 48, 41, 59, 71, 61, 105, 40, 120, 44,
  48, 44, 48, 44, 49, 41, 59, 66, 61, 105, 40, 120, 44, 48, 44, 48,
  44, 50, 41, 59, 105, 102, 40, 109, 97, 120, 40, 82, 44, 71, 44, 66,
  41, 62, 50, 94, 36, 51, 45, 49, 44, 45, 49, 44, 105, 41, 39, 10,
  45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 49, 93, 32, 99, 120, 121,
  122, 32, 45, 100, 105, 115, 99, 97, 114, 100, 91, 45, 49, 93, 32, 45,
  49, 32, 45, 114, 91, 45, 49, 93, 32, 51, 44, 123, 104, 47, 51, 125,
  44, 49, 44, 49, 44, 45, 49, 32, 45, 112, 101, 114, 109, 117, 116, 101,
  91, 45, 49, 93, 32, 121, 122, 99, 120, 10, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 10, 45, 45, 115, 114, 103, 98, 50, 114, 103,
  98, 91, 45, 49, 93, 32, 45, 114, 103, 98, 50, 108, 97, 98, 91, 45,
  49, 93, 32, 45, 114, 118, 91, 45, 50, 44, 45, 49, 93, 32, 45, 97,
  91, 45, 50, 44, 45, 49, 93, 32, 121, 32, 45, 115, 111, 114, 116, 91,
  45, 49, 93, 32, 43, 44, 120, 10, 45, 105, 102, 32, 123, 33, 36, 50,
  125, 32, 45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 49, 10, 45, 101,
  108, 115, 101, 10, 45, 115, 91, 45, 49, 93, 32, 121, 32, 45, 114, 118,
  91, 45, 50, 44, 45, 49, 93, 32, 91, 45, 49, 93, 32, 45, 115, 104,
  91, 45, 49, 93, 32, 49, 44, 50, 32, 45, 102, 91, 45, 49, 93, 32,
  48, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 45, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 110, 111, 114, 109, 91, 45, 49, 93, 10, 45, 108,
  101, 91, 45, 49, 93, 32, 36, 50, 32, 45, 42, 91, 45, 49, 93, 32,
  39, 120, 43, 49, 39, 32, 45, 100, 105, 115, 99, 97, 114, 100, 91, 45,
  49, 93, 32, 48, 32, 45, 45, 91, 45, 49, 93, 32, 49, 32, 45, 109,
  97, 112, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 114, 109, 91,
  45, 50, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 49, 48, 48, 48,
  48, 10, 45, 45, 115, 114, 103, 98, 50, 114, 103, 98, 91, 45, 49, 93,
  32, 45, 114, 103, 98, 50, 108, 97, 98, 91, 45, 49, 93, 32, 45, 45,
  115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 48, 44, 123, 49, 45, 50,
  42, 40, 36, 62, 37, 50, 41, 125, 44, 48, 44, 48, 44, 49, 32, 45,
  45, 91, 45, 50, 44, 45, 49, 93, 32, 45, 110, 111, 114, 109, 91, 45,
  49, 93, 10, 45, 108, 101, 91, 45, 49, 93, 32, 36, 50, 10, 45, 105,
  102, 32, 123, 105, 109, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  98, 114, 101, 97, 107, 32, 45, 101, 110, 100, 105, 102, 10, 45, 42, 91,
  45, 49, 93, 32, 39, 121, 43, 49, 39, 32, 45, 100, 105, 115, 99, 97,
  114, 100, 91, 45, 49, 93, 32, 48, 32, 45, 45, 91, 45, 49, 93, 32,
  49, 32, 45, 109, 97, 112, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32,
  45, 114, 109, 91, 45, 50, 93, 10, 45, 100, 111, 110, 101, 10, 45, 116,
  114, 97, 110, 115, 112, 111, 115, 101, 91, 45, 49, 93, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 118, 32, 43, 10, 114, 101, 112, 108, 97, 99, 101,
  95, 99, 111, 108, 111, 114, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 36, 49, 62, 61, 48, 32, 38, 38, 32, 36, 50, 62, 61, 48, 34,
  10, 45, 118, 32, 45, 32, 45, 108, 91, 93, 32, 40, 36, 123, 51, 45,
  45, 49, 125, 41, 32, 45, 121, 32, 99, 32, 45, 115, 32, 99, 44, 50,
  32, 99, 111, 108, 49, 61, 64, 48, 32, 99, 111, 108, 50, 61, 64, 49,
  32, 45, 114, 109, 32, 45, 101, 110, 100, 108, 32, 45, 118, 32, 43, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 112, 108, 97, 99, 101,
  32, 99, 111, 108, 111, 114, 32, 40, 34, 36, 99, 111, 108, 49, 34, 41,
  32, 98, 121, 32, 99, 111, 108, 111, 114, 32, 40, 34, 36, 99, 111, 108,
  50, 34, 41, 32, 105, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32,
  119, 105, 116, 104, 32, 116, 111, 108, 101, 114, 97, 110, 99, 101, 32, 36,
  49, 32, 97, 110, 100, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 49, 44, 49,
  44, 49, 44, 49, 48, 48, 37, 44, 36, 99, 111, 108, 49, 32, 45, 114,
  91, 49, 93, 32, 91, 48, 93, 10, 45, 105, 102, 32, 36, 49, 32, 45,
  45, 91, 49, 93, 32, 91, 48, 93, 32, 45, 110, 111, 114, 109, 91, 49,
  93, 32, 45, 108, 101, 91, 49, 93, 32, 36, 49, 32, 45, 101, 108, 115,
  101, 32, 45, 61, 61, 91, 49, 93, 32, 91, 48, 93, 32, 45, 108, 91,
  49, 93, 32, 45, 115, 32, 99, 32, 45, 97, 110, 100, 32, 45, 101, 110,
  100, 108, 32, 45, 101, 110, 100, 105, 102, 10, 45, 98, 91, 49, 93, 32,
  36, 50, 10, 49, 44, 49, 44, 49, 44, 64, 123, 48, 44, 115, 125, 44,
  36, 99, 111, 108, 50, 32, 45, 114, 91, 50, 93, 32, 91, 48, 93, 32,
  45, 106, 91, 48, 93, 32, 91, 50, 93, 44, 48, 44, 48, 44, 48, 44,
  48, 44, 49, 44, 91, 49, 93, 32, 45, 107, 91, 48, 93, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 114,
  103, 98, 50, 98, 97, 121, 101, 114, 32, 58, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 49, 61, 48, 125, 44, 36, 123, 50, 61, 48, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 84, 114, 97, 110, 115, 102, 111, 114,
  109, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 111, 32, 97, 32, 82,
  71, 66, 45, 66, 97, 121, 101, 114, 32, 34, 64, 123, 45, 97, 114, 103,
  92, 32, 49, 43, 33, 36, 50, 44, 99, 111, 108, 111, 114, 44, 109, 111,
  110, 111, 99, 104, 114, 111, 109, 101, 125, 34, 32, 103, 114, 105, 100, 44,
  32, 115, 116, 97, 114, 116, 105, 110, 103, 32, 102, 114, 111, 109, 32, 112,
  97, 116, 116, 101, 114, 110, 32, 39, 36, 49, 39, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 95, 114,
  103, 98, 50, 98, 97, 121, 101, 114, 36, 49, 32, 45, 114, 91, 49, 93,
  32, 91, 48, 93, 44, 48, 44, 50, 32, 45, 42, 32, 45, 105, 102, 32,
  123, 33, 36, 50, 125, 32, 45, 115, 32, 99, 32, 45, 43, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 95, 114, 103, 98, 50, 98, 97, 121, 101, 114,
  48, 32, 58, 32, 40, 49, 44, 48, 59, 48, 44, 48, 94, 48, 44, 49,
  59, 49, 44, 48, 94, 48, 44, 48, 59, 48, 44, 49, 41, 10, 95, 114,
  103, 98, 50, 98, 97, 121, 101, 114, 49, 32, 58, 32, 40, 48, 44, 48,
  59, 48, 44, 49, 94, 48, 44, 49, 59, 49, 44, 48, 94, 49, 44, 48,
  59, 48, 44, 48, 41, 10, 95, 114, 103, 98, 50, 98, 97, 121, 101, 114,
  50, 32, 58, 32, 40, 48, 44, 48, 59, 49, 44, 48, 94, 49, 44, 48,
  59, 48, 44, 49, 94, 48, 44, 49, 59, 48, 44, 48, 41, 10, 95, 114,
  103, 98, 50, 98, 97, 121, 101, 114, 51, 32, 58, 32, 40, 48, 44, 49,
  59, 48, 44, 48, 94, 49, 44, 48, 59, 48, 44, 49, 94, 48, 44, 48,
  59, 49, 44, 48, 41, 10, 114, 103, 98, 50, 99, 109, 121, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114, 111, 109, 32, 82, 71,
  66, 32, 116, 111, 32, 67, 77, 89, 32, 99, 111, 108, 111, 114, 32, 98,
  97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 116, 111, 95,
  114, 103, 98, 32, 45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 42, 32,
  45, 49, 32, 45, 43, 32, 50, 53, 53, 32, 45, 118, 32, 43, 10, 114,
  103, 98, 50, 99, 109, 121, 107, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101,
  36, 63, 32, 102, 114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 67,
  77, 89, 75, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 103, 98, 50, 99, 109, 121, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 115, 32, 99, 32, 45, 45, 109, 105, 110, 32, 45, 45, 91,
  48, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 45, 47, 91, 45, 49,
  93, 32, 50, 53, 53, 32, 45, 45, 91, 45, 49, 93, 32, 49, 32, 45,
  42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 45, 101, 113, 91, 45, 49,
  93, 32, 48, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 47,
  91, 48, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45,
  49, 93, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 114, 103, 98, 50, 104, 115, 105,
  56, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110,
  118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114, 111,
  109, 32, 82, 71, 66, 32, 116, 111, 32, 72, 83, 73, 56, 32, 99, 111,
  108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 103, 98, 50, 104, 115, 105, 32, 45, 95, 114, 103, 98, 50,
  104, 115, 120, 56, 32, 45, 118, 32, 43, 10, 114, 103, 98, 50, 104, 115,
  108, 56, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111,
  110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114,
  111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 72, 83, 76, 56, 32, 99,
  111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 103, 98, 50, 104, 115, 108, 32, 45, 95, 114, 103, 98,
  50, 104, 115, 120, 56, 32, 45, 118, 32, 43, 10, 114, 103, 98, 50, 104,
  115, 118, 56, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67,
  111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102,
  114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 72, 83, 86, 56, 32,
  99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 103, 98, 50, 104, 115, 118, 32, 45, 95, 114, 103,
  98, 50, 104, 115, 120, 56, 32, 45, 118, 32, 43, 10, 95, 114, 103, 98,
  50, 104, 115, 120, 56, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 10, 45, 115, 104, 91, 36, 62, 93, 32, 48, 44, 48, 32, 45,
  42, 91, 45, 49, 93, 32, 48, 46, 55, 48, 56, 51, 51, 51, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 36, 62, 93, 32, 49,
  44, 50, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 100, 111, 110, 101, 10, 114, 103, 98, 50,
  108, 97, 98, 56, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  102, 114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 76, 97, 98, 56,
  32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 103, 98, 50, 108, 97, 98, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 10, 45, 115, 104, 91, 36, 62, 93, 32,
  48, 44, 48, 32, 45, 42, 91, 45, 49, 93, 32, 50, 46, 53, 53, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 36, 62, 93, 32,
  49, 44, 49, 32, 45, 43, 91, 45, 49, 93, 32, 49, 48, 48, 32, 45,
  42, 91, 45, 49, 93, 32, 49, 46, 50, 55, 53, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 115, 104, 91, 36, 62, 93, 32, 50, 44, 50, 32,
  45, 43, 91, 45, 49, 93, 32, 49, 49, 48, 32, 45, 42, 91, 45, 49,
  93, 32, 49, 46, 49, 53, 57, 48, 57, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 114, 103, 98,
  50, 108, 99, 104, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  102, 114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 76, 99, 104, 32,
  99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 103, 98, 50, 108, 97, 98, 32, 45, 108, 97, 98,
  50, 108, 99, 104, 32, 45, 118, 32, 43, 10, 114, 103, 98, 50, 108, 99,
  104, 56, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111,
  110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114,
  111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 76, 99, 104, 56, 32, 99,
  111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 103, 98, 50, 108, 99, 104, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 10, 45, 115, 104, 91, 36, 62, 93, 32, 48, 44,
  48, 32, 45, 42, 91, 45, 49, 93, 32, 50, 46, 53, 53, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 36, 62, 93, 32, 49, 44,
  49, 32, 45, 42, 91, 45, 49, 93, 32, 49, 46, 56, 56, 56, 56, 57,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 36, 62, 93,
  32, 50, 44, 50, 32, 45, 43, 91, 45, 49, 93, 32, 51, 46, 49, 52,
  49, 53, 57, 32, 45, 42, 91, 45, 49, 93, 32, 52, 48, 46, 53, 56,
  52, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 114, 103, 98, 50, 108, 117, 118, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114, 111, 109, 32, 82, 71,
  66, 32, 116, 111, 32, 76, 85, 86, 32, 99, 111, 108, 111, 114, 32, 98,
  97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45,
  114, 103, 98, 50, 120, 121, 122, 32, 45, 114, 103, 98, 50, 108, 97, 98,
  91, 45, 50, 93, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45,
  50, 93, 32, 48, 32, 45, 115, 91, 45, 49, 93, 32, 99, 10, 45, 42,
  91, 45, 49, 93, 32, 51, 32, 45, 45, 42, 91, 45, 50, 93, 32, 49,
  53, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 43, 91, 45,
  49, 93, 32, 91, 45, 51, 93, 32, 45, 43, 91, 45, 49, 93, 32, 49,
  101, 45, 56, 10, 45, 42, 91, 45, 51, 93, 32, 52, 32, 45, 42, 91,
  45, 50, 93, 32, 57, 32, 45, 47, 91, 45, 51, 44, 45, 50, 93, 32,
  91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 45, 91,
  45, 50, 93, 32, 48, 46, 50, 48, 48, 57, 32, 45, 45, 91, 45, 49,
  93, 32, 48, 46, 52, 54, 49, 48, 10, 45, 45, 42, 91, 45, 51, 93,
  32, 49, 51, 32, 45, 42, 91, 45, 51, 93, 32, 91, 45, 49, 93, 32,
  45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 97, 32, 99, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  114, 103, 98, 50, 120, 121, 122, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101,
  36, 63, 32, 102, 114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 88,
  89, 90, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 47, 32, 50, 53, 53, 32, 45, 109, 105,
  120, 95, 114, 103, 98, 32, 48, 46, 52, 49, 50, 52, 53, 51, 44, 48,
  46, 51, 53, 55, 53, 56, 48, 44, 48, 46, 49, 56, 48, 52, 50, 51,
  44, 48, 46, 50, 49, 50, 54, 55, 49, 44, 48, 46, 55, 49, 53, 49,
  54, 48, 44, 48, 46, 48, 55, 50, 49, 54, 57, 44, 48, 46, 48, 49,
  57, 51, 51, 52, 44, 48, 46, 49, 49, 57, 49, 57, 51, 44, 48, 46,
  57, 53, 48, 50, 50, 55, 32, 45, 118, 32, 43, 10, 114, 103, 98, 50,
  120, 121, 122, 56, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  102, 114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 88, 89, 90, 56,
  32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 103, 98, 50, 120, 121, 122, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 10, 45, 115, 104, 91, 36, 62, 93, 32,
  48, 44, 48, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 36, 62, 93, 32, 49,
  44, 49, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 36, 62, 93, 32, 50, 44,
  50, 32, 45, 42, 91, 45, 49, 93, 32, 50, 51, 49, 46, 56, 49, 56,
  50, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 114, 103, 98, 50, 121, 99, 98, 99, 114, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114,
  116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114, 111, 109, 32, 82,
  71, 66, 32, 116, 111, 32, 89, 67, 98, 67, 114, 32, 99, 111, 108, 111,
  114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  109, 105, 120, 95, 114, 103, 98, 32, 54, 54, 44, 49, 50, 57, 44, 50,
  53, 44, 45, 51, 56, 44, 45, 55, 52, 44, 49, 49, 50, 44, 49, 49,
  50, 44, 45, 57, 52, 44, 45, 49, 56, 32, 45, 43, 32, 49, 50, 56,
  32, 45, 47, 32, 50, 53, 54, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 104, 32, 48, 44,
  48, 32, 45, 43, 91, 45, 49, 93, 32, 49, 54, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 115, 104, 32, 49, 44, 50, 32, 45, 43, 91, 45,
  49, 93, 32, 49, 50, 56, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 118, 32, 43, 10,
  114, 103, 98, 50, 121, 117, 118, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101,
  36, 63, 32, 102, 114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 89,
  85, 86, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 47, 32, 50, 53, 53, 32, 45, 109, 105,
  120, 95, 114, 103, 98, 32, 48, 46, 50, 57, 57, 44, 48, 46, 53, 56,
  55, 44, 48, 46, 49, 49, 52, 44, 45, 48, 46, 49, 52, 55, 49, 51,
  44, 45, 48, 46, 50, 56, 56, 56, 54, 44, 48, 46, 52, 51, 54, 44,
  48, 46, 54, 49, 53, 44, 45, 48, 46, 53, 49, 52, 57, 56, 44, 45,
  48, 46, 49, 48, 48, 48, 49, 32, 45, 118, 32, 43, 10, 114, 103, 98,
  50, 121, 117, 118, 56, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63,
  32, 102, 114, 111, 109, 32, 82, 71, 66, 32, 116, 111, 32, 89, 85, 86,
  56, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 103, 98, 50, 121, 117, 118, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 115, 104, 91, 36, 62, 93,
  32, 48, 44, 48, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 36, 62, 93, 32,
  49, 44, 49, 32, 45, 43, 91, 45, 49, 93, 32, 48, 46, 52, 52, 32,
  45, 42, 91, 45, 49, 93, 32, 50, 56, 57, 46, 55, 55, 51, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 36, 62, 93, 32, 50,
  44, 50, 32, 45, 43, 91, 45, 49, 93, 32, 48, 46, 54, 50, 32, 45,
  42, 91, 45, 49, 93, 32, 50, 48, 53, 46, 54, 52, 53, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 109, 111, 118,
  101, 32, 111, 112, 97, 99, 105, 116, 121, 32, 99, 104, 97, 110, 110, 101,
  108, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 115, 61, 61, 50, 125,
  32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48, 10, 45, 101, 108,
  105, 102, 32, 123, 115, 61, 61, 52, 125, 32, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 48, 44, 50, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  110, 109, 32, 64, 123, 45, 49, 44, 110, 125, 44, 49, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 115, 101,
  108, 101, 99, 116, 95, 99, 111, 108, 111, 114, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 49, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 83, 101, 108, 101, 99, 116, 32, 99, 111, 108, 111, 114, 32,
  40, 36, 123, 50, 45, 45, 49, 125, 41, 32, 105, 110, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 116, 111, 108, 101, 114,
  97, 110, 99, 101, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 45, 102, 99, 32, 36, 123, 50, 45, 45, 49, 125, 32, 45, 45,
  32, 45, 110, 111, 114, 109, 32, 45, 108, 101, 32, 36, 49, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 115,
  101, 112, 105, 97, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  65, 112, 112, 108, 121, 32, 115, 101, 112, 105, 97, 32, 116, 111, 110, 101,
  115, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109, 97, 103,
  101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 40, 48, 44, 52, 52,
  44, 49, 49, 53, 44, 49, 52, 51, 44, 49, 57, 54, 44, 50, 52, 52,
  94, 48, 44, 50, 48, 44, 56, 52, 44, 49, 49, 57, 44, 49, 56, 52,
  44, 50, 51, 53, 94, 48, 44, 53, 44, 52, 52, 44, 55, 51, 44, 49,
  52, 52, 44, 50, 48, 48, 41, 32, 45, 114, 91, 45, 49, 93, 32, 50,
  53, 54, 44, 49, 44, 49, 44, 51, 44, 51, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 45, 108, 91, 36, 62, 44,
  45, 49, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105,
  116, 121, 32, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 48, 93,
  32, 45, 109, 97, 112, 91, 48, 93, 32, 91, 45, 49, 93, 32, 45, 97,
  91, 94, 45, 49, 93, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 118, 32, 43,
  10, 115, 111, 108, 97, 114, 105, 122, 101, 32, 58, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 83, 111, 108, 97, 114, 105, 122, 101, 32, 105, 109,
  97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 108, 117,
  109, 105, 110, 97, 110, 99, 101, 32, 45, 110, 32, 48, 44, 49, 50, 56,
  32, 45, 109, 97, 112, 32, 49, 32, 45, 118, 32, 43, 10, 115, 112, 108,
  105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 83, 112, 108, 105, 116, 32, 99, 111, 108, 111,
  114, 32, 97, 110, 100, 32, 111, 112, 97, 99, 105, 116, 121, 32, 112, 97,
  114, 116, 115, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 60, 93, 32, 45, 115, 32, 99, 44, 123, 105, 102,
  40, 115, 61, 61, 52, 44, 45, 51, 44, 105, 102, 40, 115, 61, 61, 50,
  44, 45, 49, 44, 45, 115, 41, 41, 125, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 116, 111, 95, 97, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 70, 111, 114, 99, 101,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 111, 32, 104, 97, 118, 101,
  32, 97, 110, 32, 97, 108, 112, 104, 97, 32, 99, 104, 97, 110, 110, 101,
  108, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123,
  115, 61, 61, 49, 124, 124, 115, 61, 61, 51, 125, 32, 45, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 48, 44, 123, 115, 125, 32, 45, 115, 104, 91,
  45, 49, 93, 32, 123, 115, 45, 49, 125, 44, 123, 115, 45, 49, 125, 32,
  45, 102, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 109, 91, 45,
  49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 116, 111, 95, 99, 111,
  108, 111, 114, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 70,
  111, 114, 99, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 111, 32,
  98, 101, 32, 105, 110, 32, 99, 111, 108, 111, 114, 32, 109, 111, 100, 101,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 115,
  62, 52, 125, 32, 45, 101, 114, 114, 111, 114, 91, 93, 32, 34, 73, 109,
  97, 103, 101, 32, 91, 34, 64, 123, 60, 44, 45, 49, 125, 34, 93, 32,
  105, 115, 32, 110, 111, 116, 32, 97, 32, 71, 44, 71, 65, 44, 82, 71,
  66, 32, 111, 114, 32, 82, 71, 66, 65, 32, 105, 109, 97, 103, 101, 46,
  34, 10, 45, 101, 108, 105, 102, 32, 123, 115, 61, 61, 50, 125, 32, 45,
  114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 52, 44,
  48, 44, 49, 44, 48, 44, 48, 44, 48, 44, 49, 10, 45, 101, 108, 105,
  102, 32, 123, 115, 61, 61, 49, 125, 32, 45, 114, 32, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 44, 51, 44, 49, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 125, 10,
  45, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 32, 45, 116, 111, 95,
  103, 114, 97, 121, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61,
  50, 125, 32, 45, 116, 111, 95, 103, 114, 97, 121, 97, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 61, 61, 51, 125, 32, 45, 116, 111, 95, 114,
  103, 98, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 52, 125,
  32, 45, 116, 111, 95, 114, 103, 98, 97, 10, 45, 101, 108, 115, 101, 10,
  115, 61, 49, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45,
  105, 102, 32, 123, 64, 123, 36, 62, 44, 115, 125, 62, 52, 125, 32, 45,
  101, 114, 114, 111, 114, 32, 34, 73, 109, 97, 103, 101, 32, 91, 34, 36,
  62, 34, 93, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 71, 44, 71,
  65, 44, 82, 71, 66, 32, 111, 114, 32, 82, 71, 66, 65, 32, 105, 109,
  97, 103, 101, 46, 34, 10, 45, 101, 108, 115, 101, 32, 115, 61, 123, 109,
  97, 120, 40, 36, 115, 44, 64, 123, 36, 62, 44, 115, 125, 41, 125, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 32, 45, 116, 111,
  95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 36, 115, 10, 45, 101,
  110, 100, 105, 102, 10, 116, 111, 95, 103, 114, 97, 121, 32, 58, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 70, 111, 114, 99, 101, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 116, 111, 32, 98, 101, 32, 105, 110, 32, 71,
  82, 65, 89, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 105, 102, 32, 123, 115, 62, 52, 125, 32, 45, 101, 114, 114,
  111, 114, 91, 93, 32, 34, 73, 109, 97, 103, 101, 32, 91, 34, 64, 123,
  60, 44, 45, 49, 125, 34, 93, 32, 105, 115, 32, 110, 111, 116, 32, 97,
  32, 71, 44, 71, 65, 44, 82, 71, 66, 32, 111, 114, 32, 82, 71, 66,
  65, 32, 105, 109, 97, 103, 101, 46, 34, 10, 45, 101, 108, 105, 102, 32,
  123, 115, 62, 61, 51, 125, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 48, 44, 50, 32, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 10,
  45, 101, 108, 105, 102, 32, 123, 115, 61, 61, 50, 125, 32, 45, 114, 32,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 116, 111, 95, 103, 114,
  97, 121, 97, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 70,
  111, 114, 99, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 111, 32,
  98, 101, 32, 105, 110, 32, 71, 82, 65, 89, 65, 32, 109, 111, 100, 101,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 115,
  62, 52, 125, 32, 45, 101, 114, 114, 111, 114, 91, 93, 32, 34, 73, 109,
  97, 103, 101, 32, 91, 34, 64, 123, 60, 44, 45, 49, 125, 34, 93, 32,
  105, 115, 32, 110, 111, 116, 32, 97, 32, 71, 44, 71, 65, 44, 82, 71,
  66, 32, 111, 114, 32, 82, 71, 66, 65, 32, 105, 109, 97, 103, 101, 46,
  34, 10, 45, 101, 108, 105, 102, 32, 123, 115, 61, 61, 52, 125, 32, 45,
  45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 51, 32, 45, 99, 104, 97,
  110, 110, 101, 108, 115, 91, 45, 50, 93, 32, 48, 44, 50, 32, 45, 108,
  117, 109, 105, 110, 97, 110, 99, 101, 91, 45, 50, 93, 32, 45, 97, 32,
  99, 10, 45, 101, 108, 105, 102, 32, 123, 115, 61, 61, 51, 125, 32, 45,
  108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 48, 44, 49, 32, 45, 115, 104, 91, 45, 49, 93, 32,
  49, 44, 49, 32, 45, 102, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123, 115, 61,
  61, 49, 125, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48, 44,
  49, 32, 45, 115, 104, 91, 45, 49, 93, 32, 49, 44, 49, 32, 45, 102,
  91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 116, 111, 95, 112, 115, 101, 117,
  100, 111, 103, 114, 97, 121, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 53, 125, 41, 32, 38,
  38, 32, 36, 49, 62, 61, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116,
  40, 36, 123, 51, 61, 56, 125, 41, 32, 38, 38, 32, 36, 51, 62, 48,
  34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 49, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32,
  115, 99, 97, 108, 97, 114, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116,
  111, 32, 112, 115, 101, 117, 100, 111, 45, 103, 114, 97, 121, 32, 99, 111,
  108, 111, 114, 32, 105, 109, 97, 103, 101, 115, 44, 32, 119, 105, 116, 104,
  32, 115, 116, 101, 112, 115, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48, 32, 45, 115, 114,
  103, 98, 50, 114, 103, 98, 32, 45, 112, 115, 101, 117, 100, 111, 103, 114,
  97, 121, 32, 36, 49, 44, 123, 50, 46, 51, 42, 36, 50, 125, 44, 36,
  51, 10, 45, 45, 115, 114, 103, 98, 50, 114, 103, 98, 91, 45, 49, 93,
  32, 45, 114, 103, 98, 50, 108, 97, 98, 91, 45, 49, 93, 32, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 32, 45, 42,
  91, 45, 49, 93, 32, 123, 54, 53, 53, 51, 53, 47, 49, 48, 48, 125,
  32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 45, 114, 111, 119,
  115, 91, 45, 49, 93, 32, 48, 44, 50, 10, 45, 114, 118, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 49,
  93, 32, 120, 99, 121, 122, 32, 45, 43, 91, 45, 49, 93, 32, 49, 32,
  45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 32, 45, 112, 111, 105,
  110, 116, 99, 108, 111, 117, 100, 91, 45, 49, 93, 32, 48, 10, 45, 45,
  110, 111, 114, 109, 91, 45, 49, 93, 32, 45, 110, 101, 113, 91, 45, 49,
  93, 32, 48, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49,
  93, 32, 49, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 119,
  97, 116, 101, 114, 115, 104, 101, 100, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 45, 91, 45, 49, 93,
  32, 49, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49,
  125, 10, 45, 116, 111, 95, 114, 103, 98, 91, 36, 62, 93, 32, 45, 114,
  103, 98, 50, 108, 97, 98, 91, 36, 62, 93, 32, 45, 99, 104, 97, 110,
  110, 101, 108, 115, 91, 36, 62, 93, 32, 48, 32, 45, 42, 91, 36, 62,
  93, 32, 123, 54, 53, 53, 51, 53, 47, 49, 48, 48, 125, 32, 45, 114,
  111, 117, 110, 100, 91, 36, 62, 93, 32, 45, 99, 91, 36, 62, 93, 32,
  48, 44, 54, 53, 53, 51, 53, 10, 45, 109, 97, 112, 91, 36, 62, 93,
  32, 91, 45, 49, 93, 10, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 118, 32, 43, 10, 116, 111, 95, 114, 103, 98, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 70, 111, 114, 99, 101,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 111, 32, 98, 101, 32, 105,
  110, 32, 82, 71, 66, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 105, 102, 32, 123, 115, 62, 52, 125, 32, 45, 101,
  114, 114, 111, 114, 91, 93, 32, 34, 73, 109, 97, 103, 101, 32, 91, 34,
  64, 123, 60, 44, 45, 49, 125, 34, 93, 32, 105, 115, 32, 110, 111, 116,
  32, 97, 32, 71, 44, 71, 65, 44, 82, 71, 66, 32, 111, 114, 32, 82,
  71, 66, 65, 32, 105, 109, 97, 103, 101, 46, 34, 10, 45, 101, 108, 105,
  102, 32, 123, 115, 61, 61, 52, 125, 32, 45, 99, 104, 97, 110, 110, 101,
  108, 115, 32, 48, 44, 50, 10, 45, 101, 108, 105, 102, 32, 123, 115, 61,
  61, 50, 125, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48, 44,
  48, 32, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 51, 10, 45, 101, 108, 105, 102, 32, 123, 115, 61, 61,
  49, 125, 32, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 44, 51, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 116,
  111, 95, 114, 103, 98, 97, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 70, 111, 114, 99, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  116, 111, 32, 98, 101, 32, 105, 110, 32, 82, 71, 66, 65, 32, 109, 111,
  100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32,
  123, 115, 62, 52, 125, 32, 45, 101, 114, 114, 111, 114, 91, 93, 32, 34,
  73, 109, 97, 103, 101, 32, 91, 34, 64, 123, 60, 44, 45, 49, 125, 34,
  93, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 71, 44, 71, 65, 44,
  82, 71, 66, 32, 111, 114, 32, 82, 71, 66, 65, 32, 105, 109, 97, 103,
  101, 46, 34, 10, 45, 101, 108, 105, 102, 32, 123, 115, 61, 61, 51, 125,
  32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48, 44, 51, 32, 45,
  115, 104, 91, 45, 49, 93, 32, 51, 44, 51, 32, 45, 102, 91, 45, 49,
  93, 32, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101,
  108, 105, 102, 32, 123, 115, 61, 61, 50, 125, 32, 45, 114, 32, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 52, 32, 45,
  115, 104, 91, 45, 49, 93, 32, 50, 44, 50, 32, 45, 102, 91, 45, 49,
  93, 32, 91, 45, 50, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  101, 108, 105, 102, 32, 123, 115, 61, 61, 49, 125, 32, 45, 114, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 52, 32,
  45, 115, 104, 91, 45, 49, 93, 32, 51, 44, 51, 32, 45, 102, 91, 45,
  49, 93, 32, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 116, 114, 97, 110, 115, 102, 101, 114, 95,
  99, 111, 108, 111, 114, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 49, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 84,
  114, 97, 110, 115, 102, 101, 114, 32, 99, 111, 108, 111, 114, 115, 32, 111,
  102, 32, 105, 109, 97, 103, 101, 32, 91, 48, 93, 32, 116, 111, 32, 105,
  109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 105, 102, 32, 123, 64, 35,
  60, 50, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 118, 32, 45, 32, 45, 116, 111, 95, 114, 103, 98, 91,
  48, 93, 32, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101,
  91, 94, 48, 93, 32, 123, 109, 97, 120, 40, 51, 44, 64, 123, 45, 109,
  97, 120, 95, 115, 125, 41, 125, 32, 45, 99, 32, 48, 44, 50, 53, 53,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116,
  121, 32, 45, 114, 103, 98, 50, 121, 99, 98, 99, 114, 91, 48, 93, 32,
  45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 45, 108, 91, 48, 93, 32, 45, 115, 32, 99, 32, 45, 104, 105, 115,
  116, 111, 103, 114, 97, 109, 95, 99, 117, 109, 117, 108, 32, 50, 53, 54,
  44, 49, 44, 48, 44, 50, 53, 53, 32, 45, 97, 32, 99, 32, 45, 42,
  32, 50, 53, 53, 32, 45, 101, 110, 100, 108, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 45, 108, 91, 48, 44, 45,
  49, 93, 10, 45, 105, 102, 32, 36, 49, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 51, 32, 45, 115, 104, 91, 48, 44, 49, 93, 32, 36, 62, 44,
  36, 62, 32, 45, 101, 113, 117, 97, 108, 105, 122, 101, 91, 45, 49, 93,
  32, 50, 53, 54, 44, 48, 44, 50, 53, 53, 32, 45, 105, 110, 100, 101,
  120, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 32, 45,
  114, 109, 91, 45, 50, 44, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10,
  45, 101, 108, 115, 101, 32, 45, 114, 101, 112, 101, 97, 116, 32, 50, 32,
  45, 115, 104, 91, 48, 44, 49, 93, 32, 123, 36, 62, 43, 49, 125, 44,
  123, 36, 62, 43, 49, 125, 32, 45, 101, 113, 117, 97, 108, 105, 122, 101,
  91, 45, 49, 93, 32, 50, 53, 54, 44, 48, 44, 50, 53, 53, 32, 45,
  105, 110, 100, 101, 120, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48,
  44, 48, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 32, 45, 100,
  111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108,
  32, 45, 109, 118, 91, 45, 49, 93, 32, 49, 32, 45, 100, 111, 110, 101,
  32, 45, 114, 109, 91, 48, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116,
  95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 121, 99, 98, 99, 114, 50,
  114, 103, 98, 91, 48, 93, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 45, 118, 32, 43, 10, 95, 116, 114,
  97, 110, 115, 102, 101, 114, 95, 99, 111, 108, 111, 114, 115, 32, 58, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 32, 45, 114, 103, 98, 50, 121, 99, 98, 99, 114, 32, 45, 115, 32,
  99, 32, 45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 50, 53, 54,
  44, 48, 44, 50, 53, 53, 32, 45, 97, 32, 99, 32, 45, 100, 103, 32,
  51, 48, 48, 44, 50, 48, 48, 32, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 120, 121, 122, 50, 114, 103, 98, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 102, 114, 111, 109, 32, 88, 89, 90, 32,
  116, 111, 32, 82, 71, 66, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115,
  101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 42, 32, 50, 53, 53,
  32, 45, 109, 105, 120, 95, 114, 103, 98, 32, 51, 46, 50, 52, 48, 52,
  55, 57, 44, 45, 49, 46, 53, 51, 55, 49, 53, 48, 44, 45, 48, 46,
  52, 57, 56, 53, 51, 53, 44, 45, 48, 46, 57, 54, 57, 50, 53, 54,
  44, 49, 46, 56, 55, 53, 57, 57, 50, 44, 48, 46, 48, 52, 49, 53,
  53, 54, 44, 48, 46, 48, 53, 53, 54, 52, 56, 44, 45, 48, 46, 50,
  48, 52, 48, 52, 51, 44, 49, 46, 48, 53, 55, 51, 49, 49, 32, 45,
  99, 32, 48, 44, 50, 53, 53, 32, 45, 118, 32, 43, 10, 120, 121, 122,
  56, 50, 114, 103, 98, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63,
  32, 102, 114, 111, 109, 32, 88, 89, 90, 56, 32, 116, 111, 32, 82, 71,
  66, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10,
  45, 115, 104, 91, 36, 62, 93, 32, 48, 44, 48, 32, 45, 47, 91, 45,
  49, 93, 32, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  115, 104, 91, 36, 62, 93, 32, 49, 44, 49, 32, 45, 47, 91, 45, 49,
  93, 32, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115,
  104, 91, 36, 62, 93, 32, 50, 44, 50, 32, 45, 47, 91, 45, 49, 93,
  32, 50, 51, 49, 46, 56, 49, 56, 50, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 100, 111, 110, 101, 32, 45, 120, 121, 122, 50, 114, 103, 98,
  32, 45, 118, 32, 43, 10, 121, 99, 98, 99, 114, 50, 114, 103, 98, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101,
  114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114, 111, 109, 32,
  89, 67, 98, 67, 114, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111, 108,
  111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 32, 45, 115, 104, 32, 48, 44, 48, 32, 45, 45, 91, 45, 49, 93,
  32, 49, 54, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 115, 104, 32,
  49, 44, 50, 32, 45, 45, 91, 45, 49, 93, 32, 49, 50, 56, 32, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 45, 109, 105, 120, 95, 114, 103, 98, 32, 50, 57, 56, 44,
  48, 44, 52, 48, 57, 44, 50, 57, 56, 44, 45, 49, 48, 48, 44, 45,
  50, 48, 56, 44, 50, 57, 56, 44, 53, 49, 54, 44, 48, 32, 45, 43,
  32, 49, 50, 56, 32, 45, 47, 32, 50, 53, 54, 32, 45, 99, 32, 48,
  44, 50, 53, 53, 10, 45, 118, 32, 43, 10, 121, 117, 118, 50, 114, 103,
  98, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110,
  118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 102, 114, 111,
  109, 32, 89, 85, 86, 32, 116, 111, 32, 82, 71, 66, 32, 99, 111, 108,
  111, 114, 32, 98, 97, 115, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 109, 105, 120, 95, 114, 103, 98, 32, 49, 44, 48, 44, 49, 46, 49,
  51, 57, 56, 51, 44, 49, 44, 45, 48, 46, 51, 57, 52, 54, 53, 44,
  45, 48, 46, 53, 56, 48, 54, 44, 49, 44, 50, 46, 48, 51, 50, 49,
  49, 44, 48, 32, 45, 42, 32, 50, 53, 53, 32, 45, 118, 32, 43, 10,
  121, 117, 118, 56, 50, 114, 103, 98, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103,
  101, 36, 63, 32, 102, 114, 111, 109, 32, 89, 85, 86, 56, 32, 116, 111,
  32, 82, 71, 66, 32, 99, 111, 108, 111, 114, 32, 98, 97, 115, 101, 115,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 10, 45, 115, 104, 91, 36, 62, 93, 32, 48, 44, 48, 32, 45,
  47, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 115, 104, 91, 36, 62, 93, 32, 49, 44, 49, 32, 45, 47,
  91, 45, 49, 93, 32, 50, 56, 57, 46, 55, 55, 51, 32, 45, 45, 91,
  45, 49, 93, 32, 48, 46, 52, 52, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 115, 104, 91, 36, 62, 93, 32, 50, 44, 50, 32, 45, 47, 91,
  45, 49, 93, 32, 50, 48, 53, 46, 54, 52, 53, 32, 45, 45, 91, 45,
  49, 93, 32, 48, 46, 54, 50, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 100, 111, 110, 101, 32, 45, 121, 117, 118, 50, 114, 103, 98, 32, 45,
  118, 32, 43, 10, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110, 116,
  40, 36, 123, 49, 61, 48, 125, 41, 32, 38, 38, 32, 105, 115, 105, 110,
  116, 40, 36, 123, 50, 61, 48, 125, 41, 32, 38, 38, 32, 36, 123, 51,
  61, 48, 46, 53, 125, 62, 61, 48, 32, 38, 38, 32, 36, 51, 60, 61,
  49, 32, 38, 38, 32, 36, 123, 52, 61, 36, 51, 125, 62, 61, 48, 32,
  38, 38, 32, 36, 52, 60, 61, 49, 34, 10, 45, 105, 102, 32, 123, 33,
  64, 35, 125, 32, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 65, 112,
  112, 101, 110, 100, 32, 105, 109, 97, 103, 101, 36, 63, 32, 97, 115, 32,
  97, 32, 48, 120, 48, 45, 116, 105, 108, 101, 100, 32, 105, 109, 97, 103,
  101, 46, 34, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 33, 36, 49, 38, 38, 33, 36, 50,
  125, 10, 45, 118, 32, 45, 32, 78, 61, 123, 105, 110, 116, 40, 115, 113,
  114, 116, 40, 64, 35, 41, 41, 125, 32, 77, 61, 123, 114, 111, 117, 110,
  100, 40, 64, 35, 47, 36, 78, 44, 49, 44, 49, 41, 125, 10, 45, 118,
  32, 43, 32, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 65, 112, 112,
  101, 110, 100, 32, 105, 109, 97, 103, 101, 36, 63, 32, 97, 115, 32, 97,
  32, 34, 36, 123, 77, 125, 120, 36, 123, 78, 125, 34, 45, 116, 105, 108,
  101, 100, 32, 105, 109, 97, 103, 101, 32, 40, 97, 117, 116, 111, 45, 109,
  111, 100, 101, 41, 46, 34, 32, 45, 118, 32, 45, 10, 77, 78, 61, 123,
  36, 77, 42, 36, 78, 125, 32, 45, 105, 102, 32, 123, 64, 35, 37, 36,
  77, 78, 125, 32, 123, 36, 77, 78, 45, 40, 64, 35, 37, 36, 77, 78,
  41, 125, 32, 45, 115, 91, 45, 49, 93, 32, 120, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 108, 105, 102, 32, 123, 33, 36, 50, 125, 10, 45,
  118, 32, 45, 32, 77, 61, 36, 49, 32, 78, 61, 123, 114, 111, 117, 110,
  100, 40, 64, 35, 47, 36, 49, 44, 49, 44, 49, 41, 125, 10, 45, 118,
  32, 43, 32, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 65, 112, 112,
  101, 110, 100, 32, 105, 109, 97, 103, 101, 36, 63, 32, 97, 115, 32, 97,
  32, 34, 36, 123, 77, 125, 120, 36, 123, 78, 125, 34, 45, 116, 105, 108,
  101, 100, 32, 105, 109, 97, 103, 101, 46, 34, 32, 45, 118, 32, 45, 10,
  45, 105, 102, 32, 123, 36, 77, 62, 64, 35, 125, 32, 45, 118, 32, 43,
  32, 45, 119, 97, 114, 110, 91, 48, 45, 45, 51, 93, 32, 34, 77, 105,
  115, 115, 105, 110, 103, 32, 105, 109, 97, 103, 101, 115, 32, 102, 111, 114,
  32, 104, 97, 118, 105, 110, 103, 32, 111, 110, 101, 32, 114, 111, 119, 32,
  105, 110, 32, 97, 32, 34, 36, 123, 77, 125, 120, 36, 123, 78, 125, 34,
  45, 116, 105, 108, 101, 100, 32, 105, 109, 97, 103, 101, 46, 34, 32, 45,
  114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 64, 35, 37, 36, 77, 125, 32, 123, 36, 77, 45, 40, 64,
  35, 37, 36, 77, 41, 125, 32, 45, 115, 91, 45, 49, 93, 32, 120, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 105, 102, 32, 123, 33, 36,
  49, 125, 10, 45, 118, 32, 45, 32, 77, 61, 123, 114, 111, 117, 110, 100,
  40, 64, 35, 47, 36, 50, 44, 49, 44, 49, 41, 125, 32, 78, 61, 36,
  50, 10, 45, 118, 32, 43, 32, 45, 101, 91, 48, 45, 45, 51, 93, 32,
  34, 65, 112, 112, 101, 110, 100, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  97, 115, 32, 97, 32, 34, 36, 123, 77, 125, 120, 36, 123, 78, 125, 34,
  45, 116, 105, 108, 101, 100, 32, 105, 109, 97, 103, 101, 46, 34, 32, 45,
  118, 32, 45, 10, 45, 105, 102, 32, 123, 36, 78, 62, 64, 35, 125, 32,
  45, 118, 32, 43, 32, 45, 119, 97, 114, 110, 91, 48, 45, 45, 51, 93,
  32, 34, 77, 105, 115, 115, 105, 110, 103, 32, 105, 109, 97, 103, 101, 115,
  32, 102, 111, 114, 32, 104, 97, 118, 105, 110, 103, 32, 111, 110, 101, 32,
  99, 111, 108, 117, 109, 110, 32, 105, 110, 32, 97, 32, 34, 36, 123, 77,
  125, 120, 36, 123, 78, 125, 34, 45, 116, 105, 108, 101, 100, 32, 105, 109,
  97, 103, 101, 46, 34, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64, 35, 37, 36, 77, 125,
  32, 123, 36, 77, 45, 40, 64, 35, 37, 36, 77, 41, 125, 32, 45, 115,
  91, 45, 49, 93, 32, 120, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  108, 115, 101, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 65, 112,
  112, 101, 110, 100, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 97, 115,
  32, 36, 49, 120, 36, 50, 45, 116, 105, 108, 101, 100, 32, 105, 109, 97,
  103, 101, 115, 46, 34, 32, 45, 118, 32, 45, 10, 77, 61, 36, 49, 32,
  78, 61, 36, 50, 10, 45, 101, 110, 100, 105, 102, 10, 77, 78, 61, 123,
  36, 77, 42, 36, 78, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  105, 110, 116, 40, 64, 35, 47, 36, 77, 78, 41, 125, 32, 45, 108, 91,
  36, 62, 45, 123, 36, 62, 43, 36, 77, 78, 45, 49, 125, 93, 10, 36,
  77, 78, 44, 49, 44, 49, 44, 50, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 36, 77, 78, 32, 45, 112, 111, 105, 110, 116, 91, 45, 49, 93, 32,
  36, 62, 44, 48, 44, 48, 44, 49, 44, 64, 123, 36, 62, 44, 119, 125,
  44, 64, 123, 36, 62, 44, 104, 125, 32, 45, 100, 111, 110, 101, 32, 45,
  114, 91, 45, 49, 93, 32, 36, 77, 44, 36, 78, 44, 49, 44, 50, 44,
  45, 49, 10, 45, 115, 91, 45, 49, 93, 32, 99, 32, 45, 108, 91, 45,
  50, 93, 32, 45, 115, 32, 121, 32, 45, 109, 97, 120, 32, 45, 101, 110,
  100, 108, 32, 45, 108, 91, 45, 49, 93, 32, 45, 115, 32, 120, 32, 45,
  109, 97, 120, 32, 45, 101, 110, 100, 108, 10, 105, 61, 48, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 78, 32, 121, 61, 36, 62, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 77, 32, 45, 114, 91, 36, 105, 93, 32,
  64, 123, 45, 50, 44, 36, 62, 125, 44, 64, 123, 45, 49, 44, 36, 121,
  125, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48, 44, 48, 44,
  36, 51, 44, 36, 52, 32, 105, 61, 123, 36, 105, 43, 49, 125, 32, 45,
  100, 111, 110, 101, 32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 45,
  50, 44, 45, 49, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105,
  110, 116, 40, 64, 35, 47, 36, 77, 41, 125, 32, 45, 97, 91, 36, 62,
  45, 123, 36, 62, 43, 36, 77, 45, 49, 125, 93, 32, 120, 32, 45, 100,
  111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116,
  40, 64, 35, 47, 36, 78, 41, 125, 32, 45, 97, 91, 36, 62, 45, 123,
  36, 62, 43, 36, 78, 45, 49, 125, 93, 32, 121, 32, 45, 100, 111, 110,
  101, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 118,
  32, 43, 10, 97, 117, 116, 111, 99, 114, 111, 112, 95, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 49, 61, 48, 37, 125, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36,
  123, 50, 61, 48, 46, 49, 37, 125, 62, 61, 48, 32, 38, 38, 32, 105,
  115, 98, 111, 111, 108, 40, 36, 123, 51, 61, 48, 125, 41, 32, 38, 38,
  32, 105, 115, 105, 110, 116, 40, 36, 123, 52, 61, 49, 125, 41, 32, 38,
  38, 32, 36, 52, 62, 61, 48, 32, 38, 38, 32, 36, 52, 60, 61, 50,
  34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 117, 116, 111, 99,
  114, 111, 112, 32, 99, 111, 110, 110, 101, 99, 116, 101, 100, 32, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 115, 32, 102, 114, 111, 109, 32, 105, 109,
  97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 116, 104, 114, 101,
  115, 104, 111, 108, 100, 32, 36, 49, 44, 32, 109, 105, 110, 105, 109, 97,
  108, 32, 97, 114, 101, 97, 32, 36, 50, 44, 32, 34, 64, 123, 45, 97,
  114, 103, 92, 32, 49, 43, 36, 51, 44, 108, 111, 119, 44, 104, 105, 103,
  104, 125, 34, 32, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121,
  32, 34, 92, 10, 34, 97, 110, 100, 32, 111, 117, 116, 112, 117, 116, 32,
  116, 121, 112, 101, 32, 115, 101, 116, 32, 116, 111, 32, 39, 34, 64, 123,
  45, 97, 114, 103, 92, 32, 49, 43, 36, 52, 44, 99, 114, 111, 112, 44,
  115, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111, 110, 44, 99, 111, 111,
  114, 100, 105, 110, 97, 116, 101, 115, 125, 34, 39, 46, 92, 110, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 109, 105, 110, 95, 97, 114, 101, 97, 61,
  123, 109, 97, 120, 40, 49, 44, 114, 111, 117, 110, 100, 40, 105, 102, 40,
  64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36,
  50, 125, 44, 36, 50, 42, 119, 42, 104, 44, 36, 50, 41, 41, 41, 125,
  10, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 49, 48, 48, 37,
  32, 45, 103, 116, 91, 45, 49, 93, 32, 36, 49, 32, 45, 97, 114, 101,
  97, 95, 102, 103, 91, 45, 49, 93, 32, 48, 44, 36, 51, 32, 45, 103,
  101, 91, 45, 49, 93, 32, 36, 109, 105, 110, 95, 97, 114, 101, 97, 10,
  45, 45, 97, 114, 101, 97, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45,
  108, 116, 91, 45, 49, 93, 32, 36, 109, 105, 110, 95, 97, 114, 101, 97,
  32, 45, 111, 114, 91, 45, 50, 44, 45, 49, 93, 32, 45, 108, 97, 98,
  101, 108, 95, 102, 103, 91, 45, 49, 93, 32, 48, 44, 49, 10, 78, 61,
  123, 105, 77, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 77,
  125, 10, 110, 61, 123, 49, 43, 36, 62, 125, 10, 45, 118, 32, 43, 32,
  45, 101, 91, 93, 32, 34, 92, 114, 32, 32, 62, 32, 34, 36, 110, 47,
  36, 78, 32, 45, 118, 32, 45, 10, 45, 114, 112, 114, 111, 103, 114, 101,
  115, 115, 32, 123, 49, 48, 48, 42, 36, 110, 47, 36, 78, 125, 10, 45,
  45, 61, 61, 91, 49, 93, 32, 36, 110, 32, 45, 45, 42, 91, 48, 44,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 105, 102, 32,
  123, 36, 52, 61, 61, 48, 125, 32, 99, 111, 111, 114, 100, 115, 61, 64,
  123, 45, 97, 117, 116, 111, 99, 114, 111, 112, 95, 99, 111, 111, 114, 100,
  115, 91, 45, 49, 93, 92, 32, 97, 117, 116, 111, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 45, 122, 91, 48, 93, 32, 36, 99, 111, 111,
  114, 100, 115, 10, 45, 101, 108, 105, 102, 32, 123, 36, 52, 61, 61, 49,
  125, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 10,
  45, 101, 108, 115, 101, 32, 99, 111, 111, 114, 100, 115, 61, 64, 123, 45,
  97, 117, 116, 111, 99, 114, 111, 112, 95, 99, 111, 111, 114, 100, 115, 91,
  45, 49, 93, 92, 32, 97, 117, 116, 111, 125, 32, 45, 114, 109, 91, 45,
  49, 93, 32, 40, 36, 99, 111, 111, 114, 100, 115, 41, 32, 45, 121, 91,
  45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101,
  10, 45, 114, 109, 91, 48, 44, 49, 93, 10, 45, 105, 102, 32, 123, 36,
  52, 61, 61, 50, 125, 32, 45, 97, 32, 120, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 97, 117, 116, 111, 99, 114, 111, 112, 95, 115, 101, 113, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 97, 117, 116, 111,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 117, 116, 111, 45,
  99, 114, 111, 112, 32, 105, 109, 97, 103, 101, 36, 63, 32, 117, 115, 105,
  110, 103, 32, 99, 114, 111, 112, 32, 103, 101, 111, 109, 101, 116, 114, 121,
  32, 111, 102, 32, 108, 97, 115, 116, 32, 105, 109, 97, 103, 101, 32, 98,
  121, 32, 118, 101, 99, 116, 111, 114, 32, 39, 36, 42, 39, 46, 34, 10,
  45, 105, 102, 32, 123, 33, 64, 35, 125, 32, 45, 114, 101, 116, 117, 114,
  110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 10, 45, 105,
  102, 32, 123, 64, 35, 61, 61, 49, 125, 32, 45, 95, 97, 117, 116, 111,
  99, 114, 111, 112, 36, 105, 115, 95, 97, 117, 116, 111, 32, 36, 123, 49,
  45, 45, 49, 125, 32, 45, 118, 32, 43, 32, 45, 114, 101, 116, 117, 114,
  110, 32, 45, 101, 110, 100, 105, 102, 10, 99, 111, 111, 114, 100, 115, 61,
  64, 123, 45, 97, 117, 116, 111, 99, 114, 111, 112, 95, 99, 111, 111, 114,
  100, 115, 91, 45, 49, 93, 92, 32, 36, 123, 49, 45, 45, 49, 125, 125,
  10, 120, 48, 61, 123, 97, 114, 103, 40, 49, 44, 36, 99, 111, 111, 114,
  100, 115, 41, 125, 32, 121, 48, 61, 123, 97, 114, 103, 40, 50, 44, 36,
  99, 111, 111, 114, 100, 115, 41, 125, 32, 122, 48, 61, 123, 97, 114, 103,
  40, 51, 44, 36, 99, 111, 111, 114, 100, 115, 41, 125, 10, 120, 49, 61,
  123, 97, 114, 103, 40, 52, 44, 36, 99, 111, 111, 114, 100, 115, 41, 125,
  32, 121, 49, 61, 123, 97, 114, 103, 40, 53, 44, 36, 99, 111, 111, 114,
  100, 115, 41, 125, 32, 122, 49, 61, 123, 97, 114, 103, 40, 54, 44, 36,
  99, 111, 111, 114, 100, 115, 41, 125, 10, 45, 105, 102, 32, 123, 36, 120,
  48, 62, 36, 120, 49, 34, 32, 124, 124, 32, 34, 36, 121, 48, 62, 36,
  121, 49, 34, 32, 124, 124, 32, 34, 36, 122, 48, 62, 36, 122, 49, 125,
  32, 45, 105, 91, 48, 45, 45, 50, 93, 32, 48, 32, 45, 114, 109, 91,
  49, 45, 45, 49, 58, 50, 93, 10, 45, 101, 108, 115, 101, 32, 45, 99,
  114, 111, 112, 32, 36, 120, 48, 44, 36, 121, 48, 44, 36, 122, 48, 44,
  36, 120, 49, 44, 36, 121, 49, 44, 36, 122, 49, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 118, 32, 43, 10, 100, 105, 97, 103, 111, 110, 97, 108,
  32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 84, 114, 97, 110,
  115, 102, 111, 114, 109, 32, 118, 101, 99, 116, 111, 114, 36, 63, 32, 97,
  115, 32, 100, 105, 97, 103, 111, 110, 97, 108, 32, 109, 97, 116, 114, 105,
  120, 46, 34, 10, 45, 118, 32, 45, 32, 45, 121, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 114, 91, 36, 62, 93, 32, 64, 123,
  36, 62, 44, 104, 43, 49, 125, 44, 49, 48, 48, 37, 44, 49, 44, 49,
  44, 48, 32, 45, 114, 91, 36, 62, 93, 32, 64, 123, 36, 62, 44, 104,
  125, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 45, 49, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 101, 108, 101, 118, 97, 116, 101,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 54,
  52, 125, 62, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61,
  49, 125, 44, 36, 123, 51, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 69, 108, 101, 118, 97, 116, 101, 32, 50, 100, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 105, 110, 116, 111, 32, 36, 49, 45, 115, 108,
  105, 99, 101, 115, 32, 118, 111, 108, 117, 109, 101, 40, 115, 41, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 44, 49, 48, 48, 37, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64,
  123, 48, 44, 110, 125, 10, 45, 45, 110, 111, 114, 109, 32, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 36, 49, 44, 123, 105, 102, 40, 36, 51,
  44, 64, 123, 48, 44, 115, 125, 44, 49, 41, 125, 10, 109, 61, 64, 123,
  45, 50, 44, 109, 125, 32, 100, 61, 123, 64, 123, 45, 50, 44, 77, 125,
  45, 36, 109, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 10,
  45, 105, 102, 32, 36, 50, 32, 45, 45, 103, 101, 91, 49, 93, 32, 123,
  36, 109, 43, 36, 100, 42, 40, 36, 62, 43, 49, 41, 47, 36, 49, 125,
  10, 45, 101, 108, 115, 101, 32, 45, 45, 116, 50, 91, 49, 93, 32, 123,
  36, 109, 43, 36, 100, 42, 36, 62, 47, 36, 49, 125, 44, 123, 36, 109,
  43, 36, 100, 42, 40, 36, 62, 43, 49, 41, 47, 36, 49, 125, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 114, 91, 45, 49, 93, 32, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 49, 44, 91, 45, 50, 93, 32, 45, 105,
  102, 32, 36, 51, 32, 45, 42, 91, 45, 49, 93, 32, 91, 48, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 106, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 44, 48, 44, 48, 44, 36, 62, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 48, 44, 49, 93,
  32, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 101, 120, 112, 97,
  110, 100, 95, 120, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36,
  49, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 49, 125, 62, 61,
  48, 32, 38, 38, 32, 36, 50, 60, 61, 50, 34, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 69, 120, 112, 97, 110, 100, 32, 105, 109, 97, 103,
  101, 36, 63, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 120, 45,
  97, 120, 105, 115, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101, 32, 36,
  49, 32, 97, 110, 100, 32, 98, 111, 114, 100, 101, 114, 32, 99, 111, 110,
  100, 105, 116, 105, 111, 110, 115, 32, 36, 50, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 114, 91,
  36, 62, 93, 32, 64, 123, 36, 62, 44, 119, 43, 50, 42, 36, 49, 125,
  44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  48, 44, 36, 50, 44, 48, 46, 53, 44, 48, 46, 53, 44, 48, 46, 53,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 101, 120, 112, 97,
  110, 100, 95, 120, 121, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  36, 49, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 49, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 50, 60, 61, 50, 34, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 69, 120, 112, 97, 110, 100, 32, 105, 109, 97,
  103, 101, 36, 63, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 120,
  121, 45, 97, 120, 101, 115, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101,
  32, 36, 49, 32, 97, 110, 100, 32, 98, 111, 114, 100, 101, 114, 32, 99,
  111, 110, 100, 105, 116, 105, 111, 110, 115, 32, 36, 50, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  114, 91, 36, 62, 93, 32, 64, 123, 36, 62, 44, 119, 43, 50, 42, 36,
  49, 125, 44, 64, 123, 36, 62, 44, 104, 43, 50, 42, 36, 49, 125, 44,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48, 44, 36, 50, 44, 48,
  46, 53, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 101, 120, 112, 97, 110, 100, 95, 120, 121, 122,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48,
  32, 38, 38, 32, 36, 123, 50, 61, 49, 125, 62, 61, 48, 32, 38, 38,
  32, 36, 50, 60, 61, 50, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 69, 120, 112, 97, 110, 100, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 120, 121, 122, 45, 97, 120,
  101, 115, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101, 32, 36, 49, 32,
  97, 110, 100, 32, 98, 111, 114, 100, 101, 114, 32, 99, 111, 110, 100, 105,
  116, 105, 111, 110, 115, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 114, 91, 36, 62,
  93, 32, 64, 123, 36, 62, 44, 119, 43, 50, 42, 36, 49, 125, 44, 64,
  123, 36, 62, 44, 104, 43, 50, 42, 36, 49, 125, 44, 64, 123, 36, 62,
  44, 100, 43, 50, 42, 36, 49, 125, 44, 49, 48, 48, 37, 44, 48, 44,
  36, 50, 44, 48, 46, 53, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 101, 120, 112, 97, 110, 100,
  95, 121, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62,
  61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 49, 125, 62, 61, 48, 32,
  38, 38, 32, 36, 50, 60, 61, 50, 34, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 69, 120, 112, 97, 110, 100, 32, 105, 109, 97, 103, 101, 36,
  63, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 121, 45, 97, 120,
  105, 115, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101, 32, 36, 49, 32,
  97, 110, 100, 32, 98, 111, 114, 100, 101, 114, 32, 99, 111, 110, 100, 105,
  116, 105, 111, 110, 115, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 114, 91, 36, 62,
  93, 32, 49, 48, 48, 37, 44, 64, 123, 36, 62, 44, 104, 43, 50, 42,
  36, 49, 125, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48, 44,
  36, 50, 44, 48, 46, 53, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 101, 120, 112, 97, 110, 100,
  95, 122, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62,
  61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 49, 125, 62, 61, 48, 32,
  38, 38, 32, 36, 50, 60, 61, 50, 34, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 69, 120, 112, 97, 110, 100, 32, 105, 109, 97, 103, 101, 36,
  63, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 122, 45, 97, 120,
  105, 115, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101, 32, 36, 49, 32,
  97, 110, 100, 32, 98, 111, 114, 100, 101, 114, 32, 99, 111, 110, 100, 105,
  116, 105, 111, 110, 115, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 114, 91, 36, 62,
  93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 64, 123, 36, 62,
  44, 100, 43, 50, 42, 36, 49, 125, 44, 49, 48, 48, 37, 44, 48, 44,
  36, 50, 44, 48, 46, 53, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 114, 101, 115, 105, 122, 101,
  95, 112, 111, 119, 50, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 48, 125, 41, 32, 38, 38,
  32, 36, 49, 62, 61, 45, 49, 32, 38, 38, 32, 36, 49, 60, 61, 54,
  34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 48, 125, 44, 36,
  123, 51, 61, 48, 125, 44, 36, 123, 52, 61, 48, 125, 44, 36, 123, 53,
  61, 48, 125, 44, 36, 123, 54, 61, 48, 125, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 82, 101, 115, 105, 122, 101, 32, 105, 109, 97, 103, 101,
  36, 63, 32, 115, 111, 32, 116, 104, 97, 116, 32, 101, 97, 99, 104, 32,
  100, 105, 109, 101, 110, 115, 105, 111, 110, 32, 105, 115, 32, 97, 32, 112,
  111, 119, 101, 114, 32, 111, 102, 32, 50, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 114, 91, 36,
  62, 93, 32, 64, 123, 36, 62, 44, 50, 94, 40, 114, 111, 117, 110, 100,
  40, 108, 111, 103, 50, 40, 119, 41, 44, 49, 44, 49, 41, 41, 125, 44,
  64, 123, 36, 62, 44, 50, 94, 40, 114, 111, 117, 110, 100, 40, 108, 111,
  103, 50, 40, 104, 41, 44, 49, 44, 49, 41, 41, 125, 44, 64, 123, 36,
  62, 44, 50, 94, 40, 114, 111, 117, 110, 100, 40, 108, 111, 103, 50, 40,
  100, 41, 44, 49, 44, 49, 41, 41, 125, 44, 49, 48, 48, 37, 44, 36,
  123, 49, 45, 54, 125, 10, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 114, 114, 50, 100, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115,
  61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 114, 101, 115,
  105, 122, 101, 95, 114, 97, 116, 105, 111, 50, 100, 32, 36, 42, 10, 114,
  101, 115, 105, 122, 101, 95, 114, 97, 116, 105, 111, 50, 100, 32, 58, 10,
  45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118,
  32, 43, 10, 45, 95, 36, 48, 32, 36, 42, 10, 95, 114, 101, 115, 105,
  122, 101, 95, 114, 97, 116, 105, 111, 50, 100, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 36, 49, 62, 48, 32, 38, 38, 32, 36, 50, 62,
  48, 32, 38, 38, 32, 36, 123, 51, 61, 48, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 51, 60, 61, 50, 32, 38, 38, 32, 36, 123, 52, 61, 54,
  125, 62, 61, 48, 32, 38, 38, 32, 36, 52, 60, 61, 54, 34, 10, 45,
  101, 91, 48, 45, 45, 51, 93, 32, 34, 82, 101, 115, 105, 122, 101, 32,
  50, 100, 32, 105, 109, 97, 103, 101, 34, 36, 95, 95, 115, 34, 32, 116,
  111, 32, 36, 49, 120, 36, 50, 32, 119, 105, 116, 104, 32, 114, 97, 116,
  105, 111, 45, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 36, 51,
  44, 105, 110, 115, 105, 100, 101, 44, 111, 117, 116, 115, 105, 100, 101, 44,
  112, 97, 100, 100, 101, 100, 125, 92, 10, 34, 32, 109, 111, 100, 101, 32,
  97, 110, 100, 32, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111,
  110, 32, 116, 121, 112, 101, 32, 36, 52, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 114, 97, 116, 105,
  111, 61, 64, 123, 36, 62, 44, 105, 102, 40, 36, 51, 61, 61, 49, 44,
  109, 97, 120, 40, 36, 49, 47, 119, 44, 36, 50, 47, 104, 41, 44, 109,
  105, 110, 40, 36, 49, 47, 119, 44, 36, 50, 47, 104, 41, 41, 125, 10,
  45, 114, 91, 36, 62, 93, 32, 64, 123, 36, 62, 44, 119, 42, 36, 114,
  97, 116, 105, 111, 125, 44, 64, 123, 36, 62, 44, 104, 42, 36, 114, 97,
  116, 105, 111, 125, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 36,
  52, 10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 51, 61,
  61, 50, 125, 32, 45, 114, 32, 36, 49, 44, 36, 50, 44, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48,
  46, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 114,
  50, 100, 120, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34,
  36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 114, 101, 115, 105, 122,
  101, 50, 100, 120, 32, 36, 42, 10, 114, 101, 115, 105, 122, 101, 50, 100,
  120, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63,
  34, 32, 45, 118, 32, 43, 10, 45, 95, 36, 48, 32, 36, 42, 10, 95,
  114, 101, 115, 105, 122, 101, 50, 100, 120, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 36, 49, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61,
  51, 125, 62, 61, 48, 32, 38, 38, 32, 36, 50, 60, 61, 54, 32, 38,
  38, 32, 36, 123, 51, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36,
  51, 60, 61, 50, 32, 38, 38, 32, 36, 123, 52, 61, 48, 125, 62, 61,
  48, 32, 38, 38, 32, 36, 52, 60, 61, 49, 32, 38, 38, 32, 36, 123,
  53, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 53, 60, 61, 49,
  32, 38, 38, 32, 36, 123, 54, 61, 48, 125, 62, 61, 48, 32, 38, 38,
  32, 36, 54, 60, 61, 49, 32, 38, 38, 32, 36, 123, 55, 61, 48, 125,
  62, 61, 48, 32, 38, 38, 32, 36, 55, 60, 61, 49, 34, 10, 45, 101,
  91, 48, 45, 45, 51, 93, 32, 34, 82, 101, 115, 105, 122, 101, 32, 50,
  100, 32, 105, 109, 97, 103, 101, 34, 36, 95, 95, 115, 34, 32, 116, 111,
  32, 36, 49, 32, 112, 105, 120, 101, 108, 115, 32, 97, 108, 111, 110, 103,
  32, 116, 104, 101, 32, 120, 45, 97, 120, 105, 115, 44, 32, 112, 114, 101,
  115, 101, 114, 118, 105, 110, 103, 32, 50, 100, 32, 114, 97, 116, 105, 111,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 115, 105, 122, 101, 61, 123,
  105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116,
  92, 32, 36, 49, 125, 44, 36, 49, 42, 119, 44, 36, 49, 41, 125, 10,
  45, 114, 32, 123, 109, 97, 120, 40, 49, 44, 36, 115, 105, 122, 101, 41,
  125, 44, 123, 109, 97, 120, 40, 49, 44, 104, 42, 36, 115, 105, 122, 101,
  47, 119, 41, 125, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 36,
  123, 50, 45, 55, 125, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 114, 50, 100, 121, 32, 58, 10, 45, 118,
  32, 45, 32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43,
  10, 45, 95, 114, 101, 115, 105, 122, 101, 50, 100, 121, 32, 36, 42, 10,
  114, 101, 115, 105, 122, 101, 50, 100, 121, 32, 58, 10, 45, 118, 32, 45,
  32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45,
  95, 36, 48, 32, 36, 42, 10, 95, 114, 101, 115, 105, 122, 101, 50, 100,
  121, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61,
  48, 32, 38, 38, 32, 36, 123, 50, 61, 51, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 50, 60, 61, 54, 32, 38, 38, 32, 36, 123, 51, 61, 48,
  125, 62, 61, 48, 32, 38, 38, 32, 36, 51, 60, 61, 50, 32, 38, 38,
  32, 36, 123, 52, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 52,
  60, 61, 49, 32, 38, 38, 32, 36, 123, 53, 61, 48, 125, 62, 61, 48,
  32, 38, 38, 32, 36, 53, 60, 61, 49, 32, 38, 38, 32, 36, 123, 54,
  61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 54, 60, 61, 49, 32,
  38, 38, 32, 36, 123, 55, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32,
  36, 55, 60, 61, 49, 34, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32,
  34, 82, 101, 115, 105, 122, 101, 32, 50, 100, 32, 105, 109, 97, 103, 101,
  34, 36, 95, 95, 115, 34, 32, 116, 111, 32, 36, 49, 32, 112, 105, 120,
  101, 108, 115, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 121, 45,
  97, 120, 105, 115, 44, 32, 112, 114, 101, 115, 101, 114, 118, 105, 110, 103,
  32, 50, 100, 32, 114, 97, 116, 105, 111, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 115, 105, 122, 101, 61, 123, 105, 102, 40, 64, 123, 45, 105,
  115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 49, 125, 44, 36,
  49, 42, 104, 44, 36, 49, 41, 125, 10, 45, 114, 32, 123, 109, 97, 120,
  40, 49, 44, 119, 42, 36, 115, 105, 122, 101, 47, 104, 41, 125, 44, 123,
  109, 97, 120, 40, 49, 44, 36, 115, 105, 122, 101, 41, 125, 44, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 36, 123, 50, 45, 55, 125, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  114, 51, 100, 120, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61,
  34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 114, 101, 115, 105,
  122, 101, 51, 100, 120, 32, 36, 42, 10, 114, 101, 115, 105, 122, 101, 51,
  100, 120, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36,
  63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 36, 48, 32, 36, 42, 10,
  95, 114, 101, 115, 105, 122, 101, 51, 100, 120, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 36, 49, 62, 48, 32, 38, 38, 32, 36, 123, 50,
  61, 51, 125, 62, 61, 48, 32, 38, 38, 32, 36, 50, 60, 61, 54, 32,
  38, 38, 32, 36, 123, 51, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32,
  36, 51, 60, 61, 50, 32, 38, 38, 32, 36, 123, 52, 61, 48, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 52, 60, 61, 49, 32, 38, 38, 32, 36,
  123, 53, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 53, 60, 61,
  49, 32, 38, 38, 32, 36, 123, 54, 61, 48, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 54, 60, 61, 49, 32, 38, 38, 32, 36, 123, 55, 61, 48,
  125, 62, 61, 48, 32, 38, 38, 32, 36, 55, 60, 61, 49, 34, 10, 45,
  101, 91, 48, 45, 45, 51, 93, 32, 34, 82, 101, 115, 105, 122, 101, 32,
  51, 100, 32, 105, 109, 97, 103, 101, 34, 36, 95, 95, 115, 34, 32, 116,
  111, 32, 36, 49, 32, 112, 105, 120, 101, 108, 115, 32, 97, 108, 111, 110,
  103, 32, 116, 104, 101, 32, 120, 45, 97, 120, 105, 115, 44, 32, 112, 114,
  101, 115, 101, 114, 118, 105, 110, 103, 32, 51, 100, 32, 114, 97, 116, 105,
  111, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 115, 105, 122, 101, 61,
  123, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110,
  116, 92, 32, 36, 49, 125, 44, 36, 49, 42, 119, 44, 36, 49, 41, 125,
  10, 45, 114, 32, 123, 109, 97, 120, 40, 49, 44, 36, 115, 105, 122, 101,
  41, 125, 44, 123, 109, 97, 120, 40, 49, 44, 104, 42, 36, 115, 105, 122,
  101, 47, 119, 41, 125, 44, 123, 109, 97, 120, 40, 49, 44, 100, 42, 36,
  115, 105, 122, 101, 47, 119, 41, 125, 44, 49, 48, 48, 37, 44, 36, 123,
  50, 45, 55, 125, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 114, 51, 100, 121, 32, 58, 10, 45, 118, 32,
  45, 32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10,
  45, 95, 114, 101, 115, 105, 122, 101, 51, 100, 121, 32, 36, 42, 10, 114,
  101, 115, 105, 122, 101, 51, 100, 121, 32, 58, 10, 45, 118, 32, 45, 32,
  95, 95, 115, 61, 34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95,
  36, 48, 32, 36, 42, 10, 95, 114, 101, 115, 105, 122, 101, 51, 100, 121,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 48, 32,
  38, 38, 32, 36, 123, 50, 61, 51, 125, 62, 61, 48, 32, 38, 38, 32,
  36, 50, 60, 61, 54, 32, 38, 38, 32, 36, 123, 51, 61, 48, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 51, 60, 61, 50, 32, 38, 38, 32, 36,
  123, 52, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 52, 60, 61,
  49, 32, 38, 38, 32, 36, 123, 53, 61, 48, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 53, 60, 61, 49, 32, 38, 38, 32, 36, 123, 54, 61, 48,
  125, 62, 61, 48, 32, 38, 38, 32, 36, 54, 60, 61, 49, 32, 38, 38,
  32, 36, 123, 55, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 55,
  60, 61, 49, 34, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 82,
  101, 115, 105, 122, 101, 32, 51, 100, 32, 105, 109, 97, 103, 101, 34, 36,
  95, 95, 115, 34, 32, 116, 111, 32, 36, 49, 32, 112, 105, 120, 101, 108,
  115, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 121, 45, 97, 120,
  105, 115, 44, 32, 112, 114, 101, 115, 101, 114, 118, 105, 110, 103, 32, 51,
  100, 32, 114, 97, 116, 105, 111, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 115, 105, 122, 101, 61, 123, 105, 102, 40, 64, 123, 45, 105, 115, 95,
  112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 49, 125, 44, 36, 49, 42,
  104, 44, 36, 49, 41, 125, 10, 45, 114, 32, 123, 109, 97, 120, 40, 49,
  44, 119, 42, 36, 115, 105, 122, 101, 47, 104, 41, 125, 44, 123, 109, 97,
  120, 40, 49, 44, 36, 115, 105, 122, 101, 41, 125, 44, 123, 109, 97, 120,
  40, 49, 44, 100, 42, 36, 115, 105, 122, 101, 47, 104, 41, 125, 44, 49,
  48, 48, 37, 44, 36, 123, 50, 45, 55, 125, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 114, 51, 100, 122,
  32, 58, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63, 34,
  32, 45, 118, 32, 43, 10, 45, 95, 114, 101, 115, 105, 122, 101, 51, 100,
  122, 32, 36, 42, 10, 114, 101, 115, 105, 122, 101, 51, 100, 122, 32, 58,
  10, 45, 118, 32, 45, 32, 95, 95, 115, 61, 34, 36, 63, 34, 32, 45,
  118, 32, 43, 10, 45, 95, 36, 48, 32, 36, 42, 10, 95, 114, 101, 115,
  105, 122, 101, 51, 100, 122, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 36, 49, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 51, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 50, 60, 61, 54, 32, 38, 38, 32, 36,
  123, 51, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 51, 60, 61,
  50, 32, 38, 38, 32, 36, 123, 52, 61, 48, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 52, 60, 61, 49, 32, 38, 38, 32, 36, 123, 53, 61, 48,
  125, 62, 61, 48, 32, 38, 38, 32, 36, 53, 60, 61, 49, 32, 38, 38,
  32, 36, 123, 54, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 54,
  60, 61, 49, 32, 38, 38, 32, 36, 123, 55, 61, 48, 125, 62, 61, 48,
  32, 38, 38, 32, 36, 55, 60, 61, 49, 34, 10, 45, 101, 91, 48, 45,
  45, 51, 93, 32, 34, 82, 101, 115, 105, 122, 101, 32, 51, 100, 32, 105,
  109, 97, 103, 101, 34, 36, 95, 95, 115, 34, 32, 116, 111, 32, 36, 49,
  32, 112, 105, 120, 101, 108, 115, 32, 97, 108, 111, 110, 103, 32, 116, 104,
  101, 32, 122, 45, 97, 120, 105, 115, 44, 32, 112, 114, 101, 115, 101, 114,
  118, 105, 110, 103, 32, 51, 100, 32, 114, 97, 116, 105, 111, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 115, 105, 122, 101, 61, 123, 105, 102, 40,
  64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36,
  49, 125, 44, 36, 49, 42, 100, 44, 36, 49, 41, 125, 10, 45, 114, 91,
  36, 62, 93, 32, 123, 109, 97, 120, 40, 49, 44, 119, 42, 36, 115, 105,
  122, 101, 47, 100, 41, 125, 44, 123, 109, 97, 120, 40, 49, 44, 104, 42,
  36, 115, 105, 122, 101, 47, 100, 41, 125, 44, 123, 109, 97, 120, 40, 49,
  44, 36, 115, 105, 122, 101, 41, 125, 44, 49, 48, 48, 37, 44, 36, 123,
  50, 45, 55, 125, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 114, 111, 116, 97, 116, 101, 95, 116, 105, 108,
  101, 97, 98, 108, 101, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36,
  123, 50, 61, 56, 125, 62, 61, 48, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 82, 111, 116, 97, 116, 101, 32, 105, 109, 97, 103, 101, 36, 63,
  32, 119, 105, 116, 104, 32, 97, 110, 103, 108, 101, 32, 36, 49, 32, 100,
  101, 103, 46, 32, 97, 110, 100, 32, 109, 97, 107, 101, 32, 116, 104, 101,
  109, 32, 116, 105, 108, 101, 97, 98, 108, 101, 46, 34, 10, 45, 118, 32,
  45, 10, 97, 110, 103, 108, 101, 61, 123, 36, 49, 37, 51, 54, 48, 125,
  10, 45, 105, 102, 32, 123, 36, 97, 110, 103, 108, 101, 62, 61, 50, 55,
  48, 125, 32, 45, 114, 111, 116, 97, 116, 101, 32, 50, 55, 48, 32, 97,
  110, 103, 108, 101, 61, 123, 36, 97, 110, 103, 108, 101, 45, 50, 55, 48,
  125, 10, 45, 101, 108, 105, 102, 32, 123, 36, 97, 110, 103, 108, 101, 62,
  61, 49, 56, 48, 125, 32, 45, 114, 111, 116, 97, 116, 101, 32, 49, 56,
  48, 32, 97, 110, 103, 108, 101, 61, 123, 36, 97, 110, 103, 108, 101, 45,
  49, 56, 48, 125, 10, 45, 101, 108, 105, 102, 32, 123, 36, 97, 110, 103,
  108, 101, 62, 61, 57, 48, 125, 32, 45, 114, 111, 116, 97, 116, 101, 32,
  57, 48, 32, 97, 110, 103, 108, 101, 61, 123, 36, 97, 110, 103, 108, 101,
  45, 57, 48, 125, 10, 45, 101, 110, 100, 105, 102, 10, 40, 48, 44, 49,
  59, 49, 44, 56, 59, 49, 44, 55, 59, 49, 44, 54, 59, 49, 44, 53,
  59, 49, 44, 52, 59, 49, 44, 53, 59, 49, 44, 51, 59, 50, 44, 53,
  59, 49, 44, 50, 59, 50, 44, 53, 59, 51, 44, 53, 59, 50, 44, 51,
  59, 51, 44, 52, 59, 52, 44, 53, 59, 49, 44, 49, 59, 53, 44, 52,
  59, 55, 44, 53, 59, 51, 44, 50, 59, 56, 44, 53, 59, 57, 44, 53,
  59, 50, 44, 49, 59, 51, 44, 49, 59, 52, 44, 49, 59, 53, 44, 49,
  59, 54, 44, 49, 59, 55, 44, 49, 59, 56, 44, 49, 41, 10, 45, 115,
  91, 45, 49, 93, 32, 120, 44, 50, 32, 45, 45, 47, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 97, 116, 97, 110, 91, 45, 49, 93, 32, 45, 42,
  91, 45, 49, 93, 32, 123, 49, 56, 48, 47, 112, 105, 125, 10, 40, 36,
  97, 110, 103, 108, 101, 41, 32, 45, 105, 110, 100, 101, 120, 91, 45, 49,
  93, 32, 91, 45, 50, 93, 32, 45, 114, 109, 91, 45, 50, 93, 10, 112,
  61, 64, 123, 45, 51, 44, 64, 45, 49, 125, 32, 113, 61, 64, 123, 45,
  50, 44, 64, 45, 49, 125, 32, 45, 114, 109, 91, 45, 51, 45, 45, 49,
  93, 10, 45, 105, 102, 32, 123, 33, 36, 112, 124, 124, 33, 36, 113, 125,
  32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 116, 104, 101, 116, 97, 61, 123, 97, 116, 97, 110, 50, 40, 36,
  112, 44, 36, 113, 41, 125, 10, 103, 99, 100, 61, 64, 123, 45, 103, 99,
  100, 34, 32, 34, 123, 104, 42, 36, 113, 125, 44, 123, 119, 42, 36, 112,
  125, 125, 10, 112, 119, 61, 123, 104, 42, 36, 113, 47, 36, 103, 99, 100,
  125, 10, 110, 119, 61, 123, 114, 111, 117, 110, 100, 40, 36, 112, 119, 42,
  119, 47, 99, 111, 115, 40, 36, 116, 104, 101, 116, 97, 41, 41, 125, 10,
  103, 99, 100, 61, 64, 123, 45, 103, 99, 100, 34, 32, 34, 123, 104, 42,
  36, 112, 125, 44, 123, 119, 42, 36, 113, 125, 125, 10, 113, 104, 61, 123,
  119, 42, 36, 113, 47, 36, 103, 99, 100, 125, 10, 110, 104, 61, 123, 114,
  111, 117, 110, 100, 40, 36, 113, 104, 42, 104, 47, 99, 111, 115, 40, 36,
  116, 104, 101, 116, 97, 41, 41, 125, 10, 45, 105, 102, 32, 123, 33, 36,
  50, 34, 32, 124, 124, 32, 34, 40, 36, 110, 119, 60, 36, 50, 42, 119,
  34, 32, 38, 38, 32, 34, 36, 110, 104, 60, 36, 50, 42, 104, 41, 125,
  10, 45, 114, 32, 123, 49, 46, 53, 42, 36, 110, 119, 125, 44, 123, 49,
  46, 53, 42, 36, 110, 104, 125, 44, 49, 44, 49, 48, 48, 37, 44, 48,
  44, 50, 10, 45, 114, 111, 116, 97, 116, 101, 32, 123, 36, 116, 104, 101,
  116, 97, 42, 49, 56, 48, 47, 112, 105, 125, 44, 49, 44, 50, 44, 53,
  48, 37, 44, 53, 48, 37, 10, 45, 114, 32, 36, 110, 119, 44, 36, 110,
  104, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44, 50, 44, 48, 46, 53,
  44, 48, 46, 53, 10, 45, 101, 108, 115, 101, 32, 45, 114, 109, 32, 49,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 115, 99, 97, 108, 101, 50, 120,
  32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 111, 117, 98,
  108, 101, 32, 120, 121, 45, 100, 105, 109, 101, 110, 115, 105, 111, 110, 115,
  32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 117, 115, 105,
  110, 103, 32, 83, 99, 97, 108, 101, 50, 120, 32, 97, 108, 103, 111, 114,
  105, 116, 104, 109, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 114,
  32, 50, 48, 48, 37, 44, 50, 48, 48, 37, 10, 45, 102, 32, 34, 100,
  120, 61, 120, 38, 49, 59, 100, 121, 61, 121, 38, 49, 59, 65, 61, 106,
  40, 48, 44, 45, 50, 44, 48, 44, 48, 44, 48, 44, 49, 41, 59, 66,
  61, 106, 40, 50, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 41, 59,
  67, 61, 106, 40, 45, 50, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49,
  41, 59, 68, 61, 106, 40, 48, 44, 50, 44, 48, 44, 48, 44, 48, 44,
  49, 41, 59, 34, 92, 10, 34, 33, 100, 121, 42, 40, 33, 100, 120, 42,
  105, 102, 40, 67, 61, 61, 65, 38, 38, 67, 33, 61, 68, 38, 38, 65,
  33, 61, 66, 44, 65, 44, 105, 41, 32, 43, 32, 100, 120, 42, 105, 102,
  40, 65, 61, 61, 66, 38, 38, 65, 33, 61, 67, 38, 38, 66, 33, 61,
  68, 44, 66, 44, 105, 41, 41, 32, 43, 32, 100, 121, 42, 40, 100, 120,
  42, 105, 102, 40, 66, 61, 61, 68, 38, 38, 66, 33, 61, 65, 38, 38,
  68, 33, 61, 67, 44, 68, 44, 105, 41, 32, 43, 32, 33, 100, 120, 42,
  105, 102, 40, 68, 61, 61, 67, 38, 38, 68, 33, 61, 66, 38, 38, 67,
  33, 61, 65, 44, 67, 44, 105, 41, 41, 34, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 115, 99, 97, 108,
  101, 51, 120, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 84,
  114, 105, 112, 108, 101, 32, 120, 121, 45, 100, 105, 109, 101, 110, 115, 105,
  111, 110, 115, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32,
  117, 115, 105, 110, 103, 32, 83, 99, 97, 108, 101, 51, 120, 32, 97, 108,
  103, 111, 114, 105, 116, 104, 109, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 114, 32, 51, 48, 48, 37, 44, 51, 48, 48, 37, 10, 45, 102,
  32, 34, 100, 120, 61, 120, 37, 51, 59, 100, 121, 61, 121, 37, 51, 59,
  99, 48, 61, 33, 100, 120, 59, 99, 49, 61, 40, 100, 120, 61, 61, 49,
  41, 59, 99, 50, 61, 40, 100, 120, 61, 61, 50, 41, 59, 34, 92, 10,
  34, 65, 61, 106, 40, 45, 51, 44, 45, 51, 44, 48, 44, 48, 44, 48,
  44, 49, 41, 59, 66, 61, 106, 40, 48, 44, 45, 51, 44, 48, 44, 48,
  44, 48, 44, 49, 41, 59, 67, 61, 106, 40, 51, 44, 45, 51, 44, 48,
  44, 48, 44, 48, 44, 49, 41, 59, 34, 92, 10, 34, 68, 61, 106, 40,
  45, 51, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 41, 59, 70, 61,
  106, 40, 51, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 41, 59, 34,
  92, 10, 34, 71, 61, 106, 40, 45, 51, 44, 51, 44, 48, 44, 48, 44,
  48, 44, 49, 41, 59, 72, 61, 106, 40, 48, 44, 51, 44, 48, 44, 48,
  44, 48, 44, 49, 41, 59, 73, 61, 106, 40, 51, 44, 51, 44, 48, 44,
  48, 44, 48, 44, 49, 41, 59, 34, 92, 10, 34, 33, 100, 121, 42, 40,
  99, 48, 42, 105, 102, 40, 68, 61, 61, 66, 38, 38, 68, 33, 61, 72,
  38, 38, 66, 33, 61, 70, 44, 68, 44, 105, 41, 32, 43, 32, 99, 49,
  42, 105, 102, 40, 40, 68, 61, 61, 66, 38, 38, 68, 33, 61, 72, 38,
  38, 66, 33, 61, 70, 38, 38, 105, 33, 61, 67, 41, 124, 124, 40, 66,
  61, 61, 70, 38, 38, 66, 33, 61, 68, 38, 38, 70, 33, 61, 72, 38,
  38, 105, 33, 61, 65, 41, 44, 66, 44, 105, 41, 32, 43, 32, 99, 50,
  42, 105, 102, 40, 66, 61, 61, 70, 38, 38, 66, 33, 61, 68, 38, 38,
  70, 33, 61, 72, 44, 70, 44, 105, 41, 41, 32, 43, 32, 34, 92, 10,
  34, 40, 100, 121, 61, 61, 49, 41, 42, 40, 99, 48, 42, 105, 102, 40,
  40, 72, 61, 61, 68, 38, 38, 72, 33, 61, 70, 38, 38, 68, 33, 61,
  66, 38, 38, 105, 33, 61, 65, 41, 124, 124, 40, 68, 61, 61, 66, 38,
  38, 68, 33, 61, 72, 38, 38, 66, 33, 61, 70, 38, 38, 105, 33, 61,
  71, 41, 44, 68, 44, 105, 41, 32, 43, 32, 99, 49, 42, 105, 32, 43,
  32, 99, 50, 42, 105, 102, 40, 40, 66, 61, 61, 70, 38, 38, 66, 33,
  61, 68, 38, 38, 70, 33, 61, 72, 38, 38, 105, 33, 61, 73, 41, 124,
  124, 40, 70, 61, 61, 72, 38, 38, 70, 33, 61, 66, 38, 38, 72, 33,
  61, 68, 38, 38, 105, 33, 61, 67, 41, 44, 70, 44, 105, 41, 41, 32,
  43, 32, 34, 92, 10, 34, 40, 100, 121, 61, 61, 50, 41, 42, 40, 99,
  48, 42, 105, 102, 40, 72, 61, 61, 68, 38, 38, 72, 33, 61, 70, 38,
  38, 68, 33, 61, 66, 44, 68, 44, 105, 41, 32, 43, 32, 99, 49, 42,
  105, 102, 40, 40, 70, 61, 61, 72, 38, 38, 70, 33, 61, 66, 38, 38,
  72, 33, 61, 68, 38, 38, 105, 33, 61, 71, 41, 124, 124, 40, 72, 61,
  61, 68, 38, 38, 72, 33, 61, 70, 38, 38, 68, 33, 61, 66, 38, 38,
  105, 33, 61, 73, 41, 44, 72, 44, 105, 41, 32, 43, 32, 99, 50, 42,
  105, 102, 40, 70, 61, 61, 72, 38, 38, 70, 33, 61, 66, 38, 38, 72,
  33, 61, 68, 44, 70, 44, 105, 41, 41, 34, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 115, 104, 114, 105,
  110, 107, 95, 120, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36,
  49, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 83,
  104, 114, 105, 110, 107, 32, 105, 109, 97, 103, 101, 36, 63, 32, 97, 108,
  111, 110, 103, 32, 116, 104, 101, 32, 120, 45, 97, 120, 105, 115, 32, 119,
  105, 116, 104, 32, 115, 105, 122, 101, 32, 36, 49, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 122,
  91, 36, 62, 93, 32, 36, 49, 44, 64, 123, 36, 62, 44, 119, 45, 36,
  49, 45, 49, 125, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  115, 104, 114, 105, 110, 107, 95, 120, 121, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 36, 49, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 83, 104, 114, 105, 110, 107, 32, 105, 109, 97, 103, 101,
  36, 63, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 120, 121, 45,
  97, 120, 101, 115, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101, 32, 36,
  49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 122, 91, 36, 62, 93, 32, 36, 49, 44, 36, 49,
  44, 64, 123, 36, 62, 44, 119, 45, 36, 49, 45, 49, 125, 44, 64, 123,
  36, 62, 44, 104, 45, 36, 49, 45, 49, 125, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 115, 104, 114, 105, 110, 107, 95, 120, 121, 122,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48,
  34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 83, 104, 114, 105, 110,
  107, 32, 105, 109, 97, 103, 101, 36, 63, 32, 97, 108, 111, 110, 103, 32,
  116, 104, 101, 32, 120, 121, 122, 45, 97, 120, 101, 115, 32, 119, 105, 116,
  104, 32, 115, 105, 122, 101, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 122, 91, 36,
  62, 93, 32, 36, 49, 44, 36, 49, 44, 36, 49, 44, 64, 123, 36, 62,
  44, 119, 45, 36, 49, 45, 49, 125, 44, 64, 123, 36, 62, 44, 104, 45,
  36, 49, 45, 49, 125, 44, 64, 123, 36, 62, 44, 100, 45, 36, 49, 45,
  49, 125, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 115, 104,
  114, 105, 110, 107, 95, 121, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 36, 49, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 83, 104, 114, 105, 110, 107, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 121, 45, 97, 120, 105, 115,
  32, 119, 105, 116, 104, 32, 115, 105, 122, 101, 32, 36, 49, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 122, 91, 36, 62, 93, 32, 48, 44, 36, 49, 44, 49, 48, 48, 37,
  44, 64, 123, 36, 62, 44, 104, 45, 36, 49, 45, 49, 125, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 115, 104, 114, 105, 110, 107, 95,
  122, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61,
  48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 83, 104, 114, 105,
  110, 107, 32, 105, 109, 97, 103, 101, 36, 63, 32, 97, 108, 111, 110, 103,
  32, 116, 104, 101, 32, 122, 45, 97, 120, 105, 115, 32, 119, 105, 116, 104,
  32, 115, 105, 122, 101, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 122, 91, 36, 62,
  93, 32, 48, 44, 48, 44, 36, 49, 44, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 64, 123, 36, 62, 44, 100, 45, 36, 49, 45, 49, 125, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 115, 112, 108, 105, 116,
  95, 116, 105, 108, 101, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 50, 61, 36, 49, 125, 44, 36, 123, 51, 61, 48, 125, 10, 45, 105,
  102, 32, 36, 51, 32, 45, 101, 91, 94, 45, 49, 93, 32, 34, 83, 112,
  108, 105, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32, 97, 115, 32, 97,
  32, 36, 49, 120, 36, 50, 32, 97, 114, 114, 97, 121, 32, 111, 102, 32,
  104, 111, 109, 111, 103, 101, 110, 101, 111, 117, 115, 32, 116, 105, 108, 101,
  115, 46, 34, 10, 45, 101, 108, 115, 101, 32, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 83, 112, 108, 105, 116, 32, 105, 109, 97, 103, 101, 36, 63,
  32, 97, 115, 32, 97, 32, 36, 49, 120, 36, 50, 32, 97, 114, 114, 97,
  121, 32, 111, 102, 32, 116, 105, 108, 101, 115, 46, 34, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 60, 93, 32, 45, 115, 32, 121, 44,
  36, 50, 32, 45, 115, 32, 120, 44, 36, 49, 32, 45, 105, 102, 32, 36,
  51, 32, 45, 114, 32, 91, 48, 93, 44, 91, 48, 93, 44, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 48, 32, 45, 101, 110, 100, 105, 102, 32,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 117, 112, 115, 99, 97, 108, 101, 95, 115, 109, 97, 114, 116, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 49, 48, 48, 37, 125,
  44, 36, 123, 51, 61, 49, 48, 48, 37, 125, 32, 45, 99, 104, 101, 99,
  107, 32, 34, 36, 123, 52, 61, 50, 125, 62, 61, 48, 32, 38, 38, 32,
  36, 123, 53, 61, 48, 46, 52, 125, 62, 61, 48, 32, 38, 38, 32, 36,
  53, 60, 61, 49, 32, 38, 38, 32, 36, 123, 54, 61, 49, 48, 125, 62,
  61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 85, 112, 115,
  99, 97, 108, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 111, 32,
  36, 49, 120, 36, 50, 120, 36, 51, 44, 32, 119, 105, 116, 104, 32, 115,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 52, 44, 32, 97, 110,
  105, 115, 111, 116, 114, 111, 112, 121, 32, 36, 53, 32, 97, 110, 100, 32,
  115, 104, 97, 114, 112, 101, 110, 105, 110, 103, 32, 36, 54, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123,
  104, 125, 10, 45, 45, 114, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50,
  44, 36, 51, 44, 49, 44, 48, 10, 45, 105, 102, 32, 123, 119, 60, 36,
  119, 34, 32, 38, 38, 32, 34, 104, 60, 36, 104, 125, 10, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 114, 91, 45, 49, 93, 32, 36, 49, 44, 36,
  50, 44, 36, 51, 44, 49, 48, 48, 37, 44, 50, 10, 45, 101, 108, 115,
  101, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 45, 100, 105, 102, 102,
  117, 115, 105, 111, 110, 116, 101, 110, 115, 111, 114, 115, 32, 48, 44, 36,
  53, 44, 49, 46, 50, 44, 49, 46, 50, 10, 45, 114, 91, 45, 50, 44,
  45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 49, 48, 48,
  37, 44, 53, 10, 45, 115, 109, 111, 111, 116, 104, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 36, 52, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  34, 45, 115, 104, 97, 114, 112, 101, 110, 91, 45, 49, 93, 32, 36, 54,
  44, 49, 48, 34, 44, 51, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 98, 97, 110, 100, 112, 97, 115, 115, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 49, 61, 48, 125, 44, 36, 123, 50, 61, 50, 48, 37,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121,
  32, 98, 97, 110, 100, 112, 97, 115, 115, 32, 102, 105, 108, 116, 101, 114,
  32, 91, 36, 49, 44, 36, 50, 93, 32, 116, 111, 32, 105, 109, 97, 103,
  101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 102, 91, 45,
  49, 93, 32, 34, 115, 113, 114, 116, 40, 40, 120, 47, 119, 45, 48, 46,
  53, 41, 94, 50, 32, 43, 32, 40, 121, 47, 104, 45, 48, 46, 53, 41,
  94, 50, 32, 43, 32, 40, 122, 47, 100, 45, 48, 46, 53, 41, 94, 50,
  41, 34, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 116,
  50, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 32, 45, 115, 104, 105,
  102, 116, 91, 45, 49, 93, 32, 123, 105, 110, 116, 40, 119, 47, 50, 41,
  125, 44, 123, 105, 110, 116, 40, 104, 47, 50, 41, 125, 44, 53, 48, 37,
  44, 48, 44, 50, 10, 45, 102, 102, 116, 91, 45, 50, 93, 32, 45, 42,
  91, 45, 51, 93, 32, 91, 45, 49, 93, 32, 45, 42, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 105, 102, 102, 116, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 98, 108, 117, 114, 95, 97, 110, 103, 117, 108, 97, 114, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 48, 46, 53, 125,
  44, 36, 123, 51, 61, 48, 46, 53, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 65, 112, 112, 108, 121, 32, 97, 110, 103, 117, 108, 97, 114,
  32, 98, 108, 117, 114, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63,
  44, 32, 119, 105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101,
  32, 36, 49, 32, 97, 110, 100, 32, 99, 101, 110, 116, 101, 114, 32, 40,
  36, 50, 44, 36, 51, 41, 46, 34, 10, 45, 118, 32, 45, 32, 45, 101,
  117, 99, 108, 105, 100, 101, 97, 110, 50, 112, 111, 108, 97, 114, 32, 36,
  50, 44, 36, 51, 44, 49, 46, 51, 44, 49, 32, 45, 101, 120, 112, 97,
  110, 100, 95, 121, 32, 49, 54, 44, 50, 32, 45, 98, 108, 117, 114, 95,
  121, 32, 36, 49, 32, 45, 115, 104, 114, 105, 110, 107, 95, 121, 32, 49,
  54, 32, 45, 112, 111, 108, 97, 114, 50, 101, 117, 99, 108, 105, 100, 101,
  97, 110, 32, 36, 50, 44, 36, 51, 44, 49, 46, 51, 44, 49, 32, 45,
  118, 32, 43, 10, 98, 108, 117, 114, 95, 108, 105, 110, 101, 97, 114, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 48, 125, 44, 36,
  123, 51, 61, 48, 125, 44, 36, 123, 52, 61, 49, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 108, 105, 110, 101,
  97, 114, 32, 98, 108, 117, 114, 32, 111, 110, 32, 105, 109, 97, 103, 101,
  36, 63, 44, 32, 119, 105, 116, 104, 32, 97, 110, 103, 108, 101, 32, 36,
  51, 32, 100, 101, 103, 46, 32, 97, 110, 100, 32, 97, 109, 112, 108, 105,
  116, 117, 100, 101, 115, 32, 40, 36, 49, 44, 36, 50, 41, 46, 34, 10,
  45, 118, 32, 45, 10, 115, 116, 100, 49, 61, 123, 105, 102, 40, 64, 123,
  45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 49, 125,
  44, 36, 49, 42, 109, 97, 120, 40, 119, 44, 104, 41, 44, 36, 49, 41,
  125, 10, 115, 116, 100, 50, 61, 123, 105, 102, 40, 64, 123, 45, 105, 115,
  95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 50, 125, 44, 36, 50,
  42, 109, 97, 120, 40, 119, 44, 104, 41, 44, 36, 50, 41, 125, 10, 115,
  116, 100, 77, 61, 123, 114, 111, 117, 110, 100, 40, 49, 46, 50, 53, 42,
  109, 97, 120, 40, 36, 115, 116, 100, 49, 44, 36, 115, 116, 100, 50, 41,
  41, 125, 10, 45, 105, 102, 32, 123, 36, 115, 116, 100, 77, 60, 61, 48,
  125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 32, 36, 115,
  116, 100, 77, 44, 123, 36, 52, 33, 61, 48, 125, 10, 123, 50, 42, 36,
  115, 116, 100, 77, 125, 44, 123, 50, 42, 36, 115, 116, 100, 77, 125, 32,
  45, 103, 97, 117, 115, 115, 105, 97, 110, 91, 45, 49, 93, 32, 36, 49,
  44, 36, 50, 44, 36, 51, 32, 45, 110, 111, 114, 109, 97, 108, 105, 122,
  101, 95, 115, 117, 109, 91, 45, 49, 93, 10, 45, 99, 111, 110, 118, 111,
  108, 118, 101, 95, 102, 102, 116, 32, 45, 115, 104, 114, 105, 110, 107, 95,
  120, 121, 32, 36, 115, 116, 100, 77, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 98, 108, 117, 114, 95, 114,
  97, 100, 105, 97, 108, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  50, 61, 48, 46, 53, 125, 44, 36, 123, 51, 61, 48, 46, 53, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 114,
  97, 100, 105, 97, 108, 32, 98, 108, 117, 114, 32, 111, 110, 32, 105, 109,
  97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 97, 109, 112, 108,
  105, 116, 117, 100, 101, 32, 36, 49, 32, 97, 110, 100, 32, 99, 101, 110,
  116, 101, 114, 32, 40, 36, 50, 44, 36, 51, 41, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 101, 117, 99, 108, 105, 100, 101, 97, 110, 50, 112, 111,
  108, 97, 114, 32, 36, 50, 44, 36, 51, 44, 53, 44, 49, 32, 45, 98,
  108, 117, 114, 95, 120, 32, 36, 49, 32, 45, 112, 111, 108, 97, 114, 50,
  101, 117, 99, 108, 105, 100, 101, 97, 110, 32, 36, 50, 44, 36, 51, 44,
  53, 44, 49, 32, 45, 118, 32, 43, 10, 98, 108, 117, 114, 95, 115, 101,
  108, 101, 99, 116, 105, 118, 101, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 34, 36, 123, 49, 61, 53, 125, 62, 61, 48, 32, 38, 38, 32, 36,
  123, 50, 61, 48, 46, 53, 125, 62, 61, 48, 32, 38, 38, 32, 105, 115,
  105, 110, 116, 40, 36, 123, 51, 61, 53, 125, 41, 32, 38, 38, 32, 36,
  51, 62, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 66, 108,
  117, 114, 32, 105, 109, 97, 103, 101, 36, 63, 32, 117, 115, 105, 110, 103,
  32, 36, 51, 32, 115, 101, 108, 101, 99, 116, 105, 118, 101, 32, 103, 97,
  117, 115, 115, 105, 97, 110, 32, 115, 99, 97, 108, 101, 115, 44, 32, 119,
  105, 116, 104, 32, 115, 105, 103, 109, 97, 32, 36, 49, 32, 97, 110, 100,
  32, 101, 100, 103, 101, 115, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 45, 45, 103,
  114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 32, 45, 43, 91,
  45, 49, 93, 32, 49, 32, 45, 94, 91, 45, 49, 93, 32, 123, 45, 109,
  97, 120, 40, 48, 46, 48, 49, 44, 36, 50, 41, 125, 32, 45, 113, 117,
  97, 110, 116, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 51, 43, 49,
  125, 44, 48, 44, 49, 32, 45, 109, 105, 110, 91, 45, 49, 93, 32, 123,
  36, 51, 45, 49, 125, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50,
  93, 32, 45, 47, 91, 45, 49, 93, 32, 49, 48, 48, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 36, 51, 32, 45, 45, 61, 61, 91, 45, 49, 93,
  32, 123, 36, 62, 47, 49, 48, 48, 125, 32, 45, 42, 91, 45, 49, 93,
  32, 91, 45, 51, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 98, 91, 45, 50, 93, 32, 123, 36, 49, 47, 40, 36, 51, 43, 49,
  41, 125, 32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 45, 50, 93,
  32, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 98, 108, 117, 114,
  95, 120, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 49,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 66, 108, 117, 114, 32,
  105, 109, 97, 103, 101, 36, 63, 32, 97, 108, 111, 110, 103, 32, 116, 104,
  101, 32, 120, 45, 97, 120, 105, 115, 44, 32, 119, 105, 116, 104, 32, 115,
  105, 103, 109, 97, 32, 36, 49, 32, 97, 110, 100, 32, 34, 64, 123, 45,
  97, 114, 103, 92, 32, 49, 43, 33, 36, 50, 44, 110, 101, 117, 109, 97,
  110, 110, 44, 100, 105, 114, 105, 99, 104, 108, 101, 116, 125, 34, 32, 98,
  111, 117, 110, 100, 97, 114, 121, 32, 99, 111, 110, 100, 105, 116, 105, 111,
  110, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 100, 101, 114, 105, 99,
  104, 101, 32, 36, 49, 44, 48, 44, 120, 44, 36, 50, 32, 45, 118, 32,
  43, 10, 98, 108, 117, 114, 95, 120, 121, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 50, 61, 36, 49, 125, 44, 36, 123, 51, 61, 49, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 66, 108, 117, 114, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101,
  32, 120, 121, 45, 97, 120, 101, 115, 44, 32, 119, 105, 116, 104, 32, 115,
  105, 103, 109, 97, 32, 36, 49, 32, 97, 110, 100, 32, 34, 64, 123, 45,
  97, 114, 103, 92, 32, 49, 43, 33, 36, 50, 44, 110, 101, 117, 109, 97,
  110, 110, 44, 100, 105, 114, 105, 99, 104, 108, 101, 116, 125, 34, 32, 98,
  111, 117, 110, 100, 97, 114, 121, 32, 99, 111, 110, 100, 105, 116, 105, 111,
  110, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 100, 101, 114, 105, 99,
  104, 101, 32, 36, 49, 44, 48, 44, 120, 44, 36, 51, 32, 45, 100, 101,
  114, 105, 99, 104, 101, 32, 36, 50, 44, 48, 44, 121, 44, 36, 51, 32,
  45, 118, 32, 43, 10, 98, 108, 117, 114, 95, 120, 121, 122, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 52, 61, 49, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 66, 108, 117, 114, 32, 105, 109, 97, 103, 101,
  36, 63, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 120, 121, 122,
  45, 97, 120, 101, 115, 44, 32, 119, 105, 116, 104, 32, 115, 105, 103, 109,
  97, 32, 36, 49, 32, 97, 110, 100, 32, 34, 64, 123, 45, 97, 114, 103,
  92, 32, 49, 43, 33, 36, 50, 44, 110, 101, 117, 109, 97, 110, 110, 44,
  100, 105, 114, 105, 99, 104, 108, 101, 116, 125, 34, 32, 98, 111, 117, 110,
  100, 97, 114, 121, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 115, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 100, 101, 114, 105, 99, 104, 101, 32,
  36, 49, 44, 48, 44, 120, 44, 36, 52, 32, 45, 100, 101, 114, 105, 99,
  104, 101, 32, 36, 50, 44, 48, 44, 121, 44, 36, 52, 32, 45, 100, 101,
  114, 105, 99, 104, 101, 32, 36, 51, 44, 48, 44, 122, 44, 36, 52, 32,
  45, 118, 32, 43, 10, 98, 108, 117, 114, 95, 121, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 50, 61, 49, 125, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 66, 108, 117, 114, 32, 105, 109, 97, 103, 101, 36, 63,
  32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 121, 45, 97, 120, 105,
  115, 44, 32, 119, 105, 116, 104, 32, 115, 105, 103, 109, 97, 32, 36, 49,
  32, 97, 110, 100, 32, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43,
  33, 36, 50, 44, 110, 101, 117, 109, 97, 110, 110, 44, 100, 105, 114, 105,
  99, 104, 108, 101, 116, 125, 34, 32, 98, 111, 117, 110, 100, 97, 114, 121,
  32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 115, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 100, 101, 114, 105, 99, 104, 101, 32, 36, 49, 44, 48,
  44, 121, 44, 36, 50, 32, 45, 118, 32, 43, 10, 98, 108, 117, 114, 95,
  122, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 49, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 66, 108, 117, 114, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101,
  32, 122, 45, 97, 120, 105, 115, 44, 32, 119, 105, 116, 104, 32, 115, 105,
  103, 109, 97, 32, 36, 49, 32, 97, 110, 100, 32, 34, 64, 123, 45, 97,
  114, 103, 92, 32, 49, 43, 33, 36, 50, 44, 110, 101, 117, 109, 97, 110,
  110, 44, 100, 105, 114, 105, 99, 104, 108, 101, 116, 125, 34, 32, 98, 111,
  117, 110, 100, 97, 114, 121, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110,
  115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 100, 101, 114, 105, 99, 104,
  101, 32, 36, 49, 44, 48, 44, 122, 44, 36, 50, 32, 45, 118, 32, 43,
  10, 98, 111, 107, 101, 104, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 36, 123, 49, 61, 50, 48, 48, 125, 62, 61, 48, 32, 38, 38, 32,
  36, 123, 50, 61, 50, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 51,
  61, 48, 46, 50, 125, 62, 61, 48, 32, 38, 38, 32, 36, 51, 60, 61,
  49, 48, 48, 32, 38, 38, 32, 36, 123, 52, 61, 50, 52, 125, 62, 48,
  32, 38, 38, 32, 36, 123, 53, 61, 49, 48, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 53, 60, 61, 49, 48, 48, 32, 38, 38, 32, 36, 123, 54,
  61, 50, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 55, 61, 49, 125,
  62, 61, 48, 32, 38, 38, 32, 36, 123, 56, 61, 48, 46, 49, 125, 62,
  61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112,
  108, 121, 32, 98, 111, 107, 101, 104, 32, 101, 102, 102, 101, 99, 116, 32,
  116, 111, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104,
  32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 36, 49, 44, 32, 115,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 50, 44, 32, 100, 101,
  110, 115, 105, 116, 121, 32, 36, 51, 37, 44, 32, 98, 111, 107, 101, 104,
  32, 115, 105, 122, 101, 32, 36, 52, 44, 32, 98, 111, 107, 101, 104, 32,
  111, 117, 116, 108, 105, 110, 101, 32, 115, 105, 122, 101, 32, 36, 53, 32,
  34, 92, 10, 34, 98, 111, 107, 101, 104, 32, 111, 117, 116, 108, 105, 110,
  101, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 36, 54, 32, 97,
  110, 100, 32, 98, 111, 107, 101, 104, 32, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 36, 55, 46, 34, 10, 45, 118, 32, 45, 10, 50, 53,
  54, 44, 50, 53, 54, 32, 45, 61, 91, 45, 49, 93, 32, 49, 44, 53,
  48, 37, 44, 53, 48, 37, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101,
  91, 45, 49, 93, 32, 49, 10, 45, 45, 108, 116, 91, 45, 49, 93, 32,
  55, 48, 37, 32, 45, 116, 50, 91, 45, 50, 93, 32, 55, 48, 37, 44,
  123, 55, 48, 45, 36, 53, 42, 55, 48, 47, 49, 48, 48, 125, 37, 32,
  45, 42, 91, 45, 50, 93, 32, 36, 54, 32, 45, 43, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 114, 91, 45, 49, 93, 32, 36, 52, 44, 36, 52,
  44, 49, 44, 49, 44, 50, 10, 45, 101, 120, 112, 97, 110, 100, 95, 120,
  121, 91, 45, 49, 93, 32, 123, 51, 42, 36, 55, 125, 44, 48, 32, 45,
  98, 91, 45, 49, 93, 32, 36, 55, 44, 48, 32, 45, 45, 103, 116, 91,
  45, 49, 93, 32, 48, 46, 49, 32, 45, 42, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 10,
  45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 115, 117, 109, 91, 45,
  49, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49,
  125, 32, 45, 108, 91, 36, 62, 44, 45, 49, 93, 10, 45, 45, 114, 101,
  109, 111, 118, 101, 95, 112, 105, 120, 101, 108, 115, 91, 48, 93, 32, 123,
  49, 48, 48, 45, 36, 51, 125, 32, 45, 99, 111, 110, 118, 111, 108, 118,
  101, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 32, 45, 110, 91,
  45, 49, 93, 32, 48, 44, 36, 49, 10, 45, 98, 91, 48, 93, 32, 36,
  50, 32, 45, 43, 91, 48, 44, 45, 49, 93, 32, 45, 99, 91, 48, 93,
  32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 118, 32, 43, 10,
  99, 111, 109, 112, 111, 115, 101, 95, 102, 114, 101, 113, 32, 58, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 111, 115, 101, 32,
  108, 111, 119, 32, 97, 110, 100, 32, 104, 105, 103, 104, 32, 102, 114, 101,
  113, 117, 101, 110, 99, 121, 32, 112, 97, 114, 116, 36, 63, 32, 105, 110,
  116, 111, 32, 110, 101, 119, 32, 105, 109, 97, 103, 101, 115, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110,
  116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 43, 91, 36, 62, 44, 123,
  36, 62, 43, 49, 125, 93, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 99, 111, 110, 118, 111, 108, 118, 101, 95, 102, 102, 116, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 111, 108,
  118, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98,
  121, 45, 116, 119, 111, 32, 116, 104, 114, 111, 117, 103, 104, 32, 102, 111,
  117, 114, 105, 101, 114, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 115,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36,
  62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 119, 50, 61, 123, 105, 110,
  116, 40, 64, 123, 48, 44, 119, 125, 47, 50, 41, 125, 32, 104, 50, 61,
  123, 105, 110, 116, 40, 64, 123, 48, 44, 104, 125, 47, 50, 41, 125, 32,
  100, 50, 61, 123, 105, 110, 116, 40, 64, 123, 48, 44, 100, 125, 47, 50,
  41, 125, 10, 45, 114, 91, 49, 93, 32, 91, 48, 93, 44, 91, 48, 93,
  44, 91, 48, 93, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48,
  46, 53, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 115, 104, 105, 102,
  116, 91, 49, 93, 32, 45, 36, 119, 50, 44, 45, 36, 104, 50, 44, 45,
  36, 100, 50, 44, 48, 44, 50, 10, 45, 102, 102, 116, 91, 48, 93, 32,
  45, 102, 102, 116, 91, 50, 93, 10, 45, 45, 42, 91, 45, 52, 93, 32,
  91, 45, 49, 93, 32, 45, 45, 42, 91, 45, 52, 93, 32, 91, 45, 51,
  93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 42, 91, 45,
  53, 44, 45, 51, 93, 32, 45, 42, 91, 45, 51, 44, 45, 50, 93, 32,
  45, 45, 91, 45, 51, 44, 45, 50, 93, 10, 45, 105, 102, 102, 116, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 99, 114, 111, 115, 115, 95, 99,
  111, 114, 114, 101, 108, 97, 116, 105, 111, 110, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 99, 114,
  111, 115, 115, 45, 99, 111, 114, 114, 101, 108, 97, 116, 105, 111, 110, 32,
  117, 115, 105, 110, 103, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111,
  32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47,
  50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125,
  93, 10, 45, 110, 111, 114, 109, 32, 45, 102, 102, 116, 91, 45, 50, 93,
  32, 45, 102, 102, 116, 91, 45, 49, 93, 32, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 42, 91, 45, 50, 93, 32, 91, 45, 53, 93, 32, 45, 42,
  91, 45, 49, 93, 32, 91, 45, 54, 93, 10, 45, 45, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 42, 91, 45, 53, 44, 45, 51, 93, 32, 45, 42,
  91, 45, 51, 44, 45, 50, 93, 32, 45, 43, 91, 45, 51, 44, 45, 50,
  93, 32, 45, 105, 102, 102, 116, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 99, 117, 114, 118, 97, 116, 117, 114, 101, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 105, 115,
  111, 112, 104, 111, 116, 101, 32, 99, 117, 114, 118, 97, 116, 117, 114, 101,
  115, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 100, 61, 61, 49, 125,
  10, 45, 45, 103, 32, 120, 121, 44, 48, 32, 45, 104, 101, 115, 115, 105,
  97, 110, 91, 45, 51, 93, 32, 120, 120, 120, 121, 121, 121, 10, 45, 42,
  91, 45, 51, 93, 32, 91, 45, 50, 93, 32, 45, 42, 91, 45, 52, 93,
  32, 91, 45, 49, 93, 32, 45, 42, 91, 45, 52, 93, 32, 45, 50, 10,
  45, 43, 91, 45, 52, 44, 45, 51, 93, 32, 45, 42, 91, 45, 51, 93,
  32, 91, 45, 50, 93, 10, 45, 115, 113, 114, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 42, 91, 45, 52, 93, 32, 91, 45, 49, 93, 32, 45, 43,
  91, 45, 52, 44, 45, 51, 93, 10, 45, 43, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 43, 91, 45, 49, 93, 32, 48, 46, 49, 32, 45, 94, 91,
  45, 49, 93, 32, 49, 46, 53, 32, 45, 47, 10, 45, 101, 108, 115, 101,
  10, 45, 45, 105, 110, 110, 32, 45, 45, 103, 114, 97, 100, 105, 101, 110,
  116, 95, 110, 111, 114, 109, 91, 45, 50, 93, 32, 45, 108, 97, 112, 108,
  97, 99, 105, 97, 110, 91, 45, 51, 93, 10, 45, 45, 91, 45, 51, 44,
  45, 50, 93, 32, 45, 43, 91, 45, 49, 93, 32, 48, 46, 49, 32, 45,
  47, 91, 45, 50, 44, 45, 49, 93, 10, 45, 45, 105, 110, 110, 91, 45,
  49, 93, 32, 45, 108, 97, 112, 108, 97, 99, 105, 97, 110, 91, 45, 50,
  93, 32, 45, 45, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 100, 101, 98,
  108, 117, 114, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123,
  50, 61, 49, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 51, 61,
  50, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 52, 61, 48, 46,
  55, 125, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 53,
  61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 101, 98,
  108, 117, 114, 32, 105, 109, 97, 103, 101, 36, 63, 32, 119, 105, 116, 104,
  32, 97, 32, 114, 101, 103, 117, 108, 97, 114, 105, 122, 101, 100, 32, 74,
  97, 110, 115, 115, 111, 110, 45, 86, 97, 110, 32, 67, 105, 116, 116, 101,
  114, 116, 32, 97, 108, 103, 111, 114, 105, 116, 104, 109, 44, 32, 119, 105,
  116, 104, 32, 115, 105, 103, 109, 97, 32, 36, 49, 44, 32, 36, 50, 32,
  105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 44, 32, 116, 105, 109, 101,
  32, 115, 116, 101, 112, 32, 36, 51, 32, 97, 110, 100, 32, 114, 101, 103,
  117, 108, 97, 114, 105, 122, 97, 116, 105, 111, 110, 32, 36, 52, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110,
  125, 10, 91, 48, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 50,
  10, 45, 105, 102, 32, 123, 36, 53, 62, 61, 50, 125, 32, 45, 45, 99,
  117, 114, 118, 97, 116, 117, 114, 101, 91, 45, 49, 93, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 53, 62, 61, 49, 125, 32, 45, 45, 105, 101, 101,
  91, 45, 49, 93, 10, 45, 101, 108, 115, 101, 32, 45, 45, 108, 97, 112,
  108, 97, 99, 105, 97, 110, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 42, 91, 45, 49, 93, 32, 36, 52, 10, 45, 45, 98, 91,
  45, 50, 93, 32, 36, 49, 32, 45, 45, 91, 45, 49, 93, 32, 91, 45,
  52, 93, 10, 45, 45, 91, 45, 50, 44, 45, 49, 93, 10, 45, 42, 91,
  45, 49, 93, 32, 123, 36, 51, 47, 40, 48, 46, 48, 48, 48, 49, 43,
  109, 97, 120, 40, 97, 98, 115, 40, 64, 123, 45, 49, 44, 109, 125, 41,
  44, 97, 98, 115, 40, 64, 123, 45, 49, 44, 77, 125, 41, 41, 41, 125,
  10, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 100, 111, 110, 101,
  10, 45, 114, 109, 91, 45, 50, 93, 10, 45, 110, 109, 32, 36, 110, 109,
  44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 100, 101, 98, 108, 117, 114, 95, 103, 111, 108, 100, 109,
  101, 105, 110, 101, 108, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  36, 49, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 56, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 123, 51, 61, 49, 125, 62, 61, 48, 34,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 52, 61, 49, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 68, 101, 98, 108, 117, 114, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 117, 115, 105, 110, 103, 32, 71, 111, 108, 100,
  45, 77, 101, 105, 110, 101, 108, 32, 97, 108, 103, 111, 114, 105, 116, 104,
  109, 44, 32, 119, 105, 116, 104, 32, 115, 105, 103, 109, 97, 32, 36, 49,
  44, 32, 36, 50, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 44,
  32, 97, 99, 99, 101, 108, 101, 114, 97, 116, 105, 111, 110, 32, 36, 51,
  32, 97, 110, 100, 32, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43,
  33, 36, 52, 44, 34, 34, 44, 113, 117, 97, 115, 105, 45, 125, 34, 103,
  97, 117, 115, 115, 105, 97, 110, 32, 107, 101, 114, 110, 101, 108, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 91, 48, 93, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 36, 50, 10, 45, 45, 98, 91, 45, 49, 93, 32, 36,
  49, 44, 49, 44, 36, 52, 32, 45, 45, 47, 91, 48, 44, 45, 49, 93,
  32, 45, 114, 109, 91, 45, 50, 93, 32, 45, 94, 91, 45, 49, 93, 32,
  36, 51, 32, 45, 42, 91, 45, 49, 44, 45, 50, 93, 10, 45, 100, 111,
  110, 101, 32, 45, 114, 109, 91, 48, 93, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 100, 101, 98, 108, 117,
  114, 95, 114, 105, 99, 104, 97, 114, 100, 115, 111, 110, 108, 117, 99, 121,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48,
  32, 38, 38, 32, 36, 123, 50, 61, 53, 48, 125, 62, 61, 48, 34, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 49, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 68, 101, 98, 108, 117, 114, 32, 105, 109, 97,
  103, 101, 36, 63, 32, 117, 115, 105, 110, 103, 32, 82, 105, 99, 104, 97,
  114, 100, 115, 111, 110, 45, 76, 117, 99, 121, 32, 97, 108, 103, 111, 114,
  105, 116, 104, 109, 44, 32, 119, 105, 116, 104, 32, 115, 105, 103, 109, 97,
  32, 36, 49, 44, 32, 36, 50, 32, 105, 116, 101, 114, 97, 116, 105, 111,
  110, 115, 32, 97, 110, 100, 32, 34, 64, 123, 45, 97, 114, 103, 92, 32,
  49, 43, 33, 36, 51, 44, 34, 34, 44, 113, 117, 97, 115, 105, 45, 125,
  34, 103, 97, 117, 115, 115, 105, 97, 110, 32, 107, 101, 114, 110, 101, 108,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 91, 48, 93, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 50, 10, 45, 45, 98, 91, 45, 49, 93,
  32, 36, 49, 44, 49, 44, 123, 36, 51, 33, 61, 48, 125, 32, 45, 45,
  47, 91, 48, 44, 45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 93, 32,
  45, 98, 91, 45, 49, 93, 32, 36, 49, 44, 49, 44, 123, 36, 51, 33,
  61, 48, 125, 32, 45, 42, 91, 45, 49, 44, 45, 50, 93, 10, 45, 100,
  111, 110, 101, 32, 45, 114, 109, 91, 48, 93, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 100, 101, 99, 111,
  110, 118, 111, 108, 118, 101, 95, 102, 102, 116, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 68, 101, 99, 111, 110, 118, 111, 108, 118, 101,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45,
  116, 119, 111, 32, 116, 104, 114, 111, 117, 103, 104, 32, 102, 111, 117, 114,
  105, 101, 114, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 115, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105,
  110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44,
  123, 36, 62, 43, 49, 125, 93, 10, 119, 50, 61, 123, 105, 110, 116, 40,
  64, 123, 48, 44, 119, 125, 47, 50, 41, 125, 32, 104, 50, 61, 123, 105,
  110, 116, 40, 64, 123, 48, 44, 104, 125, 47, 50, 41, 125, 32, 100, 50,
  61, 123, 105, 110, 116, 40, 64, 123, 48, 44, 100, 125, 47, 50, 41, 125,
  10, 45, 114, 91, 49, 93, 32, 91, 48, 93, 44, 91, 48, 93, 44, 91,
  48, 93, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53,
  44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 115, 104, 105, 102, 116, 91,
  49, 93, 32, 45, 36, 119, 50, 44, 45, 36, 104, 50, 44, 45, 36, 100,
  50, 44, 48, 44, 50, 10, 45, 102, 102, 116, 91, 48, 93, 32, 45, 102,
  102, 116, 91, 49, 93, 10, 45, 45, 115, 113, 114, 91, 45, 50, 93, 32,
  45, 45, 115, 113, 114, 91, 45, 50, 93, 32, 45, 43, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 43, 91, 45, 49, 93, 32, 49, 101, 45, 53, 10,
  45, 45, 42, 91, 45, 52, 93, 32, 91, 45, 51, 93, 10, 45, 45, 42,
  91, 45, 54, 93, 32, 91, 45, 51, 93, 10, 45, 45, 91, 45, 50, 44,
  45, 49, 93, 10, 45, 42, 91, 45, 54, 44, 45, 52, 93, 10, 45, 42,
  91, 45, 52, 44, 45, 51, 93, 10, 45, 43, 91, 45, 52, 44, 45, 51,
  93, 10, 45, 47, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 47,
  91, 45, 51, 44, 45, 50, 93, 10, 45, 105, 102, 102, 116, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 100, 101, 105, 110, 116, 101, 114, 108, 97,
  99, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 101, 105, 110, 116,
  101, 114, 108, 97, 99, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 119,
  105, 116, 104, 32, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 33,
  36, 49, 44, 109, 111, 116, 105, 111, 110, 45, 99, 111, 109, 112, 101, 110,
  115, 97, 116, 101, 100, 44, 115, 116, 97, 110, 100, 97, 114, 100, 125, 34,
  32, 109, 101, 116, 104, 111, 100, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 119, 104, 61, 123, 119, 125, 44, 123, 104, 125, 10, 45, 115, 32, 121,
  32, 45, 97, 91, 48, 45, 45, 49, 58, 50, 93, 32, 121, 32, 45, 97,
  91, 94, 48, 93, 32, 121, 32, 45, 114, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 44, 48, 32, 45, 114, 32, 49, 48, 48, 37, 44, 50, 48, 48,
  37, 44, 49, 44, 49, 48, 48, 37, 44, 53, 10, 45, 105, 102, 32, 123,
  36, 49, 33, 61, 48, 125, 32, 45, 45, 100, 105, 115, 112, 108, 97, 99,
  101, 109, 101, 110, 116, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48,
  46, 48, 53, 32, 45, 119, 97, 114, 112, 91, 45, 51, 93, 32, 91, 45,
  49, 93, 44, 49, 44, 49, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 43, 32, 45, 47, 32, 50, 32,
  45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 114, 32, 36, 119, 104, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 100, 101, 110, 111, 105, 115, 101, 95, 104, 97, 97, 114, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 49, 46, 52, 125,
  62, 61, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 50,
  61, 48, 125, 41, 32, 38, 38, 32, 36, 50, 62, 61, 48, 32, 38, 38,
  32, 105, 115, 105, 110, 116, 40, 36, 123, 51, 61, 49, 48, 125, 41, 32,
  38, 38, 32, 36, 51, 62, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 68, 101, 110, 111, 105, 115, 101, 32, 105, 109, 97, 103, 101, 36,
  63, 32, 117, 115, 105, 110, 103, 32, 104, 97, 97, 114, 45, 119, 97, 118,
  101, 108, 101, 116, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 105, 110,
  103, 44, 32, 119, 105, 116, 104, 32, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 32, 36, 49, 44, 32, 34, 92, 10, 64, 123, 45, 97, 114, 103, 92,
  32, 49, 43, 40, 36, 50, 62, 48, 41, 44, 97, 117, 116, 111, 44, 36,
  50, 125, 34, 32, 115, 99, 97, 108, 101, 115, 32, 97, 110, 100, 32, 36,
  51, 32, 115, 112, 105, 110, 110, 105, 110, 103, 32, 99, 121, 99, 108, 101,
  115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123,
  48, 44, 110, 125, 10, 110, 98, 95, 115, 99, 97, 108, 101, 115, 61, 123,
  109, 105, 110, 40, 105, 102, 40, 36, 50, 44, 36, 50, 44, 51, 50, 41,
  44, 105, 110, 116, 40, 108, 111, 103, 50, 40, 109, 105, 110, 40, 119, 44,
  104, 41, 41, 45, 49, 41, 41, 125, 10, 119, 61, 123, 119, 125, 32, 104,
  61, 123, 104, 125, 32, 100, 61, 123, 100, 125, 32, 115, 105, 103, 109, 97,
  61, 64, 123, 45, 118, 97, 114, 105, 97, 110, 99, 101, 95, 110, 111, 105,
  115, 101, 125, 10, 45, 114, 32, 123, 114, 111, 117, 110, 100, 40, 119, 44,
  50, 94, 40, 36, 110, 98, 95, 115, 99, 97, 108, 101, 115, 43, 49, 41,
  44, 49, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 104, 44, 50, 94,
  40, 36, 110, 98, 95, 115, 99, 97, 108, 101, 115, 43, 49, 41, 44, 49,
  41, 125, 44, 123, 105, 102, 40, 100, 61, 61, 49, 44, 49, 44, 114, 111,
  117, 110, 100, 40, 100, 44, 50, 94, 40, 36, 110, 98, 95, 115, 99, 97,
  108, 101, 115, 43, 49, 41, 44, 49, 41, 41, 125, 44, 49, 48, 48, 37,
  44, 48, 44, 48, 10, 45, 45, 102, 32, 48, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 36, 51, 10, 100, 120, 61, 123, 114, 111, 117, 110, 100, 40,
  63, 40, 48, 44, 123, 52, 42, 36, 110, 98, 95, 115, 99, 97, 108, 101,
  115, 125, 41, 41, 125, 10, 100, 121, 61, 123, 114, 111, 117, 110, 100, 40,
  63, 40, 48, 44, 123, 52, 42, 36, 110, 98, 95, 115, 99, 97, 108, 101,
  115, 125, 41, 41, 125, 10, 100, 122, 61, 123, 105, 102, 40, 36, 100, 61,
  61, 49, 44, 48, 44, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 123,
  52, 42, 36, 110, 98, 95, 115, 99, 97, 108, 101, 115, 125, 41, 41, 41,
  125, 10, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93, 32, 36, 100, 120,
  44, 36, 100, 121, 44, 36, 100, 122, 44, 48, 44, 50, 10, 45, 104, 97,
  97, 114, 91, 45, 49, 93, 32, 36, 110, 98, 95, 115, 99, 97, 108, 101,
  115, 10, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100, 91, 45, 49, 93,
  32, 123, 36, 49, 42, 36, 115, 105, 103, 109, 97, 125, 44, 49, 10, 45,
  105, 104, 97, 97, 114, 91, 45, 49, 93, 32, 36, 110, 98, 95, 115, 99,
  97, 108, 101, 115, 10, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32,
  123, 45, 36, 100, 120, 125, 44, 123, 45, 36, 100, 121, 125, 44, 123, 45,
  36, 100, 122, 125, 44, 48, 44, 50, 10, 45, 43, 91, 45, 50, 44, 45,
  49, 93, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 48, 93, 32,
  45, 47, 32, 36, 51, 32, 45, 114, 32, 36, 119, 44, 36, 104, 44, 36,
  100, 44, 49, 48, 48, 37, 44, 48, 10, 45, 110, 109, 32, 36, 110, 109,
  44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 49, 62, 61, 48, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 50, 61, 49, 125, 44, 36, 123, 51, 61,
  48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108,
  121, 32, 99, 105, 114, 99, 117, 108, 97, 114, 32, 100, 105, 108, 97, 116,
  105, 111, 110, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 32, 98,
  121, 32, 115, 105, 122, 101, 32, 36, 49, 44, 32, 98, 111, 117, 110, 100,
  97, 114, 121, 32, 36, 50, 32, 97, 110, 100, 32, 105, 115, 95, 110, 111,
  114, 109, 97, 108, 105, 122, 101, 100, 32, 36, 51, 46, 34, 10, 45, 105,
  102, 32, 123, 36, 49, 60, 50, 125, 32, 45, 114, 101, 116, 117, 114, 110,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 32, 45, 95, 100,
  116, 95, 99, 105, 114, 99, 108, 101, 91, 93, 32, 36, 49, 32, 45, 100,
  105, 108, 97, 116, 101, 91, 94, 45, 49, 93, 32, 91, 45, 49, 93, 44,
  36, 50, 44, 36, 51, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 118,
  32, 43, 10, 100, 105, 108, 97, 116, 101, 95, 111, 99, 116, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 36, 49, 62, 61, 48, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 50, 61, 49, 125, 44, 36, 123, 51, 61, 48, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32,
  111, 99, 116, 97, 103, 111, 110, 97, 108, 32, 100, 105, 108, 97, 116, 105,
  111, 110, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 32, 98, 121,
  32, 115, 105, 122, 101, 32, 36, 49, 44, 32, 98, 111, 117, 110, 100, 97,
  114, 121, 32, 36, 50, 32, 97, 110, 100, 32, 105, 115, 95, 110, 111, 114,
  109, 97, 108, 105, 122, 101, 100, 32, 36, 51, 46, 34, 10, 45, 118, 32,
  45, 10, 45, 105, 102, 32, 123, 36, 49, 60, 50, 125, 32, 45, 114, 101,
  116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 49, 38, 49, 125, 32, 115, 115, 61, 123, 36, 49, 125, 32, 45,
  101, 108, 115, 101, 32, 115, 115, 61, 123, 36, 49, 43, 49, 125, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 91, 48, 93, 32, 40, 48, 44, 49,
  44, 48, 59, 49, 44, 49, 44, 49, 59, 48, 44, 49, 44, 48, 41, 32,
  45, 105, 91, 49, 93, 32, 40, 49, 44, 49, 44, 49, 59, 49, 44, 49,
  44, 49, 59, 49, 44, 49, 44, 49, 41, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 64, 35, 45, 50, 125, 10, 114, 61, 123, 114, 111, 117, 110,
  100, 40, 40, 36, 115, 115, 45, 49, 41, 42, 115, 113, 114, 116, 40, 50,
  41, 47, 40, 49, 43, 115, 113, 114, 116, 40, 50, 41, 41, 47, 50, 41,
  125, 10, 113, 61, 123, 114, 111, 117, 110, 100, 40, 40, 36, 115, 115, 45,
  49, 41, 47, 40, 49, 43, 115, 113, 114, 116, 40, 50, 41, 41, 47, 50,
  41, 125, 10, 45, 105, 102, 32, 123, 36, 114, 62, 48, 125, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 114, 32, 45, 100, 105, 108, 97, 116, 101,
  91, 45, 49, 93, 32, 91, 48, 93, 44, 36, 50, 44, 36, 51, 32, 45,
  100, 111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 113, 62, 48, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36,
  113, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 91, 49,
  93, 44, 36, 50, 44, 36, 51, 32, 45, 100, 111, 110, 101, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 109, 118, 91, 45, 49, 93, 32, 50, 32, 45,
  100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 44, 49, 93, 32, 45, 118,
  32, 43, 10, 95, 107, 114, 95, 99, 105, 114, 99, 108, 101, 32, 58, 10,
  45, 105, 102, 32, 123, 36, 49, 37, 50, 61, 61, 48, 125, 32, 45, 105,
  32, 50, 44, 50, 44, 49, 44, 49, 44, 49, 32, 45, 101, 108, 115, 101,
  32, 45, 105, 32, 49, 44, 49, 44, 49, 44, 49, 44, 49, 32, 45, 101,
  110, 100, 105, 102, 32, 45, 114, 91, 45, 49, 93, 32, 36, 49, 44, 36,
  49, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46,
  53, 10, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32,
  49, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 48, 46, 53,
  32, 45, 116, 50, 91, 45, 49, 93, 32, 48, 44, 123, 36, 49, 47, 50,
  125, 10, 95, 106, 102, 95, 99, 105, 114, 99, 108, 101, 32, 58, 10, 123,
  114, 111, 117, 110, 100, 40, 36, 49, 41, 125, 44, 123, 114, 111, 117, 110,
  100, 40, 36, 49, 41, 125, 10, 99, 101, 110, 116, 101, 114, 61, 123, 48,
  46, 53, 42, 40, 119, 45, 49, 41, 125, 10, 45, 102, 91, 45, 49, 93,
  32, 39, 115, 113, 114, 116, 40, 40, 120, 45, 36, 99, 101, 110, 116, 101,
  114, 41, 94, 50, 43, 40, 121, 45, 36, 99, 101, 110, 116, 101, 114, 41,
  94, 50, 41, 39, 10, 45, 105, 102, 32, 123, 33, 40, 119, 37, 50, 41,
  125, 10, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 48, 46, 48,
  48, 48, 49, 44, 45, 49, 10, 116, 49, 61, 123, 115, 113, 114, 116, 40,
  40, 40, 114, 111, 117, 110, 100, 40, 36, 49, 41, 45, 49, 41, 47, 50,
  41, 94, 50, 43, 48, 46, 50, 53, 41, 125, 10, 116, 50, 61, 123, 115,
  113, 114, 116, 40, 40, 40, 114, 111, 117, 110, 100, 40, 36, 49, 41, 43,
  49, 41, 47, 50, 41, 94, 50, 43, 48, 46, 50, 53, 41, 125, 10, 107,
  61, 123, 36, 49, 45, 114, 111, 117, 110, 100, 40, 36, 49, 41, 43, 48,
  46, 53, 125, 10, 116, 61, 123, 36, 116, 49, 43, 40, 36, 116, 50, 45,
  36, 116, 49, 41, 42, 36, 107, 125, 10, 45, 116, 50, 91, 45, 49, 93,
  32, 48, 44, 36, 116, 10, 45, 101, 108, 115, 101, 32, 45, 116, 50, 91,
  45, 49, 93, 32, 48, 44, 123, 36, 49, 47, 50, 45, 48, 46, 50, 53,
  125, 10, 45, 101, 110, 100, 105, 102, 10, 95, 100, 116, 95, 99, 105, 114,
  99, 108, 101, 32, 58, 10, 105, 114, 61, 123, 114, 111, 117, 110, 100, 40,
  36, 49, 41, 125, 10, 45, 105, 102, 32, 123, 33, 36, 105, 114, 125, 32,
  49, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 105, 114, 60, 50,
  125, 32, 36, 105, 114, 44, 36, 105, 114, 44, 49, 44, 49, 44, 49, 10,
  45, 101, 108, 115, 101, 10, 123, 105, 110, 116, 40, 36, 105, 114, 47, 50,
  41, 43, 40, 36, 105, 114, 37, 50, 41, 125, 44, 123, 105, 110, 116, 40,
  36, 105, 114, 47, 50, 41, 43, 40, 36, 105, 114, 37, 50, 41, 125, 32,
  45, 61, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 10, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93,
  32, 49, 32, 45, 108, 101, 91, 45, 49, 93, 32, 123, 40, 105, 43, 48,
  46, 52, 41, 47, 115, 113, 114, 116, 40, 50, 41, 125, 10, 45, 45, 109,
  105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 120, 10, 45, 105, 102, 32,
  123, 36, 105, 114, 62, 49, 38, 38, 40, 36, 105, 114, 37, 50, 41, 125,
  32, 45, 114, 91, 45, 49, 93, 32, 123, 119, 45, 49, 125, 44, 49, 48,
  48, 37, 44, 49, 44, 49, 44, 48, 44, 48, 44, 49, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32,
  45, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 121, 10, 45,
  105, 102, 32, 123, 36, 105, 114, 62, 49, 38, 38, 40, 36, 105, 114, 37,
  50, 41, 125, 32, 45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44,
  123, 104, 45, 49, 125, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 44,
  49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 91, 45, 50, 44, 45,
  49, 93, 32, 121, 10, 45, 101, 110, 100, 105, 102, 10, 95, 100, 116, 95,
  100, 105, 97, 109, 111, 110, 100, 32, 58, 10, 105, 114, 61, 123, 114, 111,
  117, 110, 100, 40, 36, 49, 41, 125, 10, 45, 105, 102, 32, 123, 36, 105,
  114, 60, 50, 125, 32, 36, 105, 114, 44, 36, 105, 114, 44, 49, 44, 49,
  44, 49, 10, 45, 101, 108, 115, 101, 10, 123, 105, 110, 116, 40, 36, 105,
  114, 47, 50, 41, 43, 40, 36, 105, 114, 37, 50, 41, 125, 44, 123, 105,
  110, 116, 40, 36, 105, 114, 47, 50, 41, 43, 40, 36, 105, 114, 37, 50,
  41, 125, 32, 45, 61, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 10, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91,
  45, 49, 93, 32, 49, 44, 49, 32, 45, 108, 101, 91, 45, 49, 93, 32,
  123, 105, 47, 50, 125, 10, 45, 45, 109, 105, 114, 114, 111, 114, 91, 45,
  49, 93, 32, 120, 10, 45, 105, 102, 32, 123, 36, 105, 114, 62, 49, 38,
  38, 40, 36, 105, 114, 37, 50, 41, 125, 32, 45, 114, 91, 45, 49, 93,
  32, 123, 119, 45, 49, 125, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44,
  48, 44, 48, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 91,
  45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 45, 109, 105, 114, 114, 111,
  114, 91, 45, 49, 93, 32, 121, 10, 45, 105, 102, 32, 123, 36, 105, 114,
  62, 49, 38, 38, 40, 36, 105, 114, 37, 50, 41, 125, 32, 45, 114, 91,
  45, 49, 93, 32, 49, 48, 48, 37, 44, 123, 104, 45, 49, 125, 44, 49,
  44, 49, 44, 48, 44, 48, 44, 48, 44, 49, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 10, 45, 101,
  110, 100, 105, 102, 10, 100, 105, 118, 101, 114, 103, 101, 110, 99, 101, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117,
  116, 101, 32, 100, 105, 118, 101, 114, 103, 101, 110, 99, 101, 32, 111, 102,
  32, 118, 101, 99, 116, 111, 114, 32, 102, 105, 101, 108, 100, 36, 63, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 115, 61,
  61, 49, 125, 32, 45, 103, 32, 120, 44, 48, 10, 45, 101, 108, 105, 102,
  32, 123, 115, 61, 61, 50, 125, 32, 45, 115, 32, 99, 32, 45, 103, 91,
  45, 50, 93, 32, 120, 44, 48, 32, 45, 103, 91, 45, 49, 93, 32, 121,
  44, 48, 32, 45, 43, 10, 45, 101, 108, 105, 102, 32, 123, 115, 61, 61,
  51, 125, 32, 45, 115, 32, 99, 32, 45, 103, 91, 45, 51, 93, 32, 120,
  44, 48, 32, 45, 103, 91, 45, 50, 93, 32, 121, 44, 48, 32, 45, 103,
  91, 45, 49, 93, 32, 122, 44, 48, 32, 45, 43, 10, 45, 101, 108, 115,
  101, 32, 45, 101, 114, 114, 111, 114, 91, 93, 32, 34, 67, 97, 110, 110,
  111, 116, 32, 99, 111, 109, 112, 117, 116, 101, 32, 100, 105, 118, 101, 114,
  103, 101, 110, 99, 101, 32, 111, 102, 32, 105, 109, 97, 103, 101, 32, 91,
  34, 36, 62, 34, 93, 32, 40, 104, 97, 115, 32, 34, 123, 115, 125, 34,
  62, 51, 32, 99, 104, 97, 110, 110, 101, 108, 115, 41, 46, 34, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 100, 111, 103, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 36, 123, 49, 61, 50, 37, 125, 62, 61, 48, 32,
  38, 38, 32, 36, 123, 50, 61, 51, 37, 125, 62, 61, 48, 34, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32,
  100, 105, 102, 102, 101, 114, 101, 110, 99, 101, 32, 111, 102, 32, 103, 97,
  117, 115, 115, 105, 97, 110, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 119, 105, 116, 104, 32, 115, 116, 97, 110, 100, 97, 114, 100,
  32, 100, 101, 118, 105, 97, 116, 105, 111, 110, 115, 32, 36, 49, 32, 97,
  110, 100, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 91,
  48, 93, 32, 45, 112, 97, 114, 97, 108, 108, 101, 108, 32, 34, 45, 98,
  91, 48, 93, 32, 36, 49, 34, 44, 34, 45, 98, 91, 49, 93, 32, 36,
  50, 34, 32, 45, 45, 32, 45, 110, 111, 114, 109, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 100, 105, 102,
  102, 117, 115, 105, 111, 110, 116, 101, 110, 115, 111, 114, 115, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 48, 46, 55, 125,
  62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 48, 46, 51, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 50, 60, 61, 49, 34, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 51, 61, 48, 46, 54, 125, 44, 36, 123, 52, 61,
  49, 46, 49, 125, 44, 36, 123, 53, 61, 48, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 100, 105, 102,
  102, 117, 115, 105, 111, 110, 32, 116, 101, 110, 115, 111, 114, 115, 32, 102,
  111, 114, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104,
  32, 115, 104, 97, 114, 112, 110, 101, 115, 115, 32, 36, 49, 44, 32, 97,
  110, 105, 115, 111, 116, 114, 111, 112, 121, 32, 36, 50, 44, 32, 97, 108,
  112, 104, 97, 32, 36, 51, 32, 97, 110, 100, 32, 115, 105, 103, 109, 97,
  32, 36, 52, 46, 34, 10, 45, 118, 32, 45, 10, 112, 49, 61, 123, 105,
  102, 40, 36, 53, 44, 48, 46, 53, 44, 49, 41, 42, 109, 97, 120, 40,
  36, 49, 44, 49, 101, 45, 53, 41, 125, 10, 112, 50, 61, 123, 36, 112,
  49, 47, 40, 49, 101, 45, 55, 43, 49, 45, 36, 50, 41, 125, 10, 45,
  98, 32, 36, 51, 32, 45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 115,
  116, 114, 117, 99, 116, 117, 114, 101, 116, 101, 110, 115, 111, 114, 115, 32,
  50, 32, 45, 98, 32, 36, 52, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 101, 105, 103, 101, 110,
  32, 45, 109, 97, 120, 91, 45, 50, 93, 32, 48, 10, 45, 105, 102, 32,
  123, 115, 61, 61, 50, 125, 32, 45, 115, 91, 45, 50, 93, 32, 99, 32,
  45, 43, 91, 45, 51, 44, 45, 50, 93, 32, 45, 43, 91, 45, 50, 93,
  32, 49, 32, 45, 45, 94, 91, 45, 50, 93, 32, 45, 36, 112, 49, 32,
  45, 94, 91, 45, 51, 93, 32, 45, 36, 112, 50, 32, 45, 97, 91, 45,
  51, 44, 45, 49, 93, 32, 99, 10, 45, 101, 108, 115, 101, 32, 45, 115,
  91, 45, 50, 93, 32, 99, 32, 45, 43, 91, 45, 52, 45, 45, 50, 93,
  32, 45, 43, 91, 45, 50, 93, 32, 49, 32, 45, 45, 94, 91, 45, 50,
  93, 32, 45, 36, 112, 49, 32, 45, 114, 91, 45, 49, 93, 32, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 50, 32, 45,
  94, 91, 45, 51, 93, 32, 45, 36, 112, 50, 32, 45, 97, 91, 45, 51,
  44, 45, 49, 93, 32, 99, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  105, 103, 101, 110, 50, 116, 101, 110, 115, 111, 114, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 101, 100, 103,
  101, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49,
  53, 37, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 69, 115, 116,
  105, 109, 97, 116, 101, 32, 105, 109, 97, 103, 101, 32, 99, 111, 110, 116,
  111, 117, 114, 115, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 119, 105, 116, 104, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32,
  36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 103, 114, 97, 100, 105,
  101, 110, 116, 95, 110, 111, 114, 109, 32, 45, 98, 32, 48, 46, 53, 32,
  45, 103, 101, 32, 36, 49, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101,
  32, 48, 32, 45, 101, 113, 117, 97, 108, 105, 122, 101, 32, 45, 110, 101,
  103, 97, 116, 105, 118, 101, 32, 45, 99, 32, 51, 48, 37, 44, 55, 48,
  37, 32, 45, 110, 32, 48, 44, 49, 32, 45, 118, 32, 43, 10, 101, 114,
  111, 100, 101, 95, 99, 105, 114, 99, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 36, 49, 62, 61, 48, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  50, 61, 49, 125, 44, 36, 123, 51, 61, 48, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 105, 114, 99, 117,
  108, 97, 114, 32, 101, 114, 111, 115, 105, 111, 110, 32, 111, 102, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 98, 121, 32, 115, 105, 122, 101, 32, 36,
  49, 44, 32, 98, 111, 117, 110, 100, 97, 114, 121, 32, 36, 50, 32, 97,
  110, 100, 32, 105, 115, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 100,
  32, 36, 51, 46, 34, 10, 45, 105, 102, 32, 123, 36, 49, 60, 50, 125,
  32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 118, 32, 45, 32, 45, 95, 100, 116, 95, 99, 105, 114, 99, 108, 101,
  91, 93, 32, 36, 49, 32, 45, 101, 114, 111, 100, 101, 91, 94, 45, 49,
  93, 32, 91, 45, 49, 93, 44, 36, 50, 44, 36, 51, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 118, 32, 43, 10, 101, 114, 111, 100, 101, 95,
  111, 99, 116, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 49, 62,
  61, 48, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 49, 125, 44,
  36, 123, 51, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  65, 112, 112, 108, 121, 32, 111, 99, 116, 97, 103, 111, 110, 97, 108, 32,
  101, 114, 111, 115, 105, 111, 110, 32, 111, 102, 32, 105, 109, 97, 103, 101,
  36, 63, 32, 98, 121, 32, 115, 105, 122, 101, 32, 36, 49, 44, 32, 98,
  111, 117, 110, 100, 97, 114, 121, 32, 36, 50, 32, 97, 110, 100, 32, 105,
  115, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 100, 32, 36, 51, 46,
  34, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 123, 36, 49, 60, 50,
  125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 49, 38, 49, 125, 32, 115, 115, 61, 123,
  36, 49, 125, 32, 45, 101, 108, 115, 101, 32, 115, 115, 61, 123, 36, 49,
  43, 49, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 91, 48, 93,
  32, 40, 48, 44, 49, 44, 48, 59, 49, 44, 49, 44, 49, 59, 48, 44,
  49, 44, 48, 41, 32, 45, 105, 91, 49, 93, 32, 40, 49, 44, 49, 44,
  49, 59, 49, 44, 49, 44, 49, 59, 49, 44, 49, 44, 49, 41, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 50, 125, 10, 114, 61,
  123, 114, 111, 117, 110, 100, 40, 40, 36, 115, 115, 45, 49, 41, 42, 115,
  113, 114, 116, 40, 50, 41, 47, 40, 49, 43, 115, 113, 114, 116, 40, 50,
  41, 41, 47, 50, 41, 125, 10, 113, 61, 123, 114, 111, 117, 110, 100, 40,
  40, 36, 115, 115, 45, 49, 41, 47, 40, 49, 43, 115, 113, 114, 116, 40,
  50, 41, 41, 47, 50, 41, 125, 10, 45, 105, 102, 32, 123, 36, 114, 62,
  48, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 114, 32, 45, 101,
  114, 111, 100, 101, 91, 45, 49, 93, 32, 91, 48, 93, 44, 36, 50, 44,
  36, 51, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 113, 62, 48, 125, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 36, 113, 32, 45, 101, 114, 111, 100, 101, 91, 45, 49, 93,
  32, 91, 49, 93, 44, 36, 50, 44, 36, 51, 32, 45, 100, 111, 110, 101,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 109, 118, 91, 45, 49, 93, 32,
  50, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 44, 49, 93,
  32, 45, 118, 32, 43, 10, 103, 114, 97, 100, 105, 101, 110, 116, 95, 111,
  114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 36, 123, 49, 61, 51, 125, 61, 61, 49, 32, 124,
  124, 32, 36, 49, 61, 61, 50, 32, 124, 124, 32, 36, 49, 61, 61, 51,
  34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117,
  116, 101, 32, 36, 49, 45, 100, 32, 103, 114, 97, 100, 105, 101, 110, 116,
  32, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 32, 111, 102, 32,
  105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 60, 93,
  10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 32, 45, 103, 32,
  120, 32, 45, 45, 97, 98, 115, 91, 45, 49, 93, 32, 45, 43, 91, 45,
  49, 93, 32, 49, 101, 45, 56, 32, 45, 47, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 61, 61, 50, 125, 32, 45, 103, 32, 120, 121, 32, 45,
  45, 115, 113, 114, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  43, 91, 45, 49, 93, 32, 49, 101, 45, 56, 32, 45, 115, 113, 114, 116,
  91, 45, 49, 93, 32, 45, 47, 91, 45, 51, 93, 32, 91, 45, 49, 93,
  32, 45, 47, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 108, 115, 101,
  32, 45, 103, 32, 120, 121, 122, 32, 45, 45, 115, 113, 114, 32, 45, 43,
  91, 45, 51, 45, 45, 49, 93, 32, 45, 43, 91, 45, 49, 93, 32, 49,
  101, 45, 56, 32, 45, 115, 113, 114, 116, 91, 45, 49, 93, 32, 45, 47,
  91, 45, 52, 44, 45, 51, 93, 32, 91, 45, 49, 93, 32, 45, 47, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 103,
  114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 32, 58, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32,
  103, 114, 97, 100, 105, 101, 110, 116, 32, 110, 111, 114, 109, 32, 111, 102,
  32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 45, 103, 32, 120, 32, 45, 115, 113, 114, 91, 45, 49, 93,
  10, 45, 45, 103, 91, 45, 50, 93, 32, 121, 32, 45, 115, 113, 114, 91,
  45, 49, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 103,
  91, 45, 50, 93, 32, 122, 32, 45, 115, 113, 114, 91, 45, 50, 93, 32,
  45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 115, 61, 123, 115, 125, 32,
  45, 115, 91, 45, 49, 93, 32, 99, 32, 45, 43, 91, 45, 36, 115, 45,
  45, 49, 93, 32, 45, 115, 113, 114, 116, 91, 45, 49, 93, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 104,
  97, 97, 114, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115,
  105, 110, 116, 40, 36, 123, 49, 61, 49, 125, 41, 32, 38, 38, 32, 36,
  49, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67,
  111, 109, 112, 117, 116, 101, 32, 104, 97, 97, 114, 32, 116, 114, 97, 110,
  115, 102, 111, 114, 109, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63,
  32, 119, 105, 116, 104, 32, 36, 49, 32, 115, 99, 97, 108, 101, 115, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 95, 104, 97, 97, 114, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 49, 45, 49, 125, 10, 119,
  61, 123, 109, 97, 120, 40, 48, 44, 114, 111, 117, 110, 100, 40, 119, 47,
  50, 94, 40, 49, 43, 36, 62, 41, 41, 45, 49, 41, 125, 10, 104, 61,
  123, 109, 97, 120, 40, 48, 44, 114, 111, 117, 110, 100, 40, 104, 47, 50,
  94, 40, 49, 43, 36, 62, 41, 41, 45, 49, 41, 125, 10, 100, 61, 123,
  109, 97, 120, 40, 48, 44, 114, 111, 117, 110, 100, 40, 100, 47, 50, 94,
  40, 49, 43, 36, 62, 41, 41, 45, 49, 41, 125, 10, 45, 45, 122, 32,
  48, 44, 48, 44, 48, 44, 36, 119, 44, 36, 104, 44, 36, 100, 32, 45,
  95, 104, 97, 97, 114, 91, 45, 49, 93, 32, 45, 106, 91, 45, 50, 93,
  32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 100,
  111, 110, 101, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 95, 104, 97, 97, 114, 32, 58, 10, 45, 95, 104,
  97, 97, 114, 95, 120, 32, 45, 95, 104, 97, 97, 114, 95, 121, 32, 45,
  95, 104, 97, 97, 114, 95, 122, 10, 95, 104, 97, 97, 114, 95, 120, 32,
  58, 10, 45, 105, 102, 32, 123, 119, 60, 61, 49, 125, 32, 45, 114, 101,
  116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 119, 37, 50, 125, 32, 45, 101, 114, 114, 111, 114, 91, 48, 45, 45,
  54, 93, 32, 34, 73, 110, 118, 97, 108, 105, 100, 32, 105, 109, 97, 103,
  101, 32, 119, 105, 100, 116, 104, 61, 34, 123, 119, 125, 34, 32, 40, 105,
  115, 32, 110, 111, 116, 32, 101, 118, 101, 110, 41, 46, 34, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 45, 115, 104, 105, 102, 116, 32, 45, 49, 32,
  45, 114, 32, 53, 48, 37, 32, 45, 45, 45, 91, 49, 93, 32, 91, 48,
  93, 32, 45, 43, 91, 48, 44, 49, 93, 32, 45, 47, 32, 123, 115, 113,
  114, 116, 40, 50, 41, 125, 32, 45, 97, 32, 120, 10, 95, 104, 97, 97,
  114, 95, 121, 32, 58, 10, 45, 105, 102, 32, 123, 104, 60, 61, 49, 125,
  32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 104, 37, 50, 125, 32, 45, 101, 114, 114, 111, 114,
  91, 48, 45, 45, 54, 93, 32, 34, 73, 110, 118, 97, 108, 105, 100, 32,
  105, 109, 97, 103, 101, 32, 104, 101, 105, 103, 104, 116, 61, 34, 123, 104,
  125, 34, 32, 40, 105, 115, 32, 110, 111, 116, 32, 101, 118, 101, 110, 41,
  46, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 115, 104, 105, 102,
  116, 32, 48, 44, 45, 49, 32, 45, 114, 32, 49, 48, 48, 37, 44, 53,
  48, 37, 32, 45, 45, 45, 91, 49, 93, 32, 91, 48, 93, 32, 45, 43,
  91, 48, 44, 49, 93, 32, 45, 47, 32, 123, 115, 113, 114, 116, 40, 50,
  41, 125, 32, 45, 97, 32, 121, 10, 95, 104, 97, 97, 114, 95, 122, 32,
  58, 10, 45, 105, 102, 32, 123, 100, 60, 61, 49, 125, 32, 45, 114, 101,
  116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 100, 37, 50, 125, 32, 45, 101, 114, 114, 111, 114, 91, 48, 45, 45,
  54, 93, 32, 34, 73, 110, 118, 97, 108, 105, 100, 32, 105, 109, 97, 103,
  101, 32, 100, 101, 112, 116, 104, 61, 34, 123, 104, 125, 34, 32, 40, 105,
  115, 32, 110, 111, 116, 32, 101, 118, 101, 110, 41, 46, 34, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 45, 115, 104, 105, 102, 116, 32, 48, 44, 48,
  44, 45, 49, 32, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 53, 48, 37, 32, 45, 45, 45, 91, 49, 93, 32, 91, 48, 93, 32,
  45, 43, 91, 48, 44, 49, 93, 32, 45, 47, 32, 123, 115, 113, 114, 116,
  40, 50, 41, 125, 32, 45, 97, 32, 122, 10, 104, 101, 97, 116, 95, 102,
  108, 111, 119, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  49, 48, 125, 44, 36, 123, 50, 61, 51, 48, 125, 44, 36, 123, 51, 61,
  48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108,
  121, 32, 36, 49, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32,
  111, 102, 32, 116, 104, 101, 32, 104, 101, 97, 116, 32, 102, 108, 111, 119,
  32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116,
  104, 32, 116, 105, 109, 101, 32, 115, 116, 101, 112, 32, 36, 50, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 112, 100, 101, 95, 102, 108, 111, 119, 32,
  36, 49, 44, 36, 50, 44, 108, 97, 112, 108, 97, 99, 105, 97, 110, 44,
  36, 51, 32, 45, 118, 32, 43, 10, 105, 101, 101, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 103,
  114, 97, 100, 105, 101, 110, 116, 45, 111, 114, 116, 104, 111, 103, 111, 110,
  97, 108, 45, 100, 105, 114, 101, 99, 116, 101, 100, 32, 50, 110, 100, 32,
  100, 101, 114, 105, 118, 97, 116, 105, 118, 101, 32, 111, 102, 32, 105, 109,
  97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45,
  105, 102, 32, 123, 100, 61, 61, 49, 125, 10, 45, 45, 103, 32, 120, 121,
  44, 48, 32, 45, 104, 101, 115, 115, 105, 97, 110, 91, 45, 51, 93, 32,
  120, 120, 120, 121, 121, 121, 10, 45, 42, 91, 45, 51, 93, 32, 91, 45,
  50, 93, 32, 45, 42, 91, 45, 52, 93, 32, 91, 45, 49, 93, 32, 45,
  42, 91, 45, 52, 93, 32, 45, 50, 10, 45, 43, 91, 45, 52, 44, 45,
  51, 93, 32, 45, 42, 91, 45, 51, 93, 32, 91, 45, 50, 93, 10, 45,
  115, 113, 114, 91, 45, 50, 44, 45, 49, 93, 32, 45, 42, 91, 45, 52,
  93, 32, 91, 45, 49, 93, 32, 45, 43, 91, 45, 52, 44, 45, 51, 93,
  10, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 43, 91, 45, 49,
  93, 32, 49, 101, 45, 56, 32, 45, 47, 10, 45, 101, 108, 115, 101, 10,
  45, 45, 105, 110, 110, 32, 45, 108, 97, 112, 108, 97, 99, 105, 97, 110,
  91, 45, 50, 93, 32, 45, 45, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  105, 104, 97, 97, 114, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 49, 125, 41, 32, 38, 38,
  32, 36, 49, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 67, 111, 109, 112, 117, 116, 101, 32, 105, 110, 118, 101, 114, 115, 101,
  32, 104, 97, 97, 114, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32,
  111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 32, 119, 105, 116, 104, 32,
  36, 49, 32, 115, 99, 97, 108, 101, 115, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 49, 45, 49,
  125, 10, 119, 61, 123, 109, 97, 120, 40, 48, 44, 114, 111, 117, 110, 100,
  40, 119, 47, 50, 94, 40, 49, 43, 36, 60, 41, 41, 45, 49, 41, 125,
  10, 104, 61, 123, 109, 97, 120, 40, 48, 44, 114, 111, 117, 110, 100, 40,
  104, 47, 50, 94, 40, 49, 43, 36, 60, 41, 41, 45, 49, 41, 125, 10,
  100, 61, 123, 109, 97, 120, 40, 48, 44, 114, 111, 117, 110, 100, 40, 100,
  47, 50, 94, 40, 49, 43, 36, 60, 41, 41, 45, 49, 41, 125, 10, 45,
  45, 122, 32, 48, 44, 48, 44, 48, 44, 36, 119, 44, 36, 104, 44, 36,
  100, 32, 45, 95, 105, 104, 97, 97, 114, 91, 45, 49, 93, 32, 45, 106,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 100, 111, 110, 101, 10, 45, 95, 105, 104, 97, 97, 114, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 95, 105, 104, 97, 97, 114, 32, 58, 10, 45, 95, 105, 104, 97, 97,
  114, 95, 120, 32, 45, 95, 105, 104, 97, 97, 114, 95, 121, 32, 45, 95,
  105, 104, 97, 97, 114, 95, 122, 10, 95, 105, 104, 97, 97, 114, 95, 120,
  32, 58, 10, 45, 105, 102, 32, 123, 119, 60, 61, 49, 125, 32, 45, 114,
  101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 119, 37, 50, 125, 32, 45, 101, 114, 114, 111, 114, 91, 48, 45,
  45, 54, 93, 32, 34, 73, 110, 118, 97, 108, 105, 100, 32, 105, 109, 97,
  103, 101, 32, 119, 105, 100, 116, 104, 61, 34, 123, 119, 125, 34, 32, 40,
  105, 115, 32, 110, 111, 116, 32, 101, 118, 101, 110, 41, 46, 34, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 115, 32, 120, 44, 50, 32, 45, 114, 32,
  50, 48, 48, 37, 32, 40, 45, 49, 44, 49, 41, 32, 45, 42, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 43, 32, 45, 47, 32, 123, 115, 113, 114,
  116, 40, 50, 41, 125, 10, 95, 105, 104, 97, 97, 114, 95, 121, 32, 58,
  10, 45, 105, 102, 32, 123, 104, 60, 61, 49, 125, 32, 45, 114, 101, 116,
  117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  104, 37, 50, 125, 32, 45, 101, 114, 114, 111, 114, 32, 34, 73, 110, 118,
  97, 108, 105, 100, 32, 105, 109, 97, 103, 101, 32, 104, 101, 105, 103, 104,
  116, 61, 34, 123, 104, 125, 34, 32, 40, 105, 115, 32, 110, 111, 116, 32,
  101, 118, 101, 110, 41, 46, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  115, 32, 121, 44, 50, 32, 45, 114, 32, 49, 48, 48, 37, 44, 50, 48,
  48, 37, 32, 40, 45, 49, 59, 49, 41, 32, 45, 114, 91, 45, 49, 93,
  32, 64, 123, 45, 50, 44, 119, 125, 32, 45, 42, 91, 45, 50, 44, 45,
  49, 93, 32, 45, 43, 32, 45, 47, 32, 123, 115, 113, 114, 116, 40, 50,
  41, 125, 10, 95, 105, 104, 97, 97, 114, 95, 122, 32, 58, 10, 45, 105,
  102, 32, 123, 100, 60, 61, 49, 125, 32, 45, 114, 101, 116, 117, 114, 110,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 100, 37, 50,
  125, 32, 45, 101, 114, 114, 111, 114, 32, 34, 73, 110, 118, 97, 108, 105,
  100, 32, 105, 109, 97, 103, 101, 32, 100, 101, 112, 116, 104, 61, 34, 123,
  104, 125, 34, 32, 40, 105, 115, 32, 110, 111, 116, 32, 101, 118, 101, 110,
  41, 46, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 115, 32, 122, 44,
  50, 32, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 50,
  48, 48, 37, 32, 40, 45, 49, 47, 49, 41, 32, 45, 114, 91, 45, 49,
  93, 32, 64, 123, 45, 50, 44, 119, 125, 44, 64, 123, 45, 50, 44, 104,
  125, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 43, 32, 45,
  47, 32, 123, 115, 113, 114, 116, 40, 50, 41, 125, 10, 105, 110, 110, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117,
  116, 101, 32, 103, 114, 97, 100, 105, 101, 110, 116, 45, 100, 105, 114, 101,
  99, 116, 101, 100, 32, 50, 110, 100, 32, 100, 101, 114, 105, 118, 97, 116,
  105, 118, 101, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 100, 61, 61,
  49, 125, 10, 45, 45, 103, 32, 120, 121, 44, 48, 32, 45, 104, 101, 115,
  115, 105, 97, 110, 91, 45, 51, 93, 32, 120, 120, 120, 121, 121, 121, 10,
  45, 42, 91, 45, 53, 93, 32, 91, 45, 50, 93, 32, 45, 42, 91, 45,
  52, 93, 32, 91, 45, 49, 93, 32, 45, 42, 91, 45, 52, 93, 32, 50,
  10, 45, 43, 91, 45, 53, 44, 45, 52, 93, 32, 45, 42, 91, 45, 52,
  93, 32, 91, 45, 50, 93, 10, 45, 115, 113, 114, 91, 45, 50, 44, 45,
  49, 93, 32, 45, 42, 91, 45, 51, 93, 32, 91, 45, 49, 93, 32, 45,
  43, 91, 45, 52, 44, 45, 51, 93, 10, 45, 43, 91, 45, 50, 44, 45,
  49, 93, 32, 45, 43, 91, 45, 49, 93, 32, 49, 101, 45, 56, 32, 45,
  47, 10, 45, 101, 108, 115, 101, 10, 45, 45, 103, 32, 120, 121, 122, 44,
  48, 32, 45, 104, 101, 115, 115, 105, 97, 110, 91, 45, 52, 93, 32, 120,
  120, 120, 121, 120, 122, 121, 121, 121, 122, 122, 122, 10, 45, 42, 91, 45,
  57, 93, 32, 91, 45, 51, 93, 32, 45, 42, 91, 45, 56, 93, 32, 91,
  45, 50, 93, 32, 45, 42, 91, 45, 56, 93, 32, 50, 32, 45, 42, 91,
  45, 55, 93, 32, 91, 45, 49, 93, 32, 45, 42, 91, 45, 55, 93, 32,
  50, 10, 45, 43, 91, 45, 57, 45, 45, 55, 93, 32, 45, 42, 91, 45,
  55, 93, 32, 91, 45, 51, 93, 10, 45, 42, 91, 45, 54, 93, 32, 91,
  45, 50, 93, 32, 45, 42, 91, 45, 53, 93, 32, 91, 45, 49, 93, 32,
  45, 42, 91, 45, 53, 93, 32, 50, 10, 45, 43, 91, 45, 54, 44, 45,
  53, 93, 32, 45, 42, 91, 45, 53, 93, 32, 91, 45, 50, 93, 32, 45,
  43, 91, 45, 54, 44, 45, 53, 93, 10, 45, 115, 113, 114, 91, 45, 51,
  45, 45, 49, 93, 32, 45, 42, 91, 45, 52, 93, 32, 91, 45, 49, 93,
  32, 45, 43, 91, 45, 53, 44, 45, 52, 93, 10, 45, 43, 91, 45, 51,
  45, 45, 49, 93, 32, 45, 43, 91, 45, 49, 93, 32, 49, 101, 45, 56,
  32, 45, 47, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 105, 110, 112, 97,
  105, 110, 116, 95, 102, 108, 111, 119, 32, 58, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 49, 61, 52, 125, 44, 36, 123, 50, 61, 49, 53, 125, 44,
  36, 123, 51, 61, 49, 53, 125, 44, 36, 123, 52, 61, 49, 125, 44, 36,
  123, 53, 61, 51, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65,
  112, 112, 108, 121, 32, 36, 49, 32, 105, 116, 101, 114, 97, 116, 105, 111,
  110, 32, 111, 102, 32, 116, 104, 101, 32, 105, 110, 112, 97, 105, 110, 116,
  105, 110, 103, 32, 102, 108, 111, 119, 32, 111, 110, 32, 105, 109, 97, 103,
  101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 110, 111, 114, 109,
  91, 48, 93, 32, 45, 113, 117, 97, 110, 116, 105, 122, 101, 91, 48, 93,
  32, 50, 44, 49, 44, 49, 32, 45, 110, 91, 48, 93, 32, 48, 44, 49,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 105, 102, 32,
  36, 62, 32, 45, 108, 91, 48, 44, 36, 62, 93, 10, 45, 114, 91, 48,
  93, 32, 91, 49, 93, 32, 45, 105, 110, 112, 97, 105, 110, 116, 91, 49,
  93, 32, 91, 48, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49,
  32, 45, 45, 100, 105, 102, 102, 117, 115, 105, 111, 110, 116, 101, 110, 115,
  111, 114, 115, 91, 49, 93, 32, 48, 44, 49, 44, 36, 52, 44, 36, 53,
  44, 48, 32, 45, 42, 91, 50, 93, 32, 91, 48, 93, 32, 45, 115, 109,
  111, 111, 116, 104, 91, 49, 93, 32, 91, 50, 93, 44, 36, 50, 44, 36,
  51, 44, 48, 32, 45, 114, 109, 91, 50, 93, 32, 45, 100, 111, 110, 101,
  10, 45, 101, 110, 100, 108, 32, 45, 101, 110, 100, 105, 102, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 107, 117, 119, 97, 104, 97, 114,
  97, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 49, 62, 48, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 75,
  117, 119, 97, 104, 97, 114, 97, 32, 102, 105, 108, 116, 101, 114, 32, 111,
  102, 32, 115, 105, 122, 101, 32, 36, 49, 32, 111, 110, 32, 105, 109, 97,
  103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 115, 61,
  123, 115, 125, 10, 45, 45, 100, 105, 108, 97, 116, 101, 32, 36, 49, 32,
  45, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 91, 45, 49, 93, 32, 109, 105, 110, 10, 45, 45, 101, 114, 111, 100,
  101, 91, 48, 93, 32, 36, 49, 32, 45, 99, 111, 109, 112, 111, 115, 101,
  95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 109, 97,
  120, 10, 45, 45, 91, 45, 50, 44, 45, 49, 93, 10, 36, 49, 44, 49,
  44, 49, 44, 49, 44, 123, 49, 47, 36, 49, 125, 32, 45, 99, 111, 110,
  118, 111, 108, 118, 101, 91, 48, 93, 32, 91, 45, 49, 93, 32, 45, 116,
  114, 97, 110, 115, 112, 111, 115, 101, 91, 45, 49, 93, 32, 45, 99, 111,
  110, 118, 111, 108, 118, 101, 91, 48, 93, 32, 91, 45, 49, 93, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 112, 61, 123, 105, 110, 116, 40, 36, 49,
  47, 50, 41, 125, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99,
  10, 45, 102, 32, 34, 118, 49, 61, 105, 40, 120, 45, 34, 36, 112, 34,
  44, 121, 45, 34, 36, 112, 34, 44, 48, 44, 34, 36, 115, 34, 44, 48,
  44, 49, 41, 59, 32, 92, 10, 118, 50, 61, 105, 40, 120, 43, 34, 36,
  112, 34, 44, 121, 45, 34, 36, 112, 34, 44, 48, 44, 34, 36, 115, 34,
  44, 48, 44, 49, 41, 59, 32, 92, 10, 118, 51, 61, 105, 40, 120, 45,
  34, 36, 112, 34, 44, 121, 43, 34, 36, 112, 34, 44, 48, 44, 34, 36,
  115, 34, 44, 48, 44, 49, 41, 59, 32, 92, 10, 118, 52, 61, 105, 40,
  120, 43, 34, 36, 112, 34, 44, 121, 43, 34, 36, 112, 34, 44, 48, 44,
  34, 36, 115, 34, 44, 48, 44, 49, 41, 59, 32, 92, 10, 118, 109, 61,
  109, 105, 110, 40, 118, 49, 44, 118, 50, 44, 118, 51, 44, 118, 52, 41,
  59, 32, 92, 10, 105, 102, 40, 99, 62, 61, 34, 36, 115, 34, 44, 105,
  44, 32, 92, 10, 105, 102, 40, 118, 109, 61, 61, 118, 49, 44, 105, 40,
  120, 45, 34, 36, 112, 34, 44, 121, 45, 34, 36, 112, 34, 44, 48, 44,
  99, 44, 48, 44, 49, 41, 44, 10, 105, 102, 40, 118, 109, 61, 61, 118,
  50, 44, 105, 40, 120, 43, 34, 36, 112, 34, 44, 121, 45, 34, 36, 112,
  34, 44, 48, 44, 99, 44, 48, 44, 49, 41, 44, 10, 105, 102, 40, 118,
  109, 61, 61, 118, 51, 44, 105, 40, 120, 45, 34, 36, 112, 34, 44, 121,
  43, 34, 36, 112, 34, 44, 48, 44, 99, 44, 48, 44, 49, 41, 44, 10,
  105, 40, 120, 43, 34, 36, 112, 34, 44, 121, 43, 34, 36, 112, 34, 44,
  48, 44, 99, 44, 48, 44, 49, 41, 41, 41, 41, 41, 34, 10, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 48, 44, 123, 115, 45, 50, 125, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 108, 97, 112, 108, 97, 99, 105, 97, 110, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 76, 97,
  112, 108, 97, 99, 105, 97, 110, 32, 111, 102, 32, 105, 109, 97, 103, 101,
  32, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 104, 101,
  115, 115, 105, 97, 110, 32, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43,
  40, 100, 61, 61, 49, 41, 44, 120, 120, 121, 121, 122, 122, 44, 120, 120,
  121, 121, 125, 32, 45, 43, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 108, 105, 99, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 49, 61, 51, 48, 125, 44, 36, 123, 50, 61,
  49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 110, 100,
  101, 114, 32, 76, 73, 67, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116,
  97, 116, 105, 111, 110, 32, 111, 102, 32, 50, 100, 32, 118, 101, 99, 116,
  111, 114, 32, 102, 105, 101, 108, 100, 36, 63, 44, 32, 119, 105, 116, 104,
  32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 36, 49, 32, 97, 110,
  100, 32, 36, 50, 32, 99, 104, 97, 110, 110, 101, 108, 40, 115, 41, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44,
  110, 125, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48, 44, 49,
  32, 45, 47, 32, 123, 109, 97, 120, 40, 97, 98, 115, 40, 64, 123, 45,
  49, 44, 109, 125, 41, 44, 97, 98, 115, 40, 64, 123, 45, 49, 44, 77,
  125, 41, 41, 125, 32, 45, 118, 101, 99, 116, 111, 114, 50, 116, 101, 110,
  115, 111, 114, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 36, 50, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 32, 45, 115, 109, 111, 111, 116, 104, 91, 45, 49,
  93, 32, 91, 45, 50, 93, 44, 36, 49, 32, 45, 114, 109, 91, 45, 50,
  93, 10, 45, 101, 113, 117, 97, 108, 105, 122, 101, 10, 45, 110, 109, 32,
  36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 109, 97, 112, 95, 116, 111, 110, 101, 115,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 46, 49,
  125, 44, 36, 123, 50, 61, 48, 46, 56, 125, 44, 36, 123, 51, 61, 48,
  46, 53, 125, 44, 36, 123, 52, 61, 51, 48, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 116, 111, 110, 101, 32,
  109, 97, 112, 112, 105, 110, 103, 32, 111, 112, 101, 114, 97, 116, 111, 114,
  32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116,
  104, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 36, 49, 44, 32,
  103, 97, 109, 109, 97, 32, 36, 50, 44, 32, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 36, 51, 32, 97, 110, 100, 32, 36, 52, 32, 105,
  116, 101, 114, 97, 116, 105, 111, 110, 115, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 45, 45, 108, 32, 45, 115, 32, 99, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 103,
  32, 120, 121, 44, 49, 32, 45, 97, 32, 99, 32, 45, 45, 110, 111, 114,
  109, 32, 45, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 91, 45,
  50, 93, 10, 109, 61, 123, 105, 109, 125, 32, 77, 61, 123, 105, 77, 125,
  32, 45, 98, 91, 45, 49, 93, 32, 36, 51, 32, 45, 110, 91, 45, 49,
  93, 32, 36, 109, 44, 36, 77, 10, 45, 42, 91, 45, 49, 93, 32, 39,
  97, 108, 112, 104, 97, 61, 36, 49, 42, 105, 77, 59, 40, 97, 108, 112,
  104, 97, 47, 40, 49, 101, 45, 49, 48, 43, 105, 41, 41, 42, 40, 105,
  47, 40, 49, 101, 45, 49, 48, 43, 97, 108, 112, 104, 97, 41, 41, 94,
  36, 50, 39, 10, 45, 42, 32, 45, 115, 32, 99, 32, 45, 103, 91, 45,
  50, 93, 32, 120, 44, 45, 49, 32, 45, 103, 91, 45, 49, 93, 32, 121,
  44, 45, 49, 32, 45, 43, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 97, 32, 99, 32, 45, 42, 32, 48, 46, 50, 53, 32,
  45, 101, 110, 100, 108, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 52,
  32, 45, 45, 108, 97, 112, 108, 97, 99, 105, 97, 110, 91, 45, 50, 93,
  32, 45, 42, 91, 45, 49, 93, 32, 48, 46, 50, 53, 32, 45, 43, 91,
  45, 49, 93, 32, 91, 45, 51, 93, 32, 45, 45, 91, 45, 49, 93, 32,
  91, 45, 50, 93, 32, 45, 42, 91, 45, 49, 93, 32, 56, 48, 48, 32,
  45, 43, 91, 45, 51, 44, 45, 49, 93, 32, 45, 47, 91, 45, 50, 93,
  32, 56, 48, 49, 32, 45, 99, 91, 45, 50, 93, 32, 48, 44, 50, 53,
  53, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 32, 45, 118, 32,
  43, 10, 109, 97, 112, 95, 116, 111, 110, 101, 115, 95, 102, 97, 115, 116,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 51,
  37, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 48, 46, 51,
  125, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65,
  112, 112, 108, 121, 32, 102, 97, 115, 116, 32, 116, 111, 110, 101, 32, 109,
  97, 112, 112, 105, 110, 103, 32, 111, 112, 101, 114, 97, 116, 111, 114, 32,
  111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104,
  32, 114, 97, 100, 105, 117, 115, 32, 36, 49, 32, 97, 110, 100, 32, 112,
  111, 119, 101, 114, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 98, 91,
  45, 49, 93, 32, 36, 49, 32, 45, 110, 32, 48, 44, 49, 10, 45, 45,
  42, 91, 45, 49, 93, 32, 50, 32, 45, 45, 91, 45, 49, 93, 32, 49,
  32, 45, 97, 98, 115, 91, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93,
  32, 123, 36, 50, 42, 108, 111, 103, 40, 49, 48, 41, 125, 32, 45, 101,
  120, 112, 91, 45, 49, 93, 10, 45, 108, 101, 91, 45, 50, 93, 32, 48,
  46, 53, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 51, 93, 10, 45,
  45, 42, 91, 45, 51, 93, 32, 45, 49, 32, 45, 43, 91, 45, 49, 93,
  32, 49, 32, 45, 94, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45,
  42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 43, 91, 45, 49, 93, 32,
  49, 32, 45, 42, 91, 45, 49, 93, 32, 91, 45, 51, 93, 10, 45, 94,
  91, 45, 52, 44, 45, 50, 93, 32, 45, 101, 113, 91, 45, 50, 93, 32,
  48, 32, 45, 42, 91, 45, 51, 44, 45, 50, 93, 32, 45, 43, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 110, 32, 48, 44,
  50, 53, 53, 32, 45, 118, 32, 43, 10, 109, 101, 97, 110, 99, 117, 114,
  118, 97, 116, 117, 114, 101, 95, 102, 108, 111, 119, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 49, 61, 49, 48, 125, 44, 36, 123, 50, 61,
  51, 48, 125, 44, 36, 123, 51, 61, 48, 125, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 36, 49, 32, 105, 116, 101,
  114, 97, 116, 105, 111, 110, 115, 32, 111, 102, 32, 116, 104, 101, 32, 109,
  101, 97, 110, 32, 99, 117, 114, 118, 97, 116, 117, 114, 101, 32, 102, 108,
  111, 119, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119,
  105, 116, 104, 32, 116, 105, 109, 101, 32, 115, 116, 101, 112, 32, 36, 50,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 112, 100, 101, 95, 102, 108, 111,
  119, 32, 36, 49, 44, 36, 50, 44, 105, 101, 101, 44, 36, 51, 32, 45,
  118, 32, 43, 10, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 108, 111,
  99, 97, 108, 32, 58, 10, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123,
  49, 61, 51, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 49,
  54, 125, 62, 48, 32, 38, 38, 32, 105, 115, 98, 111, 111, 108, 40, 36,
  123, 53, 61, 49, 125, 41, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  51, 61, 52, 37, 125, 44, 36, 123, 52, 61, 50, 37, 125, 44, 36, 123,
  54, 61, 48, 125, 44, 36, 123, 55, 61, 50, 53, 53, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 78, 111, 114, 109, 97, 108, 105, 122, 101,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 108, 111, 99, 97, 108, 108, 121,
  44, 32, 119, 105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101,
  32, 36, 49, 44, 32, 114, 97, 100, 105, 117, 115, 32, 36, 50, 44, 32,
  110, 101, 105, 103, 104, 98, 111, 114, 104, 111, 111, 100, 32, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 36, 51, 32, 97, 110, 100, 32, 97,
  118, 101, 114, 97, 103, 101, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 36, 52, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45,
  108, 32, 45, 101, 114, 111, 100, 101, 32, 123, 50, 42, 36, 50, 43, 49,
  125, 32, 45, 115, 32, 99, 32, 45, 109, 105, 110, 32, 45, 101, 110, 100,
  108, 10, 45, 45, 108, 91, 45, 50, 93, 32, 45, 100, 105, 108, 97, 116,
  101, 32, 123, 50, 42, 36, 50, 43, 49, 125, 32, 45, 115, 32, 99, 32,
  45, 109, 97, 120, 32, 45, 101, 110, 100, 108, 10, 45, 45, 98, 91, 45,
  51, 93, 32, 36, 52, 32, 45, 98, 91, 45, 51, 44, 45, 50, 93, 32,
  36, 51, 10, 45, 45, 45, 91, 45, 50, 93, 32, 91, 45, 51, 93, 32,
  45, 43, 91, 45, 49, 93, 32, 48, 46, 48, 49, 32, 45, 45, 91, 45,
  53, 93, 32, 91, 45, 52, 93, 32, 45, 47, 91, 45, 53, 44, 45, 49,
  93, 10, 45, 42, 91, 45, 51, 44, 45, 50, 93, 32, 123, 36, 49, 43,
  49, 125, 32, 45, 42, 91, 45, 49, 93, 32, 45, 36, 49, 32, 45, 43,
  91, 45, 51, 93, 32, 91, 45, 49, 93, 32, 45, 43, 91, 45, 50, 44,
  45, 49, 93, 10, 45, 105, 102, 32, 36, 53, 32, 45, 109, 97, 120, 91,
  45, 50, 93, 32, 36, 54, 32, 45, 109, 105, 110, 91, 45, 49, 93, 32,
  36, 55, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 32, 45, 42, 91, 45, 51, 44, 45, 49, 93, 32,
  45, 43, 10, 45, 105, 102, 32, 36, 53, 32, 45, 99, 32, 36, 54, 44,
  36, 55, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 110, 111, 114, 109, 97,
  108, 105, 122, 101, 100, 95, 99, 114, 111, 115, 115, 95, 99, 111, 114, 114,
  101, 108, 97, 116, 105, 111, 110, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 110, 111, 114, 109, 97,
  108, 105, 122, 101, 100, 32, 99, 114, 111, 115, 115, 45, 99, 111, 114, 114,
  101, 108, 97, 116, 105, 111, 110, 32, 117, 115, 105, 110, 103, 32, 116, 119,
  111, 45, 98, 121, 45, 116, 119, 111, 32, 105, 109, 97, 103, 101, 36, 63,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 110, 111, 114, 109, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41,
  125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10,
  45, 102, 102, 116, 91, 45, 50, 93, 32, 45, 102, 102, 116, 91, 45, 49,
  93, 32, 91, 45, 50, 44, 45, 49, 93, 32, 45, 109, 117, 108, 91, 45,
  50, 93, 32, 91, 45, 53, 93, 32, 45, 109, 117, 108, 91, 45, 49, 93,
  32, 91, 45, 54, 93, 10, 45, 45, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 42, 91, 45, 53, 44, 45, 51, 93, 32, 45, 42, 91, 45, 51, 44,
  45, 50, 93, 32, 45, 43, 91, 45, 51, 44, 45, 50, 93, 32, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32,
  99, 32, 45, 110, 111, 114, 109, 91, 45, 49, 93, 10, 45, 47, 91, 45,
  51, 93, 32, 91, 45, 49, 93, 32, 45, 47, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 105, 102, 102, 116, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 112, 104, 97, 115, 101, 95, 99, 111, 114, 114, 101, 108, 97, 116, 105,
  111, 110, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 69, 115,
  116, 105, 109, 97, 116, 101, 32, 116, 114, 97, 110, 115, 108, 97, 116, 105,
  111, 110, 32, 118, 101, 99, 116, 111, 114, 32, 117, 115, 105, 110, 103, 32,
  116, 119, 111, 45, 98, 121, 45, 116, 119, 111, 32, 105, 109, 97, 103, 101,
  36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108,
  91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 45, 110, 111, 114,
  109, 97, 108, 105, 122, 101, 100, 95, 99, 114, 111, 115, 115, 95, 99, 111,
  114, 114, 101, 108, 97, 116, 105, 111, 110, 10, 40, 64, 123, 45, 49, 44,
  67, 125, 41, 32, 45, 42, 91, 45, 49, 93, 32, 50, 32, 45, 115, 91,
  45, 49, 93, 32, 120, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 105,
  102, 32, 123, 64, 45, 51, 62, 64, 123, 45, 52, 44, 119, 125, 125, 32,
  45, 45, 91, 45, 51, 93, 32, 64, 123, 45, 52, 44, 119, 125, 32, 45,
  45, 91, 45, 51, 93, 32, 64, 123, 45, 52, 44, 119, 125, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64, 45, 50, 62, 64, 123,
  45, 52, 44, 104, 125, 125, 32, 45, 45, 91, 45, 50, 93, 32, 64, 123,
  45, 52, 44, 104, 125, 32, 45, 45, 91, 45, 50, 93, 32, 64, 123, 45,
  52, 44, 104, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 64, 45, 49, 62, 64, 123, 45, 52, 44, 100, 125, 125, 32, 45, 45,
  91, 45, 49, 93, 32, 64, 123, 45, 52, 44, 100, 125, 32, 45, 45, 91,
  45, 49, 93, 32, 64, 123, 45, 52, 44, 100, 125, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 99, 32, 45,
  114, 109, 91, 45, 50, 93, 32, 45, 47, 32, 50, 32, 45, 42, 32, 45,
  49, 10, 45, 110, 109, 32, 91, 112, 104, 97, 115, 101, 92, 32, 99, 111,
  114, 114, 101, 108, 97, 116, 105, 111, 110, 93, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 112, 100, 101, 95,
  102, 108, 111, 119, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49,
  61, 49, 48, 125, 44, 36, 123, 50, 61, 51, 48, 125, 44, 36, 123, 51,
  61, 108, 97, 112, 108, 97, 99, 105, 97, 110, 125, 44, 36, 123, 52, 61,
  48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108,
  121, 32, 36, 49, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32,
  111, 102, 32, 116, 104, 101, 32, 118, 101, 108, 111, 99, 105, 116, 121, 32,
  102, 108, 111, 119, 32, 39, 36, 51, 39, 32, 111, 110, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 116, 105, 109, 101, 32,
  115, 116, 101, 112, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 60, 93,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 10, 45, 45, 36, 51,
  91, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 123, 36, 50, 47,
  40, 48, 46, 48, 49, 43, 109, 97, 120, 40, 97, 98, 115, 40, 105, 109,
  41, 44, 97, 98, 115, 40, 105, 77, 41, 41, 41, 125, 10, 45, 105, 102,
  32, 36, 52, 32, 45, 43, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32,
  45, 101, 108, 115, 101, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 105, 102,
  32, 36, 52, 32, 45, 114, 109, 91, 48, 93, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 97, 32, 120, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 45, 105, 102, 32, 36, 52, 32, 45, 115, 32, 120, 44, 36,
  49, 32, 45, 101, 110, 100, 105, 102, 32, 45, 118, 32, 43, 10, 114, 101,
  100, 95, 101, 121, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  49, 61, 55, 53, 125, 44, 36, 123, 50, 61, 51, 46, 53, 125, 44, 36,
  123, 51, 61, 48, 46, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 65, 116, 116, 101, 110, 117, 97, 116, 101, 32, 114, 101, 100, 45, 101,
  121, 101, 32, 101, 102, 102, 101, 99, 116, 32, 105, 110, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 116, 104, 114, 101, 115,
  104, 111, 108, 100, 32, 36, 49, 44, 32, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 36, 50, 32, 97, 110, 100, 32, 97, 116, 116, 101, 110,
  117, 97, 116, 105, 111, 110, 32, 36, 51, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 114, 103, 98, 50, 121, 99,
  98, 99, 114, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 115, 32, 99, 32, 45, 45, 91, 45, 49,
  93, 32, 49, 50, 56, 32, 45, 45, 103, 101, 91, 45, 49, 93, 32, 36,
  49, 37, 32, 45, 98, 91, 45, 49, 93, 32, 36, 50, 32, 45, 115, 113,
  114, 116, 91, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49,
  32, 45, 43, 91, 45, 49, 93, 32, 49, 10, 45, 110, 91, 45, 49, 93,
  32, 36, 51, 44, 49, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 43, 91, 45, 49, 93, 32, 49, 50, 56, 32, 45, 97, 32, 99, 32,
  45, 121, 99, 98, 99, 114, 50, 114, 103, 98, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 114, 101, 109, 111,
  118, 101, 95, 104, 111, 116, 112, 105, 120, 101, 108, 115, 32, 58, 32, 45,
  99, 104, 101, 99, 107, 32, 36, 123, 49, 61, 51, 125, 62, 48, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 50, 61, 49, 48, 37, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 82, 101, 109, 111, 118, 101, 32, 104, 111,
  116, 32, 112, 105, 120, 101, 108, 115, 32, 105, 110, 32, 105, 109, 97, 103,
  101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 109, 97, 115, 107, 32, 115,
  105, 122, 101, 32, 36, 49, 32, 97, 110, 100, 32, 116, 104, 114, 101, 115,
  104, 111, 108, 100, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 45, 109, 101, 100, 105, 97, 110, 32, 36, 49, 32, 45, 45, 45,
  32, 45, 97, 98, 115, 91, 45, 49, 93, 32, 45, 103, 101, 91, 45, 49,
  93, 32, 36, 50, 10, 45, 42, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  32, 45, 61, 61, 91, 45, 49, 93, 32, 48, 32, 45, 42, 91, 45, 51,
  44, 45, 49, 93, 32, 45, 43, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 114, 101, 109, 111, 118, 101, 95,
  112, 105, 120, 101, 108, 115, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 36, 123, 49, 61, 49, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36,
  123, 50, 61, 48, 125, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 82, 101, 109, 111, 118, 101, 32, 36, 49, 37, 32, 111, 102,
  32, 110, 111, 110, 45, 122, 101, 114, 111, 32, 112, 105, 120, 101, 108, 115,
  32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 45, 110, 111, 114, 109, 32, 45, 103, 116, 91,
  45, 49, 93, 32, 48, 10, 45, 105, 102, 32, 36, 50, 32, 114, 97, 116,
  101, 61, 123, 36, 49, 42, 36, 50, 47, 109, 97, 120, 40, 49, 101, 45,
  56, 44, 64, 123, 45, 49, 44, 43, 125, 41, 125, 10, 45, 101, 108, 115,
  101, 32, 114, 97, 116, 101, 61, 123, 36, 49, 42, 119, 42, 104, 47, 109,
  97, 120, 40, 49, 101, 45, 56, 44, 64, 123, 45, 49, 44, 43, 125, 41,
  125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 49, 93,
  10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 114, 97, 110, 100,
  91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 103, 101, 91, 45, 49, 93,
  32, 36, 114, 97, 116, 101, 37, 32, 45, 42, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 115, 112, 108, 105,
  116, 95, 102, 114, 101, 113, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 83, 112, 108, 105, 116, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  105, 110, 116, 111, 32, 108, 111, 119, 32, 97, 110, 100, 32, 104, 105, 103,
  104, 32, 102, 114, 101, 113, 117, 101, 110, 99, 121, 32, 112, 97, 114, 116,
  115, 44, 32, 119, 105, 116, 104, 32, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45,
  45, 98, 32, 36, 49, 32, 45, 45, 91, 48, 93, 32, 91, 49, 93, 32,
  45, 114, 118, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 115, 111, 108, 105, 100, 105, 102, 121, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 112, 108, 97, 99, 101,
  32, 116, 114, 97, 110, 115, 112, 97, 114, 101, 110, 116, 32, 114, 101, 103,
  105, 111, 110, 115, 32, 111, 102, 32, 82, 71, 66, 65, 32, 105, 109, 97,
  103, 101, 36, 63, 32, 98, 121, 32, 109, 111, 114, 112, 104, 111, 108, 111,
  103, 105, 99, 97, 108, 108, 121, 32, 105, 110, 116, 101, 114, 112, 111, 108,
  97, 116, 101, 100, 32, 99, 111, 108, 111, 114, 115, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 32, 45,
  116, 111, 95, 97, 10, 91, 45, 49, 93, 32, 45, 115, 112, 108, 105, 116,
  95, 111, 112, 97, 99, 105, 116, 121, 91, 45, 50, 93, 32, 45, 103, 101,
  91, 45, 50, 93, 32, 53, 48, 37, 32, 45, 42, 91, 45, 49, 93, 32,
  91, 45, 50, 93, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111,
  108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 45, 49, 44, 45, 49, 44, 45, 49, 44, 45, 49, 32,
  45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10, 45, 100, 111, 10,
  45, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51, 10, 45,
  114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 45, 50,
  93, 32, 48, 44, 48, 44, 45, 49, 44, 45, 49, 44, 45, 49, 44, 49,
  48, 48, 48, 44, 49, 48, 48, 48, 44, 49, 48, 48, 48, 10, 45, 101,
  114, 111, 100, 101, 91, 45, 50, 93, 32, 51, 10, 45, 114, 101, 112, 108,
  97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 45, 50, 93, 32, 48, 44,
  48, 44, 49, 48, 48, 48, 44, 49, 48, 48, 48, 44, 49, 48, 48, 48,
  44, 45, 49, 44, 45, 49, 44, 45, 49, 10, 45, 43, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 47, 91, 45, 49, 93, 32, 50, 10, 45, 106, 91,
  45, 49, 93, 32, 91, 45, 51, 93, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 49, 44, 91, 45, 50, 93, 10, 45, 119, 104, 105, 108, 101, 32, 123,
  105, 109, 60, 48, 125, 10, 45, 107, 91, 45, 49, 93, 10, 45, 110, 109,
  32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 115, 111, 108, 105, 100, 105, 102, 121,
  95, 108, 105, 110, 101, 97, 114, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 34, 36, 123, 49, 61, 49, 46, 53, 125, 62, 61, 49, 32, 38, 38,
  32, 36, 123, 50, 61, 49, 125, 62, 61, 49, 32, 38, 38, 32, 36, 123,
  51, 61, 48, 46, 53, 125, 62, 61, 48, 32, 38, 38, 32, 36, 51, 60,
  61, 49, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 112,
  108, 97, 99, 101, 32, 116, 114, 97, 110, 115, 112, 97, 114, 101, 110, 116,
  32, 114, 101, 103, 105, 111, 110, 115, 32, 111, 102, 32, 82, 71, 66, 65,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 98, 121, 32, 108, 105, 110, 101,
  97, 114, 108, 121, 32, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 101,
  100, 32, 99, 111, 108, 111, 114, 115, 44, 32, 119, 105, 116, 104, 32, 115,
  105, 103, 109, 97, 32, 36, 49, 44, 32, 100, 115, 105, 103, 109, 97, 32,
  36, 50, 32, 97, 110, 100, 32, 112, 114, 101, 99, 105, 115, 105, 111, 110,
  32, 36, 51, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 112,
  108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 10, 45, 105, 102, 32,
  123, 64, 35, 62, 49, 125, 10, 45, 103, 101, 91, 45, 49, 93, 32, 53,
  48, 37, 32, 45, 42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 10, 115,
  105, 103, 109, 97, 61, 36, 49, 32, 45, 100, 111, 10, 78, 61, 123, 118,
  61, 114, 111, 117, 110, 100, 40, 51, 42, 36, 115, 105, 103, 109, 97, 41,
  59, 109, 105, 110, 40, 51, 51, 44, 109, 97, 120, 40, 51, 44, 118, 43,
  49, 45, 40, 118, 37, 50, 41, 41, 41, 125, 10, 36, 78, 44, 36, 78,
  32, 45, 61, 91, 45, 49, 93, 32, 49, 44, 53, 48, 37, 44, 53, 48,
  37, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32,
  49, 32, 45, 42, 91, 45, 49, 93, 32, 123, 45, 49, 47, 36, 115, 105,
  103, 109, 97, 94, 50, 125, 32, 45, 101, 120, 112, 91, 45, 49, 93, 32,
  45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 115, 117, 109, 91, 45,
  49, 93, 10, 45, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 45, 51,
  44, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 51,
  93, 10, 45, 109, 97, 120, 91, 45, 49, 93, 32, 49, 101, 45, 53, 32,
  45, 47, 91, 45, 50, 44, 45, 49, 93, 10, 45, 45, 100, 105, 108, 97,
  116, 101, 91, 45, 50, 93, 32, 123, 118, 61, 114, 111, 117, 110, 100, 40,
  40, 49, 47, 51, 45, 36, 78, 47, 54, 41, 42, 36, 51, 43, 36, 78,
  47, 50, 41, 59, 109, 97, 120, 40, 51, 44, 118, 43, 49, 45, 40, 118,
  37, 50, 41, 41, 125, 10, 45, 45, 91, 45, 51, 93, 32, 91, 45, 49,
  93, 32, 45, 42, 91, 45, 50, 93, 32, 91, 45, 51, 93, 32, 45, 114,
  109, 91, 45, 51, 93, 10, 45, 45, 91, 45, 51, 44, 45, 50, 93, 10,
  115, 105, 103, 109, 97, 61, 123, 36, 115, 105, 103, 109, 97, 42, 36, 50,
  125, 10, 45, 119, 104, 105, 108, 101, 32, 123, 33, 105, 109, 125, 10, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 115,
  111, 108, 105, 100, 105, 102, 121, 95, 119, 97, 116, 101, 114, 115, 104, 101,
  100, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 112,
  108, 97, 99, 101, 32, 116, 114, 97, 110, 115, 112, 97, 114, 101, 110, 116,
  32, 114, 101, 103, 105, 111, 110, 115, 32, 111, 102, 32, 82, 71, 66, 65,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 98, 121, 32, 99, 111, 108, 111,
  114, 32, 112, 114, 111, 112, 97, 103, 97, 116, 105, 111, 110, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 115, 112, 108, 105, 116, 95, 111, 112,
  97, 99, 105, 116, 121, 10, 45, 105, 102, 32, 123, 64, 35, 62, 49, 125,
  10, 45, 43, 91, 48, 93, 32, 49, 32, 45, 103, 101, 91, 49, 93, 32,
  53, 48, 37, 32, 45, 42, 91, 48, 93, 32, 91, 49, 93, 32, 45, 100,
  105, 115, 116, 97, 110, 99, 101, 91, 49, 93, 32, 49, 32, 45, 42, 91,
  49, 93, 32, 45, 49, 10, 45, 119, 97, 116, 101, 114, 115, 104, 101, 100,
  91, 48, 93, 32, 91, 49, 93, 32, 45, 114, 109, 91, 49, 93, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 115, 111, 108, 118, 101, 95, 112, 111, 105,
  115, 115, 111, 110, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36,
  123, 50, 61, 54, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 51,
  61, 53, 125, 62, 48, 32, 38, 38, 32, 36, 123, 52, 61, 48, 125, 62,
  61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 83, 111, 108,
  118, 101, 32, 80, 111, 105, 115, 115, 111, 110, 32, 101, 113, 117, 97, 116,
  105, 111, 110, 32, 102, 111, 114, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 102, 111, 114, 32, 108, 97, 112, 108, 97, 99, 105, 97, 110, 32, 99,
  111, 109, 109, 97, 110, 100, 32, 39, 36, 49, 39, 44, 32, 119, 105, 116,
  104, 32, 36, 50, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 44,
  32, 116, 105, 109, 101, 32, 115, 116, 101, 112, 32, 36, 51, 32, 97, 110,
  100, 32, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 40, 36, 52,
  61, 61, 48, 41, 44, 36, 52, 44, 97, 117, 116, 111, 125, 34, 32, 115,
  99, 97, 108, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 91,
  48, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 102, 40, 36,
  52, 44, 36, 52, 44, 105, 110, 116, 40, 109, 97, 120, 40, 108, 111, 103,
  50, 40, 109, 97, 120, 40, 119, 44, 104, 41, 41, 45, 49, 44, 49, 41,
  41, 41, 125, 10, 102, 61, 123, 50, 94, 36, 60, 125, 10, 45, 114, 91,
  49, 93, 32, 64, 123, 48, 44, 109, 97, 120, 40, 49, 44, 119, 47, 36,
  102, 41, 125, 44, 64, 123, 48, 44, 109, 97, 120, 40, 49, 44, 104, 47,
  36, 102, 41, 125, 44, 49, 44, 49, 48, 48, 37, 44, 51, 10, 45, 45,
  114, 91, 48, 93, 32, 91, 49, 93, 44, 50, 32, 45, 108, 91, 45, 49,
  93, 32, 45, 36, 49, 32, 45, 107, 91, 48, 93, 32, 45, 101, 110, 100,
  108, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 50, 32, 45, 45, 108,
  97, 112, 108, 97, 99, 105, 97, 110, 91, 45, 50, 93, 32, 45, 45, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 42, 91, 45, 49, 93, 32,
  123, 36, 51, 47, 109, 97, 120, 40, 49, 101, 45, 56, 44, 97, 98, 115,
  40, 105, 109, 41, 44, 97, 98, 115, 40, 105, 77, 41, 41, 125, 32, 45,
  43, 91, 45, 51, 44, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109,
  91, 48, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 115, 112, 108, 105, 116, 95, 100, 101, 116, 97, 105,
  108, 115, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105,
  110, 116, 40, 36, 123, 49, 61, 52, 125, 41, 32, 38, 38, 32, 36, 49,
  62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 50, 37, 125, 62, 61, 48,
  32, 38, 38, 32, 36, 123, 51, 61, 48, 46, 53, 37, 125, 62, 61, 48,
  34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 83, 112, 108, 105, 116,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 117, 115, 105, 110, 103, 32, 36,
  49, 32, 115, 112, 97, 116, 105, 97, 108, 32, 115, 99, 97, 108, 101, 115,
  32, 119, 105, 116, 104, 32, 98, 97, 115, 101, 32, 115, 99, 97, 108, 101,
  32, 36, 50, 32, 97, 110, 100, 32, 100, 101, 116, 97, 105, 108, 32, 115,
  99, 97, 108, 101, 32, 36, 51, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 60, 93,
  10, 115, 115, 61, 123, 109, 97, 120, 40, 48, 46, 51, 44, 105, 102, 40,
  64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36,
  50, 125, 44, 36, 50, 42, 109, 97, 120, 40, 119, 44, 104, 41, 44, 36,
  50, 41, 41, 125, 10, 115, 101, 61, 123, 109, 97, 120, 40, 48, 46, 51,
  44, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110,
  116, 92, 32, 36, 51, 125, 44, 36, 51, 42, 109, 97, 120, 40, 119, 44,
  104, 41, 44, 36, 51, 41, 41, 125, 10, 100, 115, 61, 123, 36, 115, 101,
  45, 36, 115, 115, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36,
  49, 45, 49, 125, 32, 45, 45, 98, 91, 45, 49, 93, 32, 123, 36, 115,
  115, 43, 36, 62, 42, 36, 100, 115, 47, 40, 36, 49, 45, 50, 41, 125,
  32, 45, 45, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 118,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 116,
  118, 95, 102, 108, 111, 119, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 49, 61, 49, 48, 125, 44, 36, 123, 50, 61, 51, 48, 125, 44, 36,
  123, 51, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65,
  112, 112, 108, 121, 32, 36, 49, 32, 105, 116, 101, 114, 97, 116, 105, 111,
  110, 115, 32, 111, 102, 32, 116, 104, 101, 32, 116, 111, 116, 97, 108, 32,
  118, 97, 114, 105, 97, 116, 105, 111, 110, 32, 102, 108, 111, 119, 32, 111,
  110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32,
  116, 105, 109, 101, 32, 115, 116, 101, 112, 32, 36, 50, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 112, 100, 101, 95, 102, 108, 111, 119, 32, 36, 49,
  44, 36, 50, 44, 99, 117, 114, 118, 97, 116, 117, 114, 101, 44, 36, 51,
  32, 45, 118, 32, 43, 10, 117, 110, 115, 104, 97, 114, 112, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 50, 61, 50, 125, 62, 61,
  48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 48, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 117,
  110, 115, 104, 97, 114, 112, 32, 109, 97, 115, 107, 32, 111, 110, 32, 105,
  109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 114, 97, 100,
  105, 117, 115, 32, 36, 49, 44, 32, 97, 109, 111, 117, 110, 116, 32, 36,
  50, 32, 97, 110, 100, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32,
  36, 51, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 10, 45, 45, 98, 91, 36, 62, 93, 32, 36, 49, 32,
  45, 45, 91, 45, 49, 93, 32, 91, 36, 62, 93, 10, 45, 105, 102, 32,
  36, 51, 32, 45, 45, 110, 111, 114, 109, 91, 45, 49, 93, 32, 45, 103,
  101, 91, 45, 49, 93, 32, 36, 51, 32, 45, 42, 91, 45, 50, 44, 45,
  49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 42, 91, 45, 49, 93,
  32, 36, 50, 32, 45, 45, 91, 36, 62, 44, 45, 49, 93, 10, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 117, 110, 115, 104, 97, 114, 112,
  95, 111, 99, 116, 97, 118, 101, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 34, 36, 123, 49, 61, 52, 125, 62, 48, 32, 38, 38, 32, 36, 123,
  51, 61, 50, 125, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 50, 61, 49, 125, 44, 36, 123, 52, 61, 48, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 111, 99, 116, 97,
  118, 101, 32, 115, 104, 97, 114, 112, 101, 110, 105, 110, 103, 32, 111, 110,
  32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 36,
  49, 32, 115, 99, 97, 108, 101, 115, 44, 32, 114, 97, 100, 105, 117, 115,
  32, 36, 50, 44, 32, 97, 109, 111, 117, 110, 116, 32, 36, 51, 32, 97,
  110, 100, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 36, 52, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44,
  110, 125, 10, 45, 45, 102, 32, 48, 32, 119, 101, 105, 103, 104, 116, 61,
  48, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 10, 45, 45, 117,
  110, 115, 104, 97, 114, 112, 91, 48, 93, 32, 123, 36, 50, 42, 50, 94,
  45, 64, 123, 60, 44, 45, 49, 125, 125, 44, 36, 51, 44, 36, 52, 32,
  45, 42, 91, 45, 49, 93, 32, 123, 50, 94, 45, 36, 62, 125, 32, 119,
  101, 105, 103, 104, 116, 61, 123, 36, 119, 101, 105, 103, 104, 116, 43, 50,
  94, 45, 36, 62, 125, 32, 45, 43, 91, 49, 44, 45, 49, 93, 10, 45,
  100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 93, 32, 45, 47, 32, 36,
  119, 101, 105, 103, 104, 116, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 119, 97, 116, 101, 114, 109, 97, 114, 107, 95, 102, 111, 117, 114,
  105, 101, 114, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 123, 50,
  61, 51, 50, 125, 62, 48, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  65, 100, 100, 32, 116, 101, 120, 116, 117, 97, 108, 32, 119, 97, 116, 101,
  114, 109, 97, 114, 107, 32, 39, 36, 49, 39, 32, 119, 105, 116, 104, 32,
  115, 105, 122, 101, 32, 36, 50, 32, 105, 110, 32, 116, 104, 101, 32, 102,
  114, 101, 113, 117, 101, 110, 99, 121, 32, 100, 111, 109, 97, 105, 110, 32,
  111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 105, 91, 48, 93, 32, 48, 32, 45, 116, 91, 48, 93, 32,
  34, 36, 49, 34, 44, 48, 44, 48, 44, 36, 50, 44, 49, 44, 49, 32,
  45, 103, 101, 91, 48, 93, 32, 48, 46, 53, 32, 45, 97, 117, 116, 111,
  99, 114, 111, 112, 91, 48, 93, 32, 48, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 64, 35, 45, 49, 125, 32, 119, 50, 61, 123, 105, 110, 116,
  40, 119, 47, 50, 41, 125, 32, 104, 50, 61, 123, 105, 110, 116, 40, 104,
  47, 50, 41, 125, 10, 45, 102, 102, 116, 91, 45, 49, 93, 10, 45, 115,
  104, 105, 102, 116, 91, 45, 50, 44, 45, 49, 93, 32, 36, 119, 50, 44,
  36, 104, 50, 44, 48, 44, 48, 44, 50, 10, 91, 48, 93, 44, 91, 48,
  93, 44, 49, 44, 123, 115, 125, 10, 45, 106, 91, 45, 51, 44, 45, 50,
  93, 32, 91, 45, 49, 93, 44, 51, 44, 51, 44, 48, 44, 48, 44, 49,
  44, 91, 48, 93, 10, 45, 109, 105, 114, 114, 111, 114, 91, 48, 93, 32,
  120, 10, 45, 106, 91, 45, 51, 44, 45, 50, 93, 32, 91, 45, 49, 93,
  44, 123, 64, 123, 45, 50, 44, 119, 125, 45, 50, 45, 64, 123, 48, 44,
  119, 125, 125, 44, 51, 44, 48, 44, 48, 44, 49, 44, 91, 48, 93, 10,
  45, 109, 105, 114, 114, 111, 114, 91, 48, 93, 32, 121, 10, 45, 106, 91,
  45, 51, 44, 45, 50, 93, 32, 91, 45, 49, 93, 44, 123, 64, 123, 45,
  50, 44, 119, 125, 45, 50, 45, 64, 123, 48, 44, 119, 125, 125, 44, 123,
  64, 123, 45, 50, 44, 104, 125, 45, 50, 45, 64, 123, 48, 44, 104, 125,
  125, 44, 48, 44, 48, 44, 49, 44, 91, 48, 93, 10, 45, 109, 105, 114,
  114, 111, 114, 91, 48, 93, 32, 120, 10, 45, 106, 91, 45, 51, 44, 45,
  50, 93, 32, 91, 45, 49, 93, 44, 51, 44, 123, 64, 123, 45, 50, 44,
  104, 125, 45, 50, 45, 64, 123, 48, 44, 104, 125, 125, 44, 48, 44, 48,
  44, 49, 44, 91, 48, 93, 10, 45, 109, 105, 114, 114, 111, 114, 91, 48,
  93, 32, 121, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 105,
  102, 116, 91, 45, 50, 44, 45, 49, 93, 32, 45, 36, 119, 50, 44, 45,
  36, 104, 50, 44, 48, 44, 48, 44, 50, 10, 45, 105, 102, 102, 116, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  109, 118, 91, 45, 49, 93, 32, 49, 32, 45, 100, 111, 110, 101, 10, 45,
  114, 109, 91, 48, 93, 32, 45, 118, 32, 43, 10, 97, 114, 101, 97, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48, 34,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 48, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 97,
  114, 101, 97, 32, 111, 102, 32, 99, 111, 110, 110, 101, 99, 116, 101, 100,
  32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 32, 105, 110, 32, 105,
  109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 116, 111, 108,
  101, 114, 97, 110, 99, 101, 32, 36, 49, 32, 97, 110, 100, 32, 34, 64,
  123, 45, 97, 114, 103, 92, 32, 49, 43, 33, 36, 50, 44, 104, 105, 103,
  104, 44, 108, 111, 119, 125, 34, 32, 99, 111, 110, 110, 101, 99, 116, 105,
  118, 105, 116, 121, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115,
  32, 99, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  97, 98, 101, 108, 91, 36, 62, 93, 32, 36, 49, 44, 36, 50, 32, 110,
  98, 61, 64, 123, 36, 62, 44, 49, 43, 105, 77, 125, 32, 45, 45, 104,
  105, 115, 116, 111, 103, 114, 97, 109, 91, 36, 62, 93, 32, 36, 110, 98,
  44, 48, 44, 123, 36, 110, 98, 45, 49, 125, 32, 45, 109, 97, 112, 91,
  36, 62, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 100, 111, 110, 101, 10, 45, 97, 32, 99, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 97, 114, 101,
  97, 95, 102, 103, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36,
  49, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61,
  48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112,
  117, 116, 101, 32, 97, 114, 101, 97, 32, 111, 102, 32, 102, 111, 114, 101,
  103, 114, 111, 117, 110, 100, 32, 99, 111, 110, 110, 101, 99, 116, 101, 100,
  32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 32, 105, 110, 32, 105,
  109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 116, 111, 108,
  101, 114, 97, 110, 99, 101, 32, 36, 49, 32, 97, 110, 100, 32, 34, 64,
  123, 45, 97, 114, 103, 92, 32, 49, 43, 33, 36, 50, 44, 104, 105, 103,
  104, 44, 108, 111, 119, 125, 34, 32, 99, 111, 110, 110, 101, 99, 116, 105,
  118, 105, 116, 121, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115,
  32, 99, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  97, 98, 101, 108, 95, 102, 103, 91, 36, 62, 93, 32, 36, 49, 44, 36,
  50, 32, 110, 98, 61, 64, 123, 36, 62, 44, 49, 43, 105, 77, 125, 32,
  45, 45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 36, 62, 93, 32,
  36, 110, 98, 44, 48, 44, 123, 36, 110, 98, 45, 49, 125, 32, 45, 61,
  91, 45, 49, 93, 32, 48, 32, 45, 109, 97, 112, 91, 36, 62, 93, 32,
  91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 100, 111,
  110, 101, 10, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 97, 116, 95, 108, 105, 110, 101,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 123, 55, 61, 49, 48,
  48, 37, 125, 62, 61, 48, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  82, 101, 116, 114, 105, 101, 118, 101, 32, 112, 105, 120, 101, 108, 115, 32,
  111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 98, 101, 108, 111,
  110, 103, 105, 110, 103, 32, 116, 111, 32, 108, 105, 110, 101, 32, 40, 36,
  49, 44, 36, 50, 44, 36, 51, 41, 45, 40, 36, 52, 44, 36, 53, 44,
  36, 54, 41, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 120, 48, 61,
  123, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110,
  116, 92, 32, 36, 49, 125, 44, 40, 119, 45, 49, 41, 42, 36, 49, 44,
  36, 49, 41, 125, 10, 121, 48, 61, 123, 105, 102, 40, 64, 123, 45, 105,
  115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 50, 125, 44, 40,
  104, 45, 49, 41, 42, 36, 50, 44, 36, 50, 41, 125, 10, 122, 48, 61,
  123, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110,
  116, 92, 32, 36, 51, 125, 44, 40, 100, 45, 49, 41, 42, 36, 51, 44,
  36, 51, 41, 125, 10, 120, 49, 61, 123, 105, 102, 40, 64, 123, 45, 105,
  115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 52, 125, 44, 40,
  119, 45, 49, 41, 42, 36, 52, 44, 36, 52, 41, 125, 10, 121, 49, 61,
  123, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110,
  116, 92, 32, 36, 53, 125, 44, 40, 104, 45, 49, 41, 42, 36, 53, 44,
  36, 53, 41, 125, 10, 122, 49, 61, 123, 105, 102, 40, 64, 123, 45, 105,
  115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 54, 125, 44, 40,
  100, 45, 49, 41, 42, 36, 54, 44, 36, 54, 41, 125, 10, 40, 36, 120,
  48, 44, 36, 120, 49, 94, 36, 121, 48, 44, 36, 121, 49, 94, 36, 122,
  48, 44, 36, 122, 49, 41, 10, 45, 114, 91, 45, 49, 93, 32, 123, 49,
  43, 109, 97, 120, 40, 97, 98, 115, 40, 36, 120, 49, 45, 36, 120, 48,
  41, 44, 97, 98, 115, 40, 36, 121, 49, 45, 36, 121, 48, 41, 44, 97,
  98, 115, 40, 36, 122, 49, 45, 36, 122, 48, 41, 41, 125, 44, 49, 44,
  49, 44, 51, 44, 51, 10, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93,
  32, 49, 32, 45, 119, 97, 114, 112, 91, 48, 93, 32, 91, 45, 49, 93,
  44, 48, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  98, 97, 114, 121, 99, 101, 110, 116, 101, 114, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 116, 104,
  101, 32, 98, 97, 114, 121, 99, 101, 110, 116, 101, 114, 32, 118, 101, 99,
  116, 111, 114, 32, 111, 102, 32, 112, 105, 120, 101, 108, 32, 118, 97, 108,
  117, 101, 115, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 110, 111, 114, 109, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109,
  61, 64, 123, 48, 44, 98, 125, 10, 115, 117, 109, 61, 64, 123, 45, 49,
  44, 43, 125, 10, 45, 105, 102, 32, 123, 36, 115, 117, 109, 62, 48, 125,
  10, 45, 105, 102, 32, 123, 100, 62, 49, 125, 32, 45, 45, 42, 32, 39,
  122, 39, 32, 122, 61, 64, 123, 45, 49, 44, 43, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 101, 108, 115, 101, 32, 122, 61, 48, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 104, 62, 49, 125, 32,
  45, 45, 42, 32, 39, 121, 39, 32, 121, 61, 64, 123, 45, 49, 44, 43,
  125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 108, 115, 101, 32,
  121, 61, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 42, 32, 39, 120,
  39, 32, 120, 61, 64, 123, 45, 49, 44, 43, 125, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 40, 123, 36, 120, 47, 36, 115, 117, 109, 125, 59, 123,
  36, 121, 47, 36, 115, 117, 109, 125, 59, 123, 36, 122, 47, 36, 115, 117,
  109, 125, 41, 10, 45, 101, 108, 115, 101, 32, 40, 123, 119, 47, 50, 125,
  44, 123, 104, 47, 50, 125, 44, 123, 100, 47, 50, 125, 41, 32, 45, 114,
  109, 91, 45, 50, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 110, 109,
  32, 34, 91, 98, 97, 114, 121, 99, 101, 110, 116, 101, 114, 32, 111, 102,
  32, 39, 34, 36, 110, 109, 34, 39, 93, 34, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 100, 101, 116, 101,
  99, 116, 95, 115, 107, 105, 110, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 34, 36, 123, 49, 61, 48, 46, 53, 125, 62, 61, 48, 32, 38, 38,
  32, 36, 49, 60, 61, 49, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  50, 61, 45, 49, 125, 44, 36, 123, 51, 61, 45, 49, 125, 44, 36, 123,
  52, 61, 45, 49, 125, 10, 45, 105, 102, 32, 123, 36, 50, 60, 48, 124,
  124, 36, 51, 60, 61, 48, 124, 124, 36, 52, 60, 61, 48, 125, 10, 45,
  101, 91, 48, 45, 45, 51, 93, 32, 34, 68, 101, 116, 101, 99, 116, 32,
  115, 107, 105, 110, 32, 105, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 117, 115, 105, 110, 103, 32, 116, 111, 108, 101, 114, 97, 110, 99, 101,
  32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 10, 109, 48, 61, 49, 50,
  48, 46, 57, 50, 57, 50, 49, 48, 56, 56, 48, 48, 48, 54, 57, 10,
  109, 49, 61, 49, 52, 50, 46, 53, 55, 52, 53, 50, 55, 50, 57, 49,
  56, 48, 56, 52, 10, 65, 61, 48, 46, 48, 57, 55, 52, 57, 57, 56,
  53, 52, 56, 54, 50, 54, 56, 57, 57, 55, 10, 66, 61, 48, 46, 48,
  54, 51, 56, 56, 56, 55, 49, 51, 55, 49, 55, 52, 54, 48, 54, 51,
  10, 67, 61, 48, 46, 48, 53, 50, 53, 48, 48, 53, 51, 49, 48, 55,
  55, 51, 56, 52, 57, 53, 10, 45, 116, 111, 95, 114, 103, 98, 32, 45,
  115, 114, 103, 98, 50, 114, 103, 98, 32, 45, 114, 103, 98, 50, 121, 99,
  98, 99, 114, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 49, 44,
  50, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 119, 104, 100, 61, 123, 119, 125, 44, 123, 104, 125, 44,
  123, 100, 125, 32, 45, 114, 32, 123, 119, 42, 104, 42, 100, 125, 44, 50,
  44, 49, 44, 49, 44, 45, 49, 10, 45, 115, 32, 121, 32, 45, 45, 91,
  48, 93, 32, 36, 109, 48, 32, 45, 45, 91, 49, 93, 32, 36, 109, 49,
  32, 45, 97, 32, 121, 10, 45, 105, 91, 48, 93, 32, 40, 36, 65, 44,
  36, 66, 59, 36, 66, 44, 36, 67, 41, 32, 45, 45, 42, 42, 32, 45,
  114, 109, 91, 48, 93, 10, 45, 42, 32, 45, 115, 32, 121, 32, 45, 43,
  32, 45, 42, 91, 45, 49, 93, 32, 123, 36, 49, 45, 49, 125, 32, 45,
  101, 120, 112, 91, 45, 49, 93, 10, 45, 114, 32, 36, 119, 104, 100, 44,
  49, 44, 45, 49, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 45, 101, 108, 115, 101, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32,
  34, 68, 101, 116, 101, 99, 116, 32, 115, 107, 105, 110, 32, 105, 110, 32,
  105, 109, 97, 103, 101, 36, 63, 44, 32, 117, 115, 105, 110, 103, 32, 116,
  111, 108, 101, 114, 97, 110, 99, 101, 32, 36, 49, 32, 97, 110, 100, 32,
  116, 97, 114, 103, 101, 116, 32, 99, 105, 114, 99, 108, 101, 32, 97, 116,
  32, 40, 36, 50, 44, 36, 51, 41, 32, 119, 105, 116, 104, 32, 114, 97,
  100, 105, 117, 115, 32, 36, 52, 46, 34, 10, 45, 118, 32, 45, 10, 45,
  116, 111, 95, 114, 103, 98, 32, 45, 115, 114, 103, 98, 50, 114, 103, 98,
  32, 45, 114, 103, 98, 50, 121, 99, 98, 99, 114, 32, 45, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 49, 44, 50, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 32, 45, 99, 105, 114, 99, 108, 101, 91, 49, 93,
  32, 36, 50, 44, 36, 51, 44, 36, 52, 44, 49, 44, 49, 32, 45, 45,
  102, 91, 49, 93, 32, 39, 105, 102, 40, 105, 44, 121, 44, 45, 49, 41,
  39, 32, 45, 102, 91, 49, 93, 32, 39, 105, 102, 40, 105, 44, 120, 44,
  45, 49, 41, 39, 32, 45, 100, 105, 115, 99, 97, 114, 100, 91, 49, 44,
  50, 93, 32, 45, 49, 32, 45, 97, 91, 49, 44, 50, 93, 32, 99, 10,
  45, 45, 119, 97, 114, 112, 91, 48, 93, 32, 91, 49, 93, 44, 48, 44,
  48, 32, 45, 114, 109, 91, 49, 93, 10, 45, 115, 91, 49, 93, 32, 99,
  10, 109, 48, 61, 64, 123, 49, 44, 105, 97, 125, 32, 45, 45, 91, 49,
  93, 32, 36, 109, 48, 10, 109, 49, 61, 64, 123, 50, 44, 105, 97, 125,
  32, 45, 45, 91, 50, 93, 32, 36, 109, 49, 10, 77, 61, 123, 104, 125,
  32, 45, 97, 91, 49, 44, 50, 93, 32, 120, 32, 45, 45, 116, 114, 97,
  110, 115, 112, 111, 115, 101, 91, 49, 93, 32, 45, 114, 118, 91, 49, 44,
  50, 93, 32, 45, 42, 42, 91, 49, 44, 50, 93, 32, 45, 47, 91, 49,
  93, 32, 36, 77, 32, 45, 105, 110, 118, 101, 114, 116, 91, 49, 93, 10,
  45, 114, 118, 32, 119, 104, 100, 61, 123, 119, 125, 44, 123, 104, 125, 44,
  123, 100, 125, 32, 45, 114, 91, 49, 93, 32, 123, 119, 42, 104, 42, 100,
  125, 44, 50, 44, 49, 44, 49, 44, 45, 49, 10, 45, 115, 91, 49, 93,
  32, 121, 32, 45, 45, 91, 49, 93, 32, 36, 109, 48, 32, 45, 45, 91,
  50, 93, 32, 36, 109, 49, 32, 45, 97, 91, 49, 44, 50, 93, 32, 121,
  32, 45, 45, 42, 42, 32, 45, 114, 109, 91, 48, 93, 10, 45, 42, 32,
  45, 115, 32, 121, 32, 45, 43, 32, 45, 42, 91, 45, 49, 93, 32, 123,
  36, 49, 45, 49, 125, 32, 45, 101, 120, 112, 91, 45, 49, 93, 10, 45,
  114, 32, 36, 119, 104, 100, 44, 49, 44, 45, 49, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  118, 32, 43, 10, 102, 108, 111, 97, 116, 50, 102, 102, 116, 56, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114,
  116, 32, 102, 108, 111, 97, 116, 45, 118, 97, 108, 117, 101, 100, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 116, 111, 32, 56, 98, 105, 116, 115, 32,
  102, 111, 117, 114, 105, 101, 114, 32, 114, 101, 112, 114, 101, 115, 101, 110,
  116, 97, 116, 105, 111, 110, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 102, 102, 116, 112, 111, 108, 97, 114, 32, 45, 43, 91, 45, 50,
  93, 32, 49, 32, 45, 108, 111, 103, 91, 45, 50, 93, 32, 45, 102, 108,
  111, 97, 116, 50, 105, 110, 116, 56, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 97, 32, 121, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 102, 102, 116, 56, 50, 102, 108, 111, 97, 116,
  32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118,
  101, 114, 116, 32, 102, 108, 111, 97, 116, 45, 118, 97, 108, 117, 101, 100,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 111, 32, 56, 98, 105, 116,
  115, 32, 102, 111, 117, 114, 105, 101, 114, 32, 114, 101, 112, 114, 101, 115,
  101, 110, 116, 97, 116, 105, 111, 110, 115, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 45, 115, 32, 121, 44, 50, 32, 45, 105, 110, 116, 56, 50,
  102, 108, 111, 97, 116, 32, 45, 101, 120, 112, 91, 45, 50, 93, 32, 45,
  45, 91, 45, 50, 93, 32, 49, 32, 45, 105, 102, 102, 116, 112, 111, 108,
  97, 114, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 102, 102, 116, 112, 111, 108, 97, 114, 32, 58, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32,
  102, 111, 117, 114, 105, 101, 114, 32, 116, 114, 97, 110, 115, 102, 111, 114,
  109, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 97, 115,
  32, 99, 101, 110, 116, 101, 114, 101, 100, 32, 109, 97, 103, 110, 105, 116,
  117, 100, 101, 47, 112, 104, 97, 115, 101, 32, 105, 109, 97, 103, 101, 115,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 60, 93, 10, 45, 102, 102, 116, 32, 45,
  99, 111, 109, 112, 108, 101, 120, 50, 112, 111, 108, 97, 114, 32, 45, 115,
  104, 105, 102, 116, 32, 123, 45, 105, 110, 116, 40, 119, 47, 50, 41, 125,
  44, 123, 45, 105, 110, 116, 40, 104, 47, 50, 41, 125, 44, 123, 45, 105,
  110, 116, 40, 100, 47, 50, 41, 125, 44, 48, 44, 50, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 104, 105,
  115, 116, 111, 103, 114, 97, 109, 51, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 36, 49, 62, 48, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50,
  61, 48, 37, 125, 44, 36, 123, 51, 61, 49, 48, 48, 37, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32,
  104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 111, 102, 32, 109, 117, 108,
  116, 105, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 105, 109, 97, 103,
  101, 36, 63, 44, 32, 117, 115, 105, 110, 103, 32, 36, 49, 32, 108, 101,
  118, 101, 108, 115, 32, 105, 110, 32, 114, 97, 110, 103, 101, 32, 91, 36,
  49, 44, 36, 50, 93, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45,
  114, 32, 123, 119, 42, 104, 42, 100, 125, 44, 123, 109, 105, 110, 40, 51,
  44, 115, 41, 125, 44, 49, 44, 49, 44, 45, 49, 32, 45, 114, 111, 117,
  110, 100, 91, 45, 49, 93, 32, 49, 10, 118, 109, 105, 110, 61, 123, 105,
  102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92,
  32, 36, 50, 125, 44, 36, 50, 42, 105, 109, 44, 36, 50, 41, 125, 32,
  118, 109, 97, 120, 61, 123, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112,
  101, 114, 99, 101, 110, 116, 92, 32, 36, 51, 125, 44, 36, 51, 42, 105,
  77, 44, 36, 51, 41, 125, 10, 45, 45, 32, 36, 118, 109, 105, 110, 32,
  45, 42, 32, 123, 40, 36, 49, 45, 49, 41, 47, 40, 36, 118, 109, 97,
  120, 45, 36, 118, 109, 105, 110, 41, 125, 10, 110, 98, 95, 108, 101, 118,
  101, 108, 115, 61, 123, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101,
  114, 99, 101, 110, 116, 92, 32, 36, 49, 125, 44, 36, 49, 42, 40, 36,
  118, 109, 97, 120, 45, 36, 118, 109, 105, 110, 41, 43, 49, 44, 36, 49,
  41, 125, 10, 45, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 32, 49,
  44, 36, 110, 98, 95, 108, 101, 118, 101, 108, 115, 44, 36, 110, 98, 95,
  108, 101, 118, 101, 108, 115, 44, 36, 110, 98, 95, 108, 101, 118, 101, 108,
  115, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 104, 105, 115, 116, 111, 103, 114, 97, 109, 95, 99, 117, 109,
  117, 108, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 123, 49, 61,
  50, 53, 54, 125, 62, 48, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50,
  61, 48, 125, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 48, 125,
  44, 36, 123, 52, 61, 48, 125, 10, 45, 97, 114, 103, 32, 49, 43, 33,
  36, 50, 44, 34, 110, 111, 114, 109, 97, 108, 105, 122, 101, 100, 32, 34,
  44, 34, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109,
  112, 117, 116, 101, 32, 34, 64, 123, 125, 34, 99, 117, 109, 117, 108, 97,
  116, 105, 118, 101, 32, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 111,
  102, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 117, 115, 105, 110, 103,
  32, 36, 49, 32, 108, 101, 118, 101, 108, 115, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 36, 49, 44,
  36, 51, 44, 36, 52, 32, 45, 99, 117, 109, 117, 108, 32, 45, 105, 102,
  32, 36, 50, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  47, 91, 36, 62, 93, 32, 64, 123, 36, 62, 44, 77, 125, 32, 45, 100,
  111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 32, 45, 118, 32, 43, 10,
  104, 105, 115, 116, 111, 103, 114, 97, 109, 95, 112, 111, 105, 110, 116, 119,
  105, 115, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61,
  48, 37, 125, 44, 36, 123, 51, 61, 49, 48, 48, 37, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 116,
  104, 101, 32, 112, 111, 105, 110, 116, 119, 105, 115, 101, 32, 104, 105, 115,
  116, 111, 103, 114, 97, 109, 32, 111, 102, 32, 118, 101, 99, 116, 111, 114,
  45, 118, 97, 108, 117, 101, 100, 32, 112, 111, 105, 110, 116, 115, 32, 105,
  110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32,
  36, 49, 32, 108, 101, 118, 101, 108, 115, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 110, 98, 95,
  108, 101, 118, 101, 108, 115, 61, 123, 114, 111, 117, 110, 100, 40, 105, 102,
  40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32,
  36, 49, 125, 44, 40, 105, 77, 45, 105, 109, 41, 42, 36, 49, 44, 36,
  49, 41, 41, 125, 10, 118, 97, 108, 117, 101, 48, 61, 123, 105, 102, 40,
  64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36,
  50, 125, 44, 105, 109, 43, 40, 105, 77, 45, 105, 109, 41, 42, 36, 50,
  44, 36, 50, 41, 125, 10, 118, 97, 108, 117, 101, 49, 61, 123, 105, 102,
  40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32,
  36, 51, 125, 44, 105, 109, 43, 40, 105, 77, 45, 105, 109, 41, 42, 36,
  51, 44, 36, 51, 41, 125, 10, 45, 45, 32, 36, 118, 97, 108, 117, 101,
  48, 32, 45, 42, 32, 123, 36, 110, 98, 95, 108, 101, 118, 101, 108, 115,
  47, 109, 97, 120, 40, 49, 44, 97, 98, 115, 40, 36, 118, 97, 108, 117,
  101, 49, 45, 36, 118, 97, 108, 117, 101, 48, 41, 41, 125, 32, 45, 99,
  32, 48, 44, 123, 36, 110, 98, 95, 108, 101, 118, 101, 108, 115, 45, 49,
  125, 32, 45, 114, 111, 117, 110, 100, 10, 119, 61, 123, 119, 125, 32, 104,
  61, 123, 104, 125, 32, 100, 61, 123, 100, 125, 32, 45, 114, 32, 123, 119,
  42, 104, 42, 100, 125, 44, 123, 115, 125, 44, 49, 44, 49, 44, 45, 49,
  10, 45, 105, 91, 45, 50, 93, 32, 40, 48, 44, 123, 119, 45, 49, 125,
  41, 32, 45, 114, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 91, 45,
  49, 93, 44, 49, 44, 49, 44, 51, 32, 45, 114, 111, 117, 110, 100, 91,
  45, 50, 93, 10, 45, 114, 91, 45, 50, 44, 45, 49, 93, 32, 51, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 52, 32, 45, 115,
  104, 105, 102, 116, 91, 45, 49, 93, 32, 49, 32, 45, 43, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 121, 91, 45, 49, 93, 10, 45, 105, 91, 45,
  50, 93, 32, 40, 123, 39, 67, 73, 109, 103, 51, 100, 39, 125, 44, 123,
  104, 47, 51, 125, 44, 123, 104, 47, 51, 125, 41, 10, 40, 49, 44, 48,
  59, 49, 44, 123, 104, 47, 51, 45, 49, 125, 41, 32, 45, 114, 91, 45,
  49, 93, 32, 50, 44, 64, 123, 45, 50, 44, 104, 47, 51, 125, 44, 49,
  44, 49, 44, 51, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 10,
  51, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 49, 32, 49, 44, 49,
  48, 48, 37, 44, 49, 44, 49, 44, 45, 49, 32, 45, 121, 91, 45, 53,
  44, 45, 51, 44, 45, 50, 93, 32, 45, 97, 91, 45, 53, 45, 45, 49,
  93, 32, 121, 10, 123, 36, 119, 42, 36, 104, 42, 36, 100, 125, 44, 36,
  110, 98, 95, 108, 101, 118, 101, 108, 115, 32, 45, 111, 98, 106, 101, 99,
  116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48,
  44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45,
  50, 93, 10, 45, 114, 32, 36, 119, 44, 36, 104, 44, 36, 100, 44, 36,
  110, 98, 95, 108, 101, 118, 101, 108, 115, 44, 45, 49, 10, 45, 110, 109,
  32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 104, 111, 117, 103, 104, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 53, 49, 50, 125,
  62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 36, 49, 125, 62, 48, 34,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 49, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 36,
  49, 120, 36, 50, 32, 104, 111, 117, 103, 104, 32, 116, 114, 97, 110, 115,
  102, 111, 114, 109, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 33, 36, 51, 44,
  119, 105, 116, 104, 44, 119, 105, 116, 104, 111, 117, 116, 125, 34, 32, 103,
  114, 97, 100, 105, 101, 110, 116, 32, 110, 111, 114, 109, 32, 118, 111, 116,
  105, 110, 103, 46, 34, 10, 45, 118, 32, 45, 32, 45, 115, 108, 105, 99,
  101, 115, 32, 53, 48, 37, 32, 45, 108, 117, 109, 105, 110, 97, 110, 99,
  101, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 114, 104,
  111, 109, 97, 120, 61, 123, 115, 113, 114, 116, 40, 119, 94, 50, 43, 104,
  94, 50, 41, 47, 50, 125, 10, 45, 103, 32, 40, 48, 44, 123, 119, 45,
  49, 125, 41, 32, 40, 48, 59, 123, 64, 123, 45, 50, 44, 104, 125, 45,
  49, 125, 41, 32, 45, 114, 91, 45, 50, 44, 45, 49, 93, 32, 64, 123,
  45, 51, 44, 119, 125, 44, 64, 123, 45, 51, 44, 104, 125, 44, 49, 44,
  49, 44, 51, 32, 45, 45, 91, 45, 50, 93, 32, 123, 119, 47, 50, 125,
  32, 45, 45, 91, 45, 49, 93, 32, 123, 104, 47, 50, 125, 10, 45, 99,
  111, 109, 112, 108, 101, 120, 50, 112, 111, 108, 97, 114, 91, 45, 52, 45,
  45, 49, 93, 32, 45, 45, 91, 45, 49, 93, 32, 91, 45, 51, 93, 32,
  45, 112, 111, 108, 97, 114, 50, 99, 111, 109, 112, 108, 101, 120, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 45,
  108, 116, 91, 45, 49, 93, 32, 48, 32, 45, 42, 91, 45, 49, 93, 32,
  123, 112, 105, 125, 32, 45, 43, 91, 45, 51, 44, 45, 49, 93, 32, 45,
  97, 98, 115, 91, 45, 49, 93, 32, 45, 37, 91, 45, 50, 93, 32, 123,
  50, 42, 112, 105, 125, 10, 45, 42, 91, 45, 49, 93, 32, 123, 36, 50,
  47, 36, 114, 104, 111, 109, 97, 120, 125, 32, 45, 42, 91, 45, 50, 93,
  32, 123, 48, 46, 53, 42, 36, 49, 47, 112, 105, 125, 10, 45, 121, 91,
  45, 51, 45, 45, 49, 93, 32, 120, 32, 123, 119, 125, 32, 45, 109, 118,
  91, 45, 52, 93, 32, 64, 35, 32, 45, 105, 102, 32, 123, 33, 36, 51,
  125, 32, 45, 102, 91, 45, 49, 93, 32, 49, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 97, 32, 121, 32, 45, 112, 111, 105, 110, 116, 99, 108, 111,
  117, 100, 32, 49, 32, 45, 114, 32, 36, 49, 44, 36, 50, 44, 49, 44,
  49, 44, 48, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 105,
  102, 102, 116, 112, 111, 108, 97, 114, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 105, 110, 118, 101,
  114, 115, 101, 32, 102, 111, 117, 114, 105, 101, 114, 32, 116, 114, 97, 110,
  115, 102, 111, 114, 109, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63,
  44, 32, 102, 114, 111, 109, 32, 99, 101, 110, 116, 101, 114, 101, 100, 32,
  109, 97, 103, 110, 105, 116, 117, 100, 101, 47, 112, 104, 97, 115, 101, 32,
  105, 109, 97, 103, 101, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41,
  125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10,
  45, 115, 104, 105, 102, 116, 32, 123, 105, 110, 116, 40, 119, 47, 50, 41,
  125, 44, 123, 105, 110, 116, 40, 104, 47, 50, 41, 125, 44, 123, 105, 110,
  116, 40, 100, 47, 50, 41, 125, 44, 48, 44, 50, 32, 45, 112, 111, 108,
  97, 114, 50, 99, 111, 109, 112, 108, 101, 120, 32, 45, 105, 102, 102, 116,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 105, 115, 111, 112, 104, 111,
  116, 101, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  54, 52, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 110,
  100, 101, 114, 32, 105, 115, 111, 112, 104, 111, 116, 101, 32, 109, 97, 112,
  115, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 115, 36, 63, 44,
  32, 119, 105, 116, 104, 32, 36, 49, 32, 108, 101, 118, 101, 108, 115, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 116, 111, 95, 114, 103, 98, 97, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 49, 32, 45, 45, 105, 115, 111, 108, 105,
  110, 101, 51, 100, 91, 49, 93, 32, 123, 36, 62, 42, 50, 53, 53, 47,
  40, 36, 49, 45, 49, 41, 125, 32, 45, 100, 111, 110, 101, 32, 45, 114,
  109, 91, 49, 93, 32, 45, 43, 51, 100, 91, 94, 48, 93, 32, 45, 99,
  111, 108, 51, 100, 91, 45, 49, 93, 32, 49, 10, 91, 48, 93, 44, 91,
  48, 93, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 44, 49, 44, 48, 44,
  48, 44, 48, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45, 42, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  108, 97, 98, 101, 108, 95, 102, 103, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 34, 36, 49, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32,
  36, 123, 50, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  76, 97, 98, 101, 108, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100,
  32, 99, 111, 110, 110, 101, 99, 116, 101, 100, 32, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 115, 32, 111, 110, 32, 105, 109, 97, 103, 101, 32, 91,
  49, 93, 44, 32, 119, 105, 116, 104, 32, 116, 111, 108, 101, 114, 97, 110,
  99, 101, 32, 36, 49, 32, 97, 110, 100, 32, 34, 64, 123, 45, 97, 114,
  103, 92, 32, 49, 43, 33, 36, 50, 44, 104, 105, 103, 104, 44, 108, 111,
  119, 125, 34, 32, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 100,
  62, 49, 125, 32, 45, 45, 122, 32, 45, 49, 44, 45, 49, 44, 45, 49,
  44, 123, 119, 45, 49, 125, 44, 123, 104, 45, 49, 125, 44, 123, 100, 45,
  49, 125, 32, 45, 108, 97, 98, 101, 108, 91, 45, 49, 93, 32, 36, 49,
  44, 36, 50, 32, 45, 122, 91, 45, 49, 93, 32, 49, 44, 49, 44, 49,
  44, 123, 119, 45, 49, 125, 44, 123, 104, 45, 49, 125, 44, 123, 100, 45,
  49, 125, 10, 45, 101, 108, 115, 101, 32, 45, 45, 122, 32, 45, 49, 44,
  45, 49, 44, 123, 119, 45, 49, 125, 44, 123, 104, 45, 49, 125, 32, 45,
  108, 97, 98, 101, 108, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 32,
  45, 122, 91, 45, 49, 93, 32, 49, 44, 49, 44, 123, 119, 45, 49, 125,
  44, 123, 104, 45, 49, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 110,
  101, 113, 91, 45, 50, 93, 32, 48, 32, 45, 42, 10, 45, 45, 104, 105,
  115, 116, 111, 103, 114, 97, 109, 32, 123, 49, 43, 105, 77, 125, 32, 45,
  110, 101, 113, 91, 45, 49, 93, 32, 48, 32, 45, 42, 91, 45, 49, 93,
  32, 39, 120, 39, 32, 45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 45,
  49, 44, 48, 32, 45, 108, 97, 98, 101, 108, 91, 45, 49, 93, 32, 45,
  114, 111, 119, 115, 91, 45, 49, 93, 32, 49, 44, 49, 10, 45, 109, 97,
  112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 109, 97, 120, 95, 112, 97, 116, 99, 104, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 123,
  49, 61, 49, 54, 125, 41, 32, 38, 38, 32, 36, 49, 62, 61, 49, 34,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 116, 117, 114, 110,
  32, 108, 111, 99, 97, 116, 105, 111, 110, 115, 32, 111, 102, 32, 109, 97,
  120, 105, 109, 97, 108, 32, 118, 97, 108, 117, 101, 115, 32, 105, 110, 32,
  108, 111, 99, 97, 108, 32, 112, 97, 116, 99, 104, 32, 110, 101, 105, 103,
  104, 98, 111, 114, 104, 111, 111, 100, 32, 111, 102, 32, 115, 105, 122, 101,
  32, 36, 49, 44, 32, 105, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 45, 100, 105, 108, 97, 116, 101, 91, 36, 62, 93, 32, 36,
  49, 32, 45, 61, 61, 91, 36, 62, 44, 45, 49, 93, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 109, 105, 110, 95, 112, 97, 116, 99,
  104, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110,
  116, 40, 36, 123, 49, 61, 49, 54, 125, 41, 32, 38, 38, 32, 36, 49,
  62, 61, 49, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101,
  116, 117, 114, 110, 32, 108, 111, 99, 97, 116, 105, 111, 110, 115, 32, 111,
  102, 32, 109, 105, 110, 105, 109, 97, 108, 32, 118, 97, 108, 117, 101, 115,
  32, 105, 110, 32, 108, 111, 99, 97, 108, 32, 112, 97, 116, 99, 104, 32,
  110, 101, 105, 103, 104, 98, 111, 114, 104, 111, 111, 100, 32, 111, 102, 32,
  115, 105, 122, 101, 32, 36, 49, 44, 32, 105, 110, 32, 105, 109, 97, 103,
  101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 45, 101, 114, 111, 100, 101, 91, 36, 62,
  93, 32, 36, 49, 32, 45, 61, 61, 91, 36, 62, 44, 45, 49, 93, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 109, 105, 110, 105, 109,
  97, 108, 95, 112, 97, 116, 104, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 34, 36, 49, 62, 61, 48, 32, 38, 38, 32, 36, 50, 62, 61, 48,
  32, 38, 38, 32, 36, 51, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 55, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 67, 111, 109, 112, 117, 116, 101, 32, 109, 105, 110, 105, 109, 97, 108,
  32, 112, 97, 116, 104, 32, 98, 101, 116, 119, 101, 101, 110, 32, 112, 111,
  105, 110, 116, 115, 32, 40, 36, 49, 44, 36, 50, 44, 36, 51, 41, 32,
  97, 110, 100, 32, 40, 36, 52, 44, 36, 53, 44, 36, 54, 41, 32, 102,
  111, 114, 32, 112, 111, 116, 101, 110, 116, 105, 97, 108, 32, 109, 97, 112,
  36, 63, 44, 32, 119, 105, 116, 104, 32, 34, 64, 123, 45, 97, 114, 103,
  92, 32, 49, 43, 36, 55, 44, 108, 111, 119, 44, 104, 105, 103, 104, 125,
  34, 32, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110,
  125, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 61, 32, 49,
  44, 36, 123, 52, 45, 54, 125, 32, 45, 100, 105, 115, 116, 97, 110, 99,
  101, 91, 45, 49, 93, 32, 49, 44, 91, 48, 93, 44, 123, 105, 102, 40,
  36, 55, 44, 52, 44, 51, 41, 125, 32, 45, 107, 91, 45, 49, 93, 10,
  120, 61, 123, 114, 111, 117, 110, 100, 40, 105, 102, 40, 64, 123, 45, 105,
  115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 49, 125, 44, 36,
  49, 42, 40, 119, 45, 49, 41, 44, 36, 49, 41, 41, 125, 10, 121, 61,
  123, 114, 111, 117, 110, 100, 40, 105, 102, 40, 64, 123, 45, 105, 115, 95,
  112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 50, 125, 44, 36, 50, 42,
  40, 104, 45, 49, 41, 44, 36, 50, 41, 41, 125, 10, 122, 61, 123, 114,
  111, 117, 110, 100, 40, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101,
  114, 99, 101, 110, 116, 92, 32, 36, 51, 125, 44, 36, 51, 42, 40, 100,
  45, 49, 41, 44, 36, 51, 41, 41, 125, 10, 40, 36, 120, 59, 36, 121,
  59, 36, 122, 41, 10, 45, 100, 111, 10, 112, 61, 64, 123, 48, 44, 40,
  36, 120, 44, 36, 121, 44, 36, 122, 41, 125, 10, 45, 105, 102, 32, 123,
  36, 112, 38, 49, 125, 32, 120, 61, 123, 36, 120, 45, 49, 125, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 112, 38, 50, 125, 32, 120, 61, 123, 36,
  120, 43, 49, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 112, 38, 52, 125, 32, 121, 61, 123, 36, 121, 45, 49, 125, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 112, 38, 56, 125, 32, 121, 61, 123,
  36, 121, 43, 49, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 112, 38, 49, 54, 125, 32, 122, 61, 123, 36, 122, 45, 49,
  125, 10, 45, 101, 108, 105, 102, 32, 123, 36, 112, 38, 51, 50, 125, 32,
  122, 61, 123, 36, 122, 43, 49, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  40, 36, 120, 59, 36, 121, 59, 36, 122, 41, 10, 45, 119, 104, 105, 108,
  101, 32, 36, 112, 10, 45, 114, 109, 91, 48, 44, 45, 49, 93, 32, 45,
  97, 32, 120, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 112,
  97, 116, 99, 104, 101, 115, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 105, 115, 105, 110, 116, 40, 36, 49, 41, 32, 38, 38, 32, 36, 49,
  62, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 50, 41, 32,
  38, 38, 32, 36, 50, 62, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116,
  40, 36, 51, 41, 32, 38, 38, 32, 36, 51, 62, 48, 34, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 69, 120, 116, 114, 97, 99, 116, 32, 36,
  49, 120, 36, 50, 120, 36, 51, 32, 112, 97, 116, 99, 104, 101, 115, 32,
  102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 97, 116,
  32, 108, 111, 99, 97, 116, 105, 111, 110, 115, 32, 40, 36, 123, 52, 45,
  45, 49, 125, 41, 46, 34, 10, 45, 118, 32, 45, 10, 40, 36, 123, 52,
  45, 45, 49, 125, 41, 32, 45, 114, 91, 45, 49, 93, 32, 51, 44, 123,
  119, 47, 51, 125, 44, 49, 44, 49, 44, 45, 49, 32, 45, 112, 101, 114,
  109, 117, 116, 101, 91, 45, 49, 93, 32, 121, 122, 99, 120, 32, 78, 61,
  123, 119, 125, 10, 72, 61, 123, 105, 110, 116, 40, 115, 113, 114, 116, 40,
  119, 41, 41, 125, 32, 87, 61, 123, 114, 111, 117, 110, 100, 40, 119, 47,
  36, 72, 44, 49, 44, 49, 41, 125, 32, 45, 114, 91, 45, 49, 93, 32,
  123, 36, 87, 42, 36, 72, 125, 44, 49, 44, 49, 44, 51, 44, 48, 32,
  45, 114, 91, 45, 49, 93, 32, 36, 87, 44, 36, 72, 44, 49, 44, 51,
  44, 45, 49, 10, 45, 114, 91, 45, 49, 93, 32, 123, 119, 42, 36, 49,
  125, 44, 123, 104, 42, 36, 50, 125, 44, 123, 100, 42, 36, 51, 125, 10,
  36, 49, 44, 36, 50, 44, 36, 51, 44, 49, 44, 120, 45, 123, 105, 110,
  116, 40, 36, 49, 47, 50, 41, 125, 32, 45, 45, 102, 91, 45, 49, 93,
  32, 121, 45, 123, 105, 110, 116, 40, 36, 50, 47, 50, 41, 125, 32, 45,
  45, 102, 91, 45, 49, 93, 32, 122, 45, 123, 105, 110, 116, 40, 36, 51,
  47, 50, 41, 125, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 99,
  32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 50,
  32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 45, 119, 97, 114, 112, 91,
  36, 62, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 44, 48, 32, 45,
  100, 111, 110, 101, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 60, 93, 32, 45,
  115, 32, 121, 44, 36, 72, 32, 45, 115, 32, 120, 44, 36, 87, 32, 45,
  107, 91, 48, 45, 123, 36, 78, 45, 49, 125, 93, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 45, 118, 32, 43, 10, 112, 108, 111,
  116, 50, 118, 97, 108, 117, 101, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 82, 101, 116, 114, 105, 101, 118, 101, 32, 118, 97, 108, 117,
  101, 115, 32, 102, 114, 111, 109, 32, 50, 100, 32, 103, 114, 97, 112, 104,
  32, 112, 108, 111, 116, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 115, 32, 99, 32, 45, 103, 101, 32, 53, 48, 37, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32,
  40, 49, 44, 123, 119, 125, 41, 32, 45, 114, 91, 49, 93, 32, 91, 48,
  93, 44, 51, 32, 45, 42, 32, 45, 104, 105, 115, 116, 111, 103, 114, 97,
  109, 32, 123, 119, 125, 44, 49, 44, 123, 119, 125, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 45, 97, 32, 99, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 112, 111,
  105, 110, 116, 99, 108, 111, 117, 100, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 34, 36, 123, 49, 61, 48, 125, 60, 51, 34, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 50, 61, 48, 125, 44, 36, 123, 51, 61, 48, 125,
  44, 36, 123, 52, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36, 63,
  32, 116, 111, 32, 112, 111, 105, 110, 116, 32, 99, 108, 111, 117, 100, 115,
  44, 32, 105, 110, 32, 34, 64, 123, 45, 97, 114, 103, 92, 32, 50, 43,
  40, 36, 49, 62, 61, 48, 41, 42, 36, 49, 45, 40, 36, 49, 60, 48,
  41, 44, 123, 45, 36, 49, 125, 45, 111, 112, 97, 99, 105, 116, 121, 44,
  98, 105, 110, 97, 114, 121, 44, 99, 117, 109, 117, 108, 97, 116, 105, 118,
  101, 44, 108, 97, 98, 101, 108, 105, 110, 103, 125, 34, 32, 109, 111, 100,
  101, 44, 34, 92, 10, 34, 119, 105, 116, 104, 32, 40, 36, 50, 44, 36,
  51, 44, 36, 52, 41, 32, 97, 115, 32, 109, 97, 120, 105, 109, 97, 108,
  32, 100, 105, 109, 101, 110, 115, 105, 111, 110, 115, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 45,
  105, 102, 32, 123, 34, 100, 62, 49, 32, 124, 124, 32, 115, 62, 49, 34,
  125, 32, 45, 101, 114, 114, 111, 114, 32, 34, 73, 110, 118, 97, 108, 105,
  100, 32, 105, 110, 112, 117, 116, 32, 105, 109, 97, 103, 101, 32, 34, 123,
  119, 125, 120, 123, 104, 125, 120, 123, 100, 125, 120, 123, 115, 125, 34, 46,
  32, 83, 104, 111, 117, 108, 100, 32, 98, 101, 32, 78, 120, 77, 120, 49,
  120, 49, 46, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 111, 119,
  115, 32, 48, 44, 123, 109, 97, 120, 40, 50, 44, 104, 45, 49, 41, 125,
  10, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48,
  32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 100, 120, 61, 123,
  114, 111, 117, 110, 100, 40, 105, 102, 40, 36, 50, 61, 61, 48, 44, 105,
  77, 43, 49, 44, 105, 102, 40, 36, 50, 60, 48, 44, 109, 105, 110, 40,
  105, 77, 43, 49, 44, 45, 36, 50, 41, 44, 36, 50, 41, 41, 41, 125,
  10, 45, 115, 104, 91, 45, 50, 93, 32, 49, 44, 49, 44, 48, 44, 48,
  32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 100, 121, 61, 123,
  114, 111, 117, 110, 100, 40, 105, 102, 40, 36, 51, 61, 61, 48, 44, 105,
  77, 43, 49, 44, 105, 102, 40, 36, 51, 60, 48, 44, 109, 105, 110, 40,
  105, 77, 43, 49, 44, 45, 36, 51, 41, 44, 36, 51, 41, 41, 41, 125,
  10, 45, 115, 104, 91, 45, 51, 93, 32, 50, 44, 50, 44, 48, 44, 48,
  32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 100, 122, 61, 123,
  114, 111, 117, 110, 100, 40, 105, 102, 40, 36, 52, 61, 61, 48, 44, 105,
  77, 43, 49, 44, 105, 102, 40, 36, 52, 60, 48, 44, 109, 105, 110, 40,
  105, 77, 43, 49, 44, 45, 36, 52, 41, 44, 36, 52, 41, 41, 41, 125,
  10, 45, 42, 91, 45, 49, 93, 32, 36, 100, 121, 32, 45, 43, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 32, 45, 102, 91, 45, 49, 93, 32, 48,
  32, 45, 114, 109, 91, 45, 51, 45, 45, 49, 93, 10, 45, 115, 32, 120,
  44, 45, 49, 48, 48, 48, 48, 48, 48, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 110, 98, 112, 61,
  123, 119, 125, 10, 45, 105, 102, 32, 123, 104, 62, 51, 125, 32, 45, 45,
  114, 111, 119, 115, 32, 51, 44, 49, 48, 48, 37, 32, 45, 114, 111, 119,
  115, 91, 45, 50, 93, 32, 48, 44, 50, 32, 45, 101, 108, 115, 101, 32,
  49, 48, 48, 37, 44, 49, 44, 49, 44, 49, 44, 49, 32, 45, 105, 102,
  32, 123, 36, 49, 61, 61, 50, 125, 32, 45, 102, 91, 45, 49, 93, 32,
  49, 43, 120, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105,
  102, 10, 115, 112, 101, 99, 116, 114, 117, 109, 61, 123, 104, 125, 32, 45,
  105, 91, 45, 50, 93, 32, 40, 45, 49, 50, 56, 59, 49, 59, 49, 59,
  123, 104, 125, 41, 32, 45, 114, 91, 45, 50, 93, 32, 123, 119, 125, 32,
  45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 10, 45, 105, 91, 45,
  51, 93, 32, 40, 123, 39, 67, 73, 109, 103, 51, 100, 39, 125, 41, 32,
  45, 116, 114, 97, 110, 115, 112, 111, 115, 101, 91, 45, 51, 45, 45, 49,
  93, 32, 45, 105, 91, 45, 51, 93, 32, 40, 36, 110, 98, 112, 59, 36,
  110, 98, 112, 41, 10, 45, 105, 91, 45, 50, 93, 32, 49, 44, 36, 110,
  98, 112, 44, 49, 44, 49, 44, 49, 32, 45, 105, 91, 45, 50, 93, 32,
  49, 44, 36, 110, 98, 112, 44, 49, 44, 49, 44, 121, 32, 45, 97, 91,
  45, 51, 44, 45, 50, 93, 32, 120, 10, 49, 44, 36, 110, 98, 112, 44,
  49, 44, 49, 44, 123, 105, 102, 40, 36, 49, 60, 48, 44, 45, 36, 49,
  44, 105, 102, 40, 36, 49, 61, 61, 49, 44, 45, 49, 44, 49, 41, 41,
  125, 10, 45, 121, 91, 45, 52, 45, 45, 50, 93, 32, 45, 97, 32, 121,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 43, 51,
  100, 10, 36, 100, 120, 44, 123, 36, 100, 121, 42, 36, 100, 122, 125, 44,
  49, 44, 36, 115, 112, 101, 99, 116, 114, 117, 109, 32, 45, 111, 98, 106,
  101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48,
  44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 32, 45, 114, 109,
  91, 45, 50, 93, 32, 45, 114, 91, 45, 49, 93, 32, 36, 100, 120, 44,
  36, 100, 121, 44, 36, 100, 122, 44, 49, 48, 48, 37, 44, 45, 49, 10,
  45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 112, 115, 110, 114, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 50, 53, 53, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116,
  101, 32, 116, 104, 101, 32, 34, 64, 35, 120, 64, 35, 34, 32, 109, 97,
  116, 114, 105, 120, 32, 111, 102, 32, 80, 83, 78, 82, 32, 118, 97, 108,
  117, 101, 115, 44, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36,
  63, 32, 119, 105, 116, 104, 32, 109, 97, 120, 105, 109, 117, 109, 32, 118,
  97, 108, 117, 101, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  109, 115, 101, 32, 45, 108, 111, 103, 49, 48, 32, 45, 45, 32, 123, 108,
  111, 103, 49, 48, 40, 36, 49, 42, 36, 49, 41, 125, 32, 45, 42, 32,
  45, 49, 48, 32, 45, 110, 109, 91, 45, 49, 93, 32, 91, 80, 83, 78,
  82, 93, 32, 45, 118, 32, 43, 10, 115, 101, 103, 109, 101, 110, 116, 95,
  119, 97, 116, 101, 114, 115, 104, 101, 100, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 36, 123, 49, 61, 50, 125, 62, 61, 48, 34, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 50, 61, 49, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 119, 97, 116, 101, 114,
  115, 104, 101, 100, 32, 115, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111,
  110, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105,
  116, 104, 32, 101, 100, 103, 101, 32, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 43,
  32, 123, 49, 43, 64, 123, 45, 49, 44, 109, 125, 125, 32, 45, 45, 103,
  114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 10, 45, 105, 102,
  32, 123, 100, 62, 49, 125, 32, 45, 45, 102, 91, 45, 49, 93, 32, 34,
  105, 102, 40, 105, 60, 36, 49, 32, 38, 38, 32, 105, 60, 106, 40, 49,
  41, 32, 38, 38, 32, 105, 60, 106, 40, 45, 49, 41, 32, 38, 38, 32,
  105, 60, 106, 40, 48, 44, 49, 41, 32, 38, 38, 32, 105, 60, 106, 40,
  48, 44, 45, 49, 41, 32, 38, 38, 32, 105, 60, 106, 40, 48, 44, 48,
  44, 49, 41, 32, 38, 38, 32, 105, 60, 106, 40, 48, 44, 48, 44, 45,
  49, 41, 44, 49, 44, 48, 41, 34, 10, 45, 101, 108, 115, 101, 32, 45,
  45, 102, 91, 45, 49, 93, 32, 34, 105, 102, 40, 105, 60, 36, 49, 32,
  38, 38, 32, 105, 60, 106, 40, 49, 41, 32, 38, 38, 32, 105, 60, 106,
  40, 45, 49, 41, 32, 38, 38, 32, 105, 60, 106, 40, 48, 44, 49, 41,
  32, 38, 38, 32, 105, 60, 106, 40, 48, 44, 45, 49, 41, 44, 49, 44,
  48, 41, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 42, 91, 45, 51,
  44, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45,
  119, 97, 116, 101, 114, 115, 104, 101, 100, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 44, 36, 50, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 115,
  107, 101, 108, 101, 116, 111, 110, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 36, 123, 49, 61, 48, 125, 62, 61, 48, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 115, 107, 101, 108,
  101, 116, 111, 110, 32, 111, 102, 32, 98, 105, 110, 97, 114, 121, 32, 105,
  109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 103,
  101, 32, 53, 48, 37, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101, 32,
  48, 32, 45, 98, 32, 36, 49, 32, 45, 115, 104, 97, 114, 112, 101, 110,
  32, 49, 101, 49, 48, 32, 45, 103, 101, 32, 49, 48, 48, 37, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 45, 101, 114, 111, 100,
  101, 91, 36, 62, 93, 32, 50, 32, 45, 45, 91, 36, 62, 44, 45, 49,
  93, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 115, 115, 100,
  95, 112, 97, 116, 99, 104, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 49, 61, 48, 125, 44, 36, 123, 50, 61, 48, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 102, 105,
  101, 108, 100, 32, 111, 102, 32, 83, 83, 68, 32, 98, 101, 116, 119, 101,
  101, 110, 32, 105, 109, 97, 103, 101, 115, 32, 97, 110, 100, 32, 112, 97,
  116, 99, 104, 115, 32, 117, 115, 105, 110, 103, 32, 34, 64, 123, 45, 97,
  114, 103, 92, 32, 49, 43, 33, 36, 49, 44, 102, 111, 117, 114, 105, 101,
  114, 44, 115, 112, 97, 116, 105, 97, 108, 125, 34, 32, 109, 111, 100, 101,
  44, 32, 105, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116,
  40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36,
  62, 43, 49, 125, 93, 10, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 64, 123, 45, 109, 97, 120, 95, 115,
  125, 32, 45, 115, 32, 99, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  64, 35, 47, 50, 125, 32, 45, 108, 91, 36, 62, 44, 123, 45, 49, 45,
  36, 60, 125, 93, 10, 45, 45, 115, 113, 114, 91, 49, 93, 32, 118, 97,
  108, 61, 64, 123, 45, 49, 44, 43, 125, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 45, 115, 113, 114, 91, 48, 93, 32, 45, 45, 102, 91, 49,
  93, 32, 49, 10, 45, 105, 102, 32, 36, 49, 10, 45, 99, 111, 110, 118,
  111, 108, 118, 101, 95, 102, 102, 116, 91, 45, 50, 44, 45, 49, 93, 10,
  45, 109, 105, 114, 114, 111, 114, 91, 49, 93, 32, 120, 121, 122, 32, 45,
  99, 111, 110, 118, 111, 108, 118, 101, 95, 102, 102, 116, 91, 48, 44, 49,
  93, 10, 45, 101, 108, 115, 101, 10, 45, 99, 111, 114, 114, 101, 108, 97,
  116, 101, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 50, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 99, 111, 114, 114, 101, 108, 97, 116,
  101, 91, 48, 93, 32, 91, 49, 93, 44, 36, 50, 32, 45, 114, 109, 91,
  49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 42, 91, 48, 93, 32,
  45, 50, 32, 45, 43, 91, 48, 44, 49, 93, 32, 45, 43, 32, 36, 118,
  97, 108, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  43, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 116, 104, 105, 110, 110, 105, 110, 103, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 115,
  107, 101, 108, 101, 116, 111, 110, 32, 111, 102, 32, 98, 105, 110, 97, 114,
  121, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 117, 115, 105, 110, 103,
  32, 109, 111, 114, 112, 104, 111, 108, 111, 103, 105, 99, 97, 108, 32, 116,
  104, 105, 110, 110, 105, 110, 103, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  103, 101, 32, 53, 48, 37, 32, 45, 42, 32, 50, 32, 45, 45, 32, 49,
  10, 40, 45, 49, 44, 45, 49, 44, 45, 49, 59, 48, 44, 49, 44, 48,
  59, 49, 44, 49, 44, 49, 41, 32, 40, 48, 44, 45, 49, 44, 45, 49,
  59, 49, 44, 49, 44, 45, 49, 59, 48, 44, 49, 44, 48, 41, 32, 45,
  45, 114, 111, 116, 97, 116, 101, 91, 45, 50, 44, 45, 49, 93, 32, 57,
  48, 32, 45, 45, 114, 111, 116, 97, 116, 101, 91, 45, 50, 44, 45, 49,
  93, 32, 57, 48, 32, 45, 45, 114, 111, 116, 97, 116, 101, 91, 45, 50,
  44, 45, 49, 93, 32, 57, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 64, 35, 45, 56, 125, 10, 98, 97, 118, 103, 61, 64, 123, 45, 57,
  44, 43, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 57, 57, 57, 57,
  57, 10, 45, 45, 99, 111, 114, 114, 101, 108, 97, 116, 101, 91, 45, 57,
  93, 32, 91, 45, 56, 93, 32, 45, 103, 101, 91, 45, 49, 93, 32, 55,
  32, 45, 42, 91, 45, 49, 93, 32, 50, 32, 45, 45, 91, 45, 49, 48,
  44, 45, 49, 93, 10, 45, 45, 99, 111, 114, 114, 101, 108, 97, 116, 101,
  91, 45, 57, 93, 32, 91, 45, 55, 93, 32, 45, 103, 101, 91, 45, 49,
  93, 32, 54, 32, 45, 42, 91, 45, 49, 93, 32, 50, 32, 45, 45, 91,
  45, 49, 48, 44, 45, 49, 93, 10, 45, 45, 99, 111, 114, 114, 101, 108,
  97, 116, 101, 91, 45, 57, 93, 32, 91, 45, 54, 93, 32, 45, 103, 101,
  91, 45, 49, 93, 32, 55, 32, 45, 42, 91, 45, 49, 93, 32, 50, 32,
  45, 45, 91, 45, 49, 48, 44, 45, 49, 93, 10, 45, 45, 99, 111, 114,
  114, 101, 108, 97, 116, 101, 91, 45, 57, 93, 32, 91, 45, 53, 93, 32,
  45, 103, 101, 91, 45, 49, 93, 32, 54, 32, 45, 42, 91, 45, 49, 93,
  32, 50, 32, 45, 45, 91, 45, 49, 48, 44, 45, 49, 93, 10, 45, 45,
  99, 111, 114, 114, 101, 108, 97, 116, 101, 91, 45, 57, 93, 32, 91, 45,
  52, 93, 32, 45, 103, 101, 91, 45, 49, 93, 32, 55, 32, 45, 42, 91,
  45, 49, 93, 32, 50, 32, 45, 45, 91, 45, 49, 48, 44, 45, 49, 93,
  10, 45, 45, 99, 111, 114, 114, 101, 108, 97, 116, 101, 91, 45, 57, 93,
  32, 91, 45, 51, 93, 32, 45, 103, 101, 91, 45, 49, 93, 32, 54, 32,
  45, 42, 91, 45, 49, 93, 32, 50, 32, 45, 45, 91, 45, 49, 48, 44,
  45, 49, 93, 10, 45, 45, 99, 111, 114, 114, 101, 108, 97, 116, 101, 91,
  45, 57, 93, 32, 91, 45, 50, 93, 32, 45, 103, 101, 91, 45, 49, 93,
  32, 55, 32, 45, 42, 91, 45, 49, 93, 32, 50, 32, 45, 45, 91, 45,
  49, 48, 44, 45, 49, 93, 10, 45, 45, 99, 111, 114, 114, 101, 108, 97,
  116, 101, 91, 45, 57, 93, 32, 91, 45, 49, 93, 32, 45, 103, 101, 91,
  45, 49, 93, 32, 54, 32, 45, 42, 91, 45, 49, 93, 32, 50, 32, 45,
  45, 91, 45, 49, 48, 44, 45, 49, 93, 10, 97, 97, 118, 103, 61, 64,
  123, 45, 57, 44, 43, 125, 32, 45, 105, 102, 32, 123, 36, 97, 97, 118,
  103, 61, 61, 36, 98, 97, 118, 103, 125, 32, 45, 98, 114, 101, 97, 107,
  32, 45, 101, 110, 100, 105, 102, 32, 98, 97, 118, 103, 61, 36, 97, 97,
  118, 103, 10, 45, 100, 111, 110, 101, 10, 45, 109, 118, 91, 45, 57, 93,
  32, 48, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 45, 56, 45,
  45, 49, 93, 32, 45, 43, 32, 49, 32, 45, 47, 32, 50, 32, 45, 118,
  32, 43, 10, 116, 111, 110, 101, 115, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 36, 49, 62, 48, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  71, 101, 116, 32, 36, 49, 32, 116, 111, 110, 101, 115, 32, 109, 97, 115,
  107, 115, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 110, 111, 114, 109, 32, 45, 110, 32,
  48, 44, 123, 36, 49, 45, 49, 125, 32, 45, 114, 111, 117, 110, 100, 32,
  49, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 60, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 49, 45,
  49, 125, 32, 45, 45, 61, 61, 91, 48, 93, 32, 123, 49, 43, 36, 62,
  125, 32, 45, 100, 111, 110, 101, 32, 45, 61, 61, 91, 48, 93, 32, 48,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 116, 111, 112, 111, 103, 114, 97, 112, 104, 105, 99, 95, 109, 97,
  112, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110,
  116, 40, 36, 123, 49, 61, 49, 54, 125, 41, 32, 38, 38, 32, 36, 49,
  62, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 50, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 110, 100, 101, 114,
  32, 116, 111, 112, 111, 103, 114, 97, 112, 104, 105, 99, 32, 109, 97, 112,
  115, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32,
  119, 105, 116, 104, 32, 36, 49, 32, 108, 101, 118, 101, 108, 115, 32, 97,
  110, 100, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 50,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 98, 32, 36, 50,
  32, 45, 105, 115, 111, 112, 104, 111, 116, 101, 115, 91, 45, 49, 93, 32,
  36, 49, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 91, 45, 49, 93, 32, 43, 32, 45, 61, 61, 91, 45,
  49, 93, 32, 48, 32, 45, 98, 108, 101, 110, 100, 32, 115, 104, 97, 112,
  101, 97, 118, 101, 114, 97, 103, 101, 48, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 98, 97, 108, 108, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 54, 52,
  125, 62, 48, 32, 38, 38, 32, 36, 123, 53, 61, 48, 46, 56, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 53, 60, 61, 56, 32, 38, 38, 32, 36,
  123, 54, 61, 49, 125, 62, 61, 48, 32, 36, 54, 60, 61, 56, 32, 38,
  38, 32, 36, 123, 55, 61, 49, 46, 53, 125, 62, 61, 48, 34, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 50, 61, 50, 53, 53, 125, 44, 36, 123,
  51, 61, 36, 50, 125, 44, 36, 123, 52, 61, 36, 51, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 36, 49, 120,
  36, 49, 32, 98, 97, 108, 108, 32, 119, 105, 116, 104, 32, 99, 111, 108,
  111, 114, 32, 40, 36, 123, 50, 45, 52, 125, 41, 44, 32, 115, 112, 101,
  99, 117, 108, 97, 114, 32, 108, 105, 103, 104, 116, 32, 36, 53, 44, 32,
  115, 112, 101, 99, 117, 108, 97, 114, 32, 115, 105, 122, 101, 32, 36, 54,
  32, 97, 110, 100, 32, 115, 104, 97, 100, 111, 119, 32, 102, 97, 99, 116,
  111, 114, 32, 36, 55, 46, 34, 10, 45, 118, 32, 45, 32, 45, 108, 91,
  93, 10, 123, 50, 42, 36, 49, 125, 44, 123, 50, 42, 36, 49, 125, 32,
  45, 61, 32, 49, 44, 54, 53, 37, 44, 51, 48, 37, 32, 45, 100, 105,
  115, 116, 97, 110, 99, 101, 32, 49, 32, 45, 42, 32, 45, 49, 10, 45,
  45, 110, 32, 48, 44, 49, 32, 45, 112, 111, 119, 91, 49, 93, 32, 36,
  55, 32, 45, 42, 91, 49, 93, 32, 49, 46, 52, 32, 45, 45, 42, 91,
  49, 93, 32, 36, 51, 32, 45, 45, 42, 91, 49, 93, 32, 36, 52, 32,
  45, 42, 91, 49, 93, 32, 36, 50, 32, 45, 97, 91, 94, 48, 93, 32,
  99, 10, 45, 103, 101, 91, 48, 93, 32, 123, 49, 48, 48, 45, 49, 48,
  42, 36, 54, 125, 37, 32, 45, 98, 91, 48, 93, 32, 123, 51, 42, 36,
  54, 125, 37, 32, 45, 110, 91, 48, 93, 32, 48, 44, 123, 36, 53, 42,
  50, 53, 53, 125, 32, 45, 114, 118, 32, 45, 43, 32, 45, 99, 32, 48,
  44, 50, 53, 53, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45,
  99, 105, 114, 99, 108, 101, 91, 49, 93, 32, 53, 48, 37, 44, 53, 48,
  37, 44, 51, 52, 37, 44, 49, 44, 49, 32, 45, 42, 91, 48, 93, 32,
  91, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45,
  97, 32, 99, 10, 45, 114, 32, 36, 49, 44, 36, 49, 44, 49, 44, 52,
  44, 50, 10, 45, 101, 110, 100, 108, 32, 45, 118, 32, 43, 10, 99, 104,
  101, 115, 115, 98, 111, 97, 114, 100, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 34, 36, 49, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 36,
  49, 125, 62, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61,
  48, 125, 44, 36, 123, 52, 61, 48, 125, 44, 36, 123, 53, 61, 48, 125,
  44, 36, 123, 54, 61, 49, 125, 44, 36, 123, 55, 61, 48, 125, 44, 36,
  123, 56, 61, 50, 53, 53, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 68, 114, 97, 119, 32, 99, 104, 101, 115, 115, 98, 111, 97, 114, 100,
  32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116,
  104, 32, 115, 105, 122, 101, 115, 32, 40, 36, 49, 44, 36, 50, 41, 44,
  32, 111, 102, 102, 115, 101, 116, 115, 32, 40, 36, 51, 44, 36, 52, 41,
  44, 32, 97, 110, 103, 108, 101, 32, 36, 53, 32, 100, 101, 103, 46, 44,
  32, 111, 112, 97, 99, 105, 116, 121, 32, 36, 54, 32, 97, 110, 100, 32,
  99, 111, 108, 111, 114, 115, 32, 40, 36, 123, 55, 45, 45, 49, 125, 41,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 105, 91, 48, 93, 32, 40, 36,
  123, 55, 45, 45, 49, 125, 41, 32, 45, 114, 91, 48, 93, 32, 123, 64,
  123, 48, 44, 119, 125, 47, 50, 125, 44, 49, 44, 49, 44, 50, 44, 45,
  49, 32, 45, 112, 101, 114, 109, 117, 116, 101, 91, 48, 93, 32, 99, 121,
  122, 120, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49,
  125, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 32, 116, 104,
  101, 116, 97, 61, 123, 36, 53, 42, 112, 105, 47, 49, 56, 48, 125, 10,
  40, 36, 51, 44, 123, 36, 51, 43, 36, 119, 45, 49, 125, 59, 36, 51,
  44, 123, 36, 51, 43, 36, 119, 45, 49, 125, 94, 36, 52, 44, 36, 52,
  59, 123, 36, 52, 43, 36, 104, 45, 49, 125, 44, 123, 36, 52, 43, 36,
  104, 45, 49, 125, 41, 32, 45, 114, 91, 45, 49, 93, 32, 36, 119, 44,
  36, 104, 44, 49, 44, 50, 44, 51, 10, 45, 114, 91, 45, 49, 93, 32,
  123, 36, 119, 42, 36, 104, 125, 44, 50, 44, 49, 44, 49, 44, 45, 49,
  10, 45, 105, 91, 45, 50, 93, 32, 40, 123, 99, 111, 115, 40, 36, 116,
  104, 101, 116, 97, 41, 125, 44, 123, 45, 115, 105, 110, 40, 36, 116, 104,
  101, 116, 97, 41, 125, 59, 123, 115, 105, 110, 40, 36, 116, 104, 101, 116,
  97, 41, 125, 44, 123, 99, 111, 115, 40, 36, 116, 104, 101, 116, 97, 41,
  125, 41, 32, 45, 42, 42, 91, 45, 50, 44, 45, 49, 93, 10, 45, 114,
  91, 45, 49, 93, 32, 36, 119, 44, 36, 104, 44, 49, 44, 50, 44, 45,
  49, 10, 45, 37, 91, 45, 49, 93, 32, 123, 36, 49, 43, 36, 50, 125,
  32, 45, 62, 61, 91, 45, 49, 93, 32, 36, 49, 32, 45, 115, 91, 45,
  49, 93, 32, 99, 32, 45, 120, 111, 114, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 109, 97, 112, 91, 45, 49, 93, 32, 91, 48, 93, 32, 45, 114,
  91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 91, 45, 50, 93, 10, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 36, 54, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 109, 118, 91, 45, 49, 93, 32, 49, 32, 45,
  100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 93, 32, 45, 118, 32, 43,
  10, 99, 105, 101, 49, 57, 51, 49, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 68, 114, 97, 119, 32, 67, 73, 69, 45, 49, 57, 51,
  49, 32, 99, 104, 114, 111, 109, 97, 116, 105, 99, 105, 116, 121, 32, 100,
  105, 97, 103, 114, 97, 109, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36,
  63, 46, 34, 10, 45, 118, 32, 45, 10, 40, 54, 55, 46, 53, 59, 55,
  51, 46, 53, 59, 49, 48, 57, 46, 53, 59, 49, 48, 51, 46, 53, 59,
  53, 49, 46, 53, 59, 49, 48, 48, 46, 53, 59, 51, 55, 59, 51, 54,
  41, 10, 40, 50, 56, 48, 44, 52, 50, 48, 44, 48, 59, 49, 55, 49,
  44, 56, 50, 57, 44, 48, 59, 49, 53, 56, 44, 56, 50, 48, 44, 48,
  59, 49, 53, 51, 44, 56, 49, 54, 44, 48, 59, 49, 52, 55, 44, 56,
  49, 49, 44, 48, 59, 49, 52, 48, 44, 56, 48, 52, 44, 48, 59, 49,
  51, 50, 44, 55, 57, 52, 44, 48, 59, 49, 50, 49, 44, 55, 55, 54,
  44, 48, 59, 49, 48, 54, 44, 55, 52, 55, 44, 48, 59, 56, 56, 44,
  55, 48, 49, 44, 48, 59, 92, 10, 54, 53, 44, 54, 51, 51, 44, 48,
  59, 52, 50, 44, 53, 51, 57, 44, 48, 59, 50, 48, 44, 52, 50, 49,
  44, 48, 59, 53, 44, 50, 57, 53, 44, 48, 59, 48, 44, 49, 55, 57,
  44, 48, 59, 52, 44, 49, 49, 53, 44, 48, 59, 49, 48, 44, 56, 51,
  44, 48, 59, 49, 54, 44, 54, 49, 44, 48, 59, 50, 53, 44, 51, 56,
  44, 48, 59, 51, 53, 44, 50, 49, 44, 48, 59, 52, 55, 44, 49, 48,
  44, 48, 59, 53, 56, 44, 51, 44, 48, 59, 92, 10, 55, 49, 44, 48,
  44, 48, 59, 57, 50, 44, 49, 44, 48, 59, 49, 49, 49, 44, 55, 44,
  48, 59, 49, 53, 49, 44, 50, 56, 44, 48, 59, 49, 56, 57, 44, 53,
  50, 44, 48, 59, 50, 50, 54, 44, 55, 57, 44, 48, 59, 50, 54, 50,
  44, 49, 48, 57, 44, 48, 59, 50, 57, 56, 44, 49, 52, 49, 44, 48,
  59, 51, 51, 52, 44, 49, 55, 53, 44, 48, 59, 51, 55, 48, 44, 50,
  48, 57, 44, 48, 59, 52, 48, 53, 44, 50, 52, 52, 44, 48, 59, 92,
  10, 52, 52, 49, 44, 50, 55, 57, 44, 48, 59, 52, 55, 53, 44, 51,
  49, 51, 44, 48, 59, 53, 48, 57, 44, 51, 52, 55, 44, 48, 59, 55,
  51, 49, 44, 53, 54, 56, 44, 48, 41, 10, 120, 77, 61, 55, 51, 49,
  32, 121, 77, 61, 56, 50, 57, 10, 50, 44, 123, 104, 45, 49, 125, 44,
  49, 44, 49, 44, 51, 44, 48, 32, 49, 44, 123, 104, 125, 44, 49, 44,
  49, 44, 39, 121, 39, 32, 45, 45, 43, 91, 45, 49, 93, 32, 49, 32,
  45, 37, 91, 45, 49, 93, 32, 123, 104, 125, 32, 45, 43, 91, 45, 50,
  44, 45, 49, 93, 32, 49, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93,
  32, 120, 10, 51, 44, 123, 104, 125, 44, 49, 44, 49, 44, 49, 54, 48,
  32, 49, 44, 123, 104, 125, 44, 49, 44, 49, 44, 49, 10, 45, 121, 91,
  45, 52, 45, 45, 50, 93, 32, 45, 97, 91, 45, 53, 45, 45, 49, 93,
  32, 121, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 10, 120, 82, 61,
  54, 51, 54, 32, 121, 82, 61, 53, 48, 52, 32, 120, 71, 61, 50, 57,
  55, 32, 121, 71, 61, 50, 51, 52, 32, 120, 66, 61, 49, 52, 55, 32,
  121, 66, 61, 55, 55, 52, 10, 53, 49, 50, 44, 53, 49, 50, 44, 49,
  44, 51, 32, 45, 116, 114, 105, 97, 110, 103, 108, 101, 95, 115, 104, 97,
  100, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 123, 119, 45, 49, 125,
  44, 48, 44, 48, 44, 123, 104, 45, 49, 125, 44, 34, 34, 50, 53, 53,
  44, 48, 44, 48, 44, 34, 34, 48, 44, 50, 53, 53, 44, 48, 44, 34,
  34, 48, 44, 48, 44, 50, 53, 53, 32, 45, 114, 103, 98, 50, 115, 114,
  103, 98, 91, 45, 49, 93, 10, 45, 45, 99, 111, 109, 112, 111, 115, 101,
  95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 109, 97,
  120, 32, 45, 43, 91, 45, 49, 93, 32, 49, 101, 45, 56, 32, 45, 47,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 50,
  53, 53, 10, 45, 105, 91, 45, 50, 93, 32, 40, 54, 55, 46, 53, 59,
  55, 51, 46, 53, 59, 49, 48, 57, 46, 53, 59, 49, 48, 51, 46, 53,
  59, 53, 49, 46, 53, 59, 49, 48, 48, 46, 53, 59, 51, 59, 49, 59,
  36, 120, 82, 59, 36, 121, 82, 59, 45, 48, 46, 48, 49, 59, 36, 120,
  71, 59, 36, 121, 71, 59, 45, 48, 46, 48, 49, 59, 36, 120, 66, 59,
  36, 121, 66, 59, 45, 48, 46, 48, 49, 59, 57, 59, 48, 59, 49, 59,
  50, 59, 48, 59, 48, 59, 53, 49, 49, 59, 48, 59, 48, 59, 53, 49,
  49, 59, 45, 49, 50, 56, 59, 53, 49, 50, 59, 53, 49, 50, 59, 51,
  41, 10, 45, 121, 91, 45, 49, 93, 32, 40, 49, 41, 32, 45, 97, 91,
  45, 51, 45, 45, 49, 93, 32, 121, 32, 45, 109, 118, 91, 45, 49, 93,
  32, 49, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 50,
  125, 10, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 32, 45, 102,
  99, 91, 45, 49, 93, 32, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53,
  53, 32, 45, 103, 114, 105, 100, 91, 45, 49, 93, 32, 49, 48, 37, 44,
  49, 48, 37, 44, 48, 44, 48, 44, 48, 46, 51, 44, 48, 120, 67, 67,
  67, 67, 67, 67, 67, 67, 44, 49, 44, 48, 10, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 44, 49, 44, 51, 10, 45, 45, 42, 51, 100, 91, 48,
  44, 49, 93, 32, 123, 40, 119, 45, 56, 41, 47, 36, 120, 77, 125, 44,
  123, 40, 104, 45, 51, 50, 41, 47, 36, 121, 77, 125, 10, 45, 111, 98,
  106, 101, 99, 116, 51, 100, 91, 45, 51, 93, 32, 91, 45, 49, 93, 44,
  50, 44, 51, 48, 44, 48, 44, 49, 44, 50, 10, 45, 45, 110, 101, 113,
  91, 45, 51, 93, 32, 48, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101,
  91, 45, 49, 93, 32, 49, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49,
  32, 45, 119, 97, 116, 101, 114, 115, 104, 101, 100, 91, 45, 52, 93, 32,
  91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 47, 91,
  45, 51, 93, 32, 49, 46, 53, 10, 45, 111, 98, 106, 101, 99, 116, 51,
  100, 91, 45, 51, 93, 32, 91, 45, 49, 93, 44, 50, 44, 51, 48, 44,
  48, 44, 49, 44, 50, 10, 45, 112, 51, 100, 91, 45, 49, 93, 32, 49,
  32, 45, 112, 51, 100, 91, 45, 49, 93, 32, 50, 32, 45, 99, 111, 108,
  51, 100, 91, 45, 49, 93, 32, 49, 50, 56, 32, 45, 111, 98, 106, 101,
  99, 116, 51, 100, 91, 45, 51, 93, 32, 91, 45, 49, 93, 44, 50, 44,
  51, 48, 44, 48, 44, 49, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 64, 123, 45, 50, 44, 119, 125, 44, 64, 123, 45, 50, 44, 104, 125,
  32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91,
  45, 50, 93, 44, 50, 44, 51, 48, 44, 48, 44, 49, 44, 50, 32, 45,
  114, 109, 91, 45, 50, 93, 10, 45, 45, 101, 114, 111, 100, 101, 91, 45,
  49, 93, 32, 52, 32, 45, 45, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  32, 45, 101, 113, 91, 45, 49, 93, 32, 48, 32, 45, 42, 91, 45, 51,
  44, 45, 49, 93, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99,
  32, 45, 98, 108, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 97,
  108, 112, 104, 97, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 49, 44, 50, 53, 53, 32, 45, 97, 120, 101, 115, 91, 45, 49, 93,
  32, 48, 44, 48, 46, 55, 53, 44, 48, 46, 56, 53, 44, 48, 44, 49,
  51, 44, 49, 32, 45, 45, 101, 114, 111, 100, 101, 91, 45, 49, 93, 32,
  51, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32,
  45, 116, 111, 95, 114, 103, 98, 91, 45, 50, 93, 10, 45, 106, 91, 45,
  51, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44,
  49, 44, 91, 45, 49, 93, 44, 52, 48, 48, 32, 45, 114, 109, 91, 45,
  50, 44, 45, 49, 93, 10, 45, 109, 118, 91, 45, 49, 93, 32, 50, 32,
  45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 44, 49, 93, 32, 45,
  118, 32, 43, 10, 99, 105, 114, 99, 108, 101, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 52, 61, 49, 125, 44, 36, 123, 53, 61, 48, 125,
  10, 45, 118, 32, 45, 32, 40, 123, 39, 34, 36, 53, 34, 39, 125, 41,
  32, 105, 115, 95, 112, 97, 116, 116, 101, 114, 110, 61, 123, 64, 123, 45,
  49, 44, 48, 45, 49, 125, 39, 61, 61, 39, 123, 39, 48, 120, 39, 125,
  125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 118, 32, 43, 10, 45,
  105, 102, 32, 36, 105, 115, 95, 112, 97, 116, 116, 101, 114, 110, 10, 45,
  101, 91, 48, 45, 45, 51, 93, 32, 34, 68, 114, 97, 119, 32, 111, 117,
  116, 108, 105, 110, 101, 100, 32, 99, 105, 114, 99, 108, 101, 32, 97, 116,
  32, 40, 36, 49, 44, 36, 50, 41, 32, 119, 105, 116, 104, 32, 114, 97,
  100, 105, 117, 115, 32, 36, 51, 32, 111, 110, 32, 105, 109, 97, 103, 101,
  36, 63, 44, 32, 119, 105, 116, 104, 32, 111, 112, 97, 99, 105, 116, 121,
  32, 36, 52, 32, 97, 110, 100, 32, 99, 111, 108, 111, 114, 32, 40, 36,
  123, 54, 45, 45, 49, 125, 41, 46, 34, 10, 45, 101, 108, 115, 101, 10,
  45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 68, 114, 97, 119, 32, 102,
  105, 108, 108, 101, 100, 32, 99, 105, 114, 99, 108, 101, 32, 97, 116, 32,
  40, 36, 49, 44, 36, 50, 41, 32, 119, 105, 116, 104, 32, 114, 97, 100,
  105, 117, 115, 32, 36, 51, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 119, 105, 116, 104, 32, 111, 112, 97, 99, 105, 116, 121, 32,
  36, 52, 32, 97, 110, 100, 32, 99, 111, 108, 111, 114, 32, 40, 36, 123,
  53, 45, 45, 49, 125, 41, 46, 34, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 118, 32, 45, 32, 45, 101, 108, 108, 105, 112, 115, 101, 32, 36, 49,
  44, 36, 50, 44, 36, 51, 44, 36, 51, 44, 48, 44, 36, 123, 52, 45,
  45, 49, 125, 32, 45, 118, 32, 43, 10, 103, 97, 117, 115, 115, 105, 97,
  110, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 51, 125,
  44, 36, 123, 50, 61, 36, 49, 125, 44, 36, 123, 51, 61, 48, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 114, 97, 119, 32, 99, 101,
  110, 116, 101, 114, 101, 100, 32, 103, 97, 117, 115, 115, 105, 97, 110, 32,
  111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 32, 119, 105, 116, 104, 32,
  115, 116, 97, 110, 100, 97, 114, 100, 32, 100, 101, 118, 105, 97, 116, 105,
  111, 110, 115, 32, 40, 36, 49, 44, 36, 50, 41, 32, 97, 110, 100, 32,
  97, 110, 103, 108, 101, 32, 36, 51, 32, 100, 101, 103, 46, 34, 10, 45,
  118, 32, 45, 10, 117, 61, 123, 99, 111, 115, 40, 36, 51, 42, 112, 105,
  47, 49, 56, 48, 41, 125, 10, 118, 61, 123, 115, 105, 110, 40, 36, 51,
  42, 112, 105, 47, 49, 56, 48, 41, 125, 10, 100, 109, 97, 120, 61, 123,
  109, 97, 120, 40, 119, 44, 104, 41, 125, 10, 45, 105, 102, 32, 123, 105,
  115, 118, 97, 108, 40, 36, 49, 41, 125, 32, 108, 49, 61, 36, 49, 32,
  45, 101, 108, 115, 101, 32, 108, 49, 61, 123, 36, 123, 49, 125, 49, 48,
  48, 48, 48, 42, 36, 100, 109, 97, 120, 47, 49, 48, 48, 125, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 105, 115, 118, 97, 108,
  40, 36, 50, 41, 125, 32, 108, 50, 61, 36, 50, 32, 45, 101, 108, 115,
  101, 32, 108, 50, 61, 123, 36, 123, 50, 125, 49, 48, 48, 48, 48, 42,
  36, 100, 109, 97, 120, 47, 49, 48, 48, 125, 32, 45, 101, 110, 100, 105,
  102, 10, 108, 49, 61, 123, 49, 47, 40, 50, 42, 109, 97, 120, 40, 49,
  47, 51, 44, 36, 108, 49, 41, 94, 50, 41, 125, 10, 108, 50, 61, 123,
  49, 47, 40, 50, 42, 109, 97, 120, 40, 49, 47, 51, 44, 36, 108, 50,
  41, 94, 50, 41, 125, 10, 65, 61, 123, 36, 108, 49, 42, 36, 117, 42,
  36, 117, 43, 36, 108, 50, 42, 36, 118, 42, 36, 118, 125, 10, 66, 61,
  123, 40, 36, 108, 49, 45, 36, 108, 50, 41, 42, 36, 117, 42, 36, 118,
  125, 10, 67, 61, 123, 36, 108, 49, 42, 36, 118, 42, 36, 118, 43, 36,
  108, 50, 42, 36, 117, 42, 36, 117, 125, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64,
  123, 48, 44, 110, 125, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104,
  125, 32, 100, 115, 61, 123, 100, 125, 44, 123, 115, 125, 32, 45, 114, 109,
  10, 40, 123, 45, 36, 119, 47, 50, 125, 44, 123, 36, 119, 47, 50, 125,
  41, 32, 45, 114, 32, 36, 119, 44, 36, 104, 44, 49, 44, 49, 44, 51,
  10, 45, 102, 91, 45, 49, 93, 32, 34, 89, 61, 121, 45, 34, 123, 36,
  104, 47, 50, 125, 59, 36, 65, 34, 42, 105, 42, 105, 43, 50, 42, 34,
  36, 66, 34, 42, 105, 42, 89, 43, 34, 36, 67, 42, 34, 89, 42, 89,
  34, 10, 45, 42, 32, 45, 49, 32, 45, 101, 120, 112, 32, 45, 114, 32,
  36, 119, 44, 36, 104, 44, 36, 100, 115, 10, 45, 110, 109, 32, 36, 110,
  109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 103, 114, 105, 100, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 36, 49, 62, 61, 48, 32, 38, 38, 32, 36, 50, 62,
  61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 48, 125,
  44, 36, 123, 52, 61, 48, 125, 44, 36, 123, 53, 61, 49, 125, 44, 36,
  123, 54, 61, 48, 125, 10, 45, 118, 32, 45, 32, 40, 123, 39, 34, 36,
  54, 34, 39, 125, 41, 32, 105, 115, 95, 112, 97, 116, 116, 101, 114, 110,
  61, 123, 64, 123, 45, 49, 44, 48, 45, 49, 125, 39, 61, 61, 39, 123,
  39, 48, 120, 39, 125, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  118, 32, 43, 10, 45, 105, 102, 32, 36, 105, 115, 95, 112, 97, 116, 116,
  101, 114, 110, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 68, 114,
  97, 119, 32, 120, 121, 45, 103, 114, 105, 100, 32, 111, 110, 32, 105, 109,
  97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101,
  115, 32, 40, 36, 49, 44, 36, 50, 41, 44, 32, 111, 102, 102, 115, 101,
  116, 115, 32, 40, 36, 51, 44, 36, 52, 41, 44, 32, 111, 112, 97, 99,
  105, 116, 121, 32, 36, 53, 44, 32, 112, 97, 116, 116, 101, 114, 110, 32,
  36, 54, 32, 97, 110, 100, 32, 99, 111, 108, 111, 114, 32, 40, 36, 123,
  55, 45, 45, 49, 125, 41, 46, 34, 10, 45, 118, 32, 45, 32, 112, 97,
  116, 116, 101, 114, 110, 61, 36, 54, 32, 99, 111, 108, 111, 114, 61, 36,
  123, 55, 45, 45, 49, 125, 10, 45, 101, 108, 115, 101, 10, 45, 101, 91,
  48, 45, 45, 51, 93, 32, 34, 68, 114, 97, 119, 32, 120, 121, 45, 103,
  114, 105, 100, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32,
  119, 105, 116, 104, 32, 115, 105, 122, 101, 115, 32, 40, 36, 49, 44, 36,
  50, 41, 44, 32, 111, 102, 102, 115, 101, 116, 115, 32, 40, 36, 51, 44,
  36, 52, 41, 44, 32, 111, 112, 97, 99, 105, 116, 121, 32, 36, 53, 44,
  32, 97, 110, 100, 32, 99, 111, 108, 111, 114, 32, 40, 36, 123, 54, 45,
  45, 49, 125, 41, 46, 34, 10, 45, 118, 32, 45, 32, 112, 97, 116, 116,
  101, 114, 110, 61, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 32, 99,
  111, 108, 111, 114, 61, 36, 123, 54, 45, 45, 49, 125, 10, 45, 101, 110,
  100, 105, 102, 10, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 115, 120,
  61, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32,
  36, 49, 125, 32, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 115, 121,
  61, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32,
  36, 50, 125, 10, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 111, 120,
  61, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32,
  36, 51, 125, 32, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 111, 121,
  61, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32,
  36, 52, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104,
  125, 32, 115, 61, 123, 115, 125, 10, 115, 105, 122, 101, 61, 123, 105, 102,
  40, 36, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 115, 120, 44, 109,
  97, 120, 40, 49, 44, 119, 42, 36, 49, 41, 44, 36, 49, 41, 125, 10,
  45, 105, 102, 32, 123, 36, 115, 105, 122, 101, 62, 61, 49, 125, 10, 111,
  102, 102, 115, 101, 116, 61, 123, 105, 102, 40, 36, 105, 115, 95, 112, 101,
  114, 99, 101, 110, 116, 111, 120, 44, 36, 115, 105, 122, 101, 42, 36, 51,
  44, 36, 51, 41, 125, 10, 40, 123, 39, 67, 73, 109, 103, 51, 100, 39,
  125, 41, 32, 45, 43, 91, 45, 49, 93, 32, 48, 46, 53, 10, 49, 44,
  123, 49, 43, 105, 110, 116, 40, 36, 119, 47, 36, 115, 105, 122, 101, 41,
  125, 44, 49, 44, 49, 44, 39, 121, 39, 32, 45, 42, 91, 45, 49, 93,
  32, 36, 115, 105, 122, 101, 32, 45, 43, 91, 45, 49, 93, 32, 123, 36,
  111, 102, 102, 115, 101, 116, 37, 36, 115, 105, 122, 101, 125, 10, 49, 44,
  123, 104, 125, 44, 49, 44, 49, 44, 123, 36, 104, 47, 50, 125, 32, 45,
  97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 122, 91, 45, 49,
  93, 32, 48, 44, 50, 32, 110, 61, 123, 104, 125, 32, 45, 105, 91, 45,
  50, 93, 32, 40, 36, 110, 59, 36, 110, 41, 10, 40, 49, 44, 48, 59,
  49, 44, 123, 36, 110, 45, 49, 125, 41, 32, 45, 114, 91, 45, 49, 93,
  32, 50, 44, 36, 110, 44, 49, 44, 49, 44, 51, 32, 45, 114, 111, 117,
  110, 100, 91, 45, 49, 93, 10, 40, 45, 49, 50, 56, 59, 49, 59, 36,
  104, 59, 36, 115, 41, 32, 49, 44, 36, 104, 44, 49, 44, 36, 115, 32,
  45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44,
  49, 48, 48, 37, 44, 49, 44, 36, 112, 97, 116, 116, 101, 114, 110, 44,
  36, 99, 111, 108, 111, 114, 10, 45, 105, 102, 32, 123, 36, 110, 62, 49,
  125, 32, 49, 44, 123, 52, 42, 40, 36, 110, 45, 49, 41, 125, 44, 49,
  44, 49, 44, 45, 49, 50, 56, 44, 48, 44, 48, 44, 48, 32, 45, 101,
  110, 100, 105, 102, 10, 40, 45, 49, 50, 56, 59, 49, 59, 36, 104, 59,
  49, 41, 32, 49, 44, 36, 104, 44, 49, 44, 49, 32, 45, 108, 105, 110,
  101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 49, 48, 48, 37,
  44, 49, 44, 36, 112, 97, 116, 116, 101, 114, 110, 44, 49, 10, 45, 105,
  102, 32, 123, 36, 110, 62, 49, 125, 32, 49, 44, 123, 52, 42, 40, 36,
  110, 45, 49, 41, 125, 44, 49, 44, 49, 44, 45, 49, 50, 56, 44, 48,
  44, 48, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 121, 91, 94,
  48, 93, 32, 45, 97, 91, 94, 48, 93, 32, 121, 32, 45, 111, 98, 106,
  101, 99, 116, 51, 100, 91, 48, 93, 32, 91, 49, 93, 44, 48, 44, 48,
  44, 48, 44, 36, 53, 44, 48, 44, 48, 44, 48, 32, 45, 114, 109, 91,
  49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 115, 105, 122, 101, 61, 123,
  105, 102, 40, 36, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 115, 121,
  44, 109, 97, 120, 40, 49, 44, 104, 42, 36, 50, 41, 44, 36, 50, 41,
  125, 10, 45, 105, 102, 32, 123, 36, 115, 105, 122, 101, 62, 61, 49, 125,
  10, 111, 102, 102, 115, 101, 116, 61, 123, 105, 102, 40, 36, 105, 115, 95,
  112, 101, 114, 99, 101, 110, 116, 111, 121, 44, 36, 115, 105, 122, 101, 42,
  36, 52, 44, 36, 52, 41, 125, 10, 40, 123, 39, 67, 73, 109, 103, 51,
  100, 39, 125, 41, 32, 45, 43, 91, 45, 49, 93, 32, 48, 46, 53, 10,
  49, 44, 123, 49, 43, 105, 110, 116, 40, 36, 104, 47, 36, 115, 105, 122,
  101, 41, 125, 44, 49, 44, 49, 44, 39, 121, 39, 32, 45, 42, 91, 45,
  49, 93, 32, 36, 115, 105, 122, 101, 32, 45, 43, 91, 45, 49, 93, 32,
  123, 36, 111, 102, 102, 115, 101, 116, 37, 36, 115, 105, 122, 101, 125, 10,
  45, 105, 91, 45, 50, 93, 32, 49, 44, 123, 104, 125, 44, 49, 44, 49,
  44, 123, 36, 119, 47, 50, 125, 32, 45, 97, 91, 45, 50, 44, 45, 49,
  93, 32, 120, 32, 45, 122, 91, 45, 49, 93, 32, 48, 44, 50, 32, 110,
  61, 123, 104, 125, 32, 45, 105, 91, 45, 50, 93, 32, 40, 36, 110, 59,
  36, 110, 41, 10, 40, 49, 44, 48, 59, 49, 44, 123, 36, 110, 45, 49,
  125, 41, 32, 45, 114, 91, 45, 49, 93, 32, 50, 44, 36, 110, 44, 49,
  44, 49, 44, 51, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 10,
  40, 45, 49, 50, 56, 59, 36, 119, 59, 49, 59, 36, 115, 41, 32, 36,
  119, 44, 49, 44, 49, 44, 36, 115, 32, 45, 108, 105, 110, 101, 91, 45,
  49, 93, 32, 48, 44, 48, 44, 49, 48, 48, 37, 44, 48, 44, 49, 44,
  36, 112, 97, 116, 116, 101, 114, 110, 44, 36, 99, 111, 108, 111, 114, 10,
  45, 105, 102, 32, 123, 36, 110, 62, 49, 125, 32, 49, 44, 123, 52, 42,
  40, 36, 110, 45, 49, 41, 125, 44, 49, 44, 49, 44, 45, 49, 50, 56,
  44, 48, 44, 48, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 40, 45,
  49, 50, 56, 59, 36, 119, 59, 49, 59, 49, 41, 32, 36, 119, 44, 49,
  44, 49, 44, 49, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 48,
  44, 48, 44, 49, 48, 48, 37, 44, 48, 44, 49, 44, 36, 112, 97, 116,
  116, 101, 114, 110, 44, 49, 10, 45, 105, 102, 32, 123, 36, 110, 62, 49,
  125, 32, 49, 44, 123, 52, 42, 40, 36, 110, 45, 49, 41, 125, 44, 49,
  44, 49, 44, 45, 49, 50, 56, 44, 48, 44, 48, 44, 48, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 121, 91, 94, 48, 93, 32, 45, 97, 91, 94,
  48, 93, 32, 121, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 44, 48, 44, 36, 53,
  44, 48, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 109, 97, 114, 98, 108, 101, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 46, 50, 125, 44, 36,
  123, 50, 61, 48, 46, 49, 125, 44, 36, 123, 51, 61, 52, 53, 125, 44,
  36, 123, 52, 61, 48, 125, 44, 36, 123, 53, 61, 48, 46, 52, 125, 44,
  36, 123, 54, 61, 48, 46, 56, 125, 44, 36, 123, 55, 61, 48, 46, 54,
  125, 44, 36, 123, 56, 61, 49, 46, 49, 125, 44, 36, 123, 57, 61, 48,
  37, 125, 44, 36, 123, 49, 48, 61, 49, 48, 48, 37, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 82, 101, 110, 100, 101, 114, 32, 109, 97,
  114, 98, 108, 101, 32, 108, 105, 107, 101, 32, 112, 97, 116, 116, 101, 114,
  110, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105,
  116, 104, 32, 105, 109, 97, 103, 101, 32, 119, 101, 105, 103, 104, 116, 32,
  36, 49, 44, 32, 112, 97, 116, 116, 101, 114, 110, 32, 119, 101, 105, 103,
  104, 116, 32, 36, 50, 44, 32, 97, 110, 103, 108, 101, 32, 36, 51, 32,
  100, 101, 103, 46, 44, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32,
  36, 52, 44, 32, 34, 92, 10, 34, 115, 104, 97, 114, 112, 110, 101, 115,
  115, 32, 36, 53, 44, 32, 97, 110, 105, 115, 111, 116, 114, 111, 112, 121,
  32, 36, 54, 44, 32, 97, 108, 112, 104, 97, 32, 36, 55, 44, 32, 115,
  105, 103, 109, 97, 32, 36, 56, 44, 32, 97, 110, 100, 32, 99, 117, 116,
  32, 40, 36, 57, 44, 36, 49, 48, 41, 46, 34, 10, 45, 118, 32, 45,
  32, 115, 120, 61, 123, 36, 50, 42, 115, 105, 110, 40, 36, 51, 42, 112,
  105, 47, 49, 56, 48, 41, 125, 32, 115, 121, 61, 123, 36, 50, 42, 99,
  111, 115, 40, 36, 51, 42, 112, 105, 47, 49, 56, 48, 41, 125, 32, 45,
  102, 32, 115, 105, 110, 40, 120, 42, 36, 115, 120, 43, 121, 42, 36, 115,
  121, 43, 105, 42, 36, 49, 41, 10, 45, 105, 102, 32, 123, 36, 52, 125,
  32, 45, 115, 109, 111, 111, 116, 104, 32, 36, 52, 44, 36, 53, 44, 36,
  54, 44, 36, 55, 44, 36, 56, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  99, 32, 36, 57, 44, 36, 49, 48, 32, 45, 110, 32, 48, 44, 50, 53,
  53, 10, 45, 118, 32, 43, 10, 109, 97, 122, 101, 32, 58, 32, 45, 99,
  104, 101, 99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 123, 49, 61,
  49, 53, 125, 41, 32, 38, 38, 32, 36, 49, 62, 48, 32, 38, 38, 32,
  105, 115, 105, 110, 116, 40, 36, 123, 50, 61, 36, 49, 125, 41, 32, 38,
  38, 32, 36, 50, 62, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40,
  36, 123, 51, 61, 50, 52, 125, 41, 32, 38, 38, 32, 36, 51, 62, 48,
  34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116,
  32, 36, 49, 120, 36, 50, 32, 109, 97, 122, 101, 46, 34, 10, 45, 118,
  32, 45, 10, 40, 123, 114, 111, 117, 110, 100, 40, 63, 40, 36, 49, 45,
  49, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 36, 50,
  45, 49, 41, 41, 125, 41, 10, 36, 49, 44, 36, 50, 44, 49, 44, 49,
  44, 49, 53, 32, 45, 45, 102, 91, 45, 49, 93, 32, 48, 32, 45, 97,
  91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 95, 103, 101, 110, 101,
  114, 97, 116, 101, 95, 109, 97, 122, 101, 32, 36, 49, 44, 36, 50, 10,
  45, 95, 114, 101, 110, 100, 101, 114, 95, 109, 97, 122, 101, 91, 45, 49,
  93, 32, 36, 51, 32, 45, 110, 109, 91, 45, 49, 93, 32, 91, 109, 97,
  122, 101, 93, 10, 45, 118, 32, 43, 10, 95, 103, 101, 110, 101, 114, 97,
  116, 101, 95, 109, 97, 122, 101, 32, 58, 10, 45, 100, 111, 10, 120, 61,
  64, 123, 45, 50, 44, 45, 50, 125, 32, 121, 61, 64, 123, 45, 50, 44,
  45, 49, 125, 10, 45, 61, 91, 45, 49, 93, 32, 49, 44, 36, 120, 44,
  36, 121, 44, 48, 44, 49, 10, 105, 115, 95, 99, 97, 110, 100, 105, 100,
  97, 116, 101, 61, 48, 10, 117, 112, 61, 45, 49, 32, 45, 105, 102, 32,
  123, 105, 40, 36, 120, 44, 36, 121, 41, 38, 56, 34, 32, 38, 38, 32,
  34, 36, 121, 62, 48, 34, 32, 38, 38, 32, 34, 33, 105, 40, 36, 120,
  44, 36, 121, 45, 49, 44, 48, 44, 49, 41, 125, 32, 117, 112, 61, 36,
  120, 44, 123, 36, 121, 45, 49, 125, 44, 56, 32, 105, 115, 95, 99, 97,
  110, 100, 105, 100, 97, 116, 101, 61, 49, 32, 45, 101, 110, 100, 105, 102,
  10, 100, 111, 119, 110, 61, 45, 49, 32, 45, 105, 102, 32, 123, 105, 40,
  36, 120, 44, 36, 121, 41, 38, 52, 34, 32, 38, 38, 32, 34, 36, 121,
  60, 36, 50, 45, 49, 34, 32, 38, 38, 32, 34, 33, 105, 40, 36, 120,
  44, 36, 121, 43, 49, 44, 48, 44, 49, 41, 125, 32, 100, 111, 119, 110,
  61, 36, 120, 44, 123, 36, 121, 43, 49, 125, 44, 52, 32, 105, 115, 95,
  99, 97, 110, 100, 105, 100, 97, 116, 101, 61, 49, 32, 45, 101, 110, 100,
  105, 102, 10, 108, 101, 102, 116, 61, 45, 49, 32, 45, 105, 102, 32, 123,
  105, 40, 36, 120, 44, 36, 121, 41, 38, 50, 34, 32, 38, 38, 32, 34,
  36, 120, 62, 48, 34, 32, 38, 38, 32, 34, 33, 105, 40, 36, 120, 45,
  49, 44, 36, 121, 44, 48, 44, 49, 41, 125, 32, 108, 101, 102, 116, 61,
  123, 36, 120, 45, 49, 125, 44, 36, 121, 44, 50, 32, 105, 115, 95, 99,
  97, 110, 100, 105, 100, 97, 116, 101, 61, 49, 32, 45, 101, 110, 100, 105,
  102, 10, 114, 105, 103, 104, 116, 61, 45, 49, 32, 45, 105, 102, 32, 123,
  105, 40, 36, 120, 44, 36, 121, 41, 38, 49, 34, 32, 38, 38, 32, 34,
  36, 120, 60, 36, 49, 45, 49, 34, 32, 38, 38, 32, 34, 33, 105, 40,
  36, 120, 43, 49, 44, 36, 121, 44, 48, 44, 49, 41, 125, 32, 114, 105,
  103, 104, 116, 61, 123, 36, 120, 43, 49, 125, 44, 36, 121, 44, 49, 32,
  105, 115, 95, 99, 97, 110, 100, 105, 100, 97, 116, 101, 61, 49, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 105, 115, 95, 99, 97,
  110, 100, 105, 100, 97, 116, 101, 10, 40, 36, 117, 112, 44, 36, 100, 111,
  119, 110, 44, 36, 108, 101, 102, 116, 44, 36, 114, 105, 103, 104, 116, 41,
  32, 45, 100, 105, 115, 99, 97, 114, 100, 91, 45, 49, 93, 32, 45, 49,
  32, 45, 114, 91, 45, 49, 93, 32, 51, 44, 123, 104, 47, 51, 125, 44,
  49, 44, 49, 44, 45, 49, 32, 45, 115, 104, 105, 102, 116, 91, 45, 49,
  93, 32, 48, 44, 123, 63, 40, 52, 41, 125, 44, 48, 44, 48, 44, 50,
  32, 45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 48, 44, 48, 32, 45,
  109, 118, 91, 45, 49, 93, 32, 45, 50, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 36, 105, 115, 95, 99, 97, 110, 100, 105, 100, 97,
  116, 101, 10, 45, 105, 102, 32, 123, 64, 123, 45, 50, 44, 45, 49, 125,
  61, 61, 56, 125, 32, 32, 32, 45, 61, 91, 45, 49, 93, 32, 123, 105,
  40, 36, 120, 44, 36, 121, 41, 38, 55, 125, 44, 36, 120, 44, 36, 121,
  32, 45, 61, 91, 45, 49, 93, 32, 123, 105, 40, 36, 120, 44, 36, 121,
  45, 49, 41, 38, 49, 49, 125, 44, 36, 120, 44, 123, 36, 121, 45, 49,
  125, 10, 45, 101, 108, 105, 102, 32, 123, 64, 123, 45, 50, 44, 45, 49,
  125, 61, 61, 52, 125, 32, 45, 61, 91, 45, 49, 93, 32, 123, 105, 40,
  36, 120, 44, 36, 121, 41, 38, 49, 49, 125, 44, 36, 120, 44, 36, 121,
  32, 45, 61, 91, 45, 49, 93, 32, 123, 105, 40, 36, 120, 44, 36, 121,
  43, 49, 41, 38, 55, 125, 44, 36, 120, 44, 123, 36, 121, 43, 49, 125,
  10, 45, 101, 108, 105, 102, 32, 123, 64, 123, 45, 50, 44, 45, 49, 125,
  61, 61, 50, 125, 32, 45, 61, 91, 45, 49, 93, 32, 123, 105, 40, 36,
  120, 44, 36, 121, 41, 38, 49, 51, 125, 44, 36, 120, 44, 36, 121, 32,
  45, 61, 91, 45, 49, 93, 32, 123, 105, 40, 36, 120, 45, 49, 44, 36,
  121, 41, 38, 49, 52, 125, 44, 123, 36, 120, 45, 49, 125, 44, 36, 121,
  10, 45, 101, 108, 115, 101, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 45, 61, 91, 45, 49, 93, 32, 123, 105, 40, 36,
  120, 44, 36, 121, 41, 38, 49, 52, 125, 44, 36, 120, 44, 36, 121, 32,
  45, 61, 91, 45, 49, 93, 32, 123, 105, 40, 36, 120, 43, 49, 44, 36,
  121, 41, 38, 49, 51, 125, 44, 123, 36, 120, 43, 49, 125, 44, 36, 121,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 122, 91, 45, 50, 93, 32, 48,
  44, 49, 32, 45, 97, 91, 45, 51, 44, 45, 50, 93, 32, 121, 10, 45,
  101, 108, 115, 101, 10, 45, 105, 102, 32, 123, 64, 123, 45, 50, 44, 104,
  125, 61, 61, 49, 125, 32, 45, 98, 114, 101, 97, 107, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 114, 111, 119, 115, 91, 45, 50, 93, 32, 48, 44,
  123, 64, 123, 45, 50, 44, 104, 125, 45, 50, 125, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 49, 10, 45, 114, 109, 91,
  45, 50, 93, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49,
  93, 32, 48, 10, 95, 114, 101, 110, 100, 101, 114, 95, 109, 97, 122, 101,
  32, 58, 10, 45, 105, 91, 48, 93, 32, 36, 49, 44, 36, 49, 32, 45,
  105, 91, 49, 93, 32, 91, 48, 93, 120, 49, 53, 10, 45, 108, 105, 110,
  101, 91, 56, 45, 49, 53, 93, 32, 48, 44, 48, 44, 49, 48, 48, 37,
  44, 48, 44, 49, 44, 49, 10, 45, 108, 105, 110, 101, 91, 52, 45, 55,
  44, 49, 50, 45, 49, 53, 93, 32, 48, 44, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 10, 45, 108, 105,
  110, 101, 91, 50, 45, 51, 44, 54, 45, 55, 44, 49, 48, 45, 49, 49,
  44, 49, 52, 45, 49, 53, 93, 32, 48, 44, 48, 44, 48, 44, 49, 48,
  48, 37, 44, 49, 44, 49, 10, 45, 108, 105, 110, 101, 91, 49, 45, 49,
  53, 58, 50, 93, 32, 49, 48, 48, 37, 44, 48, 44, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 44, 49, 10, 45, 97, 91, 48, 45, 49,
  53, 93, 32, 120, 32, 45, 114, 91, 45, 49, 93, 32, 123, 119, 42, 36,
  49, 125, 44, 123, 104, 42, 36, 49, 125, 32, 45, 42, 91, 45, 49, 93,
  32, 36, 49, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49,
  93, 32, 48, 44, 49, 10, 36, 49, 44, 36, 49, 44, 49, 44, 49, 44,
  120, 32, 36, 49, 44, 36, 49, 44, 49, 44, 49, 44, 121, 32, 45, 97,
  91, 45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 114, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 50, 44, 48,
  44, 50, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 119, 97,
  114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 44,
  48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 109, 97, 122, 101, 95, 109,
  97, 115, 107, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115,
  105, 110, 116, 40, 36, 123, 49, 61, 50, 52, 125, 41, 32, 38, 38, 32,
  36, 49, 62, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73,
  110, 112, 117, 116, 32, 109, 97, 115, 107, 101, 100, 32, 109, 97, 122, 101,
  32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 32, 119, 105,
  116, 104, 32, 99, 101, 108, 108, 32, 115, 105, 122, 101, 32, 36, 49, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 110, 111, 114, 109, 32, 45, 103, 101,
  32, 53, 48, 37, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 100, 111, 10, 45, 45, 114, 97, 110,
  100, 91, 48, 93, 32, 48, 44, 49, 32, 45, 42, 91, 45, 49, 93, 32,
  91, 48, 93, 32, 40, 123, 120, 77, 125, 44, 123, 121, 77, 125, 41, 32,
  45, 114, 109, 91, 45, 50, 93, 10, 45, 45, 102, 108, 111, 111, 100, 91,
  48, 93, 32, 64, 45, 49, 44, 48, 44, 48, 44, 48, 44, 49, 44, 50,
  32, 45, 103, 101, 91, 45, 49, 93, 32, 50, 32, 45, 45, 110, 101, 103,
  97, 116, 105, 118, 101, 91, 45, 49, 93, 32, 45, 42, 91, 45, 50, 93,
  32, 49, 53, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10,
  45, 102, 108, 111, 111, 100, 91, 48, 93, 32, 64, 45, 50, 44, 48, 44,
  48, 44, 48, 44, 49, 44, 48, 10, 45, 95, 103, 101, 110, 101, 114, 97,
  116, 101, 95, 109, 97, 122, 101, 32, 123, 119, 125, 44, 123, 104, 125, 10,
  45, 119, 104, 105, 108, 101, 32, 64, 123, 48, 44, 77, 125, 10, 45, 114,
  109, 91, 48, 93, 32, 45, 43, 32, 45, 95, 114, 101, 110, 100, 101, 114,
  95, 109, 97, 122, 101, 91, 45, 49, 93, 32, 36, 49, 32, 45, 110, 109,
  91, 45, 49, 93, 32, 91, 109, 97, 122, 101, 93, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 112, 97, 99,
  107, 95, 115, 112, 114, 105, 116, 101, 115, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 53, 125,
  41, 32, 38, 38, 32, 36, 49, 62, 61, 48, 32, 38, 38, 32, 36, 123,
  50, 61, 50, 53, 125, 62, 61, 48, 32, 38, 38, 32, 36, 50, 60, 61,
  49, 48, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 51,
  61, 51, 125, 41, 32, 38, 38, 32, 36, 51, 62, 61, 48, 32, 38, 38,
  32, 36, 51, 60, 61, 51, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40,
  36, 123, 52, 61, 49, 125, 41, 32, 38, 38, 32, 105, 115, 105, 110, 116,
  40, 36, 123, 53, 61, 55, 125, 41, 32, 38, 38, 32, 36, 53, 62, 61,
  48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 54, 61, 50,
  53, 54, 125, 41, 32, 38, 38, 32, 36, 54, 62, 61, 48, 34, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 82, 97, 110, 100, 111, 109, 108, 121,
  32, 112, 97, 99, 107, 32, 105, 109, 97, 103, 101, 36, 63, 32, 119, 105,
  116, 104, 32, 36, 49, 32, 115, 99, 97, 108, 101, 115, 44, 32, 109, 105,
  110, 105, 109, 117, 109, 32, 115, 99, 97, 108, 101, 32, 36, 50, 37, 44,
  32, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 36, 51, 44, 110,
  111, 44, 49, 56, 48, 92, 34, 92, 32, 92, 34, 100, 101, 103, 46, 44,
  57, 48, 92, 34, 92, 32, 92, 34, 100, 101, 103, 46, 44, 97, 110, 121,
  125, 34, 32, 114, 111, 116, 97, 116, 105, 111, 110, 44, 32, 115, 112, 97,
  99, 105, 110, 103, 32, 36, 52, 44, 32, 112, 114, 101, 99, 105, 115, 105,
  111, 110, 32, 36, 53, 32, 97, 110, 100, 32, 36, 54, 32, 109, 97, 120,
  105, 109, 117, 109, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 46,
  34, 10, 45, 118, 32, 45, 32, 78, 61, 123, 64, 35, 45, 49, 125, 32,
  105, 115, 95, 102, 105, 114, 115, 116, 95, 116, 105, 109, 101, 61, 49, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 114, 91, 36, 62,
  93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 123, 109,
  97, 120, 40, 50, 44, 64, 123, 36, 62, 44, 115, 125, 41, 125, 32, 45,
  100, 111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 10,
  45, 114, 112, 114, 111, 103, 114, 101, 115, 115, 32, 123, 36, 62, 42, 49,
  48, 48, 47, 36, 49, 125, 10, 110, 98, 95, 97, 116, 116, 101, 109, 112,
  116, 115, 61, 48, 10, 114, 97, 116, 105, 111, 61, 123, 105, 102, 40, 36,
  49, 62, 49, 44, 36, 50, 43, 40, 49, 48, 48, 45, 36, 50, 41, 42,
  36, 60, 47, 40, 36, 49, 45, 49, 41, 44, 49, 48, 48, 41, 125, 37,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 78, 32, 45, 45, 108, 91,
  123, 49, 43, 36, 62, 125, 93, 10, 119, 61, 123, 119, 42, 36, 114, 97,
  116, 105, 111, 125, 32, 104, 61, 123, 104, 42, 36, 114, 97, 116, 105, 111,
  125, 10, 45, 105, 102, 32, 123, 36, 119, 60, 49, 124, 124, 36, 104, 60,
  49, 125, 32, 45, 114, 109, 10, 45, 101, 108, 115, 101, 32, 45, 114, 32,
  36, 119, 44, 36, 104, 44, 49, 44, 49, 48, 48, 37, 44, 50, 32, 45,
  115, 104, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  32, 45, 110, 101, 113, 91, 45, 49, 93, 32, 48, 32, 97, 114, 101, 97,
  123, 49, 43, 36, 62, 125, 61, 64, 123, 45, 49, 44, 43, 125, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 108, 91, 48, 44, 123,
  36, 78, 43, 49, 125, 45, 45, 49, 93, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 36, 54, 10, 105, 110, 100, 61, 123, 49, 43, 40, 36, 62, 37,
  36, 78, 41, 125, 32, 97, 114, 101, 97, 61, 36, 123, 97, 114, 101, 97,
  36, 105, 110, 100, 125, 10, 45, 105, 102, 32, 123, 36, 51, 61, 61, 48,
  125, 32, 91, 36, 105, 110, 100, 93, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 51, 61, 61, 49, 125, 32, 45, 45, 114, 111, 116, 97, 116, 101, 91,
  36, 105, 110, 100, 93, 32, 123, 114, 111, 117, 110, 100, 40, 63, 41, 42,
  49, 56, 48, 125, 10, 45, 101, 108, 105, 102, 32, 123, 36, 51, 61, 61,
  50, 125, 32, 45, 45, 114, 111, 116, 97, 116, 101, 91, 36, 105, 110, 100,
  93, 32, 123, 114, 111, 117, 110, 100, 40, 63, 40, 51, 41, 41, 42, 57,
  48, 125, 10, 45, 101, 108, 115, 101, 32, 45, 45, 114, 111, 116, 97, 116,
  101, 91, 36, 105, 110, 100, 93, 32, 123, 63, 42, 51, 54, 48, 125, 32,
  45, 115, 104, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 32, 45, 110, 101, 113, 91, 45, 49, 93, 32, 48, 32, 97, 114, 101,
  97, 61, 64, 123, 45, 49, 44, 43, 125, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 91, 48, 93, 32, 49, 48, 48, 37, 32, 45, 101, 113, 91,
  45, 49, 93, 32, 48, 10, 45, 105, 102, 32, 123, 36, 52, 62, 49, 125,
  32, 45, 101, 114, 111, 100, 101, 91, 45, 49, 93, 32, 123, 50, 42, 36,
  52, 45, 49, 125, 10, 45, 101, 108, 105, 102, 32, 123, 36, 52, 60, 49,
  125, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 123, 45,
  50, 42, 36, 52, 43, 51, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48,
  44, 48, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 48,
  120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 10, 45, 105, 102, 32,
  36, 105, 115, 95, 102, 105, 114, 115, 116, 95, 116, 105, 109, 101, 32, 45,
  110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 48, 46, 49, 44, 50, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 100, 105, 115, 116, 97, 110, 99, 101,
  91, 45, 49, 93, 32, 48, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49,
  93, 32, 49, 44, 49, 10, 45, 109, 97, 120, 95, 112, 97, 116, 99, 104,
  91, 45, 49, 93, 32, 123, 114, 111, 117, 110, 100, 40, 49, 46, 53, 42,
  64, 123, 36, 105, 110, 100, 44, 109, 97, 120, 40, 119, 44, 104, 41, 125,
  41, 125, 10, 45, 42, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45,
  112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 51, 100, 91, 45, 49, 93,
  10, 45, 105, 102, 32, 123, 36, 78, 62, 49, 125, 32, 45, 108, 91, 45,
  49, 93, 10, 45, 115, 51, 100, 32, 45, 47, 91, 49, 93, 32, 36, 78,
  32, 45, 114, 111, 117, 110, 100, 91, 49, 93, 32, 45, 109, 97, 120, 91,
  49, 93, 32, 49, 32, 110, 61, 64, 123, 49, 44, 48, 125, 10, 45, 114,
  91, 50, 93, 32, 51, 44, 123, 64, 123, 50, 44, 104, 125, 47, 51, 125,
  44, 49, 44, 49, 44, 45, 49, 10, 45, 105, 91, 50, 93, 32, 49, 44,
  64, 123, 50, 44, 104, 125, 32, 45, 114, 97, 110, 100, 91, 50, 93, 32,
  48, 44, 49, 32, 45, 97, 91, 50, 44, 51, 93, 32, 120, 32, 45, 115,
  111, 114, 116, 91, 50, 93, 32, 43, 44, 121, 32, 45, 122, 91, 50, 93,
  32, 49, 44, 51, 32, 45, 114, 91, 50, 93, 32, 51, 44, 36, 110, 44,
  49, 44, 49, 32, 45, 121, 91, 50, 93, 10, 45, 114, 91, 51, 93, 32,
  49, 44, 123, 50, 42, 36, 110, 125, 44, 49, 44, 49, 44, 48, 32, 45,
  114, 91, 52, 93, 32, 49, 44, 123, 51, 42, 36, 110, 125, 44, 49, 44,
  49, 44, 48, 32, 45, 114, 91, 53, 93, 32, 49, 44, 36, 110, 44, 49,
  44, 49, 44, 48, 32, 45, 97, 32, 121, 10, 45, 101, 110, 100, 108, 32,
  45, 101, 110, 100, 105, 102, 10, 110, 61, 64, 123, 45, 49, 44, 55, 125,
  10, 45, 105, 102, 32, 36, 110, 10, 45, 115, 51, 100, 91, 45, 49, 93,
  32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 105, 102, 32,
  123, 36, 51, 61, 61, 48, 125, 10, 91, 45, 54, 93, 32, 45, 105, 91,
  45, 50, 93, 32, 40, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104,
  125, 59, 123, 115, 125, 41, 10, 45, 105, 102, 32, 123, 36, 110, 62, 49,
  125, 32, 52, 44, 123, 36, 110, 45, 49, 125, 44, 49, 44, 49, 44, 45,
  49, 50, 56, 44, 48, 44, 48, 44, 48, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 50, 93, 32,
  49, 48, 48, 37, 32, 45, 105, 91, 45, 50, 93, 32, 40, 45, 49, 50,
  56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 123, 115, 125, 41, 10, 45,
  105, 102, 32, 123, 36, 110, 62, 49, 125, 32, 91, 45, 51, 93, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 108, 105, 102, 32, 123, 36, 51, 61,
  61, 49, 125, 10, 45, 45, 114, 111, 116, 97, 116, 101, 91, 45, 54, 93,
  32, 123, 114, 111, 117, 110, 100, 40, 63, 40, 49, 41, 41, 42, 49, 56,
  48, 125, 32, 45, 105, 91, 45, 50, 93, 32, 40, 45, 49, 50, 56, 59,
  123, 119, 125, 59, 123, 104, 125, 59, 123, 115, 125, 41, 10, 45, 105, 102,
  32, 123, 36, 110, 62, 49, 125, 32, 45, 45, 114, 111, 116, 97, 116, 101,
  91, 45, 49, 93, 32, 49, 56, 48, 32, 45, 105, 91, 45, 50, 93, 32,
  40, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 123, 115,
  125, 41, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  110, 62, 50, 125, 32, 52, 44, 123, 36, 110, 45, 50, 125, 44, 49, 44,
  49, 44, 45, 49, 50, 56, 44, 48, 44, 48, 44, 48, 32, 49, 44, 49,
  48, 48, 37, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44,
  49, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 49, 32, 45,
  106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 45, 52, 93, 32, 49, 48, 48, 37, 32,
  45, 105, 91, 45, 50, 93, 32, 40, 45, 49, 50, 56, 59, 123, 119, 125,
  59, 123, 104, 125, 59, 123, 115, 125, 41, 10, 45, 105, 102, 32, 123, 36,
  110, 62, 49, 125, 32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91,
  45, 52, 93, 32, 49, 48, 48, 37, 32, 45, 105, 91, 45, 50, 93, 32,
  40, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 123, 115,
  125, 41, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  110, 62, 50, 125, 32, 91, 45, 53, 93, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 108, 115, 101, 10, 45, 45, 114, 111, 116, 97, 116, 101, 91,
  45, 54, 93, 32, 123, 114, 111, 117, 110, 100, 40, 63, 40, 51, 41, 41,
  42, 57, 48, 125, 32, 45, 105, 91, 45, 50, 93, 32, 40, 45, 49, 50,
  56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 123, 115, 125, 41, 10, 45,
  105, 102, 32, 123, 36, 110, 62, 49, 125, 32, 45, 45, 114, 111, 116, 97,
  116, 101, 91, 45, 49, 93, 32, 57, 48, 32, 45, 105, 91, 45, 50, 93,
  32, 40, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 123,
  115, 125, 41, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 110, 62, 50, 125, 32, 45, 45, 114, 111, 116, 97, 116, 101, 91, 45,
  49, 93, 32, 57, 48, 32, 45, 105, 91, 45, 50, 93, 32, 40, 45, 49,
  50, 56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 123, 115, 125, 41, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 110, 62, 51,
  125, 32, 45, 45, 114, 111, 116, 97, 116, 101, 91, 45, 49, 93, 32, 57,
  48, 32, 45, 105, 91, 45, 50, 93, 32, 40, 45, 49, 50, 56, 59, 123,
  119, 125, 59, 123, 104, 125, 59, 123, 115, 125, 41, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 110, 62, 52, 125, 32, 52, 44,
  123, 36, 110, 45, 52, 125, 44, 49, 44, 49, 44, 45, 49, 50, 56, 44,
  48, 44, 48, 44, 48, 32, 49, 44, 49, 48, 48, 37, 32, 45, 114, 97,
  110, 100, 91, 45, 49, 93, 32, 48, 44, 51, 32, 45, 114, 111, 117, 110,
  100, 91, 45, 49, 93, 32, 49, 32, 45, 106, 91, 45, 50, 93, 32, 91,
  45, 49, 93, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91,
  45, 56, 93, 32, 49, 48, 48, 37, 32, 45, 105, 91, 45, 50, 93, 32,
  40, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 123, 115,
  125, 41, 10, 45, 105, 102, 32, 123, 36, 110, 62, 49, 125, 32, 45, 45,
  99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 56, 93, 32, 49, 48, 48,
  37, 32, 45, 105, 91, 45, 50, 93, 32, 40, 45, 49, 50, 56, 59, 123,
  119, 125, 59, 123, 104, 125, 59, 123, 115, 125, 41, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 110, 62, 50, 125, 32, 45, 45,
  99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 56, 93, 32, 49, 48, 48,
  37, 32, 45, 105, 91, 45, 50, 93, 32, 40, 45, 49, 50, 56, 59, 123,
  119, 125, 59, 123, 104, 125, 59, 123, 115, 125, 41, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 110, 62, 51, 125, 32, 45, 45,
  99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 56, 93, 32, 49, 48, 48,
  37, 32, 45, 105, 91, 45, 50, 93, 32, 40, 45, 49, 50, 56, 59, 123,
  119, 125, 59, 123, 104, 125, 59, 123, 115, 125, 41, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 110, 62, 52, 125, 32, 91, 45,
  57, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 121, 91, 123, 36, 78, 43, 51, 125, 45, 45, 49, 93, 32, 45,
  97, 91, 123, 36, 78, 43, 51, 125, 45, 45, 49, 93, 32, 121, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 51, 93, 10, 91, 48,
  93, 32, 45, 115, 104, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 32, 45, 102, 91, 45, 49, 93, 32, 49, 32, 45, 45, 91,
  45, 49, 93, 32, 91, 45, 52, 93, 10, 45, 111, 98, 106, 101, 99, 116,
  51, 100, 91, 45, 50, 93, 32, 91, 45, 51, 93, 44, 48, 44, 48, 44,
  48, 44, 49, 44, 50, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 51,
  44, 45, 49, 93, 10, 45, 115, 104, 91, 45, 49, 93, 32, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 32, 45, 97, 114, 101, 97, 95, 102, 103, 91,
  45, 49, 93, 32, 48, 44, 49, 32, 45, 101, 113, 91, 45, 49, 93, 32,
  36, 97, 114, 101, 97, 10, 45, 42, 91, 45, 49, 93, 32, 91, 45, 51,
  93, 32, 45, 114, 109, 91, 45, 51, 93, 32, 45, 115, 104, 91, 45, 50,
  93, 32, 48, 44, 64, 123, 45, 50, 44, 115, 45, 50, 125, 32, 45, 42,
  91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 105, 102, 32, 123, 105, 77, 125, 32, 45, 106, 91, 48, 93,
  32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44,
  91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10,
  45, 101, 108, 115, 101, 10, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93,
  10, 110, 98, 95, 97, 116, 116, 101, 109, 112, 116, 115, 61, 123, 36, 110,
  98, 95, 97, 116, 116, 101, 109, 112, 116, 115, 43, 49, 125, 10, 45, 105,
  102, 32, 123, 36, 110, 98, 95, 97, 116, 116, 101, 109, 112, 116, 115, 62,
  36, 53, 125, 32, 45, 98, 114, 101, 97, 107, 32, 45, 101, 108, 115, 101,
  32, 45, 99, 111, 110, 116, 105, 110, 117, 101, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 32, 45,
  107, 91, 48, 93, 32, 45, 101, 110, 100, 108, 10, 45, 100, 111, 110, 101,
  32, 45, 107, 91, 48, 93, 32, 45, 118, 32, 43, 10, 112, 105, 101, 99,
  104, 97, 114, 116, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 49,
  62, 61, 48, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 114, 97,
  119, 32, 112, 105, 101, 32, 99, 104, 97, 114, 116, 32, 111, 110, 32, 105,
  109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 108, 97, 98,
  101, 108, 32, 104, 101, 105, 103, 104, 116, 32, 36, 49, 32, 97, 110, 100,
  32, 99, 111, 108, 111, 114, 32, 40, 36, 50, 44, 36, 51, 44, 36, 52,
  41, 46, 34, 10, 45, 118, 32, 45, 32, 36, 61, 97, 114, 103, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 101, 108, 108, 105, 112, 115, 101, 32, 53, 48, 37, 44, 53, 48,
  37, 44, 123, 119, 47, 50, 45, 49, 125, 44, 123, 104, 47, 50, 45, 49,
  125, 44, 48, 44, 49, 44, 49, 10, 45, 101, 108, 108, 105, 112, 115, 101,
  32, 53, 48, 37, 44, 53, 48, 37, 44, 123, 119, 47, 50, 45, 49, 125,
  44, 123, 104, 47, 50, 45, 49, 125, 44, 48, 44, 49, 44, 48, 120, 70,
  70, 70, 70, 70, 70, 70, 70, 10, 40, 36, 123, 54, 45, 45, 49, 58,
  53, 125, 41, 32, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 115,
  117, 109, 91, 45, 49, 93, 10, 116, 104, 101, 116, 97, 61, 48, 10, 45,
  105, 102, 32, 123, 119, 62, 49, 125, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 123, 119, 125, 10, 120, 101, 61, 123, 48, 46, 53, 42, 64, 123, 45,
  50, 44, 119, 125, 42, 40, 49, 43, 99, 111, 115, 40, 36, 116, 104, 101,
  116, 97, 41, 41, 125, 10, 121, 101, 61, 123, 48, 46, 53, 42, 64, 123,
  45, 50, 44, 104, 125, 42, 40, 49, 43, 115, 105, 110, 40, 36, 116, 104,
  101, 116, 97, 41, 41, 125, 10, 45, 108, 105, 110, 101, 91, 45, 50, 93,
  32, 53, 48, 37, 44, 53, 48, 37, 44, 36, 120, 101, 44, 36, 121, 101,
  10, 116, 104, 101, 116, 97, 61, 123, 36, 116, 104, 101, 116, 97, 45, 50,
  42, 112, 105, 42, 105, 40, 36, 62, 41, 125, 10, 45, 100, 111, 110, 101,
  32, 45, 101, 110, 100, 105, 102, 10, 116, 104, 101, 116, 97, 61, 48, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 119, 125, 32, 45, 105, 102, 32,
  123, 105, 40, 36, 62, 41, 125, 10, 110, 116, 104, 101, 116, 97, 61, 123,
  36, 116, 104, 101, 116, 97, 45, 50, 42, 112, 105, 42, 105, 40, 36, 62,
  41, 125, 10, 120, 99, 61, 123, 48, 46, 53, 42, 64, 123, 45, 50, 44,
  119, 125, 42, 40, 49, 43, 48, 46, 53, 42, 99, 111, 115, 40, 48, 46,
  53, 42, 40, 36, 110, 116, 104, 101, 116, 97, 43, 36, 116, 104, 101, 116,
  97, 41, 41, 41, 125, 10, 121, 99, 61, 123, 48, 46, 53, 42, 64, 123,
  45, 50, 44, 104, 125, 42, 40, 49, 43, 48, 46, 53, 42, 115, 105, 110,
  40, 48, 46, 53, 42, 40, 36, 110, 116, 104, 101, 116, 97, 43, 36, 116,
  104, 101, 116, 97, 41, 41, 41, 125, 10, 120, 102, 61, 123, 48, 46, 53,
  42, 64, 123, 45, 50, 44, 119, 125, 42, 40, 49, 43, 48, 46, 56, 42,
  99, 111, 115, 40, 48, 46, 53, 42, 40, 36, 110, 116, 104, 101, 116, 97,
  43, 36, 116, 104, 101, 116, 97, 41, 41, 41, 125, 10, 121, 102, 61, 123,
  48, 46, 53, 42, 64, 123, 45, 50, 44, 104, 125, 42, 40, 49, 43, 48,
  46, 56, 42, 115, 105, 110, 40, 48, 46, 53, 42, 40, 36, 110, 116, 104,
  101, 116, 97, 43, 36, 116, 104, 101, 116, 97, 41, 41, 41, 125, 10, 45,
  102, 108, 111, 111, 100, 91, 45, 50, 93, 32, 36, 120, 102, 44, 36, 121,
  102, 44, 48, 44, 48, 44, 48, 44, 49, 44, 36, 123, 97, 114, 103, 123,
  55, 43, 53, 42, 36, 62, 125, 125, 44, 36, 123, 97, 114, 103, 123, 56,
  43, 53, 42, 36, 62, 125, 125, 44, 36, 123, 97, 114, 103, 123, 57, 43,
  53, 42, 36, 62, 125, 125, 10, 45, 105, 102, 32, 123, 97, 98, 115, 40,
  36, 110, 116, 104, 101, 116, 97, 45, 36, 116, 104, 101, 116, 97, 41, 62,
  48, 46, 49, 125, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 36, 123,
  97, 114, 103, 123, 53, 43, 53, 42, 36, 62, 125, 125, 44, 48, 44, 48,
  44, 36, 49, 44, 49, 44, 49, 10, 40, 36, 50, 94, 36, 51, 94, 36,
  52, 41, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91,
  45, 50, 93, 44, 49, 44, 51, 32, 45, 42, 91, 45, 49, 93, 32, 91,
  45, 50, 93, 10, 45, 106, 91, 45, 52, 93, 32, 91, 45, 49, 93, 44,
  123, 36, 120, 99, 45, 119, 47, 50, 125, 44, 123, 36, 121, 99, 45, 104,
  47, 50, 125, 44, 48, 44, 48, 44, 49, 44, 91, 45, 50, 93, 10, 45,
  114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102,
  10, 116, 104, 101, 116, 97, 61, 36, 110, 116, 104, 101, 116, 97, 10, 45,
  101, 110, 100, 105, 102, 32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 112, 111, 108, 107, 97, 95, 100, 111, 116, 115, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 49, 62, 61, 48, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 50, 61, 50, 48, 125, 44, 36, 123, 51,
  61, 53, 48, 125, 44, 36, 123, 52, 61, 53, 48, 125, 44, 36, 123, 53,
  61, 48, 125, 44, 36, 123, 54, 61, 49, 48, 125, 44, 36, 123, 55, 61,
  49, 125, 44, 36, 123, 56, 61, 49, 125, 44, 36, 123, 57, 61, 50, 53,
  53, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 114, 97, 119,
  32, 112, 111, 108, 107, 97, 32, 100, 111, 116, 115, 32, 111, 110, 32, 105,
  109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 100, 105, 97,
  109, 101, 116, 101, 114, 32, 36, 49, 44, 32, 100, 101, 110, 115, 105, 116,
  121, 32, 36, 50, 44, 32, 97, 110, 103, 108, 101, 32, 36, 51, 32, 100,
  101, 103, 46, 44, 32, 115, 104, 105, 102, 116, 32, 40, 36, 52, 44, 36,
  53, 41, 44, 32, 97, 108, 105, 97, 115, 105, 110, 103, 32, 36, 54, 32,
  97, 110, 100, 32, 115, 104, 97, 100, 105, 110, 103, 32, 36, 55, 46, 34,
  10, 45, 118, 32, 45, 32, 116, 104, 101, 116, 97, 61, 123, 36, 53, 42,
  112, 105, 47, 49, 56, 48, 125, 32, 99, 116, 61, 123, 99, 111, 115, 40,
  36, 116, 104, 101, 116, 97, 41, 125, 32, 115, 116, 61, 123, 115, 105, 110,
  40, 36, 116, 104, 101, 116, 97, 41, 125, 32, 109, 105, 100, 49, 61, 123,
  36, 49, 47, 50, 125, 32, 109, 105, 100, 50, 61, 123, 36, 50, 47, 50,
  125, 10, 45, 105, 91, 48, 93, 32, 40, 36, 123, 57, 45, 45, 49, 125,
  41, 32, 45, 121, 91, 48, 93, 32, 99, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 64, 35, 45, 49, 125, 10, 87, 72, 61, 123, 109, 97, 120,
  40, 119, 44, 104, 41, 125, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 44, 34, 120, 110, 32, 61, 32, 49, 48,
  48, 42, 120, 47, 34, 36, 87, 72, 34, 45, 36, 51, 59, 32, 121, 110,
  32, 61, 32, 49, 48, 48, 42, 121, 47, 34, 36, 87, 72, 34, 45, 36,
  52, 59, 32, 92, 10, 120, 114, 32, 61, 32, 120, 110, 42, 34, 36, 99,
  116, 34, 45, 121, 110, 42, 34, 36, 115, 116, 34, 59, 32, 121, 114, 32,
  61, 32, 120, 110, 42, 34, 36, 115, 116, 34, 43, 121, 110, 42, 34, 36,
  99, 116, 34, 59, 32, 92, 10, 120, 99, 32, 61, 32, 120, 114, 37, 36,
  50, 45, 34, 36, 109, 105, 100, 50, 34, 59, 32, 121, 99, 32, 61, 32,
  121, 114, 37, 36, 50, 45, 34, 36, 109, 105, 100, 50, 34, 59, 32, 92,
  10, 34, 36, 109, 105, 100, 49, 34, 45, 115, 113, 114, 116, 40, 120, 99,
  42, 120, 99, 43, 121, 99, 42, 121, 99, 41, 34, 10, 45, 42, 91, 45,
  49, 93, 32, 36, 54, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 36,
  55, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 36, 56, 32, 40, 36,
  123, 57, 45, 45, 49, 125, 41, 32, 45, 121, 91, 45, 49, 93, 32, 99,
  32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50,
  93, 44, 91, 45, 50, 93, 10, 45, 106, 91, 45, 51, 93, 32, 91, 45,
  49, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 50,
  93, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 109, 118,
  91, 45, 49, 93, 32, 49, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109,
  91, 48, 93, 32, 45, 118, 32, 43, 10, 114, 101, 99, 116, 97, 110, 103,
  108, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 53, 61, 49,
  125, 44, 36, 123, 54, 61, 48, 125, 10, 45, 118, 32, 45, 32, 40, 123,
  39, 34, 36, 53, 34, 39, 125, 41, 32, 105, 115, 95, 112, 97, 116, 116,
  101, 114, 110, 61, 123, 64, 123, 45, 49, 44, 48, 45, 49, 125, 39, 61,
  61, 39, 123, 39, 48, 120, 39, 125, 125, 32, 45, 114, 109, 91, 45, 49,
  93, 32, 45, 118, 32, 43, 10, 45, 105, 102, 32, 36, 105, 115, 95, 112,
  97, 116, 116, 101, 114, 110, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32,
  34, 68, 114, 97, 119, 32, 111, 117, 116, 108, 105, 110, 101, 100, 32, 114,
  101, 99, 116, 97, 110, 103, 108, 101, 32, 102, 114, 111, 109, 32, 40, 36,
  49, 44, 36, 50, 41, 32, 116, 111, 32, 40, 36, 51, 44, 36, 52, 41,
  32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116,
  104, 32, 111, 112, 97, 99, 105, 116, 121, 32, 36, 53, 32, 97, 110, 100,
  32, 99, 111, 108, 111, 114, 32, 40, 36, 123, 55, 45, 45, 49, 125, 41,
  46, 34, 10, 45, 101, 108, 115, 101, 10, 45, 101, 91, 48, 45, 45, 51,
  93, 32, 34, 68, 114, 97, 119, 32, 102, 105, 108, 108, 101, 100, 32, 114,
  101, 99, 116, 97, 110, 103, 108, 101, 32, 102, 114, 111, 109, 32, 40, 36,
  49, 44, 36, 50, 41, 32, 116, 111, 32, 40, 36, 51, 44, 36, 52, 41,
  32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116,
  104, 32, 111, 112, 97, 99, 105, 116, 121, 32, 36, 53, 32, 97, 110, 100,
  32, 99, 111, 108, 111, 114, 32, 40, 36, 123, 54, 45, 45, 49, 125, 41,
  46, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 32, 45,
  112, 111, 108, 121, 103, 111, 110, 32, 52, 44, 36, 49, 44, 36, 50, 44,
  36, 51, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 49, 44, 36,
  52, 44, 36, 123, 53, 45, 45, 49, 125, 32, 45, 118, 32, 43, 10, 114,
  111, 114, 115, 99, 104, 97, 99, 104, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 34, 36, 123, 49, 61, 53, 37, 125, 62, 61, 48, 32, 38, 38,
  32, 105, 115, 105, 110, 116, 40, 36, 123, 50, 61, 49, 125, 41, 32, 38,
  38, 32, 36, 50, 62, 61, 48, 32, 38, 38, 32, 36, 50, 60, 61, 51,
  34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 110, 100, 101,
  114, 32, 114, 111, 114, 115, 99, 104, 97, 99, 104, 45, 108, 105, 107, 101,
  32, 105, 110, 107, 98, 108, 111, 116, 115, 32, 111, 110, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 115, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 36, 49, 32, 97, 110, 100, 32, 34, 64, 123,
  45, 97, 114, 103, 92, 32, 49, 43, 36, 50, 44, 110, 111, 44, 120, 44,
  121, 44, 120, 121, 125, 34, 45, 109, 105, 114, 114, 111, 114, 105, 110, 103,
  46, 34, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 123, 36, 50, 61,
  61, 48, 125, 10, 45, 114, 97, 110, 100, 32, 45, 49, 44, 49, 32, 45,
  98, 32, 36, 49, 32, 45, 103, 101, 32, 48, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 50, 61, 61, 49, 125, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 61, 123, 119, 125,
  10, 45, 99, 111, 108, 117, 109, 110, 115, 32, 48, 44, 123, 119, 47, 50,
  45, 49, 125, 32, 45, 114, 97, 110, 100, 32, 45, 49, 44, 49, 32, 45,
  98, 32, 36, 49, 32, 45, 103, 101, 32, 48, 10, 45, 45, 109, 105, 114,
  114, 111, 114, 32, 120, 32, 45, 105, 102, 32, 123, 36, 119, 37, 50, 125,
  32, 45, 99, 111, 108, 117, 109, 110, 115, 91, 45, 49, 93, 32, 49, 44,
  49, 48, 48, 37, 32, 45, 101, 110, 100, 105, 102, 32, 45, 97, 32, 120,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 50, 61, 61, 50, 125, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 104, 61, 123,
  104, 125, 10, 45, 114, 111, 119, 115, 32, 48, 44, 123, 104, 47, 50, 45,
  49, 125, 32, 45, 114, 97, 110, 100, 32, 45, 49, 44, 49, 32, 45, 98,
  32, 36, 49, 32, 45, 103, 101, 32, 48, 10, 45, 45, 109, 105, 114, 114,
  111, 114, 32, 121, 32, 45, 105, 102, 32, 123, 36, 104, 37, 50, 125, 32,
  45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48, 37,
  32, 45, 101, 110, 100, 105, 102, 32, 45, 97, 32, 121, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 50, 61, 61, 51, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 61, 123, 119, 125, 32, 104,
  61, 123, 104, 125, 10, 45, 122, 32, 48, 44, 48, 44, 123, 119, 47, 50,
  45, 49, 125, 44, 123, 104, 47, 50, 45, 49, 125, 32, 45, 114, 97, 110,
  100, 32, 45, 49, 44, 49, 32, 45, 98, 32, 36, 49, 32, 45, 103, 101,
  32, 48, 10, 45, 45, 109, 105, 114, 114, 111, 114, 32, 120, 32, 45, 105,
  102, 32, 123, 36, 119, 37, 50, 125, 32, 45, 99, 111, 108, 117, 109, 110,
  115, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48, 37, 32, 45, 101, 110,
  100, 105, 102, 32, 45, 97, 32, 120, 10, 45, 45, 109, 105, 114, 114, 111,
  114, 32, 121, 32, 45, 105, 102, 32, 123, 36, 104, 37, 50, 125, 32, 45,
  114, 111, 119, 115, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48, 37, 32,
  45, 101, 110, 100, 105, 102, 32, 45, 97, 32, 121, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  118, 32, 43, 10, 115, 105, 101, 114, 112, 105, 110, 115, 107, 105, 32, 58,
  32, 45, 99, 104, 101, 99, 107, 32, 36, 123, 49, 61, 55, 125, 62, 61,
  48, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 53, 48, 125, 44,
  36, 123, 51, 61, 48, 125, 44, 36, 123, 52, 61, 48, 125, 44, 36, 123,
  53, 61, 49, 48, 48, 125, 44, 36, 123, 54, 61, 49, 48, 48, 125, 44,
  36, 123, 55, 61, 49, 48, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 68, 114, 97, 119, 32, 83, 105, 101, 114, 112, 105, 110, 115, 107,
  105, 32, 116, 114, 105, 97, 110, 103, 108, 101, 32, 111, 102, 32, 100, 101,
  103, 114, 101, 101, 32, 36, 49, 32, 111, 110, 32, 105, 109, 97, 103, 101,
  36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 95, 115, 105, 101, 114,
  112, 105, 110, 115, 107, 105, 32, 36, 123, 50, 45, 55, 125, 44, 36, 49,
  32, 32, 45, 118, 32, 43, 10, 95, 115, 105, 101, 114, 112, 105, 110, 115,
  107, 105, 32, 58, 10, 45, 105, 102, 32, 123, 36, 55, 60, 61, 48, 125,
  32, 45, 112, 111, 108, 121, 103, 111, 110, 32, 51, 44, 36, 49, 37, 44,
  36, 50, 37, 44, 36, 51, 37, 44, 36, 52, 37, 44, 36, 53, 37, 44,
  36, 54, 37, 44, 49, 44, 50, 53, 53, 32, 45, 114, 101, 116, 117, 114,
  110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 115, 105, 101, 114, 112,
  105, 110, 115, 107, 105, 32, 36, 49, 44, 36, 50, 44, 123, 40, 36, 49,
  43, 36, 51, 41, 47, 50, 125, 44, 123, 40, 36, 50, 43, 36, 52, 41,
  47, 50, 125, 44, 123, 40, 36, 49, 43, 36, 53, 41, 47, 50, 125, 44,
  123, 40, 36, 50, 43, 36, 54, 41, 47, 50, 125, 44, 123, 36, 55, 45,
  49, 125, 10, 45, 95, 115, 105, 101, 114, 112, 105, 110, 115, 107, 105, 32,
  123, 40, 36, 49, 43, 36, 51, 41, 47, 50, 125, 44, 123, 40, 36, 50,
  43, 36, 52, 41, 47, 50, 125, 44, 36, 51, 44, 36, 52, 44, 123, 40,
  36, 51, 43, 36, 53, 41, 47, 50, 125, 44, 123, 40, 36, 52, 43, 36,
  54, 41, 47, 50, 125, 44, 123, 36, 55, 45, 49, 125, 10, 45, 95, 115,
  105, 101, 114, 112, 105, 110, 115, 107, 105, 32, 123, 40, 36, 49, 43, 36,
  53, 41, 47, 50, 125, 44, 123, 40, 36, 50, 43, 36, 54, 41, 47, 50,
  125, 44, 36, 53, 44, 36, 54, 44, 123, 40, 36, 51, 43, 36, 53, 41,
  47, 50, 125, 44, 123, 40, 36, 52, 43, 36, 54, 41, 47, 50, 125, 44,
  123, 36, 55, 45, 49, 125, 10, 115, 110, 111, 119, 102, 108, 97, 107, 101,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 123, 49, 61, 52, 125,
  62, 61, 48, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 50, 48,
  125, 44, 36, 123, 51, 61, 55, 48, 125, 44, 36, 123, 52, 61, 56, 48,
  125, 44, 36, 123, 53, 61, 55, 48, 125, 44, 36, 123, 54, 61, 53, 48,
  125, 44, 36, 123, 55, 61, 49, 48, 125, 44, 36, 123, 56, 61, 49, 125,
  44, 36, 123, 57, 61, 50, 53, 53, 125, 10, 45, 118, 32, 45, 10, 45,
  112, 111, 108, 121, 103, 111, 110, 32, 51, 44, 36, 50, 37, 44, 36, 51,
  37, 44, 36, 52, 37, 44, 36, 53, 37, 44, 36, 54, 37, 44, 36, 55,
  37, 44, 36, 123, 56, 45, 45, 49, 125, 10, 45, 95, 115, 110, 111, 119,
  102, 108, 97, 107, 101, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36,
  54, 44, 36, 55, 44, 36, 123, 56, 45, 45, 49, 125, 10, 45, 95, 115,
  110, 111, 119, 102, 108, 97, 107, 101, 32, 36, 49, 44, 36, 54, 44, 36,
  55, 44, 36, 52, 44, 36, 53, 44, 36, 123, 56, 45, 45, 49, 125, 10,
  45, 95, 115, 110, 111, 119, 102, 108, 97, 107, 101, 32, 36, 49, 44, 36,
  52, 44, 36, 53, 44, 36, 50, 44, 36, 51, 44, 36, 123, 56, 45, 45,
  49, 125, 10, 45, 118, 32, 43, 10, 95, 115, 110, 111, 119, 102, 108, 97,
  107, 101, 32, 58, 10, 120, 48, 61, 123, 36, 50, 43, 40, 36, 52, 45,
  36, 50, 41, 47, 51, 125, 32, 121, 48, 61, 123, 36, 51, 43, 40, 36,
  53, 45, 36, 51, 41, 47, 51, 125, 10, 120, 49, 61, 123, 36, 50, 43,
  50, 42, 40, 36, 52, 45, 36, 50, 41, 47, 51, 125, 32, 121, 49, 61,
  123, 36, 51, 43, 50, 42, 40, 36, 53, 45, 36, 51, 41, 47, 51, 125,
  10, 99, 61, 123, 99, 111, 115, 40, 45, 112, 105, 47, 51, 41, 125, 32,
  115, 61, 123, 115, 105, 110, 40, 45, 112, 105, 47, 51, 41, 125, 10, 120,
  50, 61, 123, 36, 120, 48, 43, 40, 36, 120, 49, 45, 36, 120, 48, 41,
  42, 36, 99, 45, 40, 36, 121, 49, 45, 36, 121, 48, 41, 42, 36, 115,
  125, 32, 121, 50, 61, 123, 36, 121, 48, 43, 40, 36, 120, 49, 45, 36,
  120, 48, 41, 42, 36, 115, 43, 40, 36, 121, 49, 45, 36, 121, 48, 41,
  42, 36, 99, 125, 10, 45, 112, 111, 108, 121, 103, 111, 110, 32, 51, 44,
  36, 120, 48, 37, 44, 36, 121, 48, 37, 44, 36, 120, 49, 37, 44, 36,
  121, 49, 37, 44, 36, 120, 50, 37, 44, 36, 121, 50, 37, 44, 36, 123,
  54, 45, 45, 49, 125, 10, 45, 105, 102, 32, 36, 49, 10, 45, 95, 115,
  110, 111, 119, 102, 108, 97, 107, 101, 32, 123, 36, 49, 45, 49, 125, 44,
  36, 50, 44, 36, 51, 44, 36, 120, 48, 44, 36, 121, 48, 44, 36, 123,
  54, 45, 45, 49, 125, 10, 45, 95, 115, 110, 111, 119, 102, 108, 97, 107,
  101, 32, 123, 36, 49, 45, 49, 125, 44, 36, 120, 48, 44, 36, 121, 48,
  44, 36, 120, 50, 44, 36, 121, 50, 44, 36, 123, 54, 45, 45, 49, 125,
  10, 45, 95, 115, 110, 111, 119, 102, 108, 97, 107, 101, 32, 123, 36, 49,
  45, 49, 125, 44, 36, 120, 50, 44, 36, 121, 50, 44, 36, 120, 49, 44,
  36, 121, 49, 44, 36, 123, 54, 45, 45, 49, 125, 10, 45, 95, 115, 110,
  111, 119, 102, 108, 97, 107, 101, 32, 123, 36, 49, 45, 49, 125, 44, 36,
  120, 49, 44, 36, 121, 49, 44, 36, 52, 44, 36, 53, 44, 36, 123, 54,
  45, 45, 49, 125, 10, 45, 101, 110, 100, 105, 102, 10, 115, 112, 105, 114,
  97, 108, 98, 119, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  68, 114, 97, 119, 32, 40, 115, 113, 117, 97, 114, 101, 100, 41, 32, 98,
  108, 97, 99, 107, 32, 97, 110, 100, 32, 119, 104, 105, 116, 101, 32, 115,
  112, 105, 114, 97, 108, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 48, 10, 45, 102, 32, 34, 114, 61, 109, 105, 110, 40, 120, 44,
  121, 44, 119, 45, 49, 45, 120, 44, 104, 45, 49, 45, 121, 41, 59, 32,
  50, 42, 114, 42, 40, 119, 43, 104, 45, 50, 42, 114, 45, 49, 41, 32,
  43, 32, 105, 102, 40, 109, 105, 110, 40, 120, 44, 104, 45, 49, 45, 121,
  41, 62, 61, 109, 105, 110, 40, 119, 45, 49, 45, 120, 44, 121, 41, 44,
  120, 43, 121, 44, 50, 42, 40, 119, 43, 104, 45, 50, 45, 50, 42, 114,
  41, 45, 120, 45, 121, 41, 34, 10, 45, 118, 32, 43, 10, 115, 112, 108,
  105, 110, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 57, 61,
  50, 53, 54, 125, 44, 36, 123, 49, 48, 61, 49, 125, 44, 36, 123, 49,
  49, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 114,
  97, 119, 32, 115, 112, 108, 105, 110, 101, 32, 102, 114, 111, 109, 32, 40,
  36, 49, 44, 36, 50, 41, 32, 91, 36, 51, 44, 36, 52, 93, 32, 116,
  111, 32, 40, 36, 53, 44, 36, 54, 41, 32, 91, 36, 55, 44, 36, 56,
  93, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105,
  116, 104, 32, 36, 57, 32, 118, 101, 114, 116, 105, 99, 101, 115, 44, 32,
  111, 112, 97, 99, 105, 116, 121, 32, 36, 49, 48, 32, 97, 110, 100, 32,
  99, 111, 108, 111, 114, 32, 40, 36, 123, 49, 49, 45, 45, 49, 125, 41,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 120, 48, 61, 123, 105, 102,
  40, 64, 123, 34, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 32,
  36, 49, 34, 125, 44, 36, 49, 42, 40, 119, 45, 49, 41, 44, 36, 49,
  41, 125, 10, 121, 48, 61, 123, 105, 102, 40, 64, 123, 34, 45, 105, 115,
  95, 112, 101, 114, 99, 101, 110, 116, 32, 36, 50, 34, 125, 44, 36, 50,
  42, 40, 104, 45, 49, 41, 44, 36, 50, 41, 125, 10, 117, 48, 61, 123,
  105, 102, 40, 64, 123, 34, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110,
  116, 32, 36, 51, 34, 125, 44, 36, 51, 42, 40, 119, 45, 49, 41, 44,
  36, 51, 41, 125, 10, 118, 48, 61, 123, 105, 102, 40, 64, 123, 34, 45,
  105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 32, 36, 52, 34, 125, 44,
  36, 52, 42, 40, 104, 45, 49, 41, 44, 36, 52, 41, 125, 10, 120, 49,
  61, 123, 105, 102, 40, 64, 123, 34, 45, 105, 115, 95, 112, 101, 114, 99,
  101, 110, 116, 32, 36, 53, 34, 125, 44, 36, 53, 42, 40, 119, 45, 49,
  41, 44, 36, 53, 41, 125, 10, 121, 49, 61, 123, 105, 102, 40, 64, 123,
  34, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 32, 36, 54, 34,
  125, 44, 36, 54, 42, 40, 104, 45, 49, 41, 44, 36, 54, 41, 125, 10,
  117, 49, 61, 123, 105, 102, 40, 64, 123, 34, 45, 105, 115, 95, 112, 101,
  114, 99, 101, 110, 116, 32, 36, 55, 34, 125, 44, 36, 55, 42, 40, 119,
  45, 49, 41, 44, 36, 55, 41, 125, 10, 118, 49, 61, 123, 105, 102, 40,
  64, 123, 34, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 32, 36,
  56, 34, 125, 44, 36, 56, 42, 40, 104, 45, 49, 41, 44, 36, 56, 41,
  125, 10, 45, 115, 112, 108, 105, 110, 101, 51, 100, 32, 36, 120, 48, 44,
  36, 121, 48, 44, 48, 44, 36, 117, 48, 44, 36, 118, 48, 44, 48, 44,
  36, 120, 49, 44, 36, 121, 49, 44, 48, 44, 36, 117, 49, 44, 36, 118,
  49, 44, 48, 44, 36, 57, 10, 45, 115, 104, 91, 45, 49, 93, 32, 56,
  44, 123, 56, 43, 51, 42, 36, 57, 45, 49, 125, 44, 48, 44, 48, 32,
  45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 99, 111, 108, 51, 100, 91, 49, 93, 32, 36, 123, 49,
  49, 45, 45, 49, 125, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91,
  48, 93, 32, 91, 49, 93, 44, 48, 44, 48, 44, 48, 44, 36, 49, 48,
  44, 49, 44, 48, 44, 48, 32, 45, 114, 109, 91, 49, 93, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 116,
  101, 120, 116, 95, 111, 117, 116, 108, 105, 110, 101, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 50, 61, 50, 125, 44, 36, 123, 51, 61, 50,
  125, 44, 36, 123, 52, 61, 49, 51, 125, 44, 36, 123, 53, 61, 50, 125,
  44, 36, 123, 54, 61, 49, 125, 44, 36, 123, 55, 61, 50, 53, 53, 125,
  44, 36, 123, 56, 61, 36, 45, 49, 125, 44, 36, 123, 57, 61, 36, 45,
  49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 114, 97, 119,
  32, 111, 117, 116, 108, 105, 110, 101, 100, 32, 116, 101, 120, 116, 32, 39,
  36, 49, 39, 32, 97, 116, 32, 112, 111, 115, 105, 116, 105, 111, 110, 32,
  40, 36, 50, 44, 36, 51, 41, 32, 111, 110, 32, 105, 109, 97, 103, 101,
  36, 63, 44, 32, 119, 105, 116, 104, 32, 102, 111, 110, 116, 32, 104, 101,
  105, 103, 104, 116, 32, 36, 52, 44, 32, 111, 117, 116, 108, 105, 110, 101,
  32, 36, 53, 44, 32, 111, 112, 97, 99, 105, 116, 121, 32, 36, 54, 32,
  97, 110, 100, 32, 99, 111, 108, 111, 114, 32, 36, 123, 55, 45, 45, 49,
  125, 46, 34, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 36, 53, 10,
  48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 36, 49, 34, 44, 48, 44,
  48, 44, 36, 52, 44, 49, 44, 49, 32, 45, 101, 120, 112, 97, 110, 100,
  95, 120, 121, 91, 45, 49, 93, 32, 123, 49, 43, 36, 53, 125, 44, 48,
  32, 45, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 123, 50,
  42, 36, 53, 43, 49, 125, 10, 40, 36, 123, 55, 45, 45, 49, 125, 41,
  32, 45, 121, 91, 45, 49, 93, 32, 99, 32, 45, 114, 91, 45, 49, 93,
  32, 50, 44, 49, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44, 48, 44,
  49, 32, 45, 109, 97, 112, 91, 45, 51, 93, 32, 91, 45, 49, 93, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 64, 35, 45, 50, 125, 32, 45, 105, 102, 32, 64, 123, 36, 62, 44,
  119, 125, 32, 45, 106, 91, 36, 62, 93, 32, 91, 45, 50, 93, 44, 36,
  50, 44, 36, 51, 44, 48, 44, 48, 44, 36, 54, 44, 91, 45, 49, 93,
  32, 45, 101, 108, 115, 101, 32, 45, 114, 109, 91, 36, 62, 93, 32, 45,
  105, 91, 36, 62, 93, 32, 91, 45, 50, 93, 32, 45, 101, 110, 100, 105,
  102, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 45, 50, 44, 45,
  49, 93, 10, 45, 101, 108, 115, 101, 10, 45, 116, 32, 34, 36, 49, 34,
  44, 36, 123, 50, 45, 52, 125, 44, 36, 123, 54, 45, 45, 49, 125, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 116, 114, 105, 97,
  110, 103, 108, 101, 95, 115, 104, 97, 100, 101, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 68, 114, 97, 119, 32, 116, 114, 105, 97, 110,
  103, 108, 101, 32, 40, 36, 49, 44, 36, 50, 41, 45, 40, 36, 51, 44,
  36, 52, 41, 45, 40, 36, 53, 44, 36, 54, 41, 32, 119, 105, 116, 104,
  32, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 101, 100, 32, 99, 111,
  108, 111, 114, 115, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46,
  34, 10, 45, 118, 32, 45, 10, 45, 108, 91, 93, 32, 40, 36, 49, 44,
  36, 50, 44, 49, 59, 36, 51, 44, 36, 52, 44, 49, 59, 36, 53, 44,
  36, 54, 44, 49, 41, 32, 40, 36, 123, 55, 45, 45, 49, 125, 41, 32,
  45, 114, 91, 45, 49, 93, 32, 123, 119, 47, 51, 125, 44, 51, 44, 49,
  44, 49, 44, 45, 49, 32, 45, 115, 91, 45, 49, 93, 32, 120, 32, 45,
  115, 111, 108, 118, 101, 91, 94, 48, 93, 32, 91, 48, 93, 32, 45, 114,
  109, 91, 48, 93, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 10,
  45, 112, 111, 108, 121, 103, 111, 110, 91, 94, 45, 49, 93, 32, 51, 44,
  36, 123, 49, 45, 54, 125, 44, 49, 44, 45, 54, 53, 53, 51, 53, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 45,
  108, 91, 36, 62, 44, 45, 49, 93, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 123, 48, 44, 115, 125, 10, 97, 61, 123, 105, 40, 48, 44, 48,
  44, 48, 44, 36, 62, 41, 125, 32, 98, 61, 123, 105, 40, 48, 44, 49,
  44, 48, 44, 36, 62, 41, 125, 32, 99, 61, 123, 105, 40, 48, 44, 50,
  44, 48, 44, 36, 62, 41, 125, 10, 45, 115, 104, 91, 48, 93, 32, 36,
  62, 44, 36, 62, 32, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102, 40,
  105, 61, 61, 45, 54, 53, 53, 51, 53, 44, 36, 97, 42, 120, 43, 36,
  98, 42, 121, 43, 36, 99, 44, 105, 41, 39, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 118, 32,
  43, 10, 116, 114, 117, 99, 104, 101, 116, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 51, 50,
  125, 41, 32, 38, 38, 32, 36, 49, 62, 48, 32, 38, 38, 32, 36, 123,
  50, 61, 51, 125, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 51, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82,
  101, 110, 100, 101, 114, 32, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49,
  43, 33, 36, 51, 44, 99, 117, 114, 118, 101, 100, 44, 115, 116, 114, 97,
  105, 103, 104, 116, 125, 34, 32, 116, 114, 117, 99, 104, 101, 116, 32, 112,
  97, 116, 116, 101, 114, 110, 115, 32, 105, 110, 32, 105, 109, 97, 103, 101,
  36, 63, 44, 32, 119, 105, 116, 104, 32, 115, 99, 97, 108, 101, 32, 36,
  49, 32, 97, 110, 100, 32, 114, 97, 100, 105, 117, 115, 32, 36, 50, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44,
  110, 125, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 32, 115,
  61, 123, 115, 125, 32, 45, 114, 109, 10, 36, 49, 44, 36, 49, 32, 45,
  61, 32, 49, 44, 48, 44, 48, 32, 45, 61, 32, 49, 44, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101,
  32, 49, 44, 123, 49, 43, 36, 51, 125, 32, 77, 61, 123, 105, 110, 116,
  40, 105, 77, 47, 50, 41, 125, 10, 45, 116, 50, 32, 123, 36, 77, 45,
  36, 50, 47, 50, 45, 40, 36, 49, 37, 50, 41, 125, 44, 123, 36, 77,
  43, 36, 50, 47, 50, 125, 32, 45, 45, 109, 105, 114, 114, 111, 114, 32,
  121, 32, 45, 97, 32, 120, 10, 123, 114, 111, 117, 110, 100, 40, 36, 119,
  47, 36, 49, 44, 49, 44, 49, 41, 125, 44, 123, 114, 111, 117, 110, 100,
  40, 36, 104, 47, 36, 49, 44, 49, 44, 49, 41, 125, 32, 45, 114, 97,
  110, 100, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 103, 101, 91, 45,
  49, 93, 32, 53, 48, 37, 32, 45, 114, 91, 45, 49, 93, 32, 123, 119,
  42, 36, 49, 125, 44, 123, 104, 42, 36, 49, 125, 32, 45, 42, 91, 45,
  49, 93, 32, 36, 49, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91,
  45, 49, 93, 32, 48, 44, 49, 32, 40, 48, 44, 123, 36, 49, 45, 49,
  125, 41, 32, 45, 114, 91, 45, 49, 93, 32, 36, 49, 44, 36, 49, 44,
  49, 44, 49, 44, 51, 32, 45, 45, 116, 114, 97, 110, 115, 112, 111, 115,
  101, 91, 45, 49, 93, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32,
  99, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44,
  50, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 119, 97, 114,
  112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45,
  49, 93, 32, 45, 103, 101, 32, 53, 48, 37, 32, 45, 114, 32, 36, 119,
  44, 36, 104, 44, 49, 44, 49, 44, 48, 32, 45, 114, 32, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 49, 44, 36, 115, 10, 45, 110, 109, 32,
  36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 116, 117, 114, 98, 117, 108, 101, 110, 99,
  101, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61,
  51, 50, 125, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 54, 125, 62,
  48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 51, 125, 44,
  36, 123, 52, 61, 48, 125, 44, 36, 123, 53, 61, 48, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 82, 101, 110, 100, 101, 114, 32, 102, 114,
  97, 99, 116, 97, 108, 32, 110, 111, 105, 115, 101, 32, 111, 114, 32, 116,
  117, 114, 98, 117, 108, 101, 110, 99, 101, 32, 111, 110, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 114, 97, 100, 105, 117,
  115, 32, 36, 49, 44, 32, 111, 99, 116, 97, 118, 101, 115, 32, 36, 50,
  44, 32, 100, 97, 109, 112, 105, 110, 103, 32, 112, 101, 114, 32, 111, 99,
  116, 97, 118, 101, 32, 36, 51, 44, 32, 100, 105, 102, 102, 101, 114, 101,
  110, 99, 101, 32, 36, 52, 32, 97, 110, 100, 32, 109, 111, 100, 101, 32,
  36, 53, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64,
  123, 48, 44, 110, 125, 10, 45, 105, 102, 32, 123, 36, 52, 125, 32, 91,
  45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 102, 91, 45, 49,
  93, 32, 48, 32, 45, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32,
  49, 48, 44, 48, 32, 45, 98, 91, 45, 49, 93, 32, 36, 49, 44, 48,
  10, 45, 105, 102, 32, 123, 36, 53, 61, 61, 48, 124, 124, 36, 53, 61,
  61, 49, 125, 32, 45, 45, 91, 45, 49, 93, 32, 64, 123, 45, 49, 44,
  97, 125, 32, 45, 97, 98, 115, 91, 45, 49, 93, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 53, 61, 61, 51, 124, 124, 36, 53, 61, 61, 52, 125,
  32, 45, 94, 91, 45, 49, 93, 32, 50, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 53, 61, 61, 53, 125, 32, 45, 94, 91, 45, 49, 93, 32, 51,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 36, 50, 45, 49, 125, 10, 45, 45, 110, 111, 105, 115, 101, 91, 45,
  50, 93, 32, 49, 48, 44, 48, 32, 45, 98, 91, 45, 49, 93, 32, 123,
  36, 49, 47, 50, 94, 36, 62, 125, 44, 48, 10, 45, 105, 102, 32, 123,
  36, 53, 61, 61, 48, 125, 32, 45, 45, 91, 45, 49, 93, 32, 64, 123,
  45, 49, 44, 97, 125, 32, 45, 97, 98, 115, 91, 45, 49, 93, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 53, 61, 61, 52, 125, 32, 45, 94, 91,
  45, 49, 93, 32, 50, 10, 45, 101, 108, 105, 102, 32, 123, 36, 53, 61,
  61, 53, 125, 32, 45, 94, 91, 45, 49, 93, 32, 51, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 42, 91, 45, 50, 93, 32, 36, 51, 32, 45, 43,
  91, 45, 50, 45, 45, 49, 93, 10, 45, 100, 111, 110, 101, 10, 45, 110,
  91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 114, 109, 91, 45,
  50, 93, 10, 45, 105, 102, 32, 123, 36, 52, 125, 32, 45, 42, 91, 45,
  49, 93, 32, 36, 52, 32, 45, 109, 118, 91, 45, 50, 93, 32, 50, 32,
  45, 45, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 121, 105, 110, 121, 97, 110, 103, 32, 58, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 68, 114, 97, 119, 32, 121, 105, 110, 45, 121, 97,
  110, 103, 32, 115, 121, 109, 98, 111, 108, 32, 111, 110, 32, 105, 109, 97,
  103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 102, 32, 48,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 115, 61, 123, 115, 125, 32, 45, 99, 104, 97, 110, 110, 101,
  108, 115, 32, 48, 10, 114, 61, 123, 114, 111, 117, 110, 100, 40, 48, 46,
  57, 53, 42, 109, 105, 110, 40, 119, 44, 104, 41, 47, 52, 41, 125, 10,
  45, 45, 108, 105, 110, 101, 32, 53, 48, 37, 44, 48, 44, 53, 48, 37,
  44, 53, 48, 37, 44, 49, 44, 50, 32, 45, 101, 108, 108, 105, 112, 115,
  101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 123, 104, 47, 50, 45, 36,
  114, 125, 44, 36, 114, 44, 36, 114, 44, 48, 44, 49, 44, 50, 10, 45,
  108, 105, 110, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37,
  44, 53, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 32, 45, 101,
  108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 123,
  104, 47, 50, 43, 36, 114, 125, 44, 36, 114, 44, 36, 114, 44, 48, 44,
  49, 44, 49, 10, 45, 102, 108, 111, 111, 100, 91, 45, 49, 93, 32, 123,
  119, 47, 50, 45, 36, 114, 125, 44, 53, 48, 37, 44, 48, 44, 48, 44,
  48, 44, 49, 44, 50, 10, 45, 102, 108, 111, 111, 100, 91, 45, 49, 93,
  32, 123, 119, 47, 50, 43, 36, 114, 125, 44, 53, 48, 37, 44, 48, 44,
  48, 44, 48, 44, 49, 44, 49, 10, 45, 101, 108, 108, 105, 112, 115, 101,
  91, 45, 50, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 123, 50, 42,
  36, 114, 125, 44, 123, 50, 42, 36, 114, 125, 44, 48, 44, 49, 44, 49,
  10, 45, 42, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93,
  32, 53, 48, 37, 44, 123, 104, 47, 50, 45, 36, 114, 125, 44, 123, 36,
  114, 47, 51, 125, 44, 123, 36, 114, 47, 51, 125, 44, 48, 44, 49, 44,
  49, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 53,
  48, 37, 44, 123, 104, 47, 50, 43, 36, 114, 125, 44, 123, 36, 114, 47,
  51, 125, 44, 123, 36, 114, 47, 51, 125, 44, 48, 44, 49, 44, 50, 10,
  45, 114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 36,
  115, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 116, 114, 97, 110, 115, 112, 111, 115, 101, 32, 58, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 84, 114, 97, 110, 115, 112, 111, 115,
  101, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 112, 101, 114, 109, 117, 116, 101, 32, 121, 120, 122, 99, 32, 45,
  118, 32, 43, 10, 97, 110, 105, 109, 97, 116, 101, 51, 100, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 54, 52, 48, 125, 44, 36,
  123, 50, 61, 52, 56, 48, 125, 44, 36, 123, 51, 61, 48, 125, 44, 36,
  123, 52, 61, 49, 48, 125, 44, 36, 123, 53, 61, 48, 125, 44, 34, 36,
  123, 55, 61, 34, 34, 125, 34, 32, 45, 99, 104, 101, 99, 107, 32, 36,
  123, 54, 61, 49, 125, 62, 61, 48, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 65, 110, 105, 109, 97, 116, 101, 32, 51, 100, 32, 111, 98, 106,
  101, 99, 116, 36, 63, 44, 32, 105, 110, 32, 97, 32, 36, 49, 120, 36,
  50, 32, 119, 105, 110, 100, 111, 119, 32, 119, 105, 116, 104, 32, 97, 110,
  103, 108, 101, 32, 118, 101, 108, 111, 99, 105, 116, 105, 101, 115, 32, 40,
  36, 51, 44, 36, 52, 44, 36, 53, 41, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 45, 108, 91,
  36, 62, 93, 10, 45, 110, 51, 100, 32, 45, 42, 51, 100, 32, 123, 36,
  54, 42, 109, 105, 110, 40, 36, 49, 44, 36, 50, 41, 47, 49, 46, 53,
  125, 32, 45, 99, 51, 100, 10, 97, 120, 61, 48, 32, 97, 121, 61, 48,
  32, 97, 122, 61, 48, 32, 102, 114, 97, 109, 101, 61, 48, 10, 45, 100,
  111, 10, 45, 45, 114, 51, 100, 32, 49, 44, 48, 44, 48, 44, 36, 97,
  120, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 49, 44, 48,
  44, 36, 97, 121, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44,
  48, 44, 49, 44, 36, 97, 122, 10, 97, 120, 61, 123, 36, 97, 120, 43,
  36, 51, 125, 32, 97, 121, 61, 123, 36, 97, 121, 43, 36, 52, 125, 32,
  97, 122, 61, 123, 36, 97, 122, 43, 36, 53, 125, 10, 36, 49, 44, 36,
  50, 44, 49, 44, 51, 44, 45, 49, 32, 45, 111, 98, 106, 101, 99, 116,
  51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 53, 48, 37, 44,
  53, 48, 37, 44, 48, 44, 49, 10, 45, 105, 102, 32, 123, 110, 97, 114,
  103, 40, 34, 36, 55, 34, 41, 125, 10, 45, 116, 111, 95, 114, 103, 98,
  97, 91, 45, 49, 93, 32, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99,
  111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 45, 49, 44,
  45, 49, 44, 45, 49, 44, 50, 53, 53, 44, 54, 52, 44, 54, 52, 44,
  54, 52, 44, 48, 10, 45, 111, 91, 45, 49, 93, 32, 64, 123, 45, 102,
  105, 108, 101, 110, 97, 109, 101, 92, 32, 34, 36, 55, 34, 44, 36, 62,
  44, 36, 102, 114, 97, 109, 101, 125, 32, 102, 114, 97, 109, 101, 61, 123,
  36, 102, 114, 97, 109, 101, 43, 49, 125, 10, 45, 101, 108, 115, 101, 10,
  45, 114, 101, 112, 108, 97, 99, 101, 91, 45, 49, 93, 32, 45, 49, 44,
  54, 52, 10, 45, 101, 110, 100, 105, 102, 10, 45, 119, 91, 45, 49, 93,
  32, 123, 119, 125, 44, 123, 104, 125, 44, 48, 44, 48, 44, 45, 49, 44,
  45, 49, 44, 64, 123, 48, 44, 110, 125, 32, 45, 119, 97, 105, 116, 32,
  50, 48, 32, 45, 107, 91, 48, 93, 10, 45, 119, 104, 105, 108, 101, 32,
  123, 64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83,
  67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125,
  32, 45, 114, 109, 32, 45, 119, 32, 48, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 97, 112, 112, 108, 121,
  95, 99, 97, 109, 101, 114, 97, 51, 100, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 52, 61, 48, 125, 44, 36, 123, 53, 61, 48, 125, 44,
  36, 123, 54, 61, 48, 125, 44, 36, 123, 55, 61, 48, 125, 44, 36, 123,
  56, 61, 45, 49, 125, 44, 36, 123, 57, 61, 48, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 51, 100, 32, 99,
  97, 109, 101, 114, 97, 32, 109, 97, 116, 114, 105, 120, 32, 116, 111, 32,
  51, 100, 32, 111, 98, 106, 101, 99, 116, 36, 63, 44, 32, 119, 105, 116,
  104, 32, 99, 97, 109, 101, 114, 97, 32, 112, 111, 115, 105, 116, 105, 111,
  110, 32, 40, 36, 49, 44, 36, 50, 44, 36, 51, 41, 44, 32, 116, 97,
  114, 103, 101, 116, 32, 112, 111, 115, 105, 116, 105, 111, 110, 32, 40, 36,
  52, 44, 36, 53, 44, 36, 54, 41, 32, 97, 110, 100, 32, 117, 112, 45,
  118, 101, 99, 116, 111, 114, 32, 40, 36, 55, 44, 36, 56, 44, 36, 57,
  41, 46, 34, 10, 45, 118, 32, 45, 10, 40, 123, 36, 52, 45, 36, 49,
  125, 94, 123, 36, 53, 45, 36, 50, 125, 94, 123, 36, 54, 45, 36, 51,
  125, 41, 10, 40, 36, 55, 94, 36, 56, 94, 36, 57, 41, 10, 45, 111,
  114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 91, 45, 50, 44, 45, 49,
  93, 10, 45, 95, 99, 114, 111, 115, 115, 51, 100, 32, 64, 45, 50, 44,
  64, 45, 49, 10, 45, 95, 99, 114, 111, 115, 115, 51, 100, 32, 64, 45,
  49, 44, 64, 45, 51, 10, 45, 114, 109, 91, 45, 51, 93, 32, 45, 121,
  91, 45, 51, 45, 45, 49, 93, 32, 120, 32, 45, 109, 118, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 51, 10, 45, 97, 91, 45, 51, 45, 45, 49,
  93, 32, 121, 32, 45, 122, 91, 45, 49, 93, 32, 48, 44, 51, 10, 45,
  45, 51, 100, 91, 94, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36,
  51, 32, 45, 97, 112, 112, 108, 121, 95, 112, 111, 115, 101, 51, 100, 91,
  94, 45, 49, 93, 32, 64, 45, 49, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 45, 51, 100, 32, 48, 44, 48, 44, 56, 48, 48, 10, 45, 118,
  32, 43, 10, 95, 99, 114, 111, 115, 115, 51, 100, 32, 58, 10, 40, 123,
  36, 50, 42, 36, 54, 45, 36, 51, 42, 36, 53, 125, 94, 123, 36, 51,
  42, 36, 52, 45, 36, 49, 42, 36, 54, 125, 94, 123, 36, 49, 42, 36,
  53, 45, 36, 50, 42, 36, 52, 125, 41, 32, 45, 111, 114, 105, 101, 110,
  116, 97, 116, 105, 111, 110, 91, 45, 49, 93, 32, 45, 121, 91, 45, 49,
  93, 10, 97, 112, 112, 108, 121, 95, 112, 111, 115, 101, 51, 100, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32,
  51, 100, 32, 112, 111, 115, 101, 32, 109, 97, 116, 114, 105, 120, 32, 91,
  32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 59, 32, 36, 53,
  44, 36, 54, 44, 36, 55, 44, 36, 56, 59, 32, 36, 57, 44, 36, 49,
  48, 44, 36, 49, 49, 44, 36, 49, 50, 32, 93, 32, 116, 111, 32, 51,
  100, 32, 111, 98, 106, 101, 99, 116, 36, 63, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 32, 45, 105, 102, 32, 64, 123, 45, 105, 115, 95, 51, 100,
  125, 10, 45, 115, 51, 100, 32, 45, 114, 91, 50, 93, 32, 51, 44, 64,
  123, 50, 44, 104, 47, 51, 125, 44, 49, 44, 49, 44, 45, 49, 32, 45,
  105, 91, 51, 93, 32, 49, 44, 64, 123, 50, 44, 104, 125, 44, 49, 44,
  49, 44, 49, 32, 45, 97, 91, 50, 44, 51, 93, 32, 120, 10, 45, 105,
  91, 51, 93, 32, 40, 36, 49, 44, 36, 53, 44, 36, 57, 59, 36, 50,
  44, 36, 54, 44, 36, 49, 48, 59, 36, 51, 44, 36, 55, 44, 36, 49,
  49, 59, 36, 52, 44, 36, 56, 44, 36, 49, 50, 41, 32, 45, 42, 42,
  91, 50, 44, 51, 93, 10, 45, 114, 91, 50, 93, 32, 49, 44, 64, 123,
  50, 44, 51, 42, 104, 125, 44, 49, 44, 49, 44, 45, 49, 32, 45, 97,
  32, 121, 10, 45, 101, 108, 115, 101, 32, 45, 101, 114, 114, 111, 114, 32,
  34, 73, 109, 97, 103, 101, 32, 91, 34, 123, 64, 35, 45, 36, 62, 45,
  49, 125, 34, 93, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 114, 101,
  112, 114, 101, 115, 101, 110, 116, 32, 97, 32, 51, 100, 32, 111, 98, 106,
  101, 99, 116, 46, 34, 10, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 97, 114,
  114, 111, 119, 51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  36, 123, 55, 61, 53, 37, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123,
  56, 61, 50, 53, 37, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 57,
  61, 49, 53, 37, 125, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 73, 110, 112, 117, 116, 32, 51, 100, 32, 97, 114, 114, 111,
  119, 44, 32, 102, 114, 111, 109, 32, 40, 36, 123, 49, 45, 51, 125, 41,
  32, 116, 111, 32, 40, 36, 123, 52, 45, 54, 125, 41, 44, 32, 119, 105,
  116, 104, 32, 114, 97, 100, 105, 117, 115, 32, 36, 55, 44, 32, 104, 101,
  97, 100, 32, 108, 101, 110, 103, 116, 104, 32, 36, 56, 32, 97, 110, 100,
  32, 104, 101, 97, 100, 32, 114, 97, 100, 105, 117, 115, 32, 36, 57, 46,
  34, 10, 45, 118, 32, 45, 10, 76, 61, 123, 115, 113, 114, 116, 40, 40,
  36, 52, 45, 36, 49, 41, 94, 50, 43, 40, 36, 53, 45, 36, 50, 41,
  94, 50, 43, 40, 36, 54, 45, 36, 51, 41, 94, 50, 41, 125, 10, 82,
  61, 123, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101,
  110, 116, 92, 32, 36, 55, 125, 44, 36, 55, 42, 36, 76, 44, 36, 55,
  41, 125, 10, 108, 61, 123, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112,
  101, 114, 99, 101, 110, 116, 92, 32, 36, 56, 125, 44, 36, 56, 42, 36,
  76, 44, 36, 56, 41, 125, 10, 114, 61, 123, 105, 102, 40, 64, 123, 45,
  105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 57, 125, 44,
  36, 57, 42, 36, 76, 44, 36, 57, 41, 125, 10, 76, 61, 123, 36, 76,
  45, 36, 108, 125, 32, 45, 99, 121, 108, 105, 110, 100, 101, 114, 51, 100,
  32, 36, 82, 44, 36, 76, 32, 45, 99, 111, 110, 101, 51, 100, 32, 36,
  114, 44, 36, 108, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 48, 44,
  48, 44, 36, 76, 32, 45, 43, 51, 100, 91, 45, 50, 44, 45, 49, 93,
  10, 40, 123, 36, 52, 45, 36, 49, 125, 94, 123, 36, 53, 45, 36, 50,
  125, 94, 123, 36, 54, 45, 36, 51, 125, 41, 32, 40, 48, 46, 48, 49,
  94, 45, 48, 46, 48, 50, 94, 48, 46, 48, 51, 41, 32, 45, 111, 114,
  105, 101, 110, 116, 97, 116, 105, 111, 110, 91, 45, 50, 44, 45, 49, 93,
  10, 45, 95, 99, 114, 111, 115, 115, 51, 100, 32, 64, 45, 50, 44, 64,
  45, 49, 32, 45, 95, 99, 114, 111, 115, 115, 51, 100, 32, 64, 45, 49,
  44, 64, 45, 51, 32, 45, 114, 109, 91, 45, 51, 93, 32, 45, 121, 91,
  45, 51, 45, 45, 49, 93, 32, 120, 32, 45, 109, 118, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 51, 10, 45, 97, 91, 45, 51, 45, 45, 49, 93,
  32, 121, 10, 45, 115, 51, 100, 91, 45, 50, 93, 32, 45, 114, 91, 45,
  53, 93, 32, 51, 44, 64, 123, 45, 53, 44, 104, 47, 51, 125, 44, 49,
  44, 49, 44, 45, 49, 32, 45, 42, 42, 91, 45, 53, 44, 45, 49, 93,
  10, 45, 121, 91, 45, 52, 93, 32, 45, 97, 91, 45, 54, 45, 45, 49,
  93, 32, 121, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 36, 123, 49,
  45, 51, 125, 32, 45, 114, 118, 51, 100, 91, 45, 49, 93, 10, 45, 118,
  32, 43, 10, 97, 120, 101, 115, 51, 100, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 36, 123, 52, 61, 50, 52, 125, 62, 48, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 49, 61, 49, 125, 44, 36, 123, 50, 61, 36, 49,
  125, 44, 36, 123, 51, 61, 36, 50, 125, 44, 34, 36, 123, 53, 61, 88,
  125, 44, 36, 123, 54, 61, 89, 125, 44, 36, 123, 55, 61, 90, 125, 34,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32,
  51, 100, 32, 97, 120, 101, 115, 32, 119, 105, 116, 104, 32, 115, 105, 122,
  101, 115, 32, 40, 36, 49, 44, 36, 50, 44, 36, 51, 41, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 108, 91, 93, 10, 109, 61, 123, 109, 97, 120,
  40, 97, 98, 115, 40, 36, 49, 41, 44, 97, 98, 115, 40, 36, 50, 41,
  44, 97, 98, 115, 40, 36, 51, 41, 41, 47, 52, 48, 125, 32, 109, 50,
  61, 123, 50, 42, 36, 109, 125, 32, 109, 51, 61, 123, 49, 46, 50, 42,
  36, 109, 50, 125, 10, 45, 95, 97, 120, 101, 115, 51, 100, 32, 34, 79,
  34, 44, 36, 52, 32, 45, 45, 51, 100, 91, 45, 49, 93, 32, 36, 109,
  51, 44, 36, 109, 51, 44, 36, 109, 51, 10, 45, 105, 102, 32, 36, 49,
  10, 45, 108, 105, 110, 101, 51, 100, 32, 48, 44, 48, 44, 48, 44, 36,
  49, 44, 48, 44, 48, 10, 45, 99, 111, 110, 101, 51, 100, 32, 36, 109,
  44, 123, 50, 42, 36, 109, 125, 44, 49, 54, 32, 45, 114, 51, 100, 91,
  45, 49, 93, 32, 48, 44, 49, 44, 48, 44, 45, 57, 48, 32, 45, 43,
  51, 100, 91, 45, 49, 93, 32, 123, 36, 49, 45, 36, 109, 50, 125, 44,
  48, 44, 48, 10, 45, 95, 97, 120, 101, 115, 51, 100, 32, 34, 36, 53,
  34, 44, 36, 52, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 123, 36,
  49, 43, 36, 109, 51, 125, 44, 48, 44, 48, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 36, 50, 10, 45, 108, 105, 110, 101, 51, 100,
  32, 48, 44, 48, 44, 48, 44, 48, 44, 36, 50, 44, 48, 10, 45, 99,
  111, 110, 101, 51, 100, 32, 36, 109, 44, 123, 50, 42, 36, 109, 125, 44,
  49, 54, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 49, 44, 48, 44,
  48, 44, 57, 48, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 48, 44,
  123, 36, 50, 45, 36, 109, 50, 125, 44, 48, 10, 45, 95, 97, 120, 101,
  115, 51, 100, 32, 34, 36, 54, 34, 44, 36, 52, 32, 45, 43, 51, 100,
  91, 45, 49, 93, 32, 48, 44, 123, 36, 50, 43, 36, 109, 51, 125, 44,
  48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 51, 10,
  45, 108, 105, 110, 101, 51, 100, 32, 48, 44, 48, 44, 48, 44, 48, 44,
  48, 44, 36, 51, 10, 45, 99, 111, 110, 101, 51, 100, 32, 36, 109, 44,
  123, 50, 42, 36, 109, 125, 44, 49, 54, 32, 45, 43, 51, 100, 91, 45,
  49, 93, 32, 48, 44, 48, 44, 123, 36, 51, 45, 36, 109, 50, 125, 10,
  45, 95, 97, 120, 101, 115, 51, 100, 32, 34, 36, 55, 34, 44, 36, 52,
  32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 48, 44, 48, 44, 123, 36,
  51, 43, 36, 109, 51, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 43,
  51, 100, 32, 45, 110, 109, 32, 91, 51, 100, 92, 32, 97, 120, 101, 115,
  93, 10, 45, 101, 110, 100, 108, 32, 45, 118, 32, 43, 10, 95, 97, 120,
  101, 115, 51, 100, 32, 58, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32,
  34, 36, 49, 34, 44, 50, 44, 48, 44, 36, 50, 44, 49, 44, 49, 32,
  45, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51, 32, 45,
  42, 91, 45, 50, 93, 32, 50, 53, 53, 32, 45, 114, 91, 45, 50, 93,
  32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 51, 10, 45,
  105, 91, 45, 51, 93, 32, 40, 54, 55, 46, 53, 59, 55, 51, 46, 53,
  59, 49, 48, 57, 46, 53, 59, 49, 48, 51, 46, 53, 59, 53, 49, 46,
  53, 59, 49, 48, 48, 46, 53, 59, 49, 59, 49, 59, 48, 59, 48, 59,
  48, 59, 49, 59, 48, 59, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123,
  104, 125, 59, 51, 41, 10, 45, 105, 91, 45, 50, 93, 32, 40, 45, 49,
  50, 56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 49, 41, 32, 45, 121,
  91, 45, 51, 44, 45, 49, 93, 32, 45, 97, 91, 45, 52, 45, 45, 49,
  93, 32, 121, 10, 98, 111, 120, 51, 100, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 49, 61, 49, 125, 44, 36, 123, 50, 61, 36, 49, 125,
  44, 36, 123, 51, 61, 36, 50, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 73, 110, 112, 117, 116, 32, 51, 100, 32, 98, 111, 120, 44, 32,
  119, 105, 116, 104, 32, 115, 105, 122, 101, 32, 40, 36, 49, 44, 36, 50,
  44, 36, 51, 41, 46, 34, 10, 45, 118, 32, 45, 10, 49, 44, 56, 54,
  44, 49, 44, 49, 44, 92, 10, 54, 55, 46, 53, 44, 55, 51, 46, 53,
  44, 49, 48, 57, 46, 53, 44, 49, 48, 51, 46, 53, 44, 53, 49, 46,
  53, 44, 49, 48, 48, 46, 53, 44, 56, 44, 54, 44, 92, 10, 48, 44,
  48, 44, 48, 44, 36, 49, 44, 48, 44, 48, 44, 36, 49, 44, 36, 50,
  44, 48, 44, 48, 44, 36, 50, 44, 48, 44, 92, 10, 48, 44, 48, 44,
  36, 51, 44, 36, 49, 44, 48, 44, 36, 51, 44, 36, 49, 44, 36, 50,
  44, 36, 51, 44, 48, 44, 36, 50, 44, 36, 51, 44, 92, 10, 52, 44,
  48, 44, 51, 44, 50, 44, 49, 44, 52, 44, 52, 44, 53, 44, 54, 44,
  55, 44, 52, 44, 48, 44, 49, 44, 53, 44, 52, 44, 52, 44, 51, 44,
  55, 44, 54, 44, 50, 44, 52, 44, 48, 44, 52, 44, 55, 44, 51, 44,
  52, 44, 49, 44, 50, 44, 54, 44, 53, 44, 92, 10, 50, 48, 48, 44,
  50, 48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44,
  50, 48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44,
  50, 48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44,
  50, 48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44,
  50, 48, 48, 44, 92, 10, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44,
  49, 10, 45, 110, 109, 91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 98,
  111, 120, 93, 10, 45, 118, 32, 43, 10, 99, 51, 100, 32, 58, 10, 45,
  95, 99, 101, 110, 116, 101, 114, 51, 100, 10, 99, 101, 110, 116, 101, 114,
  51, 100, 32, 58, 10, 45, 95, 36, 48, 10, 95, 99, 101, 110, 116, 101,
  114, 51, 100, 32, 58, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34,
  67, 101, 110, 116, 101, 114, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116,
  36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 99, 104, 101, 99, 107,
  51, 100, 32, 48, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 110, 61, 123, 105, 91, 54, 93, 125, 10,
  45, 105, 102, 32, 123, 36, 110, 62, 48, 125, 10, 45, 115, 104, 32, 56,
  44, 123, 55, 43, 51, 42, 36, 110, 125, 44, 48, 44, 48, 32, 45, 114,
  91, 45, 49, 93, 32, 51, 44, 123, 104, 47, 51, 125, 44, 49, 44, 49,
  44, 45, 49, 32, 45, 115, 91, 45, 49, 93, 32, 120, 10, 45, 45, 91,
  45, 51, 93, 32, 64, 123, 45, 51, 44, 40, 105, 77, 43, 105, 109, 41,
  47, 50, 125, 32, 45, 45, 91, 45, 50, 93, 32, 64, 123, 45, 50, 44,
  40, 105, 77, 43, 105, 109, 41, 47, 50, 125, 32, 45, 45, 91, 45, 49,
  93, 32, 123, 40, 105, 77, 43, 105, 109, 41, 47, 50, 125, 10, 45, 97,
  91, 45, 51, 45, 45, 49, 93, 32, 120, 32, 45, 121, 91, 45, 49, 93,
  32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 56,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 99, 105, 114, 99, 108, 101, 51, 100, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 49, 61, 48, 125, 44, 36, 123, 50, 61, 48, 125, 44,
  36, 123, 51, 61, 48, 125, 44, 36, 123, 52, 61, 49, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 51, 100, 32,
  99, 105, 114, 99, 108, 101, 32, 97, 116, 32, 112, 111, 115, 105, 116, 105,
  111, 110, 32, 40, 36, 49, 44, 36, 50, 44, 36, 51, 41, 32, 119, 105,
  116, 104, 32, 114, 97, 100, 105, 117, 115, 32, 36, 52, 46, 34, 10, 45,
  118, 32, 45, 10, 114, 61, 123, 36, 52, 47, 115, 113, 114, 116, 40, 51,
  41, 125, 10, 49, 44, 50, 52, 44, 49, 44, 49, 44, 92, 10, 54, 55,
  46, 53, 44, 55, 51, 46, 53, 44, 49, 48, 57, 46, 53, 44, 49, 48,
  51, 46, 53, 44, 53, 49, 46, 53, 44, 49, 48, 48, 46, 53, 44, 50,
  44, 49, 44, 92, 10, 123, 36, 49, 45, 36, 114, 125, 44, 123, 36, 50,
  45, 36, 114, 125, 44, 123, 36, 51, 45, 36, 114, 125, 44, 92, 10, 123,
  36, 49, 43, 36, 114, 125, 44, 123, 36, 50, 43, 36, 114, 125, 44, 123,
  36, 51, 43, 36, 114, 125, 44, 92, 10, 53, 44, 48, 44, 49, 44, 48,
  44, 48, 44, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44, 50, 48, 48,
  44, 49, 10, 45, 110, 109, 91, 45, 49, 93, 32, 91, 51, 100, 92, 32,
  99, 105, 114, 99, 108, 101, 93, 10, 45, 118, 32, 43, 10, 99, 105, 114,
  99, 108, 101, 115, 51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  36, 123, 49, 61, 49, 125, 62, 61, 48, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 51, 100, 32, 111, 98,
  106, 101, 99, 116, 36, 63, 32, 116, 111, 32, 115, 101, 116, 115, 32, 111,
  102, 32, 51, 100, 32, 99, 105, 114, 99, 108, 101, 115, 32, 119, 105, 116,
  104, 32, 114, 97, 100, 105, 117, 115, 32, 36, 49, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 112, 51, 100, 32, 48, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 110, 98, 118, 61,
  64, 123, 45, 49, 44, 54, 125, 32, 110, 98, 112, 61, 64, 123, 45, 49,
  44, 55, 125, 10, 45, 105, 102, 32, 123, 36, 110, 98, 118, 38, 38, 36,
  110, 98, 112, 125, 10, 45, 45, 51, 100, 32, 123, 36, 49, 47, 50, 125,
  44, 48, 44, 48, 32, 45, 45, 43, 51, 100, 32, 36, 49, 44, 48, 44,
  48, 32, 45, 43, 51, 100, 32, 110, 98, 112, 50, 61, 64, 123, 45, 49,
  44, 55, 125, 10, 45, 115, 51, 100, 32, 45, 61, 91, 49, 93, 32, 36,
  110, 98, 112, 44, 48, 44, 49, 10, 45, 114, 91, 51, 93, 32, 50, 44,
  36, 110, 98, 112, 50, 44, 49, 44, 49, 44, 45, 49, 32, 45, 99, 111,
  108, 117, 109, 110, 115, 91, 51, 93, 32, 49, 44, 49, 32, 45, 115, 91,
  51, 93, 32, 121, 44, 50, 32, 45, 105, 91, 51, 93, 32, 49, 44, 36,
  110, 98, 112, 44, 49, 44, 49, 44, 53, 32, 45, 97, 91, 51, 45, 53,
  93, 32, 120, 32, 45, 99, 111, 108, 117, 109, 110, 115, 91, 51, 93, 32,
  48, 44, 53, 32, 45, 121, 91, 51, 93, 10, 45, 114, 111, 119, 115, 91,
  52, 93, 32, 48, 44, 123, 51, 42, 36, 110, 98, 112, 45, 49, 125, 32,
  45, 114, 111, 119, 115, 91, 53, 93, 32, 48, 44, 123, 36, 110, 98, 112,
  45, 49, 125, 32, 45, 97, 32, 121, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 99, 111, 108, 111, 114, 99, 117, 98, 101, 51, 100, 32, 58, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 51, 100,
  32, 82, 71, 66, 45, 99, 111, 108, 111, 114, 32, 99, 117, 98, 101, 46,
  34, 10, 45, 118, 32, 45, 10, 40, 54, 55, 46, 53, 59, 55, 51, 46,
  53, 59, 49, 48, 57, 46, 53, 59, 49, 48, 51, 46, 53, 59, 53, 49,
  46, 53, 59, 49, 48, 48, 46, 53, 59, 56, 59, 54, 41, 10, 40, 48,
  59, 48, 59, 48, 59, 92, 10, 50, 53, 53, 59, 48, 59, 48, 59, 92,
  10, 50, 53, 53, 59, 50, 53, 53, 59, 48, 59, 92, 10, 48, 59, 50,
  53, 53, 59, 48, 59, 92, 10, 48, 59, 48, 59, 50, 53, 53, 59, 92,
  10, 50, 53, 53, 59, 48, 59, 50, 53, 53, 59, 92, 10, 50, 53, 53,
  59, 50, 53, 53, 59, 50, 53, 53, 59, 92, 10, 48, 59, 50, 53, 53,
  59, 50, 53, 53, 41, 10, 40, 49, 50, 59, 48, 59, 51, 59, 50, 59,
  49, 59, 48, 59, 48, 59, 48, 59, 54, 51, 59, 54, 51, 59, 54, 51,
  59, 54, 51, 59, 48, 59, 92, 10, 49, 50, 59, 49, 59, 50, 59, 54,
  59, 53, 59, 48, 59, 48, 59, 48, 59, 54, 51, 59, 54, 51, 59, 54,
  51, 59, 54, 51, 59, 48, 59, 92, 10, 49, 50, 59, 48, 59, 52, 59,
  55, 59, 51, 59, 48, 59, 48, 59, 54, 51, 59, 48, 59, 54, 51, 59,
  54, 51, 59, 48, 59, 54, 51, 59, 92, 10, 49, 50, 59, 52, 59, 53,
  59, 54, 59, 55, 59, 48, 59, 48, 59, 54, 51, 59, 48, 59, 54, 51,
  59, 54, 51, 59, 48, 59, 54, 51, 59, 92, 10, 49, 50, 59, 48, 59,
  49, 59, 53, 59, 52, 59, 48, 59, 48, 59, 54, 51, 59, 48, 59, 54,
  51, 59, 54, 51, 59, 48, 59, 54, 51, 59, 92, 10, 49, 50, 59, 51,
  59, 55, 59, 54, 59, 50, 59, 48, 59, 48, 59, 48, 59, 54, 51, 59,
  54, 51, 59, 54, 51, 59, 54, 51, 59, 48, 41, 10, 40, 48, 44, 50,
  53, 53, 59, 48, 44, 50, 53, 53, 94, 48, 44, 48, 59, 50, 53, 53,
  44, 50, 53, 53, 94, 48, 44, 48, 59, 48, 44, 48, 41, 10, 40, 50,
  53, 53, 44, 50, 53, 53, 59, 50, 53, 53, 44, 50, 53, 53, 94, 48,
  44, 48, 59, 50, 53, 53, 44, 50, 53, 53, 94, 48, 44, 50, 53, 53,
  59, 48, 44, 50, 53, 53, 41, 10, 40, 48, 44, 48, 59, 48, 44, 48,
  94, 48, 44, 48, 59, 50, 53, 53, 44, 50, 53, 53, 94, 48, 44, 50,
  53, 53, 59, 48, 44, 50, 53, 53, 41, 10, 40, 48, 44, 50, 53, 53,
  59, 48, 44, 50, 53, 53, 94, 48, 44, 48, 59, 50, 53, 53, 44, 50,
  53, 53, 94, 50, 53, 53, 44, 50, 53, 53, 59, 50, 53, 53, 44, 50,
  53, 53, 41, 10, 40, 48, 44, 50, 53, 53, 59, 48, 44, 50, 53, 53,
  94, 48, 44, 48, 59, 48, 44, 48, 94, 48, 44, 48, 59, 50, 53, 53,
  44, 50, 53, 53, 41, 10, 40, 48, 44, 50, 53, 53, 59, 48, 44, 50,
  53, 53, 94, 50, 53, 53, 44, 50, 53, 53, 59, 50, 53, 53, 44, 50,
  53, 53, 94, 48, 44, 48, 59, 50, 53, 53, 44, 50, 53, 53, 41, 10,
  45, 114, 91, 45, 54, 45, 45, 49, 93, 32, 54, 52, 44, 54, 52, 44,
  49, 44, 51, 44, 51, 32, 45, 121, 91, 45, 54, 45, 45, 49, 93, 32,
  45, 105, 91, 45, 55, 45, 45, 50, 93, 32, 40, 45, 49, 50, 56, 59,
  54, 52, 59, 54, 52, 59, 51, 41, 10, 40, 49, 59, 49, 59, 49, 59,
  49, 59, 49, 59, 49, 41, 10, 45, 97, 91, 45, 49, 54, 45, 45, 49,
  93, 32, 121, 32, 45, 110, 109, 91, 45, 49, 93, 32, 91, 51, 100, 92,
  32, 99, 111, 108, 111, 114, 99, 117, 98, 101, 93, 10, 45, 118, 32, 43,
  10, 99, 111, 110, 101, 51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 36, 123, 51, 61, 50, 52, 125, 62, 48, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 49, 61, 49, 125, 44, 36, 123, 50, 61, 49, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 51, 100,
  32, 99, 111, 110, 101, 44, 32, 119, 105, 116, 104, 32, 114, 97, 100, 105,
  117, 115, 32, 36, 49, 44, 32, 104, 101, 105, 103, 104, 116, 32, 36, 50,
  32, 97, 110, 100, 32, 36, 51, 32, 115, 117, 98, 100, 105, 118, 105, 115,
  105, 111, 110, 115, 46, 34, 10, 45, 118, 32, 45, 10, 40, 54, 55, 46,
  53, 59, 55, 51, 46, 53, 59, 49, 48, 57, 46, 53, 59, 49, 48, 51,
  46, 53, 59, 53, 49, 46, 53, 59, 49, 48, 48, 46, 53, 41, 10, 40,
  123, 36, 51, 43, 50, 125, 59, 123, 50, 42, 36, 51, 125, 41, 10, 40,
  48, 44, 48, 44, 48, 59, 48, 44, 48, 44, 36, 50, 41, 10, 40, 48,
  59, 123, 50, 42, 112, 105, 125, 41, 32, 45, 114, 91, 45, 49, 93, 32,
  49, 44, 123, 36, 51, 43, 49, 125, 44, 49, 44, 49, 44, 51, 32, 45,
  114, 111, 119, 115, 91, 45, 49, 93, 32, 48, 44, 123, 36, 51, 45, 49,
  125, 32, 45, 45, 115, 105, 110, 91, 45, 49, 93, 32, 45, 99, 111, 115,
  91, 45, 50, 93, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 36,
  49, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 122,
  91, 45, 49, 93, 32, 48, 44, 50, 32, 45, 97, 91, 45, 50, 44, 45,
  49, 93, 32, 121, 10, 49, 44, 36, 51, 44, 49, 44, 49, 44, 39, 121,
  39, 32, 45, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 48, 44,
  45, 49, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 50, 10, 50,
  44, 36, 51, 44, 49, 44, 49, 44, 51, 44, 48, 32, 91, 45, 50, 93,
  32, 91, 45, 52, 93, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32,
  120, 10, 45, 105, 91, 45, 52, 93, 32, 50, 44, 36, 51, 44, 49, 44,
  49, 44, 51, 44, 49, 32, 45, 97, 91, 45, 52, 45, 45, 50, 93, 32,
  120, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 10, 51, 44,
  123, 104, 125, 44, 49, 44, 49, 44, 50, 48, 48, 10, 49, 44, 123, 104,
  125, 44, 49, 44, 49, 44, 49, 10, 45, 121, 91, 45, 52, 45, 45, 50,
  93, 32, 45, 97, 91, 45, 54, 45, 45, 49, 93, 32, 121, 32, 45, 110,
  109, 91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 99, 111, 110, 101, 93,
  10, 45, 118, 32, 43, 10, 99, 117, 98, 101, 115, 51, 100, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 36, 123, 49, 61, 49, 125, 62, 61, 48,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114,
  116, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 36, 63, 32, 116, 111,
  32, 115, 101, 116, 115, 32, 111, 102, 32, 51, 100, 32, 99, 117, 98, 101,
  115, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101, 32, 36, 49, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 112, 51, 100, 32, 48, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 110,
  98, 118, 61, 64, 123, 45, 49, 44, 54, 125, 32, 110, 98, 112, 61, 64,
  123, 45, 49, 44, 55, 125, 10, 45, 105, 102, 32, 123, 36, 110, 98, 118,
  38, 38, 36, 110, 98, 112, 125, 10, 45, 115, 51, 100, 10, 45, 108, 91,
  49, 93, 32, 45, 61, 32, 123, 56, 42, 105, 91, 48, 93, 125, 32, 45,
  61, 32, 123, 54, 42, 105, 91, 49, 93, 125, 44, 48, 44, 49, 32, 45,
  101, 110, 100, 108, 10, 45, 108, 91, 50, 93, 32, 45, 114, 32, 51, 44,
  123, 104, 47, 51, 125, 44, 49, 44, 49, 44, 45, 49, 10, 104, 97, 108,
  102, 61, 123, 36, 49, 47, 50, 125, 10, 45, 45, 32, 39, 36, 104, 97,
  108, 102, 44, 48, 44, 48, 39, 32, 45, 45, 43, 32, 39, 36, 49, 44,
  48, 44, 48, 39, 32, 45, 97, 32, 120, 10, 45, 45, 32, 39, 48, 44,
  36, 104, 97, 108, 102, 44, 48, 39, 32, 45, 45, 43, 32, 39, 48, 44,
  36, 49, 44, 48, 39, 32, 45, 97, 32, 120, 10, 45, 45, 32, 39, 48,
  44, 48, 44, 36, 104, 97, 108, 102, 39, 32, 45, 45, 43, 32, 39, 48,
  44, 48, 44, 36, 49, 39, 32, 45, 97, 32, 120, 10, 45, 101, 110, 100,
  108, 10, 45, 108, 91, 51, 93, 32, 45, 114, 32, 50, 44, 123, 104, 47,
  50, 125, 44, 49, 44, 49, 44, 45, 49, 10, 45, 122, 32, 49, 44, 49,
  32, 45, 42, 32, 56, 32, 45, 114, 32, 52, 44, 49, 48, 48, 37, 32,
  45, 105, 91, 48, 93, 32, 49, 44, 49, 48, 48, 37, 44, 49, 44, 49,
  44, 52, 32, 45, 97, 32, 120, 32, 91, 45, 49, 93, 120, 53, 32, 45,
  97, 32, 120, 10, 45, 43, 32, 39, 34, 48, 44, 48, 44, 50, 44, 51,
  44, 49, 44, 32, 48, 44, 52, 44, 53, 44, 55, 44, 54, 44, 32, 48,
  44, 48, 44, 49, 44, 53, 44, 52, 44, 32, 48, 44, 50, 44, 54, 44,
  55, 44, 51, 44, 32, 48, 44, 48, 44, 52, 44, 54, 44, 50, 44, 32,
  48, 44, 49, 44, 51, 44, 55, 44, 53, 34, 39, 10, 45, 101, 110, 100,
  108, 10, 45, 108, 91, 52, 93, 32, 45, 114, 32, 51, 44, 123, 104, 47,
  51, 125, 44, 49, 44, 49, 44, 45, 49, 32, 45, 114, 32, 49, 56, 44,
  49, 48, 48, 37, 44, 49, 44, 49, 44, 48, 44, 50, 32, 45, 101, 110,
  100, 108, 32, 45, 114, 91, 53, 93, 32, 54, 44, 49, 48, 48, 37, 10,
  45, 121, 32, 45, 97, 32, 121, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  99, 117, 112, 51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36,
  123, 49, 61, 49, 50, 56, 125, 62, 48, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 73, 110, 112, 117, 116, 32, 51, 100, 32, 99, 117, 112, 44,
  32, 119, 105, 116, 104, 32, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110,
  32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 10, 49, 48, 48, 44, 50,
  48, 48, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32,
  48, 37, 44, 48, 37, 44, 52, 48, 37, 44, 52, 48, 37, 44, 48, 44,
  49, 44, 49, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93,
  32, 48, 44, 48, 44, 51, 53, 37, 44, 51, 53, 37, 44, 48, 44, 49,
  44, 48, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32,
  52, 44, 48, 44, 52, 53, 37, 44, 56, 37, 44, 52, 53, 37, 44, 50,
  48, 37, 44, 57, 48, 37, 44, 48, 44, 57, 48, 37, 44, 49, 44, 49,
  10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 48, 37,
  44, 49, 48, 48, 37, 44, 51, 48, 37, 44, 49, 48, 37, 44, 48, 44,
  49, 44, 49, 32, 45, 98, 91, 45, 49, 93, 32, 48, 46, 49, 37, 10,
  45, 108, 97, 116, 104, 101, 51, 100, 91, 45, 49, 93, 32, 36, 49, 44,
  50, 32, 45, 110, 109, 91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 99,
  117, 112, 93, 10, 45, 118, 32, 43, 10, 99, 121, 108, 105, 110, 100, 101,
  114, 51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 123, 51,
  61, 50, 52, 125, 62, 48, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49,
  61, 49, 125, 44, 36, 123, 50, 61, 49, 125, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 51, 100, 32, 99, 121, 108,
  105, 110, 100, 101, 114, 44, 32, 119, 105, 116, 104, 32, 114, 97, 100, 105,
  117, 115, 32, 36, 49, 44, 32, 104, 101, 105, 103, 104, 116, 32, 36, 50,
  32, 97, 110, 100, 32, 36, 51, 32, 115, 117, 98, 100, 105, 118, 105, 115,
  105, 111, 110, 115, 46, 34, 10, 45, 118, 32, 45, 10, 40, 54, 55, 46,
  53, 59, 55, 51, 46, 53, 59, 49, 48, 57, 46, 53, 59, 49, 48, 51,
  46, 53, 59, 53, 49, 46, 53, 59, 49, 48, 48, 46, 53, 41, 10, 40,
  123, 50, 42, 36, 51, 43, 50, 125, 59, 123, 51, 42, 36, 51, 125, 41,
  10, 40, 48, 44, 48, 44, 48, 59, 48, 44, 48, 44, 36, 50, 41, 10,
  40, 48, 59, 123, 50, 42, 112, 105, 125, 41, 32, 45, 114, 91, 45, 49,
  93, 32, 49, 44, 123, 36, 51, 43, 49, 125, 44, 49, 44, 49, 44, 51,
  32, 45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 48, 44, 123, 36, 51,
  45, 49, 125, 32, 45, 45, 115, 105, 110, 91, 45, 49, 93, 32, 45, 99,
  111, 115, 91, 45, 50, 93, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93,
  32, 36, 49, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 10,
  45, 45, 122, 91, 45, 49, 93, 32, 48, 44, 50, 32, 49, 44, 36, 51,
  44, 49, 44, 49, 44, 36, 50, 32, 45, 97, 91, 45, 51, 44, 45, 49,
  93, 32, 120, 10, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 121, 10,
  49, 44, 36, 51, 44, 49, 44, 49, 44, 39, 121, 39, 32, 45, 45, 115,
  104, 105, 102, 116, 91, 45, 49, 93, 32, 48, 44, 45, 49, 32, 45, 43,
  91, 45, 50, 44, 45, 49, 93, 32, 50, 10, 50, 44, 36, 51, 44, 49,
  44, 49, 44, 51, 44, 49, 32, 91, 45, 51, 93, 32, 91, 45, 51, 93,
  32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 120, 10, 50, 44, 36,
  51, 44, 49, 44, 49, 44, 51, 44, 48, 32, 91, 45, 51, 93, 32, 91,
  45, 53, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 36, 51,
  32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 120, 10, 45, 45, 43,
  91, 45, 52, 44, 45, 51, 93, 32, 36, 51, 32, 45, 105, 91, 45, 55,
  93, 32, 49, 44, 36, 51, 44, 49, 44, 49, 44, 52, 32, 45, 114, 118,
  91, 45, 54, 44, 45, 53, 93, 32, 45, 97, 91, 45, 55, 45, 45, 53,
  44, 45, 50, 44, 45, 49, 93, 32, 120, 10, 51, 44, 123, 51, 42, 36,
  51, 125, 44, 49, 44, 49, 44, 50, 48, 48, 10, 49, 44, 123, 104, 125,
  44, 49, 44, 49, 44, 49, 10, 45, 121, 91, 45, 54, 45, 45, 50, 93,
  32, 45, 97, 91, 45, 56, 45, 45, 49, 93, 32, 121, 32, 45, 110, 109,
  91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 99, 121, 108, 105, 110, 100,
  101, 114, 93, 10, 45, 118, 32, 43, 10, 100, 105, 115, 116, 114, 105, 98,
  117, 116, 105, 111, 110, 51, 100, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 71, 101, 116, 32, 51, 100, 32, 99, 111, 108, 111, 114, 32,
  100, 105, 115, 116, 114, 105, 98, 117, 116, 105, 111, 110, 32, 111, 102, 32,
  105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  116, 111, 95, 114, 103, 98, 32, 45, 112, 101, 114, 109, 117, 116, 101, 32,
  34, 99, 120, 121, 122, 34, 32, 45, 121, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 110, 98, 112, 61,
  123, 104, 47, 51, 125, 10, 45, 105, 91, 45, 50, 93, 32, 40, 54, 55,
  46, 53, 59, 55, 51, 46, 53, 59, 49, 48, 57, 46, 53, 59, 49, 48,
  51, 46, 53, 59, 53, 49, 46, 53, 59, 49, 48, 48, 46, 53, 59, 92,
  10, 36, 110, 98, 112, 59, 36, 110, 98, 112, 41, 10, 40, 49, 44, 48,
  59, 49, 44, 123, 36, 110, 98, 112, 45, 49, 125, 41, 32, 45, 114, 91,
  45, 49, 93, 32, 50, 44, 36, 110, 98, 112, 44, 49, 44, 49, 44, 51,
  32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 49, 32, 45, 121,
  91, 45, 49, 93, 10, 91, 45, 50, 93, 10, 49, 44, 36, 110, 98, 112,
  44, 49, 44, 49, 44, 49, 10, 45, 97, 32, 121, 32, 45, 110, 109, 91,
  45, 49, 93, 32, 91, 51, 100, 92, 32, 100, 105, 115, 116, 114, 105, 98,
  117, 116, 105, 111, 110, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 101, 109, 112, 116, 121, 51, 100, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116,
  32, 101, 109, 112, 116, 121, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116,
  46, 34, 10, 45, 118, 32, 45, 32, 40, 54, 55, 46, 53, 59, 55, 51,
  46, 53, 59, 49, 48, 57, 46, 53, 59, 49, 48, 51, 46, 53, 59, 53,
  49, 46, 53, 59, 49, 48, 48, 46, 53, 59, 48, 59, 48, 41, 32, 45,
  110, 109, 91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 101, 109, 112, 116,
  121, 93, 32, 45, 118, 32, 43, 10, 101, 120, 116, 114, 117, 100, 101, 51,
  100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61,
  49, 54, 125, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 49, 48, 50,
  52, 125, 62, 48, 32, 38, 38, 32, 36, 123, 51, 61, 48, 46, 53, 37,
  125, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 71,
  101, 110, 101, 114, 97, 116, 101, 32, 101, 120, 116, 114, 117, 100, 101, 100,
  32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 32, 102, 114, 111, 109, 32,
  88, 89, 45, 112, 114, 111, 102, 105, 108, 101, 36, 63, 44, 32, 119, 105,
  116, 104, 32, 100, 101, 112, 116, 104, 32, 36, 49, 44, 32, 114, 101, 115,
  111, 108, 117, 116, 105, 111, 110, 32, 36, 50, 32, 97, 110, 100, 32, 115,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 51, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 110, 111, 114, 109, 32, 45, 110, 32, 48, 44, 49,
  32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 48, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110,
  109, 61, 64, 123, 48, 44, 110, 125, 10, 119, 114, 61, 123, 114, 111, 117,
  110, 100, 40, 109, 97, 120, 40, 49, 44, 105, 102, 40, 119, 62, 104, 44,
  109, 105, 110, 40, 36, 50, 44, 119, 41, 44, 109, 105, 110, 40, 36, 50,
  44, 104, 41, 42, 119, 47, 104, 41, 41, 41, 125, 10, 104, 114, 61, 123,
  114, 111, 117, 110, 100, 40, 109, 97, 120, 40, 49, 44, 105, 102, 40, 119,
  62, 104, 44, 109, 105, 110, 40, 36, 50, 44, 119, 41, 42, 104, 47, 119,
  44, 109, 105, 110, 40, 36, 50, 44, 104, 41, 41, 41, 41, 125, 10, 102,
  97, 99, 116, 61, 123, 36, 49, 47, 109, 97, 120, 40, 119, 47, 36, 119,
  114, 44, 104, 47, 36, 104, 114, 41, 125, 10, 45, 98, 32, 36, 51, 44,
  48, 32, 45, 114, 32, 36, 119, 114, 44, 36, 104, 114, 44, 49, 44, 49,
  44, 50, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 122, 32, 49,
  44, 48, 10, 45, 105, 115, 111, 115, 117, 114, 102, 97, 99, 101, 51, 100,
  32, 53, 48, 37, 32, 45, 42, 51, 100, 32, 49, 44, 49, 44, 36, 102,
  97, 99, 116, 32, 45, 114, 118, 51, 100, 10, 45, 110, 109, 32, 36, 110,
  109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 103, 97, 117, 115, 115, 105, 97, 110, 115, 51, 100,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 51,
  50, 125, 62, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61,
  48, 46, 51, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111,
  110, 118, 101, 114, 116, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 36,
  63, 32, 105, 110, 116, 111, 32, 115, 101, 116, 115, 32, 111, 102, 32, 103,
  97, 117, 115, 115, 105, 97, 110, 45, 115, 104, 97, 112, 101, 100, 32, 51,
  100, 32, 115, 112, 114, 105, 116, 101, 115, 44, 32, 119, 105, 116, 104, 32,
  115, 105, 122, 101, 32, 36, 49, 32, 97, 110, 100, 32, 111, 112, 97, 99,
  105, 116, 121, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 45, 112,
  51, 100, 32, 50, 32, 45, 112, 51, 100, 32, 48, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109,
  61, 64, 123, 48, 44, 110, 125, 32, 45, 115, 51, 100, 10, 110, 98, 118,
  61, 123, 104, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 40, 45, 49,
  50, 56, 59, 36, 49, 59, 36, 49, 59, 49, 41, 10, 36, 49, 44, 36,
  49, 32, 45, 103, 97, 117, 115, 115, 105, 97, 110, 91, 45, 49, 93, 32,
  51, 53, 37, 44, 51, 53, 37, 44, 48, 32, 45, 99, 91, 45, 49, 93,
  32, 51, 48, 37, 44, 49, 48, 48, 37, 32, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 36, 50, 32, 45, 121, 91, 45, 49, 93, 32, 45, 97, 91,
  45, 50, 44, 45, 49, 93, 32, 121, 10, 45, 105, 102, 32, 123, 36, 110,
  98, 118, 62, 49, 125, 32, 52, 44, 123, 36, 110, 98, 118, 45, 49, 125,
  44, 49, 44, 49, 44, 45, 49, 50, 56, 44, 48, 44, 48, 44, 48, 32,
  45, 121, 91, 45, 50, 44, 45, 49, 93, 32, 45, 97, 91, 45, 50, 44,
  45, 49, 93, 32, 121, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 32,
  121, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 103, 109, 105,
  99, 51, 100, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73,
  110, 112, 117, 116, 32, 51, 100, 32, 71, 39, 77, 73, 67, 32, 108, 111,
  103, 111, 46, 34, 10, 45, 118, 32, 45, 10, 45, 116, 101, 120, 116, 51,
  100, 32, 71, 44, 54, 48, 44, 50, 48, 44, 50, 32, 45, 99, 111, 108,
  51, 100, 91, 45, 49, 93, 32, 49, 54, 44, 54, 52, 44, 50, 53, 53,
  10, 45, 116, 101, 120, 116, 51, 100, 32, 92, 39, 44, 54, 48, 44, 50,
  48, 44, 50, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 51, 48, 32,
  45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 54, 52, 44, 49, 50,
  56, 44, 50, 53, 53, 10, 45, 116, 101, 120, 116, 51, 100, 32, 77, 44,
  54, 48, 44, 50, 48, 44, 50, 32, 45, 43, 51, 100, 91, 45, 49, 93,
  32, 52, 48, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 57,
  54, 44, 49, 57, 54, 44, 50, 53, 53, 10, 45, 116, 101, 120, 116, 51,
  100, 32, 73, 44, 54, 48, 44, 50, 48, 44, 50, 32, 45, 43, 51, 100,
  91, 45, 49, 93, 32, 55, 48, 32, 45, 99, 111, 108, 51, 100, 91, 45,
  49, 93, 32, 54, 52, 44, 49, 50, 56, 44, 50, 53, 53, 10, 45, 116,
  101, 120, 116, 51, 100, 32, 67, 44, 54, 48, 44, 50, 48, 44, 50, 32,
  45, 43, 51, 100, 91, 45, 49, 93, 32, 57, 53, 32, 45, 99, 111, 108,
  51, 100, 91, 45, 49, 93, 32, 49, 54, 44, 54, 52, 44, 50, 53, 53,
  10, 45, 115, 112, 104, 101, 114, 101, 51, 100, 32, 56, 32, 45, 43, 51,
  100, 91, 45, 49, 93, 32, 56, 53, 44, 45, 49, 48, 44, 49, 53, 32,
  45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 49, 57, 50, 44, 49,
  50, 56, 44, 50, 53, 53, 10, 45, 43, 51, 100, 91, 45, 54, 45, 45,
  49, 93, 32, 45, 99, 51, 100, 91, 45, 49, 93, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 51, 48, 10, 45, 98, 111, 120, 51, 100, 32, 123, 109,
  105, 110, 40, 51, 43, 64, 123, 60, 44, 45, 49, 125, 47, 50, 44, 49,
  48, 41, 125, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 123,
  51, 48, 42, 36, 62, 125, 44, 123, 50, 48, 43, 56, 48, 42, 36, 62,
  125, 44, 123, 49, 48, 42, 36, 62, 125, 44, 48, 46, 53, 10, 45, 114,
  51, 100, 91, 45, 49, 93, 32, 49, 44, 49, 44, 49, 44, 123, 36, 62,
  42, 49, 50, 125, 10, 45, 43, 51, 100, 91, 45, 49, 93, 32, 123, 56,
  48, 42, 99, 111, 115, 40, 48, 46, 53, 43, 49, 46, 48, 50, 42, 36,
  62, 42, 49, 50, 42, 112, 105, 47, 49, 56, 48, 41, 125, 44, 123, 51,
  48, 42, 115, 105, 110, 40, 48, 46, 56, 43, 36, 62, 42, 49, 50, 42,
  112, 105, 47, 49, 56, 48, 41, 125, 44, 123, 50, 42, 36, 62, 45, 55,
  53, 125, 10, 45, 100, 111, 110, 101, 10, 45, 43, 51, 100, 91, 45, 51,
  48, 45, 45, 49, 93, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 48,
  44, 53, 44, 51, 48, 32, 45, 43, 51, 100, 91, 45, 50, 45, 45, 49,
  93, 32, 45, 110, 109, 91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 103,
  109, 105, 99, 93, 10, 45, 118, 32, 43, 10, 103, 121, 114, 111, 105, 100,
  51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 123, 49, 61,
  51, 50, 125, 62, 48, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61,
  53, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117,
  116, 32, 51, 100, 32, 103, 121, 114, 111, 105, 100, 44, 32, 119, 105, 116,
  104, 32, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 32, 36, 49, 32,
  97, 110, 100, 32, 114, 97, 110, 103, 101, 32, 36, 50, 46, 34, 10, 45,
  118, 32, 45, 10, 45, 105, 115, 111, 115, 117, 114, 102, 97, 99, 101, 51,
  100, 32, 34, 39, 48, 46, 52, 57, 42, 40, 92, 10, 99, 111, 115, 40,
  32, 50, 42, 120, 32, 43, 32, 121, 32, 43, 32, 122, 32, 45, 32, 112,
  105, 41, 32, 43, 32, 99, 111, 115, 40, 32, 50, 42, 120, 32, 45, 32,
  121, 32, 43, 32, 122, 32, 45, 32, 112, 105, 41, 92, 10, 43, 32, 99,
  111, 115, 40, 45, 32, 50, 42, 120, 32, 43, 32, 121, 32, 45, 32, 122,
  32, 45, 32, 112, 105, 41, 32, 43, 32, 99, 111, 115, 40, 45, 32, 50,
  42, 120, 32, 45, 32, 121, 32, 45, 32, 122, 32, 45, 32, 112, 105, 41,
  92, 10, 43, 32, 99, 111, 115, 40, 32, 120, 32, 43, 32, 50, 42, 121,
  32, 43, 32, 122, 32, 45, 32, 112, 105, 41, 32, 43, 32, 99, 111, 115,
  40, 32, 120, 32, 43, 32, 50, 42, 121, 32, 45, 32, 122, 32, 45, 32,
  112, 105, 41, 92, 10, 43, 32, 99, 111, 115, 40, 45, 32, 120, 32, 45,
  32, 50, 42, 121, 32, 43, 32, 122, 32, 45, 32, 112, 105, 41, 32, 43,
  32, 99, 111, 115, 40, 45, 32, 120, 32, 45, 32, 50, 42, 121, 32, 45,
  32, 122, 32, 45, 32, 112, 105, 41, 92, 10, 43, 32, 99, 111, 115, 40,
  32, 120, 32, 43, 32, 121, 32, 43, 32, 50, 42, 122, 32, 45, 32, 112,
  105, 41, 32, 43, 32, 99, 111, 115, 40, 45, 32, 120, 32, 43, 32, 121,
  32, 43, 32, 50, 42, 122, 32, 45, 32, 112, 105, 41, 92, 10, 43, 32,
  99, 111, 115, 40, 32, 120, 32, 45, 32, 121, 32, 45, 32, 50, 42, 122,
  32, 45, 32, 112, 105, 41, 32, 43, 32, 99, 111, 115, 40, 45, 32, 120,
  32, 45, 32, 121, 32, 45, 32, 50, 42, 122, 32, 45, 32, 112, 105, 41,
  92, 10, 43, 32, 99, 111, 115, 40, 45, 32, 50, 42, 120, 32, 43, 32,
  121, 32, 43, 32, 122, 41, 32, 43, 32, 99, 111, 115, 40, 32, 50, 42,
  120, 32, 43, 32, 121, 32, 45, 32, 122, 41, 92, 10, 43, 32, 99, 111,
  115, 40, 45, 32, 50, 42, 120, 32, 45, 32, 121, 32, 43, 32, 122, 41,
  32, 43, 32, 99, 111, 115, 40, 32, 50, 42, 120, 32, 45, 32, 121, 32,
  45, 32, 122, 41, 92, 10, 43, 32, 99, 111, 115, 40, 45, 32, 120, 32,
  43, 32, 50, 42, 121, 32, 43, 32, 122, 41, 32, 43, 32, 99, 111, 115,
  40, 32, 120, 32, 45, 32, 50, 42, 121, 32, 43, 32, 122, 41, 92, 10,
  43, 32, 99, 111, 115, 40, 45, 32, 120, 32, 43, 32, 50, 42, 121, 32,
  45, 32, 122, 41, 32, 43, 32, 99, 111, 115, 40, 32, 120, 32, 45, 32,
  50, 42, 121, 32, 45, 32, 122, 41, 92, 10, 43, 32, 99, 111, 115, 40,
  32, 120, 32, 45, 32, 121, 32, 43, 32, 50, 42, 122, 41, 32, 43, 32,
  99, 111, 115, 40, 32, 120, 32, 43, 32, 121, 32, 45, 32, 50, 42, 122,
  41, 92, 10, 43, 32, 99, 111, 115, 40, 45, 32, 120, 32, 45, 32, 121,
  32, 43, 32, 50, 42, 122, 41, 32, 43, 32, 99, 111, 115, 40, 45, 32,
  120, 32, 43, 32, 121, 32, 45, 32, 50, 42, 122, 41, 92, 10, 41, 32,
  43, 32, 48, 46, 50, 55, 42, 40, 32, 92, 10, 99, 111, 115, 40, 45,
  32, 50, 42, 120, 32, 43, 32, 50, 42, 121, 32, 45, 32, 112, 105, 41,
  32, 43, 32, 99, 111, 115, 40, 32, 50, 42, 120, 32, 45, 32, 50, 42,
  121, 32, 45, 32, 112, 105, 41, 92, 10, 43, 32, 99, 111, 115, 40, 32,
  50, 42, 120, 32, 43, 32, 50, 42, 121, 32, 45, 32, 112, 105, 41, 32,
  43, 32, 99, 111, 115, 40, 45, 32, 50, 42, 120, 32, 45, 32, 50, 42,
  121, 32, 45, 32, 112, 105, 41, 92, 10, 43, 32, 99, 111, 115, 40, 45,
  32, 50, 42, 121, 32, 43, 32, 50, 42, 122, 32, 45, 32, 112, 105, 41,
  32, 43, 32, 99, 111, 115, 40, 32, 50, 42, 121, 32, 45, 32, 50, 42,
  122, 32, 45, 32, 112, 105, 41, 92, 10, 43, 32, 99, 111, 115, 40, 32,
  50, 42, 121, 32, 43, 32, 50, 42, 122, 32, 45, 32, 112, 105, 41, 32,
  43, 32, 99, 111, 115, 40, 45, 32, 50, 42, 121, 32, 45, 32, 50, 42,
  122, 32, 45, 32, 112, 105, 41, 92, 10, 43, 32, 99, 111, 115, 40, 45,
  32, 50, 42, 122, 32, 43, 32, 50, 42, 120, 32, 45, 32, 112, 105, 41,
  32, 43, 32, 99, 111, 115, 40, 32, 50, 42, 122, 32, 45, 32, 50, 42,
  120, 32, 45, 32, 112, 105, 41, 92, 10, 43, 32, 99, 111, 115, 40, 32,
  50, 42, 122, 32, 43, 32, 50, 42, 120, 32, 45, 32, 112, 105, 41, 32,
  43, 32, 99, 111, 115, 40, 45, 32, 50, 42, 122, 32, 45, 32, 50, 42,
  120, 32, 45, 32, 112, 105, 41, 92, 10, 41, 32, 45, 32, 48, 46, 54,
  57, 39, 34, 44, 48, 44, 123, 45, 36, 50, 125, 44, 123, 45, 36, 50,
  125, 44, 123, 45, 36, 50, 125, 44, 36, 50, 44, 36, 50, 44, 36, 50,
  44, 36, 49, 44, 36, 49, 44, 36, 49, 10, 45, 99, 51, 100, 91, 45,
  49, 93, 32, 45, 110, 51, 100, 91, 45, 49, 93, 32, 45, 110, 109, 91,
  45, 49, 93, 32, 91, 51, 100, 92, 32, 103, 121, 114, 111, 105, 100, 93,
  10, 45, 118, 32, 43, 10, 104, 105, 115, 116, 111, 103, 114, 97, 109, 51,
  100, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 71, 101, 116,
  32, 51, 100, 32, 99, 111, 108, 111, 114, 32, 104, 105, 115, 116, 111, 103,
  114, 97, 109, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  45, 114, 32, 123, 119, 42, 104, 125, 44, 51, 44, 49, 44, 49, 44, 45,
  49, 32, 45, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 32, 49, 32,
  45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 109, 97, 112, 32, 51, 32,
  45, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 51, 100, 32, 45, 110,
  109, 32, 34, 91, 51, 100, 32, 104, 105, 115, 116, 111, 103, 114, 97, 109,
  93, 34, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 105, 109, 97, 103, 101, 54, 99, 117, 98, 101, 51, 100,
  32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 71, 101, 110, 101,
  114, 97, 116, 101, 32, 51, 100, 32, 109, 97, 112, 112, 101, 100, 32, 99,
  117, 98, 101, 115, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36,
  63, 46, 34, 10, 45, 118, 32, 45, 32, 77, 61, 123, 109, 97, 120, 40,
  64, 123, 45, 109, 97, 120, 95, 119, 104, 125, 41, 125, 32, 45, 114, 32,
  36, 77, 44, 36, 77, 44, 49, 44, 51, 32, 45, 105, 109, 97, 103, 101,
  112, 108, 97, 110, 101, 51, 100, 32, 45, 110, 51, 100, 32, 45, 99, 51,
  100, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64,
  35, 47, 54, 41, 125, 10, 45, 43, 51, 100, 91, 45, 54, 93, 32, 48,
  44, 48, 44, 45, 48, 46, 53, 10, 45, 114, 51, 100, 91, 45, 53, 93,
  32, 49, 44, 48, 44, 48, 44, 49, 56, 48, 32, 45, 43, 51, 100, 91,
  45, 53, 93, 32, 48, 44, 48, 44, 48, 46, 53, 10, 45, 114, 51, 100,
  91, 45, 52, 93, 32, 48, 44, 49, 44, 48, 44, 45, 57, 48, 32, 45,
  43, 51, 100, 91, 45, 52, 93, 32, 45, 48, 46, 53, 44, 48, 44, 48,
  10, 45, 114, 51, 100, 91, 45, 51, 93, 32, 48, 44, 49, 44, 48, 44,
  57, 48, 32, 45, 43, 51, 100, 91, 45, 51, 93, 32, 48, 46, 53, 44,
  48, 44, 48, 10, 45, 114, 51, 100, 91, 45, 50, 93, 32, 49, 44, 48,
  44, 48, 44, 57, 48, 32, 45, 43, 51, 100, 91, 45, 50, 93, 32, 48,
  44, 45, 48, 46, 53, 44, 48, 10, 45, 114, 51, 100, 91, 45, 49, 93,
  32, 49, 44, 48, 44, 48, 44, 45, 57, 48, 32, 45, 43, 51, 100, 91,
  45, 49, 93, 32, 48, 44, 48, 46, 53, 44, 48, 10, 45, 43, 51, 100,
  91, 45, 54, 45, 45, 49, 93, 32, 45, 110, 109, 91, 45, 49, 93, 32,
  34, 91, 51, 100, 32, 105, 109, 97, 103, 101, 32, 99, 117, 98, 101, 93,
  34, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 105, 109, 97, 103, 101, 98, 108, 111, 99,
  107, 115, 51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 123,
  50, 61, 48, 125, 62, 61, 48, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  49, 61, 49, 48, 125, 44, 36, 123, 51, 61, 48, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 71, 101, 110, 101, 114, 97, 116, 101, 32, 51,
  100, 32, 98, 108, 111, 99, 107, 115, 32, 102, 114, 111, 109, 32, 105, 109,
  97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 109, 97, 120, 105,
  109, 117, 109, 32, 101, 108, 101, 118, 97, 116, 105, 111, 110, 32, 36, 49,
  32, 97, 110, 100, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 61, 123, 119,
  125, 32, 104, 61, 123, 104, 125, 10, 45, 115, 112, 108, 105, 116, 95, 111,
  112, 97, 99, 105, 116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48,
  93, 32, 105, 115, 95, 111, 112, 97, 99, 105, 116, 121, 61, 123, 64, 35,
  61, 61, 50, 125, 10, 45, 108, 91, 93, 32, 45, 98, 111, 120, 51, 100,
  32, 49, 44, 49, 44, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  36, 119, 45, 49, 125, 32, 45, 45, 43, 51, 100, 91, 45, 49, 93, 32,
  49, 44, 48, 44, 48, 32, 45, 100, 111, 110, 101, 32, 45, 43, 51, 100,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 104, 45, 49, 125, 32,
  45, 45, 43, 51, 100, 91, 45, 49, 93, 32, 48, 44, 49, 44, 48, 32,
  45, 100, 111, 110, 101, 32, 45, 43, 51, 100, 10, 45, 101, 110, 100, 108,
  10, 45, 115, 51, 100, 91, 45, 49, 93, 10, 45, 45, 110, 111, 114, 109,
  91, 48, 93, 32, 45, 98, 91, 45, 49, 93, 32, 36, 50, 10, 45, 121,
  91, 45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 36, 49,
  10, 45, 114, 91, 45, 53, 93, 32, 50, 52, 44, 64, 123, 45, 53, 44,
  114, 111, 117, 110, 100, 40, 119, 42, 104, 47, 50, 52, 41, 125, 44, 49,
  44, 49, 44, 45, 49, 10, 45, 105, 102, 32, 123, 36, 49, 60, 48, 125,
  32, 45, 106, 91, 45, 53, 93, 32, 91, 45, 49, 93, 44, 50, 32, 45,
  106, 91, 45, 53, 93, 32, 91, 45, 49, 93, 44, 53, 32, 45, 106, 91,
  45, 53, 93, 32, 91, 45, 49, 93, 44, 56, 32, 45, 106, 91, 45, 53,
  93, 32, 91, 45, 49, 93, 44, 49, 49, 10, 45, 101, 108, 115, 101, 32,
  45, 106, 91, 45, 53, 93, 32, 91, 45, 49, 93, 44, 49, 52, 32, 45,
  106, 91, 45, 53, 93, 32, 91, 45, 49, 93, 44, 49, 55, 32, 45, 106,
  91, 45, 53, 93, 32, 91, 45, 49, 93, 44, 50, 48, 32, 45, 106, 91,
  45, 53, 93, 32, 91, 45, 49, 93, 44, 50, 51, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 121, 91, 45, 52,
  93, 10, 45, 114, 109, 91, 45, 50, 93, 32, 45, 114, 91, 48, 93, 32,
  64, 123, 48, 44, 119, 42, 104, 125, 44, 49, 44, 49, 44, 49, 48, 48,
  37, 44, 45, 49, 32, 45, 112, 101, 114, 109, 117, 116, 101, 91, 48, 93,
  32, 99, 120, 121, 122, 32, 45, 114, 91, 48, 93, 32, 54, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 48, 44, 50, 32, 45, 121,
  91, 48, 93, 32, 45, 109, 118, 91, 48, 93, 32, 45, 49, 10, 45, 105,
  102, 32, 36, 105, 115, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 109, 118, 91, 48, 93, 32, 64, 35, 32,
  45, 47, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 121, 91, 45, 49,
  93, 32, 45, 114, 91, 45, 49, 93, 32, 54, 44, 49, 48, 48, 37, 44,
  49, 44, 49, 32, 45, 121, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 97, 32, 121, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 105, 109, 97, 103, 101, 99, 117, 98,
  101, 51, 100, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 71,
  101, 110, 101, 114, 97, 116, 101, 32, 51, 100, 32, 109, 97, 112, 112, 101,
  100, 32, 99, 117, 98, 101, 115, 32, 102, 114, 111, 109, 32, 105, 109, 97,
  103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 115, 108, 105,
  99, 101, 115, 32, 53, 48, 37, 32, 45, 116, 111, 95, 114, 103, 98, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 119, 49, 61, 123,
  119, 45, 49, 125, 32, 104, 49, 61, 123, 104, 45, 49, 125, 10, 45, 105,
  91, 45, 50, 93, 32, 40, 54, 55, 46, 53, 59, 55, 51, 46, 53, 59,
  49, 48, 57, 46, 53, 59, 49, 48, 51, 46, 53, 59, 53, 49, 46, 53,
  59, 49, 48, 48, 46, 53, 59, 92, 10, 56, 59, 54, 59, 92, 10, 45,
  48, 46, 53, 59, 45, 48, 46, 53, 59, 45, 48, 46, 53, 59, 92, 10,
  48, 46, 53, 59, 45, 48, 46, 53, 59, 45, 48, 46, 53, 59, 92, 10,
  48, 46, 53, 59, 48, 46, 53, 59, 45, 48, 46, 53, 59, 92, 10, 45,
  48, 46, 53, 59, 48, 46, 53, 59, 45, 48, 46, 53, 59, 92, 10, 45,
  48, 46, 53, 59, 45, 48, 46, 53, 59, 48, 46, 53, 59, 92, 10, 48,
  46, 53, 59, 45, 48, 46, 53, 59, 48, 46, 53, 59, 92, 10, 48, 46,
  53, 59, 48, 46, 53, 59, 48, 46, 53, 59, 92, 10, 45, 48, 46, 53,
  59, 48, 46, 53, 59, 48, 46, 53, 59, 92, 10, 49, 50, 59, 48, 59,
  51, 59, 50, 59, 49, 59, 48, 59, 48, 59, 48, 59, 36, 104, 49, 59,
  36, 119, 49, 59, 36, 104, 49, 59, 36, 119, 49, 59, 48, 59, 92, 10,
  49, 50, 59, 49, 59, 50, 59, 54, 59, 53, 59, 48, 59, 48, 59, 48,
  59, 36, 104, 49, 59, 36, 119, 49, 59, 36, 104, 49, 59, 36, 119, 49,
  59, 48, 59, 92, 10, 49, 50, 59, 53, 59, 54, 59, 55, 59, 52, 59,
  48, 59, 48, 59, 48, 59, 36, 104, 49, 59, 36, 119, 49, 59, 36, 104,
  49, 59, 36, 119, 49, 59, 48, 59, 92, 10, 49, 50, 59, 52, 59, 55,
  59, 51, 59, 48, 59, 48, 59, 48, 59, 48, 59, 36, 104, 49, 59, 36,
  119, 49, 59, 36, 104, 49, 59, 36, 119, 49, 59, 48, 59, 92, 10, 49,
  50, 59, 52, 59, 48, 59, 49, 59, 53, 59, 48, 59, 48, 59, 48, 59,
  36, 104, 49, 59, 36, 119, 49, 59, 36, 104, 49, 59, 36, 119, 49, 59,
  48, 59, 92, 10, 49, 50, 59, 51, 59, 55, 59, 54, 59, 50, 59, 48,
  59, 48, 59, 48, 59, 36, 104, 49, 59, 36, 119, 49, 59, 36, 104, 49,
  59, 36, 119, 49, 59, 48, 59, 92, 10, 45, 49, 50, 56, 59, 123, 119,
  125, 59, 123, 104, 125, 59, 123, 115, 125, 41, 10, 45, 121, 91, 45, 49,
  93, 10, 40, 45, 49, 50, 56, 59, 48, 59, 48, 59, 48, 59, 45, 49,
  50, 56, 59, 48, 59, 48, 59, 48, 59, 45, 49, 50, 56, 59, 48, 59,
  48, 59, 48, 59, 45, 49, 50, 56, 59, 48, 59, 48, 59, 48, 59, 45,
  49, 50, 56, 59, 48, 59, 48, 59, 48, 59, 49, 59, 49, 59, 49, 59,
  49, 59, 49, 59, 49, 41, 10, 45, 97, 32, 121, 10, 45, 110, 109, 32,
  36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 105, 109, 97, 103, 101, 112, 108, 97, 110,
  101, 51, 100, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 71,
  101, 110, 101, 114, 97, 116, 101, 32, 51, 100, 32, 109, 97, 112, 112, 101,
  100, 32, 112, 108, 97, 110, 101, 115, 32, 102, 114, 111, 109, 32, 105, 109,
  97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 115, 108,
  105, 99, 101, 115, 32, 53, 48, 37, 32, 45, 116, 111, 95, 114, 103, 98,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 119, 49, 61,
  123, 119, 45, 49, 125, 32, 104, 49, 61, 123, 104, 45, 49, 125, 10, 45,
  105, 91, 45, 50, 93, 32, 40, 54, 55, 46, 53, 59, 55, 51, 46, 53,
  59, 49, 48, 57, 46, 53, 59, 49, 48, 51, 46, 53, 59, 53, 49, 46,
  53, 59, 49, 48, 48, 46, 53, 59, 92, 10, 52, 59, 49, 59, 92, 10,
  48, 59, 48, 59, 48, 59, 92, 10, 123, 119, 125, 59, 48, 59, 48, 59,
  92, 10, 123, 119, 125, 59, 123, 104, 125, 59, 48, 59, 92, 10, 123, 48,
  125, 59, 123, 104, 125, 59, 48, 59, 92, 10, 49, 50, 59, 48, 59, 51,
  59, 50, 59, 49, 59, 48, 59, 48, 59, 48, 59, 36, 104, 49, 59, 36,
  119, 49, 59, 36, 104, 49, 59, 36, 119, 49, 59, 48, 59, 92, 10, 45,
  49, 50, 56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 123, 115, 125, 41,
  10, 45, 121, 91, 45, 49, 93, 10, 40, 49, 41, 10, 45, 97, 32, 121,
  10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 105, 109, 97, 103,
  101, 112, 121, 114, 97, 109, 105, 100, 51, 100, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 71, 101, 110, 101, 114, 97, 116, 101, 32, 51,
  100, 32, 109, 97, 112, 112, 101, 100, 32, 112, 121, 114, 97, 109, 105, 100,
  115, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110,
  125, 10, 119, 49, 61, 123, 119, 45, 49, 125, 32, 104, 49, 61, 123, 104,
  45, 49, 125, 32, 119, 50, 61, 123, 119, 47, 50, 125, 10, 45, 105, 91,
  45, 50, 93, 32, 40, 54, 55, 46, 53, 59, 55, 51, 46, 53, 59, 49,
  48, 57, 46, 53, 59, 49, 48, 51, 46, 53, 59, 53, 49, 46, 53, 59,
  49, 48, 48, 46, 53, 59, 92, 10, 53, 59, 53, 59, 92, 10, 45, 48,
  46, 53, 59, 45, 48, 46, 53, 59, 45, 48, 46, 53, 59, 92, 10, 48,
  46, 53, 59, 45, 48, 46, 53, 59, 45, 48, 46, 53, 59, 92, 10, 48,
  46, 53, 59, 48, 46, 53, 59, 45, 48, 46, 53, 59, 92, 10, 45, 48,
  46, 53, 59, 48, 46, 53, 59, 45, 48, 46, 53, 59, 92, 10, 48, 59,
  48, 59, 48, 46, 53, 59, 92, 10, 49, 50, 59, 48, 59, 51, 59, 50,
  59, 49, 59, 48, 59, 48, 59, 48, 59, 36, 104, 49, 59, 36, 119, 49,
  59, 36, 104, 49, 59, 36, 119, 49, 59, 48, 59, 92, 10, 57, 59, 48,
  59, 52, 59, 51, 59, 48, 59, 36, 104, 49, 59, 36, 119, 50, 59, 48,
  59, 36, 119, 49, 59, 36, 104, 49, 59, 92, 10, 57, 59, 49, 59, 52,
  59, 48, 59, 48, 59, 36, 104, 49, 59, 36, 119, 50, 59, 48, 59, 36,
  119, 49, 59, 36, 104, 49, 59, 92, 10, 57, 59, 50, 59, 52, 59, 49,
  59, 48, 59, 36, 104, 49, 59, 36, 119, 50, 59, 48, 59, 36, 119, 49,
  59, 36, 104, 49, 59, 92, 10, 57, 59, 51, 59, 52, 59, 50, 59, 48,
  59, 36, 104, 49, 59, 36, 119, 50, 59, 48, 59, 36, 119, 49, 59, 36,
  104, 49, 59, 92, 10, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104,
  125, 59, 123, 115, 125, 41, 10, 45, 121, 91, 45, 49, 93, 10, 40, 45,
  49, 50, 56, 59, 48, 59, 48, 59, 48, 59, 45, 49, 50, 56, 59, 48,
  59, 48, 59, 48, 59, 45, 49, 50, 56, 59, 48, 59, 48, 59, 48, 59,
  45, 49, 50, 56, 59, 48, 59, 48, 59, 48, 59, 49, 59, 49, 59, 49,
  59, 49, 59, 49, 41, 10, 45, 97, 32, 121, 10, 45, 110, 109, 32, 36,
  110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 105, 109, 97, 103, 101, 114, 117, 98, 105, 107,
  51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49,
  61, 51, 125, 62, 61, 49, 32, 38, 38, 32, 36, 123, 50, 61, 53, 125,
  62, 61, 48, 32, 38, 38, 32, 36, 50, 60, 61, 49, 48, 48, 32, 38,
  38, 32, 36, 123, 51, 61, 53, 125, 62, 61, 48, 32, 38, 38, 32, 36,
  51, 60, 61, 49, 48, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 71, 101, 110, 101, 114, 97, 116, 101, 32, 51, 100, 32, 109, 97, 112,
  112, 101, 100, 32, 114, 117, 98, 105, 107, 39, 115, 32, 99, 117, 98, 101,
  115, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 32, 119,
  105, 116, 104, 32, 36, 49, 32, 120, 121, 45, 116, 105, 108, 101, 115, 44,
  32, 120, 121, 45, 115, 104, 105, 102, 116, 32, 36, 50, 32, 97, 110, 100,
  32, 122, 45, 115, 104, 105, 102, 116, 32, 36, 51, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 40,
  123, 39, 67, 73, 109, 103, 51, 100, 39, 125, 41, 32, 45, 43, 91, 45,
  49, 93, 32, 48, 46, 53, 10, 40, 56, 44, 53, 41, 10, 40, 48, 44,
  48, 44, 48, 59, 92, 10, 49, 48, 48, 44, 48, 44, 48, 59, 92, 10,
  49, 48, 48, 44, 49, 48, 48, 44, 48, 59, 92, 10, 48, 44, 49, 48,
  48, 44, 48, 59, 92, 10, 36, 50, 44, 36, 50, 44, 123, 45, 36, 51,
  125, 59, 92, 10, 123, 49, 48, 48, 45, 36, 50, 125, 44, 36, 50, 44,
  123, 45, 36, 51, 125, 59, 92, 10, 123, 49, 48, 48, 45, 36, 50, 125,
  44, 123, 49, 48, 48, 45, 36, 50, 125, 44, 123, 45, 36, 51, 125, 59,
  92, 10, 36, 50, 44, 123, 49, 48, 48, 45, 36, 50, 125, 44, 123, 45,
  36, 51, 125, 41, 10, 40, 52, 44, 52, 44, 55, 44, 54, 44, 53, 59,
  92, 10, 52, 44, 48, 44, 52, 44, 53, 44, 49, 59, 92, 10, 52, 44,
  51, 44, 50, 44, 54, 44, 55, 59, 92, 10, 52, 44, 48, 44, 51, 44,
  55, 44, 52, 59, 92, 10, 52, 44, 49, 44, 53, 44, 54, 44, 50, 41,
  10, 51, 44, 53, 44, 49, 44, 49, 44, 50, 48, 48, 10, 49, 44, 53,
  44, 49, 44, 49, 44, 49, 10, 45, 121, 91, 45, 54, 45, 45, 49, 93,
  32, 45, 97, 91, 45, 54, 45, 45, 49, 93, 32, 121, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 36, 49, 45, 49, 125, 32, 45, 45, 43, 51,
  100, 91, 45, 49, 93, 32, 49, 48, 48, 32, 45, 100, 111, 110, 101, 32,
  45, 43, 51, 100, 91, 45, 36, 49, 45, 45, 49, 93, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 36, 49, 45, 49, 125, 32, 45, 45, 43, 51,
  100, 91, 45, 49, 93, 32, 48, 44, 49, 48, 48, 32, 45, 100, 111, 110,
  101, 32, 45, 43, 51, 100, 91, 45, 36, 49, 45, 45, 49, 93, 10, 45,
  116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 114, 109,
  91, 45, 50, 93, 10, 45, 47, 51, 100, 91, 45, 49, 93, 32, 36, 49,
  32, 45, 45, 51, 100, 91, 45, 49, 93, 32, 53, 48, 44, 53, 48, 44,
  53, 48, 10, 45, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 49,
  44, 48, 44, 45, 57, 48, 32, 45, 45, 114, 51, 100, 91, 45, 49, 93,
  32, 48, 44, 49, 44, 48, 44, 45, 57, 48, 32, 45, 45, 114, 51, 100,
  91, 45, 49, 93, 32, 48, 44, 49, 44, 48, 44, 45, 57, 48, 10, 45,
  45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 48, 44, 49, 44, 45,
  57, 48, 32, 45, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 48,
  44, 49, 44, 49, 56, 48, 10, 45, 43, 51, 100, 10, 45, 110, 109, 32,
  36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 105, 109, 97, 103, 101, 115, 112, 104, 101,
  114, 101, 51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36,
  123, 49, 61, 51, 50, 125, 62, 61, 51, 32, 38, 38, 32, 36, 123, 50,
  61, 49, 54, 125, 62, 61, 51, 34, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 71, 101, 110, 101, 114, 97, 116, 101, 32, 51, 100, 32, 109, 97,
  112, 112, 101, 100, 32, 115, 112, 104, 101, 114, 101, 32, 102, 114, 111, 109,
  32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 114,
  101, 115, 111, 108, 117, 116, 105, 111, 110, 115, 32, 40, 36, 49, 44, 36,
  50, 41, 46, 34, 10, 45, 118, 32, 45, 32, 45, 116, 111, 95, 114, 103,
  98, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 116, 119,
  61, 123, 119, 45, 49, 125, 32, 116, 104, 61, 123, 104, 45, 49, 125, 10,
  110, 98, 118, 61, 123, 50, 43, 36, 49, 42, 40, 36, 50, 45, 50, 41,
  125, 10, 110, 98, 112, 61, 123, 36, 49, 42, 40, 36, 50, 45, 49, 41,
  125, 10, 40, 54, 55, 46, 53, 59, 55, 51, 46, 53, 59, 49, 48, 57,
  46, 53, 59, 49, 48, 51, 46, 53, 59, 53, 49, 46, 53, 59, 49, 48,
  48, 46, 53, 59, 92, 10, 36, 110, 98, 118, 59, 36, 110, 98, 112, 41,
  10, 40, 48, 59, 48, 59, 49, 41, 32, 40, 48, 59, 48, 59, 45, 49,
  41, 32, 40, 48, 44, 123, 50, 42, 112, 105, 125, 59, 48, 44, 123, 50,
  42, 112, 105, 125, 94, 48, 44, 48, 59, 123, 112, 105, 125, 44, 123, 112,
  105, 125, 41, 10, 45, 114, 91, 45, 49, 93, 32, 123, 36, 49, 43, 49,
  125, 44, 36, 50, 44, 49, 44, 50, 44, 51, 32, 45, 122, 91, 45, 49,
  93, 32, 48, 44, 49, 44, 123, 119, 45, 50, 125, 44, 123, 104, 45, 50,
  125, 32, 45, 115, 91, 45, 49, 93, 32, 99, 10, 45, 45, 115, 105, 110,
  91, 45, 49, 93, 32, 45, 45, 115, 105, 110, 91, 45, 51, 93, 32, 45,
  42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 45, 99, 111, 115, 91, 45,
  50, 93, 32, 45, 115, 105, 110, 91, 45, 51, 93, 32, 45, 99, 111, 115,
  91, 45, 52, 93, 32, 45, 42, 91, 45, 52, 44, 45, 51, 93, 10, 45,
  97, 91, 45, 51, 45, 45, 49, 93, 32, 99, 32, 45, 112, 101, 114, 109,
  117, 116, 101, 91, 45, 49, 93, 32, 99, 120, 121, 122, 32, 45, 121, 91,
  45, 49, 93, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 121, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 10, 116, 120, 48, 61, 123,
  36, 62, 42, 36, 116, 119, 47, 36, 49, 125, 32, 116, 120, 49, 61, 123,
  40, 36, 62, 43, 49, 41, 42, 36, 116, 119, 47, 36, 49, 125, 32, 116,
  121, 49, 61, 123, 36, 116, 104, 47, 40, 36, 50, 45, 49, 41, 125, 10,
  40, 57, 59, 48, 59, 123, 50, 43, 36, 62, 125, 59, 123, 50, 43, 40,
  36, 62, 43, 49, 41, 37, 36, 49, 125, 59, 123, 36, 116, 119, 47, 50,
  125, 59, 48, 59, 36, 116, 120, 48, 59, 36, 116, 121, 49, 59, 36, 116,
  120, 49, 59, 36, 116, 121, 49, 41, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 123, 36, 50, 45, 51, 125, 10, 116, 121, 48, 61, 36, 116, 121, 49,
  32, 116, 121, 49, 61, 123, 40, 36, 62, 43, 50, 41, 42, 36, 116, 104,
  47, 40, 36, 50, 45, 49, 41, 125, 32, 105, 48, 61, 123, 50, 43, 36,
  62, 42, 36, 49, 43, 64, 123, 62, 44, 45, 50, 125, 125, 32, 105, 49,
  61, 123, 50, 43, 36, 62, 42, 36, 49, 43, 40, 64, 123, 62, 44, 45,
  50, 125, 43, 49, 41, 37, 36, 49, 125, 10, 40, 49, 50, 59, 36, 105,
  48, 59, 123, 36, 105, 48, 43, 36, 49, 125, 59, 123, 36, 105, 49, 43,
  36, 49, 125, 59, 36, 105, 49, 59, 36, 116, 120, 48, 59, 36, 116, 121,
  48, 59, 36, 116, 120, 48, 59, 36, 116, 121, 49, 59, 36, 116, 120, 49,
  59, 36, 116, 121, 49, 59, 36, 116, 120, 49, 59, 36, 116, 121, 48, 41,
  10, 45, 100, 111, 110, 101, 10, 40, 57, 59, 49, 59, 123, 50, 43, 36,
  49, 42, 40, 36, 50, 45, 51, 41, 43, 40, 36, 62, 43, 49, 41, 37,
  36, 49, 125, 59, 123, 50, 43, 36, 49, 42, 40, 36, 50, 45, 51, 41,
  43, 36, 62, 125, 59, 123, 36, 116, 119, 47, 50, 125, 59, 36, 116, 104,
  59, 36, 116, 120, 49, 59, 36, 116, 121, 49, 59, 36, 116, 120, 48, 59,
  36, 116, 121, 49, 41, 10, 45, 100, 111, 110, 101, 10, 45, 97, 91, 45,
  36, 110, 98, 112, 45, 45, 49, 93, 32, 121, 10, 45, 109, 118, 91, 45,
  52, 93, 32, 64, 35, 32, 45, 105, 91, 45, 50, 93, 32, 40, 45, 49,
  50, 56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 51, 41, 32, 45, 121,
  91, 45, 49, 93, 32, 49, 44, 123, 52, 42, 40, 36, 110, 98, 112, 45,
  49, 41, 125, 44, 49, 44, 49, 44, 45, 49, 50, 56, 44, 48, 44, 48,
  44, 48, 32, 49, 44, 36, 110, 98, 112, 44, 49, 44, 49, 44, 49, 32,
  45, 97, 32, 121, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  108, 97, 98, 101, 108, 95, 112, 111, 105, 110, 116, 115, 51, 100, 32, 58,
  32, 45, 99, 104, 101, 99, 107, 32, 36, 123, 49, 61, 49, 51, 125, 62,
  48, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 48, 46, 56, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 76, 97, 98, 101, 108, 32,
  118, 101, 114, 116, 105, 99, 101, 115, 32, 111, 102, 32, 51, 100, 32, 111,
  98, 106, 101, 99, 116, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 45, 112, 51, 100, 91,
  36, 62, 93, 32, 48, 32, 45, 108, 91, 45, 49, 93, 32, 45, 115, 51,
  100, 32, 45, 114, 109, 91, 45, 51, 45, 45, 49, 93, 10, 110, 98, 112,
  61, 64, 123, 45, 50, 44, 48, 125, 32, 45, 61, 91, 45, 50, 93, 32,
  36, 110, 98, 112, 44, 48, 44, 49, 10, 40, 49, 44, 48, 59, 49, 44,
  123, 36, 110, 98, 112, 45, 49, 125, 41, 32, 45, 114, 91, 45, 49, 93,
  32, 50, 44, 36, 110, 98, 112, 44, 49, 44, 49, 44, 51, 32, 45, 114,
  91, 45, 49, 93, 32, 49, 44, 123, 50, 42, 104, 125, 44, 49, 44, 49,
  44, 45, 49, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 110, 98, 112,
  10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 36, 62, 44, 48, 44, 48,
  44, 36, 49, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53,
  53, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32,
  48, 10, 45, 105, 91, 45, 50, 93, 32, 40, 45, 49, 50, 56, 59, 123,
  119, 125, 59, 123, 104, 125, 59, 51, 41, 32, 45, 121, 91, 45, 49, 93,
  10, 45, 100, 111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36,
  110, 98, 112, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 36, 62, 44,
  48, 44, 48, 44, 36, 49, 44, 49, 44, 36, 50, 32, 45, 97, 117, 116,
  111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 48, 10, 45, 105, 91, 45,
  50, 93, 32, 40, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104, 125,
  59, 49, 41, 32, 45, 121, 91, 45, 49, 93, 10, 45, 100, 111, 110, 101,
  10, 45, 97, 32, 121, 10, 45, 101, 110, 100, 108, 10, 45, 43, 51, 100,
  91, 36, 62, 44, 45, 49, 93, 10, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 108, 97, 116, 104, 101, 51, 100, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 36, 123, 49, 61, 49, 50, 56, 125, 62, 48, 32,
  38, 38, 32, 36, 123, 50, 61, 48, 46, 53, 37, 125, 62, 61, 48, 32,
  38, 38, 32, 36, 123, 51, 61, 51, 54, 49, 125, 62, 61, 48, 34, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 71, 101, 110, 101, 114, 97, 116,
  101, 32, 108, 97, 116, 104, 101, 100, 32, 51, 100, 32, 111, 98, 106, 101,
  99, 116, 32, 102, 114, 111, 109, 32, 88, 89, 45, 112, 114, 111, 102, 105,
  108, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 114, 101, 115, 111, 108,
  117, 116, 105, 111, 110, 32, 36, 49, 44, 32, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 36, 50, 32, 97, 110, 100, 32, 109, 97, 120, 105,
  109, 117, 109, 32, 97, 110, 103, 108, 101, 32, 36, 51, 32, 100, 101, 103,
  46, 34, 10, 45, 118, 32, 45, 32, 116, 109, 97, 120, 61, 123, 40, 36,
  51, 45, 49, 56, 48, 41, 42, 112, 105, 47, 49, 56, 48, 125, 32, 45,
  110, 111, 114, 109, 32, 45, 110, 32, 48, 44, 49, 32, 45, 97, 117, 116,
  111, 99, 114, 111, 112, 32, 48, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 114, 61, 123, 109, 97,
  120, 40, 49, 44, 119, 50, 61, 50, 42, 119, 59, 105, 102, 40, 119, 50,
  62, 104, 44, 109, 105, 110, 40, 36, 49, 44, 119, 50, 41, 44, 109, 105,
  110, 40, 36, 49, 44, 104, 41, 42, 119, 50, 47, 104, 41, 41, 125, 10,
  104, 114, 61, 123, 109, 97, 120, 40, 49, 44, 119, 50, 61, 50, 42, 119,
  59, 105, 102, 40, 119, 50, 62, 104, 44, 109, 105, 110, 40, 36, 49, 44,
  119, 50, 41, 42, 104, 47, 119, 50, 44, 109, 105, 110, 40, 36, 49, 44,
  104, 41, 41, 41, 125, 10, 114, 109, 97, 120, 61, 123, 115, 113, 114, 116,
  40, 40, 36, 119, 114, 41, 94, 50, 43, 40, 36, 104, 114, 41, 94, 50,
  41, 47, 50, 125, 10, 36, 119, 114, 44, 49, 44, 36, 119, 114, 44, 49,
  44, 34, 120, 99, 61, 120, 45, 119, 47, 50, 59, 32, 122, 99, 61, 122,
  45, 100, 47, 50, 59, 32, 116, 61, 97, 116, 97, 110, 50, 40, 122, 99,
  44, 120, 99, 41, 59, 32, 105, 102, 40, 116, 62, 34, 36, 116, 109, 97,
  120, 34, 44, 34, 36, 114, 109, 97, 120, 34, 44, 115, 113, 114, 116, 40,
  120, 99, 42, 120, 99, 43, 122, 99, 42, 122, 99, 41, 41, 34, 10, 45,
  42, 91, 45, 49, 93, 32, 123, 50, 42, 40, 64, 123, 45, 50, 44, 119,
  125, 45, 49, 41, 47, 40, 119, 45, 49, 41, 125, 32, 45, 114, 91, 45,
  49, 93, 32, 36, 119, 114, 44, 36, 104, 114, 44, 36, 119, 114, 10, 40,
  48, 59, 123, 64, 123, 45, 50, 44, 104, 125, 45, 49, 125, 41, 32, 45,
  114, 91, 45, 49, 93, 32, 36, 119, 114, 44, 36, 104, 114, 44, 36, 119,
  114, 44, 49, 44, 51, 32, 45, 97, 91, 45, 50, 45, 45, 49, 93, 32,
  99, 10, 45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  44, 48, 44, 49, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  101, 120, 112, 97, 110, 100, 95, 120, 121, 122, 32, 49, 48, 44, 48, 32,
  45, 98, 32, 36, 50, 32, 45, 105, 115, 111, 115, 117, 114, 102, 97, 99,
  101, 51, 100, 32, 53, 48, 37, 32, 45, 114, 118, 51, 100, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 108,
  105, 110, 101, 51, 100, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 73, 110, 112, 117, 116, 32, 51, 100, 32, 108, 105, 110, 101, 32, 40,
  36, 123, 49, 45, 51, 125, 41, 45, 40, 36, 123, 52, 45, 54, 125, 41,
  46, 34, 10, 45, 118, 32, 45, 32, 49, 44, 50, 49, 44, 49, 44, 49,
  44, 54, 55, 46, 53, 44, 55, 51, 46, 53, 44, 49, 48, 57, 46, 53,
  44, 49, 48, 51, 46, 53, 44, 53, 49, 46, 53, 44, 49, 48, 48, 46,
  53, 44, 50, 44, 49, 44, 36, 123, 49, 45, 54, 125, 44, 50, 44, 48,
  44, 49, 44, 50, 48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44, 49,
  32, 45, 110, 109, 91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 108, 105,
  110, 101, 93, 32, 45, 118, 32, 43, 10, 108, 105, 115, 115, 97, 106, 111,
  117, 115, 51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 123,
  49, 61, 49, 48, 50, 52, 125, 62, 49, 32, 45, 115, 107, 105, 112, 32,
  36, 123, 50, 61, 50, 125, 44, 36, 123, 51, 61, 48, 125, 44, 36, 123,
  52, 61, 49, 125, 44, 36, 123, 53, 61, 48, 125, 44, 36, 123, 54, 61,
  48, 125, 44, 36, 123, 55, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 73, 110, 112, 117, 116, 32, 51, 100, 32, 108, 105, 115, 115,
  97, 106, 111, 117, 115, 32, 99, 117, 114, 118, 101, 44, 32, 119, 105, 116,
  104, 32, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 32, 36, 49, 44,
  32, 40, 97, 44, 65, 41, 61, 40, 36, 50, 44, 36, 51, 41, 44, 32,
  40, 98, 44, 66, 41, 61, 40, 36, 52, 44, 36, 53, 41, 32, 97, 110,
  100, 32, 40, 99, 44, 67, 41, 61, 40, 36, 54, 44, 36, 55, 41, 46,
  34, 10, 45, 118, 32, 45, 10, 114, 101, 115, 61, 123, 114, 111, 117, 110,
  100, 40, 36, 49, 41, 125, 10, 40, 54, 55, 46, 53, 59, 55, 51, 46,
  53, 59, 49, 48, 57, 46, 53, 59, 49, 48, 51, 46, 53, 59, 53, 49,
  46, 53, 59, 49, 48, 48, 46, 53, 59, 36, 114, 101, 115, 59, 123, 36,
  114, 101, 115, 45, 49, 125, 41, 10, 40, 48, 44, 123, 50, 42, 112, 105,
  125, 41, 32, 45, 114, 91, 45, 49, 93, 32, 36, 114, 101, 115, 44, 49,
  44, 49, 44, 49, 44, 51, 32, 91, 45, 49, 93, 120, 50, 10, 45, 42,
  91, 45, 51, 93, 32, 36, 50, 32, 45, 43, 91, 45, 51, 93, 32, 123,
  36, 51, 42, 50, 42, 112, 105, 125, 32, 45, 42, 91, 45, 50, 93, 32,
  36, 52, 32, 45, 43, 91, 45, 50, 93, 32, 123, 36, 53, 42, 50, 42,
  112, 105, 125, 32, 45, 42, 91, 45, 49, 93, 32, 36, 54, 32, 45, 43,
  91, 45, 49, 93, 32, 123, 36, 55, 42, 50, 42, 112, 105, 125, 10, 45,
  97, 91, 45, 51, 45, 45, 49, 93, 32, 121, 32, 45, 115, 105, 110, 91,
  45, 49, 93, 32, 45, 116, 114, 97, 110, 115, 112, 111, 115, 101, 91, 45,
  49, 93, 32, 45, 114, 91, 45, 49, 93, 32, 49, 44, 123, 119, 42, 104,
  125, 44, 49, 44, 49, 44, 45, 49, 10, 49, 44, 123, 36, 114, 101, 115,
  45, 49, 125, 44, 49, 44, 49, 44, 50, 32, 40, 48, 59, 123, 36, 114,
  101, 115, 45, 50, 125, 41, 32, 45, 114, 91, 45, 49, 93, 32, 49, 44,
  123, 36, 114, 101, 115, 45, 49, 125, 44, 49, 44, 49, 44, 51, 32, 45,
  45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 97, 91, 45, 51, 45, 45,
  49, 93, 32, 120, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32,
  49, 32, 45, 114, 91, 45, 49, 93, 32, 49, 44, 123, 119, 42, 104, 125,
  44, 49, 44, 49, 44, 45, 49, 10, 49, 44, 123, 51, 42, 40, 36, 114,
  101, 115, 45, 49, 41, 125, 44, 49, 44, 49, 44, 50, 48, 48, 32, 49,
  44, 123, 36, 114, 101, 115, 45, 49, 125, 44, 49, 44, 49, 44, 49, 32,
  45, 97, 91, 45, 53, 45, 45, 49, 93, 32, 121, 32, 45, 110, 109, 91,
  45, 49, 93, 32, 91, 51, 100, 92, 32, 108, 105, 115, 115, 97, 106, 111,
  117, 93, 10, 45, 118, 32, 43, 10, 110, 51, 100, 32, 58, 10, 45, 95,
  110, 111, 114, 109, 97, 108, 105, 122, 101, 51, 100, 10, 110, 111, 114, 109,
  97, 108, 105, 122, 101, 51, 100, 32, 58, 10, 45, 95, 36, 48, 10, 95,
  110, 111, 114, 109, 97, 108, 105, 122, 101, 51, 100, 32, 58, 10, 45, 101,
  91, 48, 45, 45, 51, 93, 32, 34, 78, 111, 114, 109, 97, 108, 105, 122,
  101, 32, 115, 105, 122, 101, 32, 111, 102, 32, 51, 100, 32, 111, 98, 106,
  101, 99, 116, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 99, 104,
  101, 99, 107, 51, 100, 32, 48, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 110, 61, 123, 105, 91, 54,
  93, 125, 10, 45, 105, 102, 32, 123, 36, 110, 62, 48, 125, 10, 45, 115,
  104, 32, 56, 44, 123, 55, 43, 51, 42, 36, 110, 125, 44, 48, 44, 48,
  32, 45, 114, 91, 45, 49, 93, 32, 51, 44, 123, 104, 47, 51, 125, 44,
  49, 44, 49, 44, 45, 49, 32, 45, 115, 91, 45, 49, 93, 32, 120, 10,
  45, 115, 104, 91, 45, 52, 93, 32, 56, 44, 123, 55, 43, 51, 42, 36,
  110, 125, 44, 48, 44, 48, 32, 45, 47, 91, 45, 49, 93, 32, 123, 118,
  97, 108, 61, 109, 97, 120, 40, 64, 123, 45, 51, 44, 105, 77, 125, 45,
  64, 123, 45, 51, 44, 105, 109, 125, 44, 64, 123, 45, 50, 44, 105, 77,
  125, 45, 64, 123, 45, 50, 44, 105, 109, 125, 44, 105, 77, 45, 105, 109,
  41, 59, 105, 102, 40, 118, 97, 108, 44, 118, 97, 108, 44, 49, 41, 125,
  10, 45, 114, 109, 91, 45, 52, 45, 45, 49, 93, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 110, 109, 32, 64, 123, 48, 44, 110, 125, 44, 49, 32,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 112, 97, 114, 97, 109, 101, 116, 114, 105, 99, 51, 100, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 34, 36, 123, 49, 61, 40, 50, 43, 99, 111,
  115, 40, 98, 41, 41, 42, 115, 105, 110, 40, 97, 41, 125, 34, 44, 34,
  36, 123, 50, 61, 40, 50, 43, 99, 111, 115, 40, 98, 41, 41, 42, 99,
  111, 115, 40, 97, 41, 125, 34, 44, 34, 36, 123, 51, 61, 115, 105, 110,
  40, 98, 41, 125, 34, 10, 45, 115, 107, 105, 112, 32, 36, 123, 52, 61,
  123, 45, 112, 105, 125, 125, 44, 36, 123, 53, 61, 123, 112, 105, 125, 125,
  44, 36, 123, 54, 61, 123, 45, 112, 105, 125, 125, 44, 36, 123, 55, 61,
  123, 112, 105, 125, 125, 10, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123,
  56, 61, 53, 49, 50, 125, 62, 48, 32, 38, 38, 32, 36, 123, 57, 61,
  36, 56, 125, 62, 48, 32, 38, 38, 32, 36, 123, 49, 48, 61, 54, 52,
  125, 62, 48, 32, 38, 38, 32, 36, 123, 49, 49, 61, 36, 49, 48, 125,
  62, 48, 32, 38, 38, 32, 36, 123, 49, 50, 61, 36, 49, 49, 125, 62,
  48, 32, 38, 38, 32, 92, 10, 36, 123, 49, 51, 61, 50, 37, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 123, 49, 52, 61, 49, 48, 37, 125, 62,
  61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112,
  117, 116, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116, 32, 102, 114, 111,
  109, 32, 112, 97, 114, 97, 109, 101, 116, 114, 105, 99, 32, 115, 117, 114,
  102, 97, 99, 101, 32, 40, 36, 49, 44, 36, 50, 44, 36, 51, 41, 46,
  34, 10, 45, 118, 32, 45, 10, 40, 36, 52, 44, 36, 53, 59, 36, 52,
  44, 36, 53, 94, 36, 54, 44, 36, 54, 59, 36, 55, 44, 36, 55, 41,
  32, 45, 114, 91, 45, 49, 93, 32, 36, 56, 44, 36, 57, 44, 49, 44,
  50, 44, 51, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49,
  93, 32, 48, 44, 50, 10, 45, 102, 91, 45, 49, 93, 32, 34, 97, 61,
  105, 40, 120, 44, 121, 44, 48, 44, 48, 41, 59, 98, 61, 105, 40, 120,
  44, 121, 44, 48, 44, 49, 41, 59, 105, 102, 40, 99, 61, 61, 48, 44,
  36, 49, 44, 105, 102, 40, 99, 61, 61, 49, 44, 36, 50, 44, 36, 51,
  41, 41, 34, 10, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 48, 32,
  120, 109, 105, 110, 61, 123, 105, 109, 125, 32, 120, 109, 97, 120, 61, 123,
  105, 77, 125, 32, 45, 110, 91, 45, 49, 93, 32, 49, 54, 44, 123, 36,
  49, 48, 45, 49, 55, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  115, 104, 91, 45, 49, 93, 32, 49, 44, 49, 32, 121, 109, 105, 110, 61,
  123, 105, 109, 125, 32, 121, 109, 97, 120, 61, 123, 105, 77, 125, 32, 45,
  110, 91, 45, 49, 93, 32, 49, 54, 44, 123, 36, 49, 49, 45, 49, 55,
  125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 45, 49,
  93, 32, 50, 44, 50, 32, 122, 109, 105, 110, 61, 123, 105, 109, 125, 32,
  122, 109, 97, 120, 61, 123, 105, 77, 125, 32, 45, 110, 91, 45, 49, 93,
  32, 49, 54, 44, 123, 36, 49, 50, 45, 49, 55, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 114, 91, 45, 49, 93, 32, 123, 119, 42, 104,
  125, 44, 51, 44, 49, 44, 49, 44, 45, 49, 10, 45, 112, 111, 105, 110,
  116, 99, 108, 111, 117, 100, 91, 45, 49, 93, 32, 49, 32, 45, 114, 91,
  45, 49, 93, 32, 36, 49, 48, 44, 36, 49, 49, 44, 36, 49, 50, 44,
  49, 44, 48, 32, 45, 98, 91, 45, 49, 93, 32, 36, 49, 51, 44, 48,
  10, 45, 105, 115, 111, 115, 117, 114, 102, 97, 99, 101, 51, 100, 91, 45,
  49, 93, 32, 36, 49, 52, 10, 45, 99, 51, 100, 91, 45, 49, 93, 32,
  45, 110, 51, 100, 91, 45, 49, 93, 32, 45, 42, 51, 100, 91, 45, 49,
  93, 32, 123, 36, 120, 109, 97, 120, 45, 36, 120, 109, 105, 110, 125, 44,
  123, 36, 121, 109, 97, 120, 45, 36, 121, 109, 105, 110, 125, 44, 123, 36,
  122, 109, 97, 120, 45, 36, 122, 109, 105, 110, 125, 32, 45, 110, 109, 91,
  45, 49, 93, 32, 91, 51, 100, 92, 32, 112, 97, 114, 97, 109, 101, 116,
  114, 105, 99, 93, 10, 45, 118, 32, 43, 10, 112, 99, 97, 95, 112, 97,
  116, 99, 104, 51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 55, 125, 41, 32, 38, 38,
  32, 36, 49, 62, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36,
  123, 50, 61, 49, 48, 48, 48, 125, 41, 32, 38, 38, 32, 36, 50, 62,
  48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 51, 61, 51,
  48, 48, 48, 125, 41, 32, 38, 38, 32, 36, 51, 62, 48, 34, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 52, 61, 49, 125, 44, 36, 123, 53, 61,
  48, 125, 44, 36, 123, 54, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 71, 101, 116, 32, 51, 100, 32, 112, 97, 116, 99, 104, 45,
  112, 99, 97, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 97, 116, 105,
  111, 110, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 40, 64, 35,
  62, 49, 41, 44, 115, 44, 34, 34, 125, 34, 32, 111, 102, 32, 105, 109,
  97, 103, 101, 36, 63, 44, 32, 102, 114, 111, 109, 32, 36, 50, 32, 36,
  49, 120, 36, 49, 32, 105, 110, 112, 117, 116, 32, 112, 97, 116, 99, 104,
  115, 44, 10, 119, 105, 116, 104, 32, 36, 51, 32, 111, 117, 116, 112, 117,
  116, 32, 112, 97, 116, 99, 104, 115, 44, 32, 105, 110, 112, 117, 116, 32,
  110, 111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110, 32, 34, 64,
  123, 45, 97, 114, 103, 92, 32, 49, 43, 33, 36, 52, 44, 101, 110, 97,
  98, 108, 101, 100, 44, 100, 105, 115, 97, 98, 108, 101, 100, 125, 34, 44,
  32, 111, 117, 116, 112, 117, 116, 32, 110, 111, 114, 109, 97, 108, 105, 122,
  97, 116, 105, 111, 110, 10, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49,
  43, 33, 36, 53, 44, 101, 110, 97, 98, 108, 101, 100, 44, 100, 105, 115,
  97, 98, 108, 101, 100, 125, 34, 32, 97, 110, 100, 32, 108, 97, 109, 98,
  100, 97, 95, 120, 121, 32, 36, 54, 46, 34, 10, 45, 118, 32, 45, 10,
  80, 49, 61, 123, 105, 110, 116, 40, 36, 49, 47, 50, 41, 125, 10, 80,
  50, 61, 123, 36, 49, 45, 36, 80, 49, 45, 49, 125, 10, 45, 110, 32,
  48, 44, 50, 53, 53, 32, 45, 114, 111, 117, 110, 100, 32, 49, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 115, 61, 123, 115, 125,
  10, 49, 44, 36, 50, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32,
  48, 44, 64, 123, 48, 44, 119, 45, 49, 125, 32, 45, 45, 114, 97, 110,
  100, 91, 45, 49, 93, 32, 48, 44, 64, 123, 48, 44, 104, 45, 49, 125,
  32, 45, 45, 102, 91, 45, 49, 93, 32, 48, 32, 45, 97, 91, 45, 51,
  45, 45, 49, 93, 32, 120, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49,
  93, 32, 49, 32, 45, 45, 112, 97, 116, 99, 104, 101, 115, 91, 48, 93,
  32, 36, 49, 44, 36, 49, 44, 49, 44, 64, 45, 49, 32, 45, 121, 91,
  50, 45, 45, 49, 93, 32, 45, 97, 91, 50, 45, 45, 49, 93, 32, 120,
  10, 45, 122, 91, 49, 93, 32, 48, 44, 49, 32, 45, 116, 114, 97, 110,
  115, 112, 111, 115, 101, 91, 49, 93, 32, 45, 42, 91, 49, 93, 32, 36,
  54, 32, 45, 97, 91, 49, 44, 50, 93, 32, 121, 32, 45, 115, 91, 94,
  48, 93, 32, 120, 10, 45, 45, 43, 91, 94, 48, 93, 32, 45, 47, 91,
  45, 49, 93, 32, 36, 50, 32, 45, 45, 91, 49, 45, 45, 50, 93, 32,
  91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 97, 91,
  94, 48, 93, 32, 120, 10, 45, 105, 102, 32, 36, 52, 32, 45, 108, 91,
  45, 49, 93, 32, 45, 115, 32, 121, 32, 45, 47, 32, 39, 115, 113, 114,
  116, 40, 49, 101, 45, 56, 43, 105, 118, 41, 39, 32, 45, 97, 32, 121,
  32, 45, 101, 110, 100, 108, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45,
  116, 114, 97, 110, 115, 112, 111, 115, 101, 91, 45, 49, 93, 32, 45, 42,
  42, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 105, 103, 101, 110, 91,
  45, 49, 93, 32, 45, 114, 111, 119, 115, 91, 45, 50, 93, 32, 48, 44,
  50, 32, 45, 99, 111, 108, 117, 109, 110, 115, 91, 45, 49, 93, 32, 48,
  44, 50, 32, 45, 116, 114, 97, 110, 115, 112, 111, 115, 101, 91, 45, 49,
  93, 10, 45, 105, 102, 32, 36, 53, 32, 45, 115, 113, 114, 116, 91, 45,
  50, 93, 32, 45, 47, 91, 45, 50, 93, 32, 64, 123, 45, 50, 44, 77,
  125, 32, 45, 114, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 47,
  91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 114, 109, 91, 45, 50, 93, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 36, 51, 10, 120, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 64,
  123, 48, 44, 119, 125, 41, 41, 125, 10, 121, 61, 123, 114, 111, 117, 110,
  100, 40, 63, 40, 64, 123, 48, 44, 104, 125, 41, 41, 125, 10, 40, 123,
  36, 54, 42, 36, 120, 125, 59, 123, 36, 54, 42, 36, 121, 125, 41, 10,
  45, 45, 122, 91, 48, 93, 32, 123, 36, 120, 45, 36, 80, 49, 125, 44,
  123, 36, 121, 45, 36, 80, 49, 125, 44, 123, 36, 120, 43, 36, 80, 50,
  125, 44, 123, 36, 121, 43, 36, 80, 50, 125, 44, 49, 10, 45, 121, 91,
  45, 49, 93, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 10,
  45, 100, 111, 110, 101, 10, 45, 45, 97, 91, 50, 45, 45, 49, 93, 32,
  120, 32, 45, 42, 42, 91, 49, 44, 45, 49, 93, 32, 45, 116, 114, 97,
  110, 115, 112, 111, 115, 101, 91, 49, 93, 10, 45, 114, 111, 119, 115, 91,
  50, 45, 45, 49, 93, 32, 50, 44, 49, 48, 48, 37, 10, 45, 105, 102,
  32, 123, 36, 115, 33, 61, 51, 125, 10, 45, 114, 91, 50, 45, 45, 49,
  93, 32, 36, 49, 44, 36, 49, 44, 49, 44, 123, 109, 105, 110, 40, 51,
  44, 36, 115, 41, 125, 44, 45, 49, 10, 45, 114, 91, 50, 45, 45, 49,
  93, 32, 36, 49, 44, 36, 49, 44, 49, 44, 51, 44, 123, 105, 102, 40,
  36, 115, 33, 61, 49, 44, 48, 44, 49, 41, 125, 10, 45, 121, 91, 50,
  45, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 91, 50,
  45, 45, 50, 93, 32, 40, 45, 49, 50, 56, 59, 36, 49, 59, 36, 49,
  59, 51, 41, 32, 45, 97, 91, 50, 45, 45, 49, 93, 32, 121, 10, 45,
  114, 109, 91, 48, 93, 10, 45, 105, 91, 48, 93, 32, 40, 123, 39, 67,
  73, 109, 103, 51, 100, 39, 125, 41, 10, 45, 105, 91, 49, 93, 32, 40,
  36, 51, 59, 36, 51, 41, 10, 45, 105, 91, 51, 93, 32, 50, 44, 36,
  51, 44, 49, 44, 49, 44, 105, 102, 40, 120, 61, 61, 48, 44, 49, 44,
  121, 41, 10, 49, 44, 36, 51, 44, 49, 44, 49, 44, 49, 10, 45, 121,
  32, 45, 97, 91, 45, 54, 45, 45, 49, 93, 32, 121, 10, 45, 110, 109,
  32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 112, 108, 97, 110, 101, 51, 100, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 51, 61, 50, 52,
  125, 62, 48, 32, 38, 38, 32, 36, 123, 52, 61, 50, 52, 125, 62, 48,
  34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 125, 44, 36,
  123, 50, 61, 36, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  73, 110, 112, 117, 116, 32, 51, 100, 32, 112, 108, 97, 110, 101, 44, 32,
  119, 105, 116, 104, 32, 115, 105, 122, 101, 32, 40, 36, 123, 49, 44, 50,
  125, 41, 32, 97, 110, 100, 32, 115, 117, 98, 100, 105, 118, 105, 115, 105,
  111, 110, 115, 32, 40, 36, 123, 51, 44, 52, 125, 41, 46, 34, 10, 45,
  118, 32, 45, 32, 123, 36, 51, 43, 49, 125, 44, 123, 36, 52, 43, 49,
  125, 32, 45, 101, 108, 101, 118, 97, 116, 105, 111, 110, 51, 100, 91, 45,
  49, 93, 32, 48, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 123, 36,
  49, 47, 36, 51, 125, 44, 123, 36, 50, 47, 36, 52, 125, 32, 45, 99,
  111, 108, 51, 100, 91, 45, 49, 93, 32, 50, 48, 48, 32, 45, 110, 109,
  91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 112, 108, 97, 110, 101, 93,
  32, 45, 118, 32, 43, 10, 112, 111, 105, 110, 116, 51, 100, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 51,
  100, 32, 112, 111, 105, 110, 116, 32, 40, 36, 49, 44, 36, 50, 44, 36,
  51, 41, 46, 34, 10, 45, 118, 32, 45, 32, 49, 44, 49, 55, 44, 49,
  44, 49, 44, 54, 55, 46, 53, 44, 55, 51, 46, 53, 44, 49, 48, 57,
  46, 53, 44, 49, 48, 51, 46, 53, 44, 53, 49, 46, 53, 44, 49, 48,
  48, 46, 53, 44, 49, 44, 49, 44, 36, 123, 49, 45, 51, 125, 44, 49,
  44, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44, 49,
  32, 45, 110, 109, 91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 112, 111,
  105, 110, 116, 93, 32, 45, 118, 32, 43, 10, 112, 111, 105, 110, 116, 99,
  108, 111, 117, 100, 51, 100, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101, 36,
  63, 32, 116, 111, 32, 51, 100, 32, 112, 111, 105, 110, 116, 32, 99, 108,
  111, 117, 100, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109,
  61, 64, 123, 48, 44, 110, 125, 10, 45, 115, 32, 122, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45,
  45, 110, 111, 114, 109, 32, 45, 33, 61, 91, 45, 49, 93, 32, 48, 10,
  45, 105, 91, 45, 50, 93, 32, 40, 49, 44, 123, 119, 125, 59, 49, 44,
  123, 119, 125, 94, 49, 44, 49, 59, 123, 104, 125, 44, 123, 104, 125, 41,
  32, 45, 114, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 91, 45, 49,
  93, 44, 49, 44, 50, 44, 51, 32, 45, 42, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 45, 112, 101,
  114, 109, 117, 116, 101, 91, 45, 49, 93, 32, 99, 120, 121, 122, 10, 45,
  108, 91, 45, 49, 93, 32, 45, 115, 32, 45, 44, 48, 32, 45, 97, 32,
  121, 32, 105, 115, 95, 112, 111, 105, 110, 116, 115, 61, 64, 35, 32, 45,
  101, 110, 100, 108, 10, 45, 105, 102, 32, 36, 105, 115, 95, 112, 111, 105,
  110, 116, 115, 10, 45, 45, 91, 45, 49, 93, 32, 49, 32, 45, 114, 91,
  45, 49, 93, 32, 50, 44, 123, 104, 47, 50, 125, 44, 49, 44, 49, 44,
  45, 49, 32, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 49, 93, 32,
  99, 121, 122, 120, 32, 45, 45, 119, 97, 114, 112, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 51, 93,
  10, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 50, 93, 32, 99, 121,
  122, 120, 32, 45, 105, 91, 45, 50, 93, 32, 49, 44, 123, 104, 125, 44,
  49, 44, 49, 44, 36, 62, 32, 45, 97, 91, 45, 51, 44, 45, 50, 93,
  32, 120, 10, 45, 105, 91, 45, 51, 93, 32, 40, 123, 39, 67, 73, 109,
  103, 51, 100, 39, 125, 41, 32, 45, 105, 91, 45, 51, 93, 32, 40, 123,
  104, 125, 44, 123, 104, 125, 41, 10, 45, 105, 91, 45, 50, 93, 32, 49,
  44, 123, 104, 125, 44, 49, 44, 49, 44, 49, 32, 45, 105, 91, 45, 50,
  93, 32, 49, 44, 123, 104, 125, 44, 49, 44, 49, 44, 121, 32, 45, 97,
  91, 45, 51, 44, 45, 50, 93, 32, 120, 10, 45, 112, 101, 114, 109, 117,
  116, 101, 91, 45, 49, 93, 32, 99, 121, 122, 120, 10, 45, 105, 102, 32,
  123, 119, 61, 61, 49, 125, 32, 45, 114, 91, 45, 49, 93, 32, 51, 44,
  123, 104, 125, 44, 49, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123, 119,
  62, 51, 125, 32, 45, 105, 91, 45, 50, 93, 32, 52, 44, 123, 104, 125,
  44, 49, 44, 49, 44, 45, 49, 50, 56, 44, 49, 44, 49, 44, 123, 119,
  125, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 10, 45, 101,
  108, 115, 101, 32, 45, 114, 91, 45, 49, 93, 32, 51, 44, 123, 104, 125,
  44, 49, 44, 49, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 49, 44,
  123, 104, 125, 44, 49, 44, 49, 44, 49, 10, 45, 121, 91, 45, 54, 45,
  45, 49, 93, 32, 45, 97, 91, 45, 54, 45, 45, 49, 93, 32, 121, 10,
  45, 101, 108, 115, 101, 32, 45, 114, 109, 32, 45, 101, 109, 112, 116, 121,
  51, 100, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 45, 43, 51, 100, 10, 45, 110, 109, 32, 36,
  110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 112, 114, 111, 106, 101, 99, 116, 105, 111, 110,
  115, 51, 100, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  53, 48, 37, 125, 44, 36, 123, 50, 61, 53, 48, 37, 125, 44, 36, 123,
  51, 61, 53, 48, 37, 125, 44, 36, 123, 52, 61, 49, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 71, 101, 110, 101, 114, 97, 116, 101, 32,
  51, 100, 32, 120, 121, 44, 120, 122, 44, 121, 122, 32, 112, 114, 111, 106,
  101, 99, 116, 105, 111, 110, 32, 112, 108, 97, 110, 101, 115, 32, 102, 114,
  111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 61, 123,
  119, 125, 32, 104, 61, 123, 104, 125, 32, 100, 61, 123, 100, 125, 10, 120,
  61, 123, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101,
  110, 116, 92, 32, 36, 49, 125, 44, 36, 49, 42, 119, 44, 36, 49, 41,
  125, 10, 121, 61, 123, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101,
  114, 99, 101, 110, 116, 92, 32, 36, 50, 125, 44, 36, 50, 42, 104, 44,
  36, 50, 41, 125, 10, 122, 61, 123, 105, 102, 40, 64, 123, 45, 105, 115,
  95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 51, 125, 44, 36, 51,
  42, 100, 44, 36, 51, 41, 125, 10, 45, 45, 114, 111, 119, 115, 32, 36,
  50, 44, 36, 50, 32, 45, 114, 91, 45, 49, 93, 32, 123, 119, 125, 44,
  123, 100, 125, 44, 49, 44, 49, 48, 48, 37, 44, 45, 49, 10, 45, 45,
  99, 111, 108, 117, 109, 110, 115, 91, 45, 50, 93, 32, 36, 49, 44, 36,
  49, 32, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 49, 93, 32, 122,
  121, 120, 99, 10, 45, 115, 108, 105, 99, 101, 115, 91, 45, 51, 93, 32,
  36, 51, 44, 36, 51, 32, 45, 114, 91, 45, 51, 45, 45, 49, 93, 32,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 51, 10, 45, 105,
  109, 97, 103, 101, 112, 108, 97, 110, 101, 51, 100, 91, 45, 51, 45, 45,
  49, 93, 10, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 49, 44,
  48, 44, 57, 48, 32, 45, 114, 51, 100, 91, 45, 50, 93, 32, 49, 44,
  48, 44, 48, 44, 45, 57, 48, 10, 45, 43, 51, 100, 91, 45, 51, 93,
  32, 48, 44, 48, 44, 36, 122, 32, 45, 43, 51, 100, 91, 45, 50, 93,
  32, 48, 44, 36, 121, 44, 48, 32, 45, 43, 51, 100, 91, 45, 49, 93,
  32, 36, 120, 44, 48, 44, 48, 10, 45, 43, 51, 100, 91, 45, 51, 45,
  45, 49, 93, 32, 45, 111, 51, 100, 91, 45, 49, 93, 32, 48, 46, 56,
  10, 45, 105, 102, 32, 36, 52, 32, 45, 98, 111, 120, 51, 100, 32, 36,
  119, 44, 36, 104, 44, 36, 100, 32, 45, 112, 51, 100, 91, 45, 49, 93,
  32, 49, 32, 45, 111, 51, 100, 91, 45, 49, 93, 32, 48, 46, 52, 32,
  45, 43, 51, 100, 91, 45, 50, 44, 45, 49, 93, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 112, 121, 114, 97, 109, 105, 100, 51, 100, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 110,
  101, 119, 32, 51, 100, 32, 112, 121, 114, 97, 109, 105, 100, 44, 32, 119,
  105, 116, 104, 32, 119, 105, 100, 116, 104, 32, 36, 49, 32, 97, 110, 100,
  32, 104, 101, 105, 103, 104, 116, 32, 36, 50, 46, 34, 10, 45, 118, 32,
  45, 10, 40, 54, 55, 46, 53, 59, 55, 51, 46, 53, 59, 49, 48, 57,
  46, 53, 59, 49, 48, 51, 46, 53, 59, 53, 49, 46, 53, 59, 49, 48,
  48, 46, 53, 59, 92, 10, 53, 59, 53, 59, 92, 10, 123, 45, 36, 49,
  47, 50, 125, 59, 123, 45, 36, 49, 47, 50, 125, 59, 123, 45, 36, 50,
  47, 50, 125, 59, 92, 10, 123, 36, 49, 47, 50, 125, 59, 123, 45, 36,
  49, 47, 50, 125, 59, 123, 45, 36, 50, 47, 50, 125, 59, 92, 10, 123,
  36, 49, 47, 50, 125, 59, 123, 36, 49, 47, 50, 125, 59, 123, 45, 36,
  50, 47, 50, 125, 59, 92, 10, 123, 45, 36, 49, 47, 50, 125, 59, 123,
  36, 49, 47, 50, 125, 59, 123, 45, 36, 50, 47, 50, 125, 59, 92, 10,
  48, 59, 48, 59, 123, 36, 50, 47, 50, 125, 59, 92, 10, 52, 59, 48,
  59, 51, 59, 50, 59, 49, 59, 92, 10, 51, 59, 48, 59, 52, 59, 51,
  59, 92, 10, 51, 59, 49, 59, 52, 59, 48, 59, 92, 10, 51, 59, 50,
  59, 52, 59, 49, 59, 92, 10, 51, 59, 51, 59, 52, 59, 50, 41, 10,
  49, 44, 49, 53, 44, 49, 44, 49, 44, 50, 48, 48, 32, 49, 44, 53,
  44, 49, 44, 49, 44, 49, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93,
  32, 121, 32, 45, 110, 109, 91, 45, 49, 93, 32, 91, 51, 100, 92, 32,
  112, 121, 114, 97, 109, 105, 100, 93, 10, 45, 118, 32, 43, 10, 113, 117,
  97, 100, 114, 97, 110, 103, 108, 101, 51, 100, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 51, 100, 32, 113,
  117, 97, 100, 114, 97, 110, 103, 108, 101, 32, 40, 36, 49, 44, 36, 50,
  44, 36, 51, 41, 45, 40, 36, 52, 44, 36, 53, 44, 36, 54, 41, 45,
  40, 36, 55, 44, 36, 56, 44, 36, 57, 41, 45, 40, 36, 49, 48, 44,
  36, 49, 49, 44, 36, 49, 50, 41, 46, 34, 10, 45, 118, 32, 45, 32,
  49, 44, 50, 57, 44, 49, 44, 49, 44, 54, 55, 46, 53, 44, 55, 51,
  46, 53, 44, 49, 48, 57, 46, 53, 44, 49, 48, 51, 46, 53, 44, 53,
  49, 46, 53, 44, 49, 48, 48, 46, 53, 44, 52, 44, 49, 44, 36, 123,
  49, 45, 49, 50, 125, 44, 52, 44, 48, 44, 49, 44, 50, 44, 51, 44,
  50, 48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44, 49, 32, 45, 110,
  109, 91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 113, 117, 97, 100, 114,
  97, 110, 103, 108, 101, 93, 32, 45, 118, 32, 43, 10, 114, 111, 116, 97,
  116, 105, 111, 110, 51, 100, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 73, 110, 112, 117, 116, 32, 51, 100, 32, 114, 111, 116, 97, 116,
  105, 111, 110, 32, 109, 97, 116, 114, 105, 120, 32, 97, 114, 111, 117, 110,
  100, 32, 97, 120, 105, 115, 32, 40, 36, 49, 44, 36, 50, 44, 36, 51,
  41, 32, 119, 105, 116, 104, 32, 97, 110, 103, 108, 101, 32, 36, 52, 32,
  100, 101, 103, 46, 34, 10, 45, 118, 32, 45, 10, 40, 36, 49, 94, 36,
  50, 94, 36, 51, 94, 48, 41, 32, 45, 111, 114, 105, 101, 110, 116, 97,
  116, 105, 111, 110, 91, 45, 49, 93, 32, 45, 121, 91, 45, 49, 93, 32,
  120, 32, 45, 42, 91, 45, 49, 93, 32, 123, 115, 105, 110, 40, 36, 52,
  42, 112, 105, 47, 51, 54, 48, 41, 125, 32, 45, 61, 91, 45, 49, 93,
  32, 123, 99, 111, 115, 40, 36, 52, 42, 112, 105, 47, 51, 54, 48, 41,
  125, 44, 51, 10, 120, 120, 61, 123, 105, 40, 48, 41, 42, 105, 40, 48,
  41, 125, 32, 120, 121, 61, 123, 105, 40, 48, 41, 42, 105, 40, 49, 41,
  125, 32, 120, 122, 61, 123, 105, 40, 48, 41, 42, 105, 40, 50, 41, 125,
  32, 120, 119, 61, 123, 105, 40, 48, 41, 42, 105, 40, 51, 41, 125, 10,
  121, 121, 61, 123, 105, 40, 49, 41, 42, 105, 40, 49, 41, 125, 32, 121,
  122, 61, 123, 105, 40, 49, 41, 42, 105, 40, 50, 41, 125, 32, 121, 119,
  61, 123, 105, 40, 49, 41, 42, 105, 40, 51, 41, 125, 10, 122, 122, 61,
  123, 105, 40, 50, 41, 42, 105, 40, 50, 41, 125, 32, 122, 119, 61, 123,
  105, 40, 50, 41, 42, 105, 40, 51, 41, 125, 10, 45, 114, 109, 91, 45,
  49, 93, 10, 40, 123, 49, 45, 50, 42, 40, 36, 121, 121, 43, 36, 122,
  122, 41, 125, 44, 123, 50, 42, 40, 36, 120, 121, 43, 36, 122, 119, 41,
  125, 44, 123, 50, 42, 40, 36, 120, 122, 45, 36, 121, 119, 41, 125, 59,
  92, 10, 123, 50, 42, 40, 36, 120, 121, 45, 36, 122, 119, 41, 125, 44,
  123, 49, 45, 50, 42, 40, 36, 120, 120, 43, 36, 122, 122, 41, 125, 44,
  123, 50, 42, 40, 36, 121, 122, 43, 36, 120, 119, 41, 125, 59, 92, 10,
  123, 50, 42, 40, 36, 120, 122, 43, 36, 121, 119, 41, 125, 44, 123, 50,
  42, 40, 36, 121, 122, 45, 36, 120, 119, 41, 125, 44, 123, 49, 45, 50,
  42, 40, 36, 120, 120, 43, 36, 121, 121, 41, 125, 41, 10, 45, 110, 109,
  91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 114, 111, 116, 97, 116, 105,
  111, 110, 93, 10, 45, 118, 32, 43, 10, 115, 105, 101, 114, 112, 105, 110,
  115, 107, 105, 51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36,
  123, 49, 61, 52, 125, 62, 61, 48, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 50, 61, 49, 125, 44, 36, 123, 51, 61, 49, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 51, 100, 32, 83,
  105, 101, 114, 112, 105, 110, 115, 107, 105, 32, 112, 121, 114, 97, 109, 105,
  100, 32, 111, 102, 32, 100, 101, 103, 114, 101, 101, 32, 36, 49, 44, 32,
  119, 105, 116, 104, 32, 119, 105, 100, 116, 104, 32, 36, 50, 32, 97, 110,
  100, 32, 104, 101, 105, 103, 104, 116, 32, 36, 51, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 108, 91, 93, 32, 45, 95, 115, 105, 101, 114, 112, 105,
  110, 115, 107, 105, 51, 100, 32, 123, 45, 36, 50, 47, 50, 125, 44, 123,
  45, 36, 50, 47, 50, 125, 44, 123, 45, 36, 51, 47, 50, 125, 44, 123,
  36, 50, 47, 50, 125, 44, 123, 45, 36, 50, 47, 50, 125, 44, 123, 45,
  36, 51, 47, 50, 125, 44, 123, 36, 50, 47, 50, 125, 44, 123, 36, 50,
  47, 50, 125, 44, 123, 45, 36, 51, 47, 50, 125, 44, 123, 45, 36, 50,
  47, 50, 125, 44, 123, 36, 50, 47, 50, 125, 44, 123, 45, 36, 51, 47,
  50, 125, 44, 48, 44, 48, 44, 123, 36, 51, 47, 50, 125, 44, 36, 49,
  32, 45, 43, 51, 100, 32, 45, 101, 110, 100, 108, 10, 45, 110, 109, 91,
  45, 49, 93, 32, 91, 51, 100, 92, 32, 115, 105, 101, 114, 112, 105, 110,
  115, 107, 105, 93, 32, 45, 118, 32, 43, 10, 95, 115, 105, 101, 114, 112,
  105, 110, 115, 107, 105, 51, 100, 32, 58, 10, 45, 105, 102, 32, 123, 36,
  49, 54, 60, 61, 48, 125, 10, 40, 54, 55, 46, 53, 59, 55, 51, 46,
  53, 59, 49, 48, 57, 46, 53, 59, 49, 48, 51, 46, 53, 59, 53, 49,
  46, 53, 59, 49, 48, 48, 46, 53, 59, 92, 10, 53, 59, 53, 59, 92,
  10, 36, 49, 59, 36, 50, 59, 36, 51, 59, 92, 10, 36, 52, 59, 36,
  53, 59, 36, 54, 59, 92, 10, 36, 55, 59, 36, 56, 59, 36, 57, 59,
  92, 10, 36, 49, 48, 59, 36, 49, 49, 59, 36, 49, 50, 59, 92, 10,
  36, 49, 51, 59, 36, 49, 52, 59, 36, 49, 53, 59, 92, 10, 52, 59,
  48, 59, 51, 59, 50, 59, 49, 59, 92, 10, 51, 59, 48, 59, 52, 59,
  51, 59, 92, 10, 51, 59, 49, 59, 52, 59, 48, 59, 92, 10, 51, 59,
  50, 59, 52, 59, 49, 59, 92, 10, 51, 59, 51, 59, 52, 59, 50, 41,
  10, 49, 44, 49, 53, 44, 49, 44, 49, 44, 50, 48, 48, 32, 49, 44,
  53, 44, 49, 44, 49, 44, 49, 32, 45, 97, 91, 45, 51, 45, 45, 49,
  93, 32, 121, 10, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 95, 115, 105, 101, 114, 112, 105, 110, 115, 107, 105, 51,
  100, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 92, 10, 123, 40, 36,
  49, 43, 36, 52, 41, 47, 50, 125, 44, 123, 40, 36, 50, 43, 36, 53,
  41, 47, 50, 125, 44, 123, 40, 36, 51, 43, 36, 54, 41, 47, 50, 125,
  44, 92, 10, 123, 40, 36, 49, 43, 36, 52, 43, 36, 55, 43, 36, 49,
  48, 41, 47, 52, 125, 44, 123, 40, 36, 50, 43, 36, 53, 43, 36, 56,
  43, 36, 49, 49, 41, 47, 52, 125, 44, 123, 40, 36, 51, 43, 36, 54,
  43, 36, 57, 43, 36, 49, 50, 41, 47, 52, 125, 44, 92, 10, 123, 40,
  36, 49, 43, 36, 49, 48, 41, 47, 50, 125, 44, 123, 40, 36, 50, 43,
  36, 49, 49, 41, 47, 50, 125, 44, 123, 40, 36, 51, 43, 36, 49, 50,
  41, 47, 50, 125, 44, 92, 10, 123, 40, 36, 49, 43, 36, 49, 51, 41,
  47, 50, 125, 44, 123, 40, 36, 50, 43, 36, 49, 52, 41, 47, 50, 125,
  44, 123, 40, 36, 51, 43, 36, 49, 53, 41, 47, 50, 125, 44, 92, 10,
  123, 36, 49, 54, 45, 49, 125, 10, 45, 95, 115, 105, 101, 114, 112, 105,
  110, 115, 107, 105, 51, 100, 32, 123, 40, 36, 49, 43, 36, 52, 41, 47,
  50, 125, 44, 123, 40, 36, 50, 43, 36, 53, 41, 47, 50, 125, 44, 123,
  40, 36, 51, 43, 36, 54, 41, 47, 50, 125, 44, 92, 10, 36, 52, 44,
  36, 53, 44, 36, 54, 44, 92, 10, 123, 40, 36, 52, 43, 36, 55, 41,
  47, 50, 125, 44, 123, 40, 36, 53, 43, 36, 56, 41, 47, 50, 125, 44,
  123, 40, 36, 54, 43, 36, 57, 41, 47, 50, 125, 44, 92, 10, 123, 40,
  36, 49, 43, 36, 52, 43, 36, 55, 43, 36, 49, 48, 41, 47, 52, 125,
  44, 123, 40, 36, 50, 43, 36, 53, 43, 36, 56, 43, 36, 49, 49, 41,
  47, 52, 125, 44, 123, 40, 36, 51, 43, 36, 54, 43, 36, 57, 43, 36,
  49, 50, 41, 47, 52, 125, 44, 92, 10, 123, 40, 36, 52, 43, 36, 49,
  51, 41, 47, 50, 125, 44, 123, 40, 36, 53, 43, 36, 49, 52, 41, 47,
  50, 125, 44, 123, 40, 36, 54, 43, 36, 49, 53, 41, 47, 50, 125, 44,
  92, 10, 123, 36, 49, 54, 45, 49, 125, 10, 45, 95, 115, 105, 101, 114,
  112, 105, 110, 115, 107, 105, 51, 100, 32, 123, 40, 36, 49, 43, 36, 52,
  43, 36, 55, 43, 36, 49, 48, 41, 47, 52, 125, 44, 123, 40, 36, 50,
  43, 36, 53, 43, 36, 56, 43, 36, 49, 49, 41, 47, 52, 125, 44, 123,
  40, 36, 51, 43, 36, 54, 43, 36, 57, 43, 36, 49, 50, 41, 47, 52,
  125, 44, 92, 10, 123, 40, 36, 52, 43, 36, 55, 41, 47, 50, 125, 44,
  123, 40, 36, 53, 43, 36, 56, 41, 47, 50, 125, 44, 123, 40, 36, 54,
  43, 36, 57, 41, 47, 50, 125, 44, 92, 10, 36, 55, 44, 36, 56, 44,
  36, 57, 44, 92, 10, 123, 40, 36, 55, 43, 36, 49, 48, 41, 47, 50,
  125, 44, 123, 40, 36, 56, 43, 36, 49, 49, 41, 47, 50, 125, 44, 123,
  40, 36, 57, 43, 36, 49, 50, 41, 47, 50, 125, 44, 92, 10, 123, 40,
  36, 55, 43, 36, 49, 51, 41, 47, 50, 125, 44, 123, 40, 36, 56, 43,
  36, 49, 52, 41, 47, 50, 125, 44, 123, 40, 36, 57, 43, 36, 49, 53,
  41, 47, 50, 125, 44, 92, 10, 123, 36, 49, 54, 45, 49, 125, 10, 45,
  95, 115, 105, 101, 114, 112, 105, 110, 115, 107, 105, 51, 100, 32, 123, 40,
  36, 49, 43, 36, 49, 48, 41, 47, 50, 125, 44, 123, 40, 36, 50, 43,
  36, 49, 49, 41, 47, 50, 125, 44, 123, 40, 36, 51, 43, 36, 49, 50,
  41, 47, 50, 125, 44, 92, 10, 123, 40, 36, 49, 43, 36, 52, 43, 36,
  55, 43, 36, 49, 48, 41, 47, 52, 125, 44, 123, 40, 36, 50, 43, 36,
  53, 43, 36, 56, 43, 36, 49, 49, 41, 47, 52, 125, 44, 123, 40, 36,
  51, 43, 36, 54, 43, 36, 57, 43, 36, 49, 50, 41, 47, 52, 125, 44,
  92, 10, 123, 40, 36, 55, 43, 36, 49, 48, 41, 47, 50, 125, 44, 123,
  40, 36, 56, 43, 36, 49, 49, 41, 47, 50, 125, 44, 123, 40, 36, 57,
  43, 36, 49, 50, 41, 47, 50, 125, 44, 92, 10, 36, 49, 48, 44, 36,
  49, 49, 44, 36, 49, 50, 44, 92, 10, 123, 40, 36, 49, 48, 43, 36,
  49, 51, 41, 47, 50, 125, 44, 123, 40, 36, 49, 49, 43, 36, 49, 52,
  41, 47, 50, 125, 44, 123, 40, 36, 49, 50, 43, 36, 49, 53, 41, 47,
  50, 125, 44, 92, 10, 123, 36, 49, 54, 45, 49, 125, 10, 45, 95, 115,
  105, 101, 114, 112, 105, 110, 115, 107, 105, 51, 100, 32, 123, 40, 36, 49,
  43, 36, 49, 51, 41, 47, 50, 125, 44, 123, 40, 36, 50, 43, 36, 49,
  52, 41, 47, 50, 125, 44, 123, 40, 36, 51, 43, 36, 49, 53, 41, 47,
  50, 125, 44, 92, 10, 123, 40, 36, 52, 43, 36, 49, 51, 41, 47, 50,
  125, 44, 123, 40, 36, 53, 43, 36, 49, 52, 41, 47, 50, 125, 44, 123,
  40, 36, 54, 43, 36, 49, 53, 41, 47, 50, 125, 44, 92, 10, 123, 40,
  36, 55, 43, 36, 49, 51, 41, 47, 50, 125, 44, 123, 40, 36, 56, 43,
  36, 49, 52, 41, 47, 50, 125, 44, 123, 40, 36, 57, 43, 36, 49, 53,
  41, 47, 50, 125, 44, 92, 10, 123, 40, 36, 49, 48, 43, 36, 49, 51,
  41, 47, 50, 125, 44, 123, 40, 36, 49, 49, 43, 36, 49, 52, 41, 47,
  50, 125, 44, 123, 40, 36, 49, 50, 43, 36, 49, 53, 41, 47, 50, 125,
  44, 92, 10, 36, 49, 51, 44, 36, 49, 52, 44, 36, 49, 53, 44, 92,
  10, 123, 36, 49, 54, 45, 49, 125, 10, 115, 110, 97, 112, 115, 104, 111,
  116, 51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123,
  49, 61, 53, 49, 50, 125, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61,
  49, 125, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51,
  61, 34, 34, 125, 10, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40, 36,
  51, 41, 125, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 84, 97,
  107, 101, 32, 36, 49, 120, 36, 49, 32, 115, 110, 97, 112, 115, 104, 111,
  116, 36, 63, 32, 111, 102, 32, 51, 100, 32, 111, 98, 106, 101, 99, 116,
  36, 63, 44, 32, 119, 105, 116, 104, 32, 122, 111, 111, 109, 32, 102, 97,
  99, 116, 111, 114, 32, 36, 50, 32, 97, 110, 100, 32, 98, 97, 99, 107,
  103, 114, 111, 117, 110, 100, 32, 99, 111, 108, 111, 114, 32, 36, 123, 51,
  45, 45, 49, 125, 46, 34, 10, 45, 101, 108, 115, 101, 10, 45, 101, 91,
  48, 45, 45, 51, 93, 32, 34, 84, 97, 107, 101, 32, 36, 49, 120, 36,
  49, 32, 115, 110, 97, 112, 115, 104, 111, 116, 36, 63, 32, 111, 102, 32,
  51, 100, 32, 111, 98, 106, 101, 99, 116, 36, 63, 44, 32, 119, 105, 116,
  104, 32, 122, 111, 111, 109, 32, 102, 97, 99, 116, 111, 114, 32, 36, 50,
  46, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 105, 102, 32, 123, 36, 50, 33, 61, 48, 125, 32, 45, 99, 51,
  100, 32, 45, 110, 51, 100, 32, 45, 42, 51, 100, 32, 123, 51, 42, 36,
  49, 42, 36, 50, 47, 52, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 110, 97, 114, 103, 40, 36, 51, 41, 125, 32, 40, 36,
  123, 51, 45, 45, 49, 125, 41, 32, 45, 121, 91, 45, 49, 93, 32, 99,
  32, 45, 101, 108, 115, 101, 32, 49, 44, 50, 44, 49, 44, 51, 44, 51,
  50, 44, 54, 52, 44, 51, 50, 44, 49, 49, 54, 44, 54, 52, 44, 57,
  54, 32, 45, 101, 110, 100, 105, 102, 32, 45, 114, 91, 45, 49, 93, 32,
  36, 49, 44, 36, 49, 44, 49, 44, 51, 44, 51, 10, 45, 111, 98, 106,
  101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 53,
  48, 37, 44, 53, 48, 37, 44, 48, 44, 49, 32, 45, 110, 109, 91, 45,
  49, 93, 32, 64, 123, 45, 50, 44, 110, 125, 44, 49, 32, 45, 114, 109,
  91, 45, 50, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 115, 112, 104, 101, 114, 105, 99, 97, 108, 51,
  100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61,
  54, 52, 125, 62, 61, 51, 32, 38, 38, 32, 36, 123, 50, 61, 36, 49,
  125, 62, 61, 51, 34, 32, 45, 115, 107, 105, 112, 32, 34, 36, 123, 51,
  61, 97, 98, 115, 40, 49, 43, 48, 46, 53, 42, 99, 111, 115, 40, 51,
  42, 112, 104, 105, 41, 42, 115, 105, 110, 40, 52, 42, 116, 104, 101, 116,
  97, 41, 41, 125, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73,
  110, 112, 117, 116, 32, 51, 100, 32, 115, 112, 104, 101, 114, 105, 99, 97,
  108, 32, 111, 98, 106, 101, 99, 116, 44, 32, 119, 105, 116, 104, 32, 115,
  117, 98, 100, 105, 118, 105, 115, 105, 111, 110, 115, 32, 40, 36, 49, 44,
  36, 50, 41, 32, 97, 110, 100, 32, 104, 101, 105, 103, 104, 116, 32, 102,
  117, 110, 99, 116, 105, 111, 110, 32, 39, 36, 51, 39, 46, 34, 10, 45,
  118, 32, 45, 10, 40, 123, 39, 67, 73, 109, 103, 51, 100, 39, 125, 41,
  32, 45, 121, 91, 45, 49, 93, 10, 110, 49, 61, 123, 114, 111, 117, 110,
  100, 40, 36, 49, 41, 125, 32, 110, 50, 61, 123, 114, 111, 117, 110, 100,
  40, 36, 50, 41, 125, 10, 36, 110, 49, 44, 123, 36, 110, 50, 45, 49,
  125, 44, 49, 44, 51, 44, 34, 112, 104, 105, 61, 50, 42, 112, 105, 42,
  40, 120, 43, 48, 46, 53, 41, 47, 119, 59, 92, 10, 116, 104, 101, 116,
  97, 61, 45, 112, 105, 47, 50, 43, 112, 105, 42, 40, 121, 43, 48, 46,
  53, 41, 47, 104, 59, 92, 10, 99, 112, 61, 99, 111, 115, 40, 112, 104,
  105, 41, 59, 92, 10, 115, 112, 61, 115, 105, 110, 40, 112, 104, 105, 41,
  59, 92, 10, 99, 116, 61, 99, 111, 115, 40, 116, 104, 101, 116, 97, 41,
  59, 92, 10, 40, 36, 51, 41, 42, 105, 102, 40, 99, 61, 61, 48, 44,
  99, 116, 42, 99, 112, 44, 105, 102, 40, 99, 61, 61, 49, 44, 99, 116,
  42, 115, 112, 44, 115, 105, 110, 40, 116, 104, 101, 116, 97, 41, 41, 41,
  34, 10, 45, 114, 91, 45, 49, 93, 32, 123, 119, 42, 104, 125, 44, 51,
  44, 49, 44, 49, 44, 45, 49, 32, 45, 112, 101, 114, 109, 117, 116, 101,
  91, 45, 49, 93, 32, 121, 120, 122, 99, 10, 45, 105, 91, 45, 50, 93,
  32, 40, 48, 44, 48, 44, 123, 112, 104, 105, 61, 48, 59, 116, 104, 101,
  116, 97, 61, 45, 112, 105, 47, 50, 59, 45, 36, 51, 125, 59, 48, 44,
  48, 44, 123, 112, 104, 105, 61, 48, 59, 116, 104, 101, 116, 97, 61, 112,
  105, 47, 50, 59, 36, 51, 125, 41, 32, 45, 97, 91, 45, 50, 44, 45,
  49, 93, 32, 121, 10, 110, 98, 118, 61, 123, 104, 125, 32, 45, 121, 91,
  45, 49, 93, 10, 36, 110, 49, 44, 123, 36, 110, 50, 45, 50, 125, 44,
  49, 44, 52, 44, 34, 110, 120, 61, 40, 120, 43, 49, 41, 37, 119, 59,
  110, 121, 61, 40, 121, 43, 49, 41, 59, 50, 43, 105, 102, 40, 99, 61,
  61, 48, 44, 120, 43, 121, 42, 34, 36, 110, 49, 34, 44, 105, 102, 40,
  99, 61, 61, 49, 44, 110, 120, 43, 121, 42, 34, 36, 110, 49, 34, 44,
  105, 102, 40, 99, 61, 61, 50, 44, 110, 120, 43, 110, 121, 42, 34, 36,
  110, 49, 34, 44, 120, 43, 110, 121, 42, 34, 36, 110, 49, 34, 41, 41,
  41, 34, 10, 45, 114, 91, 45, 49, 93, 32, 123, 119, 42, 104, 125, 44,
  52, 44, 49, 44, 49, 44, 45, 49, 32, 45, 112, 101, 114, 109, 117, 116,
  101, 91, 45, 49, 93, 32, 121, 120, 122, 99, 32, 45, 105, 91, 45, 50,
  93, 32, 49, 44, 123, 104, 125, 44, 49, 44, 49, 44, 52, 32, 45, 97,
  91, 45, 50, 44, 45, 49, 93, 32, 120, 10, 50, 44, 36, 110, 49, 44,
  49, 44, 49, 44, 51, 44, 48, 32, 49, 44, 36, 110, 49, 44, 49, 44,
  49, 44, 39, 121, 39, 32, 45, 45, 43, 91, 45, 49, 93, 32, 49, 32,
  45, 37, 91, 45, 49, 93, 32, 123, 104, 125, 32, 50, 44, 36, 110, 49,
  44, 49, 44, 49, 44, 51, 44, 49, 32, 91, 45, 51, 44, 45, 50, 93,
  10, 45, 43, 91, 45, 53, 44, 45, 52, 93, 32, 50, 32, 45, 114, 118,
  91, 45, 53, 44, 45, 52, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49,
  93, 32, 123, 36, 110, 98, 118, 45, 36, 110, 49, 125, 32, 45, 97, 91,
  45, 51, 45, 45, 49, 93, 32, 120, 32, 45, 97, 91, 45, 52, 45, 45,
  50, 93, 32, 120, 10, 110, 98, 112, 61, 123, 104, 43, 64, 123, 45, 50,
  44, 104, 125, 43, 64, 123, 45, 51, 44, 104, 125, 125, 10, 45, 121, 91,
  45, 51, 45, 45, 49, 93, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93,
  32, 121, 10, 45, 105, 91, 45, 51, 93, 32, 40, 36, 110, 98, 118, 59,
  36, 110, 98, 112, 41, 10, 49, 44, 123, 51, 42, 36, 110, 98, 112, 125,
  44, 49, 44, 49, 44, 50, 48, 48, 32, 49, 44, 36, 110, 98, 112, 44,
  49, 44, 49, 44, 49, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32,
  121, 10, 45, 97, 91, 45, 53, 45, 45, 49, 93, 32, 121, 32, 45, 110,
  109, 91, 45, 49, 93, 32, 34, 91, 51, 100, 32, 115, 112, 104, 101, 114,
  105, 99, 97, 108, 32, 115, 117, 114, 102, 97, 99, 101, 32, 39, 36, 51,
  39, 93, 34, 10, 45, 118, 32, 43, 10, 115, 112, 108, 105, 110, 101, 51,
  100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36, 123, 49, 51, 61,
  49, 50, 56, 125, 62, 61, 50, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 73, 110, 112, 117, 116, 32, 110, 101, 119, 32, 51, 100, 32, 115, 112,
  108, 105, 110, 101, 32, 102, 114, 111, 109, 32, 40, 36, 123, 49, 45, 51,
  125, 41, 32, 91, 36, 123, 52, 45, 54, 125, 93, 32, 116, 111, 32, 40,
  36, 123, 55, 45, 57, 125, 41, 32, 91, 36, 123, 49, 48, 45, 49, 50,
  125, 93, 32, 119, 105, 116, 104, 32, 36, 49, 51, 32, 118, 101, 114, 116,
  105, 99, 101, 115, 46, 34, 10, 45, 118, 32, 45, 10, 40, 123, 39, 67,
  73, 109, 103, 51, 100, 39, 125, 41, 32, 45, 43, 91, 45, 49, 93, 32,
  48, 46, 53, 10, 40, 36, 49, 51, 59, 123, 36, 49, 51, 45, 49, 125,
  41, 10, 49, 44, 36, 49, 51, 44, 49, 44, 49, 44, 49, 32, 40, 48,
  59, 49, 41, 32, 45, 114, 91, 45, 49, 93, 32, 49, 44, 36, 49, 51,
  44, 49, 44, 49, 44, 51, 32, 45, 45, 115, 113, 114, 91, 45, 49, 93,
  32, 45, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 97, 91, 45,
  52, 45, 45, 49, 93, 32, 120, 10, 45, 45, 42, 91, 45, 49, 93, 32,
  39, 36, 50, 44, 36, 53, 44, 123, 51, 42, 40, 40, 36, 56, 41, 45,
  40, 36, 50, 41, 41, 45, 50, 42, 40, 36, 53, 41, 45, 40, 36, 49,
  49, 41, 125, 44, 123, 40, 36, 53, 41, 43, 40, 36, 49, 49, 41, 43,
  50, 42, 40, 40, 36, 50, 41, 45, 40, 36, 56, 41, 41, 125, 39, 32,
  45, 108, 91, 45, 49, 93, 32, 45, 115, 32, 120, 32, 45, 43, 32, 45,
  101, 110, 100, 108, 10, 45, 45, 42, 91, 45, 50, 93, 32, 39, 36, 51,
  44, 36, 54, 44, 123, 51, 42, 40, 40, 36, 57, 41, 45, 40, 36, 51,
  41, 41, 45, 50, 42, 40, 36, 54, 41, 45, 40, 36, 49, 50, 41, 125,
  44, 123, 40, 36, 54, 41, 43, 40, 36, 49, 50, 41, 43, 50, 42, 40,
  40, 36, 51, 41, 45, 40, 36, 57, 41, 41, 125, 39, 32, 45, 108, 91,
  45, 49, 93, 32, 45, 115, 32, 120, 32, 45, 43, 32, 45, 101, 110, 100,
  108, 10, 45, 42, 91, 45, 51, 93, 32, 39, 36, 49, 44, 36, 52, 44,
  123, 51, 42, 40, 40, 36, 55, 41, 45, 40, 36, 49, 41, 41, 45, 50,
  42, 40, 36, 52, 41, 45, 40, 36, 49, 48, 41, 125, 44, 123, 40, 36,
  52, 41, 43, 40, 36, 49, 48, 41, 43, 50, 42, 40, 40, 36, 49, 41,
  45, 40, 36, 55, 41, 41, 125, 39, 32, 45, 108, 91, 45, 51, 93, 32,
  45, 115, 32, 120, 32, 45, 43, 32, 45, 101, 110, 100, 108, 10, 45, 97,
  91, 45, 51, 45, 45, 49, 93, 32, 120, 10, 49, 44, 123, 36, 49, 51,
  45, 49, 125, 44, 49, 44, 49, 44, 50, 32, 40, 48, 44, 49, 59, 123,
  36, 49, 51, 45, 50, 125, 44, 123, 36, 49, 51, 45, 49, 125, 41, 32,
  45, 114, 91, 45, 49, 93, 32, 50, 44, 91, 45, 50, 93, 44, 49, 44,
  49, 44, 51, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 45,
  97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 10, 49, 44, 123, 51, 42,
  40, 36, 49, 51, 45, 49, 41, 125, 44, 49, 44, 49, 44, 50, 48, 48,
  32, 49, 44, 123, 36, 49, 51, 45, 49, 125, 44, 49, 44, 49, 44, 49,
  10, 45, 121, 91, 45, 51, 44, 45, 52, 44, 45, 54, 93, 32, 45, 97,
  91, 45, 54, 45, 45, 49, 93, 32, 121, 10, 45, 118, 32, 43, 10, 115,
  112, 114, 105, 116, 101, 51, 100, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105, 109, 97, 103, 101,
  36, 63, 32, 97, 115, 32, 51, 100, 32, 115, 112, 114, 105, 116, 101, 115,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48,
  44, 110, 125, 10, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105,
  116, 121, 10, 45, 105, 91, 48, 93, 32, 40, 54, 55, 46, 53, 59, 55,
  51, 46, 53, 59, 49, 48, 57, 46, 53, 59, 49, 48, 51, 46, 53, 59,
  53, 49, 46, 53, 59, 49, 48, 48, 46, 53, 59, 49, 59, 49, 59, 48,
  59, 48, 59, 48, 59, 49, 59, 48, 59, 45, 49, 50, 56, 59, 123, 119,
  125, 59, 123, 104, 125, 59, 64, 123, 48, 44, 115, 125, 41, 32, 45, 121,
  91, 49, 93, 10, 45, 105, 102, 32, 123, 64, 35, 61, 61, 50, 125, 32,
  40, 49, 41, 32, 45, 97, 32, 121, 10, 45, 101, 108, 115, 101, 32, 45,
  47, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 105, 91, 45, 50, 93,
  32, 40, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 123,
  115, 125, 41, 32, 45, 121, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 97, 32, 121, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 115, 112, 114, 105, 116, 101, 115, 51, 100, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 97, 115, 32, 51, 100, 32, 115, 112, 114,
  105, 116, 101, 115, 32, 99, 108, 111, 117, 100, 115, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49,
  125, 10, 45, 105, 102, 32, 123, 33, 64, 123, 36, 62, 44, 40, 48, 44,
  55, 41, 125, 125, 32, 45, 99, 111, 110, 116, 105, 110, 117, 101, 32, 45,
  101, 110, 100, 105, 102, 10, 91, 45, 49, 93, 32, 45, 108, 91, 36, 62,
  44, 45, 49, 93, 10, 45, 115, 51, 100, 91, 48, 93, 32, 78, 61, 64,
  123, 49, 44, 48, 125, 32, 45, 61, 91, 49, 93, 32, 36, 78, 44, 48,
  44, 49, 10, 45, 114, 109, 91, 51, 45, 53, 93, 32, 45, 105, 91, 51,
  93, 32, 40, 49, 44, 48, 59, 49, 44, 123, 36, 78, 45, 49, 125, 41,
  32, 45, 114, 91, 51, 93, 32, 50, 44, 36, 78, 44, 49, 44, 49, 44,
  51, 32, 45, 114, 111, 117, 110, 100, 91, 51, 93, 10, 45, 105, 102, 32,
  123, 115, 61, 61, 52, 125, 10, 45, 115, 91, 45, 49, 93, 32, 99, 44,
  45, 51, 32, 45, 47, 91, 45, 49, 93, 32, 50, 53, 53, 10, 45, 105,
  91, 45, 51, 93, 32, 40, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123,
  104, 125, 59, 51, 41, 10, 45, 105, 102, 32, 123, 36, 78, 62, 49, 125,
  32, 45, 105, 91, 45, 50, 93, 32, 49, 44, 123, 52, 42, 40, 36, 78,
  45, 49, 41, 125, 44, 49, 44, 49, 44, 45, 49, 50, 56, 44, 48, 44,
  48, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 91, 45, 50,
  93, 32, 40, 45, 49, 50, 56, 59, 123, 119, 125, 59, 123, 104, 125, 59,
  49, 41, 10, 45, 105, 102, 32, 123, 36, 78, 62, 49, 125, 32, 49, 44,
  123, 52, 42, 40, 36, 78, 45, 49, 41, 125, 44, 49, 44, 49, 44, 45,
  49, 50, 56, 44, 48, 44, 48, 44, 48, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 108, 115, 101, 10, 45, 105, 91, 45, 50, 93, 32, 40, 45,
  49, 50, 56, 59, 123, 119, 125, 59, 123, 104, 125, 59, 123, 115, 125, 41,
  32, 45, 121, 91, 45, 51, 44, 45, 49, 93, 10, 45, 105, 102, 32, 123,
  36, 78, 62, 49, 125, 32, 49, 44, 123, 52, 42, 40, 36, 78, 45, 49,
  41, 125, 44, 49, 44, 49, 44, 45, 49, 50, 56, 44, 48, 44, 48, 44,
  48, 32, 45, 101, 110, 100, 105, 102, 10, 49, 44, 36, 78, 44, 49, 44,
  49, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 121, 32, 45, 97,
  32, 121, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 118, 32, 43, 10, 115, 116, 97, 114,
  51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49,
  61, 53, 125, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 48, 46, 51,
  56, 125, 62, 61, 48, 32, 38, 38, 32, 36, 50, 60, 61, 49, 34, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 51,
  100, 32, 115, 116, 97, 114, 44, 32, 119, 105, 116, 104, 32, 36, 49, 32,
  98, 114, 97, 110, 99, 104, 101, 115, 32, 97, 110, 100, 32, 116, 104, 105,
  99, 107, 110, 101, 115, 115, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45,
  10, 78, 61, 123, 50, 42, 36, 49, 125, 32, 40, 123, 39, 67, 73, 109,
  103, 51, 100, 39, 125, 41, 32, 45, 43, 91, 45, 49, 93, 32, 48, 46,
  53, 32, 40, 123, 36, 78, 43, 49, 125, 59, 36, 78, 41, 10, 40, 123,
  45, 112, 105, 47, 50, 125, 59, 123, 51, 42, 112, 105, 47, 50, 125, 41,
  32, 45, 114, 91, 45, 49, 93, 32, 49, 44, 123, 36, 78, 43, 49, 125,
  44, 49, 44, 49, 44, 51, 32, 45, 114, 111, 119, 115, 91, 45, 49, 93,
  32, 48, 44, 123, 104, 45, 50, 125, 32, 45, 45, 115, 105, 110, 91, 45,
  49, 93, 32, 45, 99, 111, 115, 91, 45, 50, 93, 32, 45, 97, 91, 45,
  50, 44, 45, 49, 93, 32, 120, 10, 40, 49, 44, 49, 59, 36, 50, 44,
  36, 50, 41, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 122,
  91, 45, 49, 93, 32, 48, 44, 50, 32, 45, 114, 91, 45, 49, 93, 32,
  51, 44, 123, 104, 43, 49, 125, 44, 49, 44, 49, 44, 48, 10, 40, 51,
  44, 36, 78, 44, 49, 44, 48, 59, 51, 44, 36, 78, 44, 36, 78, 44,
  123, 36, 78, 45, 49, 125, 41, 32, 45, 114, 91, 45, 49, 93, 32, 52,
  44, 36, 78, 44, 49, 44, 49, 44, 51, 32, 45, 114, 111, 117, 110, 100,
  91, 45, 49, 93, 32, 45, 61, 91, 45, 49, 93, 32, 48, 44, 50, 44,
  49, 48, 48, 37, 10, 51, 44, 36, 78, 44, 49, 44, 49, 44, 50, 48,
  48, 32, 49, 44, 36, 78, 44, 49, 44, 49, 44, 49, 32, 45, 121, 91,
  45, 54, 44, 45, 52, 45, 45, 50, 93, 32, 45, 97, 91, 45, 54, 45,
  45, 49, 93, 32, 121, 32, 45, 110, 109, 91, 45, 49, 93, 32, 91, 51,
  100, 92, 32, 115, 116, 97, 114, 93, 10, 45, 118, 32, 43, 10, 115, 117,
  112, 101, 114, 102, 111, 114, 109, 117, 108, 97, 51, 100, 32, 58, 32, 45,
  99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 49, 48, 50, 52, 125,
  62, 49, 32, 38, 38, 32, 36, 123, 50, 61, 56, 125, 62, 61, 49, 34,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 49, 125, 44, 36, 123,
  52, 61, 53, 125, 44, 36, 123, 53, 61, 56, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 50, 100, 32, 115, 117,
  112, 101, 114, 102, 111, 114, 109, 117, 108, 97, 32, 99, 117, 114, 118, 101,
  44, 32, 119, 105, 116, 104, 32, 114, 101, 115, 111, 108, 117, 116, 105, 111,
  110, 32, 36, 49, 44, 32, 109, 61, 36, 50, 32, 97, 110, 100, 32, 40,
  110, 49, 44, 110, 50, 44, 110, 51, 41, 61, 40, 36, 51, 44, 36, 52,
  44, 36, 53, 41, 46, 34, 10, 45, 118, 32, 45, 10, 114, 101, 115, 61,
  123, 114, 111, 117, 110, 100, 40, 36, 49, 41, 125, 10, 40, 54, 55, 46,
  53, 59, 55, 51, 46, 53, 59, 49, 48, 57, 46, 53, 59, 49, 48, 51,
  46, 53, 59, 53, 49, 46, 53, 59, 49, 48, 48, 46, 53, 59, 36, 114,
  101, 115, 59, 123, 36, 114, 101, 115, 45, 49, 125, 41, 10, 40, 48, 44,
  123, 50, 42, 112, 105, 125, 41, 32, 45, 114, 91, 45, 49, 93, 32, 36,
  114, 101, 115, 44, 49, 44, 49, 44, 49, 44, 51, 32, 91, 45, 49, 93,
  10, 45, 42, 91, 45, 49, 93, 32, 123, 36, 50, 47, 52, 125, 32, 45,
  45, 115, 105, 110, 91, 45, 49, 93, 32, 45, 99, 111, 115, 91, 45, 50,
  93, 32, 45, 97, 98, 115, 91, 45, 50, 44, 45, 49, 93, 10, 45, 94,
  91, 45, 50, 93, 32, 36, 52, 32, 45, 94, 91, 45, 49, 93, 32, 36,
  53, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 94, 91, 45,
  49, 93, 32, 123, 45, 49, 47, 36, 51, 125, 10, 45, 45, 115, 105, 110,
  91, 45, 50, 93, 32, 45, 99, 111, 115, 91, 45, 51, 93, 32, 45, 42,
  91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 42, 91, 45, 51, 44,
  45, 50, 93, 32, 45, 110, 91, 45, 50, 44, 45, 49, 93, 32, 45, 49,
  44, 49, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 32, 45,
  114, 111, 119, 115, 91, 45, 49, 93, 32, 48, 44, 50, 32, 45, 116, 114,
  97, 110, 115, 112, 111, 115, 101, 91, 45, 49, 93, 32, 45, 114, 91, 45,
  49, 93, 32, 49, 44, 123, 119, 42, 104, 125, 44, 49, 44, 49, 44, 45,
  49, 10, 49, 44, 123, 36, 114, 101, 115, 45, 49, 125, 44, 49, 44, 49,
  44, 50, 32, 40, 48, 59, 123, 36, 114, 101, 115, 45, 50, 125, 41, 32,
  45, 114, 91, 45, 49, 93, 32, 49, 44, 123, 36, 114, 101, 115, 45, 49,
  125, 44, 49, 44, 49, 44, 51, 32, 45, 45, 43, 91, 45, 49, 93, 32,
  49, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 120, 32, 45, 114,
  111, 117, 110, 100, 91, 45, 49, 93, 32, 49, 32, 45, 114, 91, 45, 49,
  93, 32, 49, 44, 123, 119, 42, 104, 125, 44, 49, 44, 49, 44, 45, 49,
  10, 49, 44, 123, 51, 42, 40, 36, 114, 101, 115, 45, 49, 41, 125, 44,
  49, 44, 49, 44, 50, 48, 48, 32, 49, 44, 123, 36, 114, 101, 115, 45,
  49, 125, 44, 49, 44, 49, 44, 49, 32, 45, 97, 91, 45, 53, 45, 45,
  49, 93, 32, 121, 32, 45, 110, 109, 91, 45, 49, 93, 32, 91, 51, 100,
  92, 32, 115, 117, 112, 101, 114, 102, 111, 114, 109, 117, 108, 97, 93, 10,
  45, 118, 32, 43, 10, 116, 101, 120, 116, 95, 112, 111, 105, 110, 116, 99,
  108, 111, 117, 100, 51, 100, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 49, 61, 34, 116, 101, 120, 116, 49, 34, 125, 44, 36, 123, 50, 61,
  34, 116, 101, 120, 116, 50, 34, 125, 44, 36, 123, 51, 61, 49, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 51,
  100, 32, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 32, 116, 101, 120,
  116, 32, 111, 98, 106, 101, 99, 116, 32, 102, 114, 111, 109, 32, 115, 116,
  114, 105, 110, 103, 115, 32, 39, 36, 49, 39, 32, 97, 110, 100, 32, 39,
  36, 50, 39, 44, 32, 119, 105, 116, 104, 32, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 36, 51, 46, 34, 10, 45, 118, 32, 45, 10, 48,
  32, 45, 116, 91, 45, 49, 93, 32, 34, 36, 49, 34, 44, 48, 44, 48,
  44, 53, 55, 44, 49, 44, 49, 10, 48, 32, 45, 116, 91, 45, 49, 93,
  32, 34, 36, 50, 34, 44, 48, 44, 48, 44, 53, 55, 44, 49, 44, 49,
  32, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 121, 10, 45,
  101, 120, 112, 97, 110, 100, 95, 120, 121, 91, 45, 50, 44, 45, 49, 93,
  32, 50, 44, 48, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 50, 44,
  45, 49, 93, 32, 50, 10, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45,
  49, 93, 32, 122, 121, 120, 99, 32, 45, 114, 91, 45, 50, 44, 45, 49,
  93, 32, 64, 123, 45, 109, 97, 120, 95, 119, 104, 100, 125, 32, 45, 97,
  110, 100, 91, 45, 50, 44, 45, 49, 93, 10, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44,
  123, 64, 123, 45, 50, 44, 100, 125, 45, 49, 125, 32, 45, 114, 111, 117,
  110, 100, 91, 45, 49, 93, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 32, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102, 40, 122, 61,
  61, 105, 44, 49, 44, 48, 41, 39, 10, 45, 100, 105, 115, 116, 97, 110,
  99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 43, 91, 45, 49, 93, 32,
  49, 32, 45, 45, 102, 91, 45, 49, 93, 32, 49, 32, 45, 114, 118, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 47, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 42, 91, 45, 49, 93, 32, 91, 45, 50, 93, 10, 45, 45, 100,
  105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 123, 100,
  125, 32, 45, 61, 61, 91, 45, 50, 44, 45, 49, 93, 32, 45, 42, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 10, 49, 44, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48,
  44, 123, 64, 123, 45, 50, 44, 119, 125, 45, 49, 125, 32, 45, 114, 111,
  117, 110, 100, 91, 45, 49, 93, 32, 45, 114, 91, 45, 49, 93, 32, 91,
  45, 50, 93, 32, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102, 40, 120,
  61, 61, 105, 44, 49, 44, 48, 41, 39, 10, 45, 100, 105, 115, 116, 97,
  110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 43, 91, 45, 49, 93,
  32, 49, 32, 45, 45, 102, 91, 45, 49, 93, 32, 49, 32, 45, 114, 118,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 47, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 42, 91, 45, 49, 93, 32, 91, 45, 51, 93, 10, 45, 45,
  100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 123,
  100, 125, 32, 45, 61, 61, 91, 45, 50, 44, 45, 49, 93, 32, 45, 42,
  91, 45, 51, 44, 45, 49, 93, 10, 45, 111, 114, 91, 45, 50, 44, 45,
  49, 93, 10, 45, 98, 91, 45, 49, 93, 32, 36, 51, 32, 45, 105, 115,
  111, 115, 117, 114, 102, 97, 99, 101, 51, 100, 91, 45, 49, 93, 32, 50,
  53, 37, 10, 45, 99, 51, 100, 91, 45, 49, 93, 32, 45, 110, 51, 100,
  91, 45, 49, 93, 32, 45, 110, 109, 91, 45, 49, 93, 32, 34, 91, 51,
  100, 32, 116, 101, 120, 116, 32, 112, 111, 105, 110, 116, 99, 108, 111, 117,
  100, 93, 34, 32, 45, 118, 32, 43, 10, 116, 101, 120, 116, 51, 100, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 53, 55, 125, 44,
  36, 123, 51, 61, 49, 48, 125, 44, 36, 123, 52, 61, 49, 46, 53, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32,
  51, 100, 32, 116, 101, 120, 116, 32, 111, 98, 106, 101, 99, 116, 32, 39,
  36, 49, 39, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101, 32, 36, 50,
  44, 32, 100, 101, 112, 116, 104, 32, 36, 51, 32, 97, 110, 100, 32, 115,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 52, 46, 34, 10, 45,
  118, 32, 45, 32, 48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 36, 49,
  34, 44, 48, 44, 48, 44, 36, 50, 44, 49, 44, 49, 32, 45, 97, 117,
  116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 48, 32, 45, 114, 91,
  45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 36, 51,
  32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 122, 91, 45, 49, 93,
  32, 49, 48, 44, 48, 10, 45, 98, 91, 45, 49, 93, 32, 36, 52, 32,
  45, 105, 115, 111, 115, 117, 114, 102, 97, 99, 101, 51, 100, 91, 45, 49,
  93, 32, 52, 48, 37, 32, 45, 114, 118, 51, 100, 91, 45, 49, 93, 32,
  45, 110, 109, 91, 45, 49, 93, 32, 34, 91, 51, 100, 32, 116, 101, 120,
  116, 32, 39, 36, 49, 39, 93, 34, 32, 45, 118, 32, 43, 10, 116, 111,
  114, 117, 115, 51, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  36, 123, 51, 61, 50, 52, 125, 62, 50, 32, 38, 38, 32, 36, 123, 52,
  61, 49, 50, 125, 62, 50, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  49, 61, 49, 125, 44, 36, 123, 50, 61, 48, 46, 51, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 73, 110, 112, 117, 116, 32, 51, 100, 32,
  116, 111, 114, 117, 115, 44, 32, 119, 105, 116, 104, 32, 114, 97, 100, 105,
  105, 32, 40, 36, 49, 44, 36, 50, 41, 32, 97, 110, 100, 32, 115, 117,
  98, 100, 105, 118, 105, 115, 105, 111, 110, 115, 32, 40, 36, 51, 44, 36,
  52, 41, 46, 34, 10, 45, 118, 32, 45, 10, 110, 98, 112, 61, 123, 36,
  51, 42, 36, 52, 125, 10, 49, 44, 56, 44, 49, 44, 49, 44, 54, 55,
  46, 53, 44, 55, 51, 46, 53, 44, 49, 48, 57, 46, 53, 44, 49, 48,
  51, 46, 53, 44, 53, 49, 46, 53, 44, 49, 48, 48, 46, 53, 44, 36,
  110, 98, 112, 44, 123, 36, 52, 42, 36, 51, 125, 10, 40, 48, 59, 123,
  50, 42, 112, 105, 125, 41, 32, 45, 45, 121, 91, 45, 49, 93, 32, 120,
  10, 45, 114, 91, 45, 50, 93, 32, 49, 44, 123, 36, 51, 43, 49, 125,
  44, 49, 44, 49, 44, 51, 32, 45, 122, 91, 45, 50, 93, 32, 48, 44,
  48, 44, 48, 44, 123, 36, 51, 45, 49, 125, 10, 45, 114, 91, 45, 49,
  93, 32, 123, 36, 52, 43, 49, 125, 44, 49, 44, 49, 44, 49, 44, 51,
  32, 45, 122, 91, 45, 49, 93, 32, 48, 44, 123, 36, 52, 45, 49, 125,
  10, 45, 45, 115, 105, 110, 91, 45, 50, 44, 45, 49, 93, 32, 45, 99,
  111, 115, 91, 45, 52, 44, 45, 51, 93, 32, 45, 114, 91, 45, 52, 45,
  45, 49, 93, 32, 36, 52, 44, 36, 51, 10, 45, 42, 91, 45, 51, 93,
  32, 36, 50, 32, 45, 43, 91, 45, 51, 93, 32, 36, 49, 32, 45, 42,
  91, 45, 49, 93, 32, 36, 50, 32, 45, 42, 91, 45, 52, 93, 32, 91,
  45, 51, 93, 32, 45, 42, 91, 45, 51, 44, 45, 50, 93, 10, 45, 121,
  91, 45, 51, 45, 45, 49, 93, 32, 45, 97, 91, 45, 51, 45, 45, 49,
  93, 32, 120, 10, 49, 44, 36, 51, 44, 49, 44, 49, 44, 39, 121, 39,
  32, 45, 42, 91, 45, 49, 93, 32, 36, 52, 32, 45, 45, 115, 104, 105,
  102, 116, 91, 45, 49, 93, 32, 48, 44, 45, 49, 32, 36, 52, 44, 49,
  44, 49, 44, 49, 44, 39, 120, 39, 32, 45, 45, 115, 104, 105, 102, 116,
  91, 45, 49, 93, 32, 45, 49, 32, 45, 114, 91, 45, 52, 45, 45, 49,
  93, 32, 36, 52, 44, 36, 51, 10, 45, 45, 43, 91, 45, 52, 44, 45,
  49, 93, 32, 45, 43, 91, 45, 50, 93, 32, 91, 45, 52, 93, 32, 45,
  43, 91, 45, 53, 93, 32, 91, 45, 51, 93, 32, 45, 43, 91, 45, 52,
  44, 45, 51, 93, 32, 45, 121, 91, 45, 52, 45, 45, 49, 93, 32, 45,
  105, 91, 45, 53, 93, 32, 49, 44, 123, 104, 125, 44, 49, 44, 49, 44,
  52, 32, 45, 97, 91, 45, 53, 45, 45, 49, 93, 32, 120, 10, 51, 44,
  123, 104, 125, 44, 49, 44, 49, 44, 50, 48, 48, 32, 49, 44, 123, 104,
  125, 44, 49, 44, 49, 44, 49, 32, 45, 121, 91, 45, 52, 45, 45, 50,
  93, 32, 45, 97, 91, 45, 53, 45, 45, 49, 93, 32, 121, 10, 45, 110,
  109, 91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 116, 111, 114, 117, 115,
  93, 10, 45, 118, 32, 43, 10, 116, 114, 105, 97, 110, 103, 108, 101, 51,
  100, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 112,
  117, 116, 32, 51, 100, 32, 116, 114, 105, 97, 110, 103, 108, 101, 32, 40,
  36, 49, 44, 36, 50, 44, 36, 51, 41, 45, 40, 36, 52, 44, 36, 53,
  44, 36, 54, 41, 45, 40, 36, 55, 44, 36, 56, 44, 36, 57, 41, 46,
  34, 10, 45, 118, 32, 45, 32, 49, 44, 50, 53, 44, 49, 44, 49, 44,
  54, 55, 46, 53, 44, 55, 51, 46, 53, 44, 49, 48, 57, 46, 53, 44,
  49, 48, 51, 46, 53, 44, 53, 49, 46, 53, 44, 49, 48, 48, 46, 53,
  44, 51, 44, 49, 44, 36, 123, 49, 45, 57, 125, 44, 51, 44, 48, 44,
  49, 44, 50, 44, 50, 48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 44,
  49, 32, 45, 110, 109, 91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 116,
  114, 105, 97, 110, 103, 108, 101, 93, 32, 45, 118, 32, 43, 10, 118, 111,
  108, 117, 109, 101, 51, 100, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 84, 114, 97, 110, 115, 102, 111, 114, 109, 32, 105, 109, 97, 103,
  101, 36, 63, 32, 97, 115, 32, 51, 100, 32, 112, 97, 114, 97, 108, 108,
  101, 108, 101, 112, 105, 112, 101, 100, 105, 99, 32, 111, 98, 106, 101, 99,
  116, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 61, 123, 119,
  125, 32, 104, 61, 123, 104, 125, 32, 100, 61, 123, 100, 125, 10, 45, 45,
  115, 108, 105, 99, 101, 115, 32, 48, 32, 45, 45, 115, 108, 105, 99, 101,
  115, 91, 48, 93, 32, 49, 48, 48, 37, 32, 45, 109, 105, 114, 114, 111,
  114, 91, 45, 49, 93, 32, 121, 10, 45, 45, 99, 111, 108, 117, 109, 110,
  115, 91, 48, 93, 32, 48, 32, 45, 45, 99, 111, 108, 117, 109, 110, 115,
  91, 48, 93, 32, 49, 48, 48, 37, 32, 45, 112, 101, 114, 109, 117, 116,
  101, 91, 45, 50, 44, 45, 49, 93, 32, 122, 121, 120, 99, 32, 45, 109,
  105, 114, 114, 111, 114, 91, 45, 50, 93, 32, 120, 10, 45, 45, 114, 111,
  119, 115, 91, 48, 93, 32, 48, 32, 45, 45, 114, 111, 119, 115, 91, 48,
  93, 32, 49, 48, 48, 37, 32, 45, 112, 101, 114, 109, 117, 116, 101, 91,
  45, 50, 44, 45, 49, 93, 32, 120, 122, 121, 99, 32, 45, 109, 105, 114,
  114, 111, 114, 91, 45, 50, 93, 32, 121, 10, 45, 114, 109, 91, 48, 93,
  32, 45, 105, 109, 97, 103, 101, 54, 99, 117, 98, 101, 51, 100, 32, 45,
  42, 51, 100, 32, 36, 119, 44, 36, 104, 44, 36, 100, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 119, 101,
  105, 114, 100, 51, 100, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  49, 61, 51, 50, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73,
  110, 112, 117, 116, 32, 51, 100, 32, 119, 101, 105, 114, 100, 32, 111, 98,
  106, 101, 99, 116, 44, 32, 119, 105, 116, 104, 32, 114, 101, 115, 111, 108,
  117, 116, 105, 111, 110, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 10,
  45, 105, 115, 111, 115, 117, 114, 102, 97, 99, 101, 51, 100, 32, 34, 39,
  92, 10, 84, 32, 61, 32, 49, 46, 54, 49, 56, 48, 51, 51, 57, 57,
  59, 92, 10, 50, 32, 45, 32, 40, 99, 111, 115, 40, 120, 32, 43, 32,
  84, 42, 121, 41, 32, 43, 32, 99, 111, 115, 40, 120, 32, 45, 32, 84,
  42, 121, 41, 32, 43, 32, 99, 111, 115, 40, 121, 32, 43, 32, 84, 42,
  122, 41, 32, 43, 32, 99, 111, 115, 40, 121, 32, 45, 32, 84, 42, 122,
  41, 32, 43, 32, 99, 111, 115, 40, 122, 32, 45, 32, 84, 42, 120, 41,
  32, 43, 32, 99, 111, 115, 40, 122, 32, 43, 32, 84, 42, 120, 41, 41,
  92, 10, 39, 34, 44, 48, 44, 45, 52, 46, 55, 44, 45, 52, 46, 55,
  44, 45, 52, 46, 55, 44, 52, 46, 55, 44, 52, 46, 55, 44, 52, 46,
  55, 44, 36, 49, 44, 36, 49, 44, 36, 49, 10, 45, 99, 51, 100, 91,
  45, 49, 93, 32, 45, 110, 51, 100, 91, 45, 49, 93, 32, 45, 110, 109,
  91, 45, 49, 93, 32, 91, 51, 100, 92, 32, 119, 101, 105, 114, 100, 93,
  10, 45, 118, 32, 43, 10, 97, 112, 112, 108, 121, 95, 112, 97, 114, 97,
  108, 108, 101, 108, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  69, 120, 101, 99, 117, 116, 101, 32, 99, 111, 109, 109, 97, 110, 100, 32,
  39, 36, 42, 39, 32, 111, 110, 32, 97, 108, 108, 32, 105, 109, 97, 103,
  101, 36, 63, 32, 105, 110, 32, 112, 97, 114, 97, 108, 108, 101, 108, 44,
  32, 117, 115, 105, 110, 103, 32, 34, 64, 42, 34, 32, 116, 104, 114, 101,
  97, 100, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 109, 32, 34, 95,
  97, 112, 112, 108, 121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 32, 58,
  32, 36, 42, 34, 32, 78, 61, 64, 35, 10, 45, 108, 91, 93, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 42, 32, 40, 123, 39, 45, 95, 97,
  112, 112, 108, 121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 91, 36, 62,
  93, 39, 125, 41, 32, 45, 100, 111, 110, 101, 32, 45, 105, 102, 32, 123,
  64, 35, 62, 49, 125, 32, 45, 105, 91, 49, 45, 45, 50, 93, 32, 40,
  123, 39, 44, 39, 125, 41, 32, 45, 101, 110, 100, 105, 102, 32, 45, 97,
  32, 120, 32, 97, 114, 103, 48, 61, 64, 123, 45, 49, 44, 116, 125, 32,
  45, 114, 109, 10, 45, 105, 102, 32, 123, 36, 78, 37, 64, 42, 125, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 78, 37, 64, 42, 125, 32,
  40, 123, 39, 45, 95, 97, 112, 112, 108, 121, 95, 112, 97, 114, 97, 108,
  108, 101, 108, 91, 36, 62, 93, 39, 125, 41, 32, 45, 100, 111, 110, 101,
  32, 45, 105, 102, 32, 123, 64, 35, 62, 49, 125, 32, 45, 105, 91, 49,
  45, 45, 50, 93, 32, 40, 123, 39, 44, 39, 125, 41, 32, 45, 101, 110,
  100, 105, 102, 32, 45, 97, 32, 120, 32, 97, 114, 103, 49, 61, 64, 123,
  45, 49, 44, 116, 125, 32, 45, 114, 109, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 108, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  114, 111, 117, 110, 100, 40, 64, 35, 47, 64, 42, 44, 49, 44, 49, 41,
  125, 32, 45, 108, 91, 123, 64, 42, 42, 36, 62, 125, 45, 123, 109, 105,
  110, 40, 64, 42, 42, 36, 62, 43, 64, 42, 45, 49, 44, 64, 35, 45,
  49, 41, 125, 93, 10, 45, 112, 97, 114, 97, 108, 108, 101, 108, 32, 36,
  123, 97, 114, 103, 123, 64, 35, 33, 61, 64, 42, 125, 125, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 117, 110, 99, 111, 109,
  109, 97, 110, 100, 32, 95, 97, 112, 112, 108, 121, 95, 112, 97, 114, 97,
  108, 108, 101, 108, 32, 45, 118, 32, 43, 10, 97, 112, 112, 108, 121, 95,
  112, 97, 114, 97, 108, 108, 101, 108, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 69, 120, 101,
  99, 117, 116, 101, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 42,
  39, 32, 111, 110, 32, 97, 108, 108, 32, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63, 32, 105, 110, 32,
  112, 97, 114, 97, 108, 108, 101, 108, 44, 32, 117, 115, 105, 110, 103, 32,
  34, 64, 42, 34, 32, 116, 104, 114, 101, 97, 100, 115, 46, 34, 10, 45,
  118, 32, 45, 32, 78, 61, 64, 35, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 36, 78, 32, 115, 36, 62, 61, 64, 123, 36, 62, 44, 115, 125, 32,
  45, 100, 111, 110, 101, 32, 45, 115, 32, 99, 10, 45, 97, 112, 112, 108,
  121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 32, 34, 36, 49, 34, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 36, 78, 32, 45, 97, 91, 36, 62,
  45, 123, 36, 62, 43, 36, 123, 115, 36, 62, 125, 45, 49, 125, 93, 32,
  99, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 97, 112, 112,
  108, 121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114,
  108, 97, 112, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123,
  50, 61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116,
  40, 36, 123, 51, 61, 48, 125, 41, 32, 38, 38, 32, 36, 51, 62, 61,
  48, 34, 10, 45, 118, 32, 45, 32, 78, 61, 123, 105, 102, 40, 36, 51,
  44, 109, 97, 120, 40, 49, 44, 114, 111, 117, 110, 100, 40, 36, 51, 41,
  41, 44, 64, 42, 41, 125, 32, 78, 61, 123, 50, 94, 105, 110, 116, 40,
  108, 111, 103, 50, 40, 109, 105, 110, 40, 49, 54, 44, 36, 78, 41, 41,
  41, 125, 32, 45, 118, 32, 43, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 65, 112, 112, 108, 121, 32, 112, 97, 114, 97, 108, 108, 101, 108, 105,
  122, 101, 100, 32, 99, 111, 109, 109, 97, 110, 100, 32, 39, 36, 49, 39,
  32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116,
  104, 32, 111, 118, 101, 114, 108, 97, 112, 32, 36, 50, 32, 97, 110, 100,
  32, 34, 36, 78, 34, 32, 116, 104, 114, 101, 97, 100, 115, 46, 34, 10,
  45, 118, 32, 45, 10, 45, 109, 32, 34, 95, 99, 104, 101, 99, 107, 49,
  32, 58, 32, 45, 105, 102, 32, 123, 64, 35, 33, 61, 49, 125, 32, 45,
  101, 114, 114, 111, 114, 91, 48, 45, 45, 57, 93, 32, 92, 34, 83, 112,
  101, 99, 105, 102, 105, 101, 100, 32, 99, 111, 109, 109, 97, 110, 100, 32,
  39, 36, 49, 39, 32, 99, 104, 97, 110, 103, 101, 115, 32, 116, 104, 101,
  32, 115, 105, 122, 101, 32, 111, 102, 32, 116, 104, 101, 32, 105, 109, 97,
  103, 101, 32, 115, 116, 97, 99, 107, 46, 92, 34, 32, 45, 101, 110, 100,
  105, 102, 34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 95, 97, 112, 112, 108, 121, 95, 112, 97,
  114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 36, 78,
  32, 34, 36, 49, 34, 44, 36, 50, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 45, 117, 110, 99, 111, 109, 109, 97, 110, 100, 32,
  95, 99, 104, 101, 99, 107, 49, 10, 45, 118, 32, 43, 10, 95, 97, 112,
  112, 108, 121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101,
  114, 108, 97, 112, 49, 32, 58, 10, 36, 49, 10, 95, 97, 112, 112, 108,
  121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108,
  97, 112, 50, 32, 58, 10, 45, 105, 102, 32, 123, 119, 62, 61, 104, 125,
  10, 111, 118, 120, 61, 123, 114, 111, 117, 110, 100, 40, 105, 102, 40, 64,
  123, 34, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 32, 36, 50,
  34, 125, 44, 119, 42, 36, 50, 44, 36, 50, 41, 41, 125, 32, 119, 50,
  61, 123, 105, 110, 116, 40, 119, 47, 50, 41, 125, 10, 45, 45, 122, 91,
  48, 93, 32, 123, 36, 119, 50, 45, 36, 111, 118, 120, 125, 44, 49, 48,
  48, 37, 32, 45, 122, 91, 48, 93, 32, 48, 44, 123, 36, 119, 50, 43,
  36, 111, 118, 120, 45, 49, 125, 10, 45, 112, 97, 114, 97, 108, 108, 101,
  108, 32, 34, 45, 108, 91, 48, 93, 32, 36, 49, 32, 45, 95, 99, 104,
  101, 99, 107, 49, 32, 45, 101, 110, 100, 108, 34, 44, 34, 45, 108, 91,
  49, 93, 32, 36, 49, 32, 45, 95, 99, 104, 101, 99, 107, 49, 32, 45,
  101, 110, 100, 108, 34, 10, 45, 122, 91, 48, 93, 32, 48, 44, 64, 123,
  48, 44, 119, 45, 49, 45, 36, 111, 118, 120, 125, 32, 45, 122, 91, 49,
  93, 32, 36, 111, 118, 120, 44, 49, 48, 48, 37, 32, 45, 97, 32, 120,
  10, 45, 101, 108, 115, 101, 10, 111, 118, 121, 61, 123, 114, 111, 117, 110,
  100, 40, 105, 102, 40, 64, 123, 34, 45, 105, 115, 95, 112, 101, 114, 99,
  101, 110, 116, 32, 36, 50, 34, 125, 44, 104, 42, 36, 50, 44, 36, 50,
  41, 41, 125, 32, 104, 50, 61, 123, 105, 110, 116, 40, 104, 47, 50, 41,
  125, 10, 45, 45, 114, 111, 119, 115, 91, 48, 93, 32, 123, 36, 104, 50,
  45, 36, 111, 118, 121, 125, 44, 49, 48, 48, 37, 32, 45, 114, 111, 119,
  115, 91, 48, 93, 32, 48, 44, 123, 36, 104, 50, 43, 36, 111, 118, 121,
  45, 49, 125, 10, 45, 112, 97, 114, 97, 108, 108, 101, 108, 32, 34, 45,
  108, 91, 48, 93, 32, 36, 49, 32, 45, 95, 99, 104, 101, 99, 107, 49,
  32, 45, 101, 110, 100, 108, 34, 44, 34, 45, 108, 91, 49, 93, 32, 36,
  49, 32, 45, 95, 99, 104, 101, 99, 107, 49, 32, 45, 101, 110, 100, 108,
  34, 10, 45, 114, 111, 119, 115, 91, 48, 93, 32, 48, 44, 64, 123, 48,
  44, 104, 45, 49, 45, 36, 111, 118, 121, 125, 32, 45, 114, 111, 119, 115,
  91, 49, 93, 32, 36, 111, 118, 121, 44, 49, 48, 48, 37, 32, 45, 97,
  32, 121, 10, 45, 101, 110, 100, 105, 102, 10, 95, 97, 112, 112, 108, 121,
  95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97,
  112, 52, 32, 58, 10, 45, 105, 102, 32, 123, 109, 97, 120, 40, 119, 44,
  104, 41, 47, 109, 105, 110, 40, 119, 44, 104, 41, 62, 61, 51, 125, 10,
  45, 95, 97, 112, 112, 108, 121, 95, 112, 97, 114, 97, 108, 108, 101, 108,
  95, 111, 118, 101, 114, 108, 97, 112, 50, 32, 34, 45, 95, 97, 112, 112,
  108, 121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114,
  108, 97, 112, 50, 32, 92, 34, 36, 49, 92, 34, 44, 36, 50, 34, 44,
  36, 50, 10, 45, 101, 108, 115, 101, 10, 111, 118, 120, 61, 123, 114, 111,
  117, 110, 100, 40, 105, 102, 40, 64, 123, 34, 45, 105, 115, 95, 112, 101,
  114, 99, 101, 110, 116, 32, 36, 50, 34, 125, 44, 119, 42, 36, 50, 44,
  36, 50, 41, 41, 125, 32, 119, 50, 61, 123, 105, 110, 116, 40, 119, 47,
  50, 41, 125, 10, 111, 118, 121, 61, 123, 114, 111, 117, 110, 100, 40, 105,
  102, 40, 64, 123, 34, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116,
  32, 36, 50, 34, 125, 44, 104, 42, 36, 50, 44, 36, 50, 41, 41, 125,
  32, 104, 50, 61, 123, 105, 110, 116, 40, 104, 47, 50, 41, 125, 10, 45,
  45, 122, 91, 48, 93, 32, 123, 36, 119, 50, 45, 36, 111, 118, 120, 125,
  44, 48, 44, 49, 48, 48, 37, 44, 123, 36, 104, 50, 43, 36, 111, 118,
  121, 45, 49, 125, 32, 45, 45, 122, 91, 48, 93, 32, 48, 44, 123, 36,
  104, 50, 45, 36, 111, 118, 121, 125, 44, 123, 36, 119, 50, 43, 36, 111,
  118, 120, 45, 49, 125, 44, 49, 48, 48, 37, 10, 45, 45, 122, 91, 48,
  93, 32, 123, 36, 119, 50, 45, 36, 111, 118, 120, 125, 44, 123, 36, 104,
  50, 45, 36, 111, 118, 121, 125, 44, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 32, 45, 122, 91, 48, 93, 32, 48, 44, 48, 44, 123, 36, 119, 50,
  43, 36, 111, 118, 120, 45, 49, 125, 44, 123, 36, 104, 50, 43, 36, 111,
  118, 121, 45, 49, 125, 10, 45, 112, 97, 114, 97, 108, 108, 101, 108, 32,
  34, 45, 108, 91, 48, 93, 32, 36, 49, 32, 45, 95, 99, 104, 101, 99,
  107, 49, 32, 45, 101, 110, 100, 108, 34, 44, 34, 45, 108, 91, 49, 93,
  32, 36, 49, 32, 45, 95, 99, 104, 101, 99, 107, 49, 32, 45, 101, 110,
  100, 108, 34, 44, 34, 45, 108, 91, 50, 93, 32, 36, 49, 32, 45, 95,
  99, 104, 101, 99, 107, 49, 32, 45, 101, 110, 100, 108, 34, 44, 34, 45,
  108, 91, 51, 93, 32, 36, 49, 32, 45, 95, 99, 104, 101, 99, 107, 49,
  32, 45, 101, 110, 100, 108, 34, 10, 45, 122, 91, 48, 93, 32, 48, 44,
  48, 44, 64, 123, 48, 44, 119, 45, 49, 45, 36, 111, 118, 120, 125, 44,
  64, 123, 48, 44, 104, 45, 49, 45, 36, 111, 118, 121, 125, 32, 45, 122,
  91, 49, 93, 32, 36, 111, 118, 120, 44, 48, 44, 49, 48, 48, 37, 44,
  64, 123, 49, 44, 104, 45, 49, 45, 36, 111, 118, 121, 125, 10, 45, 122,
  91, 50, 93, 32, 48, 44, 36, 111, 118, 121, 44, 64, 123, 50, 44, 119,
  45, 49, 45, 36, 111, 118, 120, 125, 44, 49, 48, 48, 37, 32, 45, 122,
  91, 51, 93, 32, 36, 111, 118, 120, 44, 36, 111, 118, 121, 44, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 10, 45, 97, 91, 48, 44, 49, 93, 32,
  120, 32, 45, 97, 91, 49, 44, 50, 93, 32, 120, 32, 45, 97, 32, 121,
  10, 45, 101, 110, 100, 105, 102, 10, 95, 97, 112, 112, 108, 121, 95, 112,
  97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 56,
  32, 58, 10, 45, 95, 97, 112, 112, 108, 121, 95, 112, 97, 114, 97, 108,
  108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 50, 32, 34, 45, 95,
  97, 112, 112, 108, 121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111,
  118, 101, 114, 108, 97, 112, 52, 32, 92, 34, 36, 49, 92, 34, 44, 36,
  50, 34, 44, 36, 50, 10, 95, 97, 112, 112, 108, 121, 95, 112, 97, 114,
  97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 49, 54, 32,
  58, 10, 45, 95, 97, 112, 112, 108, 121, 95, 112, 97, 114, 97, 108, 108,
  101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 52, 32, 34, 45, 95, 97,
  112, 112, 108, 121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118,
  101, 114, 108, 97, 112, 52, 32, 92, 34, 36, 49, 92, 34, 44, 36, 50,
  34, 44, 36, 50, 10, 112, 97, 114, 97, 108, 108, 101, 108, 32, 58, 10,
  45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 124, 124, 36, 49, 61, 61,
  49, 124, 124, 36, 49, 61, 61, 50, 125, 32, 45, 101, 91, 48, 45, 45,
  51, 93, 32, 34, 69, 120, 101, 99, 117, 116, 101, 32, 34, 123, 36, 35,
  45, 49, 125, 34, 32, 99, 111, 109, 109, 97, 110, 100, 115, 32, 39, 36,
  123, 50, 45, 45, 49, 125, 39, 32, 105, 110, 32, 112, 97, 114, 97, 108,
  108, 101, 108, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34,
  10, 45, 101, 108, 115, 101, 32, 45, 101, 91, 48, 45, 45, 51, 93, 32,
  34, 69, 120, 101, 99, 117, 116, 101, 32, 34, 36, 35, 34, 32, 99, 111,
  109, 109, 97, 110, 100, 115, 32, 39, 36, 42, 39, 32, 105, 110, 32, 112,
  97, 114, 97, 108, 108, 101, 108, 32, 111, 110, 32, 105, 109, 97, 103, 101,
  36, 63, 46, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45,
  32, 45, 112, 97, 114, 97, 108, 108, 101, 108, 32, 36, 34, 42, 34, 32,
  45, 118, 32, 43, 10, 114, 112, 114, 111, 103, 114, 101, 115, 115, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 34, 34, 125, 10, 45,
  118, 32, 45, 10, 45, 105, 102, 32, 123, 33, 110, 97, 114, 103, 40, 36,
  95, 112, 114, 111, 103, 114, 101, 115, 115, 95, 98, 111, 117, 110, 100, 115,
  41, 125, 32, 95, 112, 114, 111, 103, 114, 101, 115, 115, 95, 98, 111, 117,
  110, 100, 115, 61, 48, 44, 49, 48, 48, 32, 45, 101, 110, 100, 105, 102,
  10, 109, 61, 123, 97, 114, 103, 40, 45, 50, 44, 36, 95, 112, 114, 111,
  103, 114, 101, 115, 115, 95, 98, 111, 117, 110, 100, 115, 41, 125, 32, 77,
  61, 123, 97, 114, 103, 40, 45, 49, 44, 36, 95, 112, 114, 111, 103, 114,
  101, 115, 115, 95, 98, 111, 117, 110, 100, 115, 41, 125, 10, 45, 105, 102,
  32, 123, 36, 35, 61, 61, 50, 38, 38, 33, 110, 97, 114, 103, 40, 36,
  50, 41, 125, 10, 45, 118, 32, 43, 32, 45, 101, 91, 48, 45, 45, 51,
  93, 32, 34, 83, 101, 116, 32, 114, 101, 108, 97, 116, 105, 118, 101, 32,
  112, 114, 111, 103, 114, 101, 115, 115, 32, 105, 110, 100, 105, 99, 101, 32,
  116, 111, 32, 36, 49, 37, 46, 34, 32, 45, 118, 32, 45, 10, 45, 112,
  114, 111, 103, 114, 101, 115, 115, 32, 123, 105, 102, 40, 36, 49, 60, 48,
  44, 45, 49, 44, 109, 105, 110, 40, 49, 48, 48, 44, 109, 97, 120, 40,
  48, 44, 36, 109, 43, 40, 36, 77, 45, 36, 109, 41, 42, 36, 49, 37,
  41, 41, 41, 125, 10, 45, 101, 108, 105, 102, 32, 123, 36, 35, 61, 61,
  51, 125, 10, 110, 109, 61, 123, 109, 105, 110, 40, 36, 50, 44, 36, 45,
  49, 41, 125, 32, 110, 77, 61, 123, 109, 97, 120, 40, 36, 50, 44, 36,
  45, 49, 41, 125, 10, 45, 118, 32, 43, 32, 45, 101, 91, 48, 45, 45,
  51, 93, 32, 34, 67, 97, 108, 108, 32, 99, 111, 109, 109, 97, 110, 100,
  32, 39, 36, 49, 39, 32, 119, 105, 116, 104, 32, 112, 114, 111, 103, 114,
  101, 115, 115, 32, 98, 111, 117, 110, 100, 115, 32, 91, 34, 36, 110, 109,
  44, 36, 110, 77, 34, 93, 46, 34, 32, 45, 118, 32, 45, 10, 45, 112,
  114, 111, 103, 114, 101, 115, 115, 32, 36, 109, 32, 95, 112, 114, 111, 103,
  114, 101, 115, 115, 95, 98, 111, 117, 110, 100, 115, 61, 36, 95, 112, 114,
  111, 103, 114, 101, 115, 115, 95, 98, 111, 117, 110, 100, 115, 44, 123, 36,
  109, 43, 36, 110, 109, 42, 40, 36, 77, 45, 36, 109, 41, 47, 49, 48,
  48, 125, 44, 123, 36, 109, 43, 36, 110, 77, 42, 40, 36, 77, 45, 36,
  109, 41, 47, 49, 48, 48, 125, 10, 45, 95, 114, 112, 114, 111, 103, 114,
  101, 115, 115, 32, 34, 36, 49, 34, 10, 45, 112, 114, 111, 103, 114, 101,
  115, 115, 32, 36, 77, 32, 40, 36, 95, 112, 114, 111, 103, 114, 101, 115,
  115, 95, 98, 111, 117, 110, 100, 115, 41, 32, 95, 112, 114, 111, 103, 114,
  101, 115, 115, 95, 98, 111, 117, 110, 100, 115, 61, 64, 123, 45, 49, 44,
  48, 45, 45, 51, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101,
  108, 115, 101, 32, 45, 101, 114, 114, 111, 114, 91, 48, 45, 45, 51, 93,
  32, 34, 67, 111, 109, 109, 97, 110, 100, 32, 39, 45, 114, 112, 114, 111,
  103, 114, 101, 115, 115, 39, 32, 58, 32, 73, 110, 118, 97, 108, 105, 100,
  32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 39, 36, 42, 39, 46, 34,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 95, 114, 112,
  114, 111, 103, 114, 101, 115, 115, 32, 58, 32, 36, 42, 10, 97, 114, 114,
  97, 121, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105,
  110, 116, 40, 36, 49, 41, 32, 38, 38, 32, 36, 49, 62, 48, 32, 38,
  38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 50, 61, 36, 49, 125, 41,
  32, 38, 38, 32, 36, 50, 62, 48, 34, 32, 45, 115, 107, 105, 112, 32,
  36, 123, 51, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  67, 114, 101, 97, 116, 101, 32, 36, 49, 120, 36, 50, 32, 97, 114, 114,
  97, 121, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 119, 105, 116, 104, 32, 101, 120, 112, 97, 110, 100, 32, 116, 121, 112,
  101, 32, 36, 51, 46, 34, 10, 45, 118, 32, 45, 32, 114, 48, 61, 123,
  49, 48, 48, 47, 109, 97, 120, 40, 36, 49, 44, 36, 50, 41, 125, 32,
  114, 49, 61, 123, 49, 48, 48, 47, 109, 105, 110, 40, 36, 49, 44, 36,
  50, 41, 125, 32, 114, 50, 61, 49, 48, 48, 10, 45, 114, 32, 36, 123,
  114, 36, 51, 125, 37, 44, 36, 123, 114, 36, 51, 125, 37, 44, 49, 44,
  49, 48, 48, 37, 44, 50, 32, 45, 114, 32, 123, 36, 49, 42, 49, 48,
  48, 125, 37, 44, 123, 36, 50, 42, 49, 48, 48, 125, 37, 44, 49, 44,
  49, 48, 48, 37, 44, 48, 44, 50, 32, 45, 118, 32, 43, 10, 97, 114,
  114, 97, 121, 95, 102, 97, 100, 101, 32, 58, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 50, 61, 36, 49, 125, 44, 36, 123, 51, 61, 54, 48, 125,
  44, 36, 123, 52, 61, 57, 48, 125, 44, 36, 123, 53, 61, 49, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 114, 101, 97, 116, 101, 32,
  36, 49, 120, 36, 50, 32, 97, 114, 114, 97, 121, 32, 111, 102, 32, 40,
  36, 51, 37, 44, 36, 52, 37, 41, 32, 102, 97, 100, 101, 100, 32, 116,
  105, 108, 101, 115, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 119, 105, 116, 104, 32, 101, 120, 112, 97, 110, 100, 32, 116,
  121, 112, 101, 32, 36, 53, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32,
  91, 45, 49, 93, 32, 45, 115, 104, 105, 102, 116, 91, 45, 50, 93, 32,
  53, 48, 37, 44, 53, 48, 37, 44, 49, 44, 49, 44, 50, 32, 45, 102,
  97, 100, 101, 95, 100, 105, 97, 109, 111, 110, 100, 32, 36, 51, 44, 36,
  52, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 97,
  114, 114, 97, 121, 32, 36, 49, 44, 36, 50, 44, 36, 53, 10, 45, 118,
  32, 43, 10, 97, 114, 114, 97, 121, 95, 109, 105, 114, 114, 111, 114, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 50, 125, 44, 36,
  123, 51, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67,
  114, 101, 97, 116, 101, 32, 97, 32, 50, 94, 36, 49, 120, 50, 94, 36,
  49, 32, 109, 105, 114, 114, 111, 114, 101, 100, 45, 97, 114, 114, 97, 121,
  32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119,
  105, 116, 104, 32, 101, 120, 112, 97, 110, 100, 32, 116, 121, 112, 101, 32,
  36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 36, 49, 10, 45, 105, 102, 32, 123, 36, 51, 61, 61, 48, 125,
  10, 45, 105, 102, 32, 123, 36, 50, 62, 61, 51, 125, 32, 45, 114, 32,
  51, 51, 37, 44, 51, 51, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 44, 50, 10, 45, 101, 108, 115, 101, 32, 45, 114, 32, 53, 48, 37,
  44, 53, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 50,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 105, 102, 32, 123, 36, 50, 61, 61, 48, 125, 32, 45, 45, 109,
  105, 114, 114, 111, 114, 32, 120, 32, 45, 97, 32, 120, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 50, 61, 61, 49, 125, 32, 45, 45, 109, 105, 114,
  114, 111, 114, 32, 121, 32, 45, 97, 32, 121, 10, 45, 101, 108, 115, 101,
  32, 45, 45, 109, 105, 114, 114, 111, 114, 32, 120, 32, 45, 97, 32, 120,
  32, 45, 45, 109, 105, 114, 114, 111, 114, 32, 121, 32, 45, 97, 32, 121,
  32, 45, 105, 102, 32, 123, 36, 50, 61, 61, 51, 125, 32, 45, 114, 32,
  49, 53, 48, 37, 44, 49, 53, 48, 37, 44, 49, 44, 49, 48, 48, 37,
  44, 48, 44, 50, 44, 49, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 97, 114,
  114, 97, 121, 95, 114, 97, 110, 100, 111, 109, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 50, 61, 36, 49, 125, 44, 36, 123, 51, 61, 36,
  49, 125, 44, 36, 123, 52, 61, 36, 50, 125, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 67, 114, 101, 97, 116, 101, 32, 36, 51, 120, 36, 52,
  32, 97, 114, 114, 97, 121, 32, 111, 102, 32, 116, 105, 108, 101, 115, 32,
  102, 114, 111, 109, 32, 36, 49, 120, 36, 50, 32, 97, 114, 114, 97, 121,
  36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64,
  123, 48, 44, 110, 125, 10, 45, 115, 112, 108, 105, 116, 95, 116, 105, 108,
  101, 115, 32, 36, 49, 44, 36, 50, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 36, 51, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 52, 32, 91,
  123, 63, 40, 36, 49, 42, 36, 50, 45, 49, 41, 125, 93, 32, 45, 100,
  111, 110, 101, 32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 48, 45,
  123, 36, 49, 42, 36, 50, 45, 49, 125, 93, 32, 45, 97, 112, 112, 101,
  110, 100, 95, 116, 105, 108, 101, 115, 32, 36, 51, 44, 36, 52, 10, 45,
  110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 102, 114, 97, 109, 101, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48, 32,
  38, 38, 32, 36, 123, 50, 61, 36, 49, 125, 62, 61, 48, 34, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 51, 61, 50, 53, 53, 125, 44, 36, 123,
  52, 61, 36, 51, 125, 44, 36, 123, 53, 61, 36, 52, 125, 44, 36, 123,
  54, 61, 50, 53, 53, 125, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61,
  34, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 102, 114, 97, 109, 101,
  95, 120, 121, 32, 36, 123, 49, 45, 45, 49, 125, 10, 102, 114, 97, 109,
  101, 95, 98, 108, 117, 114, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 49, 61, 49, 48, 125, 44, 36, 123, 50, 61, 51, 48, 125, 44, 36,
  123, 51, 61, 48, 125, 44, 36, 123, 52, 61, 49, 125, 44, 36, 123, 53,
  61, 51, 37, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 114,
  97, 119, 32, 114, 111, 117, 110, 100, 32, 102, 114, 97, 109, 101, 32, 111,
  110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32,
  115, 104, 97, 114, 112, 110, 101, 115, 115, 32, 36, 49, 44, 32, 115, 105,
  122, 101, 32, 36, 50, 44, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 36, 51, 44, 32, 115, 104, 97, 100, 105, 110, 103, 32, 36, 52,
  32, 97, 110, 100, 32, 98, 108, 117, 114, 32, 36, 53, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110,
  109, 61, 64, 123, 48, 44, 110, 125, 10, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 44, 49, 44, 34, 45, 40, 97, 98, 115, 40, 120, 47,
  119, 45, 48, 46, 53, 41, 94, 36, 49, 32, 43, 32, 97, 98, 115, 40,
  121, 47, 104, 45, 48, 46, 53, 41, 94, 36, 49, 41, 94, 40, 49, 47,
  36, 49, 41, 34, 32, 45, 103, 101, 91, 45, 49, 93, 32, 36, 50, 37,
  10, 45, 105, 102, 32, 36, 52, 32, 45, 100, 105, 115, 116, 97, 110, 99,
  101, 91, 45, 49, 93, 32, 49, 32, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 49, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 43, 91,
  45, 49, 93, 32, 49, 32, 45, 94, 91, 45, 49, 93, 32, 123, 49, 47,
  36, 52, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 98, 91, 45, 49,
  93, 32, 36, 51, 32, 45, 45, 98, 91, 45, 50, 93, 32, 36, 53, 32,
  45, 109, 118, 91, 45, 49, 93, 32, 45, 51, 32, 45, 98, 108, 101, 110,
  100, 95, 102, 97, 100, 101, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 102, 114, 97, 109, 101, 95, 99, 117, 98, 101, 32, 58, 32, 45,
  99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 49, 125, 62, 61, 48,
  34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 48, 125, 44, 36,
  123, 51, 61, 48, 125, 44, 36, 123, 52, 61, 48, 125, 44, 36, 123, 53,
  61, 48, 125, 44, 36, 123, 54, 61, 48, 125, 44, 36, 123, 55, 61, 48,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 115, 101, 114,
  116, 32, 51, 100, 32, 102, 114, 97, 109, 101, 32, 105, 110, 32, 105, 109,
  97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 100, 101, 112, 116,
  104, 32, 36, 49, 44, 32, 99, 101, 110, 116, 101, 114, 32, 40, 36, 50,
  44, 36, 51, 41, 32, 97, 110, 100, 32, 111, 114, 105, 101, 110, 116, 97,
  116, 105, 111, 110, 115, 32, 40, 36, 123, 52, 45, 45, 49, 125, 41, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44,
  110, 125, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116,
  121, 10, 45, 105, 102, 32, 123, 64, 35, 61, 61, 50, 125, 32, 45, 102,
  114, 97, 109, 101, 95, 99, 117, 98, 101, 32, 36, 123, 49, 45, 45, 49,
  125, 32, 45, 97, 32, 99, 10, 45, 101, 108, 115, 101, 10, 109, 61, 123,
  109, 97, 120, 40, 119, 44, 104, 41, 125, 32, 119, 61, 123, 119, 125, 32,
  104, 61, 123, 104, 125, 32, 115, 61, 123, 115, 125, 10, 45, 105, 109, 97,
  103, 101, 112, 108, 97, 110, 101, 51, 100, 32, 45, 99, 51, 100, 32, 45,
  47, 51, 100, 91, 45, 49, 93, 32, 36, 119, 44, 36, 104, 44, 49, 10,
  45, 45, 95, 102, 114, 97, 109, 101, 95, 99, 117, 98, 101, 91, 48, 93,
  32, 36, 52, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 49,
  44, 48, 44, 57, 48, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 45,
  48, 46, 53, 44, 48, 44, 45, 48, 46, 53, 10, 45, 45, 95, 102, 114,
  97, 109, 101, 95, 99, 117, 98, 101, 91, 48, 93, 32, 36, 53, 32, 45,
  114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 49, 44, 48, 44, 45, 57,
  48, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 48, 46, 53, 44, 48,
  44, 45, 48, 46, 53, 10, 45, 45, 95, 102, 114, 97, 109, 101, 95, 99,
  117, 98, 101, 91, 48, 93, 32, 36, 54, 32, 45, 114, 51, 100, 91, 45,
  49, 93, 32, 49, 44, 48, 44, 48, 44, 57, 48, 32, 45, 43, 51, 100,
  91, 45, 49, 93, 32, 48, 44, 48, 46, 53, 44, 45, 48, 46, 53, 10,
  45, 45, 95, 102, 114, 97, 109, 101, 95, 99, 117, 98, 101, 91, 48, 93,
  32, 36, 55, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 49, 44, 48,
  44, 48, 44, 45, 57, 48, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32,
  48, 44, 45, 48, 46, 53, 44, 45, 48, 46, 53, 10, 45, 43, 51, 100,
  32, 48, 44, 48, 44, 49, 32, 45, 43, 51, 100, 32, 45, 42, 51, 100,
  32, 36, 119, 44, 36, 104, 44, 36, 109, 10, 102, 61, 49, 48, 48, 48,
  10, 99, 120, 61, 36, 50, 42, 36, 119, 47, 50, 42, 40, 36, 102, 43,
  36, 109, 42, 36, 49, 41, 47, 36, 102, 10, 99, 121, 61, 36, 51, 42,
  36, 104, 47, 50, 42, 40, 36, 102, 43, 36, 109, 42, 36, 49, 41, 47,
  36, 102, 10, 45, 115, 51, 100, 32, 45, 114, 91, 50, 93, 32, 51, 44,
  123, 64, 123, 50, 44, 104, 125, 47, 51, 125, 44, 49, 44, 49, 44, 45,
  49, 10, 45, 102, 91, 50, 93, 32, 34, 105, 102, 40, 105, 40, 50, 44,
  121, 41, 60, 48, 46, 53, 44, 105, 44, 105, 43, 105, 102, 40, 120, 61,
  61, 48, 44, 34, 36, 99, 120, 34, 44, 105, 102, 40, 120, 61, 61, 49,
  44, 34, 36, 99, 121, 34, 44, 40, 36, 49, 45, 49, 41, 42, 34, 36,
  109, 34, 41, 41, 41, 34, 10, 45, 121, 91, 50, 93, 32, 45, 97, 32,
  121, 10, 45, 42, 51, 100, 32, 50, 32, 123, 50, 42, 36, 119, 125, 44,
  123, 50, 42, 36, 104, 125, 44, 49, 44, 36, 115, 32, 45, 102, 51, 100,
  32, 123, 50, 42, 36, 102, 125, 10, 45, 111, 98, 106, 101, 99, 116, 51,
  100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 53, 48, 37, 44, 53,
  48, 37, 44, 48, 44, 49, 44, 50, 44, 48, 44, 48, 32, 45, 114, 109,
  91, 45, 50, 93, 10, 45, 114, 32, 36, 119, 44, 36, 104, 44, 49, 44,
  49, 48, 48, 37, 44, 50, 10, 45, 101, 110, 100, 105, 102, 10, 45, 110,
  109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 45, 118, 32, 43, 10, 95, 102, 114, 97, 109, 101, 95,
  99, 117, 98, 101, 32, 58, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61,
  49, 125, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 49, 44,
  48, 44, 49, 56, 48, 32, 45, 114, 118, 51, 100, 91, 45, 49, 93, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 50, 125, 32, 45, 114,
  51, 100, 91, 45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 49, 56, 48,
  32, 45, 114, 118, 51, 100, 91, 45, 49, 93, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 61, 61, 51, 125, 32, 45, 114, 51, 100, 91, 45, 49,
  93, 32, 48, 44, 48, 44, 49, 44, 49, 56, 48, 10, 45, 101, 110, 100,
  105, 102, 10, 102, 114, 97, 109, 101, 95, 102, 117, 122, 122, 121, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 36, 49, 125, 44, 36,
  123, 51, 61, 53, 125, 44, 36, 123, 52, 61, 49, 125, 44, 36, 123, 53,
  61, 50, 53, 53, 125, 44, 36, 123, 54, 61, 36, 53, 125, 44, 36, 123,
  55, 61, 36, 54, 125, 44, 36, 123, 56, 61, 50, 53, 53, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 68, 114, 97, 119, 32, 36, 49, 120,
  36, 50, 32, 102, 117, 122, 122, 121, 32, 102, 114, 97, 109, 101, 32, 111,
  110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32,
  102, 117, 122, 122, 121, 110, 101, 115, 115, 32, 36, 51, 44, 32, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 52, 32, 97, 110, 100, 32,
  82, 71, 66, 65, 32, 99, 111, 108, 111, 114, 32, 40, 36, 53, 44, 36,
  54, 44, 36, 55, 44, 36, 56, 41, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123,
  48, 44, 110, 125, 10, 45, 105, 91, 48, 93, 32, 40, 36, 49, 59, 36,
  50, 41, 32, 45, 42, 91, 48, 93, 32, 50, 32, 40, 36, 53, 94, 36,
  54, 94, 36, 55, 94, 36, 56, 41, 32, 45, 114, 91, 45, 49, 93, 32,
  91, 45, 50, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 10, 45,
  114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48, 44,
  48, 44, 49, 48, 48, 37, 44, 64, 123, 48, 44, 49, 125, 44, 49, 44,
  49, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93,
  32, 48, 44, 48, 44, 64, 123, 48, 44, 48, 125, 44, 49, 48, 48, 37,
  44, 49, 44, 49, 10, 45, 114, 109, 91, 48, 93, 32, 45, 115, 104, 105,
  102, 116, 91, 45, 49, 93, 32, 45, 36, 49, 44, 45, 36, 50, 44, 48,
  44, 48, 44, 50, 32, 45, 115, 112, 114, 101, 97, 100, 91, 45, 49, 93,
  32, 36, 51, 32, 45, 98, 91, 45, 49, 93, 32, 36, 52, 32, 45, 95,
  102, 97, 100, 101, 32, 53, 48, 44, 56, 48, 10, 45, 110, 109, 32, 36,
  110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 102, 114, 97, 109, 101, 95, 112, 97, 105, 110,
  116, 105, 110, 103, 32, 58, 10, 45, 99, 104, 101, 99, 107, 32, 34, 36,
  123, 49, 61, 49, 48, 37, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123,
  50, 61, 48, 46, 52, 125, 62, 61, 48, 32, 38, 38, 32, 36, 50, 60,
  61, 49, 32, 38, 38, 32, 36, 123, 51, 61, 54, 37, 125, 62, 61, 48,
  32, 38, 38, 32, 36, 123, 55, 61, 50, 37, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 123, 56, 61, 52, 48, 48, 125, 62, 61, 48, 32, 38, 38,
  32, 36, 123, 57, 61, 53, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36,
  123, 49, 48, 61, 49, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 49,
  48, 60, 61, 49, 48, 48, 32, 38, 38, 32, 36, 123, 49, 49, 61, 49,
  125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 49, 50, 61, 48, 46, 53,
  37, 125, 62, 61, 48, 34, 10, 45, 115, 107, 105, 112, 32, 36, 123, 52,
  61, 50, 50, 53, 125, 44, 36, 123, 53, 61, 50, 48, 48, 125, 44, 36,
  123, 54, 61, 49, 50, 48, 125, 44, 36, 123, 49, 51, 61, 49, 50, 51,
  52, 53, 54, 55, 56, 57, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 65, 100, 100, 32, 112, 97, 105, 110, 116, 105, 110, 103, 32, 102, 114,
  97, 109, 101, 32, 116, 111, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32,
  119, 105, 116, 104, 32, 115, 105, 122, 101, 32, 36, 49, 44, 32, 99, 111,
  110, 116, 114, 97, 115, 116, 32, 36, 50, 44, 32, 112, 114, 111, 102, 105,
  108, 101, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 51,
  44, 32, 99, 111, 108, 111, 114, 32, 40, 36, 123, 52, 45, 54, 125, 41,
  44, 32, 118, 105, 103, 110, 101, 116, 116, 101, 32, 115, 105, 122, 101, 32,
  36, 55, 44, 32, 34, 92, 10, 34, 118, 105, 103, 110, 101, 116, 116, 101,
  32, 115, 116, 114, 101, 110, 103, 116, 104, 32, 36, 56, 44, 32, 100, 101,
  102, 101, 99, 116, 115, 32, 99, 111, 110, 116, 114, 97, 115, 116, 32, 36,
  57, 44, 32, 100, 101, 102, 101, 99, 116, 115, 32, 100, 101, 110, 115, 105,
  116, 121, 32, 36, 49, 48, 44, 32, 100, 101, 102, 101, 99, 116, 115, 32,
  115, 105, 122, 101, 32, 36, 49, 49, 44, 32, 100, 101, 102, 101, 99, 116,
  115, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 49, 50,
  32, 97, 110, 100, 32, 115, 101, 114, 105, 97, 108, 32, 110, 117, 109, 98,
  101, 114, 32, 36, 49, 51, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  45, 105, 102, 32, 123, 33, 36, 49, 125, 32, 45, 114, 101, 116, 117, 114,
  110, 32, 45, 101, 110, 100, 105, 102, 10, 36, 49, 44, 36, 49, 32, 115,
  61, 123, 109, 97, 120, 40, 119, 44, 104, 41, 125, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 40, 123, 39, 64, 123, 45, 100, 101, 99, 50, 98, 105,
  110, 92, 32, 36, 49, 51, 125, 39, 125, 41, 32, 45, 45, 91, 45, 49,
  93, 32, 123, 39, 48, 39, 125, 32, 45, 114, 91, 45, 49, 93, 32, 36,
  115, 10, 45, 116, 114, 97, 110, 115, 112, 111, 115, 101, 91, 45, 49, 93,
  32, 45, 98, 91, 45, 49, 93, 32, 36, 51, 32, 45, 110, 91, 45, 49,
  93, 32, 123, 49, 45, 36, 50, 125, 44, 123, 49, 43, 36, 50, 125, 10,
  45, 45, 114, 91, 45, 49, 93, 32, 123, 64, 123, 45, 50, 44, 119, 125,
  43, 50, 42, 36, 115, 125, 44, 49, 48, 48, 37, 44, 49, 44, 49, 10,
  45, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 121, 10, 45,
  109, 118, 91, 45, 51, 93, 32, 64, 35, 32, 45, 116, 114, 97, 110, 115,
  112, 111, 115, 101, 91, 45, 49, 93, 32, 45, 114, 91, 45, 49, 93, 32,
  49, 48, 48, 37, 44, 123, 64, 123, 45, 52, 44, 104, 125, 43, 50, 42,
  36, 115, 125, 44, 49, 44, 49, 10, 45, 45, 109, 105, 114, 114, 111, 114,
  91, 45, 49, 93, 32, 120, 10, 91, 45, 51, 93, 44, 91, 45, 51, 93,
  44, 49, 44, 49, 44, 49, 32, 45, 112, 111, 108, 121, 103, 111, 110, 91,
  45, 49, 93, 32, 51, 44, 48, 44, 48, 44, 123, 36, 115, 45, 49, 125,
  44, 123, 36, 115, 45, 49, 125, 44, 48, 44, 123, 36, 115, 45, 49, 125,
  44, 49, 44, 48, 32, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49,
  93, 32, 51, 44, 49, 48, 48, 37, 44, 48, 44, 123, 119, 45, 36, 115,
  125, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 49, 44, 48, 10, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 49,
  44, 49, 44, 49, 32, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49,
  93, 32, 51, 44, 49, 44, 48, 44, 49, 48, 48, 37, 44, 123, 36, 115,
  45, 50, 125, 44, 49, 48, 48, 37, 44, 48, 32, 45, 112, 111, 108, 121,
  103, 111, 110, 91, 45, 49, 93, 32, 51, 44, 49, 44, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 123, 104, 45, 36, 115, 43, 49, 125, 44, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 48, 10, 45, 95, 102,
  114, 97, 109, 101, 95, 112, 97, 105, 110, 116, 105, 110, 103, 91, 45, 54,
  45, 45, 51, 93, 32, 36, 123, 52, 45, 54, 125, 44, 36, 123, 57, 45,
  49, 50, 125, 10, 123, 64, 123, 45, 55, 44, 119, 125, 43, 50, 42, 36,
  115, 125, 44, 123, 64, 123, 45, 55, 44, 104, 125, 43, 50, 42, 36, 115,
  125, 44, 49, 44, 51, 10, 45, 106, 91, 45, 49, 93, 32, 91, 45, 55,
  93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 51, 93,
  44, 49, 32, 45, 114, 109, 91, 45, 55, 93, 32, 45, 109, 105, 114, 114,
  111, 114, 91, 45, 51, 93, 32, 121, 10, 45, 106, 91, 45, 49, 93, 32,
  91, 45, 54, 93, 44, 48, 44, 123, 104, 45, 36, 115, 125, 44, 48, 44,
  48, 44, 49, 44, 91, 45, 51, 93, 44, 49, 32, 45, 114, 109, 91, 45,
  54, 44, 45, 51, 93, 10, 45, 106, 91, 45, 49, 93, 32, 91, 45, 52,
  93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 50, 93,
  44, 49, 32, 45, 114, 109, 91, 45, 52, 93, 32, 45, 109, 105, 114, 114,
  111, 114, 91, 45, 50, 93, 32, 120, 10, 45, 106, 91, 45, 49, 93, 32,
  91, 45, 51, 93, 44, 123, 119, 45, 36, 115, 125, 44, 48, 44, 48, 44,
  48, 44, 49, 44, 91, 45, 50, 93, 44, 49, 32, 45, 114, 109, 91, 45,
  51, 44, 45, 50, 93, 10, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44,
  49, 44, 49, 44, 45, 50, 53, 53, 32, 45, 114, 91, 45, 49, 93, 32,
  91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 49, 44, 48, 44,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 43, 91, 45, 49, 93,
  32, 50, 53, 53, 32, 45, 45, 98, 91, 45, 49, 93, 32, 36, 55, 32,
  45, 110, 91, 45, 49, 93, 32, 48, 44, 36, 56, 32, 45, 109, 97, 120,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 99, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 10, 45, 97, 91, 45, 50, 45, 45, 49, 93, 32, 99,
  10, 45, 114, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 91, 45, 49,
  93, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44, 48, 44, 48, 46, 53,
  44, 48, 46, 53, 32, 45, 98, 108, 101, 110, 100, 32, 97, 108, 112, 104,
  97, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 95, 102, 114, 97, 109, 101, 95, 112, 97, 105, 110, 116, 105,
  110, 103, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 45, 42, 91, 45, 49, 93, 32, 36,
  50, 32, 45, 45, 42, 91, 45, 50, 93, 32, 36, 51, 32, 45, 42, 91,
  45, 51, 93, 32, 36, 49, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93,
  32, 99, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 10, 105, 61, 48,
  32, 45, 100, 111, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48,
  44, 49, 32, 45, 114, 101, 109, 111, 118, 101, 95, 112, 105, 120, 101, 108,
  115, 91, 45, 49, 93, 32, 123, 49, 48, 48, 45, 36, 53, 125, 32, 45,
  98, 91, 45, 49, 93, 32, 36, 54, 32, 45, 103, 101, 91, 45, 49, 93,
  32, 53, 48, 37, 32, 105, 61, 123, 36, 105, 43, 49, 125, 32, 45, 119,
  104, 105, 108, 101, 32, 123, 34, 109, 61, 36, 53, 47, 50, 48, 48, 59,
  40, 105, 97, 60, 109, 45, 48, 46, 50, 32, 124, 124, 32, 105, 97, 62,
  109, 43, 48, 46, 50, 41, 32, 38, 38, 32, 34, 36, 105, 34, 60, 49,
  48, 34, 125, 10, 45, 98, 91, 45, 49, 93, 32, 36, 55, 32, 45, 103,
  91, 45, 49, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  110, 91, 45, 49, 93, 32, 45, 36, 52, 44, 36, 52, 10, 45, 43, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  102, 114, 97, 109, 101, 95, 112, 97, 116, 116, 101, 114, 110, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 36, 49, 62, 61, 51, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 50, 61, 48, 125, 44, 36, 123, 51, 61, 48, 125,
  10, 45, 118, 32, 45, 32, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109,
  111, 100, 101, 32, 48, 10, 45, 105, 102, 32, 123, 64, 35, 61, 61, 49,
  124, 124, 36, 50, 125, 10, 45, 118, 32, 43, 32, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 73, 110, 115, 101, 114, 116, 32, 36, 49, 120, 36, 49,
  32, 115, 101, 108, 102, 45, 112, 97, 116, 116, 101, 114, 110, 32, 102, 114,
  97, 109, 101, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34,
  32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 119, 104, 61, 123, 119, 125, 44, 123,
  104, 125, 10, 45, 45, 114, 32, 123, 119, 47, 40, 36, 49, 45, 50, 41,
  125, 44, 123, 104, 47, 40, 36, 49, 45, 50, 41, 125, 44, 49, 44, 49,
  48, 48, 37, 44, 50, 32, 45, 114, 91, 45, 50, 93, 32, 123, 36, 49,
  42, 119, 125, 44, 123, 36, 49, 42, 104, 125, 44, 49, 44, 49, 48, 48,
  37, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 91, 45,
  49, 93, 120, 123, 36, 49, 43, 50, 125, 32, 45, 97, 91, 123, 45, 36,
  49, 45, 50, 125, 45, 45, 49, 93, 32, 120, 32, 45, 106, 91, 45, 51,
  93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 32, 45, 106, 91, 45, 51,
  93, 32, 91, 45, 49, 93, 44, 48, 44, 123, 64, 123, 45, 51, 44, 104,
  125, 45, 49, 45, 104, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 91,
  45, 49, 93, 120, 123, 36, 49, 43, 49, 125, 32, 45, 97, 91, 123, 45,
  36, 49, 45, 50, 125, 45, 45, 49, 93, 32, 121, 32, 45, 106, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 32, 45, 106, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 44, 123, 64, 123, 45, 50, 44, 119, 125,
  45, 49, 45, 119, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 105,
  102, 32, 36, 51, 32, 45, 114, 32, 36, 119, 104, 44, 49, 44, 49, 48,
  48, 37, 44, 50, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 115, 101, 10, 45, 118,
  32, 43, 32, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110, 115, 101,
  114, 116, 32, 36, 49, 120, 36, 49, 32, 112, 97, 116, 116, 101, 114, 110,
  32, 102, 114, 97, 109, 101, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 117, 115, 105, 110, 103, 32, 102, 105, 114, 115, 116, 32, 105,
  109, 97, 103, 101, 46, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 10, 119, 104, 61, 123, 119,
  125, 44, 123, 104, 125, 10, 45, 45, 114, 91, 48, 93, 32, 123, 119, 47,
  40, 36, 49, 45, 50, 41, 125, 44, 123, 104, 47, 40, 36, 49, 45, 50,
  41, 125, 44, 49, 44, 49, 48, 48, 37, 44, 50, 10, 45, 114, 91, 45,
  50, 93, 32, 123, 64, 123, 45, 50, 44, 119, 125, 43, 50, 42, 119, 125,
  44, 123, 64, 123, 45, 50, 44, 104, 125, 43, 50, 42, 104, 125, 44, 49,
  44, 49, 48, 48, 37, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46,
  53, 10, 91, 45, 49, 93, 120, 123, 36, 49, 43, 50, 125, 32, 45, 97,
  91, 123, 45, 36, 49, 45, 50, 125, 45, 45, 49, 93, 32, 120, 32, 45,
  106, 91, 45, 51, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 32, 45,
  106, 91, 45, 51, 93, 32, 91, 45, 49, 93, 44, 48, 44, 123, 64, 123,
  45, 51, 44, 104, 125, 45, 49, 45, 104, 125, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 91, 45, 49, 93, 120, 123, 36, 49, 43, 49, 125, 32, 45,
  97, 91, 123, 45, 36, 49, 45, 50, 125, 45, 45, 49, 93, 32, 121, 32,
  45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 32,
  45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 123, 64, 123, 45,
  50, 44, 119, 125, 45, 49, 45, 119, 125, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 105, 102, 32, 36, 51, 32, 45, 114, 91, 45, 49, 93, 32,
  36, 119, 104, 44, 49, 44, 49, 48, 48, 37, 44, 50, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 109, 118, 91, 45, 49, 93, 32, 49, 32, 45, 100,
  111, 110, 101, 32, 45, 114, 109, 91, 48, 93, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 118, 32, 43, 10, 102, 114, 97, 109, 101, 95, 114, 111, 117,
  110, 100, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49,
  48, 125, 44, 36, 123, 50, 61, 49, 48, 125, 44, 36, 123, 51, 61, 48,
  125, 44, 36, 123, 52, 61, 48, 125, 44, 36, 123, 53, 61, 50, 53, 53,
  125, 44, 36, 123, 54, 61, 36, 53, 125, 44, 36, 123, 55, 61, 36, 54,
  125, 44, 36, 123, 56, 61, 50, 53, 53, 125, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 68, 114, 97, 119, 32, 114, 111, 117, 110, 100, 32, 102,
  114, 97, 109, 101, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 119, 105, 116, 104, 32, 115, 104, 97, 114, 112, 110, 101, 115, 115, 32,
  36, 49, 44, 32, 115, 105, 122, 101, 32, 36, 50, 44, 32, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 36, 51, 44, 32, 115, 104, 97, 100,
  105, 110, 103, 32, 36, 52, 32, 97, 110, 100, 32, 82, 71, 66, 65, 32,
  99, 111, 108, 111, 114, 32, 40, 36, 53, 44, 36, 54, 44, 36, 55, 44,
  36, 56, 41, 46, 34, 10, 45, 118, 32, 45, 32, 45, 116, 111, 95, 114,
  103, 98, 97, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125, 10,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 34, 45,
  40, 97, 98, 115, 40, 120, 47, 119, 45, 48, 46, 53, 41, 94, 36, 49,
  32, 43, 32, 97, 98, 115, 40, 121, 47, 104, 45, 48, 46, 53, 41, 94,
  36, 49, 41, 94, 40, 49, 47, 36, 49, 41, 34, 32, 45, 103, 101, 91,
  45, 49, 93, 32, 36, 50, 37, 10, 45, 105, 102, 32, 36, 52, 32, 45,
  100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45,
  110, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 42, 91, 45, 49, 93,
  32, 45, 49, 32, 45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 94, 91,
  45, 49, 93, 32, 123, 49, 47, 36, 52, 125, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 98, 91, 45, 49, 93, 32, 36, 51, 32, 45, 105, 91, 45,
  51, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 52,
  32, 45, 102, 99, 91, 45, 51, 93, 32, 36, 53, 44, 36, 54, 44, 36,
  55, 44, 36, 56, 32, 45, 98, 108, 101, 110, 100, 95, 102, 97, 100, 101,
  10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 102, 114, 97, 109,
  101, 95, 120, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49,
  62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 50,
  53, 53, 125, 44, 36, 123, 51, 61, 36, 50, 125, 44, 36, 123, 52, 61,
  36, 51, 125, 44, 36, 123, 53, 61, 50, 53, 53, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 73, 110, 115, 101, 114, 116, 32, 36, 49, 32,
  111, 117, 116, 101, 114, 32, 102, 114, 97, 109, 101, 32, 105, 110, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101,
  32, 120, 45, 97, 120, 105, 115, 44, 32, 119, 105, 116, 104, 32, 99, 111,
  108, 111, 114, 32, 40, 36, 123, 50, 45, 45, 49, 125, 41, 46, 34, 10,
  45, 95, 102, 114, 97, 109, 101, 32, 36, 49, 44, 48, 44, 48, 44, 36,
  123, 50, 45, 45, 49, 125, 10, 102, 114, 97, 109, 101, 95, 120, 121, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48, 32,
  38, 38, 32, 36, 123, 50, 61, 36, 49, 125, 62, 61, 48, 34, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 51, 61, 50, 53, 53, 125, 44, 36, 123,
  52, 61, 36, 51, 125, 44, 36, 123, 53, 61, 36, 52, 125, 44, 36, 123,
  54, 61, 50, 53, 53, 125, 10, 45, 118, 32, 45, 32, 95, 95, 115, 61,
  34, 36, 63, 34, 32, 45, 118, 32, 43, 10, 45, 95, 36, 48, 32, 36,
  123, 49, 45, 45, 49, 125, 10, 95, 102, 114, 97, 109, 101, 95, 120, 121,
  32, 58, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 73, 110, 115,
  101, 114, 116, 32, 36, 49, 120, 36, 50, 32, 111, 117, 116, 101, 114, 32,
  102, 114, 97, 109, 101, 32, 105, 110, 32, 105, 109, 97, 103, 101, 34, 36,
  95, 95, 115, 34, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 120,
  121, 45, 97, 120, 101, 115, 44, 32, 119, 105, 116, 104, 32, 99, 111, 108,
  111, 114, 32, 40, 36, 123, 51, 45, 45, 49, 125, 41, 46, 34, 10, 45,
  95, 102, 114, 97, 109, 101, 32, 36, 49, 44, 36, 50, 44, 48, 44, 36,
  123, 51, 45, 45, 49, 125, 10, 102, 114, 97, 109, 101, 95, 120, 121, 122,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48,
  32, 38, 38, 32, 36, 123, 50, 61, 36, 49, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 123, 51, 61, 36, 50, 125, 62, 61, 48, 34, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 52, 61, 50, 53, 53, 125, 44, 36, 123, 53,
  61, 36, 52, 125, 44, 36, 123, 54, 61, 36, 53, 125, 44, 36, 123, 55,
  61, 50, 53, 53, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73,
  110, 115, 101, 114, 116, 32, 36, 49, 120, 36, 50, 120, 36, 51, 32, 111,
  117, 116, 101, 114, 32, 102, 114, 97, 109, 101, 32, 105, 110, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32,
  120, 121, 122, 45, 97, 120, 101, 115, 44, 32, 119, 105, 116, 104, 32, 99,
  111, 108, 111, 114, 32, 40, 36, 123, 52, 45, 45, 49, 125, 41, 46, 34,
  10, 45, 95, 102, 114, 97, 109, 101, 32, 36, 49, 44, 36, 50, 44, 36,
  51, 44, 36, 123, 52, 45, 45, 49, 125, 10, 102, 114, 97, 109, 101, 95,
  121, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61,
  48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 50, 53, 53,
  125, 44, 36, 123, 51, 61, 36, 50, 125, 44, 36, 123, 52, 61, 36, 51,
  125, 44, 36, 123, 53, 61, 50, 53, 53, 125, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 73, 110, 115, 101, 114, 116, 32, 36, 49, 32, 111, 117,
  116, 101, 114, 32, 102, 114, 97, 109, 101, 32, 105, 110, 32, 105, 109, 97,
  103, 101, 36, 63, 32, 97, 108, 111, 110, 103, 32, 116, 104, 101, 32, 121,
  45, 97, 120, 105, 115, 44, 32, 119, 105, 116, 104, 32, 99, 111, 108, 111,
  114, 32, 40, 36, 123, 50, 45, 45, 49, 125, 41, 46, 34, 10, 45, 95,
  102, 114, 97, 109, 101, 32, 48, 44, 36, 49, 44, 48, 44, 36, 123, 50,
  45, 45, 49, 125, 10, 95, 102, 114, 97, 109, 101, 32, 58, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 119, 61, 123, 114, 111, 117, 110, 100, 40, 36, 49,
  42, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110,
  116, 92, 32, 36, 49, 125, 44, 119, 44, 49, 41, 41, 125, 10, 104, 61,
  123, 114, 111, 117, 110, 100, 40, 36, 50, 42, 105, 102, 40, 64, 123, 45,
  105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 50, 125, 44,
  104, 44, 49, 41, 41, 125, 10, 100, 61, 123, 114, 111, 117, 110, 100, 40,
  36, 51, 42, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99,
  101, 110, 116, 92, 32, 36, 51, 125, 44, 100, 44, 49, 41, 41, 125, 10,
  45, 114, 32, 123, 119, 43, 50, 42, 36, 119, 125, 44, 123, 104, 43, 50,
  42, 36, 104, 125, 44, 123, 100, 43, 50, 42, 36, 100, 125, 44, 49, 48,
  48, 37, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 44, 48,
  46, 53, 10, 45, 105, 102, 32, 123, 36, 119, 125, 32, 36, 119, 44, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 102,
  99, 91, 45, 49, 93, 32, 36, 123, 52, 45, 45, 49, 125, 32, 45, 106,
  91, 48, 93, 32, 91, 49, 93, 32, 45, 106, 91, 48, 93, 32, 91, 49,
  93, 44, 64, 123, 48, 44, 119, 45, 36, 119, 125, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 104, 125, 32, 49, 48, 48, 37, 44, 36, 104, 44, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 32, 45, 102, 99, 91, 45, 49, 93, 32, 36, 123,
  52, 45, 45, 49, 125, 32, 45, 106, 91, 48, 93, 32, 91, 49, 93, 32,
  45, 106, 91, 48, 93, 32, 91, 49, 93, 44, 48, 44, 64, 123, 48, 44,
  104, 45, 36, 104, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 100, 125, 32, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 36, 100, 44, 49, 48, 48, 37, 32,
  45, 102, 99, 91, 45, 49, 93, 32, 36, 123, 52, 45, 45, 49, 125, 32,
  45, 106, 91, 48, 93, 32, 91, 49, 93, 32, 45, 106, 91, 48, 93, 32,
  91, 49, 93, 44, 48, 44, 48, 44, 64, 123, 48, 44, 100, 45, 36, 100,
  125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 105, 109, 97, 103, 101, 103, 114, 105, 100, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 50, 61, 36, 49, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 67, 114, 101, 97, 116, 101, 32, 36, 49, 120, 36,
  50, 32, 105, 109, 97, 103, 101, 32, 103, 114, 105, 100, 32, 102, 114, 111,
  109, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 40, 123, 119, 125, 44, 123, 104, 125, 41, 32, 40, 36, 49,
  44, 36, 50, 41, 32, 45, 47, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 49, 32, 45, 114, 91, 45,
  50, 93, 32, 64, 45, 49, 44, 91, 45, 50, 93, 44, 91, 45, 50, 93,
  44, 50, 32, 45, 114, 109, 91, 45, 49, 93, 10, 40, 123, 119, 125, 44,
  123, 104, 125, 41, 32, 40, 36, 49, 44, 36, 50, 41, 32, 45, 42, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 114, 91, 45, 50, 93, 32, 64, 45,
  49, 44, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 50, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 36, 49, 44, 36, 50, 44, 49, 44, 91, 45,
  49, 93, 44, 49, 32, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32,
  49, 44, 49, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44,
  48, 44, 50, 32, 45, 42, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 108, 105, 110, 101, 97, 114, 105, 122,
  101, 95, 116, 105, 108, 101, 115, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 34, 36, 49, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 36, 49,
  125, 62, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 76, 105,
  110, 101, 97, 114, 105, 122, 101, 32, 36, 49, 120, 36, 50, 32, 116, 105,
  108, 101, 115, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110,
  125, 10, 115, 61, 123, 115, 125, 32, 45, 115, 112, 108, 105, 116, 95, 116,
  105, 108, 101, 115, 32, 36, 49, 44, 36, 50, 32, 45, 115, 32, 99, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 119, 104, 61, 123, 119, 125, 44, 123, 104, 125, 10, 45, 45, 102,
  32, 120, 32, 45, 45, 102, 91, 45, 49, 93, 32, 121, 32, 45, 45, 102,
  91, 45, 49, 93, 32, 49, 32, 45, 121, 32, 45, 97, 91, 94, 48, 93,
  32, 120, 32, 45, 115, 111, 108, 118, 101, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 36, 119, 104, 44, 49,
  44, 49, 44, 64, 123, 45, 49, 44, 48, 125, 34, 42, 120, 32, 43, 32,
  34, 64, 123, 45, 49, 44, 49, 125, 34, 42, 121, 32, 43, 32, 34, 64,
  123, 45, 49, 44, 50, 125, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 36, 115, 41, 125, 32,
  45, 97, 91, 45, 36, 115, 45, 45, 49, 93, 32, 99, 32, 45, 109, 118,
  91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 32, 45, 97, 112,
  112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 32, 36, 49, 44, 36, 50,
  10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 109, 97, 112, 95,
  115, 112, 114, 105, 116, 101, 115, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 34, 105, 115, 105, 110, 116, 40, 36, 49, 41, 32, 38, 38, 32, 36,
  49, 62, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 50,
  61, 48, 125, 41, 32, 38, 38, 32, 36, 50, 62, 61, 48, 32, 38, 38,
  32, 36, 50, 60, 61, 50, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 77, 97, 112, 32, 115, 101, 116, 32, 111, 102, 32, 36, 49, 32, 115,
  112, 114, 105, 116, 101, 115, 32, 116, 111, 32, 105, 109, 97, 103, 101, 32,
  115, 101, 108, 101, 99, 116, 105, 111, 110, 36, 63, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 110, 111, 114, 109, 91, 48, 45, 45, 123, 36, 49, 43,
  49, 125, 93, 32, 45, 113, 117, 97, 110, 116, 105, 122, 101, 91, 48, 45,
  45, 123, 36, 49, 43, 49, 125, 93, 32, 36, 49, 44, 48, 44, 49, 10,
  45, 115, 108, 105, 99, 101, 115, 91, 45, 36, 49, 45, 45, 49, 93, 32,
  48, 32, 45, 114, 91, 45, 36, 49, 45, 45, 49, 93, 32, 64, 123, 45,
  109, 97, 120, 95, 119, 104, 91, 45, 36, 49, 45, 45, 49, 93, 125, 44,
  49, 44, 49, 48, 48, 37, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48,
  46, 53, 10, 45, 105, 102, 32, 123, 36, 50, 61, 61, 49, 125, 10, 78,
  61, 123, 52, 42, 36, 49, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 64, 35, 45, 36, 49, 125, 32, 45, 42, 91, 36, 62, 93, 32, 52,
  32, 45, 45, 114, 97, 110, 100, 91, 36, 62, 93, 32, 48, 44, 51, 32,
  45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 45, 43, 91, 36, 62,
  44, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 36, 49, 32, 45, 108, 91, 123, 49, 43, 36, 60, 125, 93,
  32, 45, 45, 109, 105, 114, 114, 111, 114, 32, 120, 121, 32, 45, 45, 114,
  111, 116, 97, 116, 101, 32, 57, 48, 32, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 61, 61,
  50, 125, 10, 78, 61, 123, 50, 42, 36, 49, 125, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 64, 35, 45, 36, 49, 125, 32, 45, 42, 91, 36,
  62, 93, 32, 50, 32, 45, 45, 114, 97, 110, 100, 91, 36, 62, 93, 32,
  48, 44, 49, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 45,
  43, 91, 36, 62, 44, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 36, 49, 32, 45, 108, 91, 123, 49, 43,
  36, 60, 125, 93, 32, 45, 45, 109, 105, 114, 114, 111, 114, 32, 120, 121,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108,
  115, 101, 32, 78, 61, 36, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 91, 45, 36, 78, 45, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 49, 44, 64, 123, 45, 109, 97, 120, 95, 115, 91, 45,
  36, 78, 45, 45, 49, 93, 125, 32, 119, 61, 123, 119, 125, 32, 104, 61,
  123, 104, 125, 32, 45, 97, 91, 45, 36, 78, 45, 45, 49, 93, 32, 120,
  10, 45, 114, 91, 94, 45, 49, 93, 32, 36, 123, 119, 125, 48, 48, 37,
  44, 36, 123, 104, 125, 48, 48, 37, 44, 49, 44, 49, 32, 45, 42, 91,
  94, 45, 49, 93, 32, 36, 119, 10, 40, 48, 44, 123, 36, 119, 45, 49,
  125, 59, 48, 44, 123, 36, 119, 45, 49, 125, 94, 48, 44, 48, 59, 123,
  36, 104, 45, 49, 125, 44, 123, 36, 104, 45, 49, 125, 41, 32, 45, 114,
  91, 45, 49, 93, 32, 36, 119, 44, 36, 104, 44, 49, 44, 50, 44, 51,
  32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 64, 35, 45, 50, 125, 32, 45, 45, 114, 91, 45,
  49, 93, 32, 91, 36, 62, 93, 44, 91, 36, 62, 93, 44, 49, 44, 50,
  44, 48, 44, 50, 32, 45, 114, 91, 36, 62, 93, 32, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 44, 50, 44, 48, 32, 45, 43, 91, 36,
  62, 44, 45, 49, 93, 32, 45, 45, 119, 97, 114, 112, 91, 45, 50, 93,
  32, 91, 36, 62, 93, 44, 48, 44, 48, 32, 45, 114, 118, 91, 36, 62,
  44, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 100, 111,
  110, 101, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 32, 45, 118,
  32, 43, 10, 112, 117, 122, 122, 108, 101, 32, 58, 32, 45, 99, 104, 101,
  99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 53, 49,
  50, 125, 41, 32, 38, 38, 32, 36, 49, 62, 48, 32, 38, 38, 32, 105,
  115, 105, 110, 116, 40, 36, 123, 50, 61, 36, 49, 125, 41, 32, 38, 38,
  32, 36, 50, 62, 48, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36,
  123, 51, 61, 53, 125, 41, 32, 38, 38, 32, 36, 51, 62, 48, 32, 38,
  38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 52, 61, 36, 51, 125, 41,
  32, 38, 38, 32, 36, 52, 62, 48, 32, 38, 38, 32, 105, 115, 105, 110,
  116, 40, 36, 123, 56, 61, 54, 52, 125, 41, 32, 38, 38, 32, 36, 56,
  62, 48, 34, 10, 45, 115, 107, 105, 112, 32, 36, 123, 53, 61, 48, 46,
  53, 125, 44, 36, 123, 54, 61, 48, 46, 53, 125, 44, 36, 123, 55, 61,
  48, 46, 53, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 114,
  97, 119, 32, 36, 51, 120, 36, 52, 32, 112, 117, 122, 122, 108, 101, 32,
  112, 97, 116, 116, 101, 114, 110, 32, 111, 110, 32, 105, 109, 97, 103, 101,
  36, 63, 44, 32, 119, 105, 116, 104, 32, 99, 117, 114, 118, 97, 116, 117,
  114, 101, 32, 36, 53, 44, 32, 99, 101, 110, 116, 101, 114, 105, 110, 103,
  32, 36, 54, 44, 32, 99, 111, 110, 110, 101, 99, 116, 111, 114, 115, 32,
  118, 97, 114, 105, 97, 98, 105, 108, 105, 116, 121, 32, 36, 55, 32, 97,
  110, 100, 32, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 32, 36, 56,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 108, 91, 93, 10, 45, 105, 102,
  32, 123, 36, 52, 62, 61, 50, 125, 32, 45, 95, 112, 117, 122, 122, 108,
  101, 91, 93, 32, 36, 51, 44, 123, 36, 52, 45, 49, 125, 44, 36, 123,
  53, 45, 56, 125, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 48, 44,
  49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 51,
  62, 61, 50, 125, 32, 45, 95, 112, 117, 122, 122, 108, 101, 91, 93, 32,
  36, 52, 44, 123, 36, 51, 45, 49, 125, 44, 36, 123, 53, 45, 56, 125,
  32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 48, 44, 49, 44,
  57, 48, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 49, 44, 36, 52,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 42, 51, 100, 32, 123, 36, 49,
  47, 36, 51, 125, 44, 123, 36, 50, 47, 36, 52, 125, 32, 45, 113, 117,
  97, 100, 114, 97, 110, 103, 108, 101, 51, 100, 32, 48, 44, 48, 44, 48,
  44, 123, 36, 49, 45, 49, 125, 44, 48, 44, 48, 44, 123, 36, 49, 45,
  49, 125, 44, 123, 36, 50, 45, 49, 125, 44, 48, 44, 48, 44, 123, 36,
  50, 45, 49, 125, 44, 48, 32, 45, 112, 51, 100, 91, 45, 49, 93, 32,
  49, 32, 45, 43, 51, 100, 32, 45, 99, 111, 108, 51, 100, 32, 49, 10,
  36, 49, 44, 36, 50, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 44, 49,
  44, 49, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45,
  101, 110, 100, 108, 32, 45, 118, 32, 43, 10, 95, 112, 117, 122, 122, 108,
  101, 32, 58, 10, 82, 61, 123, 36, 54, 42, 36, 49, 125, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 50, 10, 40, 123, 39, 67, 73, 109, 103,
  51, 100, 39, 125, 44, 36, 82, 44, 123, 36, 82, 45, 49, 125, 41, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 10, 115, 105, 103, 110, 61,
  123, 105, 102, 40, 63, 60, 61, 48, 46, 53, 44, 45, 49, 44, 49, 41,
  125, 10, 99, 101, 110, 116, 101, 114, 61, 123, 36, 52, 42, 63, 40, 45,
  48, 46, 50, 53, 44, 48, 46, 50, 53, 41, 125, 10, 107, 110, 111, 98,
  61, 123, 36, 53, 42, 63, 40, 45, 48, 46, 48, 53, 44, 48, 46, 49,
  50, 41, 125, 10, 40, 36, 62, 44, 48, 59, 92, 10, 123, 48, 46, 50,
  43, 36, 99, 101, 110, 116, 101, 114, 43, 36, 62, 125, 44, 123, 45, 36,
  115, 105, 103, 110, 42, 36, 51, 42, 48, 46, 49, 125, 59, 92, 10, 123,
  48, 46, 52, 43, 36, 99, 101, 110, 116, 101, 114, 43, 36, 62, 125, 44,
  48, 59, 92, 10, 123, 48, 46, 51, 53, 43, 36, 99, 101, 110, 116, 101,
  114, 43, 36, 62, 125, 44, 123, 48, 46, 49, 42, 36, 115, 105, 103, 110,
  125, 59, 92, 10, 123, 48, 46, 52, 53, 43, 36, 99, 101, 110, 116, 101,
  114, 43, 36, 62, 125, 44, 123, 40, 48, 46, 49, 53, 43, 36, 107, 110,
  111, 98, 41, 42, 36, 115, 105, 103, 110, 125, 59, 92, 10, 123, 48, 46,
  53, 53, 43, 36, 99, 101, 110, 116, 101, 114, 43, 36, 62, 125, 44, 123,
  40, 48, 46, 49, 53, 43, 36, 107, 110, 111, 98, 41, 42, 36, 115, 105,
  103, 110, 125, 59, 92, 10, 123, 48, 46, 54, 53, 43, 36, 99, 101, 110,
  116, 101, 114, 43, 36, 62, 125, 44, 123, 48, 46, 49, 42, 36, 115, 105,
  103, 110, 125, 59, 92, 10, 123, 48, 46, 54, 43, 36, 99, 101, 110, 116,
  101, 114, 43, 36, 62, 125, 44, 48, 59, 92, 10, 123, 48, 46, 56, 43,
  36, 99, 101, 110, 116, 101, 114, 43, 36, 62, 125, 44, 123, 45, 36, 115,
  105, 103, 110, 42, 36, 51, 42, 48, 46, 49, 125, 41, 10, 45, 100, 111,
  110, 101, 10, 40, 36, 49, 44, 48, 41, 32, 45, 97, 91, 45, 123, 36,
  49, 43, 49, 125, 45, 45, 49, 93, 32, 121, 32, 45, 114, 91, 45, 49,
  93, 32, 50, 44, 36, 82, 44, 49, 44, 49, 44, 53, 32, 45, 122, 91,
  45, 49, 93, 32, 48, 44, 50, 10, 40, 50, 44, 48, 44, 49, 59, 50,
  44, 123, 36, 82, 45, 50, 125, 44, 123, 36, 82, 45, 49, 125, 41, 32,
  45, 114, 91, 45, 49, 93, 32, 51, 44, 123, 36, 82, 45, 49, 125, 44,
  49, 44, 49, 44, 51, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93,
  10, 51, 44, 123, 104, 125, 44, 49, 44, 49, 44, 50, 53, 53, 32, 49,
  44, 123, 104, 125, 44, 49, 44, 49, 44, 50, 53, 53, 32, 45, 121, 91,
  45, 53, 45, 45, 49, 93, 32, 121, 32, 45, 97, 91, 45, 53, 45, 45,
  49, 93, 32, 121, 32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 48, 44,
  36, 62, 10, 45, 100, 111, 110, 101, 32, 45, 43, 51, 100, 10, 113, 117,
  97, 100, 114, 97, 116, 105, 122, 101, 95, 116, 105, 108, 101, 115, 32, 58,
  32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 48, 32, 38, 38,
  32, 36, 123, 50, 61, 36, 49, 125, 62, 48, 34, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 81, 117, 97, 100, 114, 97, 116, 105, 122, 101, 32,
  36, 49, 120, 36, 50, 32, 116, 105, 108, 101, 115, 32, 111, 110, 32, 105,
  109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32,
  110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 115, 61, 123, 115, 125, 32,
  45, 115, 112, 108, 105, 116, 95, 116, 105, 108, 101, 115, 32, 36, 49, 44,
  36, 50, 32, 45, 115, 32, 99, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 104, 61, 123, 119, 125,
  44, 123, 104, 125, 10, 45, 45, 102, 32, 120, 94, 50, 32, 45, 45, 102,
  91, 45, 49, 93, 32, 121, 94, 50, 32, 45, 45, 102, 91, 45, 49, 93,
  32, 120, 42, 121, 32, 45, 45, 102, 91, 45, 49, 93, 32, 120, 32, 45,
  45, 102, 91, 45, 49, 93, 32, 121, 32, 45, 45, 102, 91, 45, 49, 93,
  32, 49, 32, 45, 121, 32, 45, 97, 91, 94, 48, 93, 32, 120, 32, 45,
  115, 111, 108, 118, 101, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 36, 119, 104, 44, 49, 44, 49, 44, 64,
  123, 45, 49, 44, 48, 125, 34, 42, 120, 94, 50, 32, 43, 32, 34, 64,
  123, 45, 49, 44, 49, 125, 34, 42, 121, 94, 50, 32, 43, 32, 34, 64,
  123, 45, 49, 44, 50, 125, 34, 42, 120, 42, 121, 32, 43, 34, 64, 123,
  45, 49, 44, 51, 125, 34, 42, 120, 32, 43, 32, 34, 64, 123, 45, 49,
  44, 52, 125, 34, 42, 121, 32, 43, 32, 34, 64, 123, 45, 49, 44, 53,
  125, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105,
  110, 116, 40, 64, 35, 47, 36, 115, 41, 125, 32, 45, 97, 91, 45, 36,
  115, 45, 45, 49, 93, 32, 99, 32, 45, 109, 118, 91, 45, 49, 93, 32,
  48, 32, 45, 100, 111, 110, 101, 32, 45, 97, 112, 112, 101, 110, 100, 95,
  116, 105, 108, 101, 115, 32, 36, 49, 44, 36, 50, 10, 45, 110, 109, 32,
  36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 114, 111, 116, 97, 116, 101, 95, 116, 105,
  108, 101, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61,
  56, 125, 44, 36, 123, 51, 61, 36, 50, 125, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 36, 50, 120, 36, 51, 32,
  116, 105, 108, 101, 100, 45, 114, 111, 116, 97, 116, 105, 111, 110, 32, 101,
  102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63,
  44, 32, 119, 105, 116, 104, 32, 97, 110, 103, 108, 101, 32, 36, 49, 32,
  100, 101, 103, 46, 34, 10, 45, 118, 32, 45, 32, 45, 115, 112, 108, 105,
  116, 95, 116, 105, 108, 101, 115, 32, 36, 50, 44, 36, 51, 44, 49, 32,
  45, 114, 111, 116, 97, 116, 101, 32, 36, 49, 32, 45, 97, 112, 112, 101,
  110, 100, 95, 116, 105, 108, 101, 115, 32, 36, 50, 44, 36, 51, 32, 45,
  118, 32, 43, 10, 115, 104, 105, 102, 116, 95, 116, 105, 108, 101, 115, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 50, 61, 36, 49,
  125, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61,
  50, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112,
  108, 121, 32, 36, 49, 120, 36, 50, 32, 116, 105, 108, 101, 100, 45, 115,
  104, 105, 102, 116, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105,
  109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 97, 109, 112,
  108, 105, 116, 117, 100, 101, 32, 36, 51, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 36, 49, 44, 36, 50, 44, 49, 44, 50, 32, 45, 110, 111,
  105, 115, 101, 91, 45, 49, 93, 32, 36, 51, 32, 45, 114, 91, 45, 49,
  93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 50, 32,
  45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49,
  44, 49, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 116, 97,
  113, 117, 105, 110, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105,
  115, 105, 110, 116, 40, 36, 49, 41, 32, 38, 38, 32, 36, 49, 62, 48,
  32, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 50, 61, 36, 49, 125,
  41, 32, 38, 38, 32, 36, 50, 62, 48, 34, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 51, 61, 48, 125, 44, 36, 123, 52, 61, 53, 48, 125, 44,
  36, 123, 53, 61, 53, 37, 125, 44, 36, 123, 54, 61, 48, 125, 44, 36,
  123, 55, 61, 48, 125, 44, 36, 123, 56, 61, 36, 55, 125, 44, 36, 123,
  57, 61, 36, 56, 125, 44, 36, 123, 49, 48, 61, 50, 53, 53, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 114, 101, 97, 116, 101, 32,
  36, 49, 120, 36, 50, 32, 116, 97, 113, 117, 105, 110, 32, 112, 117, 122,
  122, 108, 101, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 32, 36,
  63, 44, 32, 119, 105, 116, 104, 32, 114, 101, 108, 105, 101, 102, 32, 36,
  52, 44, 32, 98, 111, 114, 100, 101, 114, 32, 116, 104, 105, 99, 107, 110,
  101, 115, 115, 32, 36, 53, 44, 32, 98, 111, 114, 100, 101, 114, 32, 111,
  117, 116, 108, 105, 110, 101, 32, 36, 54, 32, 97, 110, 100, 32, 111, 117,
  116, 108, 105, 110, 101, 32, 99, 111, 108, 111, 114, 32, 40, 36, 123, 55,
  45, 45, 49, 125, 41, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110,
  109, 61, 64, 123, 48, 44, 110, 125, 10, 45, 115, 112, 108, 105, 116, 95,
  116, 105, 108, 101, 115, 32, 36, 49, 44, 36, 50, 32, 45, 114, 32, 64,
  123, 45, 109, 105, 110, 95, 119, 104, 125, 44, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 48, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  49, 44, 49, 44, 49, 10, 45, 105, 102, 32, 64, 123, 34, 45, 105, 115,
  95, 112, 101, 114, 99, 101, 110, 116, 32, 36, 53, 34, 125, 32, 45, 114,
  101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 123, 49, 48,
  48, 42, 36, 53, 47, 50, 125, 37, 44, 123, 49, 48, 48, 42, 36, 53,
  47, 50, 125, 37, 44, 123, 49, 48, 48, 45, 53, 48, 42, 36, 53, 125,
  37, 44, 123, 49, 48, 48, 45, 53, 48, 42, 36, 53, 125, 37, 44, 49,
  44, 48, 10, 45, 101, 108, 115, 101, 32, 45, 114, 101, 99, 116, 97, 110,
  103, 108, 101, 91, 45, 49, 93, 32, 36, 53, 44, 36, 53, 44, 123, 119,
  45, 49, 45, 36, 53, 125, 44, 123, 104, 45, 49, 45, 36, 53, 125, 44,
  49, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 42, 91, 45, 49,
  93, 32, 39, 49, 45, 50, 42, 40, 120, 60, 121, 41, 39, 32, 45, 42,
  91, 45, 49, 93, 32, 36, 52, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 64, 35, 45, 49, 125, 32, 45, 108, 91, 36, 62, 44, 45, 49, 93,
  32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 91,
  48, 93, 32, 45, 43, 91, 48, 93, 32, 91, 45, 49, 93, 32, 45, 97,
  91, 94, 45, 49, 93, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 99, 32, 48,
  44, 50, 53, 53, 10, 45, 102, 114, 97, 109, 101, 32, 36, 54, 44, 36,
  54, 44, 36, 123, 55, 45, 49, 48, 125, 10, 45, 105, 102, 32, 123, 36,
  51, 61, 61, 51, 125, 32, 45, 102, 91, 45, 49, 93, 32, 48, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 109, 118, 91, 36, 62, 93, 32, 123, 63, 40, 64, 35, 41, 125,
  32, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 51, 61, 61,
  49, 125, 32, 45, 102, 91, 48, 93, 32, 48, 32, 45, 101, 108, 105, 102,
  32, 123, 36, 51, 61, 61, 50, 125, 32, 45, 102, 91, 45, 49, 93, 32,
  48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 112, 112, 101, 110, 100,
  95, 116, 105, 108, 101, 115, 32, 36, 49, 44, 36, 50, 10, 45, 110, 109,
  32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 116, 117, 110, 110, 101, 108, 32, 58,
  32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 57, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 56, 48, 37, 125, 62, 48,
  34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 48, 46, 53, 125,
  44, 36, 123, 52, 61, 48, 46, 53, 125, 44, 36, 123, 53, 61, 48, 46,
  49, 125, 44, 36, 123, 54, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 65, 112, 112, 108, 121, 32, 116, 117, 110, 110, 101, 108, 32,
  101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 119, 105, 116, 104, 32, 100, 101, 112, 116, 104, 32, 36, 49,
  44, 32, 102, 97, 99, 116, 111, 114, 32, 36, 50, 44, 32, 99, 101, 110,
  116, 101, 114, 105, 110, 103, 32, 40, 36, 51, 44, 36, 52, 41, 44, 32,
  111, 112, 97, 99, 105, 116, 121, 32, 36, 53, 32, 97, 110, 100, 32, 97,
  110, 103, 108, 101, 32, 36, 54, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 32, 45, 45, 114, 91,
  45, 49, 93, 32, 36, 50, 44, 36, 50, 44, 49, 44, 49, 48, 48, 37,
  44, 53, 10, 45, 105, 102, 32, 36, 54, 32, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 49, 44, 49, 44, 49, 32, 45, 114, 111, 116, 97, 116,
  101, 91, 45, 50, 44, 45, 49, 93, 32, 36, 54, 44, 49, 44, 48, 32,
  45, 101, 114, 111, 100, 101, 91, 45, 49, 93, 32, 51, 32, 45, 106, 91,
  45, 51, 93, 32, 91, 45, 50, 93, 44, 123, 40, 64, 123, 45, 51, 44,
  119, 125, 45, 119, 41, 42, 36, 51, 125, 44, 123, 40, 64, 123, 45, 51,
  44, 104, 125, 45, 104, 41, 42, 36, 52, 125, 44, 48, 44, 48, 44, 36,
  53, 44, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49,
  93, 10, 45, 101, 108, 115, 101, 32, 45, 106, 91, 45, 50, 93, 32, 91,
  45, 49, 93, 44, 123, 40, 64, 123, 45, 50, 44, 119, 125, 45, 119, 41,
  42, 36, 51, 125, 44, 123, 40, 64, 123, 45, 50, 44, 104, 125, 45, 104,
  41, 42, 36, 52, 125, 44, 48, 44, 48, 44, 36, 53, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110,
  101, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 99,
  32, 48, 44, 50, 53, 53, 32, 45, 118, 32, 43, 10, 98, 111, 120, 102,
  105, 116, 116, 105, 110, 103, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 51, 125, 41, 32, 38,
  38, 32, 36, 49, 62, 61, 49, 32, 38, 38, 32, 105, 115, 105, 110, 116,
  40, 36, 123, 50, 61, 48, 125, 41, 32, 38, 38, 32, 36, 50, 62, 61,
  48, 32, 38, 38, 32, 36, 123, 51, 61, 48, 46, 49, 125, 62, 61, 48,
  32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 52, 61, 51, 125,
  41, 32, 38, 38, 32, 36, 52, 62, 61, 49, 34, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 98, 111, 120, 32, 102,
  105, 116, 116, 105, 110, 103, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110,
  32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 98,
  111, 120, 32, 115, 105, 122, 101, 115, 32, 40, 36, 49, 44, 36, 50, 41,
  44, 32, 100, 101, 110, 115, 105, 116, 121, 32, 36, 51, 32, 97, 110, 100,
  32, 36, 52, 32, 97, 116, 116, 101, 109, 112, 116, 115, 46, 34, 10, 45,
  118, 32, 45, 10, 109, 105, 110, 95, 115, 105, 122, 101, 61, 36, 49, 10,
  109, 97, 120, 95, 115, 105, 122, 101, 61, 123, 105, 102, 40, 36, 50, 44,
  36, 50, 44, 109, 97, 120, 40, 119, 44, 104, 41, 41, 125, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  110, 98, 95, 97, 116, 116, 101, 109, 112, 116, 115, 61, 48, 32, 112, 114,
  101, 99, 61, 53, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 49, 101, 56, 10, 45, 105, 102, 32, 123,
  36, 62, 60, 49, 125, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32,
  45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 123, 109, 97, 120, 40,
  49, 101, 45, 51, 44, 36, 51, 41, 125, 44, 50, 10, 45, 101, 108, 115,
  101, 10, 45, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93,
  32, 49, 32, 45, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44,
  49, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 109, 97, 120,
  95, 112, 97, 116, 99, 104, 91, 45, 49, 93, 32, 123, 114, 111, 117, 110,
  100, 40, 36, 112, 114, 101, 99, 42, 36, 109, 105, 110, 95, 115, 105, 122,
  101, 41, 125, 10, 112, 114, 101, 99, 61, 123, 109, 97, 120, 40, 49, 44,
  36, 112, 114, 101, 99, 42, 48, 46, 57, 41, 125, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 36,
  109, 105, 110, 95, 115, 105, 122, 101, 32, 45, 97, 114, 101, 97, 95, 102,
  103, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 101, 113, 91, 45, 49,
  93, 32, 123, 40, 36, 109, 105, 110, 95, 115, 105, 122, 101, 41, 94, 50,
  125, 10, 45, 45, 100, 105, 108, 97, 116, 101, 91, 45, 50, 93, 32, 51,
  32, 45, 101, 113, 91, 45, 49, 93, 32, 48, 32, 45, 42, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 97, 114, 101, 97, 95, 102, 103, 91, 45, 49,
  93, 32, 48, 44, 49, 32, 45, 101, 113, 91, 45, 49, 93, 32, 123, 40,
  36, 109, 105, 110, 95, 115, 105, 122, 101, 41, 94, 50, 125, 10, 45, 105,
  102, 32, 123, 33, 105, 77, 125, 32, 110, 98, 95, 97, 116, 116, 101, 109,
  112, 116, 115, 61, 123, 36, 110, 98, 95, 97, 116, 116, 101, 109, 112, 116,
  115, 43, 49, 125, 32, 45, 105, 102, 32, 123, 36, 110, 98, 95, 97, 116,
  116, 101, 109, 112, 116, 115, 62, 36, 52, 125, 32, 45, 114, 109, 91, 45,
  49, 93, 32, 45, 98, 114, 101, 97, 107, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 108, 115, 101, 32, 110, 98, 95, 97, 116, 116, 101, 109, 112,
  116, 115, 61, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 43, 91, 45,
  50, 44, 45, 49, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105,
  110, 116, 40, 40, 36, 109, 97, 120, 95, 115, 105, 122, 101, 45, 36, 109,
  105, 110, 95, 115, 105, 122, 101, 41, 47, 50, 41, 125, 10, 45, 45, 100,
  105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51, 32, 45, 97, 114, 101,
  97, 95, 102, 103, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 101, 113,
  91, 45, 49, 93, 32, 123, 40, 36, 109, 105, 110, 95, 115, 105, 122, 101,
  43, 50, 42, 36, 62, 43, 50, 41, 94, 50, 125, 10, 45, 105, 102, 32,
  123, 33, 105, 77, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 98,
  114, 101, 97, 107, 32, 45, 101, 110, 100, 105, 102, 10, 45, 111, 114, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 100, 111, 110, 101, 10, 45, 100, 111,
  110, 101, 10, 45, 98, 108, 101, 110, 100, 32, 115, 104, 97, 112, 101, 97,
  118, 101, 114, 97, 103, 101, 48, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 99, 97, 114, 116, 111, 111, 110,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 51, 125, 44,
  36, 123, 50, 61, 49, 53, 48, 125, 44, 36, 123, 51, 61, 50, 48, 125,
  44, 36, 123, 52, 61, 48, 46, 50, 53, 125, 44, 36, 123, 53, 61, 49,
  46, 53, 125, 44, 36, 123, 54, 61, 56, 125, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 97, 114, 116, 111, 111,
  110, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109, 97, 103,
  101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 36, 49, 44, 32, 115, 104, 97, 114, 112, 101, 110,
  105, 110, 103, 32, 36, 50, 44, 32, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 32, 36, 51, 44, 32, 116, 104, 105, 99, 107, 110, 101, 115, 115, 32,
  36, 52, 44, 32, 99, 111, 108, 111, 114, 32, 36, 53, 32, 97, 110, 100,
  32, 113, 117, 97, 110, 116, 105, 122, 97, 116, 105, 111, 110, 32, 36, 54,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116,
  95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91, 48, 93, 32, 45,
  116, 111, 95, 114, 103, 98, 10, 45, 98, 32, 36, 49, 32, 45, 115, 104,
  97, 114, 112, 101, 110, 32, 36, 50, 44, 49, 32, 45, 99, 32, 48, 44,
  50, 53, 53, 32, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 45, 101,
  100, 103, 101, 115, 32, 36, 51, 32, 45, 98, 91, 45, 49, 93, 32, 36,
  52, 32, 45, 103, 101, 91, 45, 49, 93, 32, 48, 46, 57, 10, 45, 114,
  103, 98, 50, 108, 97, 98, 91, 45, 50, 93, 32, 45, 115, 91, 45, 50,
  93, 32, 99, 32, 45, 42, 91, 45, 51, 44, 45, 50, 93, 32, 36, 53,
  32, 45, 97, 91, 45, 52, 45, 45, 50, 93, 32, 99, 32, 45, 108, 97,
  98, 50, 114, 103, 98, 91, 45, 50, 93, 32, 45, 113, 117, 97, 110, 116,
  105, 122, 101, 91, 45, 50, 93, 32, 36, 54, 44, 49, 44, 48, 32, 45,
  110, 91, 45, 50, 93, 32, 48, 44, 50, 53, 53, 32, 45, 42, 10, 45,
  101, 110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 99, 105, 114, 99, 108,
  105, 115, 109, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123,
  49, 61, 50, 125, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 50, 48,
  125, 62, 48, 32, 38, 38, 32, 36, 123, 51, 61, 49, 125, 62, 61, 48,
  32, 38, 38, 32, 36, 123, 52, 61, 48, 46, 52, 125, 62, 48, 32, 38,
  38, 32, 36, 123, 53, 61, 51, 125, 62, 61, 48, 34, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 54, 61, 50, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 105, 114, 99, 108, 105, 115,
  109, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109, 97, 103,
  101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 114, 97, 100, 105, 105, 32,
  40, 36, 49, 44, 36, 50, 41, 44, 32, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 36, 51, 44, 32, 114, 97, 100, 105, 117, 115, 32, 108,
  105, 110, 101, 97, 114, 105, 116, 121, 32, 36, 52, 32, 97, 110, 100, 32,
  108, 111, 99, 97, 116, 105, 111, 110, 32, 108, 105, 110, 101, 97, 114, 105,
  116, 121, 32, 36, 53, 46, 92, 110, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 45, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109,
  32, 45, 98, 91, 45, 49, 93, 32, 36, 51, 32, 45, 110, 91, 45, 49,
  93, 32, 48, 44, 49, 32, 45, 45, 94, 91, 45, 49, 93, 32, 36, 53,
  32, 45, 94, 91, 45, 50, 93, 32, 36, 52, 32, 115, 117, 109, 103, 48,
  61, 64, 123, 45, 49, 44, 43, 125, 32, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 10, 105, 116, 61, 48, 32, 102, 97, 105, 108, 101, 100, 61, 48,
  32, 110, 111, 101, 100, 103, 101, 115, 61, 48, 32, 115, 118, 103, 61, 34,
  45, 49, 44, 45, 49, 34, 10, 45, 100, 111, 10, 45, 45, 100, 105, 115,
  116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 44, 51, 10, 45, 105,
  102, 32, 36, 110, 111, 101, 100, 103, 101, 115, 32, 120, 121, 122, 99, 61,
  64, 123, 45, 49, 44, 67, 125, 32, 45, 101, 108, 115, 101, 32, 45, 45,
  42, 91, 45, 51, 44, 45, 49, 93, 32, 120, 121, 122, 99, 61, 64, 123,
  45, 49, 44, 67, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101,
  110, 100, 105, 102, 10, 110, 61, 64, 123, 45, 52, 44, 40, 36, 120, 121,
  122, 99, 41, 125, 10, 120, 61, 123, 97, 114, 103, 40, 49, 44, 36, 120,
  121, 122, 99, 41, 125, 10, 121, 61, 123, 97, 114, 103, 40, 50, 44, 36,
  120, 121, 122, 99, 41, 125, 10, 114, 61, 123, 109, 105, 110, 40, 109, 97,
  120, 40, 36, 49, 44, 36, 50, 42, 40, 49, 45, 36, 110, 41, 41, 44,
  115, 113, 114, 116, 40, 64, 123, 45, 49, 44, 40, 36, 120, 121, 122, 99,
  41, 125, 41, 45, 50, 41, 125, 10, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 105, 102, 32, 123, 36, 114, 62, 61, 36, 49, 125, 10, 45, 105, 102,
  32, 123, 36, 54, 61, 61, 50, 125, 10, 45, 101, 108, 108, 105, 112, 115,
  101, 91, 45, 49, 93, 32, 36, 120, 44, 36, 121, 44, 36, 114, 44, 36,
  114, 44, 48, 44, 49, 44, 49, 32, 45, 101, 108, 108, 105, 112, 115, 101,
  91, 45, 50, 93, 32, 36, 120, 44, 36, 121, 44, 123, 36, 114, 43, 36,
  49, 125, 44, 123, 36, 114, 43, 36, 49, 125, 44, 48, 44, 49, 44, 45,
  49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 54, 61, 61, 49, 125, 10,
  120, 48, 61, 123, 36, 120, 45, 36, 114, 47, 50, 125, 32, 121, 48, 61,
  123, 36, 121, 45, 36, 114, 47, 50, 125, 32, 120, 49, 61, 123, 36, 120,
  43, 36, 114, 47, 50, 125, 32, 121, 49, 61, 123, 36, 121, 43, 36, 114,
  47, 50, 125, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45,
  49, 93, 32, 36, 120, 48, 44, 36, 121, 48, 44, 36, 120, 49, 44, 36,
  121, 49, 44, 49, 44, 49, 10, 120, 48, 61, 123, 36, 120, 45, 40, 36,
  114, 43, 36, 49, 41, 47, 50, 125, 32, 121, 48, 61, 123, 36, 121, 45,
  40, 36, 114, 43, 36, 49, 41, 47, 50, 125, 32, 120, 49, 61, 123, 36,
  120, 43, 40, 36, 114, 43, 36, 49, 41, 47, 50, 125, 32, 121, 49, 61,
  123, 36, 121, 43, 40, 36, 114, 43, 36, 49, 41, 47, 50, 125, 10, 45,
  114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 50, 93, 32, 36, 120,
  48, 44, 36, 121, 48, 44, 36, 120, 49, 44, 36, 121, 49, 44, 49, 44,
  45, 49, 10, 45, 101, 108, 115, 101, 10, 120, 48, 61, 123, 114, 111, 117,
  110, 100, 40, 36, 120, 45, 36, 114, 47, 50, 41, 125, 32, 121, 48, 61,
  123, 114, 111, 117, 110, 100, 40, 36, 121, 45, 36, 114, 47, 50, 41, 125,
  32, 120, 49, 61, 123, 114, 111, 117, 110, 100, 40, 36, 120, 43, 36, 114,
  47, 50, 41, 125, 32, 121, 49, 61, 123, 114, 111, 117, 110, 100, 40, 36,
  121, 43, 36, 114, 47, 50, 41, 125, 10, 45, 112, 111, 108, 121, 103, 111,
  110, 91, 45, 49, 93, 32, 52, 44, 36, 120, 48, 44, 36, 121, 44, 36,
  120, 44, 36, 121, 48, 44, 36, 120, 49, 44, 36, 121, 44, 36, 120, 44,
  36, 121, 49, 44, 49, 44, 49, 10, 120, 48, 61, 123, 114, 111, 117, 110,
  100, 40, 36, 120, 45, 40, 36, 114, 43, 36, 49, 41, 47, 50, 41, 125,
  32, 121, 48, 61, 123, 114, 111, 117, 110, 100, 40, 36, 121, 45, 40, 36,
  114, 43, 36, 49, 41, 47, 50, 41, 125, 32, 120, 49, 61, 123, 114, 111,
  117, 110, 100, 40, 36, 120, 43, 40, 36, 114, 43, 36, 49, 41, 47, 50,
  41, 125, 32, 121, 49, 61, 123, 114, 111, 117, 110, 100, 40, 36, 121, 43,
  40, 36, 114, 43, 36, 49, 41, 47, 50, 41, 125, 10, 45, 112, 111, 108,
  121, 103, 111, 110, 91, 45, 50, 93, 32, 52, 44, 36, 120, 48, 44, 36,
  121, 44, 36, 120, 44, 36, 121, 48, 44, 36, 120, 49, 44, 36, 121, 44,
  36, 120, 44, 36, 121, 49, 44, 49, 44, 45, 49, 10, 45, 101, 110, 100,
  105, 102, 10, 102, 97, 105, 108, 101, 100, 61, 48, 10, 45, 101, 108, 115,
  101, 10, 45, 61, 91, 45, 50, 93, 32, 45, 49, 44, 36, 120, 44, 36,
  121, 10, 102, 97, 105, 108, 101, 100, 61, 123, 36, 102, 97, 105, 108, 101,
  100, 43, 49, 125, 10, 45, 105, 102, 32, 123, 36, 102, 97, 105, 108, 101,
  100, 61, 61, 49, 48, 48, 125, 32, 102, 97, 105, 108, 101, 100, 61, 48,
  32, 45, 105, 102, 32, 36, 110, 111, 101, 100, 103, 101, 115, 32, 110, 61,
  45, 49, 32, 45, 101, 108, 115, 101, 32, 110, 111, 101, 100, 103, 101, 115,
  61, 49, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 105, 102, 10, 105, 116, 61, 123, 36, 105, 116, 43,
  49, 125, 10, 45, 105, 102, 32, 123, 33, 40, 36, 105, 116, 37, 53, 48,
  41, 125, 10, 112, 61, 123, 114, 111, 117, 110, 100, 40, 49, 48, 48, 42,
  40, 40, 36, 115, 117, 109, 103, 48, 45, 64, 123, 45, 50, 44, 43, 125,
  41, 47, 64, 123, 45, 50, 44, 119, 104, 125, 41, 94, 51, 41, 125, 10,
  45, 114, 112, 114, 111, 103, 114, 101, 115, 115, 32, 36, 112, 32, 45, 118,
  32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 114, 32, 32, 34, 36, 112,
  37, 32, 45, 118, 32, 45, 10, 45, 101, 110, 100, 105, 102, 10, 45, 119,
  104, 105, 108, 101, 32, 123, 36, 110, 62, 61, 48, 125, 10, 45, 114, 109,
  91, 45, 51, 44, 45, 50, 93, 32, 45, 114, 112, 114, 111, 103, 114, 101,
  115, 115, 32, 45, 49, 10, 45, 98, 108, 101, 110, 100, 32, 115, 104, 97,
  112, 101, 97, 118, 101, 114, 97, 103, 101, 48, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 99, 111, 108, 111,
  114, 95, 101, 108, 108, 105, 112, 115, 101, 115, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 49, 61, 49, 52, 48, 48, 125, 44, 36, 123, 50,
  61, 53, 125, 44, 36, 123, 51, 61, 48, 46, 49, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 100, 100, 32, 36, 49, 32, 114, 97, 110,
  100, 111, 109, 32, 99, 111, 108, 111, 114, 32, 101, 108, 108, 105, 112, 115,
  101, 115, 32, 116, 111, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119,
  105, 116, 104, 32, 109, 97, 120, 105, 109, 117, 109, 32, 114, 97, 100, 105,
  117, 115, 32, 36, 50, 32, 97, 110, 100, 32, 111, 112, 97, 99, 105, 116,
  121, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 36, 49, 32, 45, 101, 108, 108, 105, 112, 115, 101, 32,
  123, 63, 40, 48, 44, 49, 48, 48, 41, 125, 37, 44, 123, 63, 40, 48,
  44, 49, 48, 48, 41, 125, 37, 44, 123, 63, 40, 48, 44, 36, 50, 41,
  125, 37, 44, 123, 63, 40, 48, 44, 36, 50, 41, 125, 37, 44, 123, 63,
  40, 48, 44, 51, 54, 48, 41, 125, 44, 36, 51, 44, 123, 63, 40, 54,
  48, 44, 50, 53, 53, 41, 125, 44, 123, 63, 40, 54, 48, 44, 50, 53,
  53, 41, 125, 44, 123, 63, 40, 54, 48, 44, 50, 53, 53, 41, 125, 44,
  50, 53, 53, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 99,
  117, 98, 105, 115, 109, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  36, 123, 49, 61, 53, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123,
  50, 61, 49, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 50, 60, 61,
  53, 48, 32, 38, 38, 32, 36, 123, 53, 61, 48, 125, 62, 61, 48, 34,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 55, 53, 125, 44, 36,
  123, 52, 61, 48, 46, 55, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 65, 112, 112, 108, 121, 32, 99, 117, 98, 105, 115, 109, 32, 101, 102,
  102, 101, 99, 116, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 119, 105, 116, 104, 32, 100, 101, 110, 115, 105, 116, 121, 32, 36, 49,
  44, 32, 116, 104, 105, 99, 107, 110, 101, 115, 115, 32, 36, 50, 44, 32,
  109, 97, 120, 105, 109, 117, 109, 32, 97, 110, 103, 108, 101, 32, 36, 51,
  32, 100, 101, 103, 46, 44, 32, 111, 112, 97, 99, 105, 116, 121, 32, 36,
  52, 32, 97, 110, 100, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  32, 36, 53, 46, 34, 10, 45, 105, 102, 32, 123, 34, 33, 36, 49, 32,
  124, 124, 32, 33, 36, 50, 32, 124, 124, 32, 33, 36, 51, 32, 124, 124,
  32, 33, 36, 52, 34, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 61, 123,
  119, 125, 32, 104, 61, 123, 104, 125, 32, 115, 61, 123, 115, 125, 10, 80,
  61, 123, 114, 111, 117, 110, 100, 40, 36, 50, 42, 109, 97, 120, 40, 119,
  44, 104, 41, 47, 50, 48, 48, 41, 125, 10, 78, 61, 123, 114, 111, 117,
  110, 100, 40, 49, 46, 53, 42, 36, 49, 42, 119, 42, 104, 47, 40, 52,
  42, 36, 80, 41, 47, 49, 48, 48, 41, 125, 10, 40, 123, 39, 67, 73,
  109, 103, 51, 100, 39, 125, 41, 32, 45, 43, 91, 45, 49, 93, 32, 48,
  46, 53, 32, 40, 123, 52, 42, 36, 78, 125, 59, 36, 78, 41, 10, 49,
  44, 36, 78, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 36, 80,
  44, 123, 36, 119, 45, 49, 45, 36, 80, 125, 32, 45, 45, 114, 97, 110,
  100, 91, 45, 49, 93, 32, 36, 80, 44, 123, 36, 104, 45, 49, 45, 36,
  80, 125, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45,
  114, 111, 117, 110, 100, 91, 45, 49, 93, 10, 45, 45, 43, 91, 45, 49,
  93, 32, 39, 45, 36, 80, 44, 45, 36, 80, 39, 32, 45, 45, 43, 91,
  45, 50, 93, 32, 39, 36, 80, 44, 45, 36, 80, 39, 32, 45, 45, 43,
  91, 45, 51, 93, 32, 39, 36, 80, 44, 36, 80, 39, 32, 45, 45, 43,
  91, 45, 52, 93, 32, 39, 45, 36, 80, 44, 36, 80, 39, 10, 45, 97,
  91, 45, 52, 45, 45, 49, 93, 32, 120, 32, 45, 105, 91, 45, 50, 93,
  32, 40, 49, 50, 44, 48, 44, 49, 44, 50, 44, 51, 59, 49, 50, 44,
  123, 52, 42, 40, 36, 78, 45, 49, 41, 125, 44, 123, 52, 42, 40, 36,
  78, 45, 49, 41, 43, 49, 125, 44, 123, 52, 42, 40, 36, 78, 45, 49,
  41, 43, 50, 125, 44, 123, 52, 42, 40, 36, 78, 45, 49, 41, 43, 51,
  125, 41, 10, 45, 114, 91, 45, 50, 93, 32, 53, 44, 36, 78, 44, 49,
  44, 49, 44, 51, 32, 45, 114, 111, 117, 110, 100, 91, 45, 50, 93, 32,
  49, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 10, 49, 44,
  36, 78, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 123, 50, 50,
  53, 45, 36, 51, 125, 44, 123, 50, 50, 53, 43, 36, 51, 125, 32, 45,
  42, 91, 45, 49, 93, 32, 123, 112, 105, 47, 49, 56, 48, 125, 10, 45,
  45, 115, 105, 110, 91, 45, 49, 93, 32, 45, 99, 111, 115, 91, 45, 50,
  93, 32, 45, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 91, 45, 51,
  93, 32, 45, 97, 91, 45, 52, 45, 45, 51, 93, 32, 120, 32, 45, 97,
  91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 122, 91, 45, 52, 44,
  45, 50, 44, 45, 49, 93, 32, 48, 44, 50, 32, 45, 45, 42, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 49, 32, 45, 97, 91, 45, 52, 45, 45,
  49, 93, 32, 120, 32, 45, 42, 91, 45, 49, 93, 32, 123, 115, 113, 114,
  116, 40, 50, 41, 42, 36, 80, 125, 10, 45, 114, 91, 45, 51, 93, 32,
  52, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 48, 44,
  50, 32, 45, 43, 91, 45, 51, 44, 45, 49, 93, 10, 40, 45, 49, 50,
  56, 59, 36, 119, 59, 36, 104, 59, 36, 115, 41, 32, 45, 45, 98, 91,
  48, 93, 32, 36, 53, 10, 45, 105, 102, 32, 123, 36, 78, 62, 49, 125,
  32, 52, 44, 123, 36, 78, 45, 49, 125, 44, 49, 44, 49, 44, 45, 49,
  50, 56, 44, 48, 44, 48, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10,
  49, 44, 36, 78, 44, 49, 44, 49, 44, 49, 10, 45, 121, 91, 49, 45,
  45, 49, 93, 32, 45, 97, 91, 49, 45, 45, 49, 93, 32, 121, 32, 45,
  114, 118, 51, 100, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 52,
  62, 61, 49, 125, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 48,
  93, 32, 91, 49, 93, 44, 48, 44, 48, 44, 48, 44, 49, 44, 50, 44,
  48, 44, 48, 32, 45, 114, 109, 91, 49, 93, 10, 45, 101, 108, 115, 101,
  32, 45, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 48, 93, 32, 91,
  49, 93, 44, 48, 44, 48, 44, 48, 44, 49, 44, 50, 44, 48, 44, 48,
  32, 45, 114, 109, 91, 49, 93, 32, 45, 98, 108, 101, 110, 100, 32, 97,
  108, 112, 104, 97, 44, 36, 52, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  100, 114, 97, 119, 95, 119, 104, 105, 114, 108, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 49, 61, 49, 48, 48, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 119, 104, 105, 114, 108,
  32, 100, 114, 97, 119, 105, 110, 103, 32, 101, 102, 102, 101, 99, 116, 32,
  111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 32, 119, 105, 116, 104, 32,
  97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 36, 49, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32,
  45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 55, 48, 44, 50, 32,
  45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 91, 45, 49,
  93, 32, 91, 45, 50, 93, 32, 45, 97, 110, 100, 91, 45, 49, 44, 45,
  50, 93, 32, 45, 115, 109, 111, 111, 116, 104, 91, 45, 49, 93, 32, 36,
  49, 44, 48, 44, 49, 44, 50, 44, 50, 10, 45, 115, 113, 114, 116, 91,
  45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  32, 45, 101, 113, 117, 97, 108, 105, 122, 101, 91, 45, 49, 93, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  100, 114, 97, 119, 105, 110, 103, 32, 58, 32, 45, 115, 107, 105, 112, 32,
  36, 123, 49, 61, 50, 48, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 65, 112, 112, 108, 121, 32, 100, 114, 97, 119, 105, 110, 103, 32,
  101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36,
  63, 32, 119, 105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101,
  32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112,
  108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91, 48,
  93, 32, 45, 116, 111, 95, 114, 103, 98, 10, 45, 115, 109, 111, 111, 116,
  104, 32, 36, 49, 44, 48, 46, 50, 44, 49, 44, 51, 44, 51, 32, 45,
  98, 32, 50, 32, 45, 115, 104, 97, 114, 112, 101, 110, 32, 49, 48, 48,
  48, 32, 91, 48, 93, 10, 45, 114, 91, 48, 93, 32, 50, 48, 44, 50,
  48, 44, 49, 44, 51, 44, 50, 32, 45, 101, 113, 117, 97, 108, 105, 122,
  101, 91, 48, 93, 32, 45, 105, 110, 100, 101, 120, 91, 49, 93, 32, 91,
  48, 93, 44, 49, 44, 49, 10, 45, 110, 109, 91, 49, 93, 32, 64, 123,
  48, 44, 110, 125, 44, 49, 32, 45, 114, 109, 91, 48, 93, 10, 45, 101,
  110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 100, 114, 111, 112, 95, 115,
  104, 97, 100, 111, 119, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  36, 123, 51, 61, 53, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 52,
  61, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 52, 60, 61, 49, 34,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 50, 48, 125, 44, 36,
  123, 50, 61, 36, 49, 125, 44, 36, 123, 53, 61, 49, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 68, 114, 111, 112, 32, 115, 104, 97, 100,
  111, 119, 32, 98, 101, 104, 105, 110, 100, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 119, 105, 116, 104, 32, 111, 102, 102, 115, 101, 116, 115, 32,
  40, 36, 49, 44, 36, 50, 41, 44, 32, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 36, 51, 32, 97, 110, 100, 32, 99, 117, 114, 118, 97,
  116, 117, 114, 101, 32, 36, 52, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  116, 111, 95, 97, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 100, 120, 61, 123, 105, 102, 40, 64, 123,
  45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 49, 125,
  44, 119, 42, 36, 49, 44, 36, 49, 41, 125, 10, 100, 121, 61, 123, 105,
  102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92,
  32, 36, 50, 125, 44, 104, 42, 36, 50, 44, 36, 50, 41, 125, 10, 115,
  105, 103, 109, 97, 61, 123, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112,
  101, 114, 99, 101, 110, 116, 92, 32, 36, 51, 125, 44, 109, 97, 120, 40,
  119, 44, 104, 41, 42, 36, 51, 44, 36, 51, 41, 125, 10, 119, 61, 123,
  119, 125, 32, 104, 61, 123, 104, 125, 32, 115, 61, 123, 115, 125, 32, 45,
  45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 49, 48, 48, 37, 32, 99,
  111, 111, 114, 100, 115, 61, 64, 123, 45, 97, 117, 116, 111, 99, 114, 111,
  112, 95, 99, 111, 111, 114, 100, 115, 91, 45, 49, 93, 92, 32, 48, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 99, 114, 111, 112, 32, 36,
  99, 111, 111, 114, 100, 115, 10, 45, 114, 32, 123, 119, 43, 97, 98, 115,
  40, 36, 100, 120, 41, 125, 44, 123, 104, 43, 97, 98, 115, 40, 36, 100,
  121, 41, 125, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44, 48, 44, 123,
  105, 102, 40, 36, 100, 120, 62, 48, 44, 48, 44, 49, 41, 125, 44, 123,
  105, 102, 40, 36, 100, 121, 62, 48, 44, 48, 44, 49, 41, 125, 32, 45,
  114, 91, 45, 49, 93, 32, 123, 119, 43, 52, 42, 36, 115, 105, 103, 109,
  97, 125, 44, 123, 104, 43, 52, 42, 36, 115, 105, 103, 109, 97, 125, 44,
  49, 44, 49, 48, 48, 37, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48,
  46, 53, 10, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49,
  93, 32, 49, 48, 48, 37, 10, 45, 105, 102, 32, 123, 33, 36, 52, 125,
  32, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 36, 100, 120, 44,
  36, 100, 121, 10, 45, 101, 108, 115, 101, 10, 40, 48, 59, 123, 112, 105,
  125, 41, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 51,
  32, 45, 115, 105, 110, 91, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93,
  32, 45, 36, 52, 32, 45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 42,
  91, 45, 49, 93, 32, 36, 100, 120, 10, 40, 48, 44, 123, 112, 105, 125,
  41, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 51, 32,
  45, 115, 105, 110, 91, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32,
  45, 36, 52, 32, 45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 42, 91,
  45, 49, 93, 32, 36, 100, 121, 10, 45, 97, 91, 45, 50, 44, 45, 49,
  93, 32, 99, 32, 45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 44, 49, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 98, 91, 45, 49, 93, 32, 36,
  115, 105, 103, 109, 97, 44, 48, 10, 45, 114, 91, 45, 49, 93, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 50, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 49, 32, 45, 109, 118, 91, 45, 49, 93,
  32, 48, 32, 45, 98, 108, 101, 110, 100, 32, 97, 108, 112, 104, 97, 10,
  45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 49,
  48, 48, 37, 32, 45, 103, 101, 91, 45, 49, 93, 32, 49, 32, 45, 42,
  32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 48, 10, 45, 105, 102,
  32, 123, 33, 36, 53, 125, 32, 36, 119, 44, 36, 104, 44, 49, 44, 36,
  115, 32, 45, 106, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 123, 97,
  114, 103, 40, 49, 44, 36, 99, 111, 111, 114, 100, 115, 41, 125, 44, 123,
  97, 114, 103, 40, 50, 44, 36, 99, 111, 111, 114, 100, 115, 41, 125, 32,
  45, 114, 109, 91, 45, 50, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  101, 108, 108, 105, 112, 115, 105, 111, 110, 105, 115, 109, 32, 58, 32, 45,
  99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 49, 48, 125, 62, 48,
  32, 38, 38, 32, 36, 123, 50, 61, 51, 125, 62, 48, 32, 38, 38, 32,
  36, 123, 53, 61, 56, 125, 62, 48, 32, 38, 38, 32, 36, 123, 54, 61,
  48, 46, 54, 125, 62, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  51, 61, 49, 37, 125, 44, 36, 123, 52, 61, 48, 46, 55, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 101, 108,
  108, 105, 112, 115, 105, 111, 110, 105, 115, 109, 32, 102, 105, 108, 116, 101,
  114, 32, 116, 111, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105,
  116, 104, 32, 114, 97, 100, 105, 105, 32, 40, 36, 49, 44, 36, 50, 41,
  44, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 51, 44,
  32, 111, 112, 97, 99, 105, 116, 121, 32, 36, 52, 32, 97, 110, 100, 32,
  111, 117, 116, 108, 105, 110, 101, 32, 36, 53, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 108,
  117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 103, 91, 45, 49, 93, 32,
  120, 121, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32, 45,
  98, 91, 45, 49, 93, 32, 36, 51, 32, 45, 111, 114, 105, 101, 110, 116,
  97, 116, 105, 111, 110, 91, 45, 49, 93, 10, 45, 115, 104, 91, 45, 49,
  93, 32, 48, 44, 48, 32, 45, 115, 104, 91, 45, 50, 93, 32, 49, 44,
  49, 32, 45, 97, 116, 97, 110, 50, 91, 45, 49, 93, 32, 91, 45, 50,
  93, 32, 45, 42, 91, 45, 49, 93, 32, 123, 49, 56, 48, 47, 112, 105,
  125, 32, 45, 43, 91, 45, 49, 93, 32, 57, 48, 32, 45, 114, 109, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115,
  91, 45, 49, 93, 32, 49, 44, 49, 10, 91, 45, 50, 93, 44, 91, 45,
  50, 93, 44, 49, 44, 91, 45, 50, 93, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 36, 54, 42, 119, 42, 104, 47, 109, 97, 120, 40, 36, 49,
  44, 36, 50, 41, 125, 10, 120, 121, 61, 123, 63, 40, 119, 41, 125, 44,
  123, 63, 40, 104, 41, 125, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91,
  45, 49, 93, 32, 36, 120, 121, 44, 36, 49, 44, 36, 50, 44, 64, 123,
  45, 50, 44, 40, 36, 120, 121, 41, 125, 44, 36, 52, 44, 92, 10, 64,
  123, 45, 51, 44, 40, 36, 120, 121, 44, 48, 44, 48, 41, 125, 44, 64,
  123, 45, 51, 44, 40, 36, 120, 121, 44, 48, 44, 49, 41, 125, 44, 64,
  123, 45, 51, 44, 40, 36, 120, 121, 44, 48, 44, 50, 41, 125, 44, 64,
  123, 45, 51, 44, 40, 36, 120, 121, 44, 48, 44, 51, 41, 125, 10, 45,
  101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 120, 121, 44,
  36, 49, 44, 36, 50, 44, 64, 123, 45, 50, 44, 40, 36, 120, 121, 41,
  125, 44, 36, 52, 44, 48, 120, 49, 44, 92, 10, 123, 64, 123, 45, 51,
  44, 40, 36, 120, 121, 44, 48, 44, 48, 41, 125, 47, 36, 53, 125, 44,
  123, 64, 123, 45, 51, 44, 40, 36, 120, 121, 44, 48, 44, 49, 41, 125,
  47, 36, 53, 125, 44, 123, 64, 123, 45, 51, 44, 40, 36, 120, 121, 44,
  48, 44, 50, 41, 125, 47, 36, 53, 125, 44, 123, 64, 123, 45, 51, 44,
  40, 36, 120, 121, 44, 48, 44, 51, 41, 125, 47, 36, 53, 125, 10, 45,
  100, 111, 110, 101, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 110, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 98, 108, 101, 110, 100, 91,
  45, 50, 44, 45, 49, 93, 32, 97, 108, 112, 104, 97, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 102, 105,
  114, 101, 95, 101, 100, 103, 101, 115, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 34, 36, 123, 49, 61, 48, 46, 55, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 123, 50, 61, 48, 46, 50, 53, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 50, 60, 61, 49, 32, 38, 38, 32, 36, 123, 51, 61, 48,
  46, 53, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 52, 61, 50, 53,
  125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 53, 61, 49, 125, 62, 48,
  32, 38, 38, 32, 36, 123, 54, 61, 50, 48, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 123, 55, 61, 48, 125, 62, 61, 48, 34, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 71, 101, 110, 101, 114, 97, 116, 101, 32, 102,
  105, 114, 101, 32, 101, 102, 102, 101, 99, 116, 32, 102, 114, 111, 109, 32,
  101, 100, 103, 101, 115, 32, 111, 102, 32, 105, 109, 97, 103, 101, 36, 63,
  44, 32, 119, 105, 116, 104, 32, 101, 100, 103, 101, 115, 32, 36, 49, 44,
  32, 97, 116, 116, 101, 110, 117, 97, 116, 105, 111, 110, 32, 36, 50, 44,
  32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 51, 44, 32,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 36, 52, 44, 32, 34, 92,
  10, 34, 36, 53, 32, 102, 114, 97, 109, 101, 115, 44, 32, 115, 116, 97,
  114, 116, 105, 110, 103, 32, 102, 114, 97, 109, 101, 32, 36, 54, 32, 97,
  110, 100, 32, 102, 114, 97, 109, 101, 32, 115, 107, 105, 112, 32, 36, 55,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48,
  44, 110, 125, 10, 45, 110, 111, 114, 109, 32, 45, 45, 103, 114, 97, 100,
  105, 101, 110, 116, 95, 110, 111, 114, 109, 32, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 49, 32, 45, 114, 111, 117, 110, 100, 105, 102, 121, 91, 45,
  49, 93, 32, 36, 49, 32, 45, 102, 91, 48, 93, 32, 48, 10, 40, 48,
  44, 48, 44, 48, 59, 48, 44, 48, 44, 48, 59, 49, 44, 49, 44, 49,
  59, 48, 44, 49, 44, 48, 41, 32, 45, 42, 91, 45, 49, 93, 32, 123,
  40, 49, 45, 36, 50, 94, 52, 41, 47, 52, 125, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 36, 53, 42, 40, 49, 43, 36, 55, 41, 43, 36,
  54, 125, 10, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125,
  32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  32, 45, 42, 91, 45, 49, 93, 32, 91, 49, 93, 10, 45, 98, 91, 45,
  49, 93, 32, 36, 51, 10, 45, 105, 102, 32, 36, 52, 32, 45, 103, 101,
  91, 45, 49, 93, 32, 36, 52, 37, 32, 45, 101, 108, 115, 101, 32, 45,
  101, 113, 117, 97, 108, 105, 122, 101, 91, 45, 49, 93, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  10, 45, 106, 91, 48, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 49, 44, 91, 49, 93, 44, 49, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 99, 111, 114, 114, 101, 108, 97, 116, 101, 91, 48,
  93, 32, 91, 50, 93, 10, 45, 105, 102, 32, 123, 36, 62, 62, 61, 36,
  54, 34, 32, 38, 38, 32, 34, 40, 36, 62, 45, 36, 54, 41, 37, 40,
  36, 55, 43, 49, 41, 61, 61, 48, 125, 32, 91, 48, 93, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48,
  45, 50, 93, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 40, 48, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 94, 48, 44, 48,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 94, 48, 44, 48,
  44, 48, 44, 49, 50, 56, 44, 50, 53, 53, 41, 32, 45, 114, 91, 45,
  49, 93, 32, 50, 53, 54, 44, 49, 44, 49, 44, 51, 44, 51, 10, 45,
  109, 97, 112, 91, 94, 45, 49, 93, 32, 91, 45, 49, 93, 32, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 118, 32, 43, 10, 103, 108, 111, 119, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 37, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 100, 100, 32, 115, 111, 102,
  116, 32, 103, 108, 111, 119, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 119, 105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117, 100,
  101, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115,
  112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 45, 98,
  91, 48, 93, 32, 36, 49, 32, 45, 110, 91, 45, 49, 93, 32, 91, 48,
  93, 32, 45, 98, 108, 101, 110, 100, 95, 101, 100, 103, 101, 115, 91, 48,
  44, 45, 49, 93, 32, 49, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 104, 97, 108,
  102, 116, 111, 110, 101, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  36, 123, 49, 61, 53, 125, 62, 61, 50, 32, 38, 38, 32, 36, 123, 50,
  61, 56, 125, 62, 61, 50, 32, 38, 38, 32, 36, 123, 51, 61, 56, 125,
  62, 61, 50, 32, 38, 38, 32, 36, 123, 53, 61, 48, 125, 62, 61, 48,
  34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 52, 61, 53, 125, 10, 45,
  118, 32, 45, 32, 115, 48, 61, 34, 115, 113, 117, 97, 114, 101, 34, 32,
  115, 49, 61, 34, 100, 105, 97, 109, 111, 110, 100, 34, 32, 115, 50, 61,
  34, 99, 105, 114, 99, 108, 101, 34, 32, 115, 51, 61, 34, 105, 110, 118,
  45, 115, 113, 117, 97, 114, 101, 34, 32, 115, 52, 61, 34, 105, 110, 118,
  45, 100, 105, 97, 109, 111, 110, 100, 34, 32, 115, 53, 61, 34, 105, 110,
  118, 45, 99, 105, 114, 99, 108, 101, 34, 32, 45, 118, 32, 43, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 104, 97,
  108, 102, 116, 111, 110, 101, 32, 100, 105, 116, 104, 101, 114, 105, 110, 103,
  32, 116, 111, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116,
  104, 32, 36, 49, 32, 108, 101, 118, 101, 108, 115, 44, 32, 100, 97, 114,
  107, 32, 115, 105, 122, 101, 32, 36, 51, 44, 32, 98, 114, 105, 103, 104,
  116, 32, 115, 105, 122, 101, 32, 36, 52, 44, 32, 34, 36, 123, 115, 36,
  52, 125, 34, 32, 115, 104, 97, 112, 101, 32, 97, 110, 100, 32, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 53, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 32, 45, 115, 32, 99, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 40, 48, 44, 50,
  53, 53, 41, 32, 45, 97, 32, 121, 32, 45, 113, 117, 97, 110, 116, 105,
  122, 101, 32, 36, 49, 44, 48, 32, 45, 114, 111, 119, 115, 32, 48, 44,
  123, 104, 45, 50, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49,
  10, 115, 61, 123, 114, 111, 117, 110, 100, 40, 40, 36, 50, 42, 36, 60,
  43, 36, 51, 42, 36, 62, 41, 47, 40, 36, 49, 45, 49, 41, 41, 125,
  10, 36, 115, 44, 36, 115, 32, 45, 61, 91, 45, 49, 93, 32, 49, 44,
  53, 48, 37, 44, 53, 48, 37, 32, 45, 100, 105, 115, 116, 97, 110, 99,
  101, 91, 45, 49, 93, 32, 49, 44, 123, 36, 52, 37, 51, 125, 32, 45,
  45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53,
  48, 37, 44, 48, 44, 48, 44, 50, 32, 45, 109, 105, 110, 91, 45, 50,
  44, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 52, 62, 61, 51, 125,
  32, 45, 108, 116, 91, 45, 49, 93, 32, 123, 49, 48, 48, 42, 36, 60,
  47, 40, 36, 49, 45, 49, 46, 49, 41, 125, 37, 32, 45, 42, 91, 45,
  49, 93, 32, 123, 45, 50, 53, 53, 125, 32, 45, 43, 91, 45, 49, 93,
  32, 123, 50, 53, 53, 45, 36, 62, 125, 10, 45, 101, 108, 115, 101, 32,
  45, 108, 116, 91, 45, 49, 93, 32, 123, 49, 48, 48, 42, 36, 62, 47,
  40, 36, 49, 45, 49, 46, 49, 41, 125, 37, 32, 45, 42, 91, 45, 49,
  93, 32, 50, 53, 53, 32, 45, 45, 91, 45, 49, 93, 32, 36, 62, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 114, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 44, 48, 44, 50, 32, 45, 98, 91, 45, 49, 93, 32, 36, 53,
  32, 45, 45, 101, 113, 91, 45, 50, 93, 32, 36, 62, 32, 45, 42, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93,
  10, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 104, 97, 114, 100, 115, 107, 101,
  116, 99, 104, 98, 119, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  49, 61, 51, 48, 48, 125, 44, 36, 123, 50, 61, 53, 48, 125, 44, 36,
  123, 51, 61, 48, 46, 49, 125, 44, 36, 123, 52, 61, 50, 48, 125, 44,
  36, 123, 53, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  65, 112, 112, 108, 121, 32, 104, 97, 114, 100, 32, 66, 38, 87, 32, 115,
  107, 101, 116, 99, 104, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32,
  105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 97, 109,
  112, 108, 105, 116, 117, 100, 101, 32, 36, 49, 44, 32, 100, 101, 110, 115,
  105, 116, 121, 32, 36, 50, 44, 32, 111, 112, 97, 99, 105, 116, 121, 32,
  36, 51, 32, 97, 110, 100, 32, 101, 100, 103, 101, 32, 116, 104, 114, 101,
  115, 104, 111, 108, 100, 32, 36, 52, 46, 34, 10, 45, 105, 102, 32, 123,
  33, 36, 50, 125, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48,
  32, 45, 102, 32, 50, 53, 53, 32, 45, 114, 101, 116, 117, 114, 110, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 32, 45, 108, 117, 109,
  105, 110, 97, 110, 99, 101, 32, 45, 110, 32, 48, 44, 49, 10, 45, 105,
  102, 32, 36, 53, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44, 110, 125,
  10, 45, 103, 32, 120, 121, 32, 45, 114, 118, 32, 45, 42, 91, 45, 50,
  93, 32, 45, 49, 32, 45, 97, 32, 99, 10, 45, 105, 102, 32, 36, 52,
  32, 45, 45, 110, 111, 114, 109, 32, 45, 103, 101, 91, 45, 49, 93, 32,
  36, 52, 37, 32, 45, 42, 32, 45, 101, 110, 100, 105, 102, 10, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 50, 53, 53, 32,
  45, 113, 117, 105, 118, 101, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  44, 123, 109, 97, 120, 40, 49, 44, 49, 48, 45, 36, 50, 47, 54, 41,
  125, 44, 36, 49, 44, 48, 44, 36, 51, 32, 45, 114, 109, 91, 45, 50,
  93, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 115, 101, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32,
  110, 109, 61, 64, 123, 48, 44, 110, 125, 10, 119, 61, 123, 119, 125, 32,
  104, 61, 123, 104, 125, 32, 45, 103, 32, 120, 121, 32, 45, 114, 118, 32,
  45, 42, 91, 45, 50, 93, 32, 45, 49, 32, 45, 97, 32, 99, 32, 45,
  42, 32, 36, 49, 10, 45, 45, 110, 111, 114, 109, 32, 45, 103, 101, 91,
  45, 49, 93, 32, 36, 52, 37, 32, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 36, 50, 44,
  50, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 10, 45, 112, 111, 105,
  110, 116, 99, 108, 111, 117, 100, 51, 100, 91, 45, 49, 93, 32, 45, 115,
  51, 100, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 54, 45, 45, 53,
  44, 45, 51, 45, 45, 49, 93, 32, 45, 114, 91, 45, 49, 93, 32, 51,
  44, 123, 104, 47, 51, 125, 44, 49, 44, 49, 44, 45, 49, 32, 45, 115,
  91, 45, 49, 93, 32, 120, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 119, 97, 114, 112,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 32, 45, 45,
  45, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 43, 91, 45, 51,
  44, 45, 50, 93, 32, 45, 115, 91, 45, 50, 44, 45, 49, 93, 32, 99,
  10, 45, 105, 91, 45, 51, 93, 32, 49, 44, 123, 104, 125, 32, 49, 44,
  123, 104, 125, 32, 45, 97, 91, 45, 54, 45, 45, 49, 93, 32, 120, 10,
  45, 105, 91, 45, 50, 93, 32, 40, 123, 39, 67, 73, 109, 103, 51, 100,
  39, 125, 41, 32, 45, 105, 91, 45, 50, 93, 32, 40, 123, 50, 42, 104,
  125, 44, 123, 104, 125, 41, 10, 49, 44, 123, 104, 125, 44, 49, 44, 49,
  44, 50, 32, 49, 44, 123, 104, 125, 44, 49, 44, 49, 44, 50, 42, 121,
  32, 45, 45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 97, 91, 45, 51,
  45, 45, 49, 93, 32, 120, 10, 51, 44, 123, 104, 125, 32, 49, 44, 123,
  104, 125, 44, 49, 44, 49, 44, 36, 51, 32, 45, 121, 91, 45, 54, 45,
  45, 49, 93, 32, 45, 97, 91, 45, 54, 45, 45, 49, 93, 32, 121, 10,
  36, 119, 44, 36, 104, 44, 49, 44, 49, 44, 50, 53, 53, 32, 45, 111,
  98, 106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  44, 48, 44, 48, 44, 48, 44, 49, 44, 49, 44, 48, 44, 48, 32, 45,
  114, 109, 91, 45, 50, 93, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 110,
  100, 105, 102, 32, 45, 118, 32, 43, 10, 104, 101, 97, 114, 116, 115, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 48, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 104,
  101, 97, 114, 116, 32, 102, 105, 108, 116, 101, 114, 32, 111, 110, 32, 105,
  109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 100, 101, 110,
  115, 105, 116, 121, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 32, 45, 110, 111,
  105, 115, 101, 91, 45, 49, 93, 32, 36, 49, 44, 50, 32, 45, 114, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 110, 91, 45, 49, 93, 32,
  48, 44, 49, 32, 45, 42, 91, 45, 49, 44, 45, 50, 93, 32, 45, 95,
  104, 101, 97, 114, 116, 57, 120, 55, 10, 45, 109, 105, 114, 114, 111, 114,
  91, 45, 49, 93, 32, 121, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 95, 104, 101, 97, 114, 116, 57, 120, 55, 32, 58, 10, 40, 48, 44,
  49, 44, 49, 44, 48, 44, 48, 44, 48, 44, 49, 44, 49, 44, 48, 59,
  49, 44, 49, 44, 49, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49, 44,
  49, 59, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44,
  49, 44, 49, 59, 48, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44,
  49, 44, 49, 44, 48, 59, 48, 44, 48, 44, 49, 44, 49, 44, 49, 44,
  49, 44, 49, 44, 48, 44, 48, 59, 48, 44, 48, 44, 48, 44, 49, 44,
  49, 44, 49, 44, 48, 44, 48, 44, 48, 59, 48, 44, 48, 44, 48, 44,
  48, 44, 49, 44, 48, 44, 48, 44, 48, 44, 48, 41, 10, 104, 111, 117,
  103, 104, 115, 107, 101, 116, 99, 104, 98, 119, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 36, 123, 49, 61, 56, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 123, 50, 61, 53, 125, 62, 61, 48, 32, 38, 38, 32, 36,
  123, 51, 61, 56, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 51, 60,
  61, 49, 48, 48, 32, 38, 38, 32, 36, 123, 52, 61, 48, 46, 49, 125,
  62, 61, 48, 32, 38, 38, 32, 36, 52, 60, 61, 49, 32, 38, 38, 32,
  36, 123, 53, 61, 49, 48, 48, 37, 125, 62, 48, 34, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 104, 111, 117, 103,
  104, 32, 66, 38, 87, 32, 115, 107, 101, 116, 99, 104, 32, 101, 102, 102,
  101, 99, 116, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32,
  119, 105, 116, 104, 32, 100, 101, 110, 115, 105, 116, 121, 32, 36, 49, 44,
  32, 114, 97, 100, 105, 117, 115, 32, 36, 50, 44, 32, 116, 104, 114, 101,
  115, 104, 111, 108, 100, 32, 36, 51, 44, 32, 111, 112, 97, 99, 105, 116,
  121, 32, 36, 52, 32, 97, 110, 100, 32, 118, 111, 116, 101, 115, 105, 122,
  101, 32, 36, 53, 46, 34, 10, 45, 118, 32, 45, 32, 45, 108, 117, 109,
  105, 110, 97, 110, 99, 101, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 110, 109, 61, 64, 123, 48, 44,
  110, 125, 10, 114, 101, 115, 61, 123, 114, 111, 117, 110, 100, 40, 105, 102,
  40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32,
  36, 53, 125, 44, 36, 53, 42, 109, 97, 120, 40, 119, 44, 104, 41, 44,
  36, 53, 41, 41, 125, 32, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104,
  125, 32, 114, 104, 111, 109, 97, 120, 61, 123, 115, 113, 114, 116, 40, 119,
  94, 50, 43, 104, 94, 50, 41, 47, 50, 125, 10, 45, 104, 111, 117, 103,
  104, 32, 36, 114, 101, 115, 44, 36, 114, 101, 115, 32, 45, 110, 32, 48,
  44, 50, 53, 53, 10, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95,
  108, 111, 99, 97, 108, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 32,
  45, 103, 101, 91, 45, 49, 93, 32, 36, 51, 37, 32, 45, 112, 111, 105,
  110, 116, 99, 108, 111, 117, 100, 51, 100, 91, 45, 49, 93, 10, 45, 115,
  51, 100, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 54, 45, 45, 53,
  44, 45, 51, 45, 45, 49, 93, 32, 45, 114, 91, 45, 49, 93, 32, 51,
  44, 123, 104, 47, 51, 125, 44, 49, 44, 49, 44, 45, 49, 32, 45, 99,
  111, 108, 117, 109, 110, 115, 91, 45, 49, 93, 32, 48, 44, 49, 10, 45,
  115, 91, 45, 49, 93, 32, 120, 44, 50, 10, 45, 42, 91, 45, 50, 93,
  32, 123, 50, 42, 112, 105, 47, 36, 114, 101, 115, 125, 10, 45, 42, 91,
  45, 49, 93, 32, 123, 36, 114, 104, 111, 109, 97, 120, 47, 36, 114, 101,
  115, 125, 10, 45, 45, 99, 111, 115, 91, 45, 50, 93, 32, 45, 42, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 43, 91, 45, 49, 93, 32,
  123, 36, 119, 47, 50, 125, 10, 45, 45, 115, 105, 110, 91, 45, 51, 93,
  32, 45, 42, 91, 45, 49, 93, 32, 91, 45, 51, 93, 32, 45, 43, 91,
  45, 49, 93, 32, 123, 36, 104, 47, 50, 125, 10, 45, 114, 109, 91, 45,
  51, 93, 10, 45, 105, 91, 45, 51, 93, 32, 91, 45, 51, 93, 10, 45,
  99, 111, 115, 91, 45, 52, 93, 32, 45, 115, 105, 110, 91, 45, 51, 93,
  32, 45, 42, 91, 45, 52, 44, 45, 51, 93, 32, 49, 48, 48, 48, 48,
  10, 45, 45, 43, 91, 45, 50, 93, 32, 91, 45, 51, 93, 10, 45, 45,
  45, 91, 45, 50, 93, 32, 91, 45, 53, 93, 10, 45, 45, 91, 45, 52,
  93, 32, 91, 45, 53, 93, 10, 45, 43, 91, 45, 51, 93, 32, 91, 45,
  54, 93, 10, 45, 114, 109, 91, 45, 54, 44, 45, 53, 93, 10, 45, 105,
  91, 45, 51, 93, 32, 49, 44, 123, 104, 125, 32, 49, 44, 123, 104, 125,
  32, 45, 97, 91, 45, 54, 45, 45, 49, 93, 32, 120, 10, 45, 105, 91,
  45, 50, 93, 32, 40, 123, 39, 67, 73, 109, 103, 51, 100, 39, 125, 41,
  32, 45, 105, 91, 45, 50, 93, 32, 40, 123, 50, 42, 104, 125, 44, 123,
  104, 125, 41, 10, 49, 44, 123, 104, 125, 44, 49, 44, 49, 44, 50, 32,
  49, 44, 123, 104, 125, 44, 49, 44, 49, 44, 50, 42, 121, 32, 45, 45,
  43, 91, 45, 49, 93, 32, 49, 32, 45, 97, 91, 45, 51, 45, 45, 49,
  93, 32, 120, 10, 51, 44, 123, 104, 125, 44, 49, 44, 49, 44, 48, 32,
  49, 44, 123, 104, 125, 44, 49, 44, 49, 44, 36, 52, 10, 45, 121, 91,
  45, 54, 45, 45, 49, 93, 32, 45, 97, 91, 45, 54, 45, 45, 49, 93,
  32, 121, 10, 36, 119, 44, 36, 104, 44, 49, 44, 49, 44, 50, 53, 53,
  32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91,
  45, 50, 93, 44, 48, 44, 48, 44, 48, 44, 49, 44, 49, 44, 48, 44,
  48, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 110, 109, 32, 36, 110,
  109, 44, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 108, 105, 103, 104, 116, 114, 97, 121, 115, 32, 58,
  32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 53, 48, 125,
  62, 61, 48, 32, 38, 38, 32, 36, 49, 60, 61, 49, 48, 48, 32, 38,
  38, 32, 36, 123, 52, 61, 49, 125, 32, 38, 38, 32, 36, 123, 53, 61,
  49, 125, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50,
  61, 48, 46, 53, 125, 44, 36, 123, 51, 61, 48, 46, 53, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 71, 101, 110, 101, 114, 97, 116, 101,
  32, 114, 97, 121, 32, 108, 105, 103, 104, 116, 115, 32, 102, 114, 111, 109,
  32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 100,
  101, 110, 115, 105, 116, 121, 32, 36, 49, 44, 32, 99, 101, 110, 116, 101,
  114, 32, 40, 36, 50, 44, 36, 51, 41, 44, 32, 114, 97, 121, 32, 108,
  101, 110, 103, 116, 104, 32, 36, 52, 32, 97, 110, 100, 32, 97, 116, 116,
  101, 110, 117, 97, 116, 105, 111, 110, 32, 36, 53, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110,
  111, 114, 109, 32, 45, 42, 32, 45, 49, 32, 45, 108, 116, 32, 36, 49,
  37, 32, 45, 101, 117, 99, 108, 105, 100, 101, 97, 110, 50, 112, 111, 108,
  97, 114, 32, 36, 50, 44, 36, 51, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 123, 108, 111, 103, 50, 40, 119, 41, 125, 32, 45, 45, 115, 104, 105,
  102, 116, 91, 45, 49, 93, 32, 123, 50, 94, 36, 62, 125, 32, 45, 43,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 102,
  117, 110, 99, 116, 105, 111, 110, 49, 100, 32, 48, 46, 53, 44, 48, 44,
  49, 44, 123, 36, 52, 42, 119, 125, 44, 49, 44, 123, 49, 43, 40, 36,
  52, 43, 49, 45, 36, 53, 41, 42, 119, 125, 44, 48, 32, 45, 114, 91,
  45, 49, 93, 32, 64, 123, 45, 50, 44, 119, 125, 44, 49, 44, 49, 44,
  49, 44, 48, 10, 40, 49, 44, 123, 119, 125, 41, 32, 45, 114, 91, 45,
  49, 93, 32, 64, 123, 45, 50, 44, 119, 125, 44, 49, 44, 49, 44, 49,
  44, 51, 32, 45, 47, 91, 45, 50, 44, 45, 49, 93, 10, 45, 114, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 42, 91, 45, 50, 44, 45,
  49, 93, 32, 45, 112, 111, 108, 97, 114, 50, 101, 117, 99, 108, 105, 100,
  101, 97, 110, 32, 36, 50, 44, 36, 51, 32, 45, 110, 32, 48, 44, 50,
  53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 108, 105, 103, 104, 116, 95, 114, 101, 108, 105, 101, 102,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 46, 51,
  125, 44, 36, 123, 50, 61, 48, 46, 53, 125, 44, 36, 123, 51, 61, 48,
  46, 50, 125, 44, 36, 123, 52, 61, 48, 125, 44, 36, 123, 53, 61, 48,
  46, 50, 125, 44, 36, 123, 54, 61, 48, 46, 53, 125, 44, 36, 123, 55,
  61, 48, 46, 53, 125, 44, 36, 123, 56, 61, 49, 125, 44, 36, 123, 57,
  61, 49, 125, 44, 36, 123, 49, 48, 61, 48, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 114, 101, 108, 105, 101,
  102, 32, 108, 105, 103, 104, 116, 32, 116, 111, 32, 105, 109, 97, 103, 101,
  36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 40, 123, 45, 36,
  54, 125, 44, 123, 49, 45, 36, 54, 125, 59, 123, 45, 36, 54, 125, 44,
  123, 49, 45, 36, 54, 125, 94, 123, 45, 36, 55, 125, 44, 123, 45, 36,
  55, 125, 59, 123, 49, 45, 36, 55, 125, 44, 123, 49, 45, 36, 55, 125,
  94, 36, 56, 44, 36, 56, 59, 36, 56, 44, 36, 56, 41, 32, 45, 114,
  91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 49,
  44, 51, 44, 51, 10, 45, 105, 102, 32, 36, 49, 48, 32, 45, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 91, 45, 50, 93, 32, 51, 32, 45, 116,
  111, 95, 114, 103, 98, 91, 45, 51, 93, 32, 45, 101, 108, 115, 101, 32,
  45, 45, 116, 111, 95, 114, 103, 98, 91, 45, 50, 93, 32, 45, 110, 111,
  114, 109, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 98,
  91, 45, 49, 93, 32, 36, 53, 37, 32, 45, 103, 91, 45, 49, 93, 32,
  120, 121, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49,
  44, 36, 57, 32, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 99,
  10, 45, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  115, 91, 45, 49, 93, 32, 99, 32, 45, 43, 91, 45, 51, 45, 45, 49,
  93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 61, 91, 45,
  49, 93, 32, 49, 44, 123, 36, 54, 42, 49, 48, 48, 125, 37, 44, 123,
  36, 55, 42, 49, 48, 48, 125, 37, 32, 45, 100, 105, 115, 116, 97, 110,
  99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 115, 113, 114, 91, 45, 49,
  93, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 10, 45, 47, 91, 45,
  49, 93, 32, 123, 40, 36, 51, 42, 109, 97, 120, 40, 119, 44, 104, 41,
  41, 94, 50, 125, 32, 45, 101, 120, 112, 91, 45, 49, 93, 32, 45, 42,
  91, 45, 49, 93, 32, 36, 50, 32, 45, 43, 91, 45, 49, 93, 32, 36,
  49, 10, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 45, 91, 45,
  49, 93, 32, 36, 52, 32, 45, 42, 91, 45, 49, 93, 32, 64, 123, 45,
  50, 44, 77, 125, 10, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99,
  105, 116, 121, 91, 48, 93, 32, 45, 43, 91, 48, 44, 45, 49, 93, 32,
  45, 97, 32, 99, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 109,
  111, 115, 97, 105, 99, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  49, 61, 48, 46, 56, 125, 44, 36, 123, 50, 61, 49, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 109, 111, 115,
  97, 105, 99, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109,
  97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 100, 101, 110, 115,
  105, 116, 121, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  108, 97, 98, 101, 108, 48, 61, 123, 49, 43, 105, 109, 125, 32, 45, 43,
  32, 36, 108, 97, 98, 101, 108, 48, 10, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 123, 36,
  49, 42, 50, 125, 44, 50, 32, 45, 42, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93,
  32, 49, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 119, 97,
  116, 101, 114, 115, 104, 101, 100, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  44, 123, 105, 102, 40, 36, 50, 44, 48, 44, 49, 41, 125, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 105, 102, 32, 36, 50, 32, 45, 45, 108,
  91, 45, 49, 93, 32, 45, 103, 116, 32, 48, 32, 45, 115, 32, 99, 32,
  45, 97, 110, 100, 32, 45, 101, 110, 100, 108, 32, 45, 45, 91, 45, 50,
  93, 32, 36, 108, 97, 98, 101, 108, 48, 32, 45, 42, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 101, 108, 115, 101, 32, 45, 45, 91, 45, 49, 93,
  32, 36, 108, 97, 98, 101, 108, 48, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 111, 108, 100, 95, 112, 104, 111, 116, 111, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 111, 108, 100, 32,
  112, 104, 111, 116, 111, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32,
  105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  110, 111, 105, 115, 101, 32, 50, 48, 32, 45, 98, 105, 108, 97, 116, 101,
  114, 97, 108, 32, 51, 48, 44, 54, 48, 32, 45, 98, 32, 50, 32, 45,
  115, 104, 97, 114, 112, 101, 110, 32, 49, 48, 48, 32, 45, 102, 114, 97,
  109, 101, 95, 102, 117, 122, 122, 121, 32, 50, 48, 44, 50, 48, 44, 54,
  44, 51, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 115, 104, 97, 100,
  111, 119, 95, 112, 97, 116, 99, 104, 32, 48, 46, 55, 53, 32, 45, 110,
  32, 48, 44, 50, 53, 53, 32, 45, 115, 101, 112, 105, 97, 32, 45, 118,
  32, 43, 10, 112, 101, 110, 99, 105, 108, 98, 119, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 49, 61, 48, 46, 51, 125, 44, 36, 123, 50,
  61, 54, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112,
  112, 108, 121, 32, 66, 38, 87, 32, 112, 101, 110, 99, 105, 108, 32, 101,
  102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63,
  44, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101, 32, 36, 49, 32, 97,
  110, 100, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 36, 50, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95,
  111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91, 48, 93, 32, 45, 110,
  111, 114, 109, 32, 45, 98, 32, 36, 49, 32, 45, 115, 104, 97, 114, 112,
  101, 110, 32, 52, 48, 48, 48, 32, 45, 115, 109, 111, 111, 116, 104, 32,
  36, 50, 44, 48, 44, 49, 32, 45, 101, 113, 117, 97, 108, 105, 122, 101,
  32, 45, 115, 113, 114, 116, 32, 45, 110, 32, 48, 44, 50, 53, 53, 32,
  45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 112, 111, 108, 97,
  114, 111, 105, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36,
  123, 49, 61, 49, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50,
  61, 50, 48, 125, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 67, 114, 101, 97, 116, 101, 32, 112, 111, 108, 97, 114, 111, 105,
  100, 32, 101, 102, 102, 101, 99, 116, 32, 105, 110, 32, 105, 109, 97, 103,
  101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 98, 111, 114, 100, 101, 114,
  115, 32, 115, 105, 122, 101, 115, 32, 36, 49, 32, 97, 110, 100, 32, 36,
  50, 46, 34, 10, 45, 118, 32, 45, 32, 45, 45, 32, 50, 53, 53, 32,
  45, 114, 32, 123, 49, 48, 48, 43, 36, 49, 125, 37, 44, 123, 49, 48,
  48, 43, 36, 49, 125, 37, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 114, 32, 49, 48, 48,
  37, 44, 123, 49, 48, 48, 43, 36, 50, 125, 37, 44, 49, 44, 49, 48,
  48, 37, 44, 48, 44, 48, 44, 48, 32, 45, 43, 32, 50, 53, 53, 32,
  45, 118, 32, 43, 10, 112, 111, 108, 121, 103, 111, 110, 105, 122, 101, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 51, 48,
  48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 50, 37, 125,
  62, 61, 48, 32, 38, 38, 32, 36, 123, 51, 61, 48, 46, 49, 37, 125,
  62, 61, 48, 32, 38, 38, 32, 36, 123, 52, 61, 49, 48, 37, 125, 62,
  48, 32, 38, 38, 32, 36, 123, 53, 61, 36, 52, 125, 62, 48, 34, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 80, 111, 108, 121, 103, 111, 110,
  105, 122, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 119, 105, 116, 104,
  32, 119, 97, 114, 112, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32,
  36, 49, 44, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36,
  50, 44, 32, 109, 105, 110, 105, 109, 97, 108, 32, 97, 114, 101, 97, 32,
  36, 51, 32, 97, 110, 100, 32, 114, 101, 115, 111, 108, 117, 116, 105, 111,
  110, 115, 32, 40, 36, 52, 44, 36, 53, 41, 46, 34, 10, 45, 118, 32,
  45, 32, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 45, 98, 32, 36, 50, 32, 45, 103, 114, 97,
  100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 91, 45, 49, 93, 32, 45,
  103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32, 45, 97, 91,
  45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 99, 104, 97, 110, 110, 101,
  108, 115, 91, 45, 49, 93, 32, 48, 44, 50, 32, 45, 42, 91, 45, 49,
  93, 32, 123, 49, 47, 48, 46, 49, 43, 109, 97, 120, 40, 97, 98, 115,
  40, 105, 109, 41, 44, 97, 98, 115, 40, 105, 77, 41, 41, 125, 10, 114,
  101, 115, 120, 61, 123, 109, 97, 120, 40, 49, 44, 114, 111, 117, 110, 100,
  40, 105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110,
  116, 92, 32, 36, 52, 125, 44, 119, 42, 36, 52, 44, 119, 47, 36, 52,
  41, 45, 49, 41, 41, 125, 10, 114, 101, 115, 121, 61, 123, 109, 97, 120,
  40, 49, 44, 114, 111, 117, 110, 100, 40, 105, 102, 40, 64, 123, 45, 105,
  115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 53, 125, 44, 104,
  42, 36, 53, 44, 104, 47, 36, 53, 41, 45, 49, 41, 41, 125, 10, 45,
  112, 108, 97, 110, 101, 51, 100, 32, 49, 44, 49, 44, 36, 114, 101, 115,
  120, 44, 36, 114, 101, 115, 121, 32, 45, 42, 51, 100, 91, 45, 49, 93,
  32, 64, 123, 48, 44, 119, 45, 49, 125, 44, 64, 123, 48, 44, 104, 45,
  49, 125, 44, 49, 10, 45, 115, 51, 100, 91, 45, 49, 93, 32, 45, 114,
  109, 91, 45, 50, 93, 32, 45, 105, 91, 45, 50, 93, 32, 40, 48, 59,
  123, 104, 45, 49, 125, 41, 32, 45, 114, 91, 45, 50, 93, 32, 51, 44,
  123, 104, 125, 44, 49, 44, 49, 44, 51, 32, 45, 114, 111, 117, 110, 100,
  91, 45, 50, 93, 32, 45, 121, 91, 45, 50, 93, 10, 91, 45, 52, 93,
  32, 45, 97, 91, 45, 55, 45, 45, 50, 93, 32, 121, 32, 45, 114, 91,
  45, 49, 93, 32, 51, 44, 123, 104, 47, 51, 125, 44, 49, 44, 49, 44,
  45, 49, 32, 45, 122, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 112,
  101, 114, 109, 117, 116, 101, 91, 45, 49, 93, 32, 121, 122, 99, 120, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 32, 45, 45, 119, 97, 114,
  112, 91, 49, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 32, 45, 43,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 112,
  101, 114, 109, 117, 116, 101, 91, 45, 49, 93, 32, 99, 120, 121, 122, 32,
  45, 122, 91, 45, 49, 93, 32, 48, 44, 50, 32, 45, 121, 91, 45, 49,
  93, 32, 45, 106, 91, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 56,
  32, 45, 114, 109, 91, 45, 51, 44, 45, 49, 93, 10, 91, 48, 93, 44,
  91, 48, 93, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 49,
  93, 32, 91, 49, 93, 44, 48, 44, 48, 44, 48, 44, 49, 44, 50, 32,
  45, 114, 109, 91, 49, 93, 10, 45, 105, 102, 32, 123, 36, 51, 62, 48,
  125, 10, 109, 105, 110, 95, 97, 114, 101, 97, 61, 64, 123, 48, 44, 105,
  102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92,
  32, 36, 51, 125, 44, 36, 51, 42, 119, 42, 104, 44, 36, 51, 41, 125,
  10, 45, 45, 97, 114, 101, 97, 91, 45, 49, 93, 32, 48, 44, 49, 32,
  45, 103, 101, 91, 45, 49, 93, 32, 36, 109, 105, 110, 95, 97, 114, 101,
  97, 32, 45, 43, 91, 45, 50, 93, 32, 49, 32, 45, 42, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101,
  91, 45, 49, 93, 32, 49, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49,
  32, 45, 119, 97, 116, 101, 114, 115, 104, 101, 100, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 98, 108, 101, 110, 100, 91, 48, 44, 45, 49, 93,
  32, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97, 103, 101, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 112,
  111, 115, 116, 101, 114, 95, 101, 100, 103, 101, 115, 32, 58, 32, 45, 99,
  104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 52, 48, 125, 62, 61, 48,
  32, 38, 38, 32, 36, 49, 60, 61, 49, 48, 48, 32, 38, 38, 32, 36,
  123, 50, 61, 53, 125, 62, 61, 48, 32, 38, 38, 32, 36, 50, 60, 61,
  49, 48, 48, 32, 38, 38, 32, 36, 123, 51, 61, 48, 46, 53, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 123, 52, 61, 49, 48, 125, 62, 61, 48,
  32, 38, 38, 32, 36, 123, 53, 61, 49, 50, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 53, 60, 61, 49, 53, 32, 38, 38, 32, 36, 123, 54, 61,
  48, 125, 62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  65, 112, 112, 108, 121, 32, 112, 111, 115, 116, 101, 114, 32, 101, 100, 103,
  101, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105,
  116, 104, 32, 101, 100, 103, 101, 32, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 32, 36, 49, 44, 32, 101, 100, 103, 101, 32, 115, 104, 97, 100, 101,
  32, 36, 50, 44, 32, 101, 100, 103, 101, 32, 116, 104, 105, 99, 107, 110,
  101, 115, 115, 32, 36, 51, 44, 32, 101, 100, 103, 101, 32, 97, 110, 116,
  105, 97, 108, 105, 97, 115, 105, 110, 103, 32, 36, 52, 44, 32, 36, 53,
  32, 108, 101, 118, 101, 108, 32, 111, 102, 32, 112, 111, 115, 116, 101, 114,
  105, 122, 97, 116, 105, 111, 110, 32, 97, 110, 100, 32, 112, 111, 115, 116,
  101, 114, 105, 122, 97, 116, 105, 111, 110, 32, 97, 110, 116, 105, 97, 108,
  105, 97, 115, 105, 110, 103, 32, 36, 54, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116,
  121, 32, 45, 108, 91, 48, 93, 10, 45, 45, 103, 114, 97, 100, 105, 101,
  110, 116, 32, 120, 121, 44, 49, 32, 45, 97, 91, 45, 50, 44, 45, 49,
  93, 32, 99, 32, 45, 110, 111, 114, 109, 91, 45, 49, 93, 32, 45, 98,
  91, 45, 49, 93, 32, 36, 51, 32, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 10, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118,
  101, 91, 45, 49, 93, 32, 49, 44, 48, 44, 49, 44, 123, 109, 97, 120,
  40, 48, 44, 40, 49, 48, 48, 45, 40, 36, 49, 37, 41, 94, 48, 46,
  49, 42, 49, 48, 48, 41, 42, 50, 53, 53, 37, 41, 125, 44, 48, 46,
  57, 57, 44, 123, 109, 105, 110, 40, 50, 53, 53, 44, 40, 49, 48, 49,
  45, 40, 36, 49, 37, 41, 94, 48, 46, 49, 42, 49, 48, 48, 43, 36,
  50, 41, 42, 50, 53, 53, 37, 41, 125, 44, 48, 46, 48, 49, 44, 50,
  53, 53, 44, 48, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 49, 10,
  45, 105, 102, 32, 36, 52, 32, 45, 115, 109, 111, 111, 116, 104, 91, 45,
  49, 93, 32, 123, 109, 105, 110, 40, 53, 48, 44, 36, 52, 41, 125, 44,
  48, 44, 49, 44, 123, 36, 52, 47, 52, 48, 125, 44, 123, 36, 52, 47,
  52, 48, 125, 44, 48, 46, 56, 44, 57, 48, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 36, 53, 32, 45, 97, 117, 116, 111, 105, 110,
  100, 101, 120, 91, 48, 93, 32, 123, 114, 111, 117, 110, 100, 40, 40, 52,
  45, 115, 113, 114, 116, 40, 36, 53, 43, 49, 41, 41, 42, 51, 50, 43,
  50, 41, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36,
  54, 32, 45, 115, 109, 111, 111, 116, 104, 91, 48, 93, 32, 123, 109, 105,
  110, 40, 53, 48, 44, 36, 54, 41, 125, 44, 48, 44, 49, 44, 123, 36,
  54, 47, 52, 48, 125, 44, 123, 36, 54, 47, 52, 48, 125, 44, 48, 46,
  56, 44, 57, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 42, 10, 45,
  101, 110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 112, 111, 115, 116, 101,
  114, 95, 104, 111, 112, 101, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 36, 123, 49, 61, 51, 125, 62, 61, 48, 34, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 72, 111, 112, 101, 32,
  115, 116, 101, 110, 99, 105, 108, 32, 112, 111, 115, 116, 101, 114, 32, 101,
  102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63,
  44, 32, 119, 105, 116, 104, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 116,
  111, 95, 114, 103, 98, 10, 45, 97, 112, 112, 108, 121, 95, 112, 97, 114,
  97, 108, 108, 101, 108, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34,
  45, 115, 109, 111, 111, 116, 104, 32, 50, 48, 48, 44, 48, 44, 49, 44,
  36, 49, 44, 49, 34, 10, 45, 113, 117, 97, 110, 116, 105, 122, 101, 32,
  55, 44, 48, 32, 45, 102, 32, 39, 105, 102, 40, 105, 33, 61, 53, 44,
  105, 44, 105, 43, 49, 45, 50, 42, 40, 121, 37, 50, 41, 41, 39, 10,
  40, 48, 44, 51, 50, 44, 52, 55, 59, 48, 44, 51, 50, 44, 52, 55,
  59, 50, 48, 57, 44, 49, 44, 50, 51, 59, 50, 48, 57, 44, 49, 44,
  50, 51, 59, 57, 48, 44, 49, 52, 49, 44, 49, 52, 53, 59, 45, 49,
  44, 45, 49, 44, 45, 49, 59, 50, 53, 51, 44, 50, 50, 49, 44, 49,
  51, 56, 41, 32, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 49, 93,
  32, 121, 122, 99, 120, 10, 45, 109, 97, 112, 91, 48, 93, 32, 91, 49,
  93, 32, 45, 114, 109, 91, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 114, 111, 100, 105, 108, 105,
  117, 115, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49,
  61, 49, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 49, 60, 61, 50,
  48, 48, 32, 38, 38, 32, 36, 123, 50, 61, 49, 48, 125, 62, 61, 48,
  32, 38, 38, 32, 36, 50, 60, 61, 49, 48, 48, 32, 38, 38, 32, 36,
  123, 51, 61, 52, 48, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123,
  52, 61, 55, 125, 62, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  53, 61, 48, 125, 44, 36, 123, 54, 61, 49, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 114, 111, 100, 105, 108,
  105, 117, 115, 32, 102, 105, 108, 116, 101, 114, 32, 111, 110, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 119, 105, 116, 104, 32, 97, 109, 112, 108, 105,
  116, 117, 100, 101, 32, 36, 49, 44, 32, 116, 104, 105, 99, 107, 110, 101,
  115, 115, 32, 36, 50, 44, 32, 115, 104, 97, 114, 112, 110, 101, 115, 115,
  32, 36, 51, 44, 32, 36, 52, 32, 111, 114, 105, 101, 110, 116, 97, 116,
  105, 111, 110, 115, 44, 32, 111, 102, 102, 115, 101, 116, 32, 36, 53, 32,
  97, 110, 100, 32, 34, 92, 10, 64, 123, 45, 97, 114, 103, 92, 32, 49,
  43, 33, 36, 54, 44, 98, 114, 105, 103, 104, 116, 101, 114, 44, 100, 97,
  114, 107, 101, 114, 125, 34, 32, 99, 111, 108, 111, 114, 32, 109, 111, 100,
  101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105,
  116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 114, 118, 10, 45, 105,
  102, 32, 123, 33, 36, 54, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118,
  101, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 102,
  91, 45, 49, 93, 32, 48, 32, 45, 110, 109, 91, 45, 49, 93, 32, 64,
  123, 45, 50, 44, 110, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  114, 111, 117, 110, 100, 40, 36, 52, 41, 125, 10, 97, 110, 103, 108, 101,
  61, 123, 36, 53, 43, 36, 62, 42, 49, 56, 48, 47, 114, 111, 117, 110,
  100, 40, 36, 52, 41, 125, 10, 45, 45, 98, 108, 117, 114, 95, 108, 105,
  110, 101, 97, 114, 91, 45, 50, 93, 32, 36, 49, 37, 44, 123, 36, 49,
  42, 36, 50, 47, 49, 48, 48, 125, 37, 44, 36, 97, 110, 103, 108, 101,
  44, 49, 32, 45, 98, 91, 45, 49, 93, 32, 48, 46, 55, 32, 45, 115,
  104, 97, 114, 112, 101, 110, 91, 45, 49, 93, 32, 36, 51, 32, 45, 109,
  97, 120, 91, 45, 50, 44, 45, 49, 93, 10, 45, 100, 111, 110, 101, 32,
  45, 114, 109, 91, 45, 50, 93, 10, 45, 105, 102, 32, 123, 33, 36, 54,
  125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 114, 118, 32, 45, 97, 32, 99, 32,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 115, 116, 97, 105, 110, 101, 100, 95, 103, 108, 97, 115, 115, 32, 58,
  32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 52, 48, 37,
  125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 48, 46, 50, 125,
  62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 48,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121,
  32, 115, 116, 97, 105, 110, 101, 100, 32, 103, 108, 97, 115, 115, 32, 101,
  102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63,
  44, 32, 119, 105, 116, 104, 32, 101, 100, 103, 101, 115, 32, 36, 49, 44,
  32, 115, 104, 97, 100, 105, 110, 103, 32, 36, 50, 32, 97, 110, 100, 32,
  116, 104, 105, 110, 45, 115, 101, 112, 97, 114, 97, 116, 111, 114, 115, 32,
  34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 33, 36, 51, 44, 101,
  110, 97, 98, 108, 101, 100, 44, 100, 105, 115, 97, 98, 108, 101, 100, 125,
  34, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 105, 109, 61, 123, 49,
  43, 105, 109, 125, 32, 45, 43, 32, 36, 105, 109, 10, 45, 45, 103, 114,
  97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 32, 45, 103, 101, 91,
  45, 49, 93, 32, 36, 49, 32, 45, 42, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 10, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93,
  32, 49, 32, 45, 115, 104, 97, 114, 112, 101, 110, 91, 45, 49, 93, 32,
  49, 101, 49, 48, 32, 45, 110, 101, 113, 91, 45, 49, 93, 32, 48, 10,
  45, 105, 102, 32, 36, 51, 32, 45, 115, 107, 101, 108, 101, 116, 111, 110,
  91, 45, 49, 93, 32, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 100,
  105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 119,
  97, 116, 101, 114, 115, 104, 101, 100, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 32, 45, 45, 91, 45, 50, 93, 32, 36, 105, 109, 10, 45, 110, 91,
  45, 49, 93, 32, 48, 44, 49, 32, 32, 45, 94, 91, 45, 49, 93, 32,
  36, 50, 32, 45, 42, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 115, 116, 97, 114, 32, 58, 32, 45, 99,
  104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 53, 49, 50, 125, 62, 61,
  49, 32, 38, 38, 32, 36, 123, 50, 61, 36, 49, 125, 62, 61, 49, 32,
  38, 38, 32, 36, 123, 51, 61, 53, 125, 62, 48, 32, 38, 38, 32, 36,
  123, 52, 61, 48, 46, 53, 125, 62, 61, 48, 32, 38, 38, 32, 36, 52,
  60, 61, 49, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 73, 110,
  112, 117, 116, 32, 36, 49, 120, 36, 50, 32, 115, 116, 97, 114, 32, 98,
  105, 110, 97, 114, 121, 32, 109, 97, 115, 107, 44, 32, 119, 105, 116, 104,
  32, 36, 51, 32, 98, 114, 97, 110, 99, 104, 101, 115, 32, 97, 110, 100,
  32, 116, 104, 105, 99, 107, 110, 101, 115, 115, 32, 36, 52, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 108, 91, 93, 10, 45, 115, 116, 97, 114, 51,
  100, 32, 36, 51, 44, 36, 52, 32, 45, 99, 111, 108, 51, 100, 32, 49,
  32, 45, 99, 51, 100, 32, 45, 110, 51, 100, 32, 45, 42, 51, 100, 32,
  36, 49, 44, 36, 50, 10, 36, 49, 44, 36, 50, 32, 45, 111, 98, 106,
  101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 53,
  48, 37, 44, 53, 48, 37, 44, 48, 44, 49, 44, 50, 32, 45, 114, 109,
  91, 45, 50, 93, 10, 45, 110, 109, 32, 34, 91, 72, 101, 97, 114, 116,
  32, 98, 105, 110, 97, 114, 121, 32, 109, 97, 115, 107, 93, 34, 10, 45,
  101, 110, 100, 108, 32, 45, 118, 32, 43, 10, 115, 116, 97, 114, 115, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 49, 48,
  37, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 49, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 123, 51, 61, 51, 50, 125, 62, 48, 32,
  38, 38, 32, 36, 123, 52, 61, 53, 125, 62, 61, 49, 32, 38, 38, 32,
  36, 123, 53, 61, 48, 46, 51, 56, 125, 62, 61, 48, 32, 38, 38, 32,
  36, 53, 60, 61, 49, 32, 38, 38, 32, 36, 123, 54, 61, 48, 46, 53,
  125, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 55, 61,
  50, 48, 48, 125, 44, 36, 123, 56, 61, 36, 55, 125, 44, 36, 123, 57,
  61, 36, 56, 125, 44, 36, 123, 49, 48, 61, 49, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 100, 100, 32, 36, 49, 32, 114, 97, 110,
  100, 111, 109, 32, 115, 116, 97, 114, 115, 32, 116, 111, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 100, 101, 112, 116, 104,
  32, 36, 50, 44, 32, 115, 105, 122, 101, 32, 36, 51, 44, 32, 36, 52,
  32, 98, 114, 97, 110, 99, 104, 101, 115, 44, 32, 116, 104, 105, 99, 107,
  110, 101, 115, 115, 32, 36, 53, 44, 32, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 36, 54, 44, 32, 99, 111, 108, 111, 114, 32, 40, 36,
  55, 44, 36, 56, 44, 36, 57, 41, 32, 97, 110, 100, 32, 111, 112, 97,
  99, 105, 116, 121, 32, 36, 49, 48, 46, 34, 10, 45, 118, 32, 45, 10,
  45, 115, 116, 97, 114, 51, 100, 32, 36, 52, 44, 36, 53, 32, 45, 99,
  111, 108, 51, 100, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 42, 51,
  100, 91, 45, 49, 93, 32, 36, 51, 10, 45, 108, 91, 45, 49, 93, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 52, 32, 123, 114, 111, 117, 110, 100,
  40, 50, 42, 36, 51, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 50,
  42, 36, 51, 41, 125, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91,
  45, 49, 93, 32, 91, 48, 93, 44, 53, 48, 37, 44, 53, 48, 37, 44,
  48, 44, 49, 44, 50, 44, 48, 44, 48, 32, 45, 114, 51, 100, 91, 48,
  93, 32, 48, 44, 48, 44, 49, 44, 57, 48, 32, 45, 100, 111, 110, 101,
  32, 45, 114, 109, 91, 48, 93, 32, 45, 101, 110, 100, 108, 10, 45, 97,
  117, 116, 111, 99, 114, 111, 112, 91, 45, 52, 45, 45, 49, 93, 32, 48,
  32, 45, 114, 50, 100, 121, 91, 45, 52, 45, 45, 49, 93, 32, 36, 51,
  32, 45, 98, 91, 45, 52, 45, 45, 49, 93, 32, 36, 54, 44, 48, 32,
  45, 114, 91, 45, 52, 45, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 49, 44, 52, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  52, 32, 45, 115, 104, 91, 123, 45, 49, 45, 36, 62, 125, 93, 32, 48,
  44, 50, 32, 45, 102, 99, 91, 45, 49, 93, 32, 36, 55, 44, 36, 56,
  44, 36, 57, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 100, 111, 110,
  101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125,
  32, 91, 45, 52, 45, 45, 49, 93, 32, 45, 108, 91, 36, 62, 44, 45,
  52, 45, 45, 49, 93, 10, 78, 61, 123, 114, 111, 117, 110, 100, 40, 105,
  102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92,
  32, 36, 49, 125, 44, 119, 42, 104, 42, 36, 49, 44, 36, 49, 41, 47,
  52, 44, 49, 44, 49, 41, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  52, 10, 50, 44, 36, 78, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93,
  32, 45, 49, 44, 49, 32, 49, 44, 36, 78, 32, 45, 114, 97, 110, 100,
  91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 97, 91, 45, 50, 44, 45,
  49, 93, 32, 120, 10, 45, 105, 91, 45, 50, 93, 32, 40, 123, 39, 67,
  73, 109, 103, 51, 100, 39, 125, 41, 32, 45, 43, 91, 45, 50, 93, 32,
  48, 46, 53, 32, 45, 105, 91, 45, 50, 93, 32, 40, 36, 78, 59, 36,
  78, 41, 10, 40, 49, 44, 48, 59, 49, 44, 123, 36, 78, 45, 49, 125,
  41, 32, 45, 114, 91, 45, 49, 93, 32, 50, 44, 36, 78, 44, 49, 44,
  49, 44, 51, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 52,
  44, 36, 78, 44, 49, 44, 49, 44, 49, 32, 45, 121, 91, 45, 53, 44,
  45, 51, 45, 45, 49, 93, 32, 45, 97, 91, 45, 53, 45, 45, 49, 93,
  32, 121, 10, 45, 114, 118, 91, 45, 50, 44, 45, 49, 93, 32, 45, 115,
  112, 114, 105, 116, 101, 115, 51, 100, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 42, 51, 100, 91, 45, 49, 93, 32, 123, 48, 46, 55, 53, 42, 64,
  123, 48, 44, 119, 125, 125, 44, 123, 48, 46, 55, 53, 42, 64, 123, 48,
  44, 104, 125, 125, 44, 123, 49, 48, 48, 48, 42, 36, 50, 125, 10, 45,
  111, 98, 106, 101, 99, 116, 51, 100, 91, 48, 93, 32, 91, 45, 49, 93,
  44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 36, 49, 48, 44, 48,
  44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 100, 111,
  110, 101, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45,
  114, 109, 91, 45, 52, 45, 45, 49, 93, 32, 45, 118, 32, 43, 10, 115,
  107, 101, 116, 99, 104, 98, 119, 32, 58, 10, 45, 99, 104, 101, 99, 107,
  32, 34, 36, 123, 49, 61, 50, 125, 62, 48, 32, 38, 38, 32, 36, 123,
  51, 61, 49, 56, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 52,
  61, 51, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 53, 61, 49,
  125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 55, 61, 48, 125, 62, 61,
  48, 32, 38, 38, 32, 36, 123, 56, 61, 48, 46, 54, 125, 62, 48, 32,
  38, 38, 32, 36, 123, 57, 61, 48, 46, 49, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 123, 49, 48, 61, 48, 46, 54, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 123, 49, 49, 61, 48, 46, 50, 53, 125, 62, 61, 48, 32,
  38, 38, 32, 36, 123, 49, 50, 61, 49, 125, 62, 61, 48, 34, 10, 45,
  115, 107, 105, 112, 32, 36, 123, 50, 61, 52, 53, 125, 44, 36, 123, 54,
  61, 48, 46, 48, 51, 125, 44, 36, 123, 49, 51, 61, 48, 125, 44, 36,
  123, 49, 52, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  65, 112, 112, 108, 121, 32, 66, 38, 87, 32, 115, 107, 101, 116, 99, 104,
  32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109, 97, 103, 101,
  36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 100, 105, 102, 102, 117,
  115, 105, 111, 110, 116, 101, 110, 115, 111, 114, 115, 32, 36, 57, 44, 36,
  49, 48, 44, 36, 49, 49, 44, 36, 49, 50, 10, 119, 61, 49, 32, 104,
  61, 49, 32, 45, 105, 91, 48, 93, 32, 49, 32, 45, 109, 51, 100, 32,
  48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125,
  10, 45, 47, 91, 45, 49, 93, 32, 123, 109, 97, 120, 40, 105, 77, 44,
  105, 109, 41, 125, 32, 45, 115, 91, 45, 49, 93, 32, 99, 10, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 50, 53, 53, 32,
  45, 110, 109, 91, 45, 49, 93, 32, 64, 123, 45, 52, 44, 110, 125, 44,
  49, 10, 45, 105, 102, 32, 123, 36, 119, 33, 61, 119, 124, 124, 36, 104,
  33, 61, 104, 125, 10, 45, 114, 109, 91, 48, 93, 32, 123, 36, 56, 42,
  119, 42, 104, 47, 40, 36, 49, 42, 115, 113, 114, 116, 40, 36, 52, 41,
  41, 125, 10, 45, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44,
  123, 64, 123, 45, 50, 44, 104, 125, 45, 49, 125, 32, 45, 114, 97, 110,
  100, 91, 45, 50, 93, 32, 48, 44, 123, 64, 123, 45, 51, 44, 119, 125,
  45, 49, 125, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 32,
  45, 109, 118, 91, 45, 49, 93, 32, 48, 10, 119, 61, 123, 119, 125, 32,
  104, 61, 123, 104, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 36, 49, 52, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 10,
  97, 108, 112, 104, 97, 61, 123, 40, 36, 50, 43, 36, 62, 42, 36, 51,
  47, 36, 49, 41, 42, 112, 105, 47, 49, 56, 48, 125, 10, 45, 45, 42,
  91, 45, 52, 93, 32, 123, 99, 111, 115, 40, 36, 97, 108, 112, 104, 97,
  41, 125, 32, 45, 45, 42, 91, 45, 52, 93, 32, 123, 115, 105, 110, 40,
  36, 97, 108, 112, 104, 97, 41, 125, 32, 45, 43, 91, 45, 50, 44, 45,
  49, 93, 10, 45, 45, 42, 91, 45, 52, 93, 32, 123, 99, 111, 115, 40,
  36, 97, 108, 112, 104, 97, 41, 125, 32, 45, 45, 42, 91, 45, 52, 93,
  32, 123, 115, 105, 110, 40, 36, 97, 108, 112, 104, 97, 41, 125, 32, 45,
  43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 97, 91, 45, 50, 44, 45,
  49, 93, 32, 99, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45,
  49, 93, 32, 48, 44, 50, 10, 45, 105, 102, 32, 36, 49, 51, 32, 45,
  111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 91, 45, 49, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  123, 48, 44, 119, 125, 10, 120, 121, 61, 64, 123, 48, 44, 40, 36, 62,
  44, 48, 41, 125, 44, 64, 123, 48, 44, 40, 36, 62, 44, 49, 41, 125,
  10, 45, 105, 102, 32, 123, 64, 123, 45, 53, 44, 40, 36, 120, 121, 41,
  125, 43, 64, 123, 45, 51, 44, 40, 36, 120, 121, 41, 125, 60, 36, 53,
  125, 32, 111, 112, 97, 99, 61, 36, 54, 32, 45, 101, 108, 115, 101, 32,
  111, 112, 97, 99, 61, 123, 36, 55, 42, 36, 54, 125, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 36, 111, 112, 97, 99, 10, 45, 45,
  115, 116, 114, 101, 97, 109, 108, 105, 110, 101, 51, 100, 91, 45, 49, 93,
  32, 36, 120, 121, 44, 48, 44, 36, 52, 44, 48, 46, 56, 44, 48, 44,
  48, 44, 49, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 48,
  32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 51, 93, 32, 91,
  45, 49, 93, 44, 48, 44, 48, 44, 48, 44, 36, 111, 112, 97, 99, 44,
  49, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 45,
  115, 116, 114, 101, 97, 109, 108, 105, 110, 101, 51, 100, 91, 45, 49, 93,
  32, 36, 120, 121, 44, 48, 44, 36, 52, 44, 48, 46, 56, 44, 48, 44,
  49, 44, 49, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 48,
  32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 51, 93, 32, 91,
  45, 49, 93, 44, 48, 44, 48, 44, 48, 44, 36, 111, 112, 97, 99, 44,
  49, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 100, 111, 110, 101, 10, 45, 101, 108, 115, 101, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 36, 49, 10, 97, 108, 112, 104, 97, 61,
  123, 40, 36, 50, 43, 36, 62, 42, 36, 51, 47, 36, 49, 41, 42, 112,
  105, 47, 49, 56, 48, 125, 10, 45, 45, 42, 91, 45, 52, 93, 32, 123,
  99, 111, 115, 40, 36, 97, 108, 112, 104, 97, 41, 125, 32, 45, 45, 42,
  91, 45, 52, 93, 32, 123, 115, 105, 110, 40, 36, 97, 108, 112, 104, 97,
  41, 125, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 45, 42,
  91, 45, 52, 93, 32, 123, 99, 111, 115, 40, 36, 97, 108, 112, 104, 97,
  41, 125, 32, 45, 45, 42, 91, 45, 52, 93, 32, 123, 115, 105, 110, 40,
  36, 97, 108, 112, 104, 97, 41, 125, 32, 45, 43, 91, 45, 50, 44, 45,
  49, 93, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45,
  105, 102, 32, 36, 49, 51, 32, 45, 111, 114, 105, 101, 110, 116, 97, 116,
  105, 111, 110, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 123, 48, 44, 119, 125, 10, 120, 61,
  64, 123, 48, 44, 40, 36, 62, 44, 48, 41, 125, 32, 121, 61, 64, 123,
  48, 44, 40, 36, 62, 44, 49, 41, 125, 10, 45, 105, 102, 32, 123, 64,
  123, 45, 53, 44, 40, 36, 120, 44, 36, 121, 41, 125, 43, 64, 123, 45,
  51, 44, 40, 36, 120, 44, 36, 121, 41, 125, 60, 36, 53, 125, 32, 111,
  112, 97, 99, 61, 36, 54, 32, 45, 101, 108, 115, 101, 32, 111, 112, 97,
  99, 61, 123, 36, 55, 42, 36, 54, 125, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 36, 111, 112, 97, 99, 10, 45, 108, 105, 110, 101,
  91, 45, 50, 93, 32, 123, 36, 120, 45, 36, 52, 42, 64, 123, 45, 49,
  44, 40, 36, 120, 44, 36, 121, 44, 48, 44, 48, 41, 125, 125, 44, 123,
  36, 121, 45, 36, 52, 42, 64, 123, 45, 49, 44, 40, 36, 120, 44, 36,
  121, 44, 48, 44, 49, 41, 125, 125, 44, 92, 10, 123, 36, 120, 43, 36,
  52, 42, 64, 123, 45, 49, 44, 40, 36, 120, 44, 36, 121, 44, 48, 44,
  48, 41, 125, 125, 44, 123, 36, 121, 43, 36, 52, 42, 64, 123, 45, 49,
  44, 40, 36, 120, 44, 36, 121, 44, 48, 44, 49, 41, 125, 125, 44, 92,
  10, 123, 51, 42, 36, 111, 112, 97, 99, 125, 44, 48, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 109, 91, 45, 52, 45, 45, 50, 93, 10, 45, 109, 118, 91, 45, 49,
  93, 32, 49, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 93,
  32, 45, 118, 32, 43, 10, 115, 112, 111, 110, 103, 101, 32, 58, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 51, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 115, 112, 111, 110,
  103, 101, 32, 102, 105, 108, 116, 101, 114, 32, 111, 110, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 98, 114, 117, 115, 104,
  32, 115, 105, 122, 101, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 32,
  45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 50, 48, 44, 50, 32,
  45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 110, 91, 45,
  49, 93, 32, 48, 44, 49, 32, 45, 42, 91, 45, 49, 44, 45, 50, 93,
  10, 45, 95, 99, 105, 114, 99, 108, 101, 32, 36, 49, 32, 45, 100, 105,
  108, 97, 116, 101, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 95, 99, 105, 114, 99, 108, 101, 32, 58,
  10, 45, 105, 102, 32, 123, 36, 49, 37, 50, 61, 61, 48, 125, 32, 45,
  105, 32, 50, 44, 50, 32, 45, 101, 108, 115, 101, 32, 45, 105, 32, 49,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 43, 91, 45, 49, 93, 32, 49,
  32, 45, 114, 91, 45, 49, 93, 32, 36, 49, 44, 36, 49, 44, 49, 44,
  49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 100,
  105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 110,
  91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 115, 113, 114, 116, 91, 45,
  49, 93, 32, 45, 99, 91, 45, 49, 93, 32, 48, 46, 56, 53, 44, 48,
  46, 56, 54, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 110,
  91, 45, 49, 93, 32, 48, 44, 49, 10, 115, 116, 101, 110, 99, 105, 108,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 51,
  125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 49, 125, 62, 61,
  48, 32, 38, 38, 32, 36, 123, 51, 61, 56, 125, 62, 61, 48, 34, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 115,
  116, 101, 110, 99, 105, 108, 32, 102, 105, 108, 116, 101, 114, 32, 111, 110,
  32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 114,
  97, 100, 105, 117, 115, 32, 36, 49, 44, 32, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 36, 50, 32, 97, 110, 100, 32, 36, 51, 32, 105,
  116, 101, 114, 97, 116, 105, 111, 110, 115, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 110, 32, 48, 44, 49, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  36, 51, 32, 45, 98, 32, 36, 49, 32, 45, 117, 110, 115, 104, 97, 114,
  112, 32, 123, 36, 49, 43, 36, 50, 125, 44, 49, 48, 48, 48, 32, 45,
  99, 32, 48, 44, 50, 53, 53, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 115, 116, 101, 110, 99, 105, 108, 98, 119, 32, 58, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 53, 125, 44, 36, 123, 50,
  61, 49, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112,
  112, 108, 121, 32, 66, 38, 87, 32, 115, 116, 101, 110, 99, 105, 108, 32,
  101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 119, 105, 116, 104, 32, 101, 100, 103, 101, 115, 32, 36, 49,
  32, 97, 110, 100, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108,
  105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 117, 109, 105,
  110, 97, 110, 99, 101, 91, 48, 93, 32, 45, 110, 91, 48, 93, 32, 48,
  44, 50, 53, 53, 10, 45, 45, 101, 100, 103, 101, 115, 91, 48, 93, 32,
  36, 49, 32, 45, 113, 117, 97, 110, 116, 105, 122, 101, 91, 48, 93, 32,
  51, 44, 48, 44, 49, 32, 45, 98, 91, 48, 93, 32, 36, 50, 10, 45,
  115, 104, 97, 114, 112, 101, 110, 91, 48, 93, 32, 49, 48, 48, 48, 48,
  48, 48, 32, 45, 110, 91, 48, 93, 32, 48, 44, 49, 32, 45, 42, 91,
  48, 44, 45, 49, 93, 32, 45, 110, 91, 48, 93, 32, 48, 44, 50, 53,
  53, 10, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 116, 101, 116, 114, 105, 115, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 48, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 116, 101,
  116, 114, 105, 115, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105,
  109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 115, 99, 97,
  108, 101, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119,
  104, 61, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 123, 115, 125, 32,
  45, 114, 32, 36, 49, 37, 44, 36, 49, 37, 44, 36, 49, 37, 44, 49,
  48, 48, 37, 44, 50, 32, 45, 110, 32, 48, 44, 50, 53, 53, 32, 45,
  113, 117, 97, 110, 116, 105, 122, 101, 32, 49, 48, 44, 49, 44, 48, 32,
  45, 114, 32, 36, 119, 104, 32, 45, 98, 32, 50, 32, 45, 115, 104, 97,
  114, 112, 101, 110, 32, 51, 48, 48, 44, 49, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 119, 97, 114, 104,
  111, 108, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 51,
  125, 44, 36, 123, 50, 61, 36, 49, 125, 44, 36, 123, 51, 61, 50, 125,
  44, 36, 123, 52, 61, 50, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 67, 114, 101, 97, 116, 101, 32, 36, 49, 120, 36, 50, 32, 65,
  110, 100, 121, 32, 87, 97, 114, 104, 111, 108, 45, 108, 105, 107, 101, 32,
  97, 114, 116, 119, 111, 114, 107, 32, 102, 114, 111, 109, 32, 105, 109, 97,
  103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 114, 48, 61, 123,
  49, 48, 48, 47, 109, 97, 120, 40, 36, 49, 44, 36, 50, 41, 125, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 110, 111, 114, 109, 32, 45, 98, 32, 36, 51, 32, 45, 114,
  32, 36, 114, 48, 37, 44, 36, 114, 48, 37, 44, 49, 44, 49, 48, 48,
  37, 44, 50, 32, 45, 113, 117, 97, 110, 116, 105, 122, 101, 32, 54, 32,
  45, 110, 32, 48, 44, 53, 32, 45, 114, 111, 117, 110, 100, 32, 49, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 36, 50, 10, 40, 48, 44, 49, 44, 50, 44, 51, 44, 52,
  44, 53, 41, 32, 45, 110, 91, 45, 49, 93, 32, 51, 50, 44, 50, 50,
  52, 32, 54, 44, 49, 44, 49, 44, 50, 44, 49, 50, 56, 32, 45, 110,
  111, 105, 115, 101, 91, 45, 49, 93, 32, 36, 52, 44, 48, 32, 45, 99,
  91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 97, 91, 45, 50,
  44, 45, 49, 93, 32, 99, 32, 45, 121, 99, 98, 99, 114, 50, 114, 103,
  98, 91, 45, 49, 93, 32, 45, 45, 109, 97, 112, 91, 48, 93, 32, 91,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 100, 111, 110,
  101, 32, 45, 100, 111, 110, 101, 32, 45, 97, 112, 112, 101, 110, 100, 95,
  116, 105, 108, 101, 115, 91, 94, 48, 93, 32, 36, 49, 44, 36, 50, 32,
  45, 110, 109, 91, 49, 93, 32, 64, 123, 48, 44, 110, 125, 44, 49, 32,
  45, 114, 109, 91, 48, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 119, 101, 97, 118, 101, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 54, 125, 62, 61,
  48, 32, 38, 38, 32, 36, 123, 50, 61, 54, 53, 125, 62, 61, 48, 32,
  38, 38, 32, 36, 50, 60, 61, 49, 48, 48, 32, 38, 38, 32, 36, 123,
  51, 61, 52, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 51, 60, 61,
  49, 48, 48, 32, 38, 38, 32, 36, 123, 52, 61, 48, 46, 53, 125, 62,
  61, 48, 34, 10, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 53, 61,
  48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 54, 61, 48, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 123, 55, 61, 48, 125, 62, 61, 48, 32,
  38, 38, 32, 36, 55, 60, 61, 51, 32, 38, 38, 32, 36, 123, 56, 61,
  48, 125, 62, 61, 45, 49, 32, 38, 38, 32, 36, 56, 60, 61, 49, 32,
  38, 38, 32, 36, 123, 57, 61, 48, 125, 62, 61, 45, 49, 32, 38, 38,
  32, 36, 57, 60, 61, 49, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 65, 112, 112, 108, 121, 32, 119, 101, 97, 118, 101, 32, 101, 102, 102,
  101, 99, 116, 32, 116, 111, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32,
  119, 105, 116, 104, 32, 36, 49, 32, 115, 116, 114, 105, 112, 115, 44, 32,
  116, 104, 105, 99, 107, 110, 101, 115, 115, 32, 36, 50, 44, 32, 115, 104,
  97, 100, 111, 119, 32, 36, 51, 44, 32, 115, 104, 97, 100, 105, 110, 103,
  32, 36, 52, 44, 32, 34, 92, 10, 34, 102, 105, 98, 101, 114, 115, 32,
  97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 36, 53, 32, 97, 110, 100,
  32, 102, 105, 98, 101, 114, 115, 32, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 36, 54, 44, 32, 97, 110, 103, 108, 101, 32, 34, 123, 36,
  55, 42, 50, 50, 46, 53, 125, 34, 32, 100, 101, 103, 46, 32, 97, 110,
  100, 32, 99, 117, 114, 118, 97, 116, 117, 114, 101, 115, 32, 40, 36, 56,
  44, 36, 57, 41, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115,
  112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91,
  48, 93, 10, 119, 61, 123, 114, 111, 117, 110, 100, 40, 109, 97, 120, 40,
  119, 44, 104, 41, 47, 36, 49, 44, 49, 44, 49, 41, 125, 32, 104, 61,
  36, 119, 32, 115, 61, 123, 40, 49, 48, 48, 45, 36, 51, 41, 42, 50,
  53, 53, 37, 125, 32, 112, 61, 123, 109, 97, 120, 40, 48, 46, 48, 49,
  44, 36, 52, 41, 125, 10, 49, 44, 36, 104, 32, 45, 61, 91, 45, 49,
  93, 32, 49, 44, 48, 44, 53, 48, 37, 32, 45, 100, 105, 115, 116, 97,
  110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 94, 91, 45, 49, 93,
  32, 36, 112, 32, 45, 99, 91, 45, 49, 93, 32, 53, 48, 37, 44, 49,
  48, 48, 37, 32, 45, 114, 91, 45, 49, 93, 32, 123, 109, 97, 120, 40,
  49, 44, 114, 111, 117, 110, 100, 40, 36, 50, 42, 36, 119, 37, 41, 41,
  125, 44, 49, 48, 48, 37, 10, 36, 119, 44, 49, 32, 45, 61, 91, 45,
  49, 93, 32, 49, 44, 53, 48, 37, 32, 45, 100, 105, 115, 116, 97, 110,
  99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 94, 91, 45, 49, 93, 32,
  36, 112, 32, 45, 99, 91, 45, 49, 93, 32, 53, 48, 37, 44, 49, 48,
  48, 37, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 114, 91,
  45, 49, 93, 32, 49, 48, 48, 37, 44, 123, 109, 97, 120, 40, 49, 44,
  114, 111, 117, 110, 100, 40, 36, 50, 42, 36, 104, 37, 41, 41, 125, 10,
  45, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 45, 42, 91, 45,
  51, 93, 32, 45, 49, 32, 45, 110, 91, 45, 52, 44, 45, 50, 93, 32,
  48, 44, 36, 115, 32, 45, 110, 91, 45, 51, 44, 45, 49, 93, 32, 36,
  115, 44, 50, 53, 53, 10, 123, 119, 125, 44, 49, 32, 49, 44, 91, 45,
  51, 93, 32, 45, 114, 97, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32,
  48, 44, 49, 32, 45, 98, 91, 45, 50, 44, 45, 49, 93, 32, 36, 54,
  37, 32, 45, 110, 91, 45, 50, 44, 45, 49, 93, 32, 45, 36, 53, 44,
  36, 53, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 52, 93, 32, 45,
  43, 91, 45, 53, 93, 32, 91, 45, 49, 93, 32, 45, 43, 91, 45, 52,
  44, 45, 49, 93, 32, 45, 43, 91, 45, 53, 93, 32, 91, 45, 49, 93,
  32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 45, 102, 91, 45,
  51, 93, 32, 50, 53, 53, 32, 45, 97, 91, 45, 52, 44, 45, 49, 93,
  32, 99, 32, 45, 45, 102, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45,
  97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 97, 109, 112, 95, 120,
  61, 123, 36, 56, 42, 40, 36, 119, 45, 119, 41, 47, 50, 125, 32, 97,
  109, 112, 95, 121, 61, 123, 36, 57, 42, 40, 36, 119, 45, 119, 41, 47,
  50, 125, 10, 45, 114, 91, 45, 52, 45, 45, 49, 93, 32, 36, 119, 44,
  36, 104, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 10, 45, 102, 91, 45, 52, 93, 32, 39, 105, 40,
  120, 43, 36, 97, 109, 112, 95, 120, 42, 115, 105, 110, 40, 121, 47, 104,
  42, 112, 105, 41, 44, 121, 44, 48, 44, 99, 44, 49, 44, 50, 41, 39,
  32, 45, 102, 91, 45, 49, 93, 32, 39, 105, 40, 120, 45, 36, 97, 109,
  112, 95, 120, 42, 115, 105, 110, 40, 121, 47, 104, 42, 112, 105, 41, 44,
  121, 44, 48, 44, 99, 44, 49, 44, 50, 41, 39, 10, 45, 102, 91, 45,
  51, 93, 32, 39, 105, 40, 120, 44, 121, 43, 36, 97, 109, 112, 95, 121,
  42, 115, 105, 110, 40, 120, 47, 119, 42, 112, 105, 41, 44, 48, 44, 99,
  44, 49, 44, 50, 41, 39, 32, 45, 102, 91, 45, 50, 93, 32, 39, 105,
  40, 120, 44, 121, 45, 36, 97, 109, 112, 95, 121, 42, 115, 105, 110, 40,
  120, 47, 119, 42, 112, 105, 41, 44, 48, 44, 99, 44, 49, 44, 50, 41,
  39, 10, 45, 98, 108, 101, 110, 100, 91, 45, 52, 44, 45, 51, 93, 32,
  97, 108, 112, 104, 97, 32, 45, 98, 108, 101, 110, 100, 91, 45, 50, 44,
  45, 49, 93, 32, 97, 108, 112, 104, 97, 32, 45, 99, 91, 45, 50, 44,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 47, 91, 45, 50, 44,
  45, 49, 93, 32, 50, 53, 53, 32, 91, 45, 49, 93, 32, 91, 45, 51,
  93, 32, 45, 97, 91, 45, 52, 44, 45, 50, 93, 32, 120, 32, 45, 97,
  91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 97, 91, 45, 50, 44,
  45, 49, 93, 32, 121, 32, 45, 114, 111, 116, 97, 116, 101, 95, 116, 105,
  108, 101, 97, 98, 108, 101, 91, 45, 49, 93, 32, 123, 36, 55, 42, 50,
  50, 46, 53, 125, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  44, 91, 45, 50, 93, 44, 49, 44, 49, 44, 48, 44, 50, 32, 45, 42,
  91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 97,
  32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 119, 104, 105, 114, 108, 115, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 49, 61, 51, 125, 44, 36, 123, 50, 61, 54, 125,
  44, 36, 123, 51, 61, 48, 46, 53, 125, 44, 36, 123, 52, 61, 49, 46,
  56, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 100, 100, 32,
  114, 97, 110, 100, 111, 109, 32, 119, 104, 105, 114, 108, 32, 116, 101, 120,
  116, 117, 114, 101, 32, 116, 111, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 119, 105, 116, 104, 32, 116, 101, 120, 116, 117, 114, 101, 32, 36, 49,
  44, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 50, 44,
  32, 100, 97, 114, 107, 110, 101, 115, 115, 32, 36, 51, 32, 97, 110, 100,
  32, 108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 36, 52, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 48, 46, 51, 44,
  50, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 32, 45, 98, 91,
  45, 49, 93, 32, 36, 50, 32, 45, 103, 114, 97, 100, 105, 101, 110, 116,
  95, 110, 111, 114, 109, 91, 45, 49, 93, 32, 45, 94, 91, 45, 49, 93,
  32, 48, 46, 50, 32, 45, 100, 111, 110, 101, 10, 45, 110, 91, 45, 49,
  93, 32, 36, 51, 44, 36, 52, 32, 45, 114, 91, 45, 49, 93, 32, 91,
  45, 50, 93, 32, 45, 42, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 101, 117, 99, 108, 105, 100, 101, 97, 110, 50, 112, 111, 108, 97, 114,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 46, 53,
  125, 44, 36, 123, 50, 61, 48, 46, 53, 125, 44, 36, 123, 51, 61, 49,
  125, 44, 36, 123, 52, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 65, 112, 112, 108, 121, 32, 101, 117, 99, 108, 105, 100, 101, 97,
  110, 32, 116, 111, 32, 112, 111, 108, 97, 114, 32, 116, 114, 97, 110, 115,
  102, 111, 114, 109, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 40, 123, 119, 125, 44, 123, 104,
  125, 41, 32, 40, 36, 49, 44, 36, 50, 41, 32, 45, 42, 91, 45, 50,
  44, 45, 49, 93, 32, 40, 123, 34, 115, 113, 114, 116, 40, 109, 97, 120,
  40, 34, 64, 123, 45, 49, 44, 48, 125, 34, 44, 34, 64, 123, 45, 50,
  44, 119, 125, 34, 45, 34, 64, 123, 45, 49, 44, 48, 125, 34, 41, 94,
  50, 32, 43, 32, 109, 97, 120, 40, 34, 64, 123, 45, 49, 44, 49, 125,
  34, 44, 34, 64, 123, 45, 50, 44, 104, 125, 34, 45, 34, 64, 123, 45,
  49, 44, 49, 125, 34, 41, 94, 50, 41, 34, 125, 41, 10, 45, 97, 91,
  45, 50, 44, 45, 49, 93, 32, 120, 10, 91, 45, 50, 93, 44, 91, 45,
  50, 93, 44, 49, 44, 49, 44, 64, 123, 45, 49, 44, 50, 125, 34, 42,
  40, 120, 47, 119, 41, 94, 36, 51, 42, 99, 111, 115, 40, 121, 42, 50,
  42, 112, 105, 47, 104, 41, 34, 32, 45, 43, 91, 45, 49, 93, 32, 64,
  123, 45, 50, 44, 48, 125, 10, 91, 45, 49, 93, 44, 91, 45, 49, 93,
  44, 49, 44, 49, 44, 64, 123, 45, 50, 44, 50, 125, 34, 42, 40, 120,
  47, 119, 41, 94, 36, 51, 42, 115, 105, 110, 40, 121, 42, 50, 42, 112,
  105, 47, 104, 41, 34, 32, 45, 43, 91, 45, 49, 93, 32, 64, 123, 45,
  51, 44, 49, 125, 10, 45, 114, 109, 91, 45, 51, 93, 32, 45, 97, 91,
  45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 119, 97, 114, 112, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 49, 44, 36, 52, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 100, 101, 102, 111, 114, 109, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 48, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 114, 97,
  110, 100, 111, 109, 32, 115, 109, 111, 111, 116, 104, 32, 100, 101, 102, 111,
  114, 109, 97, 116, 105, 111, 110, 32, 111, 110, 32, 105, 109, 97, 103, 101,
  36, 63, 44, 32, 119, 105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117,
  100, 101, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 50,
  37, 44, 50, 37, 44, 49, 44, 50, 32, 45, 110, 111, 105, 115, 101, 91,
  45, 49, 93, 32, 36, 49, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 50, 44, 53, 32, 45, 119,
  97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 49,
  44, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 102, 105, 115, 104,
  101, 121, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  53, 48, 125, 44, 36, 123, 50, 61, 53, 48, 125, 44, 36, 123, 51, 61,
  53, 48, 125, 44, 36, 123, 52, 61, 49, 46, 50, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 70, 105, 115, 104,
  45, 101, 121, 101, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105,
  109, 97, 103, 101, 36, 63, 44, 32, 99, 101, 110, 116, 101, 114, 101, 100,
  32, 97, 116, 32, 40, 36, 49, 37, 44, 36, 50, 37, 41, 32, 119, 105,
  116, 104, 32, 114, 97, 100, 105, 117, 115, 32, 36, 51, 37, 32, 97, 110,
  100, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 36, 52, 46, 34,
  10, 45, 105, 102, 32, 123, 36, 52, 61, 61, 48, 125, 32, 45, 114, 101,
  116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49,
  32, 45, 61, 91, 45, 49, 93, 32, 49, 44, 36, 49, 37, 44, 36, 50,
  37, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32,
  49, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 36, 51, 37, 32, 45,
  42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 110, 91, 45, 49, 93, 32,
  48, 44, 49, 32, 45, 94, 91, 45, 49, 93, 32, 123, 49, 47, 36, 52,
  125, 10, 45, 105, 91, 45, 50, 93, 32, 40, 123, 45, 36, 49, 47, 49,
  48, 48, 125, 44, 123, 49, 45, 36, 49, 47, 49, 48, 48, 125, 59, 123,
  45, 36, 49, 47, 49, 48, 48, 125, 44, 123, 49, 45, 36, 49, 47, 49,
  48, 48, 125, 94, 123, 45, 36, 50, 47, 49, 48, 48, 125, 44, 123, 45,
  36, 50, 47, 49, 48, 48, 125, 59, 123, 49, 45, 36, 50, 47, 49, 48,
  48, 125, 44, 123, 49, 45, 36, 50, 47, 49, 48, 48, 125, 41, 32, 45,
  114, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 91, 45, 49, 93, 44,
  49, 44, 50, 44, 51, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 123,
  109, 97, 120, 40, 119, 44, 104, 41, 125, 32, 45, 42, 91, 45, 50, 44,
  45, 49, 93, 10, 45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 44, 49, 44, 49, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 102, 108, 111, 119, 101, 114, 32, 58, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 49, 61, 51, 48, 125, 44, 36, 123, 50, 61, 54, 125, 44,
  36, 123, 51, 61, 48, 125, 44, 36, 123, 52, 61, 48, 125, 44, 36, 123,
  53, 61, 48, 46, 53, 125, 44, 36, 123, 54, 61, 48, 46, 53, 125, 44,
  36, 123, 55, 61, 50, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  65, 112, 112, 108, 121, 32, 102, 108, 111, 119, 101, 114, 32, 100, 101, 102,
  111, 114, 109, 97, 116, 105, 111, 110, 32, 111, 110, 32, 105, 109, 97, 103,
  101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 97, 109, 112, 108, 105, 116,
  117, 100, 101, 32, 36, 49, 44, 32, 102, 114, 101, 113, 117, 101, 110, 99,
  121, 32, 36, 50, 44, 32, 111, 102, 102, 115, 101, 116, 32, 36, 51, 44,
  32, 97, 110, 103, 108, 101, 32, 36, 52, 32, 100, 101, 103, 46, 32, 97,
  110, 100, 32, 99, 101, 110, 116, 101, 114, 32, 40, 36, 49, 44, 36, 50,
  41, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 101, 117, 99, 108,
  105, 100, 101, 97, 110, 50, 112, 111, 108, 97, 114, 32, 36, 53, 44, 36,
  54, 44, 49, 44, 36, 55, 32, 45, 115, 104, 105, 102, 116, 32, 36, 51,
  44, 48, 44, 48, 44, 48, 44, 50, 10, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 44, 49, 44, 121, 32, 45, 47, 91, 45, 49, 93, 32,
  123, 104, 125, 32, 45, 42, 91, 45, 49, 93, 32, 36, 50, 32, 40, 123,
  36, 52, 47, 51, 54, 48, 125, 41, 32, 45, 43, 91, 45, 50, 93, 32,
  64, 45, 49, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 42, 91, 45,
  49, 93, 32, 54, 46, 50, 56, 51, 49, 56, 53, 51, 32, 45, 115, 105,
  110, 91, 45, 49, 93, 10, 45, 42, 91, 45, 49, 93, 32, 36, 49, 32,
  45, 42, 91, 45, 49, 93, 32, 123, 119, 125, 32, 45, 47, 91, 45, 49,
  93, 32, 49, 48, 48, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91,
  45, 49, 93, 32, 48, 44, 49, 32, 45, 119, 97, 114, 112, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 44, 49, 44, 49, 44, 36, 55, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 112, 111, 108, 97, 114, 50, 101, 117, 99,
  108, 105, 100, 101, 97, 110, 32, 36, 53, 44, 36, 54, 44, 49, 44, 49,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 107, 97, 108, 101, 105, 100, 111, 115, 99, 111, 112, 101, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 46, 53, 125, 44,
  36, 123, 50, 61, 48, 46, 53, 125, 44, 36, 123, 51, 61, 49, 48, 48,
  125, 44, 36, 123, 52, 61, 51, 48, 125, 44, 36, 123, 53, 61, 49, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 114, 101, 97, 116, 101,
  32, 107, 97, 108, 101, 105, 100, 111, 115, 99, 111, 112, 101, 32, 101, 102,
  102, 101, 99, 116, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 119, 105, 116, 104, 32, 99, 101, 110, 116, 101, 114, 32, 40,
  36, 49, 44, 36, 50, 41, 44, 32, 114, 97, 100, 105, 117, 115, 32, 36,
  51, 44, 32, 97, 110, 103, 108, 101, 32, 36, 52, 32, 100, 101, 103, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 101, 117, 99, 108, 105, 100, 101, 97,
  110, 50, 112, 111, 108, 97, 114, 32, 36, 49, 44, 36, 50, 44, 49, 44,
  36, 53, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 45, 99, 111, 108, 117, 109, 110, 115, 32, 48,
  44, 36, 51, 37, 32, 45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 48,
  44, 36, 52, 37, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  44, 48, 44, 50, 32, 45, 110, 109, 91, 49, 93, 32, 64, 123, 48, 44,
  110, 125, 32, 45, 114, 109, 91, 48, 93, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 112, 111, 108, 97, 114, 50, 101, 117, 99,
  108, 105, 100, 101, 97, 110, 32, 36, 49, 44, 36, 50, 44, 49, 44, 36,
  53, 32, 45, 118, 32, 43, 10, 109, 97, 112, 95, 115, 112, 104, 101, 114,
  101, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61,
  53, 49, 50, 125, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 53, 49,
  50, 125, 62, 48, 32, 38, 38, 32, 36, 123, 53, 61, 48, 125, 62, 61,
  48, 32, 38, 38, 32, 36, 123, 54, 61, 48, 46, 53, 125, 62, 61, 48,
  34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 49, 48, 48, 125,
  44, 36, 123, 52, 61, 48, 46, 53, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 77, 97, 112, 32, 105, 109, 97, 103, 101, 36, 63, 32, 111,
  110, 32, 115, 112, 104, 101, 114, 101, 115, 32, 105, 110, 32, 36, 49, 120,
  36, 50, 32, 105, 109, 97, 103, 101, 115, 44, 32, 119, 105, 116, 104, 32,
  114, 97, 100, 105, 117, 115, 32, 36, 51, 44, 32, 100, 105, 108, 97, 116,
  105, 111, 110, 32, 36, 52, 32, 97, 110, 100, 32, 102, 97, 100, 105, 110,
  103, 32, 36, 53, 46, 34, 10, 45, 118, 32, 45, 32, 114, 50, 61, 123,
  40, 36, 51, 42, 109, 105, 110, 40, 36, 49, 44, 36, 50, 41, 47, 50,
  48, 48, 41, 94, 50, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 91, 45, 50, 93, 32,
  49, 48, 48, 37, 44, 49, 44, 49, 44, 49, 48, 48, 37, 44, 48, 32,
  45, 110, 109, 91, 48, 93, 32, 64, 123, 49, 44, 110, 125, 32, 45, 97,
  32, 121, 10, 40, 123, 45, 36, 49, 47, 50, 125, 44, 123, 36, 49, 47,
  50, 125, 41, 32, 40, 123, 45, 36, 50, 47, 50, 125, 59, 123, 36, 50,
  47, 50, 125, 41, 32, 45, 114, 91, 45, 50, 44, 45, 49, 93, 32, 36,
  49, 44, 36, 50, 44, 49, 44, 49, 44, 51, 32, 45, 97, 116, 97, 110,
  50, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 114, 109, 91, 45,
  50, 93, 10, 36, 49, 44, 36, 50, 32, 45, 61, 91, 45, 49, 93, 32,
  49, 44, 53, 48, 37, 44, 53, 48, 37, 32, 45, 100, 105, 115, 116, 97,
  110, 99, 101, 91, 45, 49, 93, 32, 49, 44, 51, 32, 45, 47, 91, 45,
  49, 93, 32, 36, 114, 50, 32, 45, 115, 113, 114, 116, 91, 45, 49, 93,
  32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 49, 10, 45, 97, 115, 105,
  110, 91, 45, 49, 93, 10, 45, 43, 91, 45, 50, 93, 32, 123, 112, 105,
  125, 32, 45, 42, 91, 45, 50, 93, 32, 123, 40, 64, 123, 45, 51, 44,
  119, 125, 45, 49, 41, 47, 40, 50, 42, 112, 105, 41, 125, 10, 45, 42,
  91, 45, 49, 93, 32, 123, 50, 47, 112, 105, 125, 32, 45, 94, 91, 45,
  49, 93, 32, 36, 52, 32, 45, 42, 91, 45, 49, 93, 32, 123, 64, 123,
  45, 51, 44, 104, 125, 45, 49, 125, 32, 45, 42, 91, 45, 49, 93, 32,
  45, 49, 32, 45, 43, 91, 45, 49, 93, 32, 123, 64, 123, 45, 51, 44,
  104, 125, 45, 49, 125, 10, 45, 105, 102, 32, 36, 53, 32, 45, 45, 103,
  101, 91, 45, 49, 93, 32, 49, 32, 45, 100, 105, 115, 116, 97, 110, 99,
  101, 91, 45, 49, 93, 32, 49, 32, 45, 99, 91, 45, 49, 93, 32, 48,
  44, 36, 53, 37, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 49, 32,
  45, 94, 91, 45, 49, 93, 32, 36, 54, 32, 45, 99, 91, 45, 50, 93,
  32, 49, 44, 49, 48, 48, 37, 32, 45, 45, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 91, 45, 49, 44, 45,
  50, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 64, 123, 45,
  51, 44, 100, 125, 10, 45, 45, 102, 91, 45, 49, 93, 32, 122, 32, 45,
  97, 91, 45, 51, 45, 45, 49, 93, 32, 99, 10, 45, 119, 97, 114, 112,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 49, 44, 49, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 112, 111, 108, 97, 114, 50, 101,
  117, 99, 108, 105, 100, 101, 97, 110, 32, 58, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 49, 61, 48, 46, 53, 125, 44, 36, 123, 50, 61, 48, 46,
  53, 125, 44, 36, 123, 51, 61, 49, 125, 44, 36, 123, 52, 61, 49, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32,
  112, 111, 108, 97, 114, 32, 116, 111, 32, 101, 117, 99, 108, 105, 100, 101,
  97, 110, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32, 111, 110, 32,
  105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 40, 123, 119, 125, 44, 123, 104, 125, 41, 32, 40, 36, 49, 44, 36,
  50, 41, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 40, 123, 34,
  115, 113, 114, 116, 40, 109, 97, 120, 40, 34, 64, 123, 45, 49, 44, 48,
  125, 34, 44, 34, 64, 123, 45, 50, 44, 119, 125, 34, 45, 34, 64, 123,
  45, 49, 44, 48, 125, 34, 41, 94, 50, 32, 43, 32, 109, 97, 120, 40,
  34, 64, 123, 45, 49, 44, 49, 125, 34, 44, 34, 64, 123, 45, 50, 44,
  104, 125, 34, 45, 34, 64, 123, 45, 49, 44, 49, 125, 34, 41, 94, 50,
  41, 34, 125, 41, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120,
  10, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 49, 44, 34,
  119, 42, 40, 115, 113, 114, 116, 40, 40, 120, 45, 34, 64, 123, 45, 49,
  44, 48, 125, 34, 41, 94, 50, 32, 43, 32, 40, 121, 45, 34, 64, 123,
  45, 49, 44, 49, 125, 34, 41, 94, 50, 41, 47, 34, 64, 123, 45, 49,
  44, 50, 125, 34, 41, 94, 40, 49, 47, 36, 51, 41, 34, 10, 91, 45,
  49, 93, 44, 91, 45, 49, 93, 44, 49, 44, 49, 44, 34, 40, 97, 116,
  97, 110, 50, 40, 121, 45, 34, 64, 123, 45, 50, 44, 49, 125, 34, 44,
  120, 45, 34, 64, 123, 45, 50, 44, 48, 125, 34, 41, 42, 104, 47, 40,
  50, 42, 112, 105, 41, 43, 104, 41, 37, 104, 34, 10, 45, 114, 109, 91,
  45, 51, 93, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32,
  45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48,
  44, 49, 44, 36, 52, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 114,
  97, 105, 110, 100, 114, 111, 112, 115, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 34, 36, 123, 50, 61, 48, 46, 49, 125, 62, 61, 48, 32, 38,
  38, 32, 36, 123, 51, 61, 49, 125, 62, 61, 48, 32, 38, 38, 32, 105,
  115, 105, 110, 116, 40, 36, 123, 52, 61, 48, 125, 41, 32, 38, 38, 32,
  36, 52, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49,
  61, 56, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112,
  112, 108, 121, 32, 114, 97, 105, 110, 100, 114, 111, 112, 115, 32, 100, 101,
  102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 111, 110, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 97, 109, 112, 108, 105,
  116, 117, 100, 101, 32, 36, 49, 44, 32, 100, 101, 110, 115, 105, 116, 121,
  32, 36, 50, 44, 32, 119, 97, 118, 101, 108, 101, 110, 103, 116, 104, 32,
  36, 51, 32, 97, 110, 100, 32, 36, 52, 32, 109, 101, 114, 103, 105, 110,
  103, 32, 115, 116, 101, 112, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 110, 111, 105, 115,
  101, 91, 45, 49, 93, 32, 36, 50, 44, 50, 32, 45, 100, 105, 115, 116,
  97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 102, 91, 45, 49,
  93, 32, 39, 99, 111, 115, 40, 105, 41, 47, 40, 49, 43, 105, 47, 36,
  51, 41, 39, 10, 45, 105, 102, 32, 36, 52, 10, 45, 105, 91, 45, 50,
  93, 32, 40, 48, 44, 49, 44, 48, 59, 49, 44, 48, 44, 49, 59, 48,
  44, 49, 44, 48, 41, 32, 45, 47, 91, 45, 50, 93, 32, 50, 32, 91,
  45, 49, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 52, 32, 45,
  45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 45, 49, 93, 32, 91, 45,
  51, 93, 44, 49, 32, 45, 45, 91, 45, 49, 93, 32, 91, 45, 51, 93,
  32, 45, 114, 109, 91, 45, 51, 93, 32, 45, 100, 111, 110, 101, 32, 45,
  114, 109, 91, 45, 51, 44, 45, 50, 93, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32, 45,
  97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 42, 91, 45, 49,
  93, 32, 123, 36, 49, 47, 40, 49, 101, 45, 53, 43, 109, 97, 120, 40,
  97, 98, 115, 40, 105, 109, 41, 44, 97, 98, 115, 40, 105, 77, 41, 41,
  41, 125, 10, 45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 114, 105, 112,
  112, 108, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  49, 48, 125, 44, 36, 123, 50, 61, 50, 48, 125, 44, 36, 123, 51, 61,
  50, 125, 44, 36, 123, 52, 61, 48, 125, 44, 36, 123, 53, 61, 48, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32,
  114, 105, 112, 112, 108, 101, 32, 100, 101, 102, 111, 114, 109, 97, 116, 105,
  111, 110, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119,
  105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 36, 49,
  44, 32, 102, 114, 101, 113, 117, 101, 110, 99, 121, 32, 36, 50, 44, 32,
  115, 104, 97, 112, 101, 32, 36, 51, 44, 32, 97, 110, 103, 108, 101, 32,
  36, 52, 32, 100, 101, 103, 46, 32, 97, 110, 100, 32, 111, 102, 102, 115,
  101, 116, 32, 36, 53, 46, 34, 10, 45, 118, 32, 45, 10, 116, 104, 101,
  116, 97, 61, 123, 36, 52, 42, 112, 105, 47, 49, 56, 48, 125, 32, 67,
  61, 123, 99, 111, 115, 40, 36, 116, 104, 101, 116, 97, 41, 125, 32, 83,
  61, 123, 45, 115, 105, 110, 40, 36, 116, 104, 101, 116, 97, 41, 125, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44,
  34, 120, 34, 32, 45, 45, 91, 45, 49, 93, 32, 123, 119, 47, 50, 125,
  32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 39,
  121, 39, 10, 45, 45, 91, 45, 49, 93, 32, 123, 104, 47, 50, 45, 36,
  53, 125, 32, 45, 42, 91, 45, 50, 93, 32, 36, 83, 32, 45, 42, 91,
  45, 49, 93, 32, 36, 67, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93,
  10, 45, 95, 114, 105, 112, 112, 108, 101, 36, 51, 91, 45, 49, 93, 32,
  36, 49, 44, 36, 50, 10, 45, 45, 42, 91, 45, 49, 93, 32, 123, 45,
  36, 83, 125, 32, 45, 42, 91, 45, 50, 93, 32, 36, 67, 32, 45, 97,
  91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 119, 97, 114, 112, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 95, 114, 105, 112, 112, 108, 101, 48, 32, 58, 32, 45,
  102, 32, 123, 36, 49, 47, 50, 125, 42, 34, 40, 49, 45, 50, 42, 40,
  105, 37, 34, 123, 50, 42, 36, 50, 125, 34, 60, 36, 50, 41, 41, 34,
  10, 95, 114, 105, 112, 112, 108, 101, 49, 32, 58, 32, 45, 102, 32, 34,
  73, 61, 40, 105, 37, 36, 50, 41, 47, 36, 50, 59, 36, 49, 42, 40,
  50, 42, 105, 102, 40, 73, 60, 48, 46, 53, 44, 73, 44, 49, 45, 73,
  41, 45, 48, 46, 53, 41, 34, 10, 95, 114, 105, 112, 112, 108, 101, 50,
  32, 58, 32, 45, 102, 32, 123, 45, 36, 49, 47, 50, 125, 42, 34, 99,
  111, 115, 40, 105, 42, 34, 123, 50, 42, 112, 105, 47, 36, 50, 125, 34,
  41, 34, 10, 95, 114, 105, 112, 112, 108, 101, 51, 32, 58, 32, 45, 102,
  32, 123, 45, 36, 49, 47, 50, 125, 42, 34, 97, 98, 115, 40, 99, 111,
  115, 40, 105, 42, 34, 123, 50, 42, 112, 105, 47, 36, 50, 125, 34, 41,
  41, 34, 10, 95, 114, 105, 112, 112, 108, 101, 52, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 42, 32, 45, 110, 32, 48, 44, 123, 104, 45, 49,
  125, 32, 49, 44, 123, 104, 125, 32, 45, 114, 97, 110, 100, 91, 45, 49,
  93, 32, 123, 45, 36, 49, 47, 50, 125, 44, 123, 36, 49, 47, 50, 125,
  32, 109, 61, 123, 105, 109, 125, 32, 77, 61, 123, 105, 77, 125, 32, 45,
  98, 91, 45, 49, 93, 32, 123, 36, 50, 47, 49, 48, 125, 32, 45, 110,
  91, 45, 49, 93, 32, 36, 109, 44, 36, 77, 32, 45, 109, 97, 112, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 114, 111, 116, 111, 105, 100, 111, 115, 99, 111, 112, 101, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 53, 48, 37, 125, 44, 36,
  123, 50, 61, 53, 48, 37, 125, 44, 36, 123, 53, 61, 49, 125, 32, 45,
  99, 104, 101, 99, 107, 32, 34, 36, 123, 51, 61, 49, 48, 125, 62, 48,
  32, 38, 38, 32, 36, 123, 52, 61, 49, 125, 62, 61, 48, 34, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 67, 114, 101, 97, 116, 101, 32, 114,
  111, 116, 97, 116, 105, 111, 110, 97, 108, 32, 107, 97, 108, 101, 105, 100,
  111, 115, 99, 111, 112, 101, 32, 101, 102, 102, 101, 99, 116, 32, 102, 114,
  111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104,
  32, 99, 101, 110, 116, 101, 114, 32, 40, 36, 49, 44, 36, 50, 41, 44,
  32, 36, 51, 32, 116, 105, 108, 101, 115, 32, 97, 110, 100, 32, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 52, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 51, 32,
  45, 45, 114, 111, 116, 97, 116, 101, 91, 48, 93, 32, 123, 51, 54, 48,
  47, 36, 51, 125, 44, 49, 44, 36, 53, 44, 36, 49, 44, 36, 50, 32,
  45, 98, 108, 101, 110, 100, 95, 101, 100, 103, 101, 115, 32, 36, 52, 32,
  45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 115, 121, 109, 109, 101, 116, 114, 105, 122,
  101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 53, 48,
  37, 125, 44, 36, 123, 50, 61, 53, 48, 37, 125, 44, 36, 123, 51, 61,
  57, 48, 125, 44, 36, 123, 52, 61, 49, 125, 44, 36, 123, 53, 61, 48,
  125, 44, 36, 123, 54, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 83, 121, 109, 109, 101, 116, 114, 105, 122, 101, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 114, 101, 103, 97, 114, 100, 105, 110, 103, 32,
  97, 120, 105, 115, 32, 40, 36, 49, 44, 36, 50, 44, 36, 51, 32, 100,
  101, 103, 46, 41, 46, 34, 10, 45, 118, 32, 45, 10, 116, 104, 101, 116,
  97, 61, 123, 36, 51, 42, 112, 105, 47, 49, 56, 48, 125, 32, 117, 61,
  123, 99, 111, 115, 40, 36, 116, 104, 101, 116, 97, 41, 125, 32, 118, 61,
  123, 115, 105, 110, 40, 36, 116, 104, 101, 116, 97, 41, 125, 10, 45, 105,
  102, 32, 36, 54, 32, 115, 121, 109, 109, 101, 116, 114, 121, 95, 99, 111,
  110, 100, 61, 65, 60, 48, 32, 45, 101, 108, 115, 101, 32, 115, 121, 109,
  109, 101, 116, 114, 121, 95, 99, 111, 110, 100, 61, 65, 62, 48, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 120, 48, 61, 123, 105, 102, 40, 64,
  123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 92, 32, 36, 49,
  125, 44, 119, 42, 36, 49, 44, 36, 49, 41, 125, 10, 121, 48, 61, 123,
  105, 102, 40, 64, 123, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116,
  92, 32, 36, 50, 125, 44, 104, 42, 36, 50, 44, 36, 50, 41, 125, 10,
  45, 105, 102, 32, 36, 53, 32, 45, 102, 32, 39, 65, 61, 40, 36, 121,
  48, 45, 121, 41, 42, 36, 117, 45, 40, 36, 120, 48, 45, 120, 41, 42,
  36, 118, 59, 88, 61, 120, 43, 50, 42, 40, 36, 120, 48, 45, 120, 41,
  59, 89, 61, 121, 43, 50, 42, 40, 36, 121, 48, 45, 121, 41, 59, 105,
  102, 40, 36, 115, 121, 109, 109, 101, 116, 114, 121, 95, 99, 111, 110, 100,
  44, 105, 40, 88, 44, 89, 44, 122, 44, 99, 44, 49, 44, 36, 52, 41,
  44, 105, 41, 39, 10, 45, 101, 108, 115, 101, 32, 45, 102, 32, 39, 65,
  61, 40, 36, 121, 48, 45, 121, 41, 42, 36, 117, 45, 40, 36, 120, 48,
  45, 120, 41, 42, 36, 118, 59, 88, 61, 120, 45, 50, 42, 36, 118, 42,
  65, 59, 89, 61, 121, 43, 50, 42, 36, 117, 42, 65, 59, 105, 102, 40,
  36, 115, 121, 109, 109, 101, 116, 114, 121, 95, 99, 111, 110, 100, 44, 105,
  40, 88, 44, 89, 44, 122, 44, 99, 44, 49, 44, 36, 52, 41, 44, 105,
  41, 39, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 45, 118, 32, 43, 10, 116, 114, 97, 110, 115,
  102, 111, 114, 109, 95, 112, 111, 108, 97, 114, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 34, 36, 123, 49, 61, 82, 45, 114, 125, 34, 44, 34, 36,
  123, 50, 61, 97, 125, 34, 44, 36, 123, 51, 61, 53, 48, 125, 44, 36,
  123, 52, 61, 53, 48, 125, 44, 36, 123, 53, 61, 49, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 99, 117, 115,
  116, 111, 109, 32, 112, 111, 108, 97, 114, 32, 116, 114, 97, 110, 115, 102,
  111, 114, 109, 32, 119, 105, 116, 104, 32, 39, 110, 101, 119, 95, 114, 32,
  61, 32, 36, 49, 39, 44, 32, 39, 110, 101, 119, 95, 97, 32, 61, 32,
  36, 50, 39, 44, 32, 99, 101, 110, 116, 101, 114, 101, 100, 32, 97, 116,
  32, 40, 36, 51, 37, 44, 36, 52, 37, 41, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 82, 61, 123, 34, 115, 113, 114, 116, 40, 40, 109, 97,
  120, 40, 36, 51, 44, 49, 48, 48, 45, 36, 51, 41, 42, 119, 47, 49,
  48, 48, 41, 94, 50, 32, 43, 32, 40, 109, 97, 120, 40, 36, 52, 44,
  49, 48, 48, 45, 36, 52, 41, 42, 104, 47, 49, 48, 48, 41, 94, 50,
  41, 34, 125, 10, 119, 61, 123, 34, 36, 51, 42, 119, 47, 49, 48, 48,
  34, 125, 10, 104, 61, 123, 34, 36, 52, 42, 104, 47, 49, 48, 48, 34,
  125, 10, 45, 102, 32, 34, 82, 32, 61, 34, 36, 82, 34, 59, 10, 114,
  32, 61, 32, 115, 113, 114, 116, 40, 40, 120, 45, 34, 36, 119, 34, 41,
  94, 50, 32, 43, 32, 40, 121, 45, 34, 36, 104, 34, 41, 94, 50, 41,
  59, 10, 97, 32, 61, 32, 97, 116, 97, 110, 50, 40, 121, 45, 34, 36,
  104, 34, 44, 120, 45, 34, 36, 119, 34, 41, 59, 10, 110, 114, 32, 61,
  32, 36, 49, 59, 10, 110, 97, 32, 61, 32, 36, 50, 59, 10, 105, 40,
  34, 36, 119, 34, 32, 43, 32, 110, 114, 42, 99, 111, 115, 40, 110, 97,
  41, 44, 32, 34, 36, 104, 34, 32, 43, 32, 110, 114, 42, 115, 105, 110,
  40, 110, 97, 41, 44, 32, 122, 44, 32, 99, 44, 32, 49, 44, 36, 53,
  41, 34, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 116, 119, 105, 114, 108, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 49, 61, 49, 125, 44, 36, 123, 50, 61, 48, 46, 53,
  125, 44, 36, 123, 51, 61, 48, 46, 53, 125, 44, 36, 123, 52, 61, 49,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121,
  32, 116, 119, 105, 114, 108, 32, 100, 101, 102, 111, 114, 109, 97, 116, 105,
  111, 110, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119,
  105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 36, 49,
  32, 97, 110, 100, 32, 99, 101, 110, 116, 101, 114, 32, 97, 116, 32, 40,
  36, 50, 37, 44, 36, 51, 37, 41, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 101, 117, 99, 108, 105, 100, 101, 97, 110, 50, 112, 111, 108, 97, 114,
  32, 36, 50, 44, 36, 51, 44, 49, 44, 36, 52, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 10, 91, 36, 62, 93, 44, 91, 36, 62, 93,
  44, 49, 44, 49, 44, 36, 49, 42, 120, 32, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 91, 45, 49, 93, 32, 45, 49, 44, 48, 32, 45, 119, 97,
  114, 112, 91, 36, 62, 93, 32, 91, 45, 49, 93, 44, 49, 44, 49, 44,
  50, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 100, 111, 110, 101, 32,
  45, 112, 111, 108, 97, 114, 50, 101, 117, 99, 108, 105, 100, 101, 97, 110,
  32, 36, 50, 44, 36, 51, 44, 49, 44, 49, 32, 45, 118, 32, 43, 10,
  119, 97, 114, 112, 95, 112, 101, 114, 115, 112, 101, 99, 116, 105, 118, 101,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 46, 53,
  125, 44, 36, 123, 50, 61, 48, 125, 44, 36, 123, 51, 61, 49, 125, 44,
  36, 123, 52, 61, 53, 48, 125, 44, 36, 123, 53, 61, 53, 48, 125, 44,
  36, 123, 54, 61, 50, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  65, 112, 112, 108, 121, 32, 112, 101, 114, 115, 112, 101, 99, 116, 105, 118,
  101, 32, 119, 97, 114, 112, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 119, 105, 116, 104, 32, 97, 110, 103, 108, 101, 115, 32, 40,
  36, 49, 32, 100, 101, 103, 46, 44, 36, 50, 32, 100, 101, 103, 46, 41,
  44, 32, 122, 111, 111, 109, 32, 36, 51, 32, 97, 110, 100, 32, 111, 102,
  102, 115, 101, 116, 115, 32, 40, 36, 52, 44, 36, 53, 41, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 40, 48, 44, 49, 48, 48, 41, 32, 45,
  45, 91, 45, 49, 93, 32, 36, 52, 32, 45, 47, 91, 45, 49, 93, 32,
  49, 48, 48, 32, 40, 48, 59, 49, 48, 48, 41, 32, 45, 45, 91, 45,
  49, 93, 32, 36, 53, 32, 45, 47, 91, 45, 49, 93, 32, 49, 48, 48,
  32, 45, 114, 91, 45, 50, 44, 45, 49, 93, 32, 91, 45, 51, 93, 44,
  91, 45, 51, 93, 44, 91, 45, 51, 93, 44, 49, 44, 51, 10, 45, 45,
  42, 91, 45, 50, 93, 32, 36, 50, 32, 45, 45, 42, 91, 45, 50, 93,
  32, 36, 49, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 43,
  91, 45, 49, 93, 32, 36, 51, 32, 45, 47, 91, 45, 51, 93, 32, 91,
  45, 49, 93, 32, 45, 47, 91, 45, 50, 44, 45, 49, 93, 10, 45, 42,
  91, 45, 50, 93, 32, 49, 48, 48, 32, 45, 43, 91, 45, 50, 93, 32,
  36, 52, 32, 45, 47, 91, 45, 50, 93, 32, 49, 48, 48, 32, 45, 42,
  91, 45, 50, 93, 32, 64, 123, 45, 51, 44, 119, 125, 10, 45, 42, 91,
  45, 49, 93, 32, 49, 48, 48, 32, 45, 43, 91, 45, 49, 93, 32, 36,
  53, 32, 45, 47, 91, 45, 49, 93, 32, 49, 48, 48, 32, 45, 42, 91,
  45, 49, 93, 32, 64, 123, 45, 51, 44, 104, 125, 10, 45, 97, 91, 45,
  50, 44, 45, 49, 93, 32, 99, 32, 45, 119, 97, 114, 112, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 44, 48, 44, 49, 44, 36, 54, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 119, 97, 116, 101, 114, 32, 58, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 49, 61, 51, 48, 125, 44, 36, 123, 50,
  61, 49, 46, 53, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65,
  112, 112, 108, 121, 32, 119, 97, 116, 101, 114, 32, 100, 101, 102, 111, 114,
  109, 97, 116, 105, 111, 110, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 119, 105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117, 100,
  101, 32, 36, 49, 32, 97, 110, 100, 32, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  50, 53, 37, 44, 50, 53, 37, 44, 50, 53, 37, 44, 49, 32, 45, 110,
  111, 105, 115, 101, 91, 45, 49, 93, 32, 36, 49, 32, 45, 103, 91, 45,
  49, 93, 32, 120, 121, 122, 32, 45, 43, 91, 45, 49, 44, 45, 50, 44,
  45, 51, 93, 32, 45, 98, 91, 45, 49, 93, 32, 36, 50, 32, 45, 42,
  91, 45, 49, 93, 32, 50, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 50, 44, 51, 32, 45, 119,
  97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 119, 97, 118, 101, 32, 58, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 49, 61, 52, 125, 44, 36, 123, 50, 61,
  48, 46, 52, 125, 44, 36, 123, 51, 61, 53, 48, 125, 44, 36, 123, 52,
  61, 53, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112,
  112, 108, 121, 32, 119, 97, 118, 101, 32, 100, 101, 102, 111, 114, 109, 97,
  116, 105, 111, 110, 32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 119, 105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32,
  36, 49, 44, 32, 102, 114, 101, 113, 117, 101, 110, 99, 121, 32, 36, 50,
  32, 97, 110, 100, 32, 99, 101, 110, 116, 101, 114, 32, 97, 116, 32, 40,
  36, 51, 37, 44, 36, 52, 37, 41, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 61, 91, 45,
  49, 93, 32, 49, 44, 36, 51, 37, 44, 36, 52, 37, 32, 45, 100, 105,
  115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 10, 45, 42, 91,
  45, 49, 93, 32, 36, 50, 32, 45, 45, 115, 105, 110, 91, 45, 49, 93,
  32, 45, 99, 111, 115, 91, 45, 50, 93, 32, 45, 97, 91, 45, 50, 44,
  45, 49, 93, 32, 99, 32, 45, 42, 91, 45, 49, 93, 32, 36, 49, 10,
  45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 119, 105, 110, 100, 32, 58,
  32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36,
  123, 49, 61, 50, 48, 125, 41, 32, 38, 38, 32, 36, 49, 62, 61, 48,
  32, 38, 38, 32, 36, 123, 51, 61, 48, 46, 55, 125, 62, 61, 48, 32,
  38, 38, 32, 36, 51, 60, 61, 49, 34, 32, 45, 115, 107, 105, 112, 32,
  34, 36, 123, 50, 61, 48, 125, 44, 36, 123, 52, 61, 50, 48, 125, 34,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32,
  119, 105, 110, 100, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105,
  109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 97, 109, 112,
  108, 105, 116, 117, 100, 101, 32, 36, 49, 44, 32, 97, 110, 103, 108, 101,
  32, 34, 123, 114, 111, 117, 110, 100, 40, 36, 50, 47, 52, 53, 41, 42,
  52, 53, 125, 34, 32, 100, 101, 103, 46, 44, 32, 97, 116, 116, 101, 110,
  117, 97, 116, 105, 111, 110, 32, 36, 51, 32, 97, 110, 100, 32, 116, 104,
  114, 101, 115, 104, 111, 108, 100, 32, 36, 52, 46, 34, 10, 45, 118, 32,
  45, 10, 45, 105, 102, 32, 123, 33, 36, 49, 125, 32, 45, 114, 101, 116,
  117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 100, 120, 100, 121, 61,
  64, 123, 45, 95, 119, 105, 110, 100, 123, 114, 111, 117, 110, 100, 40, 36,
  50, 47, 52, 53, 41, 37, 56, 125, 125, 10, 102, 97, 99, 116, 61, 123,
  40, 49, 45, 36, 51, 41, 94, 40, 49, 47, 36, 49, 41, 125, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 45, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109,
  32, 45, 103, 101, 91, 45, 49, 93, 32, 36, 52, 37, 10, 115, 117, 109,
  61, 64, 123, 45, 49, 44, 43, 125, 32, 45, 114, 91, 45, 49, 93, 32,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 91, 45, 50, 93,
  32, 45, 42, 91, 45, 49, 93, 32, 91, 45, 50, 93, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 36, 49, 10, 45, 115, 104, 105, 102, 116, 91, 45,
  49, 93, 32, 36, 100, 120, 100, 121, 44, 48, 44, 48, 44, 48, 32, 45,
  109, 97, 120, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 42, 91,
  45, 49, 93, 32, 36, 102, 97, 99, 116, 10, 45, 114, 101, 109, 111, 118,
  101, 95, 112, 105, 120, 101, 108, 115, 91, 45, 49, 93, 32, 123, 49, 48,
  48, 47, 36, 49, 125, 44, 36, 115, 117, 109, 10, 45, 100, 111, 110, 101,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 95, 119, 105, 110, 100, 48,
  32, 58, 32, 45, 117, 32, 49, 44, 48, 10, 95, 119, 105, 110, 100, 49,
  32, 58, 32, 45, 117, 32, 49, 44, 49, 10, 95, 119, 105, 110, 100, 50,
  32, 58, 32, 45, 117, 32, 48, 44, 49, 10, 95, 119, 105, 110, 100, 51,
  32, 58, 32, 45, 117, 32, 45, 49, 44, 49, 10, 95, 119, 105, 110, 100,
  52, 32, 58, 32, 45, 117, 32, 45, 49, 44, 48, 10, 95, 119, 105, 110,
  100, 53, 32, 58, 32, 45, 117, 32, 45, 49, 44, 45, 49, 10, 95, 119,
  105, 110, 100, 54, 32, 58, 32, 45, 117, 32, 48, 44, 45, 49, 10, 95,
  119, 105, 110, 100, 55, 32, 58, 32, 45, 117, 32, 49, 44, 45, 49, 10,
  122, 111, 111, 109, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49,
  61, 50, 125, 44, 36, 123, 50, 61, 48, 46, 53, 125, 44, 36, 123, 51,
  61, 48, 46, 53, 125, 44, 36, 123, 52, 61, 48, 46, 53, 125, 44, 36,
  123, 53, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65,
  112, 112, 108, 121, 32, 122, 111, 111, 109, 32, 101, 102, 102, 101, 99, 116,
  32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116,
  104, 32, 102, 97, 99, 116, 111, 114, 32, 36, 49, 32, 97, 110, 100, 32,
  99, 101, 110, 116, 101, 114, 32, 40, 36, 50, 44, 36, 51, 41, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 100, 61, 61,
  49, 125, 10, 40, 123, 40, 119, 45, 49, 41, 42, 36, 50, 42, 40, 49,
  45, 49, 47, 36, 49, 41, 125, 44, 123, 40, 119, 45, 49, 41, 42, 40,
  36, 50, 43, 40, 49, 45, 36, 50, 41, 47, 36, 49, 41, 125, 41, 10,
  40, 123, 40, 64, 123, 45, 50, 44, 104, 125, 45, 49, 41, 42, 36, 51,
  42, 40, 49, 45, 49, 47, 36, 49, 41, 125, 59, 123, 40, 64, 123, 45,
  50, 44, 104, 125, 45, 49, 41, 42, 40, 36, 51, 43, 40, 49, 45, 36,
  51, 41, 47, 36, 49, 41, 125, 41, 10, 45, 114, 91, 45, 50, 45, 45,
  49, 93, 32, 91, 45, 51, 93, 44, 91, 45, 51, 93, 44, 49, 44, 49,
  44, 51, 32, 45, 97, 91, 45, 50, 45, 45, 49, 93, 32, 99, 32, 45,
  119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44,
  49, 44, 36, 53, 10, 45, 101, 108, 115, 101, 10, 40, 123, 40, 119, 45,
  49, 41, 42, 36, 50, 42, 40, 49, 45, 49, 47, 36, 49, 41, 125, 44,
  123, 40, 119, 45, 49, 41, 42, 40, 36, 50, 43, 40, 49, 45, 36, 50,
  41, 47, 36, 49, 41, 125, 41, 10, 40, 123, 40, 64, 123, 45, 50, 44,
  104, 125, 45, 49, 41, 42, 36, 51, 42, 40, 49, 45, 49, 47, 36, 49,
  41, 125, 59, 123, 40, 64, 123, 45, 50, 44, 104, 125, 45, 49, 41, 42,
  40, 36, 51, 43, 40, 49, 45, 36, 51, 41, 47, 36, 49, 41, 125, 41,
  10, 40, 123, 40, 64, 123, 45, 51, 44, 100, 125, 45, 49, 41, 42, 36,
  52, 42, 40, 49, 45, 49, 47, 36, 49, 41, 125, 47, 123, 40, 64, 123,
  45, 51, 44, 100, 125, 45, 49, 41, 42, 40, 36, 52, 43, 40, 49, 45,
  36, 52, 41, 47, 36, 49, 41, 125, 41, 10, 45, 114, 91, 45, 51, 45,
  45, 49, 93, 32, 91, 45, 52, 93, 44, 91, 45, 52, 93, 44, 91, 45,
  52, 93, 44, 49, 44, 51, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93,
  32, 99, 32, 45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 48, 44, 49, 44, 36, 53, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 99, 114, 97, 99, 107, 115, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 46, 50, 125,
  44, 36, 123, 50, 61, 52, 48, 125, 44, 36, 123, 51, 61, 48, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 100, 100, 32, 114, 97, 110,
  100, 111, 109, 32, 99, 114, 97, 99, 107, 115, 32, 116, 111, 32, 105, 109,
  97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 100, 101, 110, 115,
  105, 116, 121, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  40, 123, 105, 109, 125, 44, 123, 105, 77, 125, 41, 32, 91, 45, 50, 93,
  44, 91, 45, 50, 93, 44, 49, 44, 49, 32, 45, 110, 111, 105, 115, 101,
  91, 45, 49, 93, 32, 36, 49, 44, 50, 32, 45, 100, 105, 115, 116, 97,
  110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 115, 104, 97, 114, 112,
  101, 110, 91, 45, 49, 93, 32, 49, 48, 48, 48, 48, 10, 45, 105, 102,
  32, 36, 51, 32, 45, 103, 91, 45, 49, 93, 32, 120, 121, 32, 45, 43,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 45,
  49, 44, 49, 32, 45, 101, 108, 115, 101, 32, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 42, 91, 45,
  49, 93, 32, 36, 50, 32, 45, 43, 91, 45, 51, 44, 45, 49, 93, 32,
  45, 99, 91, 45, 50, 93, 32, 64, 45, 49, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 108, 105, 103, 104, 116, 95, 112, 97, 116, 99, 104, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 48, 125, 44,
  36, 123, 50, 61, 48, 46, 57, 125, 44, 36, 123, 51, 61, 49, 46, 55,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121,
  32, 108, 105, 103, 104, 116, 32, 112, 97, 116, 99, 104, 101, 115, 32, 116,
  111, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32,
  100, 101, 110, 115, 105, 116, 121, 32, 36, 49, 44, 32, 100, 97, 114, 107,
  110, 101, 115, 115, 32, 36, 50, 32, 97, 110, 100, 32, 108, 105, 103, 104,
  116, 110, 101, 115, 115, 32, 36, 51, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 110, 32, 48, 44, 50, 53, 53, 32, 36, 49, 44, 36, 49,
  32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 52, 48, 32, 45,
  114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 53, 32, 45, 99, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 110, 91, 45, 49, 93,
  32, 36, 50, 44, 36, 51, 32, 45, 42, 32, 45, 99, 32, 48, 44, 50,
  53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 110, 111, 105, 115, 101, 95, 104, 117, 114, 108, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 48, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 65, 100, 100, 32, 104, 117, 114, 108,
  32, 110, 111, 105, 115, 101, 32, 116, 111, 32, 105, 109, 97, 103, 101, 36,
  63, 44, 32, 119, 105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117, 100,
  101, 32, 36, 49, 37, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45,
  45, 102, 32, 48, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32,
  49, 48, 32, 45, 110, 91, 45, 49, 93, 32, 64, 123, 45, 50, 44, 109,
  125, 44, 64, 123, 45, 50, 44, 77, 125, 32, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 49, 44, 49, 44, 45, 50, 10, 45, 110, 111, 105, 115,
  101, 91, 45, 49, 93, 32, 36, 49, 44, 50, 32, 45, 103, 101, 91, 45,
  49, 93, 32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  10, 45, 42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 42, 91,
  45, 49, 93, 32, 45, 49, 32, 45, 43, 91, 45, 49, 93, 32, 49, 32,
  45, 42, 91, 45, 51, 44, 45, 49, 93, 32, 45, 43, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 112, 105,
  120, 101, 108, 105, 122, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 49, 61, 50, 48, 125, 44, 36, 123, 50, 61, 36, 49, 125, 44, 36,
  123, 51, 61, 36, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  80, 105, 120, 101, 108, 105, 122, 101, 32, 105, 109, 97, 103, 101, 36, 63,
  32, 119, 105, 116, 104, 32, 115, 99, 97, 108, 101, 115, 32, 40, 36, 49,
  37, 44, 36, 50, 37, 44, 36, 51, 37, 41, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 32, 119, 104, 100, 61, 123, 119, 125, 44, 123, 104, 125, 44,
  123, 100, 125, 32, 45, 114, 32, 36, 49, 37, 44, 36, 50, 37, 44, 36,
  51, 37, 44, 49, 48, 48, 37, 44, 50, 32, 45, 114, 32, 36, 119, 104,
  100, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 115, 104, 97, 100, 101, 95, 115, 116, 114, 105, 112, 101, 115,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 53, 125, 44,
  36, 123, 50, 61, 49, 125, 44, 36, 123, 51, 61, 48, 46, 56, 125, 44,
  36, 123, 52, 61, 50, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  65, 100, 100, 32, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 33,
  36, 50, 44, 118, 101, 114, 116, 105, 99, 97, 108, 44, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 125, 34, 32, 115, 104, 97, 100, 101, 100, 32,
  115, 116, 114, 105, 112, 101, 115, 32, 116, 111, 32, 105, 109, 97, 103, 101,
  36, 63, 44, 32, 119, 105, 116, 104, 32, 102, 114, 101, 113, 117, 101, 110,
  99, 121, 32, 36, 49, 44, 32, 100, 97, 114, 107, 110, 101, 115, 115, 32,
  36, 51, 32, 97, 110, 100, 32, 108, 105, 103, 104, 116, 110, 101, 115, 115,
  32, 36, 52, 46, 34, 10, 45, 118, 32, 45, 32, 45, 110, 32, 48, 44,
  50, 53, 53, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 123, 109, 97, 120, 40, 49, 44, 119, 42, 40,
  36, 50, 33, 61, 48, 41, 41, 125, 44, 123, 109, 97, 120, 40, 49, 44,
  104, 42, 40, 36, 50, 61, 61, 48, 41, 41, 125, 32, 45, 110, 111, 105,
  115, 101, 91, 45, 49, 93, 32, 36, 49, 44, 50, 32, 45, 100, 105, 115,
  116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 114, 91, 45,
  49, 93, 32, 91, 45, 50, 93, 32, 45, 110, 91, 45, 49, 93, 32, 36,
  51, 44, 36, 52, 32, 45, 42, 32, 45, 99, 32, 48, 44, 50, 53, 53,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 115, 104, 97, 100, 111, 119, 95, 112, 97, 116, 99, 104, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 46, 55, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 115,
  104, 97, 100, 111, 119, 32, 112, 97, 116, 99, 104, 101, 115, 32, 116, 111,
  32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 111,
  112, 97, 99, 105, 116, 121, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49,
  32, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 45, 50, 44, 45,
  50, 32, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 49, 44, 49,
  10, 45, 112, 108, 97, 115, 109, 97, 91, 45, 49, 93, 32, 51, 44, 48,
  46, 51, 44, 56, 32, 45, 97, 98, 115, 91, 45, 49, 93, 32, 45, 98,
  91, 45, 49, 93, 32, 49, 32, 45, 99, 91, 45, 49, 93, 32, 51, 37,
  44, 49, 53, 37, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  10, 45, 110, 91, 45, 49, 93, 32, 36, 49, 44, 49, 32, 45, 42, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 115, 112, 114, 101, 97, 100, 32, 58, 32, 45, 115, 107, 105, 112, 32,
  36, 123, 49, 61, 51, 125, 44, 36, 123, 50, 61, 36, 49, 125, 44, 36,
  123, 51, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 83,
  112, 114, 101, 97, 100, 32, 112, 105, 120, 101, 108, 32, 111, 102, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 114, 97, 110, 100, 111, 109, 108, 121, 44,
  32, 119, 105, 116, 104, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 115,
  32, 40, 36, 49, 44, 36, 50, 44, 36, 51, 41, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 51, 10, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44,
  48, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 123, 45, 36, 49,
  125, 44, 36, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104,
  91, 45, 49, 93, 32, 49, 44, 49, 32, 45, 114, 97, 110, 100, 91, 45,
  49, 93, 32, 123, 45, 36, 50, 125, 44, 36, 50, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 115, 104, 91, 45, 49, 93, 32, 50, 44, 50, 32,
  45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 123, 45, 36, 51, 125, 44,
  36, 51, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 119, 97, 114, 112,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 115, 116, 114, 105, 112, 101, 115, 95, 121, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 48, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 65, 100, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 32, 115, 116, 114, 105, 112, 101, 115, 32, 116, 111, 32,
  105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 102, 114,
  101, 113, 117, 101, 110, 99, 121, 32, 36, 49, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 110, 32, 48, 44, 50, 53, 53, 32, 49, 48, 48,
  37, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 36, 49, 44,
  50, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 10, 45, 42, 91, 45, 49, 93, 32,
  48, 46, 49, 53, 32, 45, 43, 32, 45, 99, 32, 48, 44, 50, 53, 53,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 116, 101, 120, 116, 117, 114, 105, 122, 101, 95, 99, 97, 110, 118,
  97, 115, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49,
  61, 50, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 51,
  125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 51, 61, 48, 46, 54, 125,
  62, 61, 48, 32, 38, 38, 32, 36, 123, 52, 61, 56, 48, 125, 34, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 100, 100, 32, 99, 97, 110,
  118, 97, 115, 32, 116, 101, 120, 116, 117, 114, 101, 32, 116, 111, 32, 105,
  109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 97, 109, 112,
  108, 105, 116, 117, 100, 101, 32, 36, 49, 44, 32, 102, 105, 98, 114, 111,
  117, 115, 110, 101, 115, 115, 32, 36, 50, 32, 97, 110, 100, 32, 101, 109,
  98, 111, 115, 115, 32, 108, 101, 118, 101, 108, 32, 36, 51, 46, 34, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 123, 119, 125, 44, 123, 104, 125, 32, 45, 114, 97, 110, 100, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 45, 98, 108, 117, 114,
  95, 120, 91, 45, 49, 93, 32, 36, 50, 32, 45, 98, 108, 117, 114, 95,
  121, 91, 45, 50, 93, 32, 36, 50, 32, 45, 43, 91, 45, 50, 44, 45,
  49, 93, 32, 45, 103, 91, 45, 49, 93, 32, 45, 97, 91, 45, 50, 44,
  45, 49, 93, 32, 99, 10, 45, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 43, 32, 45,
  111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 91, 45, 50, 93, 32,
  45, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 91, 45, 50, 93, 32, 43, 32, 45, 110, 91, 45, 50, 93, 32, 36,
  51, 44, 49, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  10, 45, 115, 104, 97, 114, 112, 101, 110, 91, 45, 49, 93, 32, 56, 48,
  32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 110, 91, 45, 49,
  93, 32, 45, 36, 49, 44, 36, 49, 32, 45, 43, 32, 45, 99, 32, 48,
  44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 116, 101, 120, 116, 117, 114, 105, 122, 101, 95,
  112, 97, 112, 101, 114, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 65, 100, 100, 32, 112, 97, 112, 101, 114, 32, 116, 101, 120, 116, 117,
  114, 101, 32, 116, 111, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 91, 45, 49, 93, 32, 51, 48, 37, 44,
  51, 48, 37, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 49,
  44, 50, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91,
  45, 50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 48, 32, 45, 105, 102,
  102, 116, 91, 45, 49, 93, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48,
  37, 44, 53, 48, 37, 44, 48, 44, 50, 32, 45, 115, 104, 97, 114, 112,
  101, 110, 91, 45, 49, 93, 32, 49, 32, 45, 110, 91, 45, 49, 93, 32,
  49, 44, 49, 46, 50, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50,
  93, 10, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 99, 91, 45,
  49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 32, 45, 114, 109,
  91, 45, 50, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 118, 105, 103, 110, 101, 116, 116, 101, 32, 58,
  32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 49, 48, 48,
  125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 50, 61, 55, 48, 125, 62,
  61, 48, 32, 38, 38, 32, 36, 50, 60, 61, 49, 48, 48, 32, 38, 38,
  32, 36, 123, 51, 61, 57, 48, 125, 62, 61, 48, 32, 38, 38, 32, 36,
  51, 60, 61, 49, 48, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 65, 100, 100, 32, 118, 105, 103, 110, 101, 116, 116, 101, 32, 101, 102,
  102, 101, 99, 116, 32, 116, 111, 32, 105, 109, 97, 103, 101, 36, 63, 44,
  32, 119, 105, 116, 104, 32, 115, 116, 114, 101, 110, 103, 116, 104, 32, 36,
  49, 32, 97, 110, 100, 32, 115, 105, 122, 101, 32, 36, 50, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 109, 77, 61, 123, 105, 109, 125, 44, 123,
  105, 77, 125, 32, 100, 61, 123, 109, 97, 120, 40, 119, 44, 104, 41, 125,
  10, 36, 100, 44, 36, 100, 32, 45, 61, 91, 45, 49, 93, 32, 49, 44,
  53, 48, 37, 44, 53, 48, 37, 32, 45, 100, 105, 115, 116, 97, 110, 99,
  101, 91, 45, 49, 93, 32, 49, 32, 45, 114, 91, 45, 49, 93, 32, 91,
  45, 50, 93, 44, 50, 10, 45, 99, 91, 45, 49, 93, 32, 36, 50, 37,
  44, 36, 51, 37, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 36, 49,
  32, 45, 45, 32, 45, 99, 32, 36, 109, 77, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 119, 97, 116, 101,
  114, 109, 97, 114, 107, 95, 118, 105, 115, 105, 98, 108, 101, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 34, 36, 123, 49, 61, 92, 50, 53, 49, 92,
  32, 71, 92, 39, 77, 73, 67, 125, 34, 32, 45, 99, 104, 101, 99, 107,
  32, 34, 36, 123, 50, 61, 48, 46, 51, 125, 62, 48, 32, 38, 38, 32,
  36, 50, 60, 49, 32, 38, 38, 32, 36, 123, 51, 61, 53, 55, 125, 62,
  48, 32, 38, 38, 32, 36, 123, 54, 61, 48, 46, 53, 125, 62, 61, 48,
  34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 52, 61, 50, 53, 125, 44,
  36, 123, 53, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 64,
  123, 45, 97, 114, 103, 92, 32, 49, 43, 33, 36, 53, 44, 65, 100, 100,
  44, 82, 101, 109, 111, 118, 101, 125, 34, 32, 118, 105, 115, 105, 98, 108,
  101, 32, 119, 97, 116, 101, 114, 109, 97, 114, 107, 32, 39, 36, 49, 39,
  32, 111, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116,
  104, 32, 111, 112, 97, 99, 105, 116, 121, 32, 36, 50, 44, 32, 115, 105,
  122, 101, 32, 36, 51, 44, 32, 97, 110, 103, 108, 101, 32, 36, 52, 32,
  100, 101, 103, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 48, 32, 45,
  116, 91, 45, 49, 93, 32, 34, 36, 49, 34, 44, 48, 44, 48, 44, 36,
  51, 44, 49, 44, 50, 53, 53, 32, 45, 114, 111, 116, 97, 116, 101, 91,
  45, 49, 93, 32, 36, 52, 44, 48, 44, 48, 32, 45, 98, 91, 45, 49,
  93, 32, 36, 54, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 10, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44,
  50, 32, 45, 43, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 99,
  91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 36,
  53, 32, 45, 42, 91, 45, 49, 93, 32, 36, 50, 32, 45, 42, 91, 45,
  50, 93, 32, 123, 49, 45, 36, 50, 125, 32, 45, 43, 10, 45, 101, 108,
  115, 101, 32, 45, 42, 91, 45, 49, 93, 32, 36, 50, 32, 45, 45, 32,
  45, 47, 32, 123, 49, 45, 36, 50, 125, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 98, 108, 101, 110, 100,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 97, 108, 112,
  104, 97, 125, 44, 36, 123, 50, 61, 49, 125, 44, 36, 123, 51, 61, 48,
  125, 44, 36, 123, 52, 61, 49, 125, 10, 45, 118, 32, 45, 32, 115, 48,
  61, 34, 34, 32, 115, 49, 61, 34, 40, 114, 101, 118, 101, 114, 116, 101,
  100, 32, 108, 97, 121, 101, 114, 115, 41, 32, 34, 32, 45, 118, 32, 43,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 66, 108, 101, 110, 100, 32,
  105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116,
  119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 39, 36, 49, 39, 32, 109,
  111, 100, 101, 32, 34, 36, 123, 115, 123, 36, 51, 33, 61, 48, 125, 125,
  34, 97, 110, 100, 32, 111, 112, 97, 99, 105, 116, 121, 32, 36, 50, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 108, 91, 93, 32, 99, 111, 100, 101,
  61, 64, 123, 45, 95, 98, 108, 101, 110, 100, 95, 36, 49, 125, 10, 45,
  111, 110, 102, 97, 105, 108, 32, 45, 118, 32, 43, 32, 45, 101, 114, 114,
  111, 114, 91, 48, 45, 45, 50, 93, 32, 34, 85, 110, 107, 110, 111, 119,
  110, 32, 98, 108, 101, 110, 100, 105, 110, 103, 32, 109, 111, 100, 101, 32,
  39, 36, 49, 39, 32, 114, 101, 113, 117, 101, 115, 116, 101, 100, 46, 34,
  10, 45, 101, 110, 100, 108, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62,
  44, 123, 36, 62, 43, 49, 125, 93, 32, 45, 105, 102, 32, 36, 51, 32,
  45, 114, 118, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 91, 49, 93,
  32, 91, 48, 93, 44, 91, 48, 93, 44, 91, 48, 93, 44, 49, 48, 48,
  37, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 115, 61,
  123, 115, 48, 61, 105, 102, 40, 64, 123, 48, 44, 115, 125, 60, 51, 44,
  49, 44, 51, 41, 59, 115, 49, 61, 105, 102, 40, 115, 60, 51, 44, 49,
  44, 51, 41, 59, 109, 97, 120, 40, 115, 48, 44, 115, 49, 41, 125, 10,
  45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 91, 48, 93,
  32, 123, 36, 115, 43, 49, 45, 40, 64, 123, 48, 44, 115, 125, 37, 50,
  41, 125, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101,
  91, 49, 93, 32, 123, 36, 115, 43, 49, 45, 40, 115, 37, 50, 41, 125,
  10, 45, 105, 102, 32, 123, 64, 123, 48, 44, 115, 125, 61, 61, 50, 124,
  124, 64, 123, 48, 44, 115, 125, 61, 61, 52, 125, 10, 45, 105, 102, 32,
  123, 115, 61, 61, 50, 124, 124, 115, 61, 61, 52, 125, 10, 45, 115, 104,
  91, 48, 44, 49, 93, 32, 48, 44, 123, 115, 45, 50, 125, 32, 45, 95,
  98, 108, 101, 110, 100, 91, 50, 44, 51, 93, 32, 36, 99, 111, 100, 101,
  32, 45, 114, 109, 91, 50, 44, 51, 93, 10, 45, 105, 102, 32, 123, 36,
  49, 39, 61, 61, 39, 97, 108, 112, 104, 97, 125, 10, 45, 115, 104, 91,
  48, 44, 49, 93, 32, 48, 44, 123, 64, 123, 48, 44, 115, 125, 45, 50,
  125, 32, 45, 115, 104, 91, 48, 44, 49, 93, 32, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 32, 45, 42, 91, 50, 44, 52, 93, 32, 45, 42, 91,
  51, 44, 52, 93, 32, 45, 114, 109, 91, 50, 44, 51, 93, 10, 45, 45,
  99, 104, 97, 110, 110, 101, 108, 115, 91, 49, 93, 32, 49, 48, 48, 37,
  32, 45, 115, 104, 91, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 32, 45, 102, 91, 51, 93, 32, 50, 53, 53, 32, 45, 114, 109, 91,
  51, 93, 10, 45, 106, 91, 48, 93, 32, 91, 49, 93, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 123, 109, 97, 120, 40, 48, 44, 109, 105, 110, 40,
  49, 44, 36, 50, 41, 41, 125, 44, 91, 50, 93, 44, 50, 53, 53, 32,
  45, 114, 109, 91, 49, 44, 50, 93, 10, 45, 115, 104, 91, 48, 93, 32,
  48, 44, 123, 115, 45, 50, 125, 32, 45, 115, 104, 91, 48, 93, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 43, 91, 50, 93, 32, 49,
  101, 45, 49, 48, 32, 45, 47, 91, 49, 44, 50, 93, 32, 45, 114, 109,
  91, 49, 93, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 101, 108,
  115, 101, 10, 45, 115, 104, 91, 49, 93, 32, 48, 44, 123, 115, 45, 50,
  125, 32, 45, 115, 104, 91, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 32, 45, 106, 91, 48, 93, 32, 91, 50, 93, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 123, 109, 97, 120, 40, 48, 44, 109, 105, 110, 40,
  49, 44, 36, 50, 41, 41, 125, 44, 91, 51, 93, 44, 50, 53, 53, 32,
  45, 114, 109, 91, 94, 48, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 108, 115, 101, 10, 45, 115, 104, 91, 48, 93, 32, 48, 44, 123, 64,
  123, 48, 44, 115, 125, 45, 50, 125, 32, 45, 114, 118, 91, 49, 44, 50,
  93, 32, 45, 95, 98, 108, 101, 110, 100, 91, 49, 44, 50, 93, 32, 36,
  99, 111, 100, 101, 32, 45, 106, 91, 49, 93, 32, 91, 50, 93, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 123, 109, 97, 120, 40, 48, 44, 109, 105,
  110, 40, 49, 44, 36, 50, 41, 41, 125, 32, 45, 114, 109, 91, 94, 48,
  93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101, 10, 45,
  105, 102, 32, 123, 115, 61, 61, 50, 124, 124, 115, 61, 61, 52, 125, 10,
  45, 115, 104, 91, 49, 93, 32, 48, 44, 123, 115, 45, 50, 125, 32, 45,
  95, 98, 108, 101, 110, 100, 91, 48, 44, 50, 93, 32, 36, 99, 111, 100,
  101, 32, 45, 114, 109, 91, 50, 93, 10, 45, 115, 104, 91, 49, 93, 32,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 106, 91, 48, 93, 32,
  91, 49, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 123, 109, 97, 120,
  40, 48, 44, 109, 105, 110, 40, 49, 44, 36, 50, 41, 41, 125, 44, 91,
  50, 93, 44, 50, 53, 53, 32, 45, 114, 109, 91, 94, 48, 93, 10, 45,
  101, 108, 115, 101, 10, 45, 95, 98, 108, 101, 110, 100, 32, 36, 99, 111,
  100, 101, 32, 45, 106, 91, 48, 93, 32, 91, 49, 93, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 123, 109, 97, 120, 40, 48, 44, 109, 105, 110, 40,
  49, 44, 36, 50, 41, 41, 125, 32, 45, 114, 109, 91, 49, 93, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 95, 98,
  108, 101, 110, 100, 32, 58, 32, 36, 42, 10, 95, 98, 108, 101, 110, 100,
  95, 97, 108, 112, 104, 97, 32, 58, 10, 45, 117, 32, 34, 34, 10, 95,
  98, 108, 101, 110, 100, 95, 97, 110, 100, 32, 58, 10, 45, 117, 32, 34,
  45, 97, 110, 100, 91, 49, 93, 32, 91, 48, 93, 34, 10, 95, 98, 108,
  101, 110, 100, 95, 97, 100, 100, 32, 58, 10, 45, 117, 32, 34, 45, 43,
  91, 49, 93, 32, 91, 48, 93, 32, 45, 99, 91, 49, 93, 32, 48, 44,
  50, 53, 53, 34, 10, 95, 98, 108, 101, 110, 100, 95, 97, 118, 101, 114,
  97, 103, 101, 32, 58, 10, 45, 117, 32, 34, 45, 43, 91, 49, 93, 32,
  91, 48, 93, 32, 45, 47, 91, 49, 93, 32, 50, 34, 10, 95, 98, 108,
  101, 110, 100, 95, 98, 108, 117, 101, 32, 58, 10, 45, 117, 32, 34, 45,
  115, 104, 91, 48, 93, 32, 48, 44, 49, 32, 45, 106, 91, 49, 93, 32,
  91, 50, 93, 32, 45, 114, 109, 91, 50, 93, 34, 10, 95, 98, 108, 101,
  110, 100, 95, 98, 117, 114, 110, 32, 58, 10, 45, 117, 32, 34, 45, 45,
  45, 91, 48, 93, 32, 50, 53, 53, 32, 45, 43, 91, 49, 93, 32, 48,
  46, 49, 32, 45, 47, 91, 50, 93, 32, 91, 49, 93, 32, 45, 114, 109,
  91, 49, 93, 32, 45, 43, 91, 49, 93, 32, 49, 32, 45, 42, 91, 49,
  93, 32, 50, 53, 53, 32, 45, 99, 91, 49, 93, 32, 48, 44, 50, 53,
  53, 34, 10, 95, 98, 108, 101, 110, 100, 95, 100, 97, 114, 107, 101, 110,
  32, 58, 10, 45, 117, 32, 34, 45, 109, 105, 110, 91, 49, 93, 32, 91,
  48, 93, 34, 10, 95, 98, 108, 101, 110, 100, 95, 100, 105, 102, 102, 101,
  114, 101, 110, 99, 101, 32, 58, 10, 45, 117, 32, 34, 45, 45, 91, 49,
  93, 32, 91, 48, 93, 32, 45, 97, 98, 115, 91, 49, 93, 34, 10, 95,
  98, 108, 101, 110, 100, 95, 100, 105, 118, 105, 100, 101, 32, 58, 10, 45,
  117, 32, 34, 45, 43, 91, 49, 93, 32, 48, 46, 49, 32, 45, 94, 91,
  49, 93, 32, 45, 49, 32, 45, 42, 91, 49, 93, 32, 91, 48, 93, 32,
  45, 42, 91, 49, 93, 32, 50, 53, 53, 32, 45, 99, 91, 49, 93, 32,
  48, 44, 50, 53, 53, 34, 10, 95, 98, 108, 101, 110, 100, 95, 100, 111,
  100, 103, 101, 32, 58, 10, 45, 117, 32, 34, 45, 45, 91, 49, 93, 32,
  50, 53, 53, 46, 49, 32, 45, 94, 91, 49, 93, 32, 45, 49, 32, 45,
  42, 91, 49, 93, 32, 91, 48, 93, 32, 45, 42, 91, 49, 93, 32, 45,
  50, 53, 53, 32, 45, 99, 91, 49, 93, 32, 48, 44, 50, 53, 53, 34,
  10, 95, 98, 108, 101, 110, 100, 95, 101, 120, 99, 108, 117, 115, 105, 111,
  110, 32, 58, 10, 45, 117, 32, 34, 45, 45, 42, 91, 48, 44, 49, 93,
  32, 45, 47, 91, 50, 93, 32, 45, 49, 50, 55, 46, 53, 32, 45, 43,
  91, 49, 44, 50, 93, 32, 45, 43, 91, 49, 93, 32, 91, 48, 93, 34,
  10, 95, 98, 108, 101, 110, 100, 95, 102, 114, 101, 101, 122, 101, 32, 58,
  10, 45, 117, 32, 34, 45, 42, 91, 49, 93, 32, 45, 50, 53, 53, 32,
  45, 45, 91, 49, 93, 32, 48, 46, 49, 32, 45, 45, 45, 91, 48, 93,
  32, 50, 53, 53, 32, 45, 115, 113, 114, 91, 50, 93, 32, 45, 47, 91,
  50, 93, 32, 91, 49, 93, 32, 45, 114, 109, 91, 49, 93, 32, 45, 43,
  91, 49, 93, 32, 49, 32, 45, 42, 91, 49, 93, 32, 50, 53, 53, 32,
  45, 99, 91, 49, 93, 32, 48, 44, 50, 53, 53, 34, 10, 95, 98, 108,
  101, 110, 100, 95, 103, 114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116,
  32, 58, 10, 45, 117, 32, 34, 45, 45, 91, 49, 93, 32, 91, 48, 93,
  32, 45, 42, 91, 49, 93, 32, 45, 49, 32, 45, 43, 91, 49, 93, 32,
  49, 50, 56, 32, 45, 99, 91, 49, 93, 32, 48, 44, 50, 53, 53, 34,
  10, 95, 98, 108, 101, 110, 100, 95, 103, 114, 97, 105, 110, 109, 101, 114,
  103, 101, 32, 58, 10, 45, 117, 32, 34, 45, 43, 91, 49, 93, 32, 91,
  48, 93, 32, 45, 45, 91, 49, 93, 32, 49, 50, 56, 32, 45, 99, 91,
  49, 93, 32, 48, 44, 50, 53, 53, 34, 10, 95, 98, 108, 101, 110, 100,
  95, 103, 114, 101, 101, 110, 32, 58, 10, 45, 117, 32, 34, 45, 115, 104,
  91, 48, 93, 32, 48, 44, 48, 32, 45, 115, 104, 91, 48, 93, 32, 50,
  44, 50, 32, 45, 106, 91, 49, 93, 32, 91, 50, 93, 32, 45, 106, 91,
  49, 93, 32, 91, 51, 93, 44, 48, 44, 48, 44, 48, 44, 50, 32, 45,
  114, 109, 91, 50, 44, 51, 93, 34, 10, 95, 98, 108, 101, 110, 100, 95,
  104, 97, 114, 100, 108, 105, 103, 104, 116, 32, 58, 10, 45, 117, 32, 34,
  45, 45, 42, 91, 48, 44, 49, 93, 32, 45, 47, 91, 50, 93, 32, 49,
  50, 55, 46, 53, 32, 45, 45, 43, 91, 48, 44, 49, 93, 32, 45, 42,
  91, 51, 93, 32, 50, 32, 45, 45, 91, 51, 93, 32, 50, 53, 53, 32,
  45, 45, 91, 51, 93, 32, 91, 50, 93, 32, 45, 103, 116, 91, 49, 93,
  32, 49, 50, 56, 32, 34, 92, 10, 34, 45, 106, 91, 50, 93, 32, 91,
  51, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 49, 93,
  32, 45, 114, 109, 91, 49, 44, 51, 93, 32, 45, 99, 91, 49, 93, 32,
  48, 44, 50, 53, 53, 34, 10, 95, 98, 108, 101, 110, 100, 95, 104, 97,
  114, 100, 109, 105, 120, 32, 58, 10, 45, 117, 32, 34, 45, 43, 91, 49,
  93, 32, 91, 48, 93, 32, 45, 103, 101, 91, 49, 93, 32, 50, 53, 53,
  32, 45, 42, 91, 49, 93, 32, 50, 53, 53, 34, 10, 95, 98, 108, 101,
  110, 100, 95, 104, 117, 101, 32, 58, 10, 45, 117, 32, 34, 45, 116, 111,
  95, 99, 111, 108, 111, 114, 32, 45, 115, 104, 32, 48, 44, 50, 32, 45,
  114, 103, 98, 50, 104, 115, 118, 91, 50, 44, 51, 93, 32, 45, 115, 104,
  91, 50, 93, 32, 49, 44, 50, 32, 45, 106, 91, 49, 93, 32, 91, 52,
  93, 44, 48, 44, 48, 44, 48, 44, 49, 32, 45, 114, 109, 91, 52, 93,
  32, 45, 104, 115, 118, 50, 114, 103, 98, 91, 50, 44, 51, 93, 32, 45,
  114, 109, 91, 50, 44, 51, 93, 34, 10, 95, 98, 108, 101, 110, 100, 95,
  105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 32, 58, 10,
  45, 117, 32, 34, 45, 45, 42, 91, 48, 93, 32, 123, 112, 105, 47, 50,
  53, 53, 125, 32, 45, 42, 91, 49, 93, 32, 123, 112, 105, 47, 50, 53,
  53, 125, 32, 45, 99, 111, 115, 91, 49, 44, 50, 93, 32, 45, 43, 91,
  49, 44, 50, 93, 32, 45, 45, 91, 49, 93, 32, 50, 32, 45, 42, 91,
  49, 93, 32, 45, 54, 51, 46, 55, 53, 32, 45, 99, 91, 49, 93, 32,
  48, 44, 50, 53, 53, 34, 10, 95, 98, 108, 101, 110, 100, 95, 108, 105,
  103, 104, 116, 101, 110, 32, 58, 10, 45, 117, 32, 34, 45, 109, 97, 120,
  91, 49, 93, 32, 91, 48, 93, 34, 10, 95, 98, 108, 101, 110, 100, 95,
  108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 58, 10, 45, 117, 32, 34,
  45, 116, 111, 95, 99, 111, 108, 111, 114, 32, 45, 115, 104, 32, 48, 44,
  50, 32, 45, 114, 103, 98, 50, 108, 97, 98, 91, 50, 44, 51, 93, 32,
  45, 115, 104, 91, 50, 93, 32, 49, 44, 50, 32, 45, 106, 91, 49, 93,
  32, 91, 52, 93, 44, 48, 44, 48, 44, 48, 44, 49, 32, 45, 114, 109,
  91, 52, 93, 32, 45, 108, 97, 98, 50, 114, 103, 98, 91, 50, 44, 51,
  93, 32, 45, 114, 109, 91, 50, 44, 51, 93, 34, 10, 95, 98, 108, 101,
  110, 100, 95, 108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 58, 10, 45,
  117, 32, 34, 45, 116, 111, 95, 99, 111, 108, 111, 114, 32, 45, 115, 104,
  32, 48, 44, 50, 32, 45, 114, 103, 98, 50, 121, 99, 98, 99, 114, 91,
  50, 44, 51, 93, 32, 45, 115, 104, 91, 50, 93, 32, 49, 44, 50, 32,
  45, 106, 91, 49, 93, 32, 91, 52, 93, 44, 48, 44, 48, 44, 48, 44,
  49, 32, 45, 114, 109, 91, 52, 93, 32, 45, 121, 99, 98, 99, 114, 50,
  114, 103, 98, 91, 50, 44, 51, 93, 32, 45, 114, 109, 91, 50, 44, 51,
  93, 34, 10, 95, 98, 108, 101, 110, 100, 95, 108, 105, 110, 101, 97, 114,
  98, 117, 114, 110, 32, 58, 10, 45, 117, 32, 34, 45, 43, 91, 49, 93,
  32, 91, 48, 93, 32, 45, 45, 91, 49, 93, 32, 50, 53, 53, 32, 45,
  99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 34, 10, 95, 98, 108,
  101, 110, 100, 95, 108, 105, 110, 101, 97, 114, 108, 105, 103, 104, 116, 32,
  58, 10, 45, 117, 32, 34, 45, 42, 91, 49, 93, 32, 50, 32, 45, 43,
  91, 49, 93, 32, 91, 48, 93, 32, 45, 45, 91, 49, 93, 32, 50, 53,
  53, 32, 45, 99, 91, 49, 93, 32, 48, 44, 50, 53, 53, 34, 10, 95,
  98, 108, 101, 110, 100, 95, 109, 117, 108, 116, 105, 112, 108, 121, 32, 58,
  10, 45, 117, 32, 34, 45, 42, 91, 49, 93, 32, 91, 48, 93, 32, 45,
  47, 91, 49, 93, 32, 50, 53, 53, 34, 10, 95, 98, 108, 101, 110, 100,
  95, 110, 101, 103, 97, 116, 105, 111, 110, 32, 58, 10, 45, 117, 32, 34,
  45, 43, 91, 49, 93, 32, 91, 48, 93, 32, 45, 45, 91, 49, 93, 32,
  50, 53, 53, 32, 45, 97, 98, 115, 91, 49, 93, 32, 45, 42, 91, 49,
  93, 32, 45, 49, 32, 45, 43, 91, 49, 93, 32, 50, 53, 53, 34, 10,
  95, 98, 108, 101, 110, 100, 95, 111, 114, 32, 58, 10, 45, 117, 32, 34,
  45, 111, 114, 91, 49, 93, 32, 91, 48, 93, 34, 10, 95, 98, 108, 101,
  110, 100, 95, 111, 118, 101, 114, 108, 97, 121, 32, 58, 10, 45, 117, 32,
  34, 45, 45, 42, 91, 48, 44, 49, 93, 32, 45, 47, 91, 50, 93, 32,
  49, 50, 55, 46, 53, 32, 45, 43, 91, 49, 93, 32, 91, 48, 93, 32,
  45, 42, 91, 49, 93, 32, 50, 32, 45, 45, 91, 49, 93, 32, 50, 53,
  53, 32, 45, 45, 91, 49, 93, 32, 91, 50, 93, 32, 45, 45, 108, 116,
  91, 48, 93, 32, 49, 50, 56, 32, 45, 106, 91, 49, 93, 32, 91, 50,
  93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 51, 93, 32,
  45, 114, 109, 91, 50, 44, 51, 93, 32, 45, 99, 91, 49, 93, 32, 48,
  44, 50, 53, 53, 34, 10, 95, 98, 108, 101, 110, 100, 95, 112, 105, 110,
  108, 105, 103, 104, 116, 32, 58, 10, 45, 117, 32, 34, 45, 42, 91, 49,
  93, 32, 50, 32, 45, 45, 98, 108, 101, 110, 100, 32, 100, 97, 114, 107,
  101, 110, 32, 45, 45, 91, 49, 93, 32, 50, 53, 54, 32, 45, 45, 98,
  108, 101, 110, 100, 91, 48, 44, 49, 93, 32, 108, 105, 103, 104, 116, 101,
  110, 32, 45, 103, 101, 91, 49, 93, 32, 48, 32, 34, 92, 10, 34, 45,
  106, 91, 50, 93, 32, 91, 51, 93, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 49, 44, 91, 49, 93, 32, 45, 114, 109, 91, 49, 44, 51, 93, 34,
  10, 95, 98, 108, 101, 110, 100, 95, 114, 101, 102, 108, 101, 99, 116, 32,
  58, 10, 45, 117, 32, 34, 45, 45, 91, 49, 93, 32, 50, 53, 53, 46,
  49, 32, 45, 42, 91, 49, 93, 32, 45, 49, 32, 45, 45, 115, 113, 114,
  91, 48, 93, 32, 45, 47, 91, 50, 93, 32, 91, 49, 93, 32, 45, 114,
  109, 91, 49, 93, 32, 45, 99, 91, 49, 93, 32, 48, 44, 50, 53, 53,
  34, 10, 95, 98, 108, 101, 110, 100, 95, 114, 101, 100, 32, 58, 10, 45,
  117, 32, 34, 45, 115, 104, 91, 48, 93, 32, 49, 44, 49, 48, 48, 37,
  32, 45, 106, 91, 49, 93, 32, 91, 50, 93, 44, 48, 44, 48, 44, 48,
  44, 49, 32, 45, 114, 109, 91, 50, 93, 34, 10, 95, 98, 108, 101, 110,
  100, 95, 115, 97, 116, 117, 114, 97, 116, 105, 111, 110, 32, 58, 10, 45,
  117, 32, 34, 45, 116, 111, 95, 99, 111, 108, 111, 114, 32, 45, 115, 104,
  32, 48, 44, 50, 32, 45, 114, 103, 98, 50, 104, 115, 118, 91, 50, 44,
  51, 93, 32, 45, 115, 104, 105, 102, 116, 91, 50, 44, 51, 93, 32, 48,
  44, 48, 44, 48, 44, 45, 49, 44, 50, 32, 45, 115, 104, 91, 50, 93,
  32, 49, 44, 50, 32, 45, 106, 91, 49, 93, 32, 91, 52, 93, 44, 48,
  44, 48, 44, 48, 44, 49, 32, 45, 114, 109, 91, 52, 93, 32, 45, 115,
  104, 105, 102, 116, 91, 50, 44, 51, 93, 32, 48, 44, 48, 44, 48, 44,
  49, 44, 50, 32, 45, 104, 115, 118, 50, 114, 103, 98, 91, 50, 44, 51,
  93, 32, 45, 114, 109, 91, 50, 44, 51, 93, 34, 10, 95, 98, 108, 101,
  110, 100, 95, 115, 99, 114, 101, 101, 110, 32, 58, 10, 45, 117, 32, 34,
  45, 45, 45, 91, 48, 93, 32, 50, 53, 53, 32, 45, 45, 91, 49, 93,
  32, 50, 53, 53, 32, 45, 42, 91, 49, 44, 50, 93, 32, 45, 47, 91,
  49, 93, 32, 50, 53, 53, 32, 45, 42, 91, 49, 93, 32, 45, 49, 32,
  45, 43, 91, 49, 93, 32, 50, 53, 53, 34, 10, 95, 98, 108, 101, 110,
  100, 95, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97, 103, 101, 32, 58,
  10, 45, 117, 32, 34, 45, 110, 111, 114, 109, 91, 49, 93, 32, 45, 108,
  97, 98, 101, 108, 91, 49, 93, 32, 78, 61, 123, 105, 77, 43, 49, 125,
  32, 34, 92, 10, 34, 45, 114, 101, 112, 101, 97, 116, 32, 64, 123, 48,
  44, 115, 125, 32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48,
  93, 32, 36, 62, 32, 109, 61, 123, 105, 109, 125, 32, 77, 61, 123, 105,
  77, 125, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 123, 49, 45, 49,
  47, 50, 53, 54, 125, 32, 45, 43, 91, 45, 49, 93, 32, 91, 49, 93,
  32, 45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 49, 93, 32,
  123, 36, 78, 42, 50, 53, 54, 125, 44, 48, 44, 123, 36, 78, 45, 49,
  47, 50, 53, 54, 125, 32, 34, 92, 10, 34, 45, 105, 91, 45, 50, 93,
  32, 50, 53, 54, 44, 49, 44, 49, 44, 49, 44, 39, 120, 42, 40, 36,
  77, 45, 36, 109, 41, 47, 50, 53, 53, 43, 36, 109, 39, 32, 45, 114,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 50, 32, 45, 42,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 91, 45, 50, 44,
  45, 49, 93, 32, 36, 78, 44, 49, 44, 49, 44, 49, 44, 50, 32, 45,
  43, 91, 45, 49, 93, 32, 49, 101, 45, 56, 32, 45, 47, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 100, 111, 110, 101, 32, 34, 92, 10, 34, 45,
  97, 91, 50, 45, 45, 49, 93, 32, 99, 32, 45, 109, 97, 112, 91, 49,
  93, 32, 91, 50, 93, 32, 45, 114, 109, 91, 50, 93, 34, 10, 95, 98,
  108, 101, 110, 100, 95, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97, 103,
  101, 48, 32, 58, 10, 45, 117, 32, 34, 45, 110, 111, 114, 109, 91, 49,
  93, 32, 45, 45, 110, 101, 113, 91, 49, 93, 32, 48, 32, 45, 108, 97,
  98, 101, 108, 91, 49, 93, 32, 78, 61, 64, 123, 49, 44, 105, 77, 43,
  49, 125, 32, 34, 92, 10, 34, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  123, 48, 44, 115, 125, 32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115,
  91, 48, 93, 32, 36, 62, 32, 109, 61, 123, 105, 109, 125, 32, 77, 61,
  123, 105, 77, 125, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 123, 49,
  45, 49, 47, 50, 53, 54, 125, 32, 45, 43, 91, 45, 49, 93, 32, 91,
  49, 93, 32, 45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 49,
  93, 32, 123, 36, 78, 42, 50, 53, 54, 125, 44, 48, 44, 123, 36, 78,
  45, 49, 47, 50, 53, 54, 125, 32, 34, 92, 10, 34, 45, 105, 91, 45,
  50, 93, 32, 50, 53, 54, 44, 49, 44, 49, 44, 49, 44, 39, 120, 42,
  40, 36, 77, 45, 36, 109, 41, 47, 50, 53, 53, 43, 36, 109, 39, 32,
  45, 114, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 50, 32,
  45, 42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 91, 45,
  50, 44, 45, 49, 93, 32, 36, 78, 44, 49, 44, 49, 44, 49, 44, 50,
  32, 45, 43, 91, 45, 49, 93, 32, 49, 101, 45, 56, 32, 45, 47, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 100, 111, 110, 101, 32, 34, 92, 10,
  34, 45, 97, 91, 51, 45, 45, 49, 93, 32, 99, 32, 45, 109, 97, 112,
  91, 49, 93, 32, 91, 51, 93, 32, 45, 114, 109, 91, 51, 93, 32, 45,
  42, 91, 49, 44, 50, 93, 34, 10, 95, 98, 108, 101, 110, 100, 95, 115,
  111, 102, 116, 98, 117, 114, 110, 32, 58, 10, 45, 117, 32, 34, 45, 45,
  45, 91, 48, 93, 32, 50, 53, 53, 46, 49, 32, 45, 94, 91, 50, 93,
  32, 45, 49, 32, 45, 42, 91, 50, 93, 32, 91, 49, 93, 32, 45, 42,
  91, 50, 93, 32, 45, 49, 50, 55, 46, 53, 32, 45, 45, 45, 91, 48,
  93, 32, 50, 53, 53, 32, 45, 45, 43, 91, 49, 93, 32, 48, 46, 49,
  32, 45, 47, 91, 51, 44, 52, 93, 32, 45, 42, 91, 51, 93, 32, 49,
  50, 55, 46, 53, 32, 45, 43, 91, 51, 93, 32, 50, 53, 53, 32, 45,
  43, 91, 49, 93, 32, 91, 48, 93, 32, 45, 103, 116, 91, 49, 93, 32,
  50, 53, 53, 32, 34, 92, 10, 34, 45, 106, 91, 50, 93, 32, 91, 51,
  93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 49, 93, 32,
  45, 114, 109, 91, 49, 44, 51, 93, 32, 45, 99, 91, 49, 93, 32, 48,
  44, 50, 53, 53, 34, 10, 95, 98, 108, 101, 110, 100, 95, 115, 111, 102,
  116, 100, 111, 100, 103, 101, 32, 58, 10, 45, 117, 32, 34, 45, 45, 45,
  91, 49, 93, 32, 50, 53, 53, 46, 49, 32, 45, 94, 91, 50, 93, 32,
  45, 49, 32, 45, 42, 91, 50, 93, 32, 91, 48, 93, 32, 45, 42, 91,
  50, 93, 32, 45, 49, 50, 55, 46, 53, 32, 45, 45, 45, 91, 49, 93,
  32, 50, 53, 53, 32, 45, 45, 43, 91, 48, 93, 32, 48, 46, 49, 32,
  45, 47, 91, 51, 44, 52, 93, 32, 45, 42, 91, 51, 93, 32, 49, 50,
  55, 46, 53, 32, 45, 43, 91, 51, 93, 32, 50, 53, 53, 32, 45, 43,
  91, 49, 93, 32, 91, 48, 93, 32, 45, 103, 116, 91, 49, 93, 32, 50,
  53, 53, 32, 34, 92, 10, 34, 45, 106, 91, 50, 93, 32, 91, 51, 93,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 49, 93, 32, 45,
  114, 109, 91, 49, 44, 51, 93, 32, 45, 99, 91, 49, 93, 32, 48, 44,
  50, 53, 53, 34, 10, 95, 98, 108, 101, 110, 100, 95, 115, 111, 102, 116,
  108, 105, 103, 104, 116, 32, 58, 10, 45, 117, 32, 34, 45, 45, 47, 91,
  48, 93, 32, 50, 53, 53, 32, 45, 47, 91, 49, 93, 32, 50, 53, 53,
  32, 45, 45, 115, 113, 114, 91, 45, 49, 93, 32, 45, 42, 91, 50, 93,
  32, 91, 49, 93, 32, 45, 42, 91, 49, 93, 32, 91, 51, 93, 32, 45,
  42, 91, 49, 93, 32, 45, 50, 32, 45, 42, 91, 50, 93, 32, 50, 32,
  45, 43, 91, 49, 45, 51, 93, 32, 45, 42, 91, 49, 93, 32, 50, 53,
  53, 32, 45, 99, 91, 49, 93, 32, 48, 44, 50, 53, 53, 34, 10, 95,
  98, 108, 101, 110, 100, 95, 115, 116, 97, 109, 112, 32, 58, 10, 45, 117,
  32, 34, 45, 42, 91, 49, 93, 32, 50, 32, 45, 43, 91, 49, 93, 32,
  91, 48, 93, 32, 45, 45, 91, 49, 93, 32, 50, 53, 53, 32, 45, 99,
  91, 49, 93, 32, 48, 44, 50, 53, 53, 34, 10, 95, 98, 108, 101, 110,
  100, 95, 115, 117, 98, 116, 114, 97, 99, 116, 32, 58, 10, 45, 117, 32,
  34, 45, 45, 91, 49, 93, 32, 91, 48, 93, 32, 45, 42, 91, 49, 93,
  32, 45, 49, 32, 45, 99, 91, 49, 93, 32, 48, 44, 50, 53, 53, 34,
  10, 95, 98, 108, 101, 110, 100, 95, 118, 97, 108, 117, 101, 32, 58, 10,
  45, 117, 32, 34, 45, 116, 111, 95, 99, 111, 108, 111, 114, 32, 45, 115,
  104, 32, 48, 44, 50, 32, 45, 114, 103, 98, 50, 104, 115, 118, 91, 50,
  44, 51, 93, 32, 45, 115, 104, 91, 50, 93, 32, 48, 44, 49, 32, 45,
  106, 91, 49, 93, 32, 91, 52, 93, 32, 45, 114, 109, 91, 52, 93, 32,
  45, 104, 115, 118, 50, 114, 103, 98, 91, 50, 44, 51, 93, 32, 45, 114,
  109, 91, 50, 44, 51, 93, 34, 10, 95, 98, 108, 101, 110, 100, 95, 118,
  105, 118, 105, 100, 108, 105, 103, 104, 116, 32, 58, 10, 45, 117, 32, 34,
  45, 42, 91, 49, 93, 32, 50, 32, 45, 45, 98, 108, 101, 110, 100, 32,
  98, 117, 114, 110, 32, 45, 45, 91, 49, 93, 32, 50, 53, 54, 32, 45,
  45, 98, 108, 101, 110, 100, 91, 48, 44, 49, 93, 32, 100, 111, 100, 103,
  101, 32, 45, 103, 101, 91, 49, 93, 32, 48, 32, 34, 92, 10, 34, 45,
  106, 91, 50, 93, 32, 91, 51, 93, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 49, 44, 91, 49, 93, 32, 45, 114, 109, 91, 49, 44, 51, 93, 34,
  10, 95, 98, 108, 101, 110, 100, 95, 120, 111, 114, 32, 58, 10, 45, 117,
  32, 34, 45, 120, 111, 114, 91, 49, 93, 32, 91, 48, 93, 34, 10, 98,
  108, 101, 110, 100, 95, 101, 100, 103, 101, 115, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 123, 36, 49, 62, 61, 48, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 66, 108, 101, 110, 100, 32, 105, 109, 97, 103, 101,
  36, 63, 32, 117, 115, 105, 110, 103, 32, 39, 101, 100, 103, 101, 115, 39,
  32, 109, 111, 100, 101, 44, 32, 119, 105, 116, 104, 32, 115, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 32, 36, 49, 46, 34, 10, 45, 105, 102, 32,
  123, 64, 35, 62, 49, 125, 32, 45, 118, 32, 45, 32, 45, 116, 111, 95,
  114, 103, 98, 32, 45, 114, 91, 94, 48, 93, 32, 91, 48, 93, 44, 48,
  44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 103,
  114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 32, 45, 43, 91,
  45, 49, 93, 32, 49, 32, 45, 98, 91, 45, 49, 93, 32, 36, 49, 32,
  45, 110, 91, 45, 49, 93, 32, 49, 44, 49, 48, 32, 45, 115, 113, 114,
  91, 45, 49, 93, 32, 45, 115, 91, 45, 50, 93, 32, 99, 32, 45, 42,
  91, 45, 52, 45, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 97, 91,
  45, 52, 45, 45, 49, 93, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 114, 91, 94, 48, 93, 32, 91, 48, 93, 44,
  48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 43, 32, 45,
  115, 91, 45, 49, 93, 32, 99, 32, 45, 47, 91, 45, 52, 45, 45, 50,
  93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  97, 91, 45, 51, 45, 45, 49, 93, 32, 99, 32, 45, 118, 32, 43, 32,
  45, 101, 110, 100, 105, 102, 10, 98, 108, 101, 110, 100, 95, 102, 97, 100,
  101, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 66, 108, 101,
  110, 100, 32, 105, 109, 97, 103, 101, 36, 63, 32, 117, 115, 105, 110, 103,
  32, 39, 102, 97, 100, 101, 39, 32, 109, 111, 100, 101, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 91, 94, 45, 49, 93, 32, 64, 123, 45, 109,
  97, 120, 95, 119, 104, 100, 115, 91, 94, 45, 49, 93, 125, 44, 48, 10,
  45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93,
  44, 91, 45, 50, 93, 44, 49, 48, 48, 37, 44, 49, 32, 45, 109, 97,
  120, 91, 45, 49, 93, 32, 48, 32, 45, 109, 105, 110, 91, 45, 49, 93,
  32, 123, 64, 35, 45, 50, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 64, 35, 45, 49, 125, 32, 45, 45, 45, 91, 45, 49, 93, 32, 36,
  62, 32, 45, 97, 98, 115, 91, 45, 49, 93, 32, 45, 45, 91, 45, 49,
  93, 32, 49, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 109,
  97, 120, 91, 45, 49, 93, 32, 48, 32, 45, 42, 91, 36, 62, 44, 45,
  49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 43, 32, 45, 118, 32, 43, 10, 98, 108, 101, 110, 100, 95, 109,
  101, 100, 105, 97, 110, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 66, 108, 101, 110, 100, 32, 105, 109, 97, 103, 101, 36, 63, 32, 117,
  115, 105, 110, 103, 32, 39, 109, 101, 100, 105, 97, 110, 39, 32, 109, 111,
  100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 116, 111, 95, 99, 111,
  108, 111, 114, 109, 111, 100, 101, 32, 48, 32, 45, 114, 32, 64, 123, 45,
  109, 97, 120, 95, 119, 104, 100, 125, 44, 49, 48, 48, 37, 44, 48, 44,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 44, 48, 46, 53, 32, 119, 104,
  100, 61, 123, 119, 125, 44, 123, 104, 125, 44, 123, 100, 125, 32, 45, 114,
  32, 49, 48, 48, 37, 44, 123, 104, 42, 100, 125, 44, 49, 44, 49, 48,
  48, 37, 44, 45, 49, 10, 45, 105, 102, 32, 123, 64, 35, 61, 61, 50,
  125, 32, 45, 43, 32, 45, 47, 32, 50, 10, 45, 101, 108, 105, 102, 32,
  123, 64, 35, 62, 50, 125, 10, 45, 112, 101, 114, 109, 117, 116, 101, 32,
  120, 121, 99, 122, 32, 45, 97, 32, 99, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 115, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 115,
  45, 49, 45, 36, 62, 125, 10, 45, 115, 104, 91, 45, 49, 93, 32, 36,
  62, 44, 36, 62, 32, 45, 115, 104, 91, 45, 50, 93, 32, 123, 36, 62,
  43, 49, 125, 44, 123, 36, 62, 43, 49, 125, 32, 45, 45, 103, 116, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 45, 106, 91, 45, 51, 93, 32, 91,
  45, 50, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45,
  49, 93, 32, 45, 106, 91, 45, 51, 93, 32, 91, 45, 52, 93, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 50, 93, 32, 45, 106,
  91, 45, 52, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 52,
  45, 45, 49, 93, 10, 45, 100, 111, 110, 101, 10, 45, 100, 111, 110, 101,
  10, 45, 105, 102, 32, 123, 115, 37, 50, 125, 32, 45, 99, 104, 97, 110,
  110, 101, 108, 115, 32, 53, 48, 37, 32, 45, 101, 108, 115, 101, 32, 45,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 123, 115, 47, 50, 45, 49, 125,
  44, 123, 115, 47, 50, 125, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 43, 32, 45, 47, 32, 50, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 112, 101, 114, 109, 117, 116, 101, 32,
  120, 121, 99, 122, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 91, 45,
  49, 93, 32, 36, 119, 104, 100, 44, 49, 48, 48, 37, 44, 45, 49, 32,
  45, 118, 32, 43, 10, 95, 102, 97, 100, 101, 32, 58, 10, 45, 114, 91,
  45, 50, 93, 32, 91, 45, 51, 93, 44, 53, 32, 45, 114, 91, 45, 49,
  93, 32, 91, 45, 50, 93, 44, 51, 32, 45, 99, 91, 45, 49, 93, 32,
  36, 49, 37, 44, 36, 50, 37, 32, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 49, 32, 45, 106, 91, 45, 51, 93, 32, 91, 45, 50, 93, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 32, 45, 114,
  109, 91, 45, 50, 44, 45, 49, 93, 10, 102, 97, 100, 101, 95, 100, 105,
  97, 109, 111, 110, 100, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  49, 61, 55, 48, 125, 44, 36, 123, 50, 61, 57, 48, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 114, 101, 97, 116, 101, 32, 40, 36,
  49, 37, 44, 36, 50, 37, 41, 32, 100, 105, 97, 109, 111, 110, 100, 45,
  115, 104, 97, 112, 101, 100, 32, 102, 97, 100, 105, 110, 103, 32, 102, 114,
  111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64,
  35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43,
  49, 125, 93, 10, 40, 48, 44, 49, 44, 48, 59, 49, 44, 49, 44, 49,
  59, 48, 44, 49, 44, 48, 41, 32, 45, 95, 102, 97, 100, 101, 32, 36,
  49, 44, 36, 50, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 102, 97, 100, 101, 95, 108, 105, 110, 101, 97,
  114, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 52, 53,
  125, 44, 36, 123, 50, 61, 51, 48, 125, 44, 36, 123, 51, 61, 55, 48,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 114, 101, 97, 116,
  101, 32, 40, 36, 50, 37, 44, 36, 51, 37, 41, 32, 108, 105, 110, 101,
  97, 114, 32, 102, 97, 100, 105, 110, 103, 32, 102, 114, 111, 109, 32, 105,
  109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 97, 110, 103,
  108, 101, 32, 36, 49, 32, 100, 101, 103, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35,
  47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49,
  125, 93, 10, 54, 52, 44, 54, 52, 44, 49, 44, 49, 44, 34, 120, 42,
  99, 111, 115, 40, 36, 49, 42, 112, 105, 47, 49, 56, 48, 41, 32, 43,
  32, 121, 42, 115, 105, 110, 40, 36, 49, 42, 112, 105, 47, 49, 56, 48,
  41, 34, 32, 45, 95, 102, 97, 100, 101, 32, 36, 50, 44, 36, 51, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 102, 97, 100, 101, 95, 114, 97, 100, 105, 97, 108, 32, 58, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 49, 61, 51, 48, 125, 44, 36, 123, 50,
  61, 55, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 114,
  101, 97, 116, 101, 32, 40, 36, 49, 37, 44, 36, 50, 37, 41, 32, 114,
  97, 100, 105, 97, 108, 32, 102, 97, 100, 105, 110, 103, 32, 102, 114, 111,
  109, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35,
  47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49,
  125, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 61, 91,
  45, 49, 93, 32, 49, 44, 53, 48, 37, 44, 53, 48, 37, 32, 45, 100,
  105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 95,
  102, 97, 100, 101, 32, 36, 49, 44, 36, 50, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 102, 97, 100, 101,
  95, 120, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 51,
  48, 125, 44, 36, 123, 50, 61, 55, 48, 125, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 67, 114, 101, 97, 116, 101, 32, 40, 36, 49, 37, 44,
  36, 50, 37, 41, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 32,
  102, 97, 100, 105, 110, 103, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103,
  101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45,
  108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 32, 40, 48, 44,
  49, 41, 32, 45, 95, 102, 97, 100, 101, 32, 36, 49, 44, 36, 50, 32,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 102, 97, 100, 101, 95, 121, 32, 58, 32, 45, 115, 107, 105, 112, 32,
  36, 123, 49, 61, 51, 48, 125, 44, 36, 123, 50, 61, 55, 48, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 114, 101, 97, 116, 101, 32,
  40, 36, 49, 37, 44, 36, 50, 37, 41, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 32, 102, 97, 100, 105, 110, 103, 32, 102, 114, 111, 109, 32, 105,
  109, 97, 103, 101, 36, 63, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41,
  125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 32,
  40, 48, 59, 49, 41, 32, 45, 95, 102, 97, 100, 101, 32, 36, 49, 44,
  36, 50, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 102, 97, 100, 101, 95, 122, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 49, 61, 51, 48, 125, 44, 36, 123, 50, 61, 55,
  48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 114, 101, 97,
  116, 101, 32, 40, 36, 49, 37, 44, 36, 50, 37, 41, 32, 116, 114, 97,
  110, 115, 118, 101, 114, 115, 97, 108, 32, 102, 97, 100, 105, 110, 103, 32,
  102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116,
  40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36,
  62, 43, 49, 125, 93, 32, 40, 48, 47, 49, 41, 32, 45, 95, 102, 97,
  100, 101, 32, 36, 49, 44, 36, 50, 32, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 97, 110, 105, 109, 97, 116,
  101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 51, 48,
  125, 44, 36, 123, 50, 61, 48, 125, 44, 36, 123, 51, 61, 34, 34, 125,
  44, 36, 123, 52, 61, 49, 48, 125, 44, 36, 123, 53, 61, 49, 125, 44,
  34, 36, 123, 54, 61, 125, 34, 10, 45, 105, 102, 32, 123, 105, 115, 118,
  97, 108, 40, 36, 49, 41, 125, 10, 45, 105, 102, 32, 36, 50, 32, 45,
  101, 91, 48, 45, 45, 52, 93, 32, 34, 65, 110, 105, 109, 97, 116, 101,
  32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 97,
  32, 100, 101, 108, 97, 121, 32, 111, 102, 32, 36, 49, 32, 109, 115, 44,
  32, 97, 110, 100, 32, 112, 105, 110, 103, 45, 112, 111, 110, 103, 32, 109,
  111, 100, 101, 46, 34, 10, 45, 101, 108, 115, 101, 32, 45, 101, 91, 48,
  45, 45, 52, 93, 32, 34, 65, 110, 105, 109, 97, 116, 101, 32, 105, 109,
  97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 97, 32, 100, 101,
  108, 97, 121, 32, 111, 102, 32, 36, 49, 32, 109, 115, 46, 34, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 33, 64, 35, 125, 32,
  45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  118, 32, 45, 10, 115, 112, 101, 101, 100, 61, 36, 49, 10, 112, 97, 117,
  115, 101, 61, 45, 49, 10, 100, 105, 114, 101, 99, 116, 105, 111, 110, 61,
  49, 10, 102, 114, 97, 109, 101, 61, 48, 10, 45, 100, 111, 10, 45, 119,
  91, 36, 102, 114, 97, 109, 101, 93, 32, 45, 49, 44, 45, 49, 44, 49,
  44, 48, 44, 45, 49, 44, 45, 49, 44, 64, 123, 36, 102, 114, 97, 109,
  101, 44, 98, 125, 46, 64, 123, 36, 102, 114, 97, 109, 101, 44, 120, 125,
  10, 102, 114, 97, 109, 101, 61, 123, 36, 102, 114, 97, 109, 101, 43, 36,
  100, 105, 114, 101, 99, 116, 105, 111, 110, 125, 10, 45, 105, 102, 32, 36,
  50, 10, 45, 105, 102, 32, 123, 36, 102, 114, 97, 109, 101, 61, 61, 45,
  49, 125, 32, 102, 114, 97, 109, 101, 61, 48, 32, 100, 105, 114, 101, 99,
  116, 105, 111, 110, 61, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 102,
  114, 97, 109, 101, 61, 61, 64, 35, 125, 32, 102, 114, 97, 109, 101, 61,
  123, 64, 35, 45, 49, 125, 32, 100, 105, 114, 101, 99, 116, 105, 111, 110,
  61, 45, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101,
  32, 102, 114, 97, 109, 101, 61, 123, 36, 102, 114, 97, 109, 101, 37, 64,
  35, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 119, 97, 105, 116, 32,
  36, 115, 112, 101, 101, 100, 10, 45, 105, 102, 32, 123, 40, 64, 123, 33,
  44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 34, 32, 124, 124, 32, 34,
  64, 123, 33, 44, 67, 84, 82, 76, 82, 73, 71, 72, 84, 125, 41, 34,
  32, 38, 38, 32, 34, 64, 123, 33, 44, 68, 125, 125, 32, 45, 119, 91,
  93, 32, 123, 64, 123, 33, 44, 119, 125, 42, 49, 46, 53, 125, 44, 123,
  64, 123, 33, 44, 104, 125, 42, 49, 46, 53, 125, 32, 45, 119, 97, 105,
  116, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 40, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 34,
  32, 124, 124, 32, 34, 64, 123, 33, 44, 67, 84, 82, 76, 82, 73, 71,
  72, 84, 125, 41, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 67, 125,
  125, 32, 45, 119, 91, 93, 32, 123, 64, 123, 33, 44, 119, 125, 47, 49,
  46, 53, 125, 44, 123, 64, 123, 33, 44, 104, 125, 47, 49, 46, 53, 125,
  32, 45, 119, 97, 105, 116, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 40, 64, 123, 33, 44, 67, 84, 82, 76, 76,
  69, 70, 84, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 44, 67, 84,
  82, 76, 82, 73, 71, 72, 84, 125, 41, 34, 32, 38, 38, 32, 34, 64,
  123, 33, 44, 82, 125, 125, 32, 45, 119, 91, 93, 32, 64, 123, 48, 44,
  119, 125, 44, 64, 123, 48, 44, 104, 125, 32, 45, 119, 97, 105, 116, 32,
  45, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 64, 123,
  33, 44, 111, 125, 32, 115, 112, 101, 101, 100, 61, 123, 109, 105, 110, 40,
  53, 48, 48, 44, 109, 97, 120, 40, 49, 48, 44, 36, 115, 112, 101, 101,
  100, 45, 49, 48, 42, 64, 123, 33, 44, 111, 125, 41, 41, 125, 32, 45,
  119, 97, 105, 116, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 64, 123, 33, 44, 83, 80, 65, 67, 69, 125, 10, 45, 105,
  102, 32, 123, 36, 112, 97, 117, 115, 101, 62, 61, 48, 125, 32, 100, 105,
  114, 101, 99, 116, 105, 111, 110, 61, 36, 112, 97, 117, 115, 101, 32, 112,
  97, 117, 115, 101, 61, 45, 49, 10, 45, 101, 108, 115, 101, 32, 112, 97,
  117, 115, 101, 61, 36, 100, 105, 114, 101, 99, 116, 105, 111, 110, 32, 100,
  105, 114, 101, 99, 116, 105, 111, 110, 61, 48, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 119, 97, 105, 116, 32, 45, 49, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34, 32, 38, 38,
  32, 34, 33, 64, 123, 33, 44, 81, 125, 34, 32, 38, 38, 32, 34, 33,
  64, 123, 33, 44, 69, 83, 67, 125, 125, 32, 45, 118, 32, 43, 10, 45,
  101, 108, 115, 101, 10, 45, 101, 91, 48, 45, 45, 51, 93, 32, 34, 67,
  111, 109, 112, 117, 116, 101, 32, 97, 110, 105, 109, 97, 116, 101, 100, 32,
  118, 101, 114, 115, 105, 111, 110, 32, 111, 102, 32, 102, 105, 108, 116, 101,
  114, 32, 39, 36, 49, 39, 44, 32, 102, 114, 111, 109, 32, 112, 97, 114,
  97, 109, 101, 116, 101, 114, 115, 32, 36, 50, 32, 116, 111, 32, 36, 51,
  32, 119, 105, 116, 104, 32, 36, 52, 32, 102, 114, 97, 109, 101, 115, 46,
  34, 10, 45, 105, 102, 32, 123, 33, 40, 36, 53, 124, 124, 110, 97, 114,
  103, 40, 34, 36, 54, 34, 41, 41, 125, 32, 45, 114, 101, 116, 117, 114,
  110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 32, 40, 36,
  50, 41, 32, 40, 36, 51, 41, 32, 45, 121, 91, 45, 50, 44, 45, 49,
  93, 32, 120, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 32,
  45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 36, 52, 44, 49,
  44, 49, 44, 51, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45,
  114, 112, 114, 111, 103, 114, 101, 115, 115, 32, 48, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 10, 45, 118, 32, 43, 32,
  45, 101, 91, 93, 32, 34, 32, 62, 32, 65, 110, 105, 109, 97, 116, 101,
  32, 105, 109, 97, 103, 101, 32, 91, 34, 36, 62, 34, 93, 34, 32, 45,
  118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 52, 32, 45,
  45, 108, 91, 48, 44, 49, 93, 10, 45, 36, 49, 91, 45, 49, 93, 32,
  64, 123, 48, 44, 123, 36, 62, 42, 64, 123, 48, 44, 119, 125, 125, 45,
  123, 40, 36, 62, 43, 49, 41, 42, 64, 123, 48, 44, 119, 125, 45, 49,
  125, 125, 32, 45, 114, 109, 91, 48, 93, 10, 45, 105, 102, 32, 123, 110,
  97, 114, 103, 40, 34, 36, 54, 34, 41, 125, 32, 45, 111, 32, 64, 123,
  45, 102, 105, 108, 101, 110, 97, 109, 101, 92, 32, 34, 36, 54, 34, 44,
  64, 123, 62, 44, 45, 50, 125, 44, 36, 62, 125, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 33, 36, 53, 125, 32, 45, 114, 109,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 112, 114, 111, 103, 114, 101,
  115, 115, 32, 123, 49, 48, 48, 42, 40, 36, 62, 43, 49, 41, 47, 36,
  52, 125, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 114,
  32, 62, 32, 65, 110, 105, 109, 97, 116, 101, 32, 105, 109, 97, 103, 101,
  32, 91, 34, 64, 123, 62, 44, 45, 50, 125, 34, 93, 32, 58, 32, 70,
  114, 97, 109, 101, 32, 34, 123, 36, 62, 43, 49, 125, 34, 47, 36, 52,
  32, 32, 32, 32, 34, 32, 45, 118, 32, 45, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 49, 93, 32, 45, 100,
  111, 110, 101, 32, 45, 114, 109, 91, 48, 93, 32, 45, 118, 32, 43, 10,
  45, 101, 110, 100, 105, 102, 10, 109, 111, 114, 112, 104, 32, 58, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 50, 61, 48, 46, 49, 125, 44, 36, 123,
  51, 61, 53, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 114,
  101, 97, 116, 101, 32, 109, 111, 114, 112, 104, 105, 110, 103, 32, 115, 101,
  113, 117, 101, 110, 99, 101, 32, 98, 101, 116, 119, 101, 101, 110, 32, 105,
  109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 36, 49, 32,
  105, 110, 116, 114, 97, 45, 102, 114, 97, 109, 101, 115, 44, 32, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 50, 32, 97, 110, 100, 32,
  112, 114, 101, 99, 105, 115, 105, 111, 110, 32, 36, 51, 46, 92, 110, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 91, 94, 48, 93, 32, 91, 48, 93,
  44, 51, 32, 45, 105, 91, 48, 93, 32, 40, 64, 35, 41, 32, 45, 45,
  91, 48, 93, 32, 49, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 48,
  10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 114, 32, 62,
  32, 77, 111, 114, 112, 104, 32, 105, 109, 97, 103, 101, 32, 34, 36, 62,
  34, 32, 116, 111, 32, 105, 109, 97, 103, 101, 32, 34, 123, 36, 62, 43,
  49, 125, 34, 46, 32, 32, 32, 32, 34, 32, 45, 118, 32, 45, 10, 45,
  45, 101, 113, 117, 97, 108, 105, 122, 101, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 110, 91, 45, 50, 44, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  10, 45, 45, 100, 105, 115, 112, 108, 97, 99, 101, 109, 101, 110, 116, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 44, 36, 50, 44, 36, 51, 32, 45,
  45, 119, 97, 114, 112, 91, 45, 53, 93, 32, 91, 45, 49, 93, 44, 49,
  44, 49, 44, 49, 44, 36, 49, 32, 45, 97, 91, 45, 36, 49, 45, 45,
  49, 93, 32, 122, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 45, 100,
  105, 115, 112, 108, 97, 99, 101, 109, 101, 110, 116, 91, 45, 51, 93, 32,
  91, 45, 50, 93, 44, 36, 50, 44, 36, 51, 32, 45, 45, 119, 97, 114,
  112, 91, 45, 53, 93, 32, 91, 45, 49, 93, 44, 49, 44, 49, 44, 49,
  44, 36, 49, 32, 45, 97, 91, 45, 36, 49, 45, 45, 49, 93, 32, 122,
  32, 45, 114, 109, 91, 45, 55, 45, 45, 52, 44, 45, 50, 93, 10, 40,
  49, 47, 48, 41, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  44, 51, 32, 45, 42, 91, 45, 51, 93, 32, 91, 45, 49, 93, 32, 45,
  42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 109, 105, 114, 114, 111, 114,
  91, 45, 49, 93, 32, 122, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 115, 91, 45, 49, 93, 32, 122, 10, 45, 109, 118, 91, 45, 36,
  49, 45, 45, 49, 93, 32, 49, 32, 45, 109, 118, 91, 49, 93, 32, 64,
  35, 10, 45, 100, 111, 110, 101, 32, 45, 109, 118, 91, 45, 49, 93, 32,
  49, 32, 45, 114, 109, 91, 48, 93, 32, 45, 118, 32, 43, 10, 114, 101,
  103, 105, 115, 116, 101, 114, 95, 110, 111, 110, 114, 105, 103, 105, 100, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 46, 50, 125,
  44, 36, 123, 50, 61, 53, 125, 44, 36, 123, 51, 61, 48, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 103, 105, 115, 116, 101, 114,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 119, 105, 116, 104, 32, 110, 111,
  110, 45, 114, 105, 103, 105, 100, 32, 119, 97, 114, 112, 44, 32, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 49, 44, 32, 112, 114, 101,
  99, 105, 115, 105, 111, 110, 32, 36, 50, 32, 97, 110, 100, 32, 36, 51,
  32, 115, 99, 97, 108, 101, 40, 115, 41, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 45, 101, 113, 117, 97, 108, 105, 122, 101, 91, 48, 93, 32, 45,
  110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 109, 118, 91,
  45, 49, 93, 32, 49, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 105, 102, 32, 123, 36, 62, 62, 49, 125, 10, 45, 45, 101, 113,
  117, 97, 108, 105, 122, 101, 91, 45, 49, 93, 32, 45, 110, 91, 45, 49,
  93, 32, 48, 44, 50, 53, 53, 32, 45, 45, 100, 105, 115, 112, 108, 97,
  99, 101, 109, 101, 110, 116, 91, 49, 93, 32, 91, 45, 49, 93, 44, 36,
  49, 44, 36, 50, 44, 36, 51, 32, 45, 114, 109, 91, 45, 50, 93, 10,
  45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49,
  44, 49, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 109, 118,
  91, 45, 49, 93, 32, 50, 32, 45, 101, 110, 100, 105, 102, 32, 45, 100,
  111, 110, 101, 32, 45, 114, 109, 91, 49, 93, 32, 45, 118, 32, 43, 10,
  114, 101, 103, 105, 115, 116, 101, 114, 95, 114, 105, 103, 105, 100, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 82, 101, 103, 105, 115, 116, 101, 114, 32,
  105, 109, 97, 103, 101, 36, 63, 32, 119, 105, 116, 104, 32, 114, 105, 103,
  105, 100, 32, 119, 97, 114, 112, 32, 97, 110, 100, 32, 115, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 45, 101, 113, 117, 97, 108, 105, 122, 101, 91, 48, 93, 32, 45,
  98, 91, 45, 49, 93, 32, 36, 49, 32, 45, 110, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 32, 45, 109, 118, 91, 45, 49, 93, 32, 49, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 105, 102, 32, 123,
  36, 62, 62, 49, 125, 10, 45, 45, 101, 113, 117, 97, 108, 105, 122, 101,
  91, 45, 49, 93, 32, 45, 98, 91, 45, 49, 93, 32, 36, 49, 32, 45,
  110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 45, 112, 104,
  97, 115, 101, 95, 99, 111, 114, 114, 101, 108, 97, 116, 105, 111, 110, 91,
  49, 44, 45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45, 42,
  91, 45, 49, 93, 32, 45, 49, 32, 45, 114, 111, 117, 110, 100, 91, 45,
  49, 93, 32, 49, 10, 45, 115, 104, 105, 102, 116, 91, 45, 50, 93, 32,
  64, 45, 49, 44, 48, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 109, 118, 91, 45, 49, 93, 32, 50, 32, 45, 101, 110, 100, 105, 102,
  32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 49, 93, 32, 45, 118,
  32, 43, 10, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 95, 112, 108,
  97, 115, 109, 97, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105,
  115, 105, 110, 116, 40, 36, 123, 49, 61, 49, 48, 125, 41, 32, 38, 38,
  32, 36, 49, 62, 61, 50, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40,
  36, 123, 50, 61, 53, 125, 41, 32, 38, 38, 32, 36, 50, 62, 61, 48,
  32, 38, 38, 32, 36, 123, 51, 61, 48, 46, 53, 37, 125, 62, 61, 48,
  34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 114, 101, 97, 116,
  101, 32, 112, 108, 97, 115, 109, 97, 32, 116, 114, 97, 110, 115, 105, 116,
  105, 111, 110, 32, 115, 101, 113, 117, 101, 110, 99, 101, 32, 98, 101, 116,
  119, 101, 101, 110, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105,
  116, 104, 32, 36, 49, 32, 102, 114, 97, 109, 101, 115, 44, 32, 115, 99,
  97, 108, 101, 32, 36, 50, 44, 32, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 36, 51, 46, 92, 110, 34, 10, 45, 118, 32, 45, 10, 45,
  105, 102, 32, 123, 64, 35, 60, 50, 125, 32, 45, 114, 101, 116, 117, 114,
  110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 115, 108, 105, 99, 101, 115,
  32, 48, 32, 45, 114, 32, 64, 123, 45, 109, 97, 120, 95, 119, 104, 100,
  115, 125, 44, 51, 10, 111, 102, 102, 61, 48, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 45, 108, 91, 123, 36, 62,
  43, 36, 111, 102, 102, 125, 44, 123, 36, 62, 43, 36, 111, 102, 102, 43,
  49, 125, 93, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92,
  114, 32, 62, 32, 71, 101, 110, 101, 114, 97, 116, 101, 32, 116, 114, 97,
  110, 115, 105, 116, 105, 111, 110, 32, 102, 114, 111, 109, 32, 105, 109, 97,
  103, 101, 32, 34, 36, 62, 34, 32, 116, 111, 32, 105, 109, 97, 103, 101,
  32, 34, 123, 36, 62, 43, 49, 125, 34, 46, 32, 32, 32, 32, 34, 32,
  45, 118, 32, 45, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45,
  112, 108, 97, 115, 109, 97, 91, 45, 49, 93, 32, 49, 44, 48, 44, 36,
  50, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 49, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 36, 49, 45, 50, 125, 32, 45, 45, 108, 101,
  91, 50, 93, 32, 123, 40, 36, 62, 43, 49, 41, 47, 36, 49, 125, 32,
  45, 98, 91, 45, 49, 93, 32, 36, 51, 32, 91, 48, 93, 32, 45, 106,
  91, 45, 49, 93, 32, 91, 49, 93, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 49, 44, 91, 45, 50, 93, 32, 45, 114, 109, 91, 45, 50, 93, 32,
  45, 114, 112, 114, 111, 103, 114, 101, 115, 115, 32, 123, 36, 62, 42, 49,
  48, 48, 47, 40, 36, 49, 45, 50, 41, 125, 32, 45, 100, 111, 110, 101,
  10, 45, 114, 109, 91, 50, 93, 32, 45, 109, 118, 91, 50, 45, 45, 49,
  93, 32, 49, 32, 111, 102, 102, 61, 123, 36, 111, 102, 102, 43, 36, 49,
  45, 50, 125, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 51,
  100, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110,
  116, 40, 36, 123, 49, 61, 49, 48, 125, 41, 32, 38, 38, 32, 36, 49,
  62, 61, 50, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 50,
  61, 51, 125, 41, 32, 38, 38, 32, 36, 50, 62, 48, 32, 38, 38, 32,
  105, 115, 105, 110, 116, 40, 36, 123, 51, 61, 36, 50, 125, 41, 32, 38,
  38, 32, 36, 51, 62, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  52, 61, 49, 125, 44, 36, 123, 53, 61, 49, 125, 44, 36, 123, 54, 61,
  48, 125, 44, 36, 123, 55, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 114, 101, 97, 116, 101, 32, 51, 100, 32, 116, 114, 97,
  110, 115, 105, 116, 105, 111, 110, 32, 115, 101, 113, 117, 101, 110, 99, 101,
  32, 98, 101, 116, 119, 101, 101, 110, 32, 105, 109, 97, 103, 101, 36, 63,
  44, 32, 119, 105, 116, 104, 32, 36, 49, 32, 102, 114, 97, 109, 101, 115,
  44, 32, 36, 50, 120, 36, 51, 32, 116, 105, 108, 101, 115, 32, 97, 110,
  100, 32, 114, 111, 116, 97, 116, 105, 111, 110, 32, 97, 120, 105, 115, 32,
  40, 36, 52, 44, 36, 53, 44, 36, 54, 41, 46, 92, 110, 34, 10, 45,
  118, 32, 45, 10, 45, 105, 102, 32, 123, 64, 35, 60, 50, 125, 32, 45,
  114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 115,
  108, 105, 99, 101, 115, 32, 48, 32, 45, 116, 111, 95, 114, 103, 98, 32,
  45, 114, 32, 64, 123, 45, 109, 97, 120, 95, 119, 104, 100, 115, 125, 44,
  51, 10, 111, 102, 102, 61, 48, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 64, 35, 45, 49, 125, 32, 45, 108, 91, 123, 36, 62, 43, 36, 111,
  102, 102, 125, 44, 123, 36, 62, 43, 36, 111, 102, 102, 43, 49, 125, 93,
  10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 114, 32, 62,
  32, 71, 101, 110, 101, 114, 97, 116, 101, 32, 116, 114, 97, 110, 115, 105,
  116, 105, 111, 110, 32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 32,
  34, 36, 62, 34, 32, 116, 111, 32, 105, 109, 97, 103, 101, 32, 34, 123,
  36, 62, 43, 49, 125, 34, 46, 32, 32, 32, 32, 34, 32, 45, 118, 32,
  45, 10, 36, 50, 44, 36, 51, 44, 49, 44, 49, 44, 39, 36, 52, 39,
  10, 36, 50, 44, 36, 51, 44, 49, 44, 49, 44, 39, 36, 53, 39, 10,
  36, 50, 44, 36, 51, 44, 49, 44, 49, 44, 39, 36, 54, 39, 10, 45,
  97, 91, 45, 51, 45, 45, 49, 93, 32, 122, 10, 45, 112, 101, 114, 109,
  117, 116, 101, 91, 45, 49, 93, 32, 122, 120, 121, 99, 32, 45, 114, 91,
  45, 49, 93, 32, 51, 44, 123, 36, 50, 42, 36, 51, 125, 44, 49, 44,
  49, 44, 45, 49, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 104, 125,
  32, 114, 111, 116, 36, 62, 61, 64, 123, 45, 49, 44, 48, 45, 50, 125,
  32, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 48, 44, 45, 49,
  44, 48, 44, 48, 32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 45, 115, 112, 108, 105, 116, 95, 116, 105, 108, 101, 115,
  91, 45, 50, 44, 45, 49, 93, 32, 36, 50, 44, 36, 51, 32, 45, 109,
  118, 91, 48, 44, 49, 93, 32, 64, 35, 10, 78, 61, 123, 36, 50, 42,
  36, 51, 125, 32, 105, 61, 48, 32, 121, 61, 48, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 36, 51, 10, 120, 61, 48, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 36, 50, 10, 108, 119, 61, 64, 123, 36, 105, 44, 119, 125,
  32, 108, 104, 61, 64, 123, 36, 105, 44, 104, 125, 10, 45, 105, 109, 97,
  103, 101, 112, 108, 97, 110, 101, 51, 100, 91, 36, 105, 93, 32, 45, 105,
  109, 97, 103, 101, 112, 108, 97, 110, 101, 51, 100, 91, 36, 78, 93, 32,
  45, 114, 51, 100, 91, 36, 78, 93, 32, 36, 123, 114, 111, 116, 36, 105,
  125, 44, 45, 49, 56, 48, 32, 45, 99, 51, 100, 91, 36, 105, 44, 36,
  78, 93, 32, 45, 43, 51, 100, 91, 36, 105, 44, 36, 78, 93, 10, 120,
  36, 105, 61, 36, 120, 32, 121, 36, 105, 61, 36, 121, 32, 120, 61, 123,
  36, 120, 43, 36, 108, 119, 125, 32, 105, 61, 123, 36, 105, 43, 49, 125,
  10, 45, 100, 111, 110, 101, 10, 121, 61, 123, 36, 121, 43, 36, 108, 104,
  125, 10, 45, 100, 111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 36, 49, 45, 50, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36,
  78, 32, 45, 114, 51, 100, 91, 36, 62, 93, 32, 36, 123, 114, 111, 116,
  36, 62, 125, 44, 123, 49, 56, 48, 47, 40, 36, 49, 45, 49, 41, 125,
  32, 45, 45, 43, 51, 100, 91, 36, 62, 93, 32, 36, 123, 120, 36, 62,
  125, 44, 36, 123, 121, 36, 62, 125, 44, 48, 32, 45, 100, 111, 110, 101,
  10, 45, 43, 51, 100, 91, 45, 36, 78, 45, 45, 49, 93, 32, 45, 99,
  51, 100, 91, 45, 49, 93, 10, 45, 105, 102, 32, 36, 55, 10, 45, 105,
  91, 45, 51, 93, 32, 123, 50, 42, 64, 123, 45, 50, 44, 119, 125, 125,
  44, 123, 50, 42, 64, 123, 45, 50, 44, 104, 125, 125, 44, 49, 44, 51,
  44, 45, 49, 10, 45, 42, 51, 100, 91, 45, 49, 93, 32, 50, 32, 45,
  111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 51, 93, 32, 91, 45, 49,
  93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 49, 44, 50, 44,
  48, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 116, 111, 95,
  114, 103, 98, 97, 91, 45, 50, 93, 32, 45, 114, 101, 112, 108, 97, 99,
  101, 95, 99, 111, 108, 111, 114, 91, 45, 50, 93, 32, 48, 44, 48, 44,
  45, 49, 44, 45, 49, 44, 45, 49, 44, 50, 53, 53, 44, 48, 44, 48,
  44, 48, 44, 48, 10, 45, 114, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  44, 91, 45, 49, 93, 44, 49, 44, 49, 48, 48, 37, 44, 50, 10, 45,
  101, 108, 115, 101, 10, 45, 105, 91, 45, 51, 93, 32, 64, 123, 45, 50,
  44, 119, 125, 44, 64, 123, 45, 50, 44, 104, 125, 44, 49, 44, 51, 44,
  45, 49, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 51, 93,
  32, 91, 45, 49, 93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44,
  49, 44, 50, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 50, 93, 32, 45, 114, 101,
  112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 45, 50, 93, 32,
  48, 44, 48, 44, 45, 49, 44, 45, 49, 44, 45, 49, 44, 50, 53, 53,
  44, 48, 44, 48, 44, 48, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 48, 45, 123, 36, 78, 45,
  49, 125, 93, 10, 45, 110, 109, 91, 49, 45, 45, 50, 93, 32, 64, 123,
  48, 44, 110, 125, 10, 111, 102, 102, 61, 123, 36, 111, 102, 102, 43, 36,
  49, 45, 50, 125, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 45, 118, 32, 43, 10, 100, 101, 109, 111, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 50,
  125, 41, 32, 38, 38, 32, 36, 49, 62, 61, 48, 32, 38, 38, 32, 36,
  49, 60, 61, 50, 34, 10, 45, 101, 91, 93, 32, 34, 92, 110, 10, 45,
  45, 45, 45, 45, 45, 32, 71, 39, 77, 73, 67, 32, 100, 101, 109, 111,
  115, 32, 109, 101, 110, 117, 32, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 92,
  110, 10, 45, 45, 45, 45, 32, 77, 111, 117, 115, 101, 32, 98, 117, 116,
  116, 111, 110, 32, 116, 111, 32, 115, 101, 108, 101, 99, 116, 32, 97, 32,
  100, 101, 109, 111, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121,
  115, 32, 39, 67, 84, 82, 76, 43, 68, 39, 32, 116, 111, 32, 100, 111,
  117, 98, 108, 101, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101,
  46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67,
  84, 82, 76, 43, 67, 39, 32, 116, 111, 32, 114, 101, 115, 101, 116, 32,
  119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45,
  45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32, 111,
  114, 32, 39, 81, 39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92, 110,
  10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 34, 10, 45, 118, 32, 45, 32, 45, 108, 91, 93, 10, 112, 97, 114,
  97, 108, 108, 101, 108, 95, 109, 111, 100, 101, 61, 123, 50, 45, 105, 102,
  40, 36, 49, 33, 61, 50, 44, 36, 49, 44, 64, 42, 62, 50, 41, 125,
  10, 51, 48, 48, 44, 52, 50, 48, 44, 49, 44, 51, 32, 45, 45, 112,
  108, 97, 115, 109, 97, 91, 45, 49, 93, 32, 49, 44, 49, 44, 53, 32,
  45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 51, 48, 32, 45, 115, 104,
  91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 47, 91, 45, 49, 93, 32,
  50, 46, 50, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 119, 97, 116,
  101, 114, 91, 45, 49, 93, 32, 49, 48, 48, 32, 45, 42, 91, 45, 49,
  93, 32, 48, 46, 49, 53, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 49, 44, 51, 10, 48, 32, 45, 116, 101, 120, 116, 91, 45, 49, 93,
  32, 34, 49, 45, 32, 66, 108, 111, 98, 115, 32, 101, 100, 105, 116, 111,
  114, 92, 110, 34, 92, 10, 34, 50, 45, 32, 66, 111, 117, 110, 99, 105,
  110, 103, 32, 98, 97, 108, 108, 115, 92, 110, 34, 92, 10, 34, 51, 45,
  32, 70, 105, 114, 101, 32, 101, 102, 102, 101, 99, 116, 92, 110, 34, 92,
  10, 34, 52, 45, 32, 70, 105, 114, 101, 119, 111, 114, 107, 115, 92, 110,
  34, 92, 10, 34, 53, 45, 32, 70, 105, 115, 104, 45, 101, 121, 101, 32,
  101, 102, 102, 101, 99, 116, 92, 110, 34, 92, 10, 34, 54, 45, 32, 70,
  111, 117, 114, 105, 101, 114, 32, 102, 105, 108, 116, 101, 114, 105, 110, 103,
  92, 110, 34, 92, 10, 34, 55, 45, 32, 72, 105, 115, 116, 111, 103, 114,
  97, 109, 32, 100, 101, 109, 111, 92, 110, 34, 92, 10, 34, 56, 45, 32,
  72, 111, 117, 103, 104, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 92,
  110, 34, 92, 10, 34, 57, 45, 32, 74, 97, 119, 98, 114, 101, 97, 107,
  101, 114, 92, 110, 34, 92, 10, 34, 49, 48, 45, 32, 84, 104, 101, 32,
  103, 97, 109, 101, 32, 111, 102, 32, 108, 105, 102, 101, 92, 110, 34, 92,
  10, 34, 49, 49, 45, 32, 76, 105, 103, 104, 116, 32, 101, 102, 102, 101,
  99, 116, 92, 110, 34, 92, 10, 34, 49, 50, 45, 32, 77, 97, 110, 100,
  101, 108, 98, 114, 111, 116, 32, 101, 120, 112, 108, 111, 114, 101, 114, 92,
  110, 34, 92, 10, 34, 49, 51, 45, 32, 51, 100, 32, 109, 101, 116, 97,
  98, 97, 108, 108, 115, 92, 110, 34, 92, 10, 34, 49, 52, 45, 32, 77,
  105, 110, 101, 115, 119, 101, 101, 112, 101, 114, 92, 110, 34, 92, 10, 34,
  49, 53, 45, 32, 77, 105, 110, 105, 109, 97, 108, 32, 112, 97, 116, 104,
  92, 110, 34, 92, 10, 34, 49, 54, 45, 32, 80, 97, 99, 109, 97, 110,
  92, 110, 34, 92, 10, 34, 49, 55, 45, 32, 80, 97, 105, 110, 116, 92,
  110, 34, 92, 10, 34, 49, 56, 45, 32, 80, 108, 97, 115, 109, 97, 32,
  101, 102, 102, 101, 99, 116, 92, 110, 34, 92, 10, 34, 49, 57, 45, 32,
  82, 71, 66, 32, 113, 117, 97, 110, 116, 105, 122, 97, 116, 105, 111, 110,
  92, 110, 34, 92, 10, 34, 50, 48, 45, 32, 51, 100, 32, 114, 101, 102,
  108, 101, 99, 116, 105, 111, 110, 92, 110, 34, 92, 10, 34, 50, 49, 45,
  32, 51, 100, 32, 114, 117, 98, 98, 101, 114, 32, 111, 98, 106, 101, 99,
  116, 92, 110, 34, 92, 10, 34, 50, 50, 45, 32, 83, 104, 97, 100, 101,
  32, 98, 111, 98, 115, 92, 110, 34, 92, 10, 34, 50, 51, 45, 32, 83,
  112, 108, 105, 110, 101, 32, 101, 100, 105, 116, 111, 114, 92, 110, 34, 92,
  10, 34, 50, 52, 45, 32, 84, 101, 116, 114, 105, 115, 92, 110, 34, 92,
  10, 34, 50, 53, 45, 32, 84, 105, 99, 45, 116, 97, 99, 45, 116, 111,
  101, 92, 110, 34, 92, 10, 34, 50, 54, 45, 32, 73, 109, 97, 103, 101,
  32, 119, 97, 118, 101, 115, 92, 110, 34, 92, 10, 34, 50, 55, 45, 32,
  70, 114, 97, 99, 116, 97, 108, 32, 119, 104, 105, 114, 108, 115, 34, 44,
  48, 44, 48, 44, 49, 51, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 50, 53, 53, 10, 99, 111, 109, 109, 97, 110, 100, 115, 61, 45, 120,
  95, 98, 108, 111, 98, 115, 44, 45, 120, 95, 98, 111, 117, 110, 99, 105,
  110, 103, 44, 45, 120, 95, 102, 105, 114, 101, 44, 45, 120, 95, 102, 105,
  114, 101, 119, 111, 114, 107, 115, 44, 45, 120, 95, 102, 105, 115, 104, 101,
  121, 101, 44, 45, 120, 95, 102, 111, 117, 114, 105, 101, 114, 44, 45, 120,
  95, 104, 105, 115, 116, 111, 103, 114, 97, 109, 44, 45, 120, 95, 104, 111,
  117, 103, 104, 44, 92, 10, 45, 120, 95, 106, 97, 119, 98, 114, 101, 97,
  107, 101, 114, 44, 45, 120, 95, 108, 105, 102, 101, 44, 45, 120, 95, 108,
  105, 103, 104, 116, 44, 45, 120, 95, 109, 97, 110, 100, 101, 108, 98, 114,
  111, 116, 44, 45, 120, 95, 109, 101, 116, 97, 98, 97, 108, 108, 115, 51,
  100, 44, 45, 120, 95, 109, 105, 110, 101, 115, 119, 101, 101, 112, 101, 114,
  44, 45, 120, 95, 109, 105, 110, 105, 109, 97, 108, 95, 112, 97, 116, 104,
  44, 92, 10, 45, 120, 95, 112, 97, 99, 109, 97, 110, 44, 45, 120, 95,
  112, 97, 105, 110, 116, 44, 45, 120, 95, 112, 108, 97, 115, 109, 97, 44,
  45, 120, 95, 113, 117, 97, 110, 116, 105, 122, 101, 95, 114, 103, 98, 44,
  45, 120, 95, 114, 101, 102, 108, 101, 99, 116, 105, 111, 110, 51, 100, 44,
  45, 120, 95, 114, 117, 98, 98, 101, 114, 51, 100, 44, 45, 120, 95, 115,
  104, 97, 100, 101, 98, 111, 98, 115, 44, 92, 10, 45, 120, 95, 115, 112,
  108, 105, 110, 101, 44, 45, 120, 95, 116, 101, 116, 114, 105, 115, 44, 45,
  120, 95, 116, 105, 99, 116, 97, 99, 116, 111, 101, 44, 45, 120, 95, 119,
  97, 118, 101, 115, 44, 45, 120, 95, 119, 104, 105, 114, 108, 10, 121, 48,
  61, 53, 57, 10, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44,
  50, 48, 44, 36, 121, 48, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49,
  93, 32, 48, 44, 49, 54, 44, 49, 48, 48, 37, 44, 52, 52, 44, 49,
  44, 49, 50, 48, 44, 49, 50, 48, 44, 51, 50, 10, 48, 32, 45, 116,
  101, 120, 116, 91, 45, 49, 93, 32, 34, 71, 39, 77, 73, 67, 32, 34,
  64, 123, 45, 115, 116, 114, 118, 101, 114, 125, 34, 32, 100, 101, 109, 111,
  115, 34, 44, 50, 44, 50, 44, 50, 52, 44, 49, 44, 49, 44, 49, 44,
  49, 32, 45, 98, 91, 45, 49, 93, 32, 48, 46, 53, 32, 45, 110, 91,
  45, 49, 93, 32, 48, 44, 49, 10, 40, 51, 50, 59, 50, 53, 53, 94,
  50, 53, 53, 59, 50, 53, 53, 94, 48, 59, 48, 41, 32, 45, 114, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 49, 44,
  51, 44, 51, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 114,
  111, 117, 110, 100, 91, 45, 49, 93, 32, 49, 44, 45, 49, 32, 45, 45,
  110, 101, 113, 91, 45, 49, 93, 32, 48, 32, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 91, 45, 49, 93, 32, 49, 10, 45, 106, 91, 45, 51, 93,
  32, 91, 45, 50, 93, 44, 50, 48, 44, 49, 56, 44, 48, 44, 48, 44,
  49, 44, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93,
  32, 49, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 53,
  10, 40, 56, 48, 59, 50, 53, 53, 59, 56, 48, 94, 48, 59, 50, 53,
  53, 59, 48, 94, 48, 59, 48, 59, 48, 41, 32, 40, 49, 48, 59, 50,
  53, 53, 59, 49, 48, 94, 48, 59, 49, 48, 48, 59, 48, 94, 48, 59,
  48, 59, 48, 41, 10, 45, 114, 91, 45, 50, 44, 45, 49, 93, 32, 91,
  45, 51, 93, 44, 49, 51, 44, 49, 44, 51, 44, 51, 32, 45, 112, 111,
  108, 121, 103, 111, 110, 91, 45, 50, 44, 45, 49, 93, 32, 51, 44, 49,
  44, 49, 44, 49, 44, 49, 49, 44, 49, 48, 44, 54, 44, 49, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 45, 109, 105, 114,
  114, 111, 114, 91, 45, 50, 44, 45, 49, 93, 32, 120, 10, 45, 109, 97,
  120, 91, 45, 52, 44, 45, 50, 93, 32, 45, 109, 97, 120, 91, 45, 50,
  44, 45, 49, 93, 10, 45, 98, 97, 108, 108, 91, 93, 32, 54, 52, 44,
  50, 48, 48, 44, 49, 48, 48, 44, 54, 52, 32, 45, 110, 91, 45, 49,
  93, 32, 48, 44, 50, 51, 48, 32, 45, 115, 91, 45, 49, 93, 32, 99,
  44, 45, 51, 32, 45, 114, 103, 98, 50, 104, 115, 118, 91, 45, 50, 93,
  32, 45, 42, 91, 45, 49, 93, 32, 48, 46, 53, 32, 45, 97, 91, 45,
  50, 44, 45, 49, 93, 32, 99, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  54, 10, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 48, 32, 45, 102,
  91, 45, 49, 93, 32, 123, 36, 62, 42, 51, 54, 48, 47, 54, 125, 32,
  45, 114, 109, 91, 45, 49, 93, 32, 45, 45, 115, 91, 45, 49, 93, 32,
  99, 44, 45, 51, 32, 45, 104, 115, 118, 50, 114, 103, 98, 91, 45, 50,
  93, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 40, 123,
  39, 67, 73, 109, 103, 51, 100, 39, 125, 41, 32, 40, 53, 44, 53, 41,
  32, 51, 44, 53, 32, 40, 49, 44, 48, 59, 49, 44, 52, 41, 32, 45,
  114, 91, 45, 49, 93, 32, 50, 44, 53, 44, 49, 44, 49, 44, 51, 32,
  45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 52, 44, 53, 32, 45,
  121, 91, 45, 53, 45, 45, 49, 93, 32, 45, 97, 91, 45, 53, 45, 45,
  49, 93, 32, 121, 10, 45, 114, 118, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 115, 112, 114, 105, 116, 101, 115, 51, 100, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 114, 118, 91, 45, 50, 44, 45, 49, 93, 10, 45, 100, 111,
  110, 101, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 43, 51, 100, 91,
  45, 54, 45, 45, 49, 93, 10, 99, 102, 120, 61, 123, 48, 125, 32, 99,
  102, 121, 61, 123, 48, 125, 32, 99, 102, 122, 61, 123, 48, 125, 32, 110,
  102, 120, 61, 123, 103, 125, 32, 110, 102, 121, 61, 123, 103, 125, 32, 110,
  102, 122, 61, 123, 103, 125, 32, 97, 108, 112, 104, 97, 61, 48, 32, 116,
  105, 109, 101, 48, 61, 123, 64, 124, 45, 52, 125, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 61, 45, 49, 32, 45, 102, 51, 100, 32, 52, 48, 48,
  10, 45, 119, 91, 48, 93, 32, 45, 49, 44, 45, 49, 44, 48, 44, 48,
  44, 53, 48, 37, 44, 53, 48, 37, 44, 34, 91, 71, 39, 77, 73, 67,
  93, 32, 68, 101, 109, 111, 115, 32, 109, 101, 110, 117, 34, 10, 45, 100,
  111, 10, 116, 61, 123, 49, 46, 53, 42, 64, 124, 125, 10, 49, 44, 51,
  48, 44, 49, 44, 49, 44, 39, 40, 49, 45, 36, 97, 108, 112, 104, 97,
  41, 42, 99, 111, 115, 40, 36, 99, 102, 120, 42, 121, 43, 36, 116, 41,
  43, 36, 97, 108, 112, 104, 97, 42, 99, 111, 115, 40, 36, 110, 102, 120,
  42, 121, 43, 36, 116, 41, 39, 10, 49, 44, 51, 48, 44, 49, 44, 49,
  44, 39, 40, 49, 45, 36, 97, 108, 112, 104, 97, 41, 42, 115, 105, 110,
  40, 36, 99, 102, 121, 42, 121, 43, 36, 116, 41, 43, 36, 97, 108, 112,
  104, 97, 42, 115, 105, 110, 40, 36, 110, 102, 121, 42, 121, 43, 36, 116,
  41, 39, 10, 49, 44, 51, 48, 44, 49, 44, 49, 44, 39, 40, 49, 45,
  36, 97, 108, 112, 104, 97, 41, 42, 115, 105, 110, 40, 36, 99, 102, 122,
  42, 121, 43, 36, 116, 41, 43, 36, 97, 108, 112, 104, 97, 42, 115, 105,
  110, 40, 36, 110, 102, 122, 42, 121, 43, 36, 116, 41, 39, 10, 45, 97,
  91, 45, 51, 45, 45, 49, 93, 32, 120, 32, 45, 115, 91, 45, 49, 93,
  32, 121, 44, 53, 32, 45, 97, 91, 45, 53, 45, 45, 49, 93, 32, 120,
  32, 45, 121, 91, 45, 49, 93, 10, 45, 106, 91, 54, 93, 32, 91, 45,
  49, 93, 44, 48, 44, 56, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  42, 51, 100, 91, 54, 93, 32, 64, 123, 48, 44, 119, 47, 50, 45, 51,
  48, 125, 44, 64, 123, 48, 44, 104, 47, 50, 45, 51, 48, 125, 44, 51,
  48, 48, 32, 45, 43, 51, 100, 91, 54, 93, 32, 48, 44, 48, 44, 50,
  48, 48, 10, 45, 42, 91, 48, 93, 32, 48, 46, 56, 53, 32, 45, 43,
  91, 48, 93, 32, 91, 49, 93, 32, 45, 111, 98, 106, 101, 99, 116, 51,
  100, 91, 48, 93, 32, 91, 54, 93, 44, 53, 48, 37, 44, 53, 48, 37,
  44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 32, 45, 106, 91, 48, 93,
  32, 91, 50, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91,
  51, 93, 44, 50, 53, 53, 10, 121, 61, 123, 64, 123, 33, 44, 121, 125,
  42, 64, 123, 48, 44, 104, 125, 47, 64, 123, 33, 44, 104, 125, 125, 10,
  45, 105, 102, 32, 123, 36, 121, 62, 61, 48, 125, 32, 121, 61, 123, 109,
  97, 120, 40, 48, 44, 109, 105, 110, 40, 50, 54, 44, 105, 110, 116, 40,
  40, 36, 121, 45, 36, 121, 48, 41, 47, 49, 51, 41, 41, 41, 125, 32,
  45, 106, 91, 48, 93, 32, 91, 123, 105, 102, 40, 36, 115, 101, 108, 101,
  99, 116, 101, 100, 62, 61, 48, 44, 53, 44, 52, 41, 125, 93, 44, 48,
  44, 123, 36, 121, 48, 43, 49, 51, 42, 36, 121, 125, 44, 48, 44, 48,
  44, 48, 46, 50, 32, 45, 101, 110, 100, 105, 102, 10, 45, 119, 91, 48,
  93, 32, 45, 119, 97, 105, 116, 32, 50, 48, 10, 45, 105, 102, 32, 123,
  64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64,
  123, 33, 44, 68, 125, 125, 32, 45, 119, 91, 48, 93, 32, 50, 48, 48,
  37, 44, 50, 48, 48, 37, 32, 45, 101, 108, 105, 102, 32, 123, 64, 123,
  33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33,
  44, 67, 125, 125, 32, 45, 119, 91, 48, 93, 32, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 40, 64, 123, 33, 44, 98, 125, 38, 49, 41, 38, 38, 36, 115, 101,
  108, 101, 99, 116, 101, 100, 60, 48, 125, 32, 115, 101, 108, 101, 99, 116,
  101, 100, 61, 36, 121, 10, 45, 101, 108, 105, 102, 32, 123, 33, 64, 123,
  33, 44, 98, 125, 125, 10, 45, 105, 102, 32, 123, 36, 115, 101, 108, 101,
  99, 116, 101, 100, 62, 61, 48, 38, 38, 36, 121, 61, 61, 36, 115, 101,
  108, 101, 99, 116, 101, 100, 125, 10, 45, 109, 32, 34, 99, 111, 109, 32,
  58, 32, 45, 118, 32, 48, 32, 34, 64, 123, 45, 97, 114, 103, 92, 32,
  123, 49, 43, 36, 121, 125, 44, 36, 99, 111, 109, 109, 97, 110, 100, 115,
  125, 32, 45, 112, 97, 114, 97, 108, 108, 101, 108, 32, 36, 112, 97, 114,
  97, 108, 108, 101, 108, 95, 109, 111, 100, 101, 44, 34, 45, 108, 91, 93,
  32, 45, 99, 111, 109, 32, 45, 118, 32, 45, 49, 32, 45, 114, 109, 32,
  45, 101, 110, 100, 108, 34, 32, 45, 117, 110, 99, 111, 109, 109, 97, 110,
  100, 32, 99, 111, 109, 10, 45, 101, 110, 100, 105, 102, 10, 115, 101, 108,
  101, 99, 116, 101, 100, 61, 45, 49, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 64, 124, 45, 36, 116, 105, 109, 101, 48, 62, 53,
  125, 32, 97, 108, 112, 104, 97, 61, 123, 36, 97, 108, 112, 104, 97, 43,
  48, 46, 48, 51, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 97, 108, 112, 104, 97, 62, 49, 125, 32, 97, 108, 112, 104,
  97, 61, 123, 36, 97, 108, 112, 104, 97, 45, 49, 125, 32, 99, 102, 120,
  61, 36, 110, 102, 120, 32, 99, 102, 121, 61, 36, 110, 102, 121, 32, 99,
  102, 122, 61, 36, 110, 102, 122, 32, 110, 102, 120, 61, 123, 103, 125, 32,
  110, 102, 121, 61, 123, 103, 125, 32, 110, 102, 122, 61, 123, 103, 125, 32,
  116, 105, 109, 101, 48, 61, 123, 64, 124, 45, 63, 42, 51, 125, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 33,
  34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67, 125, 34,
  32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125, 10, 45, 114,
  109, 32, 45, 119, 32, 48, 32, 45, 101, 110, 100, 108, 32, 45, 118, 32,
  48, 32, 45, 101, 91, 93, 32, 34, 34, 10, 120, 95, 98, 108, 111, 98,
  115, 32, 58, 10, 45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45,
  45, 45, 45, 32, 66, 108, 111, 98, 115, 32, 101, 100, 105, 116, 111, 114,
  32, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45,
  45, 45, 92, 110, 10, 45, 45, 45, 45, 32, 77, 111, 117, 115, 101, 32,
  116, 111, 32, 105, 110, 115, 101, 114, 116, 47, 109, 111, 118, 101, 47, 100,
  101, 108, 101, 116, 101, 32, 98, 108, 111, 98, 115, 46, 92, 110, 10, 45,
  45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76, 43, 68,
  39, 32, 116, 111, 32, 100, 111, 117, 98, 108, 101, 32, 119, 105, 110, 100,
  111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32,
  75, 101, 121, 115, 32, 39, 67, 84, 82, 76, 43, 67, 39, 32, 116, 111,
  32, 114, 101, 115, 101, 116, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105,
  122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32,
  39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81, 39, 32, 116, 111, 32,
  101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 10, 45, 114, 109, 32, 40,
  48, 59, 48, 94, 48, 59, 49, 50, 56, 94, 48, 59, 50, 53, 53, 41,
  32, 45, 114, 91, 45, 49, 93, 32, 51, 53, 48, 44, 51, 53, 48, 44,
  49, 44, 51, 44, 51, 32, 45, 102, 108, 111, 119, 101, 114, 91, 45, 49,
  93, 32, 51, 48, 44, 56, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48,
  46, 53, 44, 49, 32, 45, 119, 97, 116, 101, 114, 91, 45, 49, 93, 32,
  50, 48, 10, 45, 119, 32, 123, 119, 125, 44, 123, 104, 125, 44, 48, 44,
  48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 66, 108, 111, 98, 115,
  32, 101, 100, 105, 116, 111, 114, 34, 10, 109, 111, 118, 105, 110, 103, 61,
  45, 49, 10, 45, 100, 111, 10, 120, 61, 123, 64, 123, 33, 44, 120, 125,
  42, 64, 123, 48, 44, 119, 125, 47, 64, 123, 33, 44, 119, 125, 125, 10,
  121, 61, 123, 64, 123, 33, 44, 121, 125, 42, 64, 123, 48, 44, 104, 125,
  47, 64, 123, 33, 44, 104, 125, 125, 10, 98, 61, 64, 123, 33, 44, 98,
  125, 32, 110, 101, 97, 114, 101, 115, 116, 61, 45, 49, 10, 45, 105, 102,
  32, 123, 64, 35, 62, 49, 125, 10, 64, 123, 48, 44, 119, 125, 44, 64,
  123, 48, 44, 104, 125, 44, 49, 44, 50, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 123, 49, 44, 104, 125, 10, 114, 61, 123, 64, 123, 49, 44,
  50, 125, 42, 40, 49, 43, 64, 123, 49, 44, 51, 125, 42, 99, 111, 115,
  40, 64, 123, 49, 44, 52, 125, 43, 64, 123, 49, 44, 53, 125, 42, 64,
  124, 42, 49, 48, 48, 48, 41, 41, 125, 10, 45, 101, 108, 108, 105, 112,
  115, 101, 91, 45, 49, 93, 32, 64, 123, 49, 44, 48, 44, 49, 125, 44,
  36, 114, 44, 36, 114, 44, 48, 44, 49, 44, 64, 123, 49, 44, 54, 45,
  55, 125, 10, 100, 61, 123, 115, 113, 114, 116, 40, 40, 36, 120, 45, 64,
  123, 49, 44, 48, 125, 41, 94, 50, 43, 40, 36, 121, 45, 64, 123, 49,
  44, 49, 125, 41, 94, 50, 41, 125, 10, 45, 105, 102, 32, 123, 36, 100,
  60, 36, 114, 125, 32, 110, 101, 97, 114, 101, 115, 116, 61, 36, 62, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 115, 104, 105, 102, 116, 91, 49, 93,
  32, 48, 44, 45, 49, 44, 48, 44, 48, 44, 50, 32, 45, 100, 111, 110,
  101, 10, 45, 98, 91, 45, 49, 93, 32, 49, 53, 10, 45, 45, 110, 111,
  114, 109, 91, 45, 49, 93, 32, 45, 45, 103, 101, 91, 45, 49, 93, 32,
  53, 48, 32, 45, 108, 101, 91, 45, 50, 93, 32, 52, 48, 32, 45, 42,
  91, 45, 51, 44, 45, 49, 93, 10, 45, 45, 42, 91, 48, 44, 45, 49,
  93, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45, 114, 118, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 49, 46, 54, 32,
  45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 43, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 119, 91, 45, 49, 93, 10, 45, 105,
  102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125,
  38, 38, 64, 123, 33, 44, 68, 125, 125, 32, 45, 119, 91, 93, 32, 123,
  50, 42, 119, 125, 44, 123, 50, 42, 104, 125, 32, 45, 101, 108, 105, 102,
  32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38,
  38, 64, 123, 33, 44, 67, 125, 125, 32, 45, 119, 91, 93, 32, 123, 119,
  125, 44, 123, 104, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 101, 108, 115, 101, 10, 45, 45, 116, 101, 120,
  116, 95, 111, 117, 116, 108, 105, 110, 101, 91, 48, 93, 32, 34, 71, 39,
  77, 73, 67, 32, 66, 108, 111, 98, 115, 32, 69, 100, 105, 116, 111, 114,
  34, 44, 54, 53, 44, 52, 48, 44, 50, 52, 44, 51, 44, 49, 44, 50,
  48, 48, 44, 49, 50, 56, 44, 50, 53, 53, 10, 45, 116, 91, 45, 49,
  93, 32, 34, 42, 32, 76, 101, 102, 116, 32, 109, 111, 117, 115, 101, 32,
  98, 117, 116, 116, 111, 110, 32, 58, 32, 67, 114, 101, 97, 116, 101, 32,
  97, 110, 100, 32, 109, 111, 118, 101, 32, 98, 108, 111, 98, 115, 46, 92,
  110, 92, 110, 92, 10, 42, 32, 82, 105, 103, 104, 116, 32, 109, 111, 117,
  115, 101, 32, 98, 117, 116, 116, 111, 110, 32, 58, 32, 82, 101, 109, 111,
  118, 101, 32, 98, 108, 111, 98, 46, 92, 110, 92, 110, 92, 10, 42, 32,
  77, 105, 100, 100, 108, 101, 32, 109, 111, 117, 115, 101, 32, 98, 117, 116,
  116, 111, 110, 32, 58, 32, 82, 101, 109, 111, 118, 101, 32, 97, 108, 108,
  32, 98, 108, 111, 98, 115, 46, 92, 110, 92, 110, 92, 10, 42, 32, 75,
  101, 121, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81, 39, 32,
  58, 32, 81, 117, 105, 116, 46, 92, 110, 92, 110, 92, 10, 42, 32, 67,
  111, 108, 111, 114, 115, 32, 97, 110, 100, 32, 115, 105, 122, 101, 115, 32,
  111, 102, 32, 97, 112, 112, 101, 97, 114, 105, 110, 103, 32, 98, 108, 111,
  98, 115, 32, 97, 114, 101, 92, 110, 32, 32, 32, 99, 104, 111, 115, 101,
  110, 32, 114, 97, 110, 100, 111, 109, 108, 121, 34, 44, 92, 10, 54, 48,
  44, 49, 50, 48, 44, 49, 51, 44, 49, 44, 50, 53, 53, 10, 45, 119,
  91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84,
  82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 68, 125, 125,
  32, 45, 119, 91, 93, 32, 123, 50, 42, 119, 125, 44, 123, 50, 42, 104,
  125, 32, 45, 101, 108, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82,
  76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 67, 125, 125, 32,
  45, 119, 91, 93, 32, 123, 119, 125, 44, 123, 104, 125, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 119, 97, 105, 116, 32, 50, 48, 10, 45, 105, 102, 32,
  123, 36, 120, 60, 48, 124, 124, 36, 121, 60, 48, 125, 32, 45, 99, 111,
  110, 116, 105, 110, 117, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 98, 38, 49, 125, 10, 45, 105, 102, 32, 123, 36, 110,
  101, 97, 114, 101, 115, 116, 62, 61, 48, 34, 32, 124, 124, 32, 34, 36,
  109, 111, 118, 105, 110, 103, 62, 61, 48, 125, 10, 45, 105, 102, 32, 123,
  36, 109, 111, 118, 105, 110, 103, 60, 48, 125, 32, 109, 111, 118, 105, 110,
  103, 61, 36, 110, 101, 97, 114, 101, 115, 116, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 61, 91, 49, 93, 32, 36, 120, 44, 48, 44, 36, 109, 111,
  118, 105, 110, 103, 32, 45, 61, 91, 49, 93, 32, 36, 121, 44, 49, 44,
  36, 109, 111, 118, 105, 110, 103, 10, 45, 101, 108, 115, 101, 10, 40, 36,
  120, 44, 36, 121, 44, 123, 63, 40, 50, 48, 44, 53, 48, 41, 125, 44,
  123, 63, 40, 45, 48, 46, 51, 44, 48, 46, 51, 41, 125, 44, 123, 63,
  40, 48, 44, 112, 105, 47, 50, 41, 125, 44, 123, 63, 40, 48, 44, 48,
  46, 48, 48, 57, 41, 125, 44, 123, 63, 40, 54, 52, 44, 50, 53, 53,
  41, 125, 44, 123, 63, 40, 54, 52, 44, 50, 53, 53, 41, 125, 41, 32,
  45, 97, 91, 94, 48, 93, 32, 121, 10, 109, 111, 118, 105, 110, 103, 61,
  123, 104, 45, 49, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 98, 38, 50, 125, 10, 45, 105, 102, 32, 123, 36,
  110, 101, 97, 114, 101, 115, 116, 62, 61, 48, 125, 32, 45, 108, 91, 49,
  93, 32, 45, 115, 32, 121, 32, 45, 114, 109, 91, 36, 110, 101, 97, 114,
  101, 115, 116, 93, 32, 45, 97, 32, 121, 32, 45, 101, 110, 100, 108, 32,
  110, 101, 97, 114, 101, 115, 116, 61, 45, 49, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 108, 105, 102, 32, 123, 36, 98, 38, 52, 125, 10, 45,
  107, 91, 48, 93, 10, 45, 101, 108, 115, 101, 10, 109, 111, 118, 105, 110,
  103, 61, 45, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 119, 104, 105,
  108, 101, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33,
  44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44,
  81, 125, 125, 10, 45, 114, 109, 32, 45, 119, 32, 48, 32, 45, 118, 32,
  43, 10, 120, 95, 98, 111, 117, 110, 99, 105, 110, 103, 32, 58, 10, 45,
  101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 66,
  111, 117, 110, 99, 105, 110, 103, 32, 98, 97, 108, 108, 115, 32, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45,
  45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32,
  39, 67, 84, 82, 76, 43, 68, 39, 32, 116, 111, 32, 100, 111, 117, 98,
  108, 101, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92,
  110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82,
  76, 43, 67, 39, 32, 116, 111, 32, 114, 101, 115, 101, 116, 32, 119, 105,
  110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45,
  45, 32, 75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32,
  39, 81, 39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45,
  45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32,
  45, 32, 45, 108, 91, 93, 10, 53, 48, 48, 44, 51, 50, 48, 44, 49,
  44, 51, 32, 45, 112, 108, 97, 115, 109, 97, 32, 49, 44, 49, 44, 57,
  32, 45, 110, 32, 48, 44, 50, 50, 48, 10, 78, 61, 49, 50, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 36, 78, 10, 45, 98, 97, 108, 108, 91,
  93, 32, 123, 114, 111, 117, 110, 100, 40, 63, 40, 51, 50, 44, 56, 48,
  41, 41, 125, 44, 64, 123, 45, 82, 71, 66, 125, 10, 116, 36, 62, 61,
  123, 63, 40, 50, 48, 48, 41, 125, 32, 120, 36, 62, 61, 64, 123, 48,
  44, 63, 40, 49, 48, 44, 119, 45, 49, 48, 41, 125, 32, 104, 36, 62,
  61, 123, 63, 40, 49, 53, 48, 44, 51, 48, 48, 41, 125, 32, 118, 120,
  36, 62, 61, 123, 105, 102, 40, 63, 60, 48, 46, 53, 44, 49, 44, 45,
  49, 41, 42, 63, 40, 49, 44, 56, 41, 125, 10, 45, 100, 111, 110, 101,
  10, 45, 109, 118, 91, 48, 93, 32, 64, 35, 32, 45, 119, 91, 45, 49,
  93, 32, 45, 49, 44, 45, 49, 44, 48, 44, 34, 91, 71, 39, 77, 73,
  67, 93, 32, 66, 111, 117, 110, 99, 105, 110, 103, 32, 98, 97, 108, 108,
  115, 34, 10, 40, 48, 59, 48, 46, 55, 59, 49, 41, 32, 45, 114, 91,
  45, 49, 93, 32, 64, 123, 45, 50, 44, 119, 125, 44, 55, 48, 44, 49,
  44, 49, 44, 51, 10, 45, 100, 111, 10, 91, 36, 78, 93, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 78, 10, 98, 119, 61, 64, 123, 36, 62,
  44, 119, 125, 32, 98, 104, 61, 64, 123, 36, 62, 44, 104, 125, 10, 121,
  61, 123, 36, 123, 104, 36, 62, 125, 42, 97, 98, 115, 40, 99, 111, 115,
  40, 36, 123, 116, 36, 62, 125, 42, 112, 105, 47, 54, 48, 41, 41, 45,
  36, 98, 104, 47, 50, 125, 10, 100, 116, 61, 49, 10, 45, 105, 102, 32,
  123, 36, 121, 60, 48, 125, 32, 100, 61, 123, 45, 36, 121, 125, 32, 121,
  61, 48, 32, 98, 104, 61, 123, 36, 98, 104, 45, 36, 100, 125, 32, 98,
  119, 61, 123, 36, 98, 119, 43, 36, 100, 125, 32, 100, 116, 61, 123, 109,
  97, 120, 40, 48, 46, 50, 44, 49, 45, 40, 36, 100, 47, 36, 98, 104,
  41, 94, 50, 41, 125, 32, 45, 101, 108, 115, 101, 32, 100, 116, 61, 49,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 123, 120,
  36, 62, 125, 43, 36, 98, 119, 47, 50, 62, 119, 125, 10, 100, 61, 123,
  36, 123, 120, 36, 62, 125, 43, 36, 98, 119, 47, 50, 45, 119, 125, 32,
  98, 119, 61, 123, 36, 98, 119, 45, 36, 100, 125, 32, 98, 104, 61, 123,
  36, 98, 104, 43, 48, 46, 53, 42, 36, 100, 125, 10, 45, 105, 102, 32,
  123, 36, 123, 120, 36, 62, 125, 43, 36, 98, 119, 47, 52, 62, 119, 125,
  32, 118, 120, 36, 62, 61, 123, 45, 36, 123, 118, 120, 36, 62, 125, 125,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 123, 120, 36, 62, 125, 45, 36, 98, 119, 47, 50,
  60, 48, 125, 10, 100, 61, 123, 36, 98, 119, 47, 50, 45, 36, 123, 120,
  36, 62, 125, 125, 32, 98, 119, 61, 123, 36, 98, 119, 45, 36, 100, 125,
  32, 98, 104, 61, 123, 36, 98, 104, 43, 48, 46, 53, 42, 36, 100, 125,
  10, 45, 105, 102, 32, 123, 36, 123, 120, 36, 62, 125, 45, 36, 98, 119,
  47, 52, 60, 48, 125, 32, 118, 120, 36, 62, 61, 123, 45, 36, 123, 118,
  120, 36, 62, 125, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 45, 114, 91, 36, 62, 93, 32, 36, 98, 119, 44,
  36, 98, 104, 44, 49, 44, 52, 44, 51, 32, 45, 115, 91, 45, 49, 93,
  32, 99, 44, 45, 51, 10, 45, 106, 91, 45, 51, 93, 32, 91, 45, 50,
  93, 44, 123, 109, 97, 120, 40, 48, 44, 109, 105, 110, 40, 64, 123, 36,
  78, 44, 119, 45, 36, 98, 119, 125, 44, 36, 123, 120, 36, 62, 125, 45,
  36, 98, 119, 47, 50, 41, 41, 125, 44, 123, 64, 123, 36, 78, 44, 104,
  125, 45, 64, 123, 45, 49, 44, 104, 125, 45, 36, 121, 45, 55, 48, 125,
  44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 44, 50, 53, 53, 32,
  45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 116, 36, 62, 61, 123,
  36, 123, 116, 36, 62, 125, 43, 36, 100, 116, 125, 10, 120, 36, 62, 61,
  123, 36, 123, 120, 36, 62, 125, 43, 36, 100, 116, 42, 36, 123, 118, 120,
  36, 62, 125, 125, 10, 45, 100, 111, 110, 101, 10, 45, 45, 114, 111, 119,
  115, 91, 45, 49, 93, 32, 123, 104, 45, 50, 42, 55, 48, 125, 44, 123,
  104, 45, 49, 45, 55, 48, 125, 32, 45, 109, 105, 114, 114, 111, 114, 91,
  45, 49, 93, 32, 121, 32, 45, 42, 91, 45, 49, 93, 32, 91, 123, 36,
  78, 43, 49, 125, 93, 10, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 48, 44, 64, 123, 45, 50, 44, 104, 45, 55, 49, 125, 44, 48,
  44, 48, 44, 48, 46, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  119, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 67,
  84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 68, 125,
  125, 32, 45, 119, 91, 93, 32, 123, 50, 42, 119, 125, 44, 123, 50, 42,
  104, 125, 32, 45, 101, 108, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84,
  82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 67, 125, 125,
  32, 45, 119, 91, 93, 32, 123, 119, 125, 44, 123, 104, 125, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 119, 97,
  105, 116, 32, 50, 48, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 33,
  34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67, 125, 34,
  32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125, 10, 45, 119,
  32, 48, 32, 45, 114, 109, 32, 45, 101, 110, 100, 108, 32, 45, 118, 32,
  43, 10, 120, 95, 102, 105, 114, 101, 32, 58, 32, 45, 115, 107, 105, 112,
  32, 34, 36, 123, 49, 61, 71, 39, 77, 73, 67, 125, 34, 10, 45, 101,
  91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 70, 105,
  114, 101, 32, 101, 102, 102, 101, 99, 116, 32, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32, 75,
  101, 121, 115, 32, 39, 67, 84, 82, 76, 43, 68, 39, 32, 116, 111, 32,
  100, 111, 117, 98, 108, 101, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105,
  122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32,
  39, 67, 84, 82, 76, 43, 67, 39, 32, 116, 111, 32, 114, 101, 115, 101,
  116, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110,
  10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 69, 83, 67, 39,
  32, 111, 114, 32, 39, 81, 39, 32, 116, 111, 32, 101, 120, 105, 116, 46,
  92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 34, 10, 45, 118, 32, 45, 10, 45, 105, 91, 48, 93, 32,
  49, 48, 48, 44, 51, 50, 32, 45, 119, 91, 48, 93, 32, 52, 53, 48,
  44, 50, 48, 48, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32,
  70, 105, 114, 101, 32, 101, 102, 102, 101, 99, 116, 34, 10, 45, 105, 91,
  49, 93, 32, 40, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 94, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 94, 48, 44, 48, 44, 48, 44, 49, 50, 56, 44,
  50, 53, 53, 41, 32, 45, 114, 91, 49, 93, 32, 50, 53, 54, 44, 49,
  44, 49, 44, 51, 44, 51, 10, 45, 105, 91, 50, 93, 32, 40, 48, 44,
  48, 44, 48, 59, 48, 44, 48, 44, 48, 59, 49, 44, 49, 44, 49, 59,
  48, 44, 49, 44, 48, 41, 32, 45, 42, 91, 50, 93, 32, 48, 46, 50,
  49, 10, 45, 116, 101, 120, 116, 51, 100, 32, 34, 36, 49, 34, 44, 51,
  52, 44, 51, 44, 49, 32, 45, 109, 118, 91, 45, 49, 93, 32, 51, 32,
  45, 99, 51, 100, 91, 51, 93, 32, 45, 110, 51, 100, 91, 51, 93, 32,
  45, 42, 51, 100, 91, 51, 93, 32, 51, 50, 48, 32, 45, 99, 111, 108,
  51, 100, 91, 51, 93, 32, 50, 53, 53, 44, 50, 48, 53, 44, 49, 51,
  48, 32, 45, 100, 98, 51, 100, 32, 48, 32, 45, 102, 51, 100, 32, 51,
  48, 48, 10, 49, 48, 48, 44, 49, 48, 48, 32, 45, 114, 97, 110, 100,
  91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 108, 105,
  112, 115, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44,
  53, 44, 53, 44, 48, 44, 49, 44, 51, 48, 48, 32, 45, 98, 91, 45,
  49, 93, 32, 49, 48, 10, 45, 115, 104, 97, 114, 112, 101, 110, 91, 45,
  49, 93, 32, 49, 48, 48, 48, 32, 45, 115, 104, 114, 105, 110, 107, 95,
  120, 121, 91, 45, 49, 93, 32, 49, 32, 45, 110, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 32, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49,
  93, 32, 45, 108, 105, 103, 104, 116, 51, 100, 32, 91, 45, 49, 93, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 97, 110, 103, 108, 101, 61, 48, 10,
  45, 100, 111, 10, 45, 99, 111, 114, 114, 101, 108, 97, 116, 101, 91, 48,
  93, 32, 91, 50, 93, 10, 64, 123, 48, 44, 119, 125, 44, 49, 32, 45,
  114, 97, 110, 100, 91, 45, 49, 93, 32, 49, 50, 56, 44, 50, 53, 54,
  32, 45, 106, 91, 48, 93, 32, 91, 45, 49, 93, 44, 48, 44, 123, 64,
  123, 48, 44, 104, 125, 45, 49, 125, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 45, 114, 91, 48, 93, 32, 52, 48, 48, 44, 50, 48, 48, 44,
  49, 44, 49, 44, 51, 32, 45, 109, 97, 112, 91, 45, 49, 93, 32, 91,
  49, 93, 10, 45, 45, 114, 51, 100, 91, 51, 93, 32, 48, 44, 49, 44,
  48, 44, 36, 97, 110, 103, 108, 101, 32, 45, 111, 98, 106, 101, 99, 116,
  51, 100, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 53, 48, 37, 44,
  53, 48, 37, 44, 48, 44, 49, 44, 53, 44, 48, 44, 48, 10, 45, 42,
  51, 100, 91, 45, 49, 93, 32, 48, 46, 50, 53, 44, 48, 46, 49, 54,
  44, 49, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 48, 93, 32,
  91, 45, 49, 93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 49,
  44, 51, 44, 48, 44, 48, 10, 45, 114, 109, 91, 45, 49, 93, 10, 97,
  110, 103, 108, 101, 61, 123, 36, 97, 110, 103, 108, 101, 43, 51, 125, 10,
  45, 119, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44,
  67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 68,
  125, 125, 32, 45, 119, 91, 93, 32, 123, 50, 42, 119, 125, 44, 123, 50,
  42, 104, 125, 32, 45, 101, 108, 105, 102, 32, 123, 64, 123, 33, 44, 67,
  84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 67, 125,
  125, 32, 45, 119, 91, 93, 32, 123, 119, 125, 44, 123, 104, 125, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 119,
  97, 105, 116, 32, 52, 48, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64,
  33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67, 125,
  34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125, 10, 45,
  114, 109, 91, 48, 45, 51, 93, 32, 45, 119, 32, 48, 10, 45, 118, 32,
  43, 10, 120, 95, 102, 105, 114, 101, 119, 111, 114, 107, 115, 32, 58, 10,
  45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32,
  70, 105, 114, 101, 119, 111, 114, 107, 115, 32, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32,
  75, 101, 121, 115, 32, 39, 67, 84, 82, 76, 43, 68, 39, 32, 116, 111,
  32, 100, 111, 117, 98, 108, 101, 32, 119, 105, 110, 100, 111, 119, 32, 115,
  105, 122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115,
  32, 39, 67, 84, 82, 76, 43, 67, 39, 32, 116, 111, 32, 114, 101, 115,
  101, 116, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92,
  110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 69, 83, 67,
  39, 32, 111, 114, 32, 39, 81, 39, 32, 116, 111, 32, 101, 120, 105, 116,
  46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 32, 45, 108, 91, 93, 10,
  116, 105, 109, 101, 61, 48, 10, 40, 48, 59, 54, 52, 94, 48, 59, 51,
  50, 94, 49, 50, 56, 59, 48, 41, 32, 45, 114, 32, 50, 53, 54, 44,
  49, 50, 56, 44, 49, 44, 51, 44, 51, 10, 91, 45, 49, 93, 10, 45,
  119, 91, 45, 49, 93, 32, 123, 49, 46, 53, 42, 119, 125, 44, 123, 49,
  46, 53, 42, 104, 125, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93,
  32, 70, 105, 114, 101, 119, 111, 114, 107, 115, 34, 10, 45, 100, 111, 10,
  116, 105, 109, 101, 61, 123, 36, 116, 105, 109, 101, 45, 49, 125, 10, 45,
  105, 102, 32, 123, 64, 35, 61, 61, 50, 92, 32, 124, 124, 92, 32, 36,
  116, 105, 109, 101, 60, 48, 125, 10, 45, 105, 91, 48, 93, 32, 40, 123,
  63, 40, 119, 41, 125, 44, 92, 10, 123, 104, 125, 44, 92, 10, 123, 63,
  40, 45, 51, 44, 51, 41, 125, 44, 92, 10, 123, 63, 40, 50, 41, 45,
  53, 125, 44, 92, 10, 123, 51, 48, 43, 63, 40, 50, 48, 41, 125, 44,
  92, 10, 49, 46, 53, 44, 92, 10, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 41, 10, 116, 105, 109, 101, 61, 123, 63, 40, 52, 48, 41,
  125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 42, 91, 45, 49, 93, 32,
  48, 46, 57, 57, 10, 45, 106, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 46, 50, 10, 105, 61, 48,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 50, 125, 10,
  116, 111, 95, 98, 101, 95, 114, 101, 109, 111, 118, 101, 100, 61, 48, 10,
  114, 97, 100, 105, 117, 115, 61, 123, 105, 102, 40, 64, 123, 36, 105, 44,
  52, 125, 62, 48, 44, 64, 123, 36, 105, 44, 53, 125, 47, 51, 44, 64,
  123, 36, 105, 44, 53, 125, 42, 40, 49, 43, 50, 42, 40, 64, 123, 36,
  105, 44, 52, 125, 43, 50, 41, 47, 49, 50, 48, 41, 41, 125, 10, 45,
  101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 64, 123, 36, 105,
  44, 48, 125, 44, 64, 123, 36, 105, 44, 49, 125, 44, 64, 123, 36, 105,
  44, 53, 125, 44, 123, 109, 97, 120, 40, 48, 46, 53, 44, 36, 114, 97,
  100, 105, 117, 115, 41, 125, 44, 123, 97, 116, 97, 110, 50, 40, 64, 123,
  36, 105, 44, 51, 125, 44, 64, 123, 36, 105, 44, 50, 125, 41, 42, 49,
  56, 48, 47, 112, 105, 125, 44, 48, 46, 54, 44, 64, 123, 36, 105, 44,
  54, 45, 56, 125, 10, 40, 64, 123, 36, 105, 44, 50, 125, 44, 64, 123,
  36, 105, 44, 51, 125, 44, 48, 44, 48, 46, 48, 57, 44, 45, 49, 44,
  48, 44, 48, 44, 48, 44, 48, 41, 32, 45, 43, 91, 36, 105, 44, 45,
  49, 93, 10, 45, 105, 102, 32, 123, 64, 123, 36, 105, 44, 48, 125, 60,
  48, 92, 32, 124, 124, 92, 32, 64, 123, 36, 105, 44, 48, 125, 62, 61,
  119, 92, 32, 124, 124, 92, 32, 64, 123, 36, 105, 44, 49, 125, 62, 61,
  104, 92, 32, 124, 124, 92, 32, 36, 114, 97, 100, 105, 117, 115, 60, 48,
  125, 32, 116, 111, 95, 98, 101, 95, 114, 101, 109, 111, 118, 101, 100, 61,
  49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64, 123,
  36, 105, 44, 52, 125, 60, 48, 92, 32, 38, 38, 92, 32, 64, 123, 36,
  105, 44, 52, 125, 62, 61, 45, 49, 125, 10, 99, 111, 108, 111, 114, 61,
  123, 109, 105, 110, 40, 50, 53, 53, 44, 56, 48, 43, 63, 40, 50, 48,
  48, 41, 41, 125, 44, 123, 109, 105, 110, 40, 50, 53, 53, 44, 56, 48,
  43, 63, 40, 50, 48, 48, 41, 41, 125, 44, 123, 109, 105, 110, 40, 50,
  53, 53, 44, 56, 48, 43, 63, 40, 50, 48, 48, 41, 41, 125, 10, 114,
  97, 100, 105, 117, 115, 61, 123, 63, 40, 49, 48, 41, 125, 10, 78, 61,
  123, 53, 43, 63, 40, 49, 48, 41, 125, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 36, 78, 10, 97, 110, 103, 108, 101, 61, 123, 36, 62, 42, 50,
  42, 112, 105, 47, 36, 78, 125, 10, 45, 105, 91, 45, 51, 93, 32, 40,
  64, 123, 36, 105, 44, 48, 44, 49, 125, 44, 123, 50, 42, 99, 111, 115,
  40, 36, 97, 110, 103, 108, 101, 41, 43, 64, 123, 36, 105, 44, 50, 125,
  47, 49, 46, 53, 125, 44, 123, 50, 42, 115, 105, 110, 40, 36, 97, 110,
  103, 108, 101, 41, 43, 64, 123, 36, 105, 44, 51, 125, 47, 49, 46, 53,
  125, 44, 45, 50, 44, 36, 114, 97, 100, 105, 117, 115, 44, 36, 99, 111,
  108, 111, 114, 41, 10, 45, 100, 111, 110, 101, 10, 116, 111, 95, 98, 101,
  95, 114, 101, 109, 111, 118, 101, 100, 61, 49, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 36, 116, 111, 95, 98, 101, 95, 114, 101, 109,
  111, 118, 101, 100, 32, 45, 114, 109, 91, 36, 105, 93, 32, 45, 101, 108,
  115, 101, 32, 105, 61, 123, 36, 105, 43, 49, 125, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 119, 91, 45, 49, 93, 32,
  45, 119, 97, 105, 116, 32, 50, 48, 10, 45, 105, 102, 32, 123, 64, 123,
  33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33,
  44, 68, 125, 125, 32, 45, 119, 91, 93, 32, 123, 51, 42, 119, 125, 44,
  123, 51, 42, 104, 125, 32, 45, 101, 108, 105, 102, 32, 123, 64, 123, 33,
  44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44,
  67, 125, 125, 32, 45, 119, 91, 93, 32, 123, 49, 46, 53, 42, 119, 125,
  44, 123, 49, 46, 53, 42, 104, 125, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34,
  33, 64, 123, 33, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33,
  64, 123, 33, 44, 81, 125, 125, 10, 45, 101, 110, 100, 108, 32, 45, 107,
  91, 45, 49, 93, 32, 45, 119, 91, 93, 32, 48, 32, 45, 118, 32, 43,
  10, 120, 95, 102, 105, 115, 104, 101, 121, 101, 32, 58, 10, 45, 101, 91,
  93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 70, 105, 115,
  104, 45, 101, 121, 101, 32, 101, 102, 102, 101, 99, 116, 32, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92,
  110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32, 77, 111,
  117, 115, 101, 32, 112, 111, 105, 110, 116, 101, 114, 32, 109, 111, 118, 101,
  115, 32, 102, 105, 115, 104, 45, 101, 121, 101, 32, 99, 101, 110, 116, 101,
  114, 46, 92, 110, 10, 45, 45, 45, 45, 32, 77, 111, 117, 115, 101, 32,
  98, 117, 116, 116, 111, 110, 115, 32, 115, 101, 116, 32, 102, 105, 115, 104,
  45, 101, 121, 101, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45,
  45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76, 43, 68, 39, 32,
  116, 111, 32, 100, 111, 117, 98, 108, 101, 32, 119, 105, 110, 100, 111, 119,
  32, 115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101,
  121, 115, 32, 39, 67, 84, 82, 76, 43, 67, 39, 32, 116, 111, 32, 114,
  101, 115, 101, 116, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101,
  46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 69,
  83, 67, 39, 32, 111, 114, 32, 39, 81, 39, 32, 116, 111, 32, 101, 120,
  105, 116, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 10, 45, 105, 102,
  32, 123, 64, 35, 62, 48, 125, 32, 45, 97, 32, 120, 32, 45, 110, 32,
  48, 44, 50, 53, 53, 32, 45, 114, 50, 100, 121, 32, 50, 50, 48, 32,
  45, 101, 108, 115, 101, 10, 49, 50, 48, 44, 57, 48, 44, 49, 44, 51,
  32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  32, 45, 112, 108, 97, 115, 109, 97, 91, 45, 49, 93, 32, 48, 46, 51,
  44, 51, 32, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 116, 32, 34,
  32, 32, 71, 39, 77, 73, 67, 92, 110, 70, 73, 83, 72, 45, 69, 89,
  69, 92, 110, 32, 69, 70, 70, 69, 67, 84, 34, 44, 49, 53, 44, 49,
  51, 44, 50, 52, 44, 49, 44, 50, 53, 53, 32, 45, 115, 99, 97, 108,
  101, 50, 120, 32, 45, 98, 32, 53, 32, 45, 115, 104, 97, 114, 112, 101,
  110, 32, 49, 48, 48, 48, 10, 45, 102, 32, 105, 43, 49, 53, 48, 45,
  52, 42, 97, 98, 115, 40, 121, 45, 104, 47, 50, 41, 32, 45, 99, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 102, 114, 97, 109, 101,
  95, 102, 117, 122, 122, 121, 91, 45, 49, 93, 32, 49, 53, 44, 49, 48,
  44, 49, 53, 44, 49, 46, 53, 44, 48, 32, 45, 116, 111, 95, 114, 103,
  98, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111,
  114, 117, 115, 51, 100, 32, 50, 48, 44, 54, 32, 45, 99, 111, 108, 51,
  100, 91, 45, 49, 93, 32, 123, 63, 40, 51, 48, 44, 50, 53, 53, 41,
  125, 44, 123, 63, 40, 51, 48, 44, 50, 53, 53, 41, 125, 44, 123, 63,
  40, 51, 48, 44, 50, 53, 53, 41, 125, 32, 45, 45, 114, 51, 100, 91,
  45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 57, 48, 10, 45, 99, 111,
  108, 51, 100, 91, 45, 49, 93, 32, 123, 63, 40, 51, 48, 44, 50, 53,
  53, 41, 125, 44, 123, 63, 40, 51, 48, 44, 50, 53, 53, 41, 125, 44,
  123, 63, 40, 51, 48, 44, 50, 53, 53, 41, 125, 32, 45, 43, 51, 100,
  91, 45, 49, 93, 32, 49, 53, 32, 45, 43, 51, 100, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 100, 98, 51, 100, 32, 48, 32, 45, 99, 51, 100,
  91, 45, 49, 93, 10, 82, 61, 51, 48, 10, 45, 119, 91, 45, 50, 93,
  32, 123, 49, 46, 53, 42, 64, 123, 45, 50, 44, 119, 125, 125, 44, 123,
  49, 46, 53, 42, 64, 123, 45, 50, 44, 104, 125, 125, 44, 48, 44, 34,
  91, 71, 39, 77, 73, 67, 93, 32, 70, 105, 115, 104, 45, 101, 121, 101,
  32, 101, 102, 102, 101, 99, 116, 34, 10, 45, 100, 111, 10, 45, 119, 97,
  105, 116, 32, 52, 48, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 98,
  125, 61, 61, 49, 125, 32, 82, 61, 123, 109, 105, 110, 40, 56, 48, 44,
  36, 82, 43, 56, 41, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 64, 123, 33, 44, 98, 125, 61, 61, 50, 125, 32, 82, 61,
  123, 109, 97, 120, 40, 51, 44, 36, 82, 45, 56, 41, 125, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 44, 123, 53, 48, 43, 51, 48, 42,
  99, 111, 115, 40, 64, 124, 42, 50, 46, 53, 41, 125, 37, 44, 123, 53,
  48, 43, 51, 48, 42, 115, 105, 110, 40, 64, 124, 42, 49, 46, 54, 41,
  125, 37, 44, 123, 53, 48, 43, 51, 51, 48, 42, 115, 105, 110, 40, 64,
  124, 42, 50, 46, 54, 41, 125, 44, 48, 46, 55, 44, 51, 44, 48, 44,
  48, 32, 45, 114, 51, 100, 91, 45, 50, 93, 32, 49, 44, 48, 46, 50,
  44, 48, 46, 54, 44, 51, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44,
  120, 125, 62, 61, 48, 125, 10, 45, 102, 105, 115, 104, 101, 121, 101, 91,
  45, 49, 93, 32, 123, 64, 123, 33, 44, 120, 125, 42, 49, 48, 48, 47,
  64, 123, 33, 44, 119, 125, 125, 44, 123, 64, 123, 33, 44, 121, 125, 42,
  49, 48, 48, 47, 64, 123, 33, 44, 104, 125, 125, 44, 36, 82, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 119, 91, 45, 49, 93, 10, 45, 105, 102,
  32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38,
  38, 64, 123, 33, 44, 68, 125, 125, 32, 45, 119, 91, 93, 32, 123, 51,
  42, 119, 125, 44, 123, 51, 42, 104, 125, 32, 45, 101, 108, 105, 102, 32,
  123, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38,
  64, 123, 33, 44, 67, 125, 125, 32, 45, 119, 91, 93, 32, 123, 49, 46,
  53, 42, 119, 125, 44, 123, 49, 46, 53, 42, 104, 125, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 105, 102, 32,
  123, 64, 33, 61, 61, 48, 34, 32, 124, 124, 32, 34, 64, 123, 33, 44,
  69, 83, 67, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 44, 81, 125,
  125, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 32, 45, 119, 32,
  48, 32, 45, 118, 32, 43, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 49, 10, 120,
  95, 102, 111, 117, 114, 105, 101, 114, 32, 58, 10, 45, 101, 91, 93, 32,
  34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 70, 111, 117, 114, 105,
  101, 114, 45, 102, 105, 108, 116, 101, 114, 105, 110, 103, 32, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45,
  45, 45, 45, 32, 77, 111, 117, 115, 101, 32, 98, 117, 116, 116, 111, 110,
  115, 32, 111, 110, 32, 116, 104, 101, 32, 114, 105, 103, 104, 116, 32, 105,
  109, 97, 103, 101, 32, 116, 111, 32, 115, 101, 116, 32, 109, 105, 110, 47,
  109, 97, 120, 32, 102, 114, 101, 113, 117, 101, 110, 99, 105, 101, 115, 46,
  92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84,
  82, 76, 43, 68, 39, 32, 116, 111, 32, 105, 110, 99, 114, 101, 97, 115,
  101, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110,
  10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76,
  43, 67, 39, 32, 116, 111, 32, 100, 101, 99, 114, 101, 97, 115, 101, 32,
  119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45,
  45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76, 43, 82,
  39, 32, 116, 111, 32, 114, 101, 115, 101, 116, 32, 119, 105, 110, 100, 111,
  119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75,
  101, 121, 115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81, 39,
  32, 116, 111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45, 45,
  92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 123,
  33, 64, 35, 125, 32, 45, 116, 101, 115, 116, 105, 109, 97, 103, 101, 50,
  100, 32, 50, 53, 54, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 110,
  101, 101, 100, 95, 117, 112, 100, 97, 116, 101, 61, 49, 10, 102, 114, 101,
  113, 109, 105, 110, 61, 48, 10, 102, 114, 101, 113, 109, 97, 120, 61, 49,
  48, 48, 10, 45, 105, 102, 32, 123, 119, 62, 51, 42, 64, 123, 33, 44,
  117, 125, 47, 53, 125, 32, 45, 114, 50, 100, 120, 91, 45, 49, 93, 32,
  123, 51, 42, 64, 123, 33, 44, 117, 125, 47, 49, 48, 125, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 104, 62, 51, 42, 64, 123,
  33, 44, 118, 125, 47, 53, 125, 32, 45, 114, 50, 100, 121, 91, 45, 49,
  93, 32, 123, 51, 42, 64, 123, 33, 44, 118, 125, 47, 53, 125, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 45, 102, 102, 116, 91, 45, 49, 93, 32,
  45, 110, 109, 91, 45, 50, 93, 32, 114, 101, 97, 108, 32, 45, 110, 109,
  91, 45, 49, 93, 32, 105, 109, 97, 103, 10, 45, 45, 115, 113, 114, 91,
  114, 101, 97, 108, 44, 105, 109, 97, 103, 93, 32, 45, 43, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 115, 113, 114, 116, 91, 45, 49, 93, 32, 45,
  43, 91, 45, 49, 93, 32, 49, 32, 45, 108, 111, 103, 91, 45, 49, 93,
  10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 115,
  104, 105, 102, 116, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37,
  44, 48, 44, 48, 44, 50, 32, 45, 116, 111, 95, 99, 111, 108, 111, 114,
  109, 111, 100, 101, 91, 45, 49, 93, 32, 64, 123, 45, 50, 44, 115, 125,
  10, 45, 110, 109, 91, 45, 49, 93, 32, 108, 111, 103, 109, 97, 103, 10,
  45, 119, 91, 48, 44, 45, 49, 93, 32, 45, 49, 44, 45, 49, 44, 48,
  44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 70, 111, 117, 114, 105, 101,
  114, 32, 102, 105, 108, 116, 101, 114, 105, 110, 103, 34, 10, 45, 105, 102,
  32, 123, 33, 110, 97, 114, 103, 40, 36, 102, 105, 114, 115, 116, 95, 116,
  105, 109, 101, 41, 125, 32, 45, 45, 108, 91, 45, 49, 93, 32, 45, 114,
  50, 100, 121, 32, 49, 50, 56, 32, 45, 102, 114, 97, 109, 101, 32, 49,
  44, 49, 44, 48, 10, 45, 97, 108, 101, 114, 116, 32, 34, 91, 71, 39,
  77, 73, 67, 32, 70, 111, 117, 114, 105, 101, 114, 32, 102, 105, 108, 116,
  101, 114, 105, 110, 103, 93, 34, 44, 92, 10, 34, 84, 104, 101, 32, 71,
  39, 77, 73, 67, 32, 70, 111, 117, 114, 105, 101, 114, 32, 102, 105, 108,
  116, 101, 114, 105, 110, 103, 32, 100, 101, 109, 111, 32, 105, 108, 108, 117,
  115, 116, 114, 97, 116, 101, 115, 32, 116, 104, 101, 32, 101, 102, 102, 101,
  99, 116, 92, 110, 34, 92, 10, 34, 111, 102, 32, 98, 97, 110, 100, 112,
  97, 115, 115, 32, 102, 114, 101, 113, 117, 101, 110, 99, 121, 32, 102, 105,
  108, 116, 101, 114, 105, 110, 103, 32, 111, 110, 32, 97, 110, 32, 105, 109,
  97, 103, 101, 46, 32, 85, 115, 101, 32, 121, 111, 117, 114, 32, 109, 111,
  117, 115, 101, 92, 110, 34, 92, 10, 34, 98, 117, 116, 116, 111, 110, 115,
  32, 116, 111, 32, 115, 101, 108, 101, 99, 116, 32, 108, 111, 119, 32, 97,
  110, 100, 32, 104, 105, 103, 104, 32, 98, 111, 117, 110, 100, 115, 32, 102,
  111, 114, 32, 116, 104, 101, 32, 102, 114, 101, 113, 117, 101, 110, 99, 105,
  101, 115, 92, 110, 34, 92, 10, 34, 100, 105, 115, 112, 108, 97, 121, 101,
  100, 32, 111, 110, 32, 116, 104, 101, 32, 70, 111, 117, 114, 105, 101, 114,
  32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 97, 116, 105, 111, 110, 32,
  111, 102, 32, 116, 104, 101, 32, 105, 109, 97, 103, 101, 92, 110, 34, 92,
  10, 34, 40, 114, 105, 103, 104, 116, 32, 105, 109, 97, 103, 101, 41, 46,
  34, 44, 92, 10, 34, 83, 116, 97, 114, 116, 32, 100, 101, 109, 111, 34,
  10, 45, 114, 109, 32, 45, 101, 110, 100, 108, 32, 102, 105, 114, 115, 116,
  95, 116, 105, 109, 101, 61, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  100, 111, 10, 45, 105, 102, 32, 36, 110, 101, 101, 100, 95, 117, 112, 100,
  97, 116, 101, 10, 45, 105, 91, 109, 97, 115, 107, 93, 32, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 10, 114, 61, 123, 115, 113, 114, 116, 40, 119,
  94, 50, 43, 104, 94, 50, 41, 42, 36, 102, 114, 101, 113, 109, 97, 120,
  47, 50, 48, 48, 125, 32, 45, 101, 108, 108, 105, 112, 115, 101, 91, 109,
  97, 115, 107, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 36, 114, 44,
  36, 114, 44, 48, 44, 49, 44, 49, 10, 114, 61, 123, 109, 97, 120, 40,
  48, 44, 115, 113, 114, 116, 40, 119, 94, 50, 43, 104, 94, 50, 41, 42,
  36, 102, 114, 101, 113, 109, 105, 110, 47, 50, 48, 48, 45, 49, 41, 125,
  32, 45, 105, 102, 32, 36, 114, 32, 45, 101, 108, 108, 105, 112, 115, 101,
  91, 109, 97, 115, 107, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 36,
  114, 44, 36, 114, 44, 48, 44, 49, 44, 48, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 45, 42, 91, 108, 111, 103, 109, 97, 103, 93, 32, 91, 109,
  97, 115, 107, 93, 32, 45, 43, 91, 45, 49, 93, 32, 91, 109, 97, 115,
  107, 93, 32, 45, 47, 91, 45, 49, 93, 32, 50, 32, 45, 110, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 115, 104, 105, 102, 116, 91,
  109, 97, 115, 107, 93, 32, 45, 53, 48, 37, 44, 45, 53, 48, 37, 44,
  48, 44, 48, 44, 50, 10, 45, 45, 42, 91, 114, 101, 97, 108, 44, 105,
  109, 97, 103, 93, 32, 91, 109, 97, 115, 107, 93, 10, 45, 114, 109, 91,
  45, 52, 93, 10, 45, 105, 102, 102, 116, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 10, 45, 114, 118, 91, 45, 50, 44, 45, 49, 93,
  10, 45, 105, 102, 32, 64, 33, 32, 45, 114, 91, 45, 50, 44, 45, 49,
  93, 32, 123, 64, 123, 33, 44, 119, 125, 47, 50, 125, 44, 64, 123, 33,
  44, 104, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 91, 45, 49,
  93, 32, 34, 70, 114, 101, 113, 46, 32, 77, 105, 110, 47, 77, 97, 120,
  32, 61, 32, 34, 123, 105, 110, 116, 40, 36, 102, 114, 101, 113, 109, 105,
  110, 41, 125, 34, 37, 32, 47, 32, 34, 123, 105, 110, 116, 40, 36, 102,
  114, 101, 113, 109, 97, 120, 41, 125, 34, 37, 34, 44, 53, 44, 53, 44,
  49, 51, 44, 49, 44, 50, 53, 53, 10, 45, 119, 91, 45, 50, 44, 45,
  49, 93, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 110, 101,
  101, 100, 95, 117, 112, 100, 97, 116, 101, 61, 48, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 119, 97, 105, 116, 10, 45, 105, 102, 32, 123, 64, 123,
  33, 44, 98, 125, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 120, 125,
  62, 61, 64, 123, 33, 44, 119, 125, 47, 50, 125, 10, 114, 61, 123, 50,
  48, 48, 42, 115, 113, 114, 116, 40, 40, 64, 123, 33, 44, 120, 125, 45,
  51, 42, 64, 123, 33, 44, 119, 125, 47, 52, 41, 94, 50, 43, 40, 64,
  123, 33, 44, 121, 125, 45, 64, 123, 33, 44, 104, 125, 47, 50, 41, 94,
  50, 41, 47, 92, 10, 115, 113, 114, 116, 40, 40, 64, 123, 33, 44, 119,
  125, 47, 50, 41, 94, 50, 43, 64, 123, 33, 44, 104, 125, 94, 50, 41,
  125, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 98, 125, 38, 49, 125,
  32, 102, 114, 101, 113, 109, 97, 120, 61, 36, 114, 10, 45, 101, 108, 115,
  101, 32, 102, 114, 101, 113, 109, 105, 110, 61, 123, 109, 97, 120, 40, 48,
  44, 36, 114, 45, 51, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 102, 114, 101, 113, 109, 105, 110, 62, 61, 36, 102,
  114, 101, 113, 109, 97, 120, 125, 32, 102, 114, 101, 113, 109, 105, 110, 61,
  36, 102, 114, 101, 113, 109, 97, 120, 32, 45, 101, 110, 100, 105, 102, 10,
  110, 101, 101, 100, 95, 117, 112, 100, 97, 116, 101, 61, 49, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 64, 123, 33, 44, 114, 125, 32,
  110, 101, 101, 100, 95, 117, 112, 100, 97, 116, 101, 61, 49, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 40, 64, 123, 33, 44, 67,
  84, 82, 76, 76, 69, 70, 84, 125, 34, 32, 124, 124, 32, 34, 64, 123,
  33, 44, 67, 84, 82, 76, 82, 73, 71, 72, 84, 125, 41, 34, 32, 38,
  38, 32, 34, 64, 123, 33, 44, 68, 125, 125, 32, 45, 119, 91, 93, 32,
  123, 64, 123, 33, 44, 119, 125, 42, 49, 46, 53, 125, 44, 123, 64, 123,
  33, 44, 104, 125, 42, 49, 46, 53, 125, 32, 110, 101, 101, 100, 95, 117,
  112, 100, 97, 116, 101, 61, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 40, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70,
  84, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 44, 67, 84, 82, 76,
  82, 73, 71, 72, 84, 125, 41, 34, 32, 38, 38, 32, 34, 64, 123, 33,
  44, 67, 125, 125, 32, 45, 119, 91, 93, 32, 123, 64, 123, 33, 44, 119,
  125, 47, 49, 46, 53, 125, 44, 123, 64, 123, 33, 44, 104, 125, 47, 49,
  46, 53, 125, 32, 110, 101, 101, 100, 95, 117, 112, 100, 97, 116, 101, 61,
  49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 40, 64,
  123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 34, 32, 124, 124,
  32, 34, 64, 123, 33, 44, 67, 84, 82, 76, 82, 73, 71, 72, 84, 125,
  41, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 82, 125, 125, 32, 45,
  119, 91, 93, 32, 123, 50, 42, 64, 123, 48, 44, 119, 125, 125, 44, 64,
  123, 48, 44, 104, 125, 32, 110, 101, 101, 100, 95, 117, 112, 100, 97, 116,
  101, 61, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 119, 104, 105, 108,
  101, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44,
  69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81,
  125, 125, 10, 45, 114, 109, 91, 45, 51, 45, 45, 49, 93, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 119, 32, 48, 32, 45,
  114, 109, 32, 45, 118, 32, 43, 10, 120, 95, 104, 105, 115, 116, 111, 103,
  114, 97, 109, 32, 58, 10, 45, 101, 91, 93, 32, 34, 92, 110, 10, 45,
  45, 45, 45, 45, 45, 32, 72, 105, 115, 116, 111, 103, 114, 97, 109, 32,
  100, 101, 109, 111, 32, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45,
  45, 45, 32, 77, 111, 117, 115, 101, 32, 116, 111, 32, 115, 101, 116, 32,
  112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 46, 92, 110, 10, 45, 45,
  45, 45, 32, 82, 105, 103, 104, 116, 32, 98, 117, 116, 116, 111, 110, 32,
  111, 114, 32, 107, 101, 121, 32, 39, 83, 80, 65, 67, 69, 39, 32, 116,
  111, 32, 114, 101, 115, 101, 116, 46, 92, 110, 10, 45, 45, 45, 45, 32,
  75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81,
  39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45,
  45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 10,
  45, 105, 102, 32, 123, 33, 64, 35, 125, 32, 45, 116, 101, 115, 116, 105,
  109, 97, 103, 101, 50, 100, 32, 51, 48, 48, 44, 51, 48, 48, 32, 45,
  101, 108, 115, 101, 32, 45, 107, 91, 48, 93, 32, 45, 116, 111, 95, 114,
  103, 98, 32, 45, 114, 50, 100, 121, 32, 51, 48, 48, 44, 50, 32, 45,
  105, 102, 32, 123, 119, 62, 56, 48, 48, 125, 32, 45, 114, 32, 56, 48,
  48, 44, 49, 48, 48, 37, 44, 49, 44, 51, 44, 50, 32, 45, 101, 110,
  100, 105, 102, 32, 45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93, 32,
  49, 44, 49, 44, 48, 10, 51, 48, 48, 44, 123, 104, 125, 44, 49, 44,
  51, 44, 50, 50, 48, 10, 45, 116, 91, 45, 49, 93, 32, 34, 71, 97,
  109, 109, 97, 32, 58, 34, 44, 53, 44, 48, 44, 49, 54, 44, 49, 44,
  48, 10, 45, 116, 91, 45, 49, 93, 32, 34, 67, 111, 110, 116, 114, 97,
  115, 116, 32, 58, 34, 44, 53, 44, 53, 48, 44, 49, 54, 44, 49, 44,
  48, 10, 45, 116, 91, 45, 49, 93, 32, 34, 66, 114, 105, 103, 104, 116,
  110, 101, 115, 115, 32, 58, 34, 44, 53, 44, 49, 48, 48, 44, 49, 54,
  44, 49, 44, 48, 10, 45, 116, 91, 45, 49, 93, 32, 34, 83, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 58, 34, 44, 53, 44, 49, 53, 48,
  44, 49, 54, 44, 49, 44, 48, 10, 45, 116, 91, 45, 49, 93, 32, 34,
  83, 104, 97, 114, 112, 110, 101, 115, 115, 32, 58, 34, 44, 53, 44, 50,
  48, 48, 44, 49, 54, 44, 49, 44, 48, 10, 45, 116, 91, 45, 49, 93,
  32, 34, 67, 108, 117, 115, 116, 101, 114, 115, 32, 58, 34, 44, 53, 44,
  50, 53, 48, 44, 49, 54, 44, 49, 44, 48, 10, 45, 97, 91, 45, 50,
  44, 45, 49, 93, 32, 120, 10, 123, 119, 125, 44, 50, 48, 48, 44, 49,
  44, 51, 44, 50, 53, 53, 10, 45, 103, 114, 105, 100, 91, 45, 49, 93,
  32, 49, 48, 37, 44, 49, 48, 37, 44, 48, 44, 48, 44, 48, 46, 51,
  44, 48, 120, 67, 67, 67, 67, 67, 67, 67, 67, 44, 48, 10, 45, 114,
  101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48, 44, 48,
  44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 48, 120, 70,
  70, 70, 70, 70, 70, 70, 70, 44, 48, 10, 45, 97, 120, 101, 115, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 44, 49, 44, 48, 44, 49, 51,
  44, 49, 44, 48, 10, 45, 102, 114, 97, 109, 101, 91, 45, 50, 44, 45,
  49, 93, 32, 53, 44, 53, 44, 50, 50, 48, 10, 45, 97, 91, 45, 50,
  44, 45, 49, 93, 32, 121, 10, 99, 108, 117, 115, 116, 101, 114, 115, 61,
  54, 52, 32, 115, 104, 97, 114, 112, 110, 101, 115, 115, 61, 48, 32, 115,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 48, 32, 99, 111, 110, 116,
  114, 97, 115, 116, 61, 49, 32, 98, 114, 105, 103, 104, 116, 110, 101, 115,
  115, 61, 48, 32, 103, 97, 109, 109, 97, 61, 49, 10, 45, 100, 111, 10,
  91, 48, 93, 10, 105, 97, 61, 123, 105, 97, 125, 10, 45, 105, 102, 32,
  36, 103, 97, 109, 109, 97, 32, 45, 47, 91, 45, 49, 93, 32, 50, 53,
  53, 32, 45, 94, 91, 45, 49, 93, 32, 123, 49, 47, 36, 103, 97, 109,
  109, 97, 125, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 45, 91, 45, 49, 93, 32, 36, 105, 97,
  32, 45, 42, 91, 45, 49, 93, 32, 36, 99, 111, 110, 116, 114, 97, 115,
  116, 32, 45, 43, 91, 45, 49, 93, 32, 36, 98, 114, 105, 103, 104, 116,
  110, 101, 115, 115, 32, 45, 43, 91, 45, 49, 93, 32, 36, 105, 97, 10,
  45, 98, 91, 45, 49, 93, 32, 36, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 10, 45, 115, 104, 97, 114, 112, 101, 110, 91, 45, 49, 93, 32,
  36, 115, 104, 97, 114, 112, 110, 101, 115, 115, 10, 45, 99, 91, 45, 49,
  93, 32, 48, 44, 50, 53, 53, 10, 45, 45, 106, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 54, 44, 54, 10, 115, 120, 61, 123, 64, 123, 48,
  44, 119, 125, 43, 49, 50, 125, 10, 45, 95, 120, 95, 104, 105, 115, 116,
  111, 103, 114, 97, 109, 91, 45, 49, 93, 32, 123, 36, 103, 97, 109, 109,
  97, 42, 49, 48, 48, 47, 52, 125, 32, 45, 106, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 36, 115, 120, 44, 50, 53, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 95, 120, 95, 104, 105, 115, 116, 111, 103, 114, 97,
  109, 91, 45, 49, 93, 32, 123, 36, 99, 111, 110, 116, 114, 97, 115, 116,
  42, 49, 48, 48, 47, 52, 125, 32, 45, 106, 91, 45, 50, 93, 32, 91,
  45, 49, 93, 44, 36, 115, 120, 44, 55, 53, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 95, 120, 95, 104, 105, 115, 116, 111, 103, 114, 97, 109,
  91, 45, 49, 93, 32, 123, 40, 36, 98, 114, 105, 103, 104, 116, 110, 101,
  115, 115, 43, 49, 50, 56, 41, 42, 49, 48, 48, 47, 50, 53, 54, 125,
  32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 115, 120,
  44, 49, 50, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 95, 120,
  95, 104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 49, 93, 32, 123,
  36, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 42, 49, 48, 48, 47,
  49, 48, 125, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44,
  36, 115, 120, 44, 49, 55, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 95, 120, 95, 104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 49,
  93, 32, 123, 36, 115, 104, 97, 114, 112, 110, 101, 115, 115, 42, 49, 48,
  48, 47, 50, 48, 48, 48, 125, 32, 45, 106, 91, 45, 50, 93, 32, 91,
  45, 49, 93, 44, 36, 115, 120, 44, 50, 50, 53, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 95, 120, 95, 104, 105, 115, 116, 111, 103, 114, 97,
  109, 91, 45, 49, 93, 32, 123, 36, 99, 108, 117, 115, 116, 101, 114, 115,
  42, 49, 48, 48, 47, 50, 53, 54, 125, 32, 45, 106, 91, 45, 50, 93,
  32, 91, 45, 49, 93, 44, 36, 115, 120, 44, 50, 55, 53, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 45, 115, 91, 45, 50, 93, 32, 99, 32,
  45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 51, 45, 45, 49,
  93, 32, 36, 99, 108, 117, 115, 116, 101, 114, 115, 44, 48, 44, 50, 53,
  53, 32, 45, 47, 91, 45, 51, 45, 45, 49, 93, 32, 123, 51, 42, 64,
  123, 48, 44, 119, 104, 125, 47, 36, 99, 108, 117, 115, 116, 101, 114, 115,
  125, 32, 45, 114, 109, 91, 45, 53, 93, 10, 45, 45, 122, 91, 45, 52,
  93, 32, 53, 44, 51, 49, 55, 44, 123, 64, 123, 45, 52, 44, 119, 125,
  45, 53, 125, 44, 123, 64, 123, 45, 52, 44, 104, 125, 45, 54, 125, 10,
  45, 103, 114, 97, 112, 104, 91, 45, 49, 93, 32, 91, 45, 52, 93, 44,
  51, 44, 48, 44, 49, 44, 48, 44, 48, 46, 50, 44, 50, 53, 53, 44,
  48, 44, 48, 10, 45, 103, 114, 97, 112, 104, 91, 45, 49, 93, 32, 91,
  45, 51, 93, 44, 51, 44, 48, 44, 49, 44, 48, 44, 48, 46, 50, 44,
  48, 44, 50, 53, 53, 44, 48, 10, 45, 103, 114, 97, 112, 104, 91, 45,
  49, 93, 32, 91, 45, 50, 93, 44, 51, 44, 48, 44, 49, 44, 48, 44,
  48, 46, 50, 44, 48, 44, 48, 44, 50, 53, 53, 10, 45, 114, 109, 91,
  45, 52, 45, 45, 50, 93, 10, 45, 106, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 44, 53, 44, 51, 49, 55, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 119, 91, 45, 49, 93, 32, 123, 119, 125, 44, 123, 104, 125, 44,
  48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 72, 105, 115, 116, 111,
  103, 114, 97, 109, 32, 100, 101, 109, 111, 34, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 119, 97, 105, 116, 10, 45, 105, 102, 32, 123, 64, 123,
  33, 44, 98, 125, 38, 49, 92, 32, 38, 38, 92, 32, 64, 123, 33, 44,
  120, 125, 62, 61, 64, 123, 48, 44, 119, 125, 45, 49, 48, 125, 10, 45,
  105, 102, 32, 123, 64, 123, 33, 44, 121, 125, 62, 61, 50, 53, 92, 32,
  38, 38, 92, 32, 64, 123, 33, 44, 121, 125, 60, 61, 52, 50, 125, 10,
  103, 97, 109, 109, 97, 61, 123, 109, 97, 120, 40, 48, 44, 109, 105, 110,
  40, 52, 44, 40, 64, 123, 33, 44, 120, 125, 45, 36, 115, 120, 41, 42,
  52, 47, 50, 56, 48, 41, 41, 125, 10, 45, 101, 108, 105, 102, 32, 123,
  64, 123, 33, 44, 121, 125, 62, 61, 55, 53, 92, 32, 38, 38, 92, 32,
  64, 123, 33, 44, 121, 125, 60, 61, 57, 50, 125, 10, 99, 111, 110, 116,
  114, 97, 115, 116, 61, 123, 109, 97, 120, 40, 48, 44, 109, 105, 110, 40,
  52, 44, 40, 64, 123, 33, 44, 120, 125, 45, 36, 115, 120, 41, 42, 52,
  47, 50, 56, 48, 41, 41, 125, 10, 45, 101, 108, 105, 102, 32, 123, 64,
  123, 33, 44, 121, 125, 62, 61, 49, 50, 53, 92, 32, 38, 38, 92, 32,
  64, 123, 33, 44, 121, 125, 60, 61, 49, 52, 50, 125, 10, 98, 114, 105,
  103, 104, 116, 110, 101, 115, 115, 61, 123, 109, 97, 120, 40, 45, 49, 50,
  56, 44, 109, 105, 110, 40, 49, 50, 56, 44, 40, 64, 123, 33, 44, 120,
  125, 45, 36, 115, 120, 41, 42, 50, 53, 54, 47, 50, 56, 48, 45, 49,
  50, 56, 41, 41, 125, 10, 45, 101, 108, 105, 102, 32, 123, 64, 123, 33,
  44, 121, 125, 62, 61, 49, 55, 53, 92, 32, 38, 38, 92, 32, 64, 123,
  33, 44, 121, 125, 60, 61, 49, 57, 50, 125, 10, 115, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 61, 123, 109, 97, 120, 40, 48, 44, 109, 105, 110,
  40, 49, 48, 44, 40, 64, 123, 33, 44, 120, 125, 45, 36, 115, 120, 41,
  42, 49, 48, 47, 50, 56, 48, 41, 41, 125, 10, 45, 101, 108, 105, 102,
  32, 123, 64, 123, 33, 44, 121, 125, 62, 61, 50, 50, 53, 92, 32, 38,
  38, 92, 32, 64, 123, 33, 44, 121, 125, 60, 61, 50, 52, 50, 125, 10,
  115, 104, 97, 114, 112, 110, 101, 115, 115, 61, 123, 109, 97, 120, 40, 48,
  44, 109, 105, 110, 40, 50, 48, 48, 48, 44, 40, 64, 123, 33, 44, 120,
  125, 45, 36, 115, 120, 41, 42, 50, 48, 48, 48, 47, 50, 56, 48, 41,
  41, 125, 10, 45, 101, 108, 105, 102, 32, 123, 64, 123, 33, 44, 121, 125,
  62, 61, 50, 55, 53, 92, 32, 38, 38, 92, 32, 64, 123, 33, 44, 121,
  125, 60, 61, 50, 57, 50, 125, 10, 99, 108, 117, 115, 116, 101, 114, 115,
  61, 123, 109, 97, 120, 40, 50, 44, 109, 105, 110, 40, 50, 53, 54, 44,
  40, 64, 123, 33, 44, 120, 125, 45, 36, 115, 120, 41, 42, 50, 53, 54,
  47, 50, 56, 48, 41, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 98,
  125, 38, 50, 92, 32, 124, 124, 92, 32, 64, 123, 33, 44, 83, 80, 65,
  67, 69, 125, 125, 32, 99, 108, 117, 115, 116, 101, 114, 115, 61, 54, 52,
  32, 115, 104, 97, 114, 112, 110, 101, 115, 115, 61, 48, 32, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 61, 48, 32, 99, 111, 110, 116, 114, 97,
  115, 116, 61, 49, 32, 98, 114, 105, 103, 104, 116, 110, 101, 115, 115, 61,
  48, 32, 103, 97, 109, 109, 97, 61, 49, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34, 32, 38, 38, 32,
  34, 33, 64, 123, 33, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34,
  33, 64, 123, 33, 44, 81, 125, 125, 10, 45, 119, 32, 48, 32, 45, 114,
  109, 32, 45, 118, 32, 43, 10, 95, 120, 95, 104, 105, 115, 116, 111, 103,
  114, 97, 109, 32, 58, 10, 118, 97, 108, 61, 123, 109, 97, 120, 40, 48,
  44, 109, 105, 110, 40, 49, 48, 48, 44, 36, 49, 41, 41, 125, 10, 50,
  56, 48, 44, 50, 44, 49, 44, 51, 44, 50, 53, 53, 32, 45, 108, 105,
  110, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 36, 118, 97, 108, 37,
  44, 48, 44, 49, 44, 48, 44, 50, 53, 53, 44, 48, 32, 45, 108, 105,
  110, 101, 91, 45, 49, 93, 32, 48, 44, 49, 44, 36, 118, 97, 108, 37,
  44, 49, 44, 49, 44, 50, 52, 48, 44, 50, 53, 53, 44, 54, 50, 32,
  45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 54, 44, 49,
  44, 51, 44, 51, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 123, 114,
  111, 117, 110, 100, 40, 36, 118, 97, 108, 41, 125, 37, 44, 48, 44, 48,
  44, 50, 48, 44, 49, 44, 49, 32, 45, 45, 42, 91, 45, 49, 93, 32,
  45, 50, 53, 53, 32, 45, 43, 91, 45, 49, 93, 32, 50, 53, 53, 32,
  45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 49, 44, 51, 10, 45, 106, 91, 45, 51, 93, 32, 91, 45, 49, 93,
  44, 123, 40, 50, 56, 48, 45, 119, 41, 47, 50, 125, 44, 123, 40, 49,
  54, 45, 104, 41, 47, 50, 125, 44, 48, 44, 48, 44, 49, 44, 91, 45,
  50, 93, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 114,
  91, 45, 49, 93, 32, 123, 119, 43, 50, 125, 44, 123, 104, 43, 50, 125,
  44, 49, 44, 51, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53,
  10, 120, 95, 104, 111, 117, 103, 104, 32, 58, 10, 45, 101, 91, 93, 32,
  34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 72, 111, 117, 103, 104,
  45, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45,
  45, 45, 32, 77, 111, 117, 115, 101, 32, 98, 117, 116, 116, 111, 110, 115,
  32, 111, 110, 32, 116, 104, 101, 32, 118, 111, 116, 101, 32, 105, 109, 97,
  103, 101, 32, 116, 111, 32, 100, 114, 97, 119, 32, 99, 111, 114, 114, 101,
  115, 112, 111, 110, 100, 105, 110, 103, 32, 108, 105, 110, 101, 46, 92, 110,
  10, 45, 45, 45, 45, 32, 77, 111, 117, 115, 101, 32, 98, 117, 116, 116,
  111, 110, 115, 32, 111, 110, 32, 116, 104, 101, 32, 105, 109, 97, 103, 101,
  32, 116, 111, 32, 118, 111, 116, 101, 32, 102, 111, 114, 32, 97, 108, 108,
  32, 108, 105, 110, 101, 115, 32, 99, 114, 111, 115, 115, 105, 110, 103, 46,
  92, 110, 10, 45, 45, 45, 45, 32, 116, 104, 101, 32, 99, 108, 105, 99,
  107, 101, 100, 32, 112, 111, 105, 110, 116, 46, 92, 110, 10, 45, 45, 45,
  45, 32, 75, 101, 121, 32, 39, 83, 80, 65, 67, 69, 39, 32, 116, 111,
  32, 114, 101, 115, 101, 116, 32, 116, 104, 101, 32, 104, 111, 117, 103, 104,
  32, 119, 105, 110, 100, 111, 119, 46, 92, 110, 10, 45, 45, 45, 45, 32,
  75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81,
  39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45,
  45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32,
  123, 33, 64, 35, 125, 32, 45, 116, 101, 115, 116, 105, 109, 97, 103, 101,
  50, 100, 32, 52, 48, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 110,
  32, 48, 44, 50, 53, 53, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 114, 91, 45, 49, 93, 32,
  64, 123, 45, 102, 105, 116, 115, 99, 114, 101, 101, 110, 92, 32, 123, 119,
  125, 44, 123, 104, 125, 125, 44, 49, 44, 49, 48, 48, 37, 44, 51, 10,
  114, 104, 111, 109, 97, 120, 61, 123, 115, 113, 114, 116, 40, 119, 94, 50,
  43, 104, 94, 50, 41, 47, 50, 125, 10, 45, 45, 98, 91, 45, 49, 93,
  32, 49, 46, 53, 32, 45, 104, 111, 117, 103, 104, 91, 45, 49, 93, 32,
  53, 49, 50, 44, 52, 48, 48, 32, 45, 98, 91, 45, 49, 93, 32, 48,
  46, 53, 32, 45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 108, 111, 103,
  91, 45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 10, 45, 119, 91, 45, 50, 93, 32, 45, 49, 44, 45, 49, 44, 48,
  44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 73, 109, 97, 103, 101, 34,
  32, 45, 119, 49, 91, 45, 49, 93, 32, 45, 49, 44, 45, 49, 44, 48,
  44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 72, 111, 117, 103, 104, 32,
  116, 114, 97, 110, 115, 102, 111, 114, 109, 34, 10, 45, 105, 102, 32, 123,
  33, 110, 97, 114, 103, 40, 36, 102, 105, 114, 115, 116, 95, 116, 105, 109,
  101, 41, 125, 32, 45, 45, 108, 91, 48, 93, 32, 45, 114, 50, 100, 121,
  32, 49, 50, 56, 32, 45, 102, 114, 97, 109, 101, 32, 49, 44, 49, 44,
  48, 10, 45, 97, 108, 101, 114, 116, 32, 34, 91, 71, 39, 77, 73, 67,
  32, 72, 111, 117, 103, 104, 32, 84, 114, 97, 110, 115, 102, 111, 114, 109,
  93, 34, 44, 92, 10, 34, 84, 104, 101, 32, 71, 39, 77, 73, 67, 32,
  72, 111, 117, 103, 104, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32,
  100, 101, 109, 111, 32, 105, 108, 108, 117, 115, 116, 114, 97, 116, 101, 115,
  32, 116, 104, 101, 32, 97, 112, 112, 108, 105, 99, 97, 116, 105, 111, 110,
  92, 110, 34, 92, 10, 34, 111, 102, 32, 116, 104, 101, 32, 72, 111, 117,
  103, 104, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32, 116, 111, 32,
  100, 101, 116, 101, 99, 116, 32, 108, 105, 110, 101, 115, 32, 105, 110, 32,
  97, 110, 32, 105, 109, 97, 103, 101, 46, 32, 85, 115, 101, 32, 121, 111,
  117, 114, 92, 110, 34, 92, 10, 34, 109, 111, 117, 115, 101, 32, 98, 117,
  116, 116, 111, 110, 115, 32, 116, 111, 32, 101, 120, 112, 108, 111, 114, 101,
  32, 116, 104, 101, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32, 105,
  109, 97, 103, 101, 32, 97, 110, 100, 32, 115, 101, 101, 32, 104, 111, 119,
  92, 110, 34, 92, 10, 34, 108, 105, 110, 101, 115, 32, 105, 110, 32, 105,
  109, 97, 103, 101, 115, 32, 97, 114, 101, 32, 114, 101, 112, 114, 101, 115,
  101, 110, 116, 101, 100, 32, 98, 121, 32, 112, 111, 105, 110, 116, 115, 32,
  105, 110, 32, 116, 104, 101, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109,
  46, 34, 44, 92, 10, 34, 83, 116, 97, 114, 116, 32, 100, 101, 109, 111,
  34, 10, 45, 114, 109, 32, 45, 101, 110, 100, 108, 32, 102, 105, 114, 115,
  116, 95, 116, 105, 109, 101, 61, 48, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 100, 111, 10, 45, 119, 97, 105, 116, 10, 45, 105, 102, 32, 64, 123,
  33, 44, 98, 125, 10, 120, 48, 61, 123, 64, 123, 33, 44, 120, 125, 45,
  64, 123, 33, 44, 119, 125, 47, 50, 125, 10, 121, 48, 61, 123, 64, 123,
  33, 44, 121, 125, 45, 64, 123, 33, 44, 104, 125, 47, 50, 125, 10, 114,
  104, 111, 48, 61, 123, 115, 113, 114, 116, 40, 40, 36, 120, 48, 41, 94,
  50, 43, 40, 36, 121, 48, 41, 94, 50, 41, 125, 10, 116, 104, 101, 116,
  97, 48, 61, 123, 97, 116, 97, 110, 50, 40, 36, 121, 48, 44, 36, 120,
  48, 41, 125, 10, 40, 48, 44, 123, 50, 42, 112, 105, 125, 41, 32, 40,
  36, 116, 104, 101, 116, 97, 48, 44, 123, 36, 116, 104, 101, 116, 97, 48,
  45, 50, 42, 112, 105, 125, 41, 10, 45, 114, 91, 45, 50, 44, 45, 49,
  93, 32, 64, 123, 45, 51, 44, 119, 125, 44, 49, 44, 49, 44, 49, 44,
  51, 10, 45, 99, 111, 115, 91, 45, 49, 93, 32, 45, 42, 91, 45, 49,
  93, 32, 36, 114, 104, 111, 48, 32, 45, 45, 108, 116, 91, 45, 49, 93,
  32, 48, 32, 45, 97, 98, 115, 91, 45, 50, 93, 10, 45, 42, 91, 45,
  49, 93, 32, 123, 112, 105, 125, 32, 45, 43, 91, 45, 51, 44, 45, 49,
  93, 32, 45, 37, 91, 45, 50, 93, 32, 123, 50, 42, 112, 105, 125, 10,
  45, 42, 91, 45, 50, 93, 32, 123, 48, 46, 53, 42, 64, 123, 45, 51,
  44, 119, 125, 47, 112, 105, 125, 32, 45, 42, 91, 45, 49, 93, 32, 123,
  64, 123, 45, 51, 44, 104, 125, 47, 36, 114, 104, 111, 109, 97, 120, 125,
  10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 119, 125, 32, 45, 112, 111, 105, 110, 116, 91,
  45, 50, 93, 32, 64, 123, 45, 49, 44, 40, 36, 62, 44, 48, 41, 125,
  44, 64, 123, 45, 49, 44, 40, 36, 62, 44, 49, 41, 125, 44, 48, 44,
  48, 46, 51, 44, 50, 53, 53, 32, 45, 100, 111, 110, 101, 10, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 119, 49, 91, 45, 49, 93, 10, 45, 101,
  108, 105, 102, 32, 123, 64, 123, 33, 49, 44, 120, 125, 62, 61, 48, 34,
  32, 38, 38, 32, 34, 64, 123, 33, 49, 44, 98, 125, 125, 10, 116, 104,
  101, 116, 97, 61, 123, 64, 123, 33, 49, 44, 120, 125, 42, 50, 42, 112,
  105, 47, 64, 123, 33, 49, 44, 119, 125, 125, 10, 114, 104, 111, 61, 123,
  64, 123, 33, 49, 44, 121, 125, 42, 36, 114, 104, 111, 109, 97, 120, 47,
  64, 123, 33, 49, 44, 104, 125, 125, 10, 120, 61, 123, 64, 123, 45, 50,
  44, 119, 125, 47, 50, 43, 36, 114, 104, 111, 42, 99, 111, 115, 40, 36,
  116, 104, 101, 116, 97, 41, 125, 10, 121, 61, 123, 64, 123, 45, 50, 44,
  104, 125, 47, 50, 43, 36, 114, 104, 111, 42, 115, 105, 110, 40, 36, 116,
  104, 101, 116, 97, 41, 125, 10, 120, 48, 61, 123, 36, 120, 43, 49, 48,
  48, 48, 42, 115, 105, 110, 40, 36, 116, 104, 101, 116, 97, 41, 125, 10,
  121, 48, 61, 123, 36, 121, 45, 49, 48, 48, 48, 42, 99, 111, 115, 40,
  36, 116, 104, 101, 116, 97, 41, 125, 10, 120, 49, 61, 123, 36, 120, 45,
  49, 48, 48, 48, 42, 115, 105, 110, 40, 36, 116, 104, 101, 116, 97, 41,
  125, 10, 121, 49, 61, 123, 36, 121, 43, 49, 48, 48, 48, 42, 99, 111,
  115, 40, 36, 116, 104, 101, 116, 97, 41, 125, 10, 91, 45, 50, 93, 10,
  45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 120, 48, 44, 36, 121,
  48, 44, 36, 120, 49, 44, 36, 121, 49, 44, 49, 44, 48, 120, 48, 70,
  48, 70, 48, 70, 48, 70, 44, 50, 53, 53, 10, 45, 108, 105, 110, 101,
  91, 45, 49, 93, 32, 123, 36, 120, 48, 43, 49, 125, 44, 36, 121, 48,
  44, 36, 120, 49, 44, 36, 121, 49, 44, 49, 44, 48, 120, 48, 70, 48,
  70, 48, 70, 48, 70, 44, 50, 53, 53, 10, 45, 108, 105, 110, 101, 91,
  45, 49, 93, 32, 36, 120, 48, 44, 123, 36, 121, 48, 43, 49, 125, 44,
  36, 120, 49, 44, 36, 121, 49, 44, 49, 44, 48, 120, 48, 70, 48, 70,
  48, 70, 48, 70, 44, 50, 53, 53, 10, 45, 108, 105, 110, 101, 91, 45,
  49, 93, 32, 36, 120, 48, 44, 36, 121, 48, 44, 36, 120, 49, 44, 36,
  121, 49, 44, 49, 44, 48, 120, 70, 48, 70, 48, 70, 48, 70, 48, 44,
  48, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 123, 36, 120, 48,
  43, 49, 125, 44, 36, 121, 48, 44, 36, 120, 49, 44, 36, 121, 49, 44,
  49, 44, 48, 120, 70, 48, 70, 48, 70, 48, 70, 48, 44, 48, 10, 45,
  108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 120, 48, 44, 123, 36, 121,
  48, 43, 49, 125, 44, 36, 120, 49, 44, 36, 121, 49, 44, 49, 44, 48,
  120, 70, 48, 70, 48, 70, 48, 70, 48, 44, 48, 10, 45, 119, 91, 45,
  49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 105, 102,
  32, 123, 64, 123, 33, 44, 83, 80, 65, 67, 69, 125, 34, 32, 124, 124,
  32, 34, 64, 123, 33, 49, 44, 83, 80, 65, 67, 69, 125, 125, 10, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 45, 98, 91, 45, 49, 93, 32, 49,
  46, 53, 32, 45, 104, 111, 117, 103, 104, 91, 45, 49, 93, 32, 53, 49,
  50, 44, 52, 48, 48, 32, 45, 98, 91, 45, 49, 93, 32, 48, 46, 53,
  32, 45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 108, 111, 103, 91, 45,
  49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10,
  45, 119, 49, 91, 45, 49, 93, 32, 45, 49, 44, 45, 49, 44, 48, 44,
  34, 72, 111, 117, 103, 104, 32, 84, 114, 97, 110, 115, 102, 111, 114, 109,
  34, 10, 45, 101, 108, 105, 102, 32, 64, 123, 33, 44, 114, 125, 32, 45,
  119, 91, 45, 50, 93, 10, 45, 101, 108, 105, 102, 32, 64, 123, 33, 49,
  44, 114, 125, 32, 45, 119, 49, 91, 45, 49, 93, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34, 32, 38,
  38, 32, 34, 64, 123, 33, 49, 125, 34, 32, 38, 38, 32, 34, 33, 64,
  123, 33, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123,
  33, 44, 81, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 49, 44,
  69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 49, 44,
  81, 125, 125, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 110, 100,
  108, 10, 45, 105, 102, 32, 123, 33, 64, 33, 34, 32, 124, 124, 32, 34,
  33, 64, 123, 33, 49, 125, 125, 32, 45, 98, 114, 101, 97, 107, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 119, 48, 32, 48, 10, 45, 100, 111, 110,
  101, 32, 45, 114, 109, 32, 45, 118, 32, 43, 10, 120, 95, 106, 97, 119,
  98, 114, 101, 97, 107, 101, 114, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 34, 36, 123, 49, 61, 49, 50, 125, 62, 48, 32, 38, 38, 32, 36,
  49, 60, 50, 48, 32, 38, 38, 32, 36, 123, 50, 61, 49, 51, 125, 62,
  48, 32, 38, 38, 32, 36, 50, 60, 50, 48, 32, 38, 38, 32, 36, 123,
  51, 61, 53, 125, 62, 48, 32, 38, 38, 32, 36, 51, 60, 61, 56, 34,
  10, 45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45,
  32, 74, 97, 119, 98, 114, 101, 97, 107, 101, 114, 32, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 92,
  110, 10, 45, 45, 45, 45, 32, 84, 104, 101, 32, 103, 111, 97, 108, 32,
  111, 102, 32, 116, 104, 101, 32, 103, 97, 109, 101, 32, 105, 115, 32, 116,
  111, 32, 114, 101, 109, 111, 118, 101, 32, 116, 104, 101, 32, 109, 97, 120,
  105, 109, 117, 109, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 92, 110,
  10, 45, 45, 45, 45, 32, 98, 97, 108, 108, 115, 32, 111, 110, 32, 116,
  104, 101, 32, 98, 111, 97, 114, 100, 44, 32, 115, 105, 109, 112, 108, 121,
  32, 98, 121, 32, 99, 108, 105, 99, 107, 105, 110, 103, 32, 111, 110, 32,
  116, 104, 101, 109, 46, 32, 66, 117, 116, 32, 97, 92, 110, 10, 45, 45,
  45, 45, 32, 99, 111, 108, 111, 114, 101, 100, 32, 98, 97, 108, 108, 32,
  99, 97, 110, 32, 100, 105, 115, 97, 112, 112, 101, 97, 114, 32, 111, 110,
  108, 121, 32, 105, 102, 32, 105, 116, 32, 105, 115, 32, 103, 114, 111, 117,
  112, 101, 100, 32, 119, 105, 116, 104, 32, 97, 116, 92, 110, 10, 45, 45,
  45, 45, 32, 108, 101, 97, 115, 116, 32, 111, 110, 101, 32, 98, 97, 108,
  108, 32, 111, 102, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 99, 111,
  108, 111, 114, 46, 32, 84, 104, 101, 32, 115, 99, 111, 114, 101, 32, 105,
  115, 32, 104, 105, 103, 104, 101, 114, 32, 105, 102, 92, 110, 10, 45, 45,
  45, 45, 32, 121, 111, 117, 32, 100, 101, 115, 116, 114, 111, 121, 32, 108,
  97, 114, 103, 101, 114, 32, 115, 101, 116, 115, 32, 111, 102, 32, 99, 111,
  110, 110, 101, 99, 116, 101, 100, 32, 99, 111, 108, 111, 114, 101, 100, 32,
  98, 97, 108, 108, 115, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10,
  45, 45, 45, 45, 32, 76, 101, 102, 116, 32, 109, 111, 117, 115, 101, 32,
  98, 117, 116, 116, 111, 110, 32, 116, 111, 32, 115, 101, 108, 101, 99, 116,
  47, 100, 101, 115, 116, 114, 111, 121, 32, 98, 97, 108, 108, 115, 32, 111,
  110, 32, 98, 111, 97, 114, 100, 46, 92, 110, 10, 45, 45, 45, 45, 32,
  75, 101, 121, 32, 39, 66, 65, 67, 75, 83, 80, 65, 67, 69, 39, 32,
  111, 114, 32, 39, 83, 80, 65, 67, 69, 39, 32, 116, 111, 32, 117, 110,
  100, 111, 32, 116, 104, 101, 32, 108, 97, 115, 116, 32, 109, 111, 118, 101,
  46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 32, 39, 83, 39,
  32, 116, 111, 32, 115, 97, 118, 101, 32, 115, 110, 97, 112, 115, 104, 111,
  116, 32, 111, 102, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116,
  32, 118, 105, 101, 119, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101,
  121, 115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81, 39, 32,
  116, 111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45, 45, 92,
  110, 10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  34, 10, 45, 118, 32, 45, 10, 45, 105, 91, 98, 111, 97, 114, 100, 93,
  32, 36, 49, 44, 36, 50, 32, 45, 114, 97, 110, 100, 91, 98, 111, 97,
  114, 100, 93, 32, 49, 44, 36, 51, 32, 45, 114, 111, 117, 110, 100, 91,
  98, 111, 97, 114, 100, 93, 32, 49, 10, 45, 105, 91, 117, 110, 100, 111,
  93, 32, 91, 45, 49, 93, 10, 45, 105, 91, 98, 97, 108, 108, 115, 93,
  32, 51, 50, 44, 51, 50, 44, 49, 44, 52, 32, 45, 95, 120, 95, 106,
  97, 119, 98, 114, 101, 97, 107, 101, 114, 95, 98, 97, 108, 108, 91, 45,
  49, 93, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93,
  32, 48, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 91, 45, 49,
  93, 32, 49, 44, 48, 32, 45, 42, 91, 45, 49, 93, 32, 49, 46, 53,
  32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 114,
  91, 45, 49, 93, 32, 123, 64, 123, 98, 111, 97, 114, 100, 44, 119, 125,
  42, 119, 125, 44, 123, 64, 123, 98, 111, 97, 114, 100, 44, 104, 125, 42,
  104, 125, 44, 49, 44, 49, 44, 48, 44, 50, 32, 45, 47, 91, 45, 49,
  93, 32, 50, 53, 53, 10, 45, 105, 91, 98, 97, 99, 107, 93, 32, 123,
  119, 125, 44, 123, 104, 125, 44, 49, 44, 51, 32, 45, 108, 91, 45, 49,
  93, 10, 45, 114, 97, 110, 100, 32, 48, 44, 50, 53, 53, 32, 45, 98,
  108, 117, 114, 95, 120, 121, 32, 54, 44, 50, 48, 32, 45, 101, 113, 117,
  97, 108, 105, 122, 101, 32, 49, 48, 48, 44, 48, 44, 50, 53, 53, 32,
  45, 98, 108, 117, 114, 95, 120, 121, 32, 50, 44, 52, 10, 45, 115, 104,
  32, 48, 44, 48, 32, 45, 115, 104, 91, 45, 50, 93, 32, 49, 44, 49,
  32, 45, 115, 104, 91, 45, 51, 93, 32, 50, 44, 50, 32, 45, 47, 91,
  45, 51, 93, 32, 52, 32, 45, 47, 91, 45, 50, 93, 32, 56, 32, 45,
  47, 91, 45, 49, 93, 32, 50, 32, 45, 114, 109, 91, 45, 51, 45, 45,
  49, 93, 10, 45, 101, 110, 100, 108, 10, 45, 105, 91, 118, 105, 115, 117,
  93, 32, 91, 98, 97, 99, 107, 93, 10, 115, 99, 111, 114, 101, 61, 48,
  10, 117, 110, 100, 111, 115, 99, 111, 114, 101, 61, 48, 10, 114, 101, 110,
  100, 101, 114, 95, 98, 111, 97, 114, 100, 61, 49, 10, 115, 104, 97, 112,
  101, 115, 99, 111, 114, 101, 121, 61, 48, 10, 115, 104, 97, 112, 101, 115,
  99, 111, 114, 101, 61, 48, 10, 45, 100, 111, 10, 45, 105, 102, 32, 36,
  114, 101, 110, 100, 101, 114, 95, 98, 111, 97, 114, 100, 10, 45, 45, 97,
  98, 115, 91, 98, 111, 97, 114, 100, 93, 32, 45, 45, 91, 45, 49, 93,
  32, 49, 32, 45, 42, 91, 45, 49, 93, 32, 123, 51, 54, 48, 47, 36,
  51, 125, 32, 45, 45, 103, 101, 91, 98, 111, 97, 114, 100, 93, 32, 48,
  32, 45, 42, 91, 45, 49, 93, 32, 48, 46, 57, 32, 45, 114, 91, 45,
  50, 44, 45, 49, 93, 32, 91, 98, 97, 108, 108, 115, 93, 32, 91, 98,
  97, 108, 108, 115, 93, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32,
  99, 32, 45, 104, 115, 118, 50, 114, 103, 98, 91, 45, 49, 93, 10, 45,
  45, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 91, 45, 49, 93, 32, 43, 32, 45, 103, 116, 91, 45, 49, 93, 32,
  48, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51, 10,
  45, 106, 91, 118, 105, 115, 117, 93, 32, 91, 98, 97, 99, 107, 93, 32,
  45, 106, 91, 118, 105, 115, 117, 93, 32, 91, 45, 50, 93, 44, 48, 44,
  48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 32, 45, 114, 109,
  91, 45, 50, 44, 45, 49, 93, 10, 45, 105, 102, 32, 123, 33, 36, 115,
  104, 97, 112, 101, 115, 99, 111, 114, 101, 121, 125, 32, 45, 119, 91, 118,
  105, 115, 117, 93, 32, 64, 123, 98, 97, 99, 107, 44, 119, 125, 44, 64,
  123, 98, 97, 99, 107, 44, 104, 125, 44, 48, 44, 34, 91, 71, 39, 77,
  73, 67, 93, 32, 74, 97, 119, 98, 114, 101, 97, 107, 101, 114, 32, 40,
  115, 99, 111, 114, 101, 32, 58, 32, 34, 36, 115, 99, 111, 114, 101, 34,
  41, 34, 32, 45, 101, 110, 100, 105, 102, 10, 114, 101, 110, 100, 101, 114,
  95, 98, 111, 97, 114, 100, 61, 48, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 36, 115, 104, 97, 112, 101, 115, 99, 111, 114, 101, 121,
  10, 45, 45, 116, 91, 118, 105, 115, 117, 93, 32, 34, 43, 34, 36, 115,
  104, 97, 112, 101, 115, 99, 111, 114, 101, 44, 64, 123, 33, 44, 120, 125,
  44, 123, 64, 123, 33, 44, 121, 125, 45, 54, 52, 43, 36, 115, 104, 97,
  112, 101, 115, 99, 111, 114, 101, 121, 125, 44, 51, 50, 44, 123, 40, 36,
  115, 104, 97, 112, 101, 115, 99, 111, 114, 101, 121, 45, 49, 41, 47, 51,
  49, 125, 44, 50, 53, 53, 10, 115, 104, 97, 112, 101, 115, 99, 111, 114,
  101, 121, 61, 123, 109, 97, 120, 40, 48, 44, 36, 115, 104, 97, 112, 101,
  115, 99, 111, 114, 101, 121, 45, 49, 41, 125, 10, 45, 119, 91, 45, 49,
  93, 32, 64, 123, 98, 97, 99, 107, 44, 119, 125, 44, 64, 123, 98, 97,
  99, 107, 44, 104, 125, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93,
  32, 74, 97, 119, 98, 114, 101, 97, 107, 101, 114, 32, 40, 115, 99, 111,
  114, 101, 32, 58, 32, 34, 36, 115, 99, 111, 114, 101, 34, 41, 34, 32,
  45, 114, 109, 91, 45, 49, 93, 32, 45, 119, 97, 105, 116, 32, 50, 53,
  10, 45, 101, 108, 115, 101, 32, 45, 119, 97, 105, 116, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 45, 102, 91, 98, 111, 97, 114, 100, 93, 32, 34,
  105, 102, 40, 105, 44, 106, 40, 45, 49, 41, 61, 61, 105, 32, 124, 124,
  32, 106, 40, 49, 41, 61, 61, 105, 32, 124, 124, 32, 106, 40, 48, 44,
  49, 41, 61, 61, 105, 32, 124, 124, 32, 106, 40, 48, 44, 45, 49, 41,
  61, 61, 105, 44, 48, 41, 34, 10, 45, 105, 102, 32, 123, 33, 64, 123,
  45, 49, 44, 43, 125, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  98, 114, 101, 97, 107, 32, 45, 101, 110, 100, 105, 102, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 105, 102, 32, 64, 123, 33, 44, 114, 125, 32,
  114, 101, 110, 100, 101, 114, 95, 98, 111, 97, 114, 100, 61, 49, 10, 45,
  101, 108, 105, 102, 32, 64, 123, 33, 44, 83, 125, 32, 45, 111, 91, 118,
  105, 115, 117, 93, 32, 103, 109, 105, 99, 95, 106, 97, 119, 98, 114, 101,
  97, 107, 101, 114, 46, 112, 110, 103, 10, 45, 101, 108, 105, 102, 32, 123,
  64, 123, 33, 44, 66, 65, 67, 75, 83, 80, 65, 67, 69, 125, 34, 32,
  124, 124, 32, 34, 64, 123, 33, 44, 83, 80, 65, 67, 69, 125, 125, 10,
  45, 97, 98, 115, 91, 117, 110, 100, 111, 93, 32, 45, 106, 91, 98, 111,
  97, 114, 100, 93, 32, 91, 117, 110, 100, 111, 93, 10, 115, 99, 111, 114,
  101, 61, 36, 117, 110, 100, 111, 115, 99, 111, 114, 101, 10, 114, 101, 110,
  100, 101, 114, 95, 98, 111, 97, 114, 100, 61, 49, 10, 45, 101, 108, 105,
  102, 32, 123, 64, 123, 33, 44, 120, 125, 34, 62, 61, 48, 32, 38, 38,
  32, 34, 64, 123, 33, 44, 98, 125, 125, 10, 45, 119, 97, 105, 116, 32,
  45, 49, 10, 120, 61, 123, 34, 105, 110, 116, 40, 34, 64, 123, 33, 44,
  120, 125, 34, 42, 34, 64, 123, 98, 111, 97, 114, 100, 44, 119, 125, 34,
  47, 34, 64, 123, 33, 44, 119, 125, 34, 41, 34, 125, 10, 121, 61, 123,
  34, 105, 110, 116, 40, 34, 64, 123, 33, 44, 121, 125, 34, 42, 34, 64,
  123, 98, 111, 97, 114, 100, 44, 104, 125, 34, 47, 34, 64, 123, 33, 44,
  104, 125, 34, 41, 34, 125, 10, 45, 105, 102, 32, 123, 64, 123, 98, 111,
  97, 114, 100, 44, 40, 36, 120, 44, 36, 121, 41, 125, 62, 48, 125, 10,
  45, 97, 98, 115, 91, 98, 111, 97, 114, 100, 93, 32, 45, 102, 108, 111,
  111, 100, 91, 98, 111, 97, 114, 100, 93, 32, 36, 120, 44, 36, 121, 44,
  48, 44, 48, 44, 48, 44, 49, 44, 45, 64, 123, 98, 111, 97, 114, 100,
  44, 40, 36, 120, 44, 36, 121, 41, 125, 10, 45, 45, 103, 101, 91, 98,
  111, 97, 114, 100, 93, 32, 48, 32, 45, 45, 91, 45, 49, 93, 32, 49,
  10, 115, 104, 97, 112, 101, 115, 99, 111, 114, 101, 61, 123, 40, 64, 123,
  45, 49, 44, 43, 125, 43, 49, 41, 94, 50, 125, 32, 115, 104, 97, 112,
  101, 115, 99, 111, 114, 101, 121, 61, 123, 105, 102, 40, 36, 115, 104, 97,
  112, 101, 115, 99, 111, 114, 101, 44, 51, 50, 44, 48, 41, 125, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 105, 102, 32, 64, 123, 98,
  111, 97, 114, 100, 44, 40, 36, 120, 44, 36, 121, 41, 125, 10, 45, 45,
  102, 108, 111, 111, 100, 91, 98, 111, 97, 114, 100, 93, 32, 36, 120, 44,
  36, 121, 44, 48, 44, 48, 44, 48, 44, 49, 44, 45, 49, 32, 45, 61,
  61, 91, 45, 49, 93, 32, 45, 49, 10, 45, 105, 102, 32, 123, 64, 123,
  45, 49, 44, 43, 125, 62, 49, 125, 10, 45, 106, 91, 117, 110, 100, 111,
  93, 32, 91, 98, 111, 97, 114, 100, 93, 10, 117, 110, 100, 111, 115, 99,
  111, 114, 101, 61, 36, 115, 99, 111, 114, 101, 10, 45, 102, 108, 111, 111,
  100, 91, 98, 111, 97, 114, 100, 93, 32, 36, 120, 44, 36, 121, 44, 48,
  44, 48, 44, 48, 44, 49, 44, 48, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 123, 98, 111, 97, 114, 100, 44, 119, 125, 10, 45, 45, 99, 111,
  108, 117, 109, 110, 115, 91, 98, 111, 97, 114, 100, 93, 32, 36, 62, 32,
  45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 121, 10, 104, 61,
  64, 123, 98, 111, 97, 114, 100, 44, 104, 125, 32, 45, 108, 91, 45, 49,
  93, 32, 45, 115, 32, 45, 44, 48, 32, 45, 97, 32, 121, 32, 45, 105,
  102, 32, 64, 35, 32, 45, 114, 32, 49, 44, 36, 104, 44, 49, 44, 49,
  44, 48, 32, 45, 109, 105, 114, 114, 111, 114, 32, 121, 32, 45, 101, 108,
  115, 101, 32, 45, 105, 32, 49, 44, 36, 104, 32, 45, 101, 110, 100, 105,
  102, 32, 45, 101, 110, 100, 108, 10, 45, 106, 91, 98, 111, 97, 114, 100,
  93, 32, 91, 45, 49, 93, 44, 36, 62, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 100, 111, 110, 101, 10, 45, 114, 111, 119, 115, 91, 98, 111,
  97, 114, 100, 93, 32, 45, 49, 44, 49, 48, 48, 37, 32, 45, 102, 91,
  98, 111, 97, 114, 100, 93, 32, 34, 105, 102, 40, 121, 61, 61, 48, 44,
  105, 102, 40, 105, 40, 120, 44, 104, 45, 49, 41, 44, 120, 44, 119, 41,
  44, 105, 41, 34, 32, 45, 115, 111, 114, 116, 91, 98, 111, 97, 114, 100,
  93, 32, 43, 44, 120, 32, 45, 114, 111, 119, 115, 91, 98, 111, 97, 114,
  100, 93, 32, 49, 44, 49, 48, 48, 37, 10, 115, 99, 111, 114, 101, 61,
  123, 36, 115, 99, 111, 114, 101, 43, 105, 110, 116, 40, 40, 64, 123, 45,
  49, 44, 43, 125, 45, 49, 41, 94, 50, 41, 125, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 115, 101,
  32, 45, 97, 98, 115, 91, 98, 111, 97, 114, 100, 93, 10, 45, 101, 110,
  100, 105, 102, 10, 114, 101, 110, 100, 101, 114, 95, 98, 111, 97, 114, 100,
  61, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 119, 104, 105, 108, 101,
  32, 123, 64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81,
  125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67, 125,
  125, 10, 45, 105, 102, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34, 33,
  64, 123, 33, 44, 69, 83, 67, 125, 125, 10, 45, 119, 91, 93, 32, 64,
  123, 118, 105, 115, 117, 44, 119, 125, 44, 64, 123, 118, 105, 115, 117, 44,
  104, 125, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 74, 97,
  119, 98, 114, 101, 97, 107, 101, 114, 32, 40, 102, 105, 110, 97, 108, 32,
  115, 99, 111, 114, 101, 32, 58, 32, 34, 36, 115, 99, 111, 114, 101, 34,
  41, 34, 10, 45, 105, 91, 103, 97, 109, 101, 111, 118, 101, 114, 93, 32,
  50, 51, 48, 44, 56, 53, 32, 45, 116, 91, 45, 49, 93, 32, 34, 71,
  97, 109, 101, 32, 79, 118, 101, 114, 33, 34, 44, 51, 44, 48, 44, 53,
  55, 44, 49, 44, 49, 32, 45, 116, 91, 45, 49, 93, 32, 34, 83, 99,
  111, 114, 101, 32, 58, 32, 34, 36, 115, 99, 111, 114, 101, 44, 50, 52,
  44, 53, 52, 44, 51, 50, 44, 49, 44, 49, 10, 45, 45, 100, 105, 108,
  97, 116, 101, 91, 45, 49, 93, 32, 53, 32, 45, 110, 109, 91, 45, 49,
  93, 32, 34, 109, 103, 97, 109, 101, 111, 118, 101, 114, 34, 32, 45, 42,
  91, 45, 50, 93, 32, 50, 53, 53, 32, 45, 114, 91, 45, 50, 93, 32,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 51, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 50, 53, 10, 45, 45, 114, 91, 103, 97, 109,
  101, 111, 118, 101, 114, 44, 109, 103, 97, 109, 101, 111, 118, 101, 114, 93,
  32, 123, 52, 48, 48, 45, 49, 50, 42, 40, 36, 62, 43, 49, 41, 125,
  37, 44, 123, 52, 48, 48, 45, 49, 50, 42, 40, 36, 62, 43, 49, 41,
  125, 37, 10, 45, 45, 106, 91, 118, 105, 115, 117, 93, 32, 91, 45, 50,
  93, 44, 123, 40, 64, 123, 118, 105, 115, 117, 44, 119, 125, 45, 119, 41,
  47, 50, 125, 44, 123, 40, 64, 123, 118, 105, 115, 117, 44, 104, 125, 45,
  104, 41, 47, 50, 125, 44, 48, 44, 48, 44, 123, 36, 62, 47, 50, 53,
  125, 44, 91, 45, 49, 93, 10, 45, 119, 91, 45, 49, 93, 32, 45, 114,
  109, 91, 45, 51, 45, 45, 49, 93, 32, 45, 119, 97, 105, 116, 32, 50,
  53, 10, 45, 100, 111, 110, 101, 10, 45, 100, 111, 10, 45, 119, 97, 105,
  116, 32, 45, 105, 102, 32, 64, 123, 33, 44, 114, 125, 32, 45, 119, 91,
  93, 32, 64, 123, 33, 44, 119, 125, 44, 64, 123, 33, 44, 104, 125, 32,
  45, 119, 97, 105, 116, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34,
  33, 64, 123, 33, 44, 81, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123,
  33, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33,
  44, 98, 125, 125, 10, 45, 114, 109, 91, 103, 97, 109, 101, 111, 118, 101,
  114, 44, 109, 103, 97, 109, 101, 111, 118, 101, 114, 93, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 114, 109, 91, 98, 111, 97, 114, 100, 44, 117, 110,
  100, 111, 44, 98, 97, 108, 108, 115, 44, 98, 97, 99, 107, 44, 118, 105,
  115, 117, 93, 10, 45, 119, 32, 48, 32, 45, 118, 32, 43, 10, 95, 120,
  95, 106, 97, 119, 98, 114, 101, 97, 107, 101, 114, 95, 98, 97, 108, 108,
  32, 58, 10, 109, 119, 104, 61, 123, 109, 105, 110, 40, 119, 44, 104, 41,
  125, 10, 45, 115, 104, 32, 51, 44, 51, 32, 45, 102, 91, 45, 49, 93,
  32, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 108, 105,
  112, 115, 101, 32, 123, 48, 46, 53, 42, 36, 109, 119, 104, 125, 44, 123,
  48, 46, 53, 42, 36, 109, 119, 104, 125, 44, 123, 48, 46, 53, 42, 36,
  109, 119, 104, 45, 52, 125, 44, 123, 48, 46, 53, 42, 36, 109, 119, 104,
  45, 52, 125, 44, 48, 44, 49, 44, 50, 52, 48, 44, 50, 52, 48, 44,
  50, 52, 48, 44, 49, 10, 45, 115, 104, 32, 48, 44, 50, 32, 45, 42,
  91, 45, 49, 93, 32, 39, 40, 36, 109, 119, 104, 43, 121, 45, 120, 41,
  47, 40, 50, 42, 119, 41, 39, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 101, 108, 108, 105, 112, 115, 101, 32, 123, 36, 109, 119, 104, 42, 48,
  46, 55, 125, 44, 123, 36, 109, 119, 104, 42, 48, 46, 51, 125, 44, 123,
  109, 105, 110, 40, 51, 48, 44, 36, 109, 119, 104, 42, 36, 109, 119, 104,
  47, 53, 49, 50, 41, 125, 44, 123, 109, 105, 110, 40, 51, 48, 44, 36,
  109, 119, 104, 42, 36, 109, 119, 104, 47, 53, 49, 50, 41, 125, 44, 48,
  44, 123, 109, 105, 110, 40, 36, 109, 119, 104, 47, 54, 52, 44, 49, 41,
  125, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 49, 10,
  45, 115, 104, 32, 48, 44, 50, 32, 45, 98, 91, 45, 49, 93, 32, 123,
  48, 46, 48, 50, 42, 36, 109, 119, 104, 125, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 115, 104, 32, 51, 44, 51, 32, 45, 42, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45,
  49, 93, 32, 51, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104,
  32, 48, 44, 50, 32, 45, 43, 91, 45, 49, 93, 32, 39, 105, 102, 40,
  105, 38, 38, 40, 33, 106, 40, 45, 49, 41, 124, 124, 33, 106, 40, 49,
  41, 124, 124, 33, 106, 40, 48, 44, 45, 49, 41, 124, 124, 33, 106, 40,
  48, 44, 49, 41, 41, 44, 50, 52, 48, 47, 54, 44, 48, 41, 39, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 120, 95, 108, 105, 102, 101, 32, 58,
  10, 45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45,
  32, 84, 104, 101, 32, 103, 97, 109, 101, 32, 111, 102, 32, 108, 105, 102,
  101, 32, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 92,
  110, 10, 45, 45, 45, 45, 32, 84, 104, 101, 32, 103, 111, 97, 108, 32,
  105, 115, 32, 116, 111, 32, 99, 114, 101, 97, 116, 101, 32, 116, 104, 101,
  32, 98, 105, 103, 103, 101, 115, 116, 32, 112, 111, 115, 115, 105, 98, 108,
  101, 32, 98, 105, 111, 108, 111, 103, 105, 99, 97, 108, 92, 110, 10, 45,
  45, 45, 45, 32, 115, 121, 115, 116, 101, 109, 46, 32, 89, 111, 117, 32,
  115, 116, 97, 114, 116, 32, 119, 105, 116, 104, 32, 97, 32, 115, 116, 111,
  99, 107, 32, 111, 102, 32, 99, 101, 108, 108, 115, 32, 119, 104, 105, 99,
  104, 32, 121, 111, 117, 32, 99, 97, 110, 92, 110, 10, 45, 45, 45, 45,
  32, 115, 112, 114, 101, 97, 100, 32, 111, 118, 101, 114, 32, 116, 104, 101,
  32, 98, 111, 97, 114, 100, 46, 32, 70, 111, 114, 32, 101, 97, 99, 104,
  32, 110, 101, 119, 32, 99, 101, 108, 108, 115, 32, 99, 114, 101, 97, 116,
  101, 100, 92, 110, 10, 45, 45, 45, 45, 32, 115, 105, 109, 117, 108, 116,
  97, 110, 101, 111, 117, 115, 108, 121, 32, 97, 110, 100, 32, 115, 112, 111,
  110, 116, 97, 110, 101, 111, 117, 115, 108, 121, 32, 98, 121, 32, 121, 111,
  117, 114, 32, 115, 121, 115, 116, 101, 109, 44, 32, 121, 111, 117, 92, 110,
  10, 45, 45, 45, 45, 32, 103, 97, 105, 110, 32, 109, 111, 114, 101, 32,
  110, 101, 119, 32, 99, 101, 108, 108, 115, 32, 116, 111, 32, 115, 99, 97,
  116, 116, 101, 114, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45,
  45, 45, 45, 32, 76, 101, 102, 116, 32, 109, 111, 117, 115, 101, 32, 98,
  117, 116, 116, 111, 110, 32, 116, 111, 32, 115, 99, 97, 116, 116, 101, 114,
  32, 99, 101, 108, 108, 115, 32, 105, 110, 32, 115, 116, 111, 99, 107, 46,
  92, 110, 10, 45, 45, 45, 45, 32, 82, 105, 103, 104, 116, 32, 109, 111,
  117, 115, 101, 32, 98, 117, 116, 116, 111, 110, 32, 116, 111, 32, 114, 101,
  115, 101, 116, 32, 103, 97, 109, 101, 46, 92, 110, 10, 45, 45, 45, 45,
  32, 75, 101, 121, 32, 39, 83, 39, 32, 116, 111, 32, 115, 97, 118, 101,
  32, 115, 110, 97, 112, 115, 104, 111, 116, 32, 111, 102, 32, 116, 104, 101,
  32, 99, 117, 114, 114, 101, 110, 116, 32, 118, 105, 101, 119, 46, 92, 110,
  10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 69, 83, 67, 39,
  32, 111, 114, 32, 39, 81, 39, 32, 116, 111, 32, 101, 120, 105, 116, 46,
  92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 10, 45,
  105, 91, 48, 93, 32, 57, 48, 44, 57, 48, 44, 49, 44, 49, 44, 48,
  10, 45, 105, 91, 49, 93, 32, 91, 48, 93, 32, 45, 102, 91, 49, 93,
  32, 48, 10, 45, 105, 91, 50, 93, 32, 52, 48, 48, 44, 52, 48, 48,
  44, 49, 44, 51, 10, 45, 105, 91, 51, 93, 32, 49, 10, 105, 116, 101,
  114, 97, 116, 105, 111, 110, 61, 48, 10, 115, 99, 111, 114, 101, 61, 48,
  10, 98, 101, 115, 116, 115, 99, 111, 114, 101, 61, 48, 10, 115, 116, 111,
  99, 107, 61, 53, 48, 48, 10, 45, 119, 91, 48, 93, 32, 52, 48, 48,
  44, 52, 48, 48, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32,
  84, 104, 101, 32, 103, 97, 109, 101, 32, 111, 102, 32, 108, 105, 102, 101,
  34, 10, 45, 99, 117, 114, 115, 111, 114, 91, 48, 93, 32, 48, 10, 45,
  100, 111, 10, 40, 49, 44, 49, 44, 49, 59, 49, 44, 48, 44, 49, 59,
  49, 44, 49, 44, 49, 41, 32, 45, 45, 99, 111, 114, 114, 101, 108, 97,
  116, 101, 91, 48, 93, 32, 91, 45, 49, 93, 44, 48, 32, 45, 114, 109,
  91, 45, 50, 93, 10, 45, 45, 116, 50, 91, 45, 49, 93, 32, 50, 44,
  50, 32, 45, 97, 110, 100, 91, 45, 49, 93, 32, 91, 48, 93, 32, 45,
  116, 50, 91, 45, 50, 93, 32, 51, 44, 51, 32, 45, 111, 114, 91, 45,
  50, 44, 45, 49, 93, 10, 45, 114, 118, 91, 48, 44, 45, 49, 93, 10,
  45, 105, 102, 32, 123, 64, 123, 33, 44, 120, 125, 62, 48, 34, 32, 38,
  38, 32, 34, 64, 123, 33, 44, 98, 125, 61, 61, 49, 34, 32, 38, 38,
  32, 34, 36, 115, 116, 111, 99, 107, 62, 48, 125, 10, 110, 98, 61, 123,
  63, 42, 55, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 110, 98,
  10, 120, 61, 123, 64, 123, 33, 44, 120, 125, 47, 64, 123, 33, 44, 119,
  125, 42, 64, 123, 48, 44, 119, 125, 43, 63, 40, 45, 52, 44, 52, 41,
  125, 10, 121, 61, 123, 64, 123, 33, 44, 121, 125, 47, 64, 123, 33, 44,
  104, 125, 42, 64, 123, 48, 44, 104, 125, 43, 63, 40, 45, 51, 44, 51,
  41, 125, 10, 45, 61, 91, 48, 93, 32, 49, 44, 36, 120, 44, 36, 121,
  10, 45, 61, 91, 49, 93, 32, 36, 105, 116, 101, 114, 97, 116, 105, 111,
  110, 44, 36, 120, 44, 36, 121, 10, 45, 112, 111, 105, 110, 116, 91, 50,
  93, 32, 123, 36, 120, 42, 64, 123, 50, 44, 119, 125, 47, 64, 123, 48,
  44, 119, 125, 125, 44, 123, 36, 121, 42, 64, 123, 50, 44, 104, 125, 47,
  64, 123, 48, 44, 104, 125, 125, 44, 48, 44, 48, 46, 56, 44, 50, 53,
  53, 10, 45, 100, 111, 110, 101, 10, 115, 116, 111, 99, 107, 61, 123, 114,
  111, 117, 110, 100, 40, 109, 97, 120, 40, 48, 44, 36, 115, 116, 111, 99,
  107, 45, 36, 110, 98, 41, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 45, 91, 45, 49, 93, 32, 91, 48, 93, 32, 45, 42, 91, 45, 49,
  93, 32, 45, 49, 10, 115, 116, 111, 99, 107, 61, 123, 36, 115, 116, 111,
  99, 107, 45, 50, 42, 40, 109, 105, 110, 40, 48, 44, 105, 110, 116, 40,
  64, 123, 45, 49, 44, 43, 125, 47, 49, 54, 42, 36, 115, 99, 111, 114,
  101, 47, 49, 53, 48, 41, 41, 41, 125, 10, 45, 43, 91, 49, 93, 32,
  91, 48, 93, 10, 45, 109, 105, 110, 91, 45, 49, 93, 32, 48, 32, 45,
  43, 91, 45, 49, 93, 32, 49, 32, 45, 42, 91, 49, 44, 45, 49, 93,
  10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 98, 125, 61, 61, 50, 125,
  10, 45, 102, 91, 48, 45, 50, 93, 32, 48, 32, 105, 116, 101, 114, 97,
  116, 105, 111, 110, 61, 48, 32, 115, 99, 111, 114, 101, 61, 48, 32, 98,
  101, 115, 116, 115, 99, 111, 114, 101, 61, 48, 32, 115, 116, 111, 99, 107,
  61, 53, 48, 48, 32, 45, 114, 109, 91, 51, 93, 32, 45, 105, 91, 51,
  93, 32, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  64, 123, 51, 44, 119, 125, 61, 61, 49, 125, 10, 45, 114, 109, 91, 51,
  93, 32, 45, 105, 91, 51, 93, 32, 123, 63, 40, 51, 44, 49, 50, 41,
  125, 44, 49, 44, 49, 44, 51, 44, 63, 40, 49, 48, 48, 44, 50, 53,
  53, 41, 10, 45, 114, 91, 51, 93, 32, 123, 63, 40, 49, 48, 48, 44,
  51, 48, 48, 41, 125, 37, 44, 49, 44, 49, 44, 51, 44, 52, 10, 45,
  112, 111, 105, 110, 116, 91, 51, 93, 32, 48, 44, 48, 44, 48, 44, 49,
  44, 48, 10, 45, 114, 91, 51, 93, 32, 123, 63, 40, 49, 48, 48, 44,
  54, 48, 48, 41, 125, 37, 44, 49, 44, 49, 44, 51, 44, 53, 32, 45,
  99, 91, 51, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 45, 114, 91, 49, 93, 32, 64, 123, 50, 44, 119, 125, 44,
  64, 123, 50, 44, 104, 125, 32, 45, 97, 110, 100, 91, 45, 49, 93, 32,
  55, 32, 45, 98, 91, 45, 49, 93, 32, 123, 49, 43, 36, 115, 99, 111,
  114, 101, 42, 48, 46, 48, 53, 125, 10, 45, 110, 91, 45, 49, 93, 32,
  48, 44, 64, 123, 51, 44, 119, 125, 32, 45, 109, 97, 112, 91, 45, 49,
  93, 32, 91, 51, 93, 32, 45, 42, 91, 45, 49, 93, 32, 48, 46, 49,
  32, 45, 43, 91, 50, 44, 45, 49, 93, 32, 45, 47, 91, 50, 93, 32,
  49, 46, 49, 10, 91, 50, 93, 32, 45, 105, 102, 32, 123, 64, 123, 33,
  44, 120, 125, 62, 48, 125, 10, 111, 112, 97, 99, 61, 123, 48, 46, 55,
  42, 109, 105, 110, 40, 49, 44, 36, 115, 116, 111, 99, 107, 47, 53, 48,
  48, 41, 125, 32, 114, 61, 123, 109, 105, 110, 40, 53, 48, 48, 44, 36,
  115, 116, 111, 99, 107, 41, 42, 99, 111, 115, 40, 36, 105, 116, 101, 114,
  97, 116, 105, 111, 110, 41, 47, 49, 48, 48, 125, 10, 45, 101, 108, 108,
  105, 112, 115, 101, 91, 45, 49, 93, 32, 64, 123, 33, 44, 120, 125, 44,
  64, 123, 33, 44, 121, 125, 44, 123, 49, 53, 43, 36, 114, 125, 44, 123,
  49, 53, 43, 36, 114, 125, 44, 48, 44, 36, 111, 112, 97, 99, 44, 48,
  44, 49, 57, 54, 44, 48, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91,
  45, 49, 93, 32, 64, 123, 33, 44, 120, 125, 44, 64, 123, 33, 44, 121,
  125, 44, 123, 49, 48, 43, 36, 114, 125, 44, 123, 49, 48, 43, 36, 114,
  125, 44, 48, 44, 36, 111, 112, 97, 99, 44, 51, 50, 44, 54, 52, 44,
  49, 54, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32,
  64, 123, 33, 44, 120, 125, 44, 64, 123, 33, 44, 121, 125, 44, 123, 53,
  43, 36, 114, 125, 44, 123, 53, 43, 36, 114, 125, 44, 48, 44, 36, 111,
  112, 97, 99, 44, 50, 53, 53, 44, 50, 51, 48, 44, 48, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 116, 91, 45, 49, 93, 32, 34, 76, 105, 118,
  105, 110, 103, 32, 99, 101, 108, 108, 115, 32, 58, 32, 34, 36, 115, 99,
  111, 114, 101, 34, 92, 110, 34, 92, 10, 34, 83, 116, 111, 99, 107, 32,
  58, 32, 34, 36, 115, 116, 111, 99, 107, 34, 92, 110, 34, 92, 10, 34,
  83, 99, 111, 114, 101, 32, 58, 32, 34, 36, 98, 101, 115, 116, 115, 99,
  111, 114, 101, 44, 53, 44, 51, 44, 50, 50, 44, 48, 46, 55, 44, 50,
  53, 53, 10, 45, 119, 91, 45, 49, 93, 32, 64, 123, 33, 44, 119, 125,
  44, 64, 123, 33, 44, 104, 125, 10, 45, 105, 102, 32, 64, 123, 33, 44,
  83, 125, 32, 45, 111, 91, 45, 49, 93, 32, 103, 109, 105, 99, 95, 108,
  105, 102, 101, 46, 112, 110, 103, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 33, 40, 36, 105,
  116, 101, 114, 97, 116, 105, 111, 110, 37, 49, 48, 41, 125, 32, 115, 99,
  111, 114, 101, 61, 64, 123, 48, 44, 43, 125, 32, 98, 101, 115, 116, 115,
  99, 111, 114, 101, 61, 123, 109, 97, 120, 40, 36, 115, 99, 111, 114, 101,
  44, 36, 98, 101, 115, 116, 115, 99, 111, 114, 101, 41, 125, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 119, 97, 105, 116, 32, 54, 48, 10, 105, 116,
  101, 114, 97, 116, 105, 111, 110, 61, 123, 36, 105, 116, 101, 114, 97, 116,
  105, 111, 110, 43, 49, 125, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64,
  33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67, 125,
  34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125, 10, 45,
  114, 109, 91, 48, 45, 51, 93, 32, 45, 119, 32, 48, 32, 45, 118, 32,
  43, 10, 120, 95, 108, 105, 103, 104, 116, 32, 58, 10, 45, 101, 91, 93,
  32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 76, 105, 103, 104,
  116, 32, 101, 102, 102, 101, 99, 116, 32, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92,
  110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32, 77, 111,
  118, 101, 32, 108, 105, 103, 104, 116, 32, 112, 111, 115, 105, 116, 105, 111,
  110, 32, 119, 105, 116, 104, 32, 109, 111, 117, 115, 101, 46, 92, 110, 10,
  45, 45, 45, 45, 32, 77, 111, 117, 115, 101, 32, 98, 117, 116, 116, 111,
  110, 115, 32, 102, 97, 100, 101, 32, 108, 105, 103, 104, 116, 32, 105, 110,
  47, 111, 117, 116, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121,
  115, 32, 39, 67, 84, 82, 76, 43, 68, 39, 32, 116, 111, 32, 100, 111,
  117, 98, 108, 101, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101,
  46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67,
  84, 82, 76, 43, 67, 39, 32, 116, 111, 32, 114, 101, 115, 101, 116, 32,
  119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45,
  45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32, 111,
  114, 32, 39, 81, 39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92, 110,
  10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 34, 10, 45, 118, 32, 45, 10, 48, 32, 45, 116, 91, 45, 49, 93,
  32, 34, 32, 32, 32, 32, 71, 39, 77, 73, 67, 92, 110, 76, 105, 103,
  104, 116, 32, 101, 102, 102, 101, 99, 116, 34, 44, 48, 44, 48, 44, 53,
  55, 44, 49, 44, 50, 53, 53, 32, 45, 101, 120, 112, 97, 110, 100, 95,
  120, 121, 91, 45, 49, 93, 32, 49, 53, 44, 48, 32, 45, 98, 91, 45,
  49, 93, 32, 51, 10, 91, 45, 49, 93, 32, 45, 110, 91, 45, 50, 93,
  32, 48, 44, 49, 32, 45, 114, 91, 45, 50, 93, 32, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 44, 51, 10, 45, 115, 104, 91, 45, 50,
  93, 32, 48, 44, 48, 32, 45, 42, 91, 45, 49, 93, 32, 49, 50, 48,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 45, 50, 93,
  32, 49, 44, 49, 32, 45, 42, 91, 45, 49, 93, 32, 55, 48, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 45, 50, 93, 32, 48,
  44, 53, 48, 37, 44, 48, 44, 50, 32, 45, 42, 91, 45, 49, 93, 32,
  49, 50, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 50, 53, 37, 44,
  50, 53, 37, 44, 49, 44, 49, 32, 45, 114, 97, 110, 100, 91, 45, 49,
  93, 32, 45, 50, 48, 44, 50, 48, 32, 45, 115, 109, 111, 111, 116, 104,
  91, 45, 49, 93, 32, 49, 48, 44, 48, 44, 49, 44, 49, 44, 52, 32,
  45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 51, 32, 45, 98,
  91, 45, 49, 93, 32, 51, 32, 45, 110, 91, 45, 49, 93, 32, 45, 54,
  48, 44, 54, 48, 10, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  103, 91, 45, 49, 93, 32, 120, 121, 32, 45, 97, 91, 45, 50, 44, 45,
  49, 93, 32, 99, 32, 45, 110, 91, 45, 49, 93, 32, 45, 49, 53, 48,
  44, 49, 53, 48, 10, 45, 119, 91, 93, 32, 123, 49, 46, 53, 42, 64,
  123, 45, 50, 44, 119, 125, 125, 44, 123, 49, 46, 53, 42, 64, 123, 45,
  50, 44, 104, 125, 125, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93,
  32, 76, 105, 103, 104, 116, 32, 101, 102, 102, 101, 99, 116, 34, 10, 45,
  99, 117, 114, 115, 111, 114, 91, 48, 93, 32, 48, 10, 108, 105, 103, 104,
  116, 61, 55, 48, 10, 53, 49, 50, 44, 53, 49, 50, 32, 45, 103, 97,
  117, 115, 115, 105, 97, 110, 91, 45, 49, 93, 32, 36, 108, 105, 103, 104,
  116, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 116,
  61, 48, 10, 45, 100, 111, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44,
  120, 125, 62, 61, 48, 125, 10, 88, 61, 123, 114, 111, 117, 110, 100, 40,
  40, 119, 45, 64, 123, 33, 44, 120, 125, 41, 47, 50, 41, 125, 10, 89,
  61, 123, 114, 111, 117, 110, 100, 40, 40, 104, 45, 64, 123, 33, 44, 121,
  125, 41, 47, 50, 41, 125, 10, 45, 101, 108, 115, 101, 10, 88, 61, 123,
  114, 111, 117, 110, 100, 40, 40, 119, 45, 64, 123, 45, 50, 44, 119, 125,
  42, 40, 49, 43, 99, 111, 115, 40, 50, 42, 36, 116, 41, 41, 41, 47,
  50, 41, 125, 10, 89, 61, 123, 114, 111, 117, 110, 100, 40, 40, 104, 45,
  64, 123, 45, 50, 44, 104, 125, 42, 40, 49, 43, 115, 105, 110, 40, 50,
  46, 53, 42, 36, 116, 41, 41, 41, 47, 50, 41, 125, 10, 116, 61, 123,
  36, 116, 43, 48, 46, 48, 50, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 64, 123, 33, 44, 98, 125, 38, 49, 125, 32, 108,
  105, 103, 104, 116, 61, 123, 109, 105, 110, 40, 50, 48, 48, 44, 36, 108,
  105, 103, 104, 116, 43, 49, 48, 41, 125, 32, 45, 103, 97, 117, 115, 115,
  105, 97, 110, 91, 45, 49, 93, 32, 36, 108, 105, 103, 104, 116, 32, 45,
  110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 98, 125, 38, 50,
  125, 32, 108, 105, 103, 104, 116, 61, 123, 109, 97, 120, 40, 49, 48, 44,
  36, 108, 105, 103, 104, 116, 45, 49, 48, 41, 125, 32, 45, 103, 97, 117,
  115, 115, 105, 97, 110, 91, 45, 49, 93, 32, 36, 108, 105, 103, 104, 116,
  32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 45, 122, 91, 45, 49, 93, 32, 36, 88, 44,
  36, 89, 44, 123, 36, 88, 43, 64, 123, 45, 50, 44, 119, 125, 45, 49,
  125, 44, 123, 36, 89, 43, 64, 123, 45, 50, 44, 104, 125, 45, 49, 125,
  10, 45, 119, 97, 114, 112, 91, 45, 49, 93, 32, 91, 45, 51, 93, 44,
  49, 44, 48, 44, 49, 10, 45, 114, 91, 45, 49, 93, 32, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 49, 44, 51, 32, 45, 43, 91, 45, 49,
  93, 32, 91, 45, 52, 93, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 10, 45, 119, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123,
  64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64,
  123, 33, 44, 68, 125, 125, 32, 45, 119, 91, 93, 32, 123, 51, 42, 119,
  125, 44, 123, 51, 42, 104, 125, 10, 45, 101, 108, 105, 102, 32, 123, 64,
  123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123,
  33, 44, 67, 125, 125, 32, 45, 119, 91, 93, 32, 123, 49, 46, 53, 42,
  119, 125, 44, 123, 49, 46, 53, 42, 104, 125, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 105, 102, 32, 123, 64,
  123, 33, 44, 120, 125, 62, 61, 48, 34, 32, 38, 38, 32, 34, 33, 64,
  123, 33, 44, 98, 125, 125, 32, 45, 119, 97, 105, 116, 32, 45, 101, 108,
  115, 101, 32, 45, 119, 97, 105, 116, 32, 50, 48, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34, 32, 38,
  38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67, 125, 34, 32, 38, 38,
  32, 34, 33, 64, 123, 33, 44, 81, 125, 125, 10, 45, 119, 91, 93, 32,
  48, 32, 45, 114, 109, 91, 45, 51, 45, 45, 49, 93, 32, 45, 118, 32,
  43, 10, 120, 95, 109, 97, 110, 100, 101, 108, 98, 114, 111, 116, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 125, 44, 36, 123,
  50, 61, 48, 46, 51, 49, 55, 125, 44, 36, 123, 51, 61, 48, 46, 48,
  51, 125, 10, 45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45,
  45, 45, 32, 77, 97, 110, 100, 101, 108, 98, 114, 111, 116, 47, 74, 117,
  108, 105, 97, 32, 101, 120, 112, 108, 111, 114, 101, 114, 32, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110,
  10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32, 83, 101, 108,
  101, 99, 116, 32, 122, 111, 111, 109, 105, 110, 103, 32, 114, 101, 103, 105,
  111, 110, 32, 119, 105, 116, 104, 32, 109, 111, 117, 115, 101, 46, 92, 110,
  10, 45, 45, 45, 45, 32, 67, 108, 105, 99, 107, 32, 111, 110, 99, 101,
  32, 116, 111, 32, 114, 101, 115, 101, 116, 32, 122, 111, 111, 109, 32, 102,
  97, 99, 116, 111, 114, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101,
  121, 115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81, 39, 32,
  116, 111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45, 45, 32,
  75, 101, 121, 32, 39, 67, 39, 32, 116, 111, 32, 112, 114, 105, 110, 116,
  32, 99, 117, 114, 114, 101, 110, 116, 32, 102, 114, 97, 99, 116, 97, 108,
  32, 99, 111, 111, 114, 100, 105, 110, 97, 116, 101, 115, 46, 92, 110, 10,
  45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 10,
  45, 114, 109, 32, 45, 119, 32, 53, 49, 50, 44, 53, 49, 50, 44, 48,
  32, 45, 95, 120, 95, 109, 97, 110, 100, 101, 108, 98, 114, 111, 116, 95,
  99, 111, 111, 114, 100, 115, 32, 36, 49, 32, 45, 95, 120, 95, 109, 97,
  110, 100, 101, 108, 98, 114, 111, 116, 95, 112, 97, 108, 101, 116, 116, 101,
  10, 45, 100, 111, 10, 115, 105, 122, 61, 123, 109, 105, 110, 40, 64, 123,
  33, 44, 119, 125, 44, 64, 123, 33, 44, 104, 125, 41, 125, 10, 36, 115,
  105, 122, 44, 36, 115, 105, 122, 32, 45, 109, 97, 110, 100, 101, 108, 98,
  114, 111, 116, 91, 45, 49, 93, 32, 64, 48, 44, 50, 53, 54, 44, 36,
  49, 44, 123, 105, 102, 40, 36, 49, 44, 36, 50, 44, 48, 41, 125, 44,
  123, 105, 102, 40, 36, 49, 44, 36, 51, 44, 48, 41, 125, 32, 45, 109,
  97, 112, 91, 45, 49, 93, 32, 91, 49, 93, 10, 45, 105, 102, 32, 36,
  49, 32, 45, 119, 91, 45, 49, 93, 32, 36, 115, 105, 122, 44, 36, 115,
  105, 122, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 74, 117,
  108, 105, 97, 32, 115, 101, 116, 32, 99, 61, 40, 34, 64, 123, 48, 44,
  48, 125, 34, 44, 34, 64, 123, 48, 44, 49, 125, 34, 41, 45, 40, 34,
  64, 123, 48, 44, 50, 125, 34, 44, 34, 64, 123, 48, 44, 51, 125, 34,
  41, 44, 32, 99, 48, 61, 40, 36, 50, 44, 36, 51, 41, 34, 10, 45,
  101, 108, 115, 101, 32, 45, 119, 91, 45, 49, 93, 32, 36, 115, 105, 122,
  44, 36, 115, 105, 122, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93,
  32, 77, 97, 110, 100, 101, 108, 98, 114, 111, 116, 32, 115, 101, 116, 32,
  99, 61, 40, 34, 64, 123, 48, 44, 48, 125, 34, 44, 34, 64, 123, 48,
  44, 49, 125, 34, 41, 45, 40, 34, 64, 123, 48, 44, 50, 125, 34, 44,
  34, 64, 123, 48, 44, 51, 125, 34, 41, 34, 32, 45, 101, 110, 100, 105,
  102, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 32, 45, 115,
  101, 108, 101, 99, 116, 91, 45, 49, 93, 32, 50, 10, 45, 105, 102, 32,
  123, 64, 123, 45, 49, 44, 48, 125, 62, 48, 125, 10, 77, 61, 123, 109,
  97, 120, 40, 64, 123, 45, 49, 44, 51, 125, 45, 64, 123, 45, 49, 44,
  48, 125, 44, 64, 123, 45, 49, 44, 52, 125, 45, 64, 123, 45, 49, 44,
  49, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 77, 60, 53, 125, 32,
  45, 95, 120, 95, 109, 97, 110, 100, 101, 108, 98, 114, 111, 116, 95, 99,
  111, 111, 114, 100, 115, 32, 36, 49, 32, 45, 114, 109, 91, 49, 93, 32,
  45, 95, 120, 95, 109, 97, 110, 100, 101, 108, 98, 114, 111, 116, 95, 112,
  97, 108, 101, 116, 116, 101, 32, 45, 109, 118, 91, 45, 49, 93, 32, 49,
  10, 45, 101, 108, 115, 101, 32, 40, 123, 64, 123, 48, 44, 48, 125, 43,
  64, 123, 45, 49, 44, 48, 125, 42, 40, 64, 123, 48, 44, 50, 125, 45,
  64, 123, 48, 44, 48, 125, 41, 47, 36, 119, 125, 59, 92, 10, 123, 64,
  123, 48, 44, 49, 125, 43, 64, 123, 45, 49, 44, 49, 125, 42, 40, 64,
  123, 48, 44, 51, 125, 45, 64, 123, 48, 44, 49, 125, 41, 47, 36, 104,
  125, 59, 92, 10, 123, 64, 123, 48, 44, 48, 125, 43, 40, 64, 123, 45,
  49, 44, 48, 125, 43, 36, 77, 41, 42, 40, 64, 123, 48, 44, 50, 125,
  45, 64, 123, 48, 44, 48, 125, 41, 47, 36, 119, 125, 59, 92, 10, 123,
  64, 123, 48, 44, 49, 125, 43, 40, 64, 123, 45, 49, 44, 49, 125, 43,
  36, 77, 41, 42, 40, 64, 123, 48, 44, 51, 125, 45, 64, 123, 48, 44,
  49, 125, 41, 47, 36, 104, 125, 41, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 114, 109, 91, 48, 93, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 105, 102, 32, 123, 64, 123, 33, 44, 67, 125, 125, 10, 45, 105, 102,
  32, 36, 49, 32, 45, 118, 32, 43, 32, 45, 101, 91, 48, 45, 45, 52,
  93, 32, 34, 74, 117, 108, 105, 97, 32, 115, 101, 116, 44, 32, 97, 116,
  32, 99, 32, 61, 32, 40, 34, 64, 123, 48, 44, 48, 45, 49, 125, 34,
  41, 45, 40, 34, 64, 123, 48, 44, 50, 45, 51, 125, 34, 41, 44, 32,
  119, 105, 116, 104, 32, 99, 48, 32, 61, 32, 40, 36, 50, 44, 36, 51,
  41, 46, 34, 32, 45, 118, 32, 45, 10, 45, 101, 108, 115, 101, 32, 45,
  118, 32, 43, 32, 45, 101, 91, 48, 45, 45, 52, 93, 32, 34, 77, 97,
  110, 100, 101, 108, 98, 114, 111, 116, 32, 115, 101, 116, 44, 32, 97, 116,
  32, 99, 32, 61, 32, 40, 34, 64, 123, 48, 44, 48, 45, 49, 125, 34,
  41, 45, 40, 34, 64, 123, 48, 44, 50, 45, 51, 125, 34, 41, 46, 34,
  32, 45, 118, 32, 45, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 33, 64, 33, 34, 32, 124, 124,
  32, 34, 64, 123, 33, 44, 69, 83, 67, 125, 34, 32, 124, 124, 32, 34,
  64, 123, 33, 44, 81, 125, 125, 32, 45, 114, 109, 32, 45, 119, 32, 48,
  32, 45, 118, 32, 43, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 119, 97, 105, 116, 32, 45, 49, 10, 45, 119,
  104, 105, 108, 101, 32, 49, 10, 95, 120, 95, 109, 97, 110, 100, 101, 108,
  98, 114, 111, 116, 95, 99, 111, 111, 114, 100, 115, 32, 58, 10, 45, 105,
  102, 32, 36, 49, 32, 40, 45, 50, 59, 45, 50, 59, 50, 59, 50, 41,
  32, 45, 101, 108, 115, 101, 32, 40, 45, 50, 46, 49, 59, 45, 49, 46,
  53, 59, 49, 46, 50, 59, 49, 46, 53, 41, 32, 45, 101, 110, 100, 105,
  102, 10, 95, 120, 95, 109, 97, 110, 100, 101, 108, 98, 114, 111, 116, 95,
  112, 97, 108, 101, 116, 116, 101, 32, 58, 10, 54, 44, 49, 44, 49, 44,
  51, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 50, 48, 44, 50,
  53, 53, 32, 45, 114, 91, 45, 49, 93, 32, 51, 50, 44, 49, 44, 49,
  44, 51, 44, 51, 32, 45, 114, 91, 45, 49, 93, 32, 49, 48, 50, 52,
  44, 49, 44, 49, 44, 51, 44, 48, 44, 50, 32, 45, 61, 91, 45, 49,
  93, 32, 48, 44, 48, 44, 48, 44, 48, 44, 48, 32, 45, 61, 91, 45,
  49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 44, 49, 32, 45, 61, 91,
  45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 44, 50, 10, 120, 95,
  109, 101, 116, 97, 98, 97, 108, 108, 115, 51, 100, 32, 58, 10, 45, 101,
  91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 51, 100,
  32, 109, 101, 116, 97, 98, 97, 108, 108, 115, 32, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45,
  32, 77, 111, 117, 115, 101, 32, 98, 117, 116, 116, 111, 110, 32, 111, 114,
  32, 39, 83, 80, 65, 67, 69, 39, 32, 107, 101, 121, 32, 116, 111, 32,
  115, 119, 105, 116, 99, 104, 32, 114, 101, 110, 100, 101, 114, 105, 110, 103,
  32, 109, 111, 100, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101,
  121, 115, 32, 39, 67, 84, 82, 76, 43, 68, 39, 32, 116, 111, 32, 100,
  111, 117, 98, 108, 101, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122,
  101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39,
  67, 84, 82, 76, 43, 67, 39, 32, 116, 111, 32, 114, 101, 115, 101, 116,
  32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10,
  45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32,
  111, 114, 32, 39, 81, 39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92,
  110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 32, 45, 108, 91, 93, 10,
  49, 48, 48, 44, 49, 48, 48, 32, 45, 110, 111, 105, 115, 101, 91, 45,
  49, 93, 32, 49, 48, 48, 44, 49, 32, 45, 112, 108, 97, 115, 109, 97,
  91, 45, 49, 93, 32, 49, 44, 48, 44, 49, 48, 32, 45, 114, 91, 45,
  49, 93, 32, 53, 49, 50, 44, 51, 50, 48, 44, 49, 44, 51, 32, 45,
  110, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 98, 91, 45, 49, 93,
  32, 52, 44, 48, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 10, 45, 109, 105, 120, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91,
  45, 49, 93, 32, 40, 48, 46, 55, 44, 48, 44, 48, 59, 48, 44, 48,
  46, 57, 44, 48, 59, 48, 44, 48, 44, 49, 46, 50, 41, 32, 45, 99,
  91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 108, 51, 100, 10,
  48, 10, 50, 52, 44, 50, 52, 44, 50, 52, 44, 49, 44, 39, 88, 61,
  120, 45, 119, 47, 50, 59, 89, 61, 121, 45, 104, 47, 50, 59, 90, 61,
  122, 45, 100, 47, 50, 59, 101, 120, 112, 40, 45, 40, 88, 42, 88, 43,
  89, 42, 89, 43, 90, 42, 90, 41, 47, 49, 48, 48, 41, 39, 10, 55,
  50, 44, 55, 50, 44, 55, 50, 32, 77, 61, 56, 32, 109, 111, 100, 101,
  61, 53, 10, 115, 48, 61, 68, 111, 116, 115, 32, 115, 49, 61, 87, 105,
  114, 101, 102, 114, 97, 109, 101, 32, 115, 50, 61, 70, 108, 97, 116, 32,
  115, 51, 61, 70, 108, 97, 116, 45, 115, 104, 97, 100, 101, 100, 32, 115,
  52, 61, 71, 111, 117, 114, 97, 117, 100, 45, 115, 104, 97, 100, 101, 100,
  32, 115, 53, 61, 80, 104, 111, 110, 103, 45, 115, 104, 97, 100, 101, 100,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 77, 32, 102, 120, 36, 62,
  61, 123, 103, 42, 49, 46, 53, 125, 32, 102, 121, 36, 62, 61, 123, 103,
  42, 49, 46, 53, 125, 32, 102, 122, 36, 62, 61, 123, 103, 42, 49, 46,
  53, 125, 32, 45, 100, 111, 110, 101, 10, 45, 119, 91, 48, 93, 32, 45,
  49, 44, 45, 49, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32,
  51, 100, 32, 109, 101, 116, 97, 98, 97, 108, 108, 115, 34, 10, 45, 100,
  111, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 77, 10, 120, 36, 62,
  61, 123, 119, 47, 50, 43, 48, 46, 53, 42, 40, 119, 45, 64, 123, 50,
  44, 119, 125, 45, 52, 41, 42, 99, 111, 115, 40, 36, 123, 102, 120, 36,
  62, 125, 42, 64, 124, 41, 125, 10, 121, 36, 62, 61, 123, 104, 47, 50,
  43, 48, 46, 53, 42, 40, 104, 45, 64, 123, 50, 44, 104, 125, 45, 52,
  41, 42, 115, 105, 110, 40, 36, 123, 102, 121, 36, 62, 125, 42, 64, 124,
  41, 125, 10, 122, 36, 62, 61, 123, 100, 47, 50, 43, 48, 46, 53, 42,
  40, 100, 45, 64, 123, 50, 44, 100, 125, 45, 52, 41, 42, 115, 105, 110,
  40, 36, 123, 102, 122, 36, 62, 125, 42, 64, 124, 41, 125, 10, 45, 100,
  111, 110, 101, 10, 45, 102, 91, 51, 93, 32, 48, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 36, 77, 32, 45, 106, 91, 51, 93, 32, 91, 50, 93,
  44, 123, 36, 123, 120, 36, 62, 125, 45, 64, 123, 50, 44, 119, 47, 50,
  125, 125, 44, 123, 36, 123, 121, 36, 62, 125, 45, 64, 123, 50, 44, 104,
  47, 50, 125, 125, 44, 123, 36, 123, 122, 36, 62, 125, 45, 64, 123, 50,
  44, 100, 47, 50, 125, 125, 44, 48, 44, 45, 49, 32, 45, 100, 111, 110,
  101, 10, 45, 45, 114, 91, 51, 93, 32, 50, 52, 44, 50, 52, 44, 50,
  52, 44, 49, 44, 50, 32, 45, 105, 115, 111, 115, 117, 114, 102, 97, 99,
  101, 51, 100, 91, 45, 49, 93, 32, 48, 46, 52, 32, 45, 45, 51, 100,
  91, 45, 49, 93, 32, 49, 50, 44, 49, 50, 44, 49, 50, 32, 45, 42,
  51, 100, 91, 45, 49, 93, 32, 49, 51, 32, 45, 114, 118, 51, 100, 91,
  45, 49, 93, 10, 45, 114, 51, 100, 91, 45, 49, 93, 32, 49, 44, 50,
  44, 49, 44, 123, 49, 48, 48, 42, 64, 124, 125, 10, 78, 61, 123, 105,
  91, 55, 93, 125, 32, 40, 50, 53, 53, 44, 50, 53, 53, 44, 49, 53,
  48, 59, 50, 48, 48, 44, 57, 54, 44, 49, 54, 52, 59, 53, 48, 44,
  49, 53, 48, 44, 50, 51, 48, 41, 32, 45, 114, 91, 45, 49, 93, 32,
  51, 44, 36, 78, 44, 49, 44, 49, 44, 51, 32, 45, 121, 91, 45, 49,
  93, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44,
  123, 64, 123, 45, 50, 44, 104, 125, 45, 52, 42, 36, 78, 125, 10, 45,
  105, 102, 32, 123, 33, 36, 109, 111, 100, 101, 125, 32, 45, 99, 105, 114,
  99, 108, 101, 115, 51, 100, 91, 45, 50, 93, 32, 52, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 33, 64, 123, 49, 44, 119, 125,
  125, 10, 48, 32, 45, 116, 101, 120, 116, 91, 45, 49, 93, 32, 36, 123,
  115, 36, 109, 111, 100, 101, 125, 44, 53, 44, 53, 44, 50, 52, 44, 48,
  46, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45,
  98, 91, 45, 49, 93, 32, 48, 46, 55, 32, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 10, 45, 45, 100, 105, 108, 97, 116, 101, 91,
  45, 49, 93, 32, 51, 32, 45, 45, 106, 91, 48, 93, 32, 91, 45, 50,
  93, 44, 53, 44, 51, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93,
  44, 50, 53, 53, 32, 45, 109, 118, 91, 45, 49, 93, 32, 49, 32, 45,
  114, 109, 91, 50, 44, 45, 50, 44, 45, 49, 93, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 49, 93,
  32, 91, 45, 50, 93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44,
  49, 44, 123, 105, 102, 40, 33, 36, 109, 111, 100, 101, 44, 51, 44, 36,
  109, 111, 100, 101, 41, 125, 44, 48, 44, 48, 44, 51, 48, 48, 44, 48,
  44, 48, 44, 45, 53, 48, 48, 44, 48, 46, 49, 44, 49, 46, 53, 10,
  45, 119, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44,
  67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 68,
  125, 125, 32, 45, 119, 91, 93, 32, 123, 50, 42, 119, 125, 44, 123, 50,
  42, 104, 125, 32, 45, 101, 108, 105, 102, 32, 123, 64, 123, 33, 44, 67,
  84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 67, 125,
  125, 32, 45, 119, 91, 93, 32, 123, 119, 125, 44, 123, 104, 125, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 51, 45, 45, 49, 93,
  32, 45, 119, 97, 105, 116, 32, 50, 48, 10, 45, 105, 102, 32, 123, 64,
  123, 33, 44, 98, 125, 124, 124, 64, 123, 33, 44, 83, 80, 65, 67, 69,
  125, 125, 32, 109, 111, 100, 101, 61, 123, 40, 36, 109, 111, 100, 101, 43,
  105, 102, 40, 64, 123, 33, 44, 98, 125, 38, 50, 44, 45, 49, 44, 49,
  41, 41, 37, 54, 125, 32, 45, 119, 97, 105, 116, 32, 45, 49, 32, 45,
  114, 109, 91, 49, 93, 32, 45, 105, 91, 49, 93, 32, 48, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34,
  32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67, 125, 34, 32,
  38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125, 10, 45, 114, 109,
  32, 45, 119, 32, 48, 32, 45, 101, 110, 100, 108, 32, 45, 118, 32, 43,
  10, 120, 95, 109, 105, 110, 101, 115, 119, 101, 101, 112, 101, 114, 32, 58,
  32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 50, 48, 125,
  62, 61, 56, 32, 38, 38, 32, 36, 49, 60, 61, 51, 48, 32, 38, 38,
  32, 36, 123, 50, 61, 36, 49, 125, 62, 61, 56, 32, 38, 38, 32, 36,
  50, 60, 61, 51, 48, 34, 10, 45, 101, 91, 93, 32, 34, 92, 110, 10,
  45, 45, 45, 45, 45, 45, 32, 77, 105, 110, 101, 115, 119, 101, 101, 112,
  101, 114, 32, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110,
  10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32, 84, 104, 101,
  32, 103, 111, 97, 108, 32, 105, 115, 32, 116, 111, 32, 99, 108, 101, 97,
  114, 32, 116, 104, 101, 32, 109, 105, 110, 101, 102, 105, 101, 108, 100, 32,
  119, 105, 116, 104, 111, 117, 116, 32, 100, 101, 116, 111, 110, 97, 116, 105,
  110, 103, 32, 97, 92, 110, 10, 45, 45, 45, 45, 32, 109, 105, 110, 101,
  46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32,
  76, 101, 102, 116, 32, 109, 111, 117, 115, 101, 32, 98, 117, 116, 116, 111,
  110, 32, 116, 111, 32, 116, 114, 121, 32, 99, 108, 101, 97, 114, 105, 110,
  103, 32, 111, 110, 101, 32, 115, 113, 117, 97, 114, 101, 46, 92, 110, 10,
  45, 45, 45, 45, 32, 82, 105, 103, 104, 116, 32, 109, 111, 117, 115, 101,
  32, 98, 117, 116, 116, 111, 110, 32, 116, 111, 32, 102, 108, 97, 103, 32,
  111, 114, 32, 117, 110, 102, 108, 97, 103, 32, 97, 32, 115, 113, 117, 97,
  114, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 77, 105, 100, 100, 108,
  101, 32, 109, 111, 117, 115, 101, 32, 98, 117, 116, 116, 111, 110, 32, 116,
  111, 32, 114, 101, 115, 101, 116, 32, 109, 105, 110, 101, 32, 102, 105, 101,
  108, 100, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32,
  39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81, 39, 32, 116, 111, 32,
  101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110, 34,
  10, 45, 118, 32, 45, 10, 36, 49, 44, 36, 50, 32, 45, 110, 111, 105,
  115, 101, 91, 45, 49, 93, 32, 51, 48, 44, 50, 32, 110, 98, 95, 109,
  105, 110, 101, 115, 61, 64, 123, 45, 49, 44, 43, 125, 32, 40, 49, 44,
  49, 44, 49, 59, 49, 44, 48, 44, 49, 59, 49, 44, 49, 44, 49, 41,
  32, 45, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 48, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45,
  43, 91, 45, 49, 93, 32, 49, 32, 45, 61, 61, 91, 45, 50, 93, 32,
  48, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 110, 109, 91,
  45, 49, 93, 32, 102, 105, 101, 108, 100, 10, 45, 100, 111, 32, 120, 61,
  123, 114, 111, 117, 110, 100, 40, 63, 40, 119, 45, 49, 41, 41, 125, 32,
  121, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 104, 45, 49, 41, 41,
  125, 32, 45, 119, 104, 105, 108, 101, 32, 123, 105, 40, 36, 120, 44, 36,
  121, 41, 33, 61, 49, 125, 10, 45, 45, 102, 91, 102, 105, 101, 108, 100,
  93, 32, 49, 49, 32, 45, 61, 91, 45, 49, 93, 32, 49, 50, 44, 36,
  120, 44, 36, 121, 32, 45, 110, 109, 91, 45, 49, 93, 32, 98, 111, 97,
  114, 100, 10, 50, 52, 44, 50, 52, 44, 49, 44, 51, 44, 50, 48, 48,
  32, 45, 102, 99, 91, 45, 49, 93, 32, 50, 53, 53, 44, 49, 56, 48,
  44, 49, 51, 48, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49,
  93, 32, 49, 50, 44, 49, 50, 44, 52, 44, 52, 32, 45, 108, 105, 110,
  101, 91, 45, 49, 93, 32, 54, 44, 49, 50, 44, 49, 56, 44, 49, 50,
  32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 49, 50, 44, 54, 44,
  49, 50, 44, 49, 56, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32,
  49, 51, 44, 49, 48, 44, 49, 52, 44, 49, 48, 44, 49, 44, 50, 53,
  53, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 49, 51, 44, 49,
  49, 44, 49, 52, 44, 49, 49, 44, 49, 44, 50, 53, 53, 10, 45, 122,
  91, 45, 49, 93, 32, 49, 44, 49, 44, 123, 119, 45, 50, 125, 44, 123,
  104, 45, 50, 125, 32, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93, 32,
  49, 44, 49, 44, 48, 10, 45, 45, 102, 99, 91, 45, 49, 93, 32, 50,
  51, 48, 44, 50, 53, 48, 44, 50, 53, 53, 10, 45, 45, 116, 91, 45,
  49, 93, 32, 34, 49, 34, 44, 49, 48, 44, 53, 44, 49, 51, 44, 49,
  44, 48, 44, 49, 57, 54, 44, 48, 32, 45, 45, 116, 91, 45, 50, 93,
  32, 34, 50, 34, 44, 57, 44, 53, 44, 49, 51, 44, 49, 44, 48, 44,
  49, 50, 56, 44, 48, 32, 45, 45, 116, 91, 45, 51, 93, 32, 34, 51,
  34, 44, 57, 44, 53, 44, 49, 51, 44, 49, 44, 48, 44, 48, 44, 50,
  53, 53, 10, 45, 45, 116, 91, 45, 52, 93, 32, 34, 52, 34, 44, 57,
  44, 53, 44, 49, 51, 44, 49, 44, 50, 53, 53, 44, 48, 44, 48, 32,
  45, 45, 116, 91, 45, 53, 93, 32, 34, 53, 34, 44, 57, 44, 53, 44,
  49, 51, 44, 49, 44, 50, 48, 48, 44, 48, 44, 48, 32, 45, 45, 116,
  91, 45, 54, 93, 32, 34, 54, 34, 44, 57, 44, 53, 44, 49, 51, 44,
  49, 44, 49, 53, 48, 44, 48, 44, 48, 10, 45, 45, 116, 91, 45, 55,
  93, 32, 34, 55, 34, 44, 57, 44, 53, 44, 49, 51, 44, 49, 44, 49,
  50, 56, 44, 48, 44, 48, 32, 45, 45, 116, 91, 45, 56, 93, 32, 34,
  56, 34, 44, 57, 44, 53, 44, 49, 51, 44, 49, 44, 54, 52, 44, 48,
  44, 48, 32, 45, 101, 114, 111, 100, 101, 91, 45, 56, 45, 45, 49, 93,
  32, 50, 10, 45, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102, 40, 120,
  60, 61, 49, 124, 124, 121, 60, 61, 49, 124, 124, 120, 62, 61, 119, 45,
  50, 124, 124, 121, 62, 61, 104, 45, 50, 44, 105, 102, 40, 120, 60, 121,
  44, 49, 50, 56, 44, 50, 53, 53, 41, 44, 49, 54, 48, 43, 50, 42,
  40, 121, 43, 120, 41, 41, 39, 10, 45, 45, 112, 111, 108, 121, 103, 111,
  110, 91, 45, 49, 93, 32, 52, 44, 49, 51, 44, 49, 53, 44, 49, 49,
  44, 49, 53, 44, 54, 44, 49, 56, 44, 49, 55, 44, 49, 56, 44, 49,
  44, 48, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 49, 50, 44,
  49, 53, 44, 49, 50, 44, 54, 44, 49, 44, 50, 53, 53, 44, 48, 44,
  48, 32, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 51,
  44, 49, 50, 44, 54, 44, 54, 44, 57, 44, 49, 50, 44, 49, 50, 44,
  49, 44, 50, 50, 48, 44, 48, 44, 48, 10, 45, 114, 118, 91, 45, 50,
  44, 45, 49, 93, 10, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 49, 44, 51, 32, 45, 108, 105, 110, 101, 91, 45, 49,
  93, 32, 54, 44, 49, 52, 44, 49, 48, 44, 49, 56, 44, 49, 44, 48,
  44, 50, 48, 48, 44, 48, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93,
  32, 49, 48, 44, 49, 56, 44, 49, 54, 44, 54, 44, 49, 44, 48, 44,
  50, 48, 48, 44, 48, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49,
  93, 32, 50, 10, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45,
  49, 93, 32, 49, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 48, 46,
  55, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51, 32,
  45, 106, 91, 45, 51, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45,
  50, 44, 45, 49, 93, 10, 45, 97, 91, 45, 49, 51, 45, 45, 49, 93,
  32, 120, 32, 45, 110, 109, 91, 45, 49, 93, 32, 115, 112, 114, 105, 116,
  101, 115, 10, 40, 48, 44, 50, 51, 59, 48, 44, 50, 51, 94, 48, 44,
  48, 59, 50, 51, 44, 50, 51, 41, 32, 45, 114, 91, 45, 49, 93, 32,
  50, 52, 44, 50, 52, 44, 49, 44, 50, 44, 51, 32, 45, 114, 91, 45,
  49, 93, 32, 123, 64, 123, 98, 111, 97, 114, 100, 44, 119, 125, 42, 50,
  52, 125, 44, 123, 64, 123, 98, 111, 97, 114, 100, 44, 104, 125, 42, 50,
  52, 125, 44, 49, 44, 50, 44, 48, 44, 50, 32, 45, 110, 109, 91, 45,
  49, 93, 32, 111, 102, 102, 115, 101, 116, 115, 10, 91, 45, 49, 93, 44,
  91, 45, 49, 93, 44, 49, 44, 51, 44, 50, 53, 53, 32, 45, 102, 114,
  97, 109, 101, 91, 45, 49, 93, 32, 49, 44, 49, 44, 48, 32, 45, 102,
  114, 97, 109, 101, 91, 45, 49, 93, 32, 50, 51, 44, 50, 51, 44, 50,
  53, 53, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 78, 117, 109,
  98, 101, 114, 32, 111, 102, 32, 109, 105, 110, 101, 115, 32, 58, 32, 34,
  36, 110, 98, 95, 109, 105, 110, 101, 115, 44, 48, 44, 48, 44, 49, 56,
  44, 49, 44, 49, 48, 48, 44, 50, 48, 48, 44, 50, 53, 53, 32, 45,
  110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32, 45, 106, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 44, 123, 40, 64, 123, 45, 50, 44,
  119, 125, 45, 119, 41, 47, 50, 125, 44, 123, 64, 123, 45, 50, 44, 104,
  125, 45, 104, 45, 50, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  110, 109, 91, 45, 49, 93, 32, 99, 97, 110, 118, 97, 115, 10, 102, 97,
  105, 108, 101, 100, 61, 48, 32, 115, 117, 99, 99, 101, 101, 100, 101, 100,
  61, 48, 32, 110, 98, 95, 102, 108, 97, 103, 115, 61, 48, 32, 115, 116,
  97, 114, 116, 101, 100, 61, 48, 10, 45, 100, 111, 10, 45, 45, 42, 91,
  98, 111, 97, 114, 100, 93, 32, 50, 52, 32, 45, 114, 91, 45, 49, 93,
  32, 91, 111, 102, 102, 115, 101, 116, 115, 93, 44, 91, 111, 102, 102, 115,
  101, 116, 115, 93, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45,
  49, 93, 32, 48, 44, 49, 32, 45, 43, 91, 45, 49, 93, 32, 91, 111,
  102, 102, 115, 101, 116, 115, 93, 32, 45, 45, 119, 97, 114, 112, 91, 115,
  112, 114, 105, 116, 101, 115, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48,
  32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 106, 91, 99, 97, 110, 118,
  97, 115, 93, 32, 91, 45, 49, 93, 44, 50, 52, 44, 50, 52, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 119, 97, 105, 116, 32, 45, 49, 10,
  45, 105, 102, 32, 36, 102, 97, 105, 108, 101, 100, 10, 48, 32, 45, 116,
  91, 45, 49, 93, 32, 34, 71, 97, 109, 101, 92, 110, 79, 118, 101, 114,
  33, 34, 44, 51, 44, 51, 44, 51, 56, 44, 49, 44, 50, 53, 53, 32,
  45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 49, 44, 52, 32, 45, 115, 104, 91, 45, 49, 93, 32, 51, 44, 51,
  32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 53, 32, 45,
  47, 91, 45, 49, 93, 32, 50, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119, 91, 45, 49, 93,
  32, 53, 44, 53, 44, 49, 32, 45, 98, 108, 101, 110, 100, 91, 99, 97,
  110, 118, 97, 115, 44, 45, 49, 93, 32, 97, 108, 112, 104, 97, 10, 48,
  32, 45, 116, 91, 45, 49, 93, 32, 34, 66, 111, 111, 109, 33, 32, 89,
  111, 117, 32, 102, 97, 105, 108, 101, 100, 33, 34, 44, 48, 44, 48, 44,
  49, 56, 44, 49, 44, 49, 48, 48, 44, 50, 53, 53, 44, 50, 53, 53,
  32, 45, 114, 91, 45, 49, 93, 32, 64, 123, 99, 97, 110, 118, 97, 115,
  44, 119, 125, 44, 49, 48, 48, 37, 44, 49, 44, 51, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 110, 101, 103, 97, 116, 105,
  118, 101, 91, 45, 49, 93, 32, 45, 106, 91, 99, 97, 110, 118, 97, 115,
  93, 32, 91, 45, 49, 93, 44, 48, 44, 51, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 100, 111, 32, 45, 119, 91, 99, 97, 110, 118, 97, 115,
  93, 32, 123, 119, 125, 44, 123, 104, 125, 32, 45, 119, 97, 105, 116, 32,
  45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34,
  33, 64, 123, 33, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33,
  64, 123, 33, 44, 81, 125, 125, 10, 45, 101, 108, 105, 102, 32, 36, 115,
  117, 99, 99, 101, 101, 100, 101, 100, 10, 48, 32, 45, 116, 91, 45, 49,
  93, 32, 34, 83, 117, 99, 99, 101, 115, 115, 33, 34, 44, 51, 44, 51,
  44, 51, 56, 44, 49, 44, 50, 53, 53, 32, 45, 114, 91, 45, 49, 93,
  32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 52, 32, 45,
  115, 104, 91, 45, 49, 93, 32, 51, 44, 51, 32, 45, 100, 105, 108, 97,
  116, 101, 91, 45, 49, 93, 32, 53, 32, 45, 47, 91, 45, 49, 93, 32,
  50, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 100, 114, 111, 112, 95,
  115, 104, 97, 100, 111, 119, 91, 45, 49, 93, 32, 53, 44, 53, 44, 49,
  32, 45, 98, 108, 101, 110, 100, 91, 99, 97, 110, 118, 97, 115, 44, 45,
  49, 93, 32, 97, 108, 112, 104, 97, 10, 48, 32, 45, 116, 91, 45, 49,
  93, 32, 34, 67, 111, 110, 103, 114, 97, 116, 117, 108, 97, 116, 105, 111,
  110, 115, 33, 32, 40, 34, 123, 114, 111, 117, 110, 100, 40, 64, 124, 45,
  36, 116, 105, 99, 41, 125, 34, 32, 115, 41, 34, 44, 48, 44, 48, 44,
  49, 56, 44, 49, 44, 50, 53, 53, 44, 49, 48, 48, 44, 50, 53, 53,
  32, 45, 114, 91, 45, 49, 93, 32, 64, 123, 99, 97, 110, 118, 97, 115,
  44, 119, 125, 44, 49, 48, 48, 37, 44, 49, 44, 51, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 110, 101, 103, 97, 116, 105,
  118, 101, 91, 45, 49, 93, 32, 45, 106, 91, 99, 97, 110, 118, 97, 115,
  93, 32, 91, 45, 49, 93, 44, 48, 44, 51, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 100, 111, 32, 45, 119, 91, 99, 97, 110, 118, 97, 115,
  93, 32, 123, 119, 125, 44, 123, 104, 125, 32, 45, 119, 97, 105, 116, 32,
  45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34,
  33, 64, 123, 33, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33,
  64, 123, 33, 44, 81, 125, 125, 10, 45, 101, 108, 115, 101, 10, 45, 45,
  61, 61, 91, 98, 111, 97, 114, 100, 93, 32, 49, 48, 32, 110, 98, 95,
  102, 108, 97, 103, 115, 61, 64, 123, 45, 49, 44, 43, 125, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 100, 111, 10, 45, 105, 102, 32, 123, 33,
  36, 115, 116, 97, 114, 116, 101, 100, 125, 32, 116, 105, 99, 61, 64, 124,
  32, 45, 101, 110, 100, 105, 102, 10, 48, 32, 45, 116, 91, 45, 49, 93,
  32, 34, 69, 108, 97, 112, 115, 101, 100, 32, 116, 105, 109, 101, 32, 58,
  32, 34, 123, 114, 111, 117, 110, 100, 40, 64, 124, 45, 36, 116, 105, 99,
  41, 125, 34, 32, 115, 32, 47, 32, 70, 108, 97, 103, 115, 32, 58, 32,
  34, 36, 110, 98, 95, 102, 108, 97, 103, 115, 44, 48, 44, 48, 44, 49,
  56, 44, 49, 44, 50, 53, 53, 44, 50, 48, 48, 44, 48, 32, 45, 114,
  91, 45, 49, 93, 32, 64, 123, 99, 97, 110, 118, 97, 115, 44, 119, 125,
  44, 49, 48, 48, 37, 44, 49, 44, 51, 44, 48, 44, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 10, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91,
  45, 49, 93, 32, 45, 106, 91, 99, 97, 110, 118, 97, 115, 93, 32, 91,
  45, 49, 93, 44, 48, 44, 51, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 119, 97, 105, 116, 32, 53, 48, 10, 120, 61, 123, 105, 110, 116, 40,
  40, 64, 123, 33, 44, 120, 125, 45, 50, 52, 41, 47, 50, 52, 41, 125,
  32, 121, 61, 123, 105, 110, 116, 40, 40, 64, 123, 33, 44, 121, 125, 45,
  50, 52, 41, 47, 50, 52, 41, 125, 32, 98, 61, 64, 123, 33, 44, 98,
  125, 10, 45, 119, 91, 99, 97, 110, 118, 97, 115, 93, 32, 123, 119, 125,
  44, 123, 104, 125, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32,
  77, 105, 110, 101, 115, 119, 101, 101, 112, 101, 114, 34, 10, 45, 119, 104,
  105, 108, 101, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123,
  33, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33,
  44, 81, 125, 34, 32, 38, 38, 32, 34, 33, 36, 98, 125, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 120, 62, 61, 48, 92,
  32, 38, 38, 92, 32, 36, 121, 62, 61, 48, 92, 32, 38, 38, 92, 32,
  36, 120, 60, 64, 123, 98, 111, 97, 114, 100, 44, 119, 125, 92, 32, 38,
  38, 92, 32, 36, 121, 60, 64, 123, 98, 111, 97, 114, 100, 44, 104, 125,
  125, 10, 45, 105, 102, 32, 123, 36, 98, 38, 49, 125, 10, 115, 116, 97,
  114, 116, 101, 100, 61, 49, 32, 118, 97, 108, 61, 64, 123, 102, 105, 101,
  108, 100, 44, 40, 36, 120, 44, 36, 121, 41, 125, 10, 45, 105, 102, 32,
  123, 36, 118, 97, 108, 61, 61, 48, 125, 32, 45, 45, 61, 61, 91, 102,
  105, 101, 108, 100, 93, 32, 48, 32, 45, 106, 91, 98, 111, 97, 114, 100,
  93, 32, 91, 102, 105, 101, 108, 100, 93, 44, 48, 44, 48, 44, 48, 44,
  48, 44, 49, 44, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 102, 97, 105, 108, 101, 100, 61, 49, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 118, 97, 108, 61, 61, 49, 125, 32, 45, 45, 102, 108, 111, 111,
  100, 91, 102, 105, 101, 108, 100, 93, 32, 36, 120, 44, 36, 121, 44, 48,
  44, 48, 44, 49, 44, 49, 44, 45, 49, 32, 45, 61, 61, 91, 45, 49,
  93, 32, 45, 49, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93,
  32, 51, 32, 45, 106, 91, 98, 111, 97, 114, 100, 93, 32, 91, 102, 105,
  101, 108, 100, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 115,
  101, 32, 45, 61, 91, 98, 111, 97, 114, 100, 93, 32, 36, 118, 97, 108,
  44, 36, 120, 44, 36, 121, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  108, 105, 102, 32, 123, 110, 61, 64, 123, 98, 111, 97, 114, 100, 44, 40,
  36, 120, 44, 36, 121, 41, 125, 59, 36, 98, 38, 50, 34, 32, 38, 38,
  32, 34, 110, 62, 61, 49, 48, 34, 32, 38, 38, 32, 34, 110, 60, 61,
  49, 49, 125, 10, 45, 61, 91, 98, 111, 97, 114, 100, 93, 32, 123, 105,
  102, 40, 64, 123, 98, 111, 97, 114, 100, 44, 40, 36, 120, 44, 36, 121,
  41, 125, 61, 61, 49, 49, 44, 49, 48, 44, 49, 49, 41, 125, 44, 36,
  120, 44, 36, 121, 10, 45, 101, 108, 105, 102, 32, 123, 36, 98, 38, 52,
  125, 32, 45, 102, 91, 98, 111, 97, 114, 100, 93, 32, 49, 48, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 110, 98, 95, 109, 105, 110, 101, 115, 61, 61, 36, 110, 98,
  95, 102, 108, 97, 103, 115, 92, 32, 38, 38, 92, 32, 64, 123, 98, 111,
  97, 114, 100, 44, 77, 125, 33, 61, 49, 49, 125, 32, 115, 117, 99, 99,
  101, 101, 100, 101, 100, 61, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  119, 104, 105, 108, 101, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34, 33,
  64, 123, 33, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64,
  123, 33, 44, 81, 125, 125, 10, 45, 119, 32, 48, 32, 45, 118, 32, 43,
  10, 120, 95, 109, 105, 110, 105, 109, 97, 108, 95, 112, 97, 116, 104, 32,
  58, 10, 45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45,
  45, 32, 77, 105, 110, 105, 109, 97, 108, 32, 112, 97, 116, 104, 32, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45,
  92, 110, 10, 45, 45, 45, 45, 32, 67, 108, 105, 99, 107, 32, 111, 110,
  32, 116, 119, 111, 32, 112, 111, 105, 110, 116, 115, 32, 116, 111, 32, 99,
  111, 109, 112, 117, 116, 101, 32, 97, 110, 100, 32, 100, 105, 115, 112, 108,
  97, 121, 32, 116, 104, 101, 32, 109, 105, 110, 105, 109, 97, 108, 92, 110,
  10, 45, 45, 45, 45, 32, 112, 97, 116, 104, 32, 98, 101, 116, 119, 101,
  101, 110, 32, 116, 104, 111, 115, 101, 32, 112, 111, 105, 110, 116, 115, 46,
  32, 84, 104, 101, 32, 101, 110, 100, 105, 110, 103, 32, 112, 111, 105, 110,
  116, 32, 105, 115, 32, 116, 104, 101, 110, 92, 110, 10, 45, 45, 45, 45,
  32, 99, 104, 111, 115, 101, 110, 32, 97, 115, 32, 116, 104, 101, 32, 110,
  101, 120, 116, 32, 115, 116, 97, 114, 116, 105, 110, 103, 32, 112, 111, 105,
  110, 116, 32, 102, 111, 114, 32, 97, 110, 111, 116, 104, 101, 114, 32, 112,
  97, 116, 104, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 32,
  39, 83, 39, 32, 116, 111, 32, 115, 97, 118, 101, 32, 115, 110, 97, 112,
  115, 104, 111, 116, 32, 111, 102, 32, 116, 104, 101, 32, 99, 117, 114, 114,
  101, 110, 116, 32, 118, 105, 101, 119, 46, 92, 110, 10, 45, 45, 45, 45,
  32, 75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39,
  81, 39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45,
  45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 34, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 123, 33,
  64, 35, 125, 32, 45, 116, 101, 115, 116, 105, 109, 97, 103, 101, 50, 100,
  32, 52, 48, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 110, 32, 48,
  44, 50, 48, 48, 32, 45, 114, 111, 117, 110, 100, 32, 49, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  45, 119, 91, 48, 93, 32, 45, 49, 44, 45, 49, 44, 48, 44, 34, 91,
  71, 39, 77, 73, 67, 93, 32, 83, 101, 108, 101, 99, 116, 32, 115, 116,
  97, 114, 116, 105, 110, 103, 32, 112, 111, 105, 110, 116, 32, 80, 48, 34,
  10, 45, 105, 102, 32, 123, 33, 110, 97, 114, 103, 40, 36, 102, 105, 114,
  115, 116, 95, 116, 105, 109, 101, 41, 125, 32, 45, 45, 108, 91, 48, 93,
  32, 45, 114, 50, 100, 121, 32, 49, 50, 56, 32, 45, 102, 114, 97, 109,
  101, 32, 49, 44, 49, 44, 48, 10, 45, 97, 108, 101, 114, 116, 32, 34,
  91, 71, 39, 77, 73, 67, 32, 77, 105, 110, 105, 109, 97, 108, 32, 112,
  97, 116, 104, 93, 34, 44, 92, 10, 34, 84, 104, 101, 32, 71, 39, 77,
  73, 67, 32, 109, 105, 110, 105, 109, 97, 108, 32, 112, 97, 116, 104, 32,
  100, 101, 109, 111, 32, 105, 108, 108, 117, 115, 116, 114, 97, 116, 101, 115,
  32, 104, 111, 119, 32, 109, 105, 110, 105, 109, 97, 108, 32, 112, 97, 116,
  104, 115, 92, 110, 34, 92, 10, 34, 99, 97, 110, 32, 98, 101, 32, 99,
  111, 109, 112, 117, 116, 101, 100, 32, 105, 110, 32, 105, 109, 97, 103, 101,
  115, 32, 116, 111, 32, 100, 101, 116, 101, 99, 116, 32, 97, 110, 100, 32,
  116, 114, 97, 99, 107, 32, 101, 100, 103, 101, 32, 112, 111, 105, 110, 116,
  115, 46, 92, 110, 34, 92, 10, 34, 85, 115, 101, 32, 121, 111, 117, 114,
  32, 109, 111, 117, 115, 101, 32, 116, 111, 32, 115, 101, 108, 101, 99, 116,
  32, 100, 101, 115, 105, 114, 101, 100, 32, 115, 116, 97, 114, 116, 105, 110,
  103, 32, 97, 110, 100, 32, 101, 110, 100, 105, 110, 103, 32, 112, 111, 105,
  110, 116, 115, 44, 92, 110, 34, 92, 10, 34, 97, 110, 100, 32, 115, 101,
  101, 32, 119, 104, 97, 116, 32, 105, 115, 32, 116, 104, 101, 32, 109, 105,
  110, 105, 109, 97, 108, 32, 112, 97, 116, 104, 32, 99, 111, 109, 112, 117,
  116, 101, 100, 32, 98, 101, 116, 119, 101, 101, 110, 32, 116, 104, 101, 115,
  101, 32, 112, 111, 105, 110, 116, 115, 46, 34, 44, 92, 10, 34, 83, 116,
  97, 114, 116, 32, 100, 101, 109, 111, 34, 10, 45, 114, 109, 32, 45, 101,
  110, 100, 108, 32, 102, 105, 114, 115, 116, 95, 116, 105, 109, 101, 61, 48,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 103, 114, 97, 100, 105, 101,
  110, 116, 95, 110, 111, 114, 109, 32, 45, 98, 91, 45, 49, 93, 32, 49,
  32, 45, 102, 91, 45, 49, 93, 32, 101, 120, 112, 40, 45, 105, 47, 49,
  48, 41, 10, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 32, 45, 45,
  115, 101, 108, 101, 99, 116, 91, 48, 93, 32, 48, 32, 80, 48, 61, 64,
  45, 49, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 48, 93, 32, 64,
  123, 45, 49, 44, 48, 44, 49, 125, 44, 51, 44, 51, 44, 48, 44, 49,
  44, 50, 53, 53, 44, 48, 44, 50, 53, 53, 10, 45, 101, 108, 108, 105,
  112, 115, 101, 91, 48, 93, 32, 64, 123, 45, 49, 44, 48, 44, 49, 125,
  44, 51, 44, 51, 44, 48, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70,
  70, 70, 70, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 109, 105, 110,
  40, 36, 80, 48, 41, 62, 61, 48, 125, 10, 112, 61, 49, 10, 45, 100,
  111, 10, 45, 119, 91, 48, 93, 32, 45, 49, 44, 45, 49, 44, 48, 44,
  34, 91, 71, 39, 77, 73, 67, 93, 32, 83, 101, 108, 101, 99, 116, 32,
  101, 110, 100, 105, 110, 103, 32, 112, 111, 105, 110, 116, 32, 80, 34, 36,
  112, 10, 45, 45, 115, 101, 108, 101, 99, 116, 91, 48, 93, 32, 48, 10,
  45, 105, 102, 32, 123, 64, 123, 33, 44, 83, 125, 125, 10, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 45, 116, 101, 120, 116, 95, 111, 117, 116, 108,
  105, 110, 101, 91, 48, 93, 32, 34, 83, 97, 118, 105, 110, 103, 32, 115,
  110, 97, 112, 115, 104, 111, 116, 46, 46, 46, 34, 44, 53, 44, 53, 44,
  49, 51, 44, 49, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 32, 45, 119, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 111, 91, 48, 93, 32, 103, 109, 105, 99, 95, 109, 105, 110,
  105, 109, 97, 108, 95, 112, 97, 116, 104, 46, 112, 110, 103, 10, 45, 119,
  97, 105, 116, 32, 45, 49, 10, 45, 101, 108, 115, 101, 10, 80, 49, 61,
  64, 45, 49, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 48, 93, 32,
  64, 123, 45, 49, 44, 48, 44, 49, 125, 44, 51, 44, 51, 44, 48, 44,
  49, 44, 50, 53, 53, 44, 48, 44, 50, 53, 53, 10, 45, 101, 108, 108,
  105, 112, 115, 101, 91, 48, 93, 32, 64, 123, 45, 49, 44, 48, 44, 49,
  125, 44, 51, 44, 51, 44, 48, 44, 49, 44, 48, 120, 70, 70, 70, 70,
  70, 70, 70, 70, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 109, 105,
  110, 40, 36, 80, 49, 41, 62, 61, 48, 125, 10, 45, 45, 116, 101, 120,
  116, 95, 111, 117, 116, 108, 105, 110, 101, 91, 48, 93, 32, 34, 80, 114,
  111, 99, 101, 115, 115, 105, 110, 103, 46, 46, 46, 34, 44, 53, 44, 53,
  44, 49, 51, 44, 49, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 32, 45, 119, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 45, 109, 105, 110, 105, 109, 97, 108, 95, 112, 97, 116,
  104, 91, 49, 93, 32, 36, 80, 48, 44, 36, 80, 49, 44, 49, 10, 45,
  112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 91, 45, 49, 93, 32, 48,
  32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 91, 45,
  49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 91,
  48, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 46, 53,
  32, 45, 114, 91, 45, 49, 93, 32, 91, 48, 93, 44, 48, 32, 45, 111,
  114, 91, 48, 44, 45, 49, 93, 10, 80, 48, 61, 36, 80, 49, 32, 112,
  61, 123, 36, 112, 43, 49, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 33,
  34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67, 125, 34,
  32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 109, 91, 49, 93, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 119, 32, 48, 32, 45, 118, 32,
  43, 10, 120, 95, 112, 97, 99, 109, 97, 110, 32, 58, 10, 45, 101, 91,
  93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 80, 97, 99,
  109, 97, 110, 32, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45,
  45, 32, 84, 104, 105, 115, 32, 105, 115, 32, 97, 32, 71, 39, 77, 73,
  67, 32, 105, 109, 112, 108, 101, 109, 101, 110, 116, 97, 116, 105, 111, 110,
  32, 111, 102, 32, 116, 104, 101, 32, 112, 97, 99, 109, 97, 110, 32, 103,
  97, 109, 101, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45,
  45, 45, 32, 77, 111, 118, 101, 32, 116, 104, 101, 32, 112, 97, 99, 109,
  97, 110, 32, 116, 111, 32, 101, 97, 116, 32, 97, 108, 108, 32, 112, 97,
  99, 100, 111, 116, 115, 32, 111, 110, 32, 116, 104, 101, 32, 100, 105, 102,
  102, 101, 114, 101, 110, 116, 32, 108, 101, 118, 101, 108, 115, 46, 92, 110,
  10, 45, 45, 45, 45, 32, 69, 97, 116, 105, 110, 103, 32, 97, 32, 112,
  97, 99, 103, 117, 109, 32, 109, 97, 107, 101, 115, 32, 112, 97, 99, 109,
  97, 110, 32, 105, 110, 118, 105, 110, 99, 105, 98, 108, 101, 32, 102, 111,
  114, 32, 49, 48, 32, 115, 101, 99, 111, 110, 100, 115, 44, 92, 110, 10,
  45, 45, 45, 45, 32, 119, 104, 105, 99, 104, 32, 109, 101, 97, 110, 32,
  112, 97, 99, 109, 97, 110, 32, 99, 97, 110, 32, 101, 97, 116, 32, 103,
  104, 111, 115, 116, 115, 32, 100, 117, 114, 105, 110, 103, 32, 116, 104, 105,
  115, 32, 116, 105, 109, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 69,
  97, 116, 105, 110, 103, 32, 97, 32, 103, 104, 111, 115, 116, 32, 101, 97,
  114, 110, 115, 32, 49, 48, 48, 32, 112, 116, 115, 46, 92, 110, 10, 45,
  45, 45, 45, 32, 69, 97, 116, 105, 110, 103, 32, 97, 32, 99, 104, 101,
  114, 114, 121, 32, 101, 97, 114, 110, 115, 32, 49, 48, 32, 112, 116, 115,
  46, 92, 110, 10, 45, 45, 45, 45, 32, 69, 97, 116, 105, 110, 103, 32,
  97, 32, 115, 116, 114, 97, 119, 98, 101, 114, 114, 121, 32, 101, 97, 114,
  110, 115, 32, 49, 48, 48, 32, 112, 116, 115, 46, 92, 110, 10, 45, 45,
  45, 45, 32, 69, 97, 116, 105, 110, 103, 32, 97, 110, 32, 111, 114, 97,
  110, 103, 101, 32, 101, 97, 114, 110, 115, 32, 49, 48, 48, 48, 32, 112,
  116, 115, 46, 92, 110, 10, 45, 45, 45, 45, 32, 69, 97, 116, 105, 110,
  103, 32, 97, 32, 98, 97, 110, 97, 110, 97, 32, 101, 97, 114, 110, 115,
  32, 53, 48, 48, 48, 32, 112, 116, 115, 46, 92, 110, 10, 45, 45, 45,
  45, 92, 110, 10, 45, 45, 45, 45, 32, 65, 114, 114, 111, 119, 32, 107,
  101, 121, 115, 32, 116, 111, 32, 99, 111, 110, 116, 114, 111, 108, 32, 112,
  97, 99, 109, 97, 110, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101,
  121, 115, 32, 39, 67, 84, 82, 76, 43, 68, 39, 32, 116, 111, 32, 100,
  111, 117, 98, 108, 101, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122,
  101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39,
  67, 84, 82, 76, 43, 67, 39, 32, 116, 111, 32, 114, 101, 115, 101, 116,
  32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10,
  45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32,
  111, 114, 32, 39, 81, 39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92,
  110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  109, 10, 45, 109, 32, 34, 95, 112, 97, 99, 109, 97, 110, 95, 103, 104,
  111, 115, 116, 95, 98, 97, 115, 101, 95, 103, 102, 120, 32, 58, 32, 51,
  49, 44, 49, 57, 32, 45, 99, 105, 114, 99, 108, 101, 91, 45, 49, 93,
  32, 49, 53, 44, 49, 53, 44, 49, 53, 44, 49, 44, 49, 32, 51, 49,
  44, 49, 50, 44, 49, 44, 49, 44, 39, 121, 60, 52, 43, 56, 42, 97,
  98, 115, 40, 99, 111, 115, 40, 120, 42, 48, 46, 51, 43, 48, 46, 50,
  53, 42, 112, 105, 42, 36, 34, 34, 49, 41, 41, 39, 32, 45, 97, 91,
  45, 50, 44, 45, 49, 93, 32, 121, 34, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 52, 10, 45, 95, 112, 97, 99, 109, 97, 110, 95, 103, 104, 111,
  115, 116, 95, 115, 116, 97, 110, 100, 97, 114, 100, 95, 103, 102, 120, 32,
  50, 53, 53, 44, 48, 44, 48, 44, 36, 62, 32, 45, 110, 109, 91, 45,
  49, 93, 32, 103, 104, 111, 115, 116, 48, 95, 36, 62, 10, 45, 95, 112,
  97, 99, 109, 97, 110, 95, 103, 104, 111, 115, 116, 95, 115, 116, 97, 110,
  100, 97, 114, 100, 95, 103, 102, 120, 32, 48, 44, 50, 53, 53, 44, 50,
  50, 50, 44, 36, 62, 32, 45, 110, 109, 91, 45, 49, 93, 32, 103, 104,
  111, 115, 116, 49, 95, 36, 62, 10, 45, 95, 112, 97, 99, 109, 97, 110,
  95, 103, 104, 111, 115, 116, 95, 115, 116, 97, 110, 100, 97, 114, 100, 95,
  103, 102, 120, 32, 50, 53, 53, 44, 49, 56, 52, 44, 50, 50, 50, 44,
  36, 62, 32, 45, 110, 109, 91, 45, 49, 93, 32, 103, 104, 111, 115, 116,
  50, 95, 36, 62, 10, 45, 95, 112, 97, 99, 109, 97, 110, 95, 103, 104,
  111, 115, 116, 95, 115, 116, 97, 110, 100, 97, 114, 100, 95, 103, 102, 120,
  32, 50, 53, 53, 44, 49, 56, 52, 44, 55, 49, 44, 36, 62, 32, 45,
  110, 109, 91, 45, 49, 93, 32, 103, 104, 111, 115, 116, 51, 95, 36, 62,
  10, 45, 95, 112, 97, 99, 109, 97, 110, 95, 103, 104, 111, 115, 116, 95,
  97, 102, 114, 97, 105, 100, 95, 103, 102, 120, 32, 36, 62, 32, 45, 110,
  109, 91, 45, 49, 93, 32, 103, 104, 111, 115, 116, 97, 95, 36, 62, 10,
  45, 95, 112, 97, 99, 109, 97, 110, 95, 103, 104, 111, 115, 116, 95, 98,
  97, 115, 101, 95, 103, 102, 120, 32, 36, 62, 32, 45, 114, 91, 45, 49,
  93, 32, 49, 54, 44, 49, 54, 44, 49, 44, 49, 44, 50, 32, 45, 110,
  109, 91, 45, 49, 93, 32, 103, 104, 111, 115, 116, 109, 95, 36, 62, 10,
  45, 95, 112, 97, 99, 109, 97, 110, 95, 103, 104, 111, 115, 116, 95, 115,
  116, 97, 110, 100, 97, 114, 100, 95, 103, 102, 120, 32, 48, 44, 48, 44,
  48, 44, 36, 62, 32, 45, 110, 109, 91, 45, 49, 93, 32, 103, 104, 111,
  115, 116, 100, 95, 36, 62, 10, 45, 95, 112, 97, 99, 109, 97, 110, 95,
  112, 97, 99, 109, 97, 110, 95, 103, 102, 120, 32, 36, 62, 32, 45, 110,
  109, 91, 45, 50, 93, 32, 112, 97, 99, 109, 97, 110, 95, 36, 62, 32,
  45, 110, 109, 91, 45, 49, 93, 32, 112, 97, 99, 109, 97, 110, 109, 95,
  36, 62, 10, 45, 100, 111, 110, 101, 10, 45, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 91, 103, 104, 111, 115, 116, 100, 95, 48, 93, 32, 48, 32,
  45, 33, 61, 91, 45, 49, 93, 32, 48, 32, 45, 110, 109, 91, 45, 49,
  93, 32, 103, 104, 111, 115, 116, 100, 109, 10, 45, 95, 112, 97, 99, 109,
  97, 110, 95, 99, 104, 101, 114, 114, 121, 95, 103, 102, 120, 32, 45, 110,
  109, 91, 45, 49, 93, 32, 102, 114, 117, 105, 116, 48, 32, 45, 95, 112,
  97, 99, 109, 97, 110, 95, 115, 116, 114, 97, 119, 98, 101, 114, 114, 121,
  95, 103, 102, 120, 32, 45, 110, 109, 91, 45, 49, 93, 32, 102, 114, 117,
  105, 116, 49, 10, 45, 95, 112, 97, 99, 109, 97, 110, 95, 111, 114, 97,
  110, 103, 101, 95, 103, 102, 120, 32, 45, 110, 109, 91, 45, 49, 93, 32,
  102, 114, 117, 105, 116, 50, 32, 45, 95, 112, 97, 99, 109, 97, 110, 95,
  98, 97, 110, 97, 110, 97, 95, 103, 102, 120, 32, 45, 110, 109, 91, 45,
  49, 93, 32, 102, 114, 117, 105, 116, 51, 10, 50, 48, 44, 50, 44, 49,
  44, 51, 44, 50, 48, 48, 32, 45, 110, 109, 91, 45, 49, 93, 32, 103,
  97, 116, 101, 10, 115, 99, 111, 114, 101, 48, 61, 34, 49, 48, 34, 32,
  115, 99, 111, 114, 101, 49, 61, 34, 49, 48, 48, 34, 32, 115, 99, 111,
  114, 101, 50, 61, 34, 49, 48, 48, 48, 34, 32, 115, 99, 111, 114, 101,
  51, 61, 34, 53, 48, 48, 48, 34, 32, 115, 99, 111, 114, 101, 52, 61,
  34, 65, 114, 103, 104, 33, 34, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  53, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 36, 123, 115, 99, 111,
  114, 101, 36, 62, 125, 44, 48, 44, 48, 44, 49, 51, 44, 49, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 97, 117, 116, 111,
  99, 114, 111, 112, 91, 45, 49, 93, 32, 48, 32, 45, 101, 120, 112, 97,
  110, 100, 95, 120, 121, 91, 45, 49, 93, 32, 49, 44, 48, 32, 45, 45,
  100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51, 10, 45, 110, 109,
  91, 45, 49, 93, 32, 115, 99, 111, 114, 101, 109, 36, 62, 32, 45, 110,
  109, 91, 45, 50, 93, 32, 115, 99, 111, 114, 101, 36, 62, 10, 45, 100,
  111, 110, 101, 10, 116, 105, 109, 101, 52, 61, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 32, 116, 105, 109, 101, 51, 61, 50, 53, 53, 44,
  50, 53, 53, 44, 51, 50, 32, 116, 105, 109, 101, 50, 61, 50, 53, 53,
  44, 49, 50, 56, 44, 51, 50, 32, 116, 105, 109, 101, 49, 61, 50, 53,
  53, 44, 51, 50, 44, 51, 50, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  49, 49, 32, 48, 32, 45, 116, 91, 45, 49, 93, 32, 36, 60, 34, 32,
  115, 34, 44, 48, 44, 48, 44, 50, 51, 44, 49, 44, 36, 123, 116, 105,
  109, 101, 123, 109, 105, 110, 40, 52, 44, 114, 111, 117, 110, 100, 40, 40,
  36, 60, 43, 49, 41, 47, 50, 41, 41, 125, 125, 32, 45, 110, 109, 91,
  45, 49, 93, 32, 116, 105, 109, 101, 36, 60, 32, 45, 100, 111, 110, 101,
  10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 71, 101, 116, 32, 82,
  101, 97, 100, 121, 33, 34, 44, 48, 44, 48, 44, 51, 50, 44, 49, 44,
  50, 53, 53, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49,
  93, 32, 48, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 91, 45,
  49, 93, 32, 52, 44, 48, 32, 45, 45, 100, 105, 108, 97, 116, 101, 91,
  45, 49, 93, 32, 56, 32, 45, 114, 91, 45, 50, 93, 32, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 49, 44, 51, 10, 45, 110, 109, 91, 45,
  50, 93, 32, 103, 101, 116, 95, 114, 101, 97, 100, 121, 32, 45, 110, 109,
  91, 45, 49, 93, 32, 103, 101, 116, 95, 114, 101, 97, 100, 121, 109, 10,
  48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 71, 97, 109, 101, 92, 110,
  79, 118, 101, 114, 33, 34, 44, 48, 44, 48, 44, 53, 55, 44, 49, 44,
  50, 53, 53, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49,
  93, 32, 48, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 91, 45,
  49, 93, 32, 52, 44, 48, 32, 45, 45, 100, 105, 108, 97, 116, 101, 91,
  45, 49, 93, 32, 56, 32, 45, 114, 91, 45, 50, 93, 32, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 49, 44, 51, 10, 45, 110, 109, 91, 45,
  50, 93, 32, 103, 97, 109, 101, 95, 111, 118, 101, 114, 32, 45, 110, 109,
  91, 45, 49, 93, 32, 103, 97, 109, 101, 95, 111, 118, 101, 114, 109, 10,
  115, 99, 111, 114, 101, 61, 48, 32, 108, 101, 118, 101, 108, 61, 45, 49,
  32, 108, 105, 118, 101, 115, 61, 51, 32, 105, 115, 95, 113, 117, 105, 116,
  61, 48, 10, 45, 100, 111, 10, 45, 105, 102, 32, 123, 36, 108, 101, 118,
  101, 108, 60, 48, 125, 10, 95, 114, 108, 101, 118, 101, 108, 61, 51, 51,
  32, 95, 103, 108, 101, 118, 101, 108, 61, 51, 51, 32, 95, 98, 108, 101,
  118, 101, 108, 61, 50, 53, 53, 10, 45, 95, 112, 97, 99, 109, 97, 110,
  95, 109, 97, 112, 95, 108, 101, 118, 101, 108, 123, 40, 40, 45, 36, 108,
  101, 118, 101, 108, 45, 49, 41, 37, 54, 41, 43, 49, 125, 32, 109, 119,
  61, 123, 119, 125, 32, 109, 104, 61, 123, 104, 125, 32, 109, 119, 50, 61,
  123, 105, 110, 116, 40, 119, 47, 50, 41, 125, 32, 109, 104, 50, 61, 123,
  105, 110, 116, 40, 104, 47, 50, 41, 125, 10, 45, 105, 102, 32, 123, 36,
  108, 101, 118, 101, 108, 60, 45, 54, 125, 32, 45, 114, 101, 112, 108, 97,
  99, 101, 91, 45, 49, 93, 32, 51, 44, 50, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 110, 109, 91, 45, 49, 93, 32, 109, 97, 112, 48, 32, 45,
  105, 91, 109, 97, 112, 93, 32, 91, 45, 49, 93, 10, 45, 45, 115, 104,
  105, 102, 116, 91, 109, 97, 112, 93, 32, 45, 49, 44, 48, 32, 45, 45,
  115, 104, 105, 102, 116, 91, 109, 97, 112, 93, 32, 48, 44, 45, 49, 32,
  45, 45, 115, 104, 105, 102, 116, 91, 109, 97, 112, 93, 32, 49, 44, 48,
  32, 45, 45, 115, 104, 105, 102, 116, 91, 109, 97, 112, 93, 32, 48, 44,
  49, 32, 45, 97, 91, 45, 52, 45, 45, 49, 93, 32, 122, 32, 45, 33,
  61, 91, 45, 49, 93, 32, 49, 32, 45, 110, 109, 91, 45, 49, 93, 32,
  99, 97, 110, 95, 103, 111, 10, 45, 45, 61, 61, 91, 109, 97, 112, 93,
  32, 49, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 61, 91,
  45, 49, 93, 32, 49, 44, 36, 109, 119, 50, 44, 36, 109, 104, 50, 32,
  45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 44,
  91, 45, 50, 93, 44, 51, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45,
  102, 91, 45, 49, 93, 32, 39, 105, 102, 40, 105, 61, 61, 50, 44, 48,
  44, 105, 102, 40, 105, 61, 61, 56, 44, 49, 44, 105, 102, 40, 105, 61,
  61, 49, 44, 50, 44, 105, 102, 40, 105, 61, 61, 52, 44, 51, 44, 105,
  41, 41, 41, 41, 39, 32, 45, 110, 109, 91, 45, 49, 93, 32, 112, 97,
  116, 104, 10, 45, 45, 61, 61, 91, 109, 97, 112, 93, 32, 50, 32, 112,
  97, 99, 100, 111, 116, 115, 61, 64, 123, 45, 49, 44, 43, 125, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 108, 101, 118, 101, 108, 61, 123, 45, 36,
  108, 101, 118, 101, 108, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 102,
  91, 109, 97, 112, 93, 32, 39, 105, 102, 40, 105, 62, 61, 52, 44, 48,
  44, 105, 41, 39, 32, 45, 45, 61, 61, 91, 109, 97, 112, 93, 32, 49,
  32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 91, 45, 49, 93, 32,
  49, 44, 48, 32, 45, 114, 91, 45, 49, 93, 32, 49, 54, 48, 48, 37,
  44, 49, 54, 48, 48, 37, 32, 45, 101, 114, 111, 100, 101, 91, 45, 49,
  93, 32, 57, 32, 45, 98, 91, 45, 49, 93, 32, 50, 10, 45, 103, 91,
  45, 49, 93, 32, 120, 121, 32, 45, 97, 98, 115, 91, 45, 50, 44, 45,
  49, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 103, 101,
  91, 45, 49, 93, 32, 56, 48, 37, 32, 45, 98, 91, 45, 49, 93, 32,
  50, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 115, 104,
  114, 105, 110, 107, 95, 120, 121, 91, 45, 49, 93, 32, 49, 54, 10, 45,
  45, 42, 91, 45, 49, 93, 32, 36, 95, 103, 108, 101, 118, 101, 108, 32,
  45, 45, 42, 91, 45, 50, 93, 32, 36, 95, 98, 108, 101, 118, 101, 108,
  32, 45, 42, 91, 45, 51, 93, 32, 36, 95, 114, 108, 101, 118, 101, 108,
  32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 99, 10, 49, 54, 44,
  49, 54, 44, 49, 44, 49, 44, 39, 120, 39, 32, 45, 45, 45, 91, 109,
  97, 112, 93, 32, 49, 32, 45, 109, 97, 120, 91, 45, 49, 93, 32, 48,
  32, 45, 42, 91, 45, 49, 93, 32, 49, 54, 32, 45, 114, 91, 45, 49,
  93, 32, 49, 54, 48, 48, 37, 44, 49, 54, 48, 48, 37, 10, 49, 54,
  44, 49, 54, 44, 49, 44, 49, 44, 39, 121, 39, 32, 45, 114, 91, 45,
  51, 44, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 50, 32, 45,
  43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 97, 91, 45, 50, 44, 45,
  49, 93, 32, 99, 10, 49, 54, 44, 49, 54, 44, 49, 44, 51, 32, 45,
  95, 112, 97, 99, 109, 97, 110, 95, 112, 97, 99, 100, 111, 116, 115, 95,
  103, 102, 120, 32, 45, 95, 112, 97, 99, 109, 97, 110, 95, 112, 97, 99,
  103, 117, 109, 95, 103, 102, 120, 32, 45, 97, 91, 45, 51, 45, 45, 49,
  93, 32, 121, 10, 45, 119, 97, 114, 112, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45,
  111, 114, 91, 45, 50, 44, 45, 49, 93, 32, 45, 114, 91, 45, 49, 93,
  32, 49, 48, 48, 37, 44, 123, 104, 43, 50, 52, 125, 44, 49, 44, 51,
  44, 48, 44, 48, 44, 48, 44, 49, 10, 45, 116, 91, 45, 49, 93, 32,
  34, 76, 105, 118, 101, 115, 32, 58, 34, 44, 49, 48, 44, 48, 44, 50,
  51, 44, 49, 44, 50, 53, 53, 32, 45, 116, 91, 45, 49, 93, 32, 34,
  83, 99, 111, 114, 101, 32, 58, 34, 44, 123, 119, 45, 49, 52, 48, 125,
  44, 48, 44, 50, 51, 44, 49, 44, 50, 53, 53, 10, 45, 105, 102, 32,
  36, 108, 105, 118, 101, 115, 32, 45, 45, 114, 91, 112, 97, 99, 109, 97,
  110, 95, 50, 93, 32, 49, 50, 44, 49, 50, 44, 49, 44, 52, 44, 50,
  32, 45, 114, 91, 45, 49, 93, 32, 123, 49, 48, 48, 42, 36, 108, 105,
  118, 101, 115, 125, 37, 44, 49, 48, 48, 37, 44, 49, 44, 52, 44, 48,
  44, 50, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 57,
  48, 44, 55, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 110, 109, 91, 45, 49, 93, 32, 118, 105, 115, 117, 10,
  45, 119, 91, 118, 105, 115, 117, 93, 32, 45, 49, 44, 45, 49, 44, 48,
  44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 80, 97, 99, 109, 97, 110,
  34, 32, 45, 99, 117, 114, 115, 111, 114, 91, 48, 93, 32, 48, 10, 48,
  32, 45, 116, 91, 45, 49, 93, 32, 34, 76, 101, 118, 101, 108, 32, 34,
  36, 108, 101, 118, 101, 108, 44, 48, 44, 48, 44, 53, 55, 44, 49, 44,
  49, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32,
  48, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 91, 45, 49, 93,
  32, 52, 44, 48, 32, 40, 48, 44, 50, 53, 53, 94, 48, 44, 50, 53,
  53, 94, 48, 44, 48, 41, 32, 45, 45, 109, 97, 112, 91, 45, 50, 93,
  32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45, 100,
  105, 108, 97, 116, 101, 91, 45, 50, 93, 32, 56, 10, 45, 110, 109, 91,
  45, 49, 93, 32, 108, 101, 118, 101, 108, 95, 78, 32, 45, 110, 109, 91,
  45, 50, 93, 32, 108, 101, 118, 101, 108, 109, 95, 78, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 52, 32, 120, 103, 36, 62, 61, 123, 49, 54, 42,
  36, 109, 119, 50, 125, 32, 121, 103, 36, 62, 61, 123, 49, 54, 42, 36,
  109, 104, 50, 43, 52, 42, 36, 62, 125, 32, 100, 103, 36, 62, 61, 51,
  32, 109, 103, 36, 62, 61, 48, 32, 45, 100, 111, 110, 101, 10, 120, 112,
  61, 123, 49, 54, 42, 49, 48, 125, 32, 121, 112, 61, 123, 49, 54, 42,
  50, 49, 125, 32, 100, 112, 61, 45, 49, 32, 112, 97, 99, 103, 117, 109,
  95, 116, 105, 109, 101, 114, 61, 45, 49, 32, 102, 114, 117, 105, 116, 95,
  116, 105, 109, 101, 114, 61, 64, 124, 32, 100, 121, 105, 110, 103, 95, 112,
  97, 99, 109, 97, 110, 61, 48, 32, 105, 115, 95, 103, 101, 116, 95, 114,
  101, 97, 100, 121, 61, 49, 10, 120, 115, 99, 111, 114, 101, 61, 48, 32,
  121, 115, 99, 111, 114, 101, 61, 48, 32, 110, 115, 99, 111, 114, 101, 61,
  48, 32, 111, 115, 99, 111, 114, 101, 61, 48, 10, 45, 100, 111, 10, 116,
  61, 123, 105, 110, 116, 40, 54, 42, 64, 124, 41, 37, 52, 125, 32, 108,
  101, 102, 116, 61, 123, 105, 102, 40, 36, 112, 97, 99, 103, 117, 109, 95,
  116, 105, 109, 101, 114, 62, 61, 48, 44, 49, 48, 45, 64, 124, 43, 36,
  112, 97, 99, 103, 117, 109, 95, 116, 105, 109, 101, 114, 44, 45, 49, 41,
  125, 10, 91, 118, 105, 115, 117, 93, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 52, 10, 109, 103, 61, 36, 123, 109, 103, 36, 62, 125, 32, 120, 103,
  61, 36, 123, 120, 103, 36, 62, 125, 32, 121, 103, 61, 123, 36, 123, 121,
  103, 36, 62, 125, 43, 50, 52, 125, 10, 45, 105, 102, 32, 123, 36, 109,
  103, 61, 61, 48, 125, 32, 45, 106, 91, 45, 49, 93, 32, 91, 103, 104,
  111, 115, 116, 36, 62, 95, 36, 116, 93, 44, 36, 120, 103, 44, 36, 121,
  103, 44, 48, 44, 48, 44, 49, 44, 91, 103, 104, 111, 115, 116, 109, 95,
  36, 116, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 109, 103, 61, 61,
  49, 125, 32, 116, 50, 61, 123, 105, 102, 40, 36, 108, 101, 102, 116, 62,
  55, 44, 36, 116, 44, 105, 102, 40, 36, 108, 101, 102, 116, 62, 51, 44,
  105, 110, 116, 40, 49, 50, 42, 64, 124, 41, 37, 52, 44, 105, 110, 116,
  40, 50, 52, 42, 64, 124, 41, 37, 52, 41, 41, 125, 32, 45, 106, 91,
  45, 49, 93, 32, 91, 103, 104, 111, 115, 116, 97, 95, 36, 116, 50, 93,
  44, 36, 120, 103, 44, 36, 121, 103, 44, 48, 44, 48, 44, 49, 44, 91,
  103, 104, 111, 115, 116, 109, 95, 36, 116, 93, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 109, 103, 61, 61, 50, 125, 32, 45, 106, 91, 45, 49, 93,
  32, 91, 103, 104, 111, 115, 116, 100, 95, 36, 116, 93, 44, 36, 120, 103,
  44, 36, 121, 103, 44, 48, 44, 48, 44, 48, 46, 56, 44, 91, 103, 104,
  111, 115, 116, 100, 109, 93, 10, 45, 101, 108, 115, 101, 32, 45, 106, 91,
  45, 49, 93, 32, 91, 103, 104, 111, 115, 116, 36, 62, 95, 36, 116, 93,
  44, 36, 120, 103, 44, 36, 121, 103, 44, 48, 44, 48, 44, 123, 36, 109,
  103, 45, 50, 125, 44, 91, 103, 104, 111, 115, 116, 109, 95, 36, 116, 93,
  32, 45, 106, 91, 45, 49, 93, 32, 91, 103, 104, 111, 115, 116, 100, 95,
  36, 116, 93, 44, 36, 120, 103, 44, 36, 121, 103, 44, 48, 44, 48, 44,
  49, 44, 91, 103, 104, 111, 115, 116, 100, 109, 93, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 36, 100, 121,
  105, 110, 103, 95, 112, 97, 99, 109, 97, 110, 10, 45, 95, 112, 97, 99,
  109, 97, 110, 95, 112, 97, 99, 109, 97, 110, 95, 103, 102, 120, 32, 123,
  36, 100, 121, 105, 110, 103, 95, 112, 97, 99, 109, 97, 110, 47, 50, 125,
  32, 45, 114, 111, 116, 97, 116, 101, 91, 45, 50, 44, 45, 49, 93, 32,
  123, 57, 48, 42, 40, 97, 98, 115, 40, 36, 100, 112, 41, 45, 49, 41,
  125, 32, 45, 106, 91, 45, 51, 93, 32, 91, 45, 50, 93, 44, 36, 120,
  112, 44, 123, 50, 52, 43, 36, 121, 112, 125, 44, 48, 44, 48, 44, 49,
  44, 91, 45, 49, 93, 44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 50,
  44, 45, 49, 93, 10, 100, 121, 105, 110, 103, 95, 112, 97, 99, 109, 97,
  110, 61, 123, 36, 100, 121, 105, 110, 103, 95, 112, 97, 99, 109, 97, 110,
  43, 49, 125, 10, 45, 105, 102, 32, 123, 36, 100, 121, 105, 110, 103, 95,
  112, 97, 99, 109, 97, 110, 62, 54, 52, 125, 10, 45, 105, 102, 32, 123,
  36, 108, 105, 118, 101, 115, 33, 61, 49, 125, 32, 45, 114, 109, 91, 45,
  49, 93, 32, 45, 98, 114, 101, 97, 107, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 106, 91, 45, 49, 93, 32, 91, 103, 97, 109, 101, 95, 111, 118,
  101, 114, 93, 44, 123, 40, 119, 45, 64, 123, 103, 97, 109, 101, 95, 111,
  118, 101, 114, 44, 119, 125, 41, 47, 50, 125, 44, 123, 49, 50, 43, 40,
  104, 45, 64, 123, 103, 97, 109, 101, 95, 111, 118, 101, 114, 44, 104, 125,
  41, 47, 50, 125, 44, 48, 44, 48, 44, 123, 109, 105, 110, 40, 49, 44,
  40, 36, 100, 121, 105, 110, 103, 95, 112, 97, 99, 109, 97, 110, 45, 54,
  52, 41, 47, 53, 48, 41, 125, 44, 91, 103, 97, 109, 101, 95, 111, 118,
  101, 114, 109, 93, 44, 50, 53, 53, 10, 45, 114, 101, 99, 116, 97, 110,
  103, 108, 101, 91, 45, 49, 93, 32, 57, 48, 44, 55, 44, 49, 48, 49,
  44, 49, 56, 44, 49, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 108, 115, 101, 10, 45, 45, 114, 111, 116, 97, 116, 101, 91, 112, 97,
  99, 109, 97, 110, 95, 36, 116, 44, 112, 97, 99, 109, 97, 110, 109, 95,
  36, 116, 93, 32, 123, 57, 48, 42, 40, 97, 98, 115, 40, 36, 100, 112,
  41, 45, 49, 41, 125, 32, 45, 106, 91, 45, 51, 93, 32, 91, 45, 50,
  93, 44, 36, 120, 112, 44, 123, 50, 52, 43, 36, 121, 112, 125, 44, 48,
  44, 48, 44, 49, 44, 91, 45, 49, 93, 44, 50, 53, 53, 32, 45, 114,
  109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 108,
  101, 102, 116, 62, 61, 48, 34, 32, 38, 38, 32, 34, 40, 36, 108, 101,
  102, 116, 62, 61, 53, 34, 32, 124, 124, 32, 34, 36, 116, 60, 61, 50,
  41, 125, 32, 45, 106, 91, 45, 49, 93, 32, 91, 116, 105, 109, 101, 123,
  114, 111, 117, 110, 100, 40, 36, 108, 101, 102, 116, 41, 125, 93, 44, 123,
  40, 119, 45, 64, 123, 116, 105, 109, 101, 48, 44, 119, 125, 41, 47, 50,
  125, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 116, 91, 45, 49, 93, 32, 36, 115, 99, 111, 114, 101, 44,
  123, 119, 45, 54, 53, 125, 44, 49, 44, 50, 50, 44, 49, 44, 50, 53,
  53, 10, 45, 105, 102, 32, 123, 36, 105, 115, 95, 103, 101, 116, 95, 114,
  101, 97, 100, 121, 125, 10, 45, 106, 91, 45, 49, 93, 32, 91, 108, 101,
  118, 101, 108, 95, 78, 93, 44, 123, 40, 119, 45, 64, 123, 108, 101, 118,
  101, 108, 95, 78, 44, 119, 125, 41, 47, 50, 125, 44, 123, 49, 50, 43,
  40, 104, 45, 49, 46, 53, 42, 64, 123, 108, 101, 118, 101, 108, 95, 78,
  44, 104, 125, 41, 47, 50, 125, 44, 48, 44, 48, 44, 49, 44, 91, 108,
  101, 118, 101, 108, 109, 95, 78, 93, 10, 45, 105, 102, 32, 123, 105, 110,
  116, 40, 64, 124, 42, 52, 41, 37, 50, 125, 32, 45, 106, 91, 45, 49,
  93, 32, 91, 103, 101, 116, 95, 114, 101, 97, 100, 121, 93, 44, 123, 40,
  119, 45, 64, 123, 103, 101, 116, 95, 114, 101, 97, 100, 121, 44, 119, 125,
  41, 47, 50, 125, 44, 123, 50, 52, 43, 40, 104, 43, 64, 123, 103, 101,
  116, 95, 114, 101, 97, 100, 121, 44, 104, 125, 41, 47, 50, 125, 44, 48,
  44, 48, 44, 49, 44, 91, 103, 101, 116, 95, 114, 101, 97, 100, 121, 109,
  93, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 111, 115, 99, 111, 114, 101,
  62, 48, 125, 32, 45, 106, 91, 45, 49, 93, 32, 91, 115, 99, 111, 114,
  101, 36, 110, 115, 99, 111, 114, 101, 93, 44, 36, 120, 115, 99, 111, 114,
  101, 44, 36, 121, 115, 99, 111, 114, 101, 44, 48, 44, 48, 44, 36, 111,
  115, 99, 111, 114, 101, 44, 91, 115, 99, 111, 114, 101, 109, 36, 110, 115,
  99, 111, 114, 101, 93, 44, 50, 53, 53, 32, 111, 115, 99, 111, 114, 101,
  61, 123, 36, 111, 115, 99, 111, 114, 101, 45, 48, 46, 48, 52, 125, 32,
  121, 115, 99, 111, 114, 101, 61, 123, 36, 121, 115, 99, 111, 114, 101, 45,
  49, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 106, 91, 45, 49, 93,
  32, 91, 103, 97, 116, 101, 93, 44, 49, 53, 56, 44, 50, 50, 51, 44,
  48, 44, 48, 44, 48, 46, 54, 10, 45, 119, 91, 45, 49, 93, 10, 45,
  105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84,
  125, 38, 38, 64, 123, 33, 44, 68, 125, 125, 32, 45, 119, 91, 93, 32,
  123, 50, 42, 119, 125, 44, 123, 50, 42, 104, 125, 32, 45, 101, 108, 105,
  102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125,
  38, 38, 64, 123, 33, 44, 67, 125, 125, 32, 45, 119, 91, 93, 32, 123,
  119, 125, 44, 123, 104, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 52, 10,
  120, 103, 61, 36, 123, 120, 103, 36, 62, 125, 32, 121, 103, 61, 36, 123,
  121, 103, 36, 62, 125, 32, 100, 103, 61, 36, 123, 100, 103, 36, 62, 125,
  32, 109, 103, 61, 36, 123, 109, 103, 36, 62, 125, 10, 45, 105, 102, 32,
  123, 109, 97, 120, 40, 97, 98, 115, 40, 36, 120, 103, 45, 36, 120, 112,
  41, 44, 97, 98, 115, 40, 36, 121, 103, 45, 36, 121, 112, 41, 41, 60,
  61, 56, 125, 10, 45, 105, 102, 32, 123, 36, 109, 103, 61, 61, 48, 34,
  32, 38, 38, 32, 34, 33, 36, 100, 121, 105, 110, 103, 95, 112, 97, 99,
  109, 97, 110, 125, 32, 100, 121, 105, 110, 103, 95, 112, 97, 99, 109, 97,
  110, 61, 49, 10, 120, 115, 99, 111, 114, 101, 61, 36, 120, 112, 32, 121,
  115, 99, 111, 114, 101, 61, 123, 36, 121, 112, 43, 49, 50, 125, 32, 111,
  115, 99, 111, 114, 101, 61, 49, 32, 110, 115, 99, 111, 114, 101, 61, 52,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 109, 103, 61, 61, 49, 125, 32,
  109, 103, 61, 50, 32, 109, 103, 36, 62, 61, 36, 109, 103, 32, 115, 99,
  111, 114, 101, 61, 123, 36, 115, 99, 111, 114, 101, 43, 49, 48, 48, 125,
  10, 120, 115, 99, 111, 114, 101, 61, 36, 120, 112, 32, 121, 115, 99, 111,
  114, 101, 61, 123, 36, 121, 112, 43, 49, 50, 125, 32, 111, 115, 99, 111,
  114, 101, 61, 49, 32, 110, 115, 99, 111, 114, 101, 61, 49, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 109, 103, 62, 61, 50, 34, 32, 38, 38, 32, 34, 40, 36, 120,
  103, 62, 62, 52, 41, 61, 61, 36, 109, 119, 50, 34, 32, 38, 38, 32,
  34, 40, 36, 121, 103, 62, 62, 52, 41, 61, 61, 36, 109, 104, 50, 125,
  10, 109, 103, 61, 123, 36, 109, 103, 43, 48, 46, 48, 49, 125, 10, 45,
  105, 102, 32, 123, 36, 109, 103, 62, 61, 51, 125, 32, 109, 103, 61, 48,
  32, 120, 103, 61, 123, 36, 120, 103, 38, 45, 50, 125, 32, 121, 103, 61,
  123, 36, 121, 103, 38, 45, 50, 125, 32, 45, 101, 110, 100, 105, 102, 10,
  109, 103, 36, 62, 61, 36, 109, 103, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 33, 40, 36, 120, 103, 38, 49, 53, 41, 34, 32,
  38, 38, 32, 34, 33, 40, 36, 121, 103, 38, 49, 53, 41, 125, 10, 40,
  123, 63, 125, 44, 123, 63, 125, 44, 123, 63, 125, 44, 123, 63, 125, 59,
  48, 44, 49, 44, 50, 44, 51, 41, 10, 45, 105, 102, 32, 123, 36, 109,
  103, 60, 50, 125, 10, 45, 61, 91, 45, 49, 93, 32, 123, 63, 40, 48,
  46, 54, 44, 49, 41, 125, 44, 123, 105, 102, 40, 36, 109, 103, 61, 61,
  48, 44, 100, 88, 48, 61, 36, 120, 112, 45, 36, 120, 103, 59, 100, 89,
  48, 61, 36, 121, 112, 45, 36, 121, 103, 59, 105, 102, 40, 97, 98, 115,
  40, 100, 88, 48, 41, 62, 97, 98, 115, 40, 100, 89, 48, 41, 44, 105,
  102, 40, 100, 88, 48, 62, 48, 44, 48, 44, 50, 41, 44, 105, 102, 40,
  100, 89, 48, 62, 48, 44, 49, 44, 51, 41, 41, 44, 92, 10, 100, 88,
  49, 61, 36, 120, 112, 45, 36, 120, 103, 59, 100, 89, 49, 61, 36, 121,
  112, 45, 36, 121, 103, 59, 105, 102, 40, 97, 98, 115, 40, 100, 88, 49,
  41, 60, 97, 98, 115, 40, 100, 89, 49, 41, 44, 105, 102, 40, 100, 88,
  49, 62, 48, 44, 50, 44, 48, 41, 44, 105, 102, 40, 100, 89, 49, 62,
  48, 44, 51, 44, 49, 41, 41, 41, 125, 10, 45, 61, 91, 45, 49, 93,
  32, 48, 44, 123, 40, 36, 100, 103, 43, 50, 41, 37, 52, 125, 10, 45,
  105, 102, 32, 36, 105, 115, 95, 103, 101, 116, 95, 114, 101, 97, 100, 121,
  32, 45, 61, 91, 45, 49, 93, 32, 48, 46, 56, 44, 64, 123, 112, 97,
  116, 104, 44, 40, 123, 36, 120, 103, 62, 62, 52, 125, 44, 123, 36, 121,
  103, 62, 62, 52, 125, 41, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 108, 115, 101, 32, 45, 61, 91, 45, 49, 93, 32, 49, 44, 64, 123,
  112, 97, 116, 104, 44, 40, 123, 36, 120, 103, 62, 62, 52, 125, 44, 123,
  36, 121, 103, 62, 62, 52, 125, 41, 125, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 115, 111, 114, 116, 91, 45, 49, 93, 32, 45, 44, 120, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 52, 32, 100, 61, 123, 105, 40, 36, 62,
  44, 49, 41, 125, 32, 45, 105, 102, 32, 64, 123, 99, 97, 110, 95, 103,
  111, 44, 40, 123, 36, 120, 103, 62, 62, 52, 125, 44, 123, 36, 121, 103,
  62, 62, 52, 125, 44, 36, 100, 41, 125, 32, 100, 103, 61, 36, 100, 32,
  45, 98, 114, 101, 97, 107, 32, 45, 101, 110, 100, 105, 102, 32, 45, 100,
  111, 110, 101, 32, 45, 114, 109, 91, 45, 49, 93, 10, 100, 103, 36, 62,
  61, 36, 100, 10, 45, 101, 110, 100, 105, 102, 10, 117, 61, 123, 68, 61,
  36, 123, 100, 103, 36, 62, 125, 59, 40, 68, 61, 61, 48, 41, 45, 40,
  68, 61, 61, 50, 41, 125, 10, 118, 61, 123, 68, 61, 36, 123, 100, 103,
  36, 62, 125, 59, 40, 68, 61, 61, 49, 41, 45, 40, 68, 61, 61, 51,
  41, 125, 10, 120, 103, 36, 62, 61, 123, 40, 36, 120, 103, 43, 36, 117,
  42, 40, 49, 43, 40, 36, 109, 103, 61, 61, 48, 41, 41, 41, 37, 40,
  49, 54, 42, 36, 109, 119, 41, 125, 10, 121, 103, 36, 62, 61, 123, 40,
  36, 121, 103, 43, 36, 118, 42, 40, 49, 43, 40, 36, 109, 103, 61, 61,
  48, 41, 41, 41, 37, 40, 49, 54, 42, 36, 109, 104, 41, 125, 10, 45,
  100, 111, 110, 101, 10, 45, 119, 97, 105, 116, 32, 50, 50, 10, 45, 105,
  102, 32, 123, 33, 36, 100, 121, 105, 110, 103, 95, 112, 97, 99, 109, 97,
  110, 125, 10, 100, 61, 123, 105, 102, 40, 64, 123, 33, 44, 65, 82, 82,
  79, 87, 82, 73, 71, 72, 84, 125, 44, 49, 44, 105, 102, 40, 64, 123,
  33, 44, 65, 82, 82, 79, 87, 68, 79, 87, 78, 125, 44, 50, 44, 105,
  102, 40, 64, 123, 33, 44, 65, 82, 82, 79, 87, 76, 69, 70, 84, 125,
  44, 51, 44, 105, 102, 40, 64, 123, 33, 44, 65, 82, 82, 79, 87, 85,
  80, 125, 44, 52, 44, 36, 100, 112, 41, 41, 41, 41, 125, 10, 45, 105,
  102, 32, 123, 33, 40, 36, 120, 112, 38, 49, 53, 41, 34, 32, 38, 38,
  32, 34, 33, 40, 36, 121, 112, 38, 49, 53, 41, 125, 10, 105, 61, 64,
  123, 109, 97, 112, 44, 40, 123, 36, 120, 112, 62, 62, 52, 125, 44, 123,
  36, 121, 112, 62, 62, 52, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36,
  105, 61, 61, 50, 125, 32, 115, 99, 111, 114, 101, 61, 123, 36, 115, 99,
  111, 114, 101, 43, 49, 48, 125, 32, 112, 97, 99, 100, 111, 116, 115, 61,
  123, 36, 112, 97, 99, 100, 111, 116, 115, 45, 49, 125, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 105, 61, 61, 51, 125, 32, 112, 97, 99, 103, 117,
  109, 95, 116, 105, 109, 101, 114, 61, 64, 124, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 52, 32, 45, 105, 102, 32, 123, 33, 36, 123, 109, 103, 36,
  62, 125, 125, 32, 109, 103, 36, 62, 61, 49, 32, 100, 103, 36, 62, 61,
  123, 40, 36, 123, 100, 103, 36, 62, 125, 43, 50, 41, 37, 52, 125, 32,
  45, 101, 110, 100, 105, 102, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 105, 62, 61, 52, 125, 32, 115, 99, 111, 114, 101,
  61, 123, 36, 115, 99, 111, 114, 101, 43, 36, 123, 115, 99, 111, 114, 101,
  123, 36, 105, 45, 52, 125, 125, 125, 32, 120, 115, 99, 111, 114, 101, 61,
  36, 120, 112, 32, 121, 115, 99, 111, 114, 101, 61, 123, 36, 121, 112, 43,
  49, 50, 125, 32, 111, 115, 99, 111, 114, 101, 61, 49, 32, 110, 115, 99,
  111, 114, 101, 61, 123, 36, 105, 45, 52, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 61, 91, 109, 97, 112, 93, 32, 48, 44, 123, 36, 120, 112,
  62, 62, 52, 125, 44, 123, 36, 121, 112, 62, 62, 52, 125, 10, 49, 54,
  44, 49, 54, 44, 49, 44, 51, 32, 45, 106, 91, 118, 105, 115, 117, 93,
  32, 91, 45, 49, 93, 44, 36, 120, 112, 44, 123, 50, 52, 43, 36, 121,
  112, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 100, 61, 123, 105, 102,
  40, 64, 123, 99, 97, 110, 95, 103, 111, 44, 40, 123, 36, 120, 112, 62,
  62, 52, 125, 44, 123, 36, 121, 112, 62, 62, 52, 125, 44, 123, 97, 98,
  115, 40, 36, 100, 41, 45, 49, 125, 41, 125, 44, 36, 100, 44, 36, 100,
  112, 41, 125, 10, 100, 61, 123, 105, 102, 40, 64, 123, 99, 97, 110, 95,
  103, 111, 44, 40, 123, 36, 120, 112, 62, 62, 52, 125, 44, 123, 36, 121,
  112, 62, 62, 52, 125, 44, 123, 97, 98, 115, 40, 36, 100, 41, 45, 49,
  125, 41, 125, 44, 36, 100, 44, 45, 97, 98, 115, 40, 36, 100, 112, 41,
  41, 125, 10, 100, 112, 61, 36, 100, 10, 45, 101, 108, 115, 101, 32, 100,
  112, 61, 123, 105, 102, 40, 97, 98, 115, 40, 36, 100, 45, 36, 100, 112,
  41, 61, 61, 50, 44, 36, 100, 44, 36, 100, 112, 41, 125, 10, 45, 101,
  110, 100, 105, 102, 10, 105, 115, 95, 103, 101, 116, 95, 114, 101, 97, 100,
  121, 61, 123, 105, 102, 40, 36, 100, 112, 62, 48, 44, 48, 44, 36, 105,
  115, 95, 103, 101, 116, 95, 114, 101, 97, 100, 121, 41, 125, 10, 117, 61,
  123, 40, 36, 100, 112, 61, 61, 49, 41, 45, 40, 36, 100, 112, 61, 61,
  51, 41, 125, 10, 118, 61, 123, 40, 36, 100, 112, 61, 61, 50, 41, 45,
  40, 36, 100, 112, 61, 61, 52, 41, 125, 10, 120, 112, 61, 123, 40, 36,
  120, 112, 43, 50, 42, 36, 117, 41, 37, 40, 49, 54, 42, 36, 109, 119,
  41, 125, 10, 121, 112, 61, 123, 40, 36, 121, 112, 43, 50, 42, 36, 118,
  41, 37, 40, 49, 54, 42, 36, 109, 104, 41, 125, 10, 45, 105, 102, 32,
  123, 36, 112, 97, 99, 103, 117, 109, 95, 116, 105, 109, 101, 114, 62, 61,
  48, 34, 32, 38, 38, 32, 34, 64, 124, 62, 36, 112, 97, 99, 103, 117,
  109, 95, 116, 105, 109, 101, 114, 43, 49, 48, 125, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 52, 32, 120, 103, 36, 62, 61, 123, 36, 123, 120, 103,
  36, 62, 125, 38, 45, 50, 125, 32, 121, 103, 36, 62, 61, 123, 36, 123,
  121, 103, 36, 62, 125, 38, 45, 50, 125, 32, 109, 103, 36, 62, 61, 123,
  105, 102, 40, 36, 123, 109, 103, 36, 62, 125, 61, 61, 49, 44, 48, 44,
  36, 123, 109, 103, 36, 62, 125, 41, 125, 32, 45, 100, 111, 110, 101, 10,
  112, 97, 99, 103, 117, 109, 95, 116, 105, 109, 101, 114, 61, 45, 49, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 33, 36, 105, 115,
  95, 103, 101, 116, 95, 114, 101, 97, 100, 121, 34, 32, 38, 38, 32, 34,
  40, 64, 124, 45, 36, 102, 114, 117, 105, 116, 95, 116, 105, 109, 101, 114,
  41, 62, 61, 49, 48, 125, 10, 120, 61, 123, 114, 111, 117, 110, 100, 40,
  63, 40, 48, 44, 64, 123, 109, 97, 112, 48, 44, 119, 125, 41, 41, 125,
  10, 121, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 64, 123,
  109, 97, 112, 48, 44, 104, 125, 41, 41, 125, 10, 45, 105, 102, 32, 123,
  33, 64, 123, 109, 97, 112, 44, 40, 36, 120, 44, 36, 121, 41, 125, 34,
  32, 38, 38, 32, 34, 64, 123, 109, 97, 112, 48, 44, 40, 36, 120, 44,
  36, 121, 41, 125, 61, 61, 50, 125, 10, 110, 61, 123, 109, 105, 110, 40,
  51, 44, 105, 110, 116, 40, 97, 98, 115, 40, 103, 42, 49, 46, 55, 41,
  41, 41, 125, 32, 45, 61, 91, 109, 97, 112, 93, 32, 123, 52, 43, 36,
  110, 125, 44, 36, 120, 44, 36, 121, 32, 45, 106, 91, 118, 105, 115, 117,
  93, 32, 91, 102, 114, 117, 105, 116, 36, 110, 93, 44, 123, 49, 54, 42,
  36, 120, 125, 44, 123, 49, 54, 42, 36, 121, 43, 50, 52, 125, 32, 102,
  114, 117, 105, 116, 95, 116, 105, 109, 101, 114, 61, 64, 124, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 33, 64, 33, 34, 32, 124, 124, 32,
  34, 64, 123, 33, 44, 81, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33,
  44, 69, 83, 67, 125, 125, 32, 105, 115, 95, 113, 117, 105, 116, 61, 49,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123,
  33, 36, 105, 115, 95, 113, 117, 105, 116, 34, 32, 38, 38, 32, 34, 36,
  112, 97, 99, 100, 111, 116, 115, 125, 10, 45, 105, 102, 32, 36, 105, 115,
  95, 113, 117, 105, 116, 32, 45, 98, 114, 101, 97, 107, 10, 45, 101, 108,
  105, 102, 32, 36, 112, 97, 99, 100, 111, 116, 115, 10, 108, 105, 118, 101,
  115, 61, 123, 36, 108, 105, 118, 101, 115, 45, 49, 125, 10, 45, 101, 108,
  115, 101, 10, 108, 101, 118, 101, 108, 61, 123, 45, 36, 108, 101, 118, 101,
  108, 45, 49, 125, 32, 45, 119, 97, 105, 116, 91, 48, 93, 32, 45, 49,
  10, 45, 114, 109, 91, 109, 97, 112, 48, 44, 109, 97, 112, 44, 99, 97,
  110, 95, 103, 111, 44, 112, 97, 116, 104, 93, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 114, 109, 91, 118, 105, 115, 117, 44, 108, 101, 118, 101, 108,
  95, 78, 44, 108, 101, 118, 101, 108, 109, 95, 78, 93, 10, 45, 119, 104,
  105, 108, 101, 32, 36, 108, 105, 118, 101, 115, 10, 45, 114, 109, 32, 45,
  119, 32, 48, 32, 45, 118, 32, 43, 10, 95, 112, 97, 99, 109, 97, 110,
  95, 103, 104, 111, 115, 116, 95, 115, 116, 97, 110, 100, 97, 114, 100, 95,
  103, 102, 120, 32, 58, 10, 45, 95, 112, 97, 99, 109, 97, 110, 95, 103,
  104, 111, 115, 116, 95, 98, 97, 115, 101, 95, 103, 102, 120, 32, 36, 52,
  32, 40, 48, 44, 36, 49, 94, 48, 44, 36, 50, 94, 48, 44, 36, 51,
  41, 32, 45, 109, 97, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 108, 105, 112, 115, 101,
  91, 45, 49, 93, 32, 49, 48, 44, 49, 49, 44, 51, 44, 52, 44, 48,
  44, 49, 44, 50, 53, 53, 32, 45, 101, 108, 108, 105, 112, 115, 101, 91,
  45, 49, 93, 32, 50, 48, 44, 49, 49, 44, 51, 44, 52, 44, 48, 44,
  49, 44, 50, 53, 53, 10, 45, 114, 91, 45, 49, 93, 32, 49, 54, 44,
  49, 54, 44, 49, 44, 51, 44, 50, 32, 45, 112, 111, 105, 110, 116, 91,
  45, 49, 93, 32, 53, 44, 123, 55, 45, 40, 36, 52, 62, 61, 50, 41,
  125, 44, 48, 44, 49, 44, 49, 32, 45, 112, 111, 105, 110, 116, 91, 45,
  49, 93, 32, 49, 48, 44, 123, 55, 45, 40, 36, 52, 62, 61, 50, 41,
  125, 44, 48, 44, 49, 44, 49, 10, 95, 112, 97, 99, 109, 97, 110, 95,
  103, 104, 111, 115, 116, 95, 97, 102, 114, 97, 105, 100, 95, 103, 102, 120,
  32, 58, 10, 45, 95, 112, 97, 99, 109, 97, 110, 95, 103, 104, 111, 115,
  116, 95, 98, 97, 115, 101, 95, 103, 102, 120, 32, 36, 49, 10, 45, 105,
  102, 32, 123, 36, 49, 60, 50, 125, 32, 99, 111, 108, 61, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 32, 40, 48, 44, 48, 94, 48, 44,
  48, 94, 48, 44, 50, 48, 56, 41, 32, 45, 101, 108, 115, 101, 32, 99,
  111, 108, 61, 50, 53, 53, 44, 48, 44, 48, 32, 40, 48, 44, 50, 52,
  56, 94, 48, 44, 50, 52, 56, 94, 48, 44, 50, 52, 56, 41, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 109, 97, 112, 91, 45, 50, 93, 32, 91,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 114, 91, 45,
  49, 93, 32, 49, 54, 44, 49, 54, 44, 49, 44, 51, 44, 50, 10, 45,
  108, 105, 110, 101, 91, 45, 49, 93, 32, 52, 44, 52, 44, 54, 44, 54,
  44, 49, 44, 36, 99, 111, 108, 44, 50, 53, 53, 32, 45, 108, 105, 110,
  101, 91, 45, 49, 93, 32, 52, 44, 54, 44, 54, 44, 52, 44, 49, 44,
  36, 99, 111, 108, 44, 50, 53, 53, 10, 45, 108, 105, 110, 101, 91, 45,
  49, 93, 32, 57, 44, 52, 44, 49, 49, 44, 54, 44, 49, 44, 36, 99,
  111, 108, 44, 50, 53, 53, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93,
  32, 57, 44, 54, 44, 49, 49, 44, 52, 44, 49, 44, 36, 99, 111, 108,
  44, 50, 53, 53, 10, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102, 40,
  121, 62, 61, 57, 38, 38, 121, 60, 61, 49, 48, 38, 38, 120, 62, 61,
  50, 38, 38, 120, 60, 61, 49, 51, 38, 38, 40, 40, 105, 110, 116, 40,
  40, 120, 43, 49, 41, 47, 50, 41, 43, 121, 41, 37, 50, 41, 44, 97,
  114, 103, 40, 99, 43, 49, 44, 36, 99, 111, 108, 41, 44, 105, 41, 39,
  10, 95, 112, 97, 99, 109, 97, 110, 95, 112, 97, 99, 109, 97, 110, 95,
  103, 102, 120, 32, 58, 10, 51, 50, 44, 51, 50, 44, 49, 44, 49, 44,
  39, 88, 61, 120, 45, 49, 53, 59, 89, 61, 121, 45, 49, 53, 59, 65,
  61, 97, 116, 97, 110, 50, 40, 89, 44, 88, 41, 59, 82, 61, 115, 113,
  114, 116, 40, 88, 94, 50, 43, 89, 94, 50, 41, 59, 82, 60, 49, 53,
  46, 53, 38, 38, 97, 98, 115, 40, 65, 41, 62, 48, 46, 56, 42, 48,
  46, 51, 51, 42, 36, 49, 39, 10, 40, 48, 44, 50, 53, 53, 94, 48,
  44, 50, 53, 53, 94, 48, 44, 48, 94, 48, 44, 50, 53, 53, 41, 32,
  45, 109, 97, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 114, 91, 45, 49, 93, 32, 49, 54, 44,
  49, 54, 44, 49, 44, 52, 44, 50, 32, 45, 115, 91, 45, 49, 93, 32,
  99, 44, 45, 51, 10, 95, 112, 97, 99, 109, 97, 110, 95, 112, 97, 99,
  100, 111, 116, 115, 95, 103, 102, 120, 32, 58, 10, 40, 50, 53, 53, 94,
  49, 56, 52, 94, 49, 53, 49, 41, 32, 45, 114, 91, 45, 49, 93, 32,
  52, 44, 52, 44, 49, 44, 51, 32, 45, 114, 91, 45, 49, 93, 32, 49,
  54, 44, 49, 54, 44, 49, 44, 51, 44, 48, 44, 48, 44, 48, 46, 53,
  44, 48, 46, 53, 10, 95, 112, 97, 99, 109, 97, 110, 95, 112, 97, 99,
  103, 117, 109, 95, 103, 102, 120, 32, 58, 10, 49, 54, 44, 49, 54, 44,
  49, 44, 51, 32, 45, 99, 105, 114, 99, 108, 101, 91, 45, 49, 93, 32,
  55, 44, 55, 44, 55, 44, 49, 44, 50, 53, 53, 44, 49, 50, 56, 44,
  54, 52, 10, 95, 112, 97, 99, 109, 97, 110, 95, 99, 104, 101, 114, 114,
  121, 95, 103, 102, 120, 32, 58, 10, 40, 49, 50, 44, 49, 50, 44, 49,
  44, 49, 44, 48, 44, 45, 49, 48, 44, 45, 50, 44, 49, 44, 45, 56,
  44, 45, 52, 44, 49, 44, 45, 54, 44, 45, 50, 44, 49, 44, 48, 44,
  49, 44, 45, 55, 44, 48, 44, 49, 44, 45, 51, 44, 48, 44, 49, 44,
  45, 51, 44, 45, 52, 44, 50, 44, 45, 51, 44, 48, 44, 49, 44, 45,
  51, 44, 45, 54, 44, 50, 44, 48, 44, 49, 44, 45, 52, 44, 45, 53,
  44, 50, 44, 48, 44, 45, 52, 44, 50, 44, 45, 50, 44, 92, 10, 48,
  44, 50, 44, 51, 44, 45, 50, 44, 50, 44, 48, 44, 45, 54, 44, 50,
  44, 48, 44, 45, 50, 44, 50, 44, 51, 44, 50, 44, 48, 44, 45, 54,
  44, 50, 44, 45, 50, 44, 45, 51, 44, 50, 44, 48, 44, 50, 44, 51,
  44, 45, 52, 44, 50, 44, 45, 54, 44, 45, 50, 44, 50, 44, 51, 44,
  45, 51, 44, 50, 44, 45, 55, 44, 45, 52, 44, 50, 44, 45, 50, 44,
  48, 41, 10, 45, 117, 110, 99, 111, 109, 112, 114, 101, 115, 115, 95, 114,
  108, 101, 91, 45, 49, 93, 32, 40, 48, 44, 48, 44, 50, 53, 53, 44,
  50, 53, 53, 94, 48, 44, 49, 55, 51, 44, 48, 44, 50, 53, 53, 94,
  48, 44, 48, 44, 48, 44, 50, 53, 53, 41, 32, 45, 109, 97, 112, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 114, 50, 100, 121, 91, 45, 49, 93, 32, 49, 52, 32, 45, 114,
  91, 45, 49, 93, 32, 49, 54, 44, 49, 54, 44, 49, 44, 51, 44, 48,
  44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 95, 112, 97, 99, 109,
  97, 110, 95, 115, 116, 114, 97, 119, 98, 101, 114, 114, 121, 95, 103, 102,
  120, 32, 58, 10, 40, 49, 49, 44, 49, 50, 44, 49, 44, 49, 44, 48,
  44, 45, 53, 44, 48, 44, 51, 44, 45, 55, 44, 45, 51, 44, 49, 44,
  51, 44, 45, 51, 44, 49, 44, 45, 51, 44, 45, 50, 44, 50, 44, 45,
  53, 44, 49, 44, 45, 50, 44, 50, 44, 48, 44, 45, 52, 44, 50, 44,
  45, 51, 44, 49, 44, 45, 50, 44, 50, 44, 51, 44, 45, 50, 44, 50,
  44, 51, 44, 45, 53, 44, 50, 44, 51, 44, 45, 54, 44, 50, 44, 51,
  44, 92, 10, 50, 44, 51, 44, 45, 49, 51, 44, 50, 44, 51, 44, 45,
  50, 44, 50, 44, 48, 44, 50, 44, 51, 44, 45, 50, 44, 50, 44, 51,
  44, 45, 52, 44, 50, 44, 45, 50, 44, 45, 57, 44, 50, 44, 45, 51,
  44, 45, 50, 44, 50, 44, 51, 44, 45, 50, 44, 50, 44, 51, 44, 45,
  54, 44, 45, 53, 44, 50, 44, 45, 56, 44, 48, 44, 50, 44, 45, 53,
  44, 48, 41, 10, 45, 117, 110, 99, 111, 109, 112, 114, 101, 115, 115, 95,
  114, 108, 101, 91, 45, 49, 93, 32, 40, 48, 44, 48, 44, 50, 53, 53,
  44, 50, 53, 53, 94, 48, 44, 49, 55, 51, 44, 48, 44, 50, 53, 53,
  94, 48, 44, 48, 44, 48, 44, 50, 53, 53, 41, 32, 45, 109, 97, 112,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49,
  93, 32, 45, 114, 50, 100, 121, 91, 45, 49, 93, 32, 49, 52, 32, 45,
  114, 91, 45, 49, 93, 32, 49, 54, 44, 49, 54, 44, 49, 44, 51, 44,
  48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 95, 112, 97, 99,
  109, 97, 110, 95, 111, 114, 97, 110, 103, 101, 95, 103, 102, 120, 32, 58,
  10, 40, 49, 50, 44, 49, 51, 44, 49, 44, 49, 44, 48, 44, 45, 53,
  44, 48, 44, 49, 44, 48, 44, 45, 50, 44, 49, 44, 45, 56, 44, 45,
  54, 44, 49, 44, 45, 54, 44, 48, 44, 49, 44, 51, 44, 45, 51, 44,
  49, 44, 45, 52, 44, 45, 51, 44, 50, 44, 49, 44, 45, 52, 44, 50,
  44, 45, 51, 44, 45, 49, 48, 44, 50, 44, 48, 44, 45, 54, 48, 44,
  50, 44, 48, 44, 45, 49, 48, 44, 50, 44, 45, 50, 44, 45, 49, 48,
  44, 50, 44, 45, 52, 44, 45, 54, 44, 50, 44, 45, 51, 44, 48, 41,
  10, 45, 117, 110, 99, 111, 109, 112, 114, 101, 115, 115, 95, 114, 108, 101,
  91, 45, 49, 93, 32, 40, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53,
  53, 94, 48, 44, 49, 55, 51, 44, 49, 55, 51, 44, 50, 53, 53, 94,
  48, 44, 48, 44, 48, 44, 50, 53, 53, 41, 32, 45, 109, 97, 112, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 114, 50, 100, 121, 91, 45, 49, 93, 32, 49, 52, 32, 45, 114,
  91, 45, 49, 93, 32, 49, 54, 44, 49, 54, 44, 49, 44, 51, 44, 48,
  44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 95, 112, 97, 99, 109,
  97, 110, 95, 98, 97, 110, 97, 110, 97, 95, 103, 102, 120, 32, 58, 10,
  40, 57, 44, 49, 50, 44, 49, 44, 49, 44, 48, 44, 45, 55, 44, 48,
  44, 49, 44, 45, 55, 44, 45, 50, 44, 49, 44, 45, 55, 44, 45, 51,
  44, 49, 44, 45, 53, 44, 48, 44, 49, 44, 48, 44, 45, 50, 44, 49,
  44, 45, 53, 44, 48, 44, 49, 44, 48, 44, 45, 50, 44, 49, 44, 45,
  52, 44, 48, 44, 49, 44, 48, 44, 45, 51, 44, 49, 44, 45, 52, 44,
  48, 44, 49, 44, 48, 44, 45, 51, 44, 92, 10, 49, 44, 45, 51, 44,
  48, 44, 49, 44, 48, 44, 49, 44, 50, 44, 49, 44, 45, 51, 44, 48,
  44, 49, 44, 48, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 45, 50,
  44, 48, 44, 49, 44, 48, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44,
  45, 50, 44, 45, 54, 44, 49, 44, 45, 51, 44, 45, 52, 44, 49, 44,
  45, 53, 44, 48, 41, 10, 45, 117, 110, 99, 111, 109, 112, 114, 101, 115,
  115, 95, 114, 108, 101, 91, 45, 49, 93, 32, 40, 48, 44, 50, 53, 53,
  44, 50, 53, 53, 94, 48, 44, 49, 55, 51, 44, 50, 53, 53, 94, 48,
  44, 48, 44, 50, 53, 53, 41, 32, 45, 109, 97, 112, 91, 45, 50, 93,
  32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 114,
  50, 100, 121, 91, 45, 49, 93, 32, 49, 52, 32, 45, 114, 91, 45, 49,
  93, 32, 49, 54, 44, 49, 54, 44, 49, 44, 51, 44, 48, 44, 48, 44,
  48, 46, 53, 44, 48, 46, 53, 10, 95, 112, 97, 99, 109, 97, 110, 95,
  109, 97, 112, 95, 108, 101, 118, 101, 108, 49, 32, 58, 10, 40, 49, 49,
  44, 50, 56, 44, 49, 44, 49, 44, 48, 44, 45, 49, 50, 44, 49, 44,
  45, 53, 44, 50, 44, 49, 44, 45, 52, 44, 50, 44, 49, 44, 51, 44,
  45, 51, 44, 49, 44, 50, 44, 49, 44, 50, 44, 45, 52, 44, 49, 44,
  50, 44, 45, 51, 44, 49, 44, 50, 44, 49, 44, 50, 44, 45, 52, 44,
  49, 44, 45, 49, 48, 44, 50, 44, 45, 51, 44, 49, 44, 50, 44, 49,
  44, 50, 44, 45, 51, 44, 49, 44, 50, 44, 49, 44, 45, 50, 44, 48,
  44, 49, 44, 50, 44, 49, 44, 50, 44, 45, 51, 44, 49, 44, 50, 44,
  45, 52, 44, 49, 44, 92, 10, 50, 44, 49, 44, 50, 44, 45, 51, 44,
  49, 44, 50, 44, 49, 44, 45, 51, 44, 48, 44, 50, 44, 49, 44, 45,
  53, 44, 50, 44, 45, 52, 44, 49, 44, 50, 44, 45, 51, 44, 49, 44,
  48, 44, 45, 51, 44, 49, 44, 45, 50, 44, 48, 44, 49, 44, 50, 44,
  45, 51, 44, 49, 44, 48, 44, 45, 51, 44, 49, 44, 45, 50, 44, 48,
  44, 49, 44, 50, 44, 45, 57, 44, 48, 44, 49, 44, 50, 44, 45, 51,
  44, 49, 44, 48, 44, 45, 50, 44, 49, 44, 45, 51, 44, 48, 44, 49,
  44, 50, 44, 49, 44, 45, 51, 44, 48, 44, 49, 44, 45, 52, 44, 92,
  10, 48, 44, 49, 44, 50, 44, 49, 44, 48, 44, 49, 44, 48, 44, 49,
  44, 45, 50, 44, 45, 51, 44, 49, 44, 50, 44, 49, 44, 48, 44, 49,
  44, 48, 44, 45, 51, 44, 49, 44, 45, 51, 44, 48, 44, 50, 44, 45,
  50, 44, 48, 44, 49, 44, 45, 52, 44, 45, 51, 44, 49, 44, 50, 44,
  45, 53, 44, 49, 44, 48, 44, 49, 44, 45, 50, 44, 48, 44, 49, 44,
  45, 53, 44, 50, 44, 45, 50, 44, 48, 44, 49, 44, 45, 50, 44, 48,
  44, 49, 44, 50, 44, 45, 51, 44, 49, 44, 50, 44, 45, 54, 44, 49,
  44, 50, 44, 45, 51, 44, 49, 44, 50, 44, 92, 10, 45, 52, 44, 49,
  44, 45, 57, 44, 50, 44, 48, 44, 49, 44, 50, 44, 45, 51, 44, 49,
  44, 50, 44, 45, 51, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50,
  44, 45, 51, 44, 49, 44, 50, 44, 49, 44, 45, 51, 44, 50, 44, 45,
  50, 44, 49, 44, 51, 44, 45, 51, 44, 49, 44, 50, 44, 49, 44, 50,
  44, 45, 52, 44, 49, 44, 50, 44, 45, 51, 44, 49, 44, 50, 44, 49,
  44, 50, 44, 45, 52, 44, 49, 44, 45, 49, 48, 44, 50, 44, 45, 49,
  49, 44, 49, 41, 10, 45, 117, 110, 99, 111, 109, 112, 114, 101, 115, 115,
  95, 114, 108, 101, 91, 45, 49, 93, 32, 45, 45, 109, 105, 114, 114, 111,
  114, 91, 45, 49, 93, 32, 120, 32, 45, 99, 114, 111, 112, 91, 45, 49,
  93, 32, 49, 44, 49, 48, 48, 37, 32, 45, 97, 91, 45, 50, 44, 45,
  49, 93, 32, 120, 10, 95, 114, 108, 101, 118, 101, 108, 61, 51, 51, 32,
  95, 103, 108, 101, 118, 101, 108, 61, 51, 51, 32, 95, 98, 108, 101, 118,
  101, 108, 61, 50, 53, 53, 10, 95, 112, 97, 99, 109, 97, 110, 95, 109,
  97, 112, 95, 108, 101, 118, 101, 108, 50, 32, 58, 10, 40, 49, 49, 44,
  50, 56, 44, 49, 44, 49, 44, 48, 44, 45, 49, 50, 44, 49, 44, 45,
  49, 48, 44, 50, 44, 49, 44, 51, 44, 49, 44, 50, 44, 45, 51, 44,
  49, 44, 50, 44, 45, 52, 44, 49, 44, 50, 44, 49, 44, 50, 44, 45,
  51, 44, 49, 44, 50, 44, 49, 44, 45, 50, 44, 50, 44, 49, 44, 50,
  44, 49, 44, 45, 53, 44, 50, 44, 49, 44, 50, 44, 45, 50, 44, 49,
  44, 50, 44, 45, 51, 44, 49, 44, 50, 44, 49, 44, 50, 44, 49, 44,
  50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 51, 44, 49, 44, 50, 44,
  49, 44, 50, 44, 49, 44, 92, 10, 50, 44, 45, 50, 44, 49, 44, 45,
  53, 44, 50, 44, 49, 44, 45, 51, 44, 50, 44, 45, 52, 44, 49, 44,
  50, 44, 45, 53, 44, 49, 44, 48, 44, 49, 44, 45, 50, 44, 48, 44,
  49, 44, 50, 44, 45, 53, 44, 49, 44, 48, 44, 49, 44, 45, 50, 44,
  48, 44, 49, 44, 50, 44, 45, 53, 44, 49, 44, 48, 44, 49, 44, 45,
  50, 44, 48, 44, 49, 44, 45, 51, 44, 50, 44, 49, 44, 45, 52, 44,
  45, 51, 44, 49, 44, 48, 44, 49, 44, 50, 44, 49, 44, 48, 44, 45,
  50, 44, 49, 44, 45, 53, 44, 48, 44, 49, 44, 50, 44, 49, 44, 48,
  44, 49, 44, 92, 10, 45, 50, 44, 45, 53, 44, 49, 44, 50, 44, 45,
  50, 44, 48, 44, 49, 44, 45, 50, 44, 45, 53, 44, 49, 44, 50, 44,
  49, 44, 48, 44, 45, 51, 44, 49, 44, 45, 52, 44, 48, 44, 49, 44,
  50, 44, 49, 44, 45, 52, 44, 45, 51, 44, 49, 44, 45, 51, 44, 50,
  44, 45, 51, 44, 49, 44, 48, 44, 49, 44, 45, 50, 44, 48, 44, 49,
  44, 50, 44, 49, 44, 45, 51, 44, 50, 44, 45, 50, 44, 48, 44, 49,
  44, 45, 50, 44, 48, 44, 49, 44, 50, 44, 45, 51, 44, 49, 44, 50,
  44, 49, 44, 48, 44, 45, 52, 44, 49, 44, 50, 44, 45, 51, 44, 49,
  44, 92, 10, 50, 44, 49, 44, 48, 44, 45, 50, 44, 49, 44, 45, 55,
  44, 50, 44, 49, 44, 45, 50, 44, 48, 44, 49, 44, 50, 44, 45, 51,
  44, 49, 44, 50, 44, 49, 44, 50, 44, 45, 52, 44, 49, 44, 50, 44,
  49, 44, 45, 51, 44, 50, 44, 49, 44, 45, 52, 44, 50, 44, 49, 44,
  51, 44, 49, 44, 50, 44, 45, 53, 44, 49, 44, 50, 44, 45, 50, 44,
  49, 44, 50, 44, 49, 44, 50, 44, 45, 53, 44, 49, 44, 50, 44, 45,
  50, 44, 49, 44, 45, 57, 44, 50, 44, 45, 49, 50, 44, 49, 41, 10,
  45, 117, 110, 99, 111, 109, 112, 114, 101, 115, 115, 95, 114, 108, 101, 91,
  45, 49, 93, 32, 45, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93,
  32, 120, 32, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 49, 44, 49,
  48, 48, 37, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 10,
  95, 114, 108, 101, 118, 101, 108, 61, 50, 48, 48, 32, 95, 103, 108, 101,
  118, 101, 108, 61, 51, 51, 32, 95, 98, 108, 101, 118, 101, 108, 61, 51,
  51, 10, 95, 112, 97, 99, 109, 97, 110, 95, 109, 97, 112, 95, 108, 101,
  118, 101, 108, 51, 32, 58, 10, 40, 49, 49, 44, 50, 56, 44, 49, 44,
  49, 44, 48, 44, 45, 49, 49, 44, 49, 44, 45, 54, 44, 48, 44, 49,
  44, 45, 52, 44, 50, 44, 45, 53, 44, 49, 44, 48, 44, 49, 44, 50,
  44, 45, 56, 44, 49, 44, 48, 44, 49, 44, 50, 44, 45, 52, 44, 49,
  44, 51, 44, 45, 56, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45,
  53, 44, 49, 44, 50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50,
  44, 45, 53, 44, 49, 44, 50, 44, 49, 44, 50, 44, 45, 50, 44, 49,
  44, 50, 44, 49, 44, 45, 53, 44, 50, 44, 49, 44, 50, 44, 45, 50,
  44, 49, 44, 50, 44, 92, 10, 49, 44, 50, 44, 45, 51, 44, 49, 44,
  48, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 45, 53, 44, 50, 44,
  49, 44, 48, 44, 49, 44, 45, 50, 44, 50, 44, 45, 53, 44, 49, 44,
  50, 44, 49, 44, 48, 44, 45, 52, 44, 49, 44, 45, 53, 44, 50, 44,
  49, 44, 45, 52, 44, 48, 44, 49, 44, 50, 44, 45, 51, 44, 49, 44,
  50, 44, 49, 44, 48, 44, 45, 50, 44, 49, 44, 48, 44, 49, 44, 50,
  44, 45, 51, 44, 49, 44, 50, 44, 49, 44, 48, 44, 49, 44, 45, 50,
  44, 48, 44, 49, 44, 45, 51, 44, 50, 44, 49, 44, 50, 44, 45, 50,
  44, 48, 44, 49, 44, 92, 10, 45, 50, 44, 45, 51, 44, 49, 44, 50,
  44, 49, 44, 50, 44, 49, 44, 48, 44, 45, 51, 44, 49, 44, 45, 50,
  44, 48, 44, 49, 44, 50, 44, 49, 44, 50, 44, 49, 44, 45, 54, 44,
  48, 44, 49, 44, 50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 48,
  44, 45, 50, 44, 49, 44, 45, 50, 44, 48, 44, 49, 44, 50, 44, 49,
  44, 50, 44, 45, 50, 44, 49, 44, 48, 44, 45, 50, 44, 49, 44, 45,
  50, 44, 48, 44, 49, 44, 45, 54, 44, 50, 44, 45, 53, 44, 49, 44,
  50, 44, 45, 52, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 45, 51,
  44, 45, 51, 44, 50, 44, 92, 10, 49, 44, 45, 51, 44, 50, 44, 48,
  44, 45, 51, 44, 49, 44, 50, 44, 49, 44, 50, 44, 49, 44, 50, 44,
  45, 52, 44, 49, 44, 51, 44, 45, 50, 44, 50, 44, 49, 44, 45, 53,
  44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 51, 44, 49, 44, 50,
  44, 45, 51, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45,
  51, 44, 49, 44, 50, 44, 45, 51, 44, 49, 44, 50, 44, 45, 50, 44,
  49, 44, 45, 49, 48, 44, 50, 44, 45, 49, 49, 44, 49, 41, 10, 45,
  117, 110, 99, 111, 109, 112, 114, 101, 115, 115, 95, 114, 108, 101, 91, 45,
  49, 93, 32, 45, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32,
  120, 32, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 49, 44, 49, 48,
  48, 37, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 10, 95,
  114, 108, 101, 118, 101, 108, 61, 51, 51, 32, 95, 103, 108, 101, 118, 101,
  108, 61, 50, 48, 48, 32, 95, 98, 108, 101, 118, 101, 108, 61, 50, 53,
  53, 10, 95, 112, 97, 99, 109, 97, 110, 95, 109, 97, 112, 95, 108, 101,
  118, 101, 108, 52, 32, 58, 10, 40, 49, 49, 44, 50, 56, 44, 49, 44,
  49, 44, 48, 44, 45, 57, 44, 49, 44, 45, 50, 44, 48, 44, 49, 44,
  45, 55, 44, 50, 44, 49, 44, 45, 50, 44, 48, 44, 49, 44, 50, 44,
  45, 50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 49, 44,
  45, 50, 44, 48, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44,
  45, 50, 44, 49, 44, 50, 44, 49, 44, 45, 50, 44, 48, 44, 49, 44,
  45, 51, 44, 50, 44, 51, 44, 45, 51, 44, 50, 44, 45, 52, 44, 49,
  44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 45,
  52, 44, 50, 44, 49, 44, 50, 44, 92, 10, 45, 50, 44, 49, 44, 50,
  44, 45, 50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 49,
  44, 45, 55, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 49, 44, 50,
  44, 45, 50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 45, 52, 44,
  50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 50, 44,
  49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 49, 44, 45, 55, 44,
  50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 51, 44, 49, 44, 45, 49,
  48, 44, 48, 44, 49, 44, 45, 53, 44, 45, 50, 44, 49, 44, 48, 44,
  45, 51, 44, 49, 44, 45, 53, 44, 48, 44, 49, 44, 92, 10, 45, 49,
  48, 44, 48, 44, 49, 44, 45, 50, 44, 45, 51, 44, 49, 44, 45, 53,
  44, 45, 54, 44, 49, 44, 45, 56, 44, 48, 44, 49, 44, 50, 44, 45,
  57, 44, 48, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45,
  50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 49, 44, 50,
  44, 45, 50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45,
  50, 44, 49, 44, 50, 44, 49, 44, 45, 49, 48, 44, 50, 44, 49, 44,
  50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44,
  45, 51, 44, 48, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44,
  92, 10, 45, 50, 44, 49, 44, 50, 44, 48, 44, 45, 51, 44, 49, 44,
  45, 51, 44, 50, 44, 51, 44, 45, 52, 44, 50, 44, 49, 44, 48, 44,
  49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44,
  50, 44, 45, 50, 44, 49, 44, 48, 44, 49, 44, 50, 44, 45, 50, 44,
  49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 49, 44, 45, 50, 44,
  48, 44, 49, 44, 45, 55, 44, 50, 44, 49, 44, 45, 50, 44, 45, 57,
  44, 49, 44, 45, 50, 44, 48, 41, 10, 45, 117, 110, 99, 111, 109, 112,
  114, 101, 115, 115, 95, 114, 108, 101, 91, 45, 49, 93, 32, 45, 45, 109,
  105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 120, 32, 45, 99, 114, 111,
  112, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48, 37, 32, 45, 97, 91,
  45, 50, 44, 45, 49, 93, 32, 120, 10, 95, 114, 108, 101, 118, 101, 108,
  61, 50, 48, 48, 32, 95, 103, 108, 101, 118, 101, 108, 61, 50, 48, 48,
  32, 95, 98, 108, 101, 118, 101, 108, 61, 51, 51, 10, 95, 112, 97, 99,
  109, 97, 110, 95, 109, 97, 112, 95, 108, 101, 118, 101, 108, 53, 32, 58,
  10, 40, 49, 49, 44, 50, 56, 44, 49, 44, 49, 44, 48, 44, 45, 49,
  50, 44, 49, 44, 45, 55, 44, 50, 44, 49, 44, 45, 50, 44, 50, 44,
  49, 44, 51, 44, 45, 53, 44, 49, 44, 50, 44, 49, 44, 50, 44, 45,
  50, 44, 49, 44, 50, 44, 45, 53, 44, 49, 44, 50, 44, 49, 44, 50,
  44, 45, 50, 44, 49, 44, 50, 44, 49, 44, 45, 55, 44, 50, 44, 45,
  50, 44, 49, 44, 45, 51, 44, 50, 44, 49, 44, 50, 44, 45, 51, 44,
  49, 44, 50, 44, 45, 52, 44, 49, 44, 50, 44, 49, 44, 50, 44, 49,
  44, 48, 44, 49, 44, 50, 44, 45, 52, 44, 49, 44, 50, 44, 49, 44,
  50, 44, 92, 10, 45, 51, 44, 49, 44, 50, 44, 49, 44, 45, 52, 44,
  48, 44, 49, 44, 45, 54, 44, 50, 44, 49, 44, 50, 44, 49, 44, 48,
  44, 45, 51, 44, 49, 44, 48, 44, 45, 52, 44, 49, 44, 50, 44, 49,
  44, 48, 44, 45, 51, 44, 49, 44, 48, 44, 45, 52, 44, 49, 44, 50,
  44, 49, 44, 45, 56, 44, 48, 44, 49, 44, 50, 44, 45, 51, 44, 49,
  44, 48, 44, 49, 44, 48, 44, 45, 50, 44, 49, 44, 48, 44, 49, 44,
  50, 44, 45, 51, 44, 49, 44, 48, 44, 49, 44, 48, 44, 49, 44, 45,
  50, 44, 48, 44, 49, 44, 50, 44, 45, 52, 44, 48, 44, 49, 44, 48,
  44, 49, 44, 45, 50, 44, 92, 10, 48, 44, 49, 44, 50, 44, 49, 44,
  48, 44, 45, 51, 44, 49, 44, 48, 44, 45, 52, 44, 49, 44, 50, 44,
  49, 44, 45, 56, 44, 48, 44, 49, 44, 50, 44, 45, 51, 44, 49, 44,
  48, 44, 45, 51, 44, 49, 44, 48, 44, 45, 50, 44, 49, 44, 45, 53,
  44, 50, 44, 49, 44, 45, 51, 44, 50, 44, 45, 52, 44, 49, 44, 50,
  44, 49, 44, 50, 44, 49, 44, 50, 44, 45, 54, 44, 49, 44, 50, 44,
  49, 44, 50, 44, 49, 44, 50, 44, 45, 52, 44, 49, 44, 51, 44, 45,
  50, 44, 50, 44, 49, 44, 45, 53, 44, 50, 44, 48, 44, 49, 44, 50,
  44, 45, 51, 44, 49, 44, 50, 44, 45, 51, 44, 92, 10, 49, 44, 50,
  44, 45, 50, 44, 49, 44, 45, 53, 44, 50, 44, 49, 44, 45, 51, 44,
  50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 51, 44, 49, 44, 50, 44,
  49, 44, 50, 44, 45, 52, 44, 49, 44, 50, 44, 45, 51, 44, 49, 44,
  50, 44, 49, 44, 50, 44, 45, 52, 44, 49, 44, 45, 53, 44, 50, 44,
  49, 44, 45, 52, 44, 50, 44, 45, 49, 49, 44, 49, 41, 10, 45, 117,
  110, 99, 111, 109, 112, 114, 101, 115, 115, 95, 114, 108, 101, 91, 45, 49,
  93, 32, 45, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 120,
  32, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48,
  37, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 10, 95, 114,
  108, 101, 118, 101, 108, 61, 50, 48, 48, 32, 95, 103, 108, 101, 118, 101,
  108, 61, 50, 53, 53, 32, 95, 98, 108, 101, 118, 101, 108, 61, 51, 51,
  10, 95, 112, 97, 99, 109, 97, 110, 95, 109, 97, 112, 95, 108, 101, 118,
  101, 108, 54, 32, 58, 10, 40, 49, 49, 44, 50, 56, 44, 49, 44, 49,
  44, 48, 44, 45, 49, 50, 44, 49, 44, 45, 49, 48, 44, 50, 44, 49,
  44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 55, 44, 49, 44, 51,
  44, 45, 57, 44, 50, 44, 45, 53, 44, 49, 44, 50, 44, 45, 54, 44,
  49, 44, 45, 49, 48, 44, 50, 44, 49, 44, 50, 44, 45, 52, 44, 49,
  44, 48, 44, 45, 53, 44, 49, 44, 50, 44, 49, 44, 45, 56, 44, 48,
  44, 49, 44, 50, 44, 49, 44, 48, 44, 45, 51, 44, 49, 44, 48, 44,
  45, 51, 44, 49, 44, 48, 44, 50, 44, 49, 44, 48, 44, 49, 44, 45,
  54, 44, 50, 44, 49, 44, 50, 44, 92, 10, 45, 50, 44, 48, 44, 49,
  44, 50, 44, 45, 50, 44, 49, 44, 48, 44, 45, 51, 44, 49, 44, 50,
  44, 49, 44, 45, 50, 44, 48, 44, 50, 44, 49, 44, 45, 52, 44, 48,
  44, 49, 44, 50, 44, 49, 44, 48, 44, 49, 44, 50, 44, 45, 50, 44,
  45, 50, 44, 49, 44, 48, 44, 49, 44, 50, 44, 49, 44, 48, 44, 49,
  44, 50, 44, 49, 44, 48, 44, 49, 44, 45, 50, 44, 48, 44, 49, 44,
  50, 44, 49, 44, 48, 44, 49, 44, 50, 44, 49, 44, 48, 44, 49, 44,
  45, 50, 44, 48, 44, 49, 44, 50, 44, 49, 44, 48, 44, 49, 44, 50,
  44, 45, 50, 44, 45, 52, 44, 49, 44, 50, 44, 92, 10, 49, 44, 45,
  50, 44, 48, 44, 50, 44, 49, 44, 45, 52, 44, 48, 44, 49, 44, 50,
  44, 45, 50, 44, 48, 44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 48,
  44, 45, 50, 44, 49, 44, 48, 44, 50, 44, 49, 44, 48, 44, 49, 44,
  45, 54, 44, 50, 44, 49, 44, 50, 44, 49, 44, 48, 44, 45, 51, 44,
  49, 44, 48, 44, 45, 52, 44, 49, 44, 50, 44, 49, 44, 45, 56, 44,
  48, 44, 49, 44, 50, 44, 45, 52, 44, 49, 44, 48, 44, 45, 51, 44,
  49, 44, 48, 44, 49, 44, 45, 49, 48, 44, 50, 44, 45, 53, 44, 49,
  44, 50, 44, 45, 54, 44, 49, 44, 51, 44, 45, 57, 44, 92, 10, 50,
  44, 49, 44, 50, 44, 45, 50, 44, 49, 44, 50, 44, 45, 55, 44, 49,
  44, 45, 49, 48, 44, 50, 44, 45, 49, 49, 44, 49, 41, 10, 45, 117,
  110, 99, 111, 109, 112, 114, 101, 115, 115, 95, 114, 108, 101, 91, 45, 49,
  93, 32, 45, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 120,
  32, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48,
  37, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 10, 95, 114,
  108, 101, 118, 101, 108, 61, 50, 53, 53, 32, 95, 103, 108, 101, 118, 101,
  108, 61, 49, 51, 48, 32, 95, 98, 108, 101, 118, 101, 108, 61, 50, 51,
  51, 10, 120, 95, 112, 97, 105, 110, 116, 32, 58, 10, 45, 101, 91, 93,
  32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 73, 110, 116, 101,
  114, 97, 99, 116, 105, 118, 101, 32, 112, 97, 105, 110, 116, 101, 114, 32,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110,
  10, 45, 45, 45, 45, 32, 85, 115, 101, 32, 109, 111, 117, 115, 101, 32,
  116, 111, 32, 115, 101, 108, 101, 99, 116, 32, 99, 111, 108, 111, 114, 32,
  97, 110, 100, 32, 98, 114, 117, 115, 104, 46, 92, 110, 10, 45, 45, 45,
  45, 32, 76, 101, 102, 116, 32, 98, 117, 116, 116, 111, 110, 32, 100, 114,
  97, 119, 115, 32, 97, 32, 99, 111, 108, 111, 114, 101, 100, 32, 115, 116,
  114, 111, 107, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 82, 105, 103,
  104, 116, 32, 98, 117, 116, 116, 111, 110, 32, 102, 105, 108, 108, 115, 32,
  97, 32, 99, 111, 108, 111, 114, 101, 100, 32, 114, 101, 103, 105, 111, 110,
  46, 92, 110, 10, 45, 45, 45, 45, 32, 65, 114, 114, 111, 119, 32, 107,
  101, 121, 115, 32, 111, 114, 32, 83, 80, 65, 67, 69, 32, 97, 110, 100,
  32, 66, 65, 67, 75, 83, 80, 65, 67, 69, 32, 116, 111, 32, 115, 119,
  97, 112, 92, 110, 10, 45, 45, 45, 45, 32, 98, 101, 116, 119, 101, 101,
  110, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 32, 105, 109, 97, 103,
  101, 115, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 32, 39,
  83, 39, 32, 116, 111, 32, 115, 97, 118, 101, 32, 115, 110, 97, 112, 115,
  104, 111, 116, 32, 111, 102, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101,
  110, 116, 32, 118, 105, 101, 119, 46, 92, 110, 10, 45, 45, 45, 45, 32,
  75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81,
  39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45,
  45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 32, 45, 116, 111,
  95, 114, 103, 98, 10, 45, 105, 102, 32, 123, 33, 64, 35, 125, 32, 45,
  105, 91, 48, 93, 32, 53, 49, 50, 44, 53, 49, 50, 44, 49, 44, 51,
  44, 50, 53, 53, 32, 45, 110, 109, 91, 48, 93, 32, 34, 91, 78, 101,
  119, 32, 105, 109, 97, 103, 101, 93, 34, 32, 45, 101, 110, 100, 105, 102,
  10, 99, 111, 108, 111, 114, 61, 48, 44, 48, 44, 48, 10, 115, 97, 116,
  117, 114, 97, 116, 105, 111, 110, 61, 49, 10, 98, 114, 117, 115, 104, 115,
  105, 122, 101, 61, 51, 10, 98, 114, 117, 115, 104, 111, 112, 97, 99, 105,
  116, 121, 61, 48, 10, 98, 114, 117, 115, 104, 97, 110, 103, 108, 101, 61,
  57, 48, 10, 98, 114, 117, 115, 104, 116, 104, 105, 99, 107, 110, 101, 115,
  115, 61, 49, 10, 105, 109, 97, 103, 101, 61, 48, 10, 114, 101, 102, 114,
  101, 115, 104, 95, 112, 97, 108, 101, 116, 116, 101, 61, 49, 10, 114, 101,
  102, 114, 101, 115, 104, 95, 105, 109, 97, 103, 101, 61, 49, 10, 114, 101,
  102, 114, 101, 115, 104, 95, 98, 114, 117, 115, 104, 61, 49, 10, 111, 120,
  49, 61, 45, 49, 10, 111, 121, 49, 61, 45, 49, 10, 49, 32, 49, 10,
  45, 100, 111, 10, 45, 105, 102, 32, 36, 114, 101, 102, 114, 101, 115, 104,
  95, 112, 97, 108, 101, 116, 116, 101, 10, 45, 114, 109, 91, 45, 50, 93,
  32, 40, 48, 44, 51, 53, 57, 59, 48, 44, 51, 53, 57, 94, 36, 115,
  97, 116, 117, 114, 97, 116, 105, 111, 110, 44, 36, 115, 97, 116, 117, 114,
  97, 116, 105, 111, 110, 59, 36, 115, 97, 116, 117, 114, 97, 116, 105, 111,
  110, 44, 36, 115, 97, 116, 117, 114, 97, 116, 105, 111, 110, 94, 49, 44,
  49, 59, 48, 44, 48, 41, 32, 45, 114, 91, 45, 49, 93, 32, 50, 53,
  54, 44, 54, 52, 44, 49, 44, 51, 44, 51, 32, 45, 104, 115, 118, 50,
  114, 103, 98, 91, 45, 49, 93, 10, 40, 50, 53, 53, 59, 48, 41, 32,
  45, 114, 91, 45, 49, 93, 32, 49, 54, 44, 64, 123, 45, 50, 44, 104,
  125, 44, 49, 44, 51, 44, 51, 32, 45, 108, 105, 110, 101, 91, 45, 49,
  93, 32, 48, 44, 48, 44, 48, 44, 49, 48, 48, 37, 44, 49, 44, 48,
  32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 10, 123, 119, 125,
  44, 49, 54, 44, 49, 44, 51, 32, 45, 116, 91, 45, 49, 93, 32, 34,
  83, 101, 108, 101, 99, 116, 101, 100, 32, 99, 111, 108, 111, 114, 34, 44,
  52, 44, 50, 44, 49, 51, 44, 49, 44, 50, 53, 53, 10, 45, 114, 101,
  99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 56, 48, 44, 51,
  44, 49, 48, 48, 44, 49, 51, 44, 49, 44, 36, 99, 111, 108, 111, 114,
  10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32,
  56, 48, 44, 51, 44, 49, 48, 48, 44, 49, 51, 44, 49, 44, 48, 120,
  70, 70, 70, 70, 70, 70, 70, 70, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 50, 53, 53, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121,
  32, 45, 119, 50, 91, 45, 49, 93, 32, 123, 119, 125, 44, 123, 104, 125,
  44, 48, 44, 34, 80, 97, 108, 101, 116, 116, 101, 34, 32, 45, 109, 118,
  91, 45, 49, 93, 32, 45, 50, 10, 114, 101, 102, 114, 101, 115, 104, 95,
  112, 97, 108, 101, 116, 116, 101, 61, 48, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 36, 114, 101, 102, 114, 101, 115, 104, 95, 98, 114,
  117, 115, 104, 10, 45, 114, 109, 91, 45, 49, 93, 32, 40, 51, 50, 44,
  54, 52, 59, 54, 52, 44, 51, 50, 41, 32, 45, 114, 91, 45, 49, 93,
  32, 49, 54, 44, 49, 54, 44, 49, 44, 51, 44, 49, 32, 45, 114, 91,
  45, 49, 93, 32, 123, 56, 42, 52, 56, 125, 44, 123, 52, 42, 52, 56,
  125, 44, 49, 44, 51, 44, 48, 44, 50, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 52, 32, 45, 114, 101, 112, 101, 97, 116, 32, 56, 10, 45, 101,
  108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 123, 52, 56, 42, 36,
  62, 43, 50, 52, 125, 44, 123, 52, 56, 42, 64, 123, 62, 44, 45, 50,
  125, 43, 50, 52, 125, 44, 123, 50, 42, 36, 62, 43, 49, 125, 44, 123,
  40, 50, 42, 36, 62, 43, 49, 41, 42, 36, 98, 114, 117, 115, 104, 116,
  104, 105, 99, 107, 110, 101, 115, 115, 125, 44, 36, 98, 114, 117, 115, 104,
  97, 110, 103, 108, 101, 44, 123, 49, 45, 64, 123, 62, 44, 45, 50, 125,
  47, 52, 125, 44, 50, 53, 53, 10, 45, 100, 111, 110, 101, 32, 45, 100,
  111, 110, 101, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45,
  49, 93, 32, 123, 36, 98, 114, 117, 115, 104, 115, 105, 122, 101, 42, 52,
  56, 125, 44, 123, 36, 98, 114, 117, 115, 104, 111, 112, 97, 99, 105, 116,
  121, 42, 52, 56, 125, 44, 92, 10, 123, 36, 98, 114, 117, 115, 104, 115,
  105, 122, 101, 42, 52, 56, 43, 52, 55, 125, 44, 123, 36, 98, 114, 117,
  115, 104, 111, 112, 97, 99, 105, 116, 121, 42, 52, 56, 43, 52, 55, 125,
  44, 92, 10, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44,
  50, 53, 53, 44, 49, 50, 56, 44, 49, 50, 56, 10, 123, 119, 125, 44,
  49, 54, 44, 49, 44, 51, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93,
  32, 48, 44, 53, 48, 37, 44, 49, 48, 48, 37, 44, 53, 48, 37, 44,
  49, 44, 48, 120, 53, 53, 53, 53, 53, 53, 53, 53, 44, 49, 50, 56,
  44, 54, 52, 44, 49, 50, 56, 10, 98, 120, 61, 123, 36, 98, 114, 117,
  115, 104, 97, 110, 103, 108, 101, 42, 119, 47, 49, 56, 48, 125, 10, 45,
  114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 123, 36,
  98, 120, 45, 49, 54, 125, 44, 50, 48, 37, 44, 123, 36, 98, 120, 43,
  49, 54, 125, 44, 56, 48, 37, 44, 49, 44, 49, 50, 56, 10, 45, 108,
  105, 110, 101, 91, 45, 49, 93, 32, 123, 36, 98, 120, 45, 49, 54, 125,
  44, 50, 48, 37, 44, 123, 36, 98, 120, 43, 49, 54, 125, 44, 50, 48,
  37, 44, 49, 44, 50, 53, 53, 32, 45, 108, 105, 110, 101, 91, 45, 49,
  93, 32, 123, 36, 98, 120, 43, 49, 54, 125, 44, 50, 48, 37, 44, 123,
  36, 98, 120, 43, 49, 54, 125, 44, 56, 48, 37, 44, 49, 44, 50, 53,
  53, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 123, 36, 98, 120,
  45, 49, 54, 125, 44, 56, 48, 37, 44, 123, 36, 98, 120, 43, 49, 54,
  125, 44, 56, 48, 37, 44, 49, 44, 54, 52, 32, 45, 108, 105, 110, 101,
  91, 45, 49, 93, 32, 123, 36, 98, 120, 45, 49, 54, 125, 44, 50, 48,
  37, 44, 123, 36, 98, 120, 45, 49, 54, 125, 44, 56, 48, 37, 44, 49,
  44, 54, 52, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 10,
  49, 54, 44, 123, 104, 45, 49, 54, 125, 44, 49, 44, 51, 32, 45, 108,
  105, 110, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 48, 44, 53, 48,
  37, 44, 49, 48, 48, 37, 44, 49, 44, 48, 120, 53, 53, 53, 53, 53,
  53, 53, 53, 44, 49, 50, 56, 44, 54, 52, 44, 49, 50, 56, 10, 98,
  121, 61, 123, 36, 98, 114, 117, 115, 104, 116, 104, 105, 99, 107, 110, 101,
  115, 115, 42, 40, 104, 45, 49, 54, 41, 125, 10, 45, 114, 101, 99, 116,
  97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 50, 48, 37, 44, 123, 36,
  98, 121, 45, 49, 54, 125, 44, 56, 48, 37, 44, 123, 36, 98, 121, 43,
  49, 54, 125, 44, 49, 44, 49, 50, 56, 10, 45, 108, 105, 110, 101, 91,
  45, 49, 93, 32, 50, 48, 37, 44, 123, 36, 98, 121, 45, 49, 54, 125,
  44, 56, 48, 37, 44, 123, 36, 98, 121, 45, 49, 54, 125, 44, 49, 44,
  50, 53, 53, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 56, 48,
  37, 44, 123, 36, 98, 121, 45, 49, 54, 125, 44, 56, 48, 37, 44, 123,
  36, 98, 121, 43, 49, 54, 125, 44, 49, 44, 50, 53, 53, 10, 45, 108,
  105, 110, 101, 91, 45, 49, 93, 32, 50, 48, 37, 44, 123, 36, 98, 121,
  45, 49, 54, 125, 44, 50, 48, 37, 44, 123, 36, 98, 121, 43, 49, 54,
  125, 44, 49, 44, 54, 52, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93,
  32, 50, 48, 37, 44, 123, 36, 98, 121, 43, 49, 54, 125, 44, 56, 48,
  37, 44, 123, 36, 98, 121, 43, 49, 54, 125, 44, 49, 44, 54, 52, 10,
  45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 10, 45, 119, 51, 91,
  45, 49, 93, 32, 123, 119, 125, 44, 123, 104, 125, 44, 48, 44, 34, 66,
  114, 117, 115, 104, 34, 10, 114, 101, 102, 114, 101, 115, 104, 95, 98, 114,
  117, 115, 104, 61, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 36, 114, 101, 102, 114, 101, 115, 104, 95, 105, 109, 97, 103, 101, 10,
  45, 119, 49, 91, 36, 105, 109, 97, 103, 101, 93, 32, 64, 123, 36, 105,
  109, 97, 103, 101, 44, 119, 125, 44, 64, 123, 36, 105, 109, 97, 103, 101,
  44, 104, 125, 44, 48, 44, 34, 73, 109, 97, 103, 101, 32, 34, 35, 36,
  105, 109, 97, 103, 101, 34, 32, 58, 32, 34, 64, 123, 36, 105, 109, 97,
  103, 101, 44, 98, 125, 46, 64, 123, 36, 105, 109, 97, 103, 101, 44, 120,
  125, 10, 114, 101, 102, 114, 101, 115, 104, 95, 105, 109, 97, 103, 101, 61,
  48, 10, 45, 101, 110, 100, 105, 102, 10, 120, 49, 61, 64, 123, 33, 49,
  44, 120, 125, 32, 121, 49, 61, 64, 123, 33, 49, 44, 121, 125, 10, 120,
  50, 61, 64, 123, 33, 50, 44, 120, 125, 32, 121, 50, 61, 64, 123, 33,
  50, 44, 121, 125, 10, 120, 51, 61, 64, 123, 33, 51, 44, 120, 125, 32,
  121, 51, 61, 64, 123, 33, 51, 44, 121, 125, 10, 45, 105, 102, 32, 123,
  36, 120, 49, 62, 61, 48, 125, 10, 45, 105, 102, 32, 123, 64, 123, 33,
  49, 44, 98, 125, 38, 49, 125, 10, 111, 120, 49, 61, 123, 105, 102, 40,
  36, 111, 120, 49, 60, 48, 44, 36, 120, 49, 44, 36, 111, 120, 49, 41,
  125, 10, 111, 121, 49, 61, 123, 105, 102, 40, 36, 111, 121, 49, 60, 48,
  44, 36, 121, 49, 44, 36, 111, 121, 49, 41, 125, 10, 100, 101, 108, 116,
  97, 61, 123, 109, 97, 120, 40, 97, 98, 115, 40, 36, 120, 49, 45, 36,
  111, 120, 49, 41, 44, 97, 98, 115, 40, 36, 121, 49, 45, 36, 111, 121,
  49, 41, 41, 125, 10, 114, 49, 61, 123, 50, 42, 36, 98, 114, 117, 115,
  104, 115, 105, 122, 101, 43, 49, 125, 10, 114, 50, 61, 123, 36, 114, 49,
  42, 36, 98, 114, 117, 115, 104, 116, 104, 105, 99, 107, 110, 101, 115, 115,
  125, 10, 100, 120, 61, 123, 50, 42, 40, 36, 120, 49, 45, 36, 111, 120,
  49, 41, 47, 109, 97, 120, 40, 49, 44, 36, 100, 101, 108, 116, 97, 41,
  125, 10, 100, 121, 61, 123, 50, 42, 40, 36, 121, 49, 45, 36, 111, 121,
  49, 41, 47, 109, 97, 120, 40, 49, 44, 36, 100, 101, 108, 116, 97, 41,
  125, 10, 111, 61, 123, 49, 45, 40, 36, 98, 114, 117, 115, 104, 111, 112,
  97, 99, 105, 116, 121, 47, 52, 41, 94, 48, 46, 48, 52, 125, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 109, 97, 120, 40, 49, 44, 40, 36,
  100, 101, 108, 116, 97, 43, 49, 41, 47, 50, 41, 125, 10, 45, 101, 108,
  108, 105, 112, 115, 101, 91, 36, 105, 109, 97, 103, 101, 93, 32, 123, 36,
  111, 120, 49, 43, 36, 62, 42, 36, 100, 120, 125, 44, 123, 36, 111, 121,
  49, 43, 36, 62, 42, 36, 100, 121, 125, 44, 36, 114, 49, 44, 36, 114,
  50, 44, 36, 98, 114, 117, 115, 104, 97, 110, 103, 108, 101, 44, 36, 111,
  44, 36, 99, 111, 108, 111, 114, 10, 45, 100, 111, 110, 101, 10, 111, 120,
  49, 61, 36, 120, 49, 32, 111, 121, 49, 61, 36, 121, 49, 10, 114, 101,
  102, 114, 101, 115, 104, 95, 105, 109, 97, 103, 101, 61, 49, 10, 45, 101,
  108, 115, 101, 10, 111, 120, 49, 61, 45, 49, 32, 111, 121, 49, 61, 45,
  49, 10, 45, 105, 102, 32, 123, 64, 123, 33, 49, 44, 98, 125, 38, 50,
  125, 10, 45, 102, 108, 111, 111, 100, 91, 36, 105, 109, 97, 103, 101, 93,
  32, 36, 120, 49, 44, 36, 121, 49, 44, 48, 44, 49, 48, 44, 48, 44,
  49, 44, 36, 99, 111, 108, 111, 114, 10, 114, 101, 102, 114, 101, 115, 104,
  95, 105, 109, 97, 103, 101, 61, 49, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 64, 123, 33, 49, 44, 65, 82, 82, 79, 87, 82, 73, 71,
  72, 84, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 50, 44, 65, 82,
  82, 79, 87, 82, 73, 71, 72, 84, 125, 34, 32, 124, 124, 32, 34, 64,
  123, 33, 51, 44, 65, 82, 82, 79, 87, 82, 73, 71, 72, 84, 125, 34,
  32, 124, 124, 32, 34, 92, 10, 64, 123, 33, 49, 44, 65, 82, 82, 79,
  87, 85, 80, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 50, 44, 65,
  82, 82, 79, 87, 85, 80, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33,
  51, 44, 65, 82, 82, 79, 87, 85, 80, 125, 34, 32, 124, 124, 32, 34,
  92, 10, 64, 123, 33, 49, 44, 83, 80, 65, 67, 69, 125, 34, 32, 124,
  124, 32, 34, 64, 123, 33, 50, 44, 83, 80, 65, 67, 69, 125, 34, 32,
  124, 124, 32, 34, 64, 123, 33, 51, 44, 83, 80, 65, 67, 69, 125, 125,
  10, 105, 109, 97, 103, 101, 61, 123, 40, 36, 105, 109, 97, 103, 101, 43,
  49, 41, 37, 40, 64, 35, 45, 50, 41, 125, 32, 114, 101, 102, 114, 101,
  115, 104, 95, 105, 109, 97, 103, 101, 61, 49, 10, 45, 101, 108, 105, 102,
  32, 123, 64, 123, 33, 49, 44, 65, 82, 82, 79, 87, 76, 69, 70, 84,
  125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 50, 44, 65, 82, 82, 79,
  87, 76, 69, 70, 84, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 51,
  44, 65, 82, 82, 79, 87, 76, 69, 70, 84, 125, 34, 32, 124, 124, 32,
  34, 92, 10, 64, 123, 33, 49, 44, 65, 82, 82, 79, 87, 68, 79, 87,
  78, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 50, 44, 65, 82, 82,
  79, 87, 68, 79, 87, 78, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33,
  51, 44, 65, 82, 82, 79, 87, 68, 79, 87, 78, 125, 34, 32, 124, 124,
  32, 34, 92, 10, 64, 123, 33, 49, 44, 66, 65, 67, 75, 83, 80, 65,
  67, 69, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 50, 44, 66, 65,
  67, 75, 83, 80, 65, 67, 69, 125, 34, 32, 124, 124, 32, 34, 64, 123,
  33, 51, 44, 66, 65, 67, 75, 83, 80, 65, 67, 69, 125, 125, 10, 105,
  109, 97, 103, 101, 61, 123, 40, 36, 105, 109, 97, 103, 101, 45, 49, 41,
  37, 40, 64, 35, 45, 50, 41, 125, 32, 114, 101, 102, 114, 101, 115, 104,
  95, 105, 109, 97, 103, 101, 61, 49, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 64, 123, 33, 49, 44, 83, 125, 32, 45, 111, 91, 36,
  105, 109, 97, 103, 101, 93, 32, 103, 109, 105, 99, 95, 112, 97, 105, 110,
  116, 46, 112, 110, 103, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 64, 123, 33, 50, 44, 98, 125, 34, 32, 38, 38, 32, 34, 36,
  120, 50, 62, 61, 48, 34, 32, 38, 38, 32, 34, 36, 121, 50, 60, 54,
  52, 125, 10, 45, 105, 102, 32, 123, 36, 120, 50, 62, 61, 50, 53, 54,
  125, 32, 115, 97, 116, 117, 114, 97, 116, 105, 111, 110, 61, 123, 49, 45,
  36, 121, 50, 47, 54, 51, 125, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  120, 50, 62, 61, 48, 125, 32, 99, 111, 108, 111, 114, 61, 64, 123, 45,
  50, 44, 40, 36, 120, 50, 44, 36, 121, 50, 44, 48, 44, 48, 41, 125,
  44, 64, 123, 45, 50, 44, 40, 36, 120, 50, 44, 36, 121, 50, 44, 48,
  44, 49, 41, 125, 44, 64, 123, 45, 50, 44, 40, 36, 120, 50, 44, 36,
  121, 50, 44, 48, 44, 50, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  114, 101, 102, 114, 101, 115, 104, 95, 112, 97, 108, 101, 116, 116, 101, 61,
  49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64, 123,
  33, 51, 44, 98, 125, 34, 32, 38, 38, 32, 34, 36, 120, 51, 62, 61,
  48, 125, 10, 45, 105, 102, 32, 123, 36, 120, 51, 60, 51, 56, 52, 34,
  32, 38, 38, 32, 34, 36, 121, 51, 62, 61, 49, 57, 50, 125, 32, 98,
  114, 117, 115, 104, 97, 110, 103, 108, 101, 61, 123, 36, 120, 51, 42, 49,
  56, 48, 47, 40, 119, 45, 49, 54, 41, 125, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 120, 51, 62, 61, 51, 56, 52, 34, 32, 38, 38, 32, 34,
  36, 121, 51, 60, 49, 57, 50, 125, 32, 98, 114, 117, 115, 104, 116, 104,
  105, 99, 107, 110, 101, 115, 115, 61, 123, 36, 121, 51, 47, 40, 104, 45,
  49, 54, 41, 125, 10, 45, 101, 108, 105, 102, 32, 123, 36, 120, 51, 60,
  51, 56, 52, 34, 32, 38, 38, 32, 34, 36, 121, 51, 60, 49, 57, 50,
  125, 32, 98, 114, 117, 115, 104, 115, 105, 122, 101, 61, 123, 105, 110, 116,
  40, 36, 120, 51, 42, 56, 47, 40, 119, 45, 49, 54, 41, 41, 125, 32,
  98, 114, 117, 115, 104, 111, 112, 97, 99, 105, 116, 121, 61, 123, 105, 110,
  116, 40, 36, 121, 51, 42, 52, 47, 40, 104, 45, 49, 54, 41, 41, 125,
  10, 45, 101, 110, 100, 105, 102, 10, 114, 101, 102, 114, 101, 115, 104, 95,
  98, 114, 117, 115, 104, 61, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  119, 97, 105, 116, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 123, 33,
  49, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 49, 44, 81, 125,
  34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 49, 44, 69, 83, 67, 125,
  125, 10, 45, 119, 49, 91, 93, 32, 48, 32, 45, 119, 50, 91, 93, 32,
  48, 32, 45, 119, 51, 91, 93, 32, 48, 32, 45, 114, 109, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 118, 32, 43, 10, 120, 95, 112, 108, 97, 115,
  109, 97, 32, 58, 10, 45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45,
  45, 45, 45, 45, 32, 80, 108, 97, 115, 109, 97, 32, 101, 102, 102, 101,
  99, 116, 32, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110,
  10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76,
  43, 68, 39, 32, 116, 111, 32, 100, 111, 117, 98, 108, 101, 32, 119, 105,
  110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45,
  45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76, 43, 67, 39, 32,
  116, 111, 32, 114, 101, 115, 101, 116, 32, 119, 105, 110, 100, 111, 119, 32,
  115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121,
  115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81, 39, 32, 116,
  111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110,
  10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45,
  32, 45, 108, 91, 93, 10, 78, 61, 56, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 36, 78, 10, 50, 53, 54, 44, 49, 53, 48, 44, 49, 44, 51,
  32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  32, 45, 112, 108, 97, 115, 109, 97, 91, 45, 49, 93, 32, 49, 44, 48,
  44, 55, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10,
  97, 109, 112, 61, 123, 63, 40, 45, 52, 48, 44, 52, 48, 41, 125, 32,
  102, 114, 101, 113, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 50, 44,
  54, 41, 41, 125, 32, 100, 105, 114, 36, 62, 61, 123, 105, 102, 40, 63,
  60, 48, 46, 53, 44, 45, 49, 44, 49, 41, 42, 114, 111, 117, 110, 100,
  40, 63, 40, 49, 44, 50, 41, 41, 125, 10, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 49, 44, 49, 44, 39, 36, 97, 109, 112, 42, 99, 111,
  115, 40, 121, 42, 50, 42, 112, 105, 42, 36, 102, 114, 101, 113, 47, 104,
  41, 39, 10, 45, 100, 111, 110, 101, 10, 123, 119, 43, 50, 125, 44, 49,
  48, 48, 37, 44, 49, 44, 49, 44, 39, 120, 39, 32, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 39, 89, 61, 40, 121, 45,
  54, 48, 43, 53, 42, 99, 111, 115, 40, 120, 47, 51, 48, 41, 43, 49,
  48, 42, 115, 105, 110, 40, 120, 47, 49, 53, 41, 41, 59, 105, 102, 40,
  89, 60, 48, 124, 124, 89, 62, 61, 51, 50, 44, 45, 49, 44, 89, 41,
  39, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 48, 32,
  45, 116, 91, 45, 49, 93, 32, 34, 42, 42, 32, 87, 101, 108, 99, 111,
  109, 101, 32, 116, 111, 32, 71, 39, 77, 73, 67, 44, 32, 97, 32, 112,
  111, 119, 101, 114, 102, 117, 108, 32, 105, 109, 97, 103, 101, 32, 112, 114,
  111, 99, 101, 115, 115, 105, 110, 103, 32, 102, 114, 97, 109, 101, 119, 111,
  114, 107, 32, 42, 42, 34, 44, 48, 44, 48, 44, 51, 50, 44, 49, 44,
  50, 53, 53, 10, 45, 98, 91, 45, 49, 93, 32, 48, 46, 54, 32, 45,
  110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 77, 61, 123, 119,
  125, 10, 45, 119, 91, 93, 32, 123, 49, 46, 53, 42, 64, 123, 48, 44,
  119, 125, 125, 44, 123, 49, 46, 53, 42, 64, 123, 48, 44, 104, 125, 125,
  44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 80, 108, 97, 115,
  109, 97, 32, 101, 102, 102, 101, 99, 116, 34, 10, 116, 61, 48, 32, 116,
  116, 61, 123, 45, 49, 46, 53, 42, 64, 123, 48, 44, 119, 125, 125, 10,
  45, 100, 111, 10, 116, 105, 99, 61, 64, 124, 10, 97, 61, 123, 105, 110,
  116, 40, 36, 116, 41, 125, 32, 32, 32, 97, 50, 61, 123, 50, 42, 36,
  97, 125, 32, 97, 50, 49, 61, 123, 36, 97, 50, 43, 49, 125, 10, 98,
  61, 123, 40, 36, 97, 43, 49, 41, 37, 36, 78, 125, 32, 98, 50, 61,
  123, 50, 42, 36, 98, 125, 32, 98, 50, 49, 61, 123, 36, 98, 50, 43,
  49, 125, 10, 45, 45, 119, 97, 114, 112, 91, 36, 97, 50, 93, 32, 91,
  36, 97, 50, 49, 93, 44, 49, 44, 48, 44, 50, 10, 45, 45, 119, 97,
  114, 112, 91, 36, 98, 50, 93, 32, 91, 36, 98, 50, 49, 93, 44, 49,
  44, 48, 44, 50, 10, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 123, 36, 116, 45, 36, 97, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 105, 102, 116, 91,
  36, 97, 50, 49, 93, 32, 48, 44, 36, 123, 100, 105, 114, 36, 97, 125,
  44, 48, 44, 48, 44, 50, 10, 45, 115, 104, 105, 102, 116, 91, 36, 98,
  50, 49, 93, 32, 48, 44, 36, 123, 100, 105, 114, 36, 98, 125, 44, 48,
  44, 48, 44, 50, 10, 45, 105, 102, 32, 123, 105, 110, 116, 40, 36, 116,
  43, 48, 46, 48, 48, 53, 41, 62, 105, 110, 116, 40, 36, 116, 41, 125,
  32, 100, 105, 114, 36, 97, 61, 123, 105, 102, 40, 63, 60, 48, 46, 53,
  44, 45, 49, 44, 49, 41, 42, 114, 111, 117, 110, 100, 40, 63, 40, 49,
  44, 51, 41, 41, 125, 32, 45, 101, 110, 100, 105, 102, 10, 116, 61, 123,
  40, 36, 116, 43, 40, 64, 124, 45, 36, 116, 105, 99, 41, 41, 37, 36,
  78, 125, 10, 45, 45, 122, 91, 45, 50, 93, 32, 36, 116, 116, 44, 123,
  36, 116, 116, 43, 119, 45, 49, 43, 50, 125, 10, 45, 119, 97, 114, 112,
  91, 45, 49, 93, 32, 91, 45, 52, 93, 44, 48, 44, 48, 44, 48, 10,
  45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 49, 44, 51, 10, 45, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32,
  45, 43, 91, 45, 49, 93, 32, 50, 53, 53, 10, 45, 106, 91, 45, 51,
  93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49,
  44, 91, 45, 50, 93, 44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 45, 50,
  44, 45, 50, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 44, 50,
  53, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 116, 116, 61, 123, 36,
  116, 116, 43, 40, 64, 124, 45, 36, 116, 105, 99, 41, 42, 50, 53, 48,
  125, 10, 45, 105, 102, 32, 123, 36, 116, 116, 62, 61, 36, 77, 125, 32,
  116, 116, 61, 123, 45, 49, 46, 53, 42, 64, 123, 48, 44, 119, 125, 125,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 119, 91, 45, 49, 93, 10, 45,
  105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84,
  125, 38, 38, 64, 123, 33, 44, 68, 125, 125, 32, 45, 119, 91, 93, 32,
  123, 51, 42, 119, 125, 44, 123, 51, 42, 104, 125, 32, 45, 101, 108, 105,
  102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125,
  38, 38, 64, 123, 33, 44, 67, 125, 125, 32, 45, 119, 91, 93, 32, 123,
  49, 46, 53, 42, 119, 125, 44, 123, 49, 46, 53, 42, 104, 125, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 119,
  97, 105, 116, 32, 50, 48, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64,
  33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67, 125,
  34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125, 10, 45,
  114, 109, 91, 123, 45, 50, 42, 36, 78, 45, 50, 125, 45, 45, 49, 93,
  32, 45, 119, 91, 93, 32, 48, 32, 45, 101, 110, 100, 108, 32, 45, 118,
  32, 43, 10, 120, 95, 113, 117, 97, 110, 116, 105, 122, 101, 95, 114, 103,
  98, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110,
  116, 40, 36, 123, 49, 61, 49, 54, 125, 41, 32, 38, 38, 32, 36, 49,
  62, 49, 34, 10, 45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45,
  45, 45, 45, 32, 82, 71, 66, 32, 81, 117, 97, 110, 116, 105, 122, 97,
  116, 105, 111, 110, 32, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45,
  45, 45, 92, 110, 10, 45, 45, 45, 45, 32, 84, 104, 105, 115, 32, 100,
  101, 109, 111, 32, 115, 104, 111, 119, 115, 32, 104, 111, 119, 32, 82, 71,
  66, 32, 99, 111, 108, 111, 114, 115, 32, 99, 97, 110, 32, 98, 101, 32,
  113, 117, 97, 110, 116, 105, 102, 105, 101, 100, 32, 117, 115, 105, 110, 103,
  92, 110, 10, 45, 45, 45, 45, 32, 116, 104, 101, 32, 107, 45, 109, 101,
  97, 110, 115, 32, 97, 108, 103, 111, 114, 105, 116, 104, 109, 46, 92, 110,
  10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32, 76, 101, 102,
  116, 32, 109, 111, 117, 115, 101, 32, 98, 117, 116, 116, 111, 110, 32, 111,
  110, 32, 51, 100, 32, 118, 105, 101, 119, 32, 114, 111, 116, 97, 116, 101,
  115, 32, 116, 104, 101, 32, 99, 111, 108, 111, 114, 32, 99, 117, 98, 101,
  46, 92, 110, 10, 45, 45, 45, 45, 32, 82, 105, 103, 104, 116, 32, 109,
  111, 117, 115, 101, 32, 98, 117, 116, 116, 111, 110, 32, 111, 110, 32, 51,
  100, 32, 118, 105, 101, 119, 32, 116, 111, 103, 103, 108, 101, 115, 32, 99,
  111, 108, 111, 114, 115, 47, 99, 108, 117, 115, 116, 101, 114, 115, 32, 109,
  111, 100, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 76, 101, 102, 116,
  32, 109, 111, 117, 115, 101, 32, 98, 117, 116, 116, 111, 110, 32, 111, 110,
  32, 105, 109, 97, 103, 101, 32, 116, 111, 103, 103, 108, 101, 115, 32, 100,
  105, 116, 104, 101, 114, 105, 110, 103, 32, 109, 111, 100, 101, 44, 92, 110,
  10, 45, 45, 45, 45, 32, 76, 101, 102, 116, 32, 109, 111, 117, 115, 101,
  32, 98, 117, 116, 116, 111, 110, 32, 111, 110, 32, 99, 111, 108, 111, 114,
  109, 97, 112, 32, 97, 100, 100, 115, 32, 97, 32, 114, 97, 110, 100, 111,
  109, 32, 99, 111, 108, 111, 114, 46, 92, 110, 10, 45, 45, 45, 45, 32,
  82, 105, 103, 104, 116, 32, 109, 111, 117, 115, 101, 32, 98, 117, 116, 116,
  111, 110, 32, 111, 110, 32, 99, 111, 108, 111, 114, 109, 97, 112, 32, 114,
  101, 109, 111, 118, 101, 115, 32, 97, 32, 99, 111, 108, 111, 114, 46, 92,
  110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 32, 39, 82, 39, 32, 105,
  110, 105, 116, 32, 99, 111, 108, 111, 114, 109, 97, 112, 32, 119, 105, 116,
  104, 32, 114, 97, 110, 100, 111, 109, 32, 118, 97, 108, 117, 101, 115, 46,
  92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 32, 39, 85, 39, 32,
  105, 110, 105, 116, 32, 99, 111, 108, 111, 114, 109, 97, 112, 32, 119, 105,
  116, 104, 32, 117, 110, 105, 102, 111, 114, 109, 32, 115, 97, 109, 112, 108,
  105, 110, 103, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 32,
  39, 77, 39, 32, 105, 110, 105, 116, 32, 99, 111, 108, 111, 114, 109, 97,
  112, 32, 119, 105, 116, 104, 32, 109, 101, 100, 105, 97, 110, 45, 99, 117,
  116, 32, 97, 108, 103, 111, 114, 105, 116, 104, 109, 46, 92, 110, 10, 45,
  45, 45, 45, 32, 75, 101, 121, 32, 39, 83, 80, 65, 67, 69, 39, 32,
  100, 111, 101, 115, 32, 97, 32, 115, 105, 110, 103, 108, 101, 32, 105, 116,
  101, 114, 97, 116, 105, 111, 110, 32, 111, 102, 32, 107, 45, 109, 101, 97,
  110, 115, 32, 97, 110, 100, 32, 112, 97, 117, 115, 101, 115, 46, 92, 110,
  10, 45, 45, 45, 45, 32, 75, 101, 121, 32, 39, 69, 78, 84, 69, 82,
  39, 32, 114, 117, 110, 115, 32, 107, 45, 109, 101, 97, 110, 115, 32, 97,
  108, 103, 111, 114, 105, 116, 104, 109, 46, 92, 110, 10, 45, 45, 45, 45,
  32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76, 43, 68, 39, 32, 116,
  111, 32, 100, 111, 117, 98, 108, 101, 32, 119, 105, 110, 100, 111, 119, 32,
  115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121,
  115, 32, 39, 67, 84, 82, 76, 43, 67, 39, 32, 116, 111, 32, 114, 101,
  115, 101, 116, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46,
  92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 69, 83,
  67, 39, 32, 111, 114, 32, 39, 81, 39, 32, 116, 111, 32, 101, 120, 105,
  116, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45,
  10, 45, 105, 102, 32, 123, 33, 64, 35, 125, 32, 45, 116, 101, 115, 116,
  105, 109, 97, 103, 101, 50, 100, 32, 51, 48, 48, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 107, 91, 48, 93, 32, 45, 116, 111, 95, 114, 103, 98,
  32, 45, 105, 102, 32, 123, 104, 62, 51, 48, 48, 125, 32, 45, 114, 50,
  100, 121, 32, 51, 48, 48, 32, 45, 114, 111, 117, 110, 100, 32, 49, 32,
  45, 101, 110, 100, 105, 102, 32, 45, 110, 109, 91, 45, 49, 93, 32, 105,
  109, 103, 10, 45, 45, 114, 32, 123, 119, 42, 104, 125, 44, 49, 44, 49,
  44, 51, 44, 45, 49, 32, 45, 114, 91, 45, 49, 93, 32, 123, 109, 105,
  110, 40, 119, 44, 56, 49, 57, 50, 41, 125, 44, 49, 44, 49, 44, 51,
  32, 45, 110, 109, 91, 45, 49, 93, 32, 99, 111, 108, 111, 114, 115, 10,
  36, 49, 44, 49, 44, 49, 44, 51, 32, 45, 114, 97, 110, 100, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 114, 111, 117, 110, 100, 91,
  45, 49, 93, 32, 49, 32, 45, 110, 109, 91, 45, 49, 93, 32, 99, 101,
  110, 116, 114, 111, 105, 100, 115, 10, 45, 95, 120, 95, 113, 117, 97, 110,
  116, 105, 122, 101, 95, 114, 103, 98, 95, 51, 100, 32, 40, 49, 44, 48,
  44, 48, 44, 48, 59, 48, 44, 49, 44, 48, 44, 48, 59, 48, 44, 48,
  44, 49, 44, 48, 41, 32, 45, 110, 109, 91, 45, 49, 93, 32, 112, 111,
  115, 101, 51, 100, 10, 45, 95, 120, 95, 113, 117, 97, 110, 116, 105, 122,
  101, 95, 114, 103, 98, 95, 116, 101, 120, 116, 32, 34, 67, 111, 108, 111,
  114, 115, 34, 44, 99, 108, 117, 115, 116, 101, 114, 105, 110, 103, 48, 10,
  45, 95, 120, 95, 113, 117, 97, 110, 116, 105, 122, 101, 95, 114, 103, 98,
  95, 116, 101, 120, 116, 32, 34, 67, 108, 117, 115, 116, 101, 114, 115, 34,
  44, 99, 108, 117, 115, 116, 101, 114, 105, 110, 103, 49, 10, 45, 95, 120,
  95, 113, 117, 97, 110, 116, 105, 122, 101, 95, 114, 103, 98, 95, 116, 101,
  120, 116, 32, 34, 68, 105, 116, 104, 101, 114, 105, 110, 103, 58, 32, 111,
  102, 102, 34, 44, 100, 105, 116, 104, 101, 114, 105, 110, 103, 48, 10, 45,
  95, 120, 95, 113, 117, 97, 110, 116, 105, 122, 101, 95, 114, 103, 98, 95,
  116, 101, 120, 116, 32, 34, 68, 105, 116, 104, 101, 114, 105, 110, 103, 58,
  32, 111, 110, 34, 44, 100, 105, 116, 104, 101, 114, 105, 110, 103, 49, 10,
  45, 105, 102, 32, 123, 64, 123, 105, 109, 103, 44, 104, 125, 60, 51, 48,
  48, 125, 32, 45, 45, 114, 50, 100, 121, 91, 105, 109, 103, 93, 32, 51,
  48, 48, 44, 49, 32, 45, 101, 108, 115, 101, 32, 91, 105, 109, 103, 93,
  32, 45, 101, 110, 100, 105, 102, 10, 123, 119, 43, 51, 49, 53, 125, 44,
  51, 54, 53, 44, 49, 44, 51, 44, 50, 53, 53, 32, 45, 114, 109, 91,
  45, 50, 93, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45,
  49, 93, 32, 52, 44, 52, 44, 51, 48, 53, 44, 51, 48, 53, 44, 49,
  44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 10, 45, 114,
  101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 51, 48, 57,
  44, 52, 44, 123, 119, 45, 53, 125, 44, 51, 48, 53, 44, 49, 44, 48,
  120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 10, 45, 114, 101, 99,
  116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 52, 44, 51, 48, 57,
  44, 123, 119, 45, 53, 125, 44, 51, 54, 48, 44, 49, 44, 48, 120, 70,
  70, 70, 70, 70, 70, 70, 70, 44, 48, 10, 91, 45, 49, 93, 44, 91,
  45, 49, 93, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45,
  49, 93, 32, 51, 49, 48, 44, 53, 44, 123, 119, 45, 54, 125, 44, 51,
  48, 53, 44, 49, 44, 49, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108,
  101, 91, 45, 49, 93, 32, 53, 44, 51, 49, 48, 44, 123, 119, 45, 54,
  125, 44, 51, 54, 48, 44, 49, 44, 50, 10, 51, 48, 48, 44, 51, 48,
  48, 44, 49, 44, 49, 44, 39, 40, 121, 60, 60, 49, 49, 41, 43, 40,
  120, 60, 60, 50, 41, 43, 51, 39, 32, 45, 106, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 53, 44, 53, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32, 32, 45, 110,
  109, 91, 45, 49, 93, 32, 118, 105, 115, 117, 10, 100, 105, 116, 104, 101,
  114, 105, 110, 103, 61, 48, 32, 99, 108, 117, 115, 116, 101, 114, 105, 110,
  103, 61, 48, 32, 112, 97, 117, 115, 101, 61, 49, 32, 115, 48, 61, 111,
  102, 102, 32, 115, 49, 61, 111, 110, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 49, 101, 49, 48, 10, 45, 105, 102, 32, 123, 33, 110, 97, 114, 103,
  40, 36, 118, 105, 115, 117, 95, 51, 100, 41, 125, 10, 45, 45, 45, 91,
  99, 101, 110, 116, 114, 111, 105, 100, 115, 93, 32, 50, 32, 45, 45, 43,
  91, 99, 101, 110, 116, 114, 111, 105, 100, 115, 93, 32, 50, 32, 45, 97,
  91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 112, 101, 114, 109, 117,
  116, 101, 91, 45, 49, 93, 32, 99, 120, 121, 122, 32, 45, 121, 91, 45,
  49, 93, 32, 45, 45, 91, 45, 49, 93, 32, 49, 50, 56, 10, 45, 106,
  91, 111, 98, 106, 51, 100, 93, 32, 91, 45, 49, 93, 44, 48, 44, 56,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 91, 111, 98, 106, 51, 100, 93,
  10, 45, 105, 102, 32, 36, 99, 108, 117, 115, 116, 101, 114, 105, 110, 103,
  10, 45, 105, 102, 32, 123, 64, 123, 99, 111, 108, 111, 114, 115, 44, 77,
  125, 60, 50, 53, 54, 125, 32, 45, 45, 105, 110, 100, 101, 120, 91, 99,
  111, 108, 111, 114, 115, 93, 32, 91, 99, 101, 110, 116, 114, 111, 105, 100,
  115, 93, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 54, 32, 45, 43,
  91, 99, 111, 108, 111, 114, 115, 44, 45, 49, 93, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 99, 111,
  108, 111, 114, 115, 93, 32, 48, 32, 45, 62, 62, 91, 45, 49, 93, 32,
  56, 32, 45, 109, 97, 112, 91, 45, 49, 93, 32, 50, 32, 45, 112, 101,
  114, 109, 117, 116, 101, 91, 45, 49, 93, 32, 99, 120, 121, 122, 32, 45,
  121, 91, 45, 49, 93, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 48, 44, 123, 64, 123, 45, 50, 44, 104, 125, 45, 36, 95, 78,
  45, 104, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 97, 112, 112, 108, 121, 95, 112, 111, 115, 101, 51, 100,
  91, 45, 49, 93, 32, 64, 112, 111, 115, 101, 51, 100, 32, 51, 48, 48,
  44, 51, 48, 48, 44, 49, 44, 51, 32, 45, 111, 98, 106, 101, 99, 116,
  51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 53, 48, 37, 44,
  53, 48, 37, 44, 49, 48, 48, 44, 49, 44, 50, 44, 48, 44, 48, 44,
  51, 48, 48, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 106, 91, 45,
  49, 93, 32, 91, 99, 108, 117, 115, 116, 101, 114, 105, 110, 103, 36, 99,
  108, 117, 115, 116, 101, 114, 105, 110, 103, 93, 44, 50, 44, 48, 44, 48,
  44, 48, 44, 49, 44, 91, 109, 99, 108, 117, 115, 116, 101, 114, 105, 110,
  103, 36, 99, 108, 117, 115, 116, 101, 114, 105, 110, 103, 93, 44, 50, 53,
  53, 10, 45, 110, 109, 91, 45, 49, 93, 32, 118, 105, 115, 117, 95, 51,
  100, 32, 45, 106, 91, 118, 105, 115, 117, 93, 32, 91, 118, 105, 115, 117,
  95, 51, 100, 93, 44, 53, 44, 53, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 33, 110, 97, 114, 103, 40, 36, 118, 105, 115, 117,
  95, 105, 109, 103, 41, 125, 10, 45, 45, 105, 110, 100, 101, 120, 91, 105,
  109, 103, 93, 32, 91, 99, 101, 110, 116, 114, 111, 105, 100, 115, 93, 44,
  123, 48, 46, 55, 42, 36, 100, 105, 116, 104, 101, 114, 105, 110, 103, 125,
  44, 49, 32, 45, 105, 102, 32, 123, 104, 60, 51, 48, 48, 125, 32, 45,
  114, 50, 100, 121, 91, 45, 49, 93, 32, 51, 48, 48, 44, 49, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 106, 91, 45, 49, 93, 32, 91, 100, 105,
  116, 104, 101, 114, 105, 110, 103, 36, 100, 105, 116, 104, 101, 114, 105, 110,
  103, 93, 44, 50, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 109, 100,
  105, 116, 104, 101, 114, 105, 110, 103, 36, 100, 105, 116, 104, 101, 114, 105,
  110, 103, 93, 44, 50, 53, 53, 10, 45, 110, 109, 91, 45, 49, 93, 32,
  118, 105, 115, 117, 95, 105, 109, 103, 32, 45, 106, 91, 118, 105, 115, 117,
  93, 32, 91, 118, 105, 115, 117, 95, 105, 109, 103, 93, 44, 51, 49, 48,
  44, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 33,
  110, 97, 114, 103, 40, 36, 118, 105, 115, 117, 95, 99, 101, 110, 116, 114,
  111, 105, 100, 115, 41, 125, 10, 45, 45, 108, 117, 109, 105, 110, 97, 110,
  99, 101, 91, 99, 101, 110, 116, 114, 111, 105, 100, 115, 93, 32, 45, 97,
  91, 45, 49, 93, 32, 91, 99, 101, 110, 116, 114, 111, 105, 100, 115, 93,
  44, 121, 32, 45, 115, 111, 114, 116, 91, 45, 49, 93, 32, 43, 44, 120,
  32, 45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 49, 32, 45, 114, 91,
  45, 49, 93, 32, 123, 64, 123, 118, 105, 115, 117, 44, 119, 125, 45, 49,
  48, 125, 44, 53, 48, 44, 49, 44, 51, 10, 48, 32, 45, 116, 101, 120,
  116, 91, 45, 49, 93, 32, 34, 67, 111, 108, 111, 114, 115, 58, 32, 34,
  64, 123, 99, 101, 110, 116, 114, 111, 105, 100, 115, 44, 119, 125, 44, 50,
  44, 48, 44, 49, 51, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 32, 45, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93,
  32, 51, 32, 45, 106, 91, 45, 51, 93, 32, 91, 45, 50, 93, 44, 50,
  44, 50, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 44, 50, 53,
  53, 10, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 32, 45, 110, 109,
  91, 45, 49, 93, 32, 118, 105, 115, 117, 95, 99, 101, 110, 116, 114, 111,
  105, 100, 115, 32, 45, 106, 91, 118, 105, 115, 117, 93, 32, 91, 118, 105,
  115, 117, 95, 99, 101, 110, 116, 114, 111, 105, 100, 115, 93, 44, 53, 44,
  51, 49, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 108, 91, 118, 105,
  115, 117, 93, 10, 45, 119, 32, 45, 49, 44, 45, 49, 44, 48, 44, 34,
  91, 71, 39, 77, 73, 67, 93, 32, 82, 71, 66, 32, 113, 117, 97, 110,
  116, 105, 122, 97, 116, 105, 111, 110, 34, 10, 45, 105, 102, 32, 123, 64,
  123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123,
  33, 44, 68, 125, 125, 32, 45, 119, 91, 93, 32, 123, 50, 42, 119, 125,
  44, 123, 50, 42, 104, 125, 32, 45, 101, 108, 105, 102, 32, 123, 64, 123,
  33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33,
  44, 67, 125, 125, 32, 45, 119, 91, 93, 32, 123, 119, 125, 44, 123, 104,
  125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 10, 120,
  61, 123, 105, 110, 116, 40, 64, 123, 33, 44, 120, 125, 42, 64, 123, 118,
  105, 115, 117, 44, 119, 125, 47, 64, 123, 33, 44, 119, 125, 41, 125, 10,
  121, 61, 123, 105, 110, 116, 40, 64, 123, 33, 44, 121, 125, 42, 64, 123,
  118, 105, 115, 117, 44, 104, 125, 47, 64, 123, 33, 44, 104, 125, 41, 125,
  10, 98, 61, 64, 123, 33, 44, 98, 125, 10, 105, 61, 64, 123, 118, 105,
  115, 117, 44, 40, 36, 120, 44, 36, 121, 44, 48, 44, 51, 41, 125, 10,
  45, 105, 102, 32, 123, 36, 98, 38, 49, 34, 32, 38, 38, 32, 34, 36,
  105, 61, 61, 49, 125, 10, 100, 105, 116, 104, 101, 114, 105, 110, 103, 61,
  123, 33, 36, 100, 105, 116, 104, 101, 114, 105, 110, 103, 125, 32, 45, 114,
  109, 91, 118, 105, 115, 117, 95, 105, 109, 103, 93, 32, 45, 119, 97, 105,
  116, 32, 45, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 98, 38, 49,
  34, 32, 38, 38, 32, 34, 36, 105, 61, 61, 50, 125, 10, 40, 64, 123,
  45, 82, 71, 66, 125, 41, 32, 45, 121, 91, 45, 49, 93, 32, 99, 32,
  45, 97, 91, 99, 101, 110, 116, 114, 111, 105, 100, 115, 44, 45, 49, 93,
  32, 120, 32, 32, 45, 95, 120, 95, 113, 117, 97, 110, 116, 105, 122, 101,
  95, 114, 103, 98, 95, 51, 100, 32, 45, 114, 109, 91, 118, 105, 115, 117,
  95, 51, 100, 44, 118, 105, 115, 117, 95, 105, 109, 103, 44, 118, 105, 115,
  117, 95, 99, 101, 110, 116, 114, 111, 105, 100, 115, 93, 32, 45, 97, 110,
  100, 91, 99, 111, 108, 111, 114, 115, 93, 32, 50, 53, 53, 32, 112, 97,
  117, 115, 101, 61, 49, 32, 45, 119, 97, 105, 116, 32, 49, 48, 48, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 98, 38, 50, 34, 32, 38, 38, 32,
  34, 36, 105, 61, 61, 50, 34, 32, 38, 38, 32, 34, 64, 123, 99, 101,
  110, 116, 114, 111, 105, 100, 115, 44, 119, 125, 62, 50, 125, 10, 45, 114,
  91, 99, 101, 110, 116, 114, 111, 105, 100, 115, 93, 32, 123, 64, 123, 99,
  101, 110, 116, 114, 111, 105, 100, 115, 44, 119, 125, 45, 49, 125, 32, 45,
  95, 120, 95, 113, 117, 97, 110, 116, 105, 122, 101, 95, 114, 103, 98, 95,
  51, 100, 32, 45, 114, 109, 91, 118, 105, 115, 117, 95, 51, 100, 44, 118,
  105, 115, 117, 95, 105, 109, 103, 44, 118, 105, 115, 117, 95, 99, 101, 110,
  116, 114, 111, 105, 100, 115, 93, 32, 45, 97, 110, 100, 91, 99, 111, 108,
  111, 114, 115, 93, 32, 50, 53, 53, 32, 112, 97, 117, 115, 101, 61, 49,
  32, 45, 119, 97, 105, 116, 32, 49, 48, 48, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 98, 38, 50, 34, 32, 38, 38, 32, 34, 36, 105, 62, 61,
  51, 125, 10, 99, 108, 117, 115, 116, 101, 114, 105, 110, 103, 61, 123, 33,
  36, 99, 108, 117, 115, 116, 101, 114, 105, 110, 103, 125, 32, 45, 114, 109,
  91, 118, 105, 115, 117, 95, 51, 100, 93, 32, 45, 119, 97, 105, 116, 32,
  45, 49, 10, 45, 101, 108, 105, 102, 32, 64, 123, 33, 44, 77, 125, 10,
  45, 45, 97, 110, 100, 91, 99, 111, 108, 111, 114, 115, 93, 32, 50, 53,
  53, 32, 45, 99, 111, 108, 111, 114, 109, 97, 112, 91, 45, 49, 93, 32,
  64, 123, 99, 101, 110, 116, 114, 111, 105, 100, 115, 44, 119, 125, 44, 48,
  44, 48, 32, 45, 114, 109, 91, 99, 101, 110, 116, 114, 111, 105, 100, 115,
  93, 32, 45, 110, 109, 91, 45, 49, 93, 32, 99, 101, 110, 116, 114, 111,
  105, 100, 115, 10, 45, 95, 120, 95, 113, 117, 97, 110, 116, 105, 122, 101,
  95, 114, 103, 98, 95, 51, 100, 32, 45, 114, 109, 91, 118, 105, 115, 117,
  95, 51, 100, 44, 118, 105, 115, 117, 95, 105, 109, 103, 44, 118, 105, 115,
  117, 95, 99, 101, 110, 116, 114, 111, 105, 100, 115, 93, 32, 45, 97, 110,
  100, 91, 99, 111, 108, 111, 114, 115, 93, 32, 50, 53, 53, 32, 112, 97,
  117, 115, 101, 61, 49, 32, 45, 119, 97, 105, 116, 32, 45, 49, 10, 45,
  101, 108, 105, 102, 32, 64, 123, 33, 44, 82, 125, 10, 45, 114, 97, 110,
  100, 91, 99, 101, 110, 116, 114, 111, 105, 100, 115, 93, 32, 48, 44, 50,
  53, 53, 32, 45, 114, 111, 117, 110, 100, 91, 99, 101, 110, 116, 114, 111,
  105, 100, 115, 93, 32, 49, 10, 45, 95, 120, 95, 113, 117, 97, 110, 116,
  105, 122, 101, 95, 114, 103, 98, 95, 51, 100, 32, 45, 114, 109, 91, 118,
  105, 115, 117, 95, 51, 100, 44, 118, 105, 115, 117, 95, 105, 109, 103, 44,
  118, 105, 115, 117, 95, 99, 101, 110, 116, 114, 111, 105, 100, 115, 93, 32,
  45, 97, 110, 100, 91, 99, 111, 108, 111, 114, 115, 93, 32, 50, 53, 53,
  32, 112, 97, 117, 115, 101, 61, 49, 32, 45, 119, 97, 105, 116, 32, 45,
  49, 10, 45, 101, 108, 105, 102, 32, 64, 123, 33, 44, 85, 125, 10, 45,
  117, 110, 105, 102, 111, 114, 109, 95, 100, 105, 115, 116, 114, 105, 98, 117,
  116, 105, 111, 110, 32, 64, 123, 99, 101, 110, 116, 114, 111, 105, 100, 115,
  44, 119, 125, 44, 51, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53,
  32, 45, 114, 109, 91, 99, 101, 110, 116, 114, 111, 105, 100, 115, 93, 32,
  45, 110, 109, 91, 45, 49, 93, 32, 99, 101, 110, 116, 114, 111, 105, 100,
  115, 10, 45, 95, 120, 95, 113, 117, 97, 110, 116, 105, 122, 101, 95, 114,
  103, 98, 95, 51, 100, 32, 45, 114, 109, 91, 118, 105, 115, 117, 95, 51,
  100, 44, 118, 105, 115, 117, 95, 105, 109, 103, 44, 118, 105, 115, 117, 95,
  99, 101, 110, 116, 114, 111, 105, 100, 115, 93, 32, 45, 97, 110, 100, 91,
  99, 111, 108, 111, 114, 115, 93, 32, 50, 53, 53, 32, 112, 97, 117, 115,
  101, 61, 49, 32, 45, 119, 97, 105, 116, 32, 45, 49, 10, 45, 101, 108,
  105, 102, 32, 64, 123, 33, 44, 69, 78, 84, 69, 82, 125, 10, 112, 97,
  117, 115, 101, 61, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 98, 38,
  49, 34, 32, 38, 38, 32, 34, 36, 105, 62, 61, 51, 125, 10, 99, 111,
  111, 114, 100, 115, 61, 123, 64, 123, 118, 105, 115, 117, 44, 40, 36, 120,
  44, 36, 121, 44, 48, 44, 51, 41, 125, 45, 51, 125, 32, 117, 49, 61,
  123, 40, 40, 36, 99, 111, 111, 114, 100, 115, 62, 62, 50, 41, 38, 53,
  49, 49, 41, 45, 49, 53, 48, 125, 32, 118, 49, 61, 123, 40, 36, 99,
  111, 111, 114, 100, 115, 62, 62, 49, 49, 41, 45, 49, 53, 48, 125, 10,
  45, 105, 102, 32, 123, 33, 110, 97, 114, 103, 40, 36, 117, 48, 41, 125,
  32, 117, 48, 61, 36, 117, 49, 32, 118, 48, 61, 36, 118, 49, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 117, 48, 33, 61,
  36, 117, 49, 34, 32, 38, 38, 32, 34, 36, 118, 48, 33, 61, 36, 118,
  49, 125, 10, 110, 48, 61, 123, 115, 113, 114, 116, 40, 40, 36, 117, 48,
  41, 94, 50, 43, 40, 36, 118, 48, 41, 94, 50, 41, 125, 10, 110, 117,
  48, 61, 123, 105, 102, 40, 36, 110, 48, 62, 49, 51, 53, 44, 36, 117,
  48, 42, 49, 51, 53, 47, 36, 110, 48, 44, 36, 117, 48, 41, 125, 32,
  110, 118, 48, 61, 123, 105, 102, 40, 36, 110, 48, 62, 49, 51, 53, 44,
  36, 118, 48, 42, 49, 51, 53, 47, 36, 110, 48, 44, 36, 118, 48, 41,
  125, 32, 110, 119, 48, 61, 123, 115, 113, 114, 116, 40, 109, 97, 120, 40,
  48, 44, 49, 56, 50, 50, 53, 45, 40, 36, 110, 117, 48, 41, 94, 50,
  45, 40, 36, 110, 118, 48, 41, 94, 50, 41, 41, 125, 10, 110, 49, 61,
  123, 115, 113, 114, 116, 40, 40, 36, 117, 49, 41, 94, 50, 43, 40, 36,
  118, 49, 41, 94, 50, 41, 125, 10, 110, 117, 49, 61, 123, 105, 102, 40,
  36, 110, 49, 62, 49, 51, 53, 44, 36, 117, 49, 42, 49, 51, 53, 47,
  36, 110, 49, 44, 36, 117, 49, 41, 125, 32, 110, 118, 49, 61, 123, 105,
  102, 40, 36, 110, 49, 62, 49, 51, 53, 44, 36, 118, 49, 42, 49, 51,
  53, 47, 36, 110, 49, 44, 36, 118, 49, 41, 125, 32, 110, 119, 49, 61,
  123, 115, 113, 114, 116, 40, 109, 97, 120, 40, 48, 44, 49, 56, 50, 50,
  53, 45, 40, 36, 110, 117, 49, 41, 94, 50, 45, 40, 36, 110, 118, 49,
  41, 94, 50, 41, 41, 125, 10, 117, 61, 123, 36, 110, 118, 48, 42, 36,
  110, 119, 49, 45, 36, 110, 119, 48, 42, 36, 110, 118, 49, 125, 32, 118,
  61, 123, 36, 110, 119, 48, 42, 36, 110, 117, 49, 45, 36, 110, 117, 48,
  42, 36, 110, 119, 49, 125, 32, 119, 61, 123, 36, 110, 118, 48, 42, 36,
  110, 117, 49, 45, 36, 110, 117, 48, 42, 36, 110, 118, 49, 125, 32, 110,
  61, 123, 115, 113, 114, 116, 40, 40, 36, 117, 41, 94, 50, 43, 40, 36,
  118, 41, 94, 50, 43, 40, 36, 119, 41, 94, 50, 41, 125, 10, 45, 114,
  111, 116, 97, 116, 105, 111, 110, 51, 100, 91, 93, 32, 36, 117, 44, 36,
  118, 44, 36, 119, 44, 123, 97, 115, 105, 110, 40, 36, 110, 47, 49, 56,
  50, 50, 53, 41, 42, 49, 56, 48, 47, 112, 105, 125, 32, 45, 109, 118,
  91, 112, 111, 115, 101, 51, 100, 93, 32, 64, 35, 32, 45, 42, 42, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 110, 109, 91, 45, 49, 93, 32, 112,
  111, 115, 101, 51, 100, 10, 117, 48, 61, 36, 117, 49, 32, 118, 48, 61,
  36, 118, 49, 32, 45, 114, 109, 91, 118, 105, 115, 117, 95, 51, 100, 93,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 105, 102, 32, 123, 33,
  40, 36, 98, 38, 49, 41, 125, 32, 117, 48, 61, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 33, 36, 112, 97, 117, 115, 101, 34,
  32, 124, 124, 32, 34, 64, 123, 33, 44, 83, 80, 65, 67, 69, 125, 125,
  10, 112, 97, 117, 115, 101, 61, 64, 123, 33, 44, 83, 80, 65, 67, 69,
  125, 10, 45, 97, 110, 100, 91, 99, 111, 108, 111, 114, 115, 93, 32, 50,
  53, 53, 32, 45, 45, 105, 110, 100, 101, 120, 91, 99, 111, 108, 111, 114,
  115, 93, 32, 91, 99, 101, 110, 116, 114, 111, 105, 100, 115, 93, 32, 45,
  42, 91, 45, 49, 93, 32, 50, 53, 54, 32, 45, 43, 91, 99, 111, 108,
  111, 114, 115, 44, 45, 49, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 123, 99, 111, 108, 111, 114, 115, 44, 115, 125, 10, 45, 115, 104, 91,
  99, 111, 108, 111, 114, 115, 93, 32, 36, 62, 44, 36, 62, 32, 45, 45,
  104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 49, 93, 32, 123, 64,
  123, 99, 101, 110, 116, 114, 111, 105, 100, 115, 44, 119, 125, 42, 50, 53,
  54, 125, 44, 48, 44, 123, 64, 123, 99, 101, 110, 116, 114, 111, 105, 100,
  115, 44, 119, 125, 42, 50, 53, 54, 45, 49, 125, 32, 45, 114, 109, 91,
  45, 50, 93, 10, 45, 105, 91, 45, 50, 93, 32, 50, 53, 54, 44, 49,
  44, 49, 44, 49, 44, 39, 120, 39, 32, 45, 114, 91, 45, 50, 93, 32,
  123, 119, 125, 44, 49, 44, 49, 44, 49, 44, 48, 44, 50, 32, 45, 42,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 91, 45, 50, 44,
  45, 49, 93, 32, 64, 123, 99, 101, 110, 116, 114, 111, 105, 100, 115, 44,
  119, 125, 44, 49, 44, 49, 44, 49, 44, 50, 32, 45, 109, 97, 120, 91,
  45, 49, 93, 32, 48, 46, 48, 49, 32, 45, 47, 91, 45, 50, 44, 45,
  49, 93, 10, 45, 100, 111, 110, 101, 32, 45, 97, 91, 45, 64, 123, 99,
  111, 108, 111, 114, 115, 44, 115, 125, 45, 45, 49, 93, 32, 99, 10, 45,
  114, 109, 91, 99, 101, 110, 116, 114, 111, 105, 100, 115, 93, 32, 45, 110,
  109, 91, 45, 49, 93, 32, 99, 101, 110, 116, 114, 111, 105, 100, 115, 10,
  45, 45, 62, 62, 91, 99, 111, 108, 111, 114, 115, 93, 32, 56, 32, 45,
  99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 32, 45,
  104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 49, 93, 32, 64, 123,
  99, 101, 110, 116, 114, 111, 105, 100, 115, 44, 119, 125, 44, 48, 44, 123,
  64, 123, 99, 101, 110, 116, 114, 111, 105, 100, 115, 44, 119, 125, 45, 49,
  125, 10, 99, 109, 97, 120, 61, 64, 123, 45, 49, 44, 120, 77, 125, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 119, 125, 32, 45, 105, 102, 32,
  123, 33, 105, 40, 36, 62, 41, 125, 32, 45, 112, 111, 105, 110, 116, 91,
  99, 101, 110, 116, 114, 111, 105, 100, 115, 93, 32, 36, 62, 44, 48, 44,
  48, 44, 49, 44, 64, 123, 45, 97, 116, 91, 99, 101, 110, 116, 114, 111,
  105, 100, 115, 93, 92, 32, 36, 99, 109, 97, 120, 125, 32, 45, 112, 111,
  105, 110, 116, 91, 99, 101, 110, 116, 114, 111, 105, 100, 115, 93, 32, 36,
  62, 44, 48, 44, 48, 44, 45, 48, 46, 48, 48, 49, 44, 64, 123, 45,
  82, 71, 66, 125, 32, 45, 101, 110, 100, 105, 102, 32, 45, 100, 111, 110,
  101, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 99, 91, 99, 101, 110,
  116, 114, 111, 105, 100, 115, 93, 32, 48, 44, 50, 53, 53, 10, 45, 105,
  102, 32, 36, 118, 105, 115, 117, 95, 51, 100, 32, 45, 114, 109, 91, 118,
  105, 115, 117, 95, 51, 100, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 36, 118, 105, 115, 117, 95, 105, 109, 103, 32, 45, 114, 109,
  91, 118, 105, 115, 117, 95, 105, 109, 103, 93, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 36, 118, 105, 115, 117, 95, 99, 101, 110, 116,
  114, 111, 105, 100, 115, 32, 45, 114, 109, 91, 118, 105, 115, 117, 95, 99,
  101, 110, 116, 114, 111, 105, 100, 115, 93, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 119, 97, 105, 116, 32, 50, 48, 10, 45, 101, 108, 115, 101, 32,
  45, 105, 102, 32, 36, 118, 105, 115, 117, 95, 105, 109, 103, 32, 45, 119,
  97, 105, 116, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 33, 64, 33, 34, 32, 124, 124, 32, 34,
  64, 123, 33, 44, 81, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 44,
  69, 83, 67, 125, 125, 32, 45, 98, 114, 101, 97, 107, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109, 32, 45, 119,
  32, 48, 32, 45, 118, 32, 43, 10, 95, 120, 95, 113, 117, 97, 110, 116,
  105, 122, 101, 95, 114, 103, 98, 95, 51, 100, 32, 58, 10, 45, 105, 102,
  32, 36, 111, 98, 106, 51, 100, 32, 45, 114, 109, 91, 111, 98, 106, 51,
  100, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 100, 105, 115, 116,
  114, 105, 98, 117, 116, 105, 111, 110, 51, 100, 91, 99, 101, 110, 116, 114,
  111, 105, 100, 115, 93, 32, 45, 99, 105, 114, 99, 108, 101, 115, 51, 100,
  91, 45, 49, 93, 32, 53, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49,
  93, 32, 50, 53, 53, 10, 45, 99, 111, 108, 111, 114, 99, 117, 98, 101,
  51, 100, 32, 45, 112, 51, 100, 91, 45, 49, 93, 32, 49, 10, 45, 45,
  97, 110, 100, 91, 99, 111, 108, 111, 114, 115, 93, 32, 50, 53, 53, 32,
  45, 100, 105, 115, 116, 114, 105, 98, 117, 116, 105, 111, 110, 51, 100, 91,
  45, 49, 93, 32, 45, 111, 51, 100, 91, 45, 49, 93, 32, 48, 46, 56,
  32, 45, 43, 51, 100, 91, 45, 51, 45, 45, 49, 93, 10, 45, 45, 51,
  100, 91, 45, 49, 93, 32, 49, 50, 56, 44, 49, 50, 56, 44, 49, 50,
  56, 32, 45, 110, 109, 91, 45, 49, 93, 32, 111, 98, 106, 51, 100, 32,
  95, 78, 61, 123, 105, 91, 55, 93, 125, 10, 95, 120, 95, 113, 117, 97,
  110, 116, 105, 122, 101, 95, 114, 103, 98, 95, 116, 101, 120, 116, 32, 58,
  10, 48, 32, 45, 116, 101, 120, 116, 91, 45, 49, 93, 32, 34, 36, 49,
  34, 44, 48, 44, 48, 44, 49, 51, 44, 49, 44, 50, 53, 53, 32, 45,
  114, 91, 45, 49, 93, 32, 123, 119, 43, 50, 125, 44, 49, 53, 44, 49,
  44, 49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45,
  45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51, 32, 45, 116,
  111, 95, 114, 103, 98, 91, 45, 50, 93, 10, 45, 110, 109, 91, 45, 50,
  93, 32, 36, 50, 32, 45, 110, 109, 91, 45, 49, 93, 32, 109, 36, 50,
  10, 120, 95, 114, 101, 102, 108, 101, 99, 116, 105, 111, 110, 51, 100, 32,
  58, 10, 45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45,
  45, 32, 51, 100, 32, 114, 101, 102, 108, 101, 99, 116, 105, 111, 110, 32,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45,
  45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76, 43, 68, 39,
  32, 116, 111, 32, 100, 111, 117, 98, 108, 101, 32, 119, 105, 110, 100, 111,
  119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75,
  101, 121, 115, 32, 39, 67, 84, 82, 76, 43, 67, 39, 32, 116, 111, 32,
  114, 101, 115, 101, 116, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122,
  101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39,
  69, 83, 67, 39, 32, 111, 114, 32, 39, 81, 39, 32, 116, 111, 32, 101,
  120, 105, 116, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 10, 49, 50,
  56, 44, 50, 53, 54, 44, 49, 44, 51, 32, 45, 114, 97, 110, 100, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 112, 108, 97, 115, 109,
  97, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48, 32, 45, 98, 108, 117,
  114, 95, 120, 121, 91, 45, 49, 93, 32, 51, 48, 44, 50, 10, 45, 115,
  104, 91, 45, 49, 93, 32, 48, 44, 48, 32, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 57, 48, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 115,
  104, 91, 45, 49, 93, 32, 49, 44, 49, 32, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 54, 48, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 115,
  104, 91, 45, 49, 93, 32, 50, 44, 50, 32, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 49, 56, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 120, 32, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 97, 91, 45, 52, 45, 45, 49, 93, 32,
  120, 10, 45, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 45, 49,
  93, 32, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 120, 32,
  45, 98, 91, 45, 49, 93, 32, 50, 32, 45, 110, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 10, 45, 116, 111, 114, 117, 115, 51, 100, 32, 51,
  48, 44, 49, 48, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32,
  50, 53, 53, 44, 50, 48, 48, 44, 48, 10, 45, 115, 112, 104, 101, 114,
  105, 99, 97, 108, 51, 100, 32, 52, 55, 44, 51, 52, 44, 34, 56, 48,
  43, 50, 48, 42, 97, 98, 115, 40, 99, 111, 115, 40, 50, 42, 116, 104,
  101, 116, 97, 41, 41, 34, 32, 45, 115, 51, 100, 91, 45, 49, 93, 32,
  45, 114, 109, 91, 45, 50, 93, 32, 45, 105, 91, 45, 50, 93, 32, 51,
  44, 123, 104, 125, 44, 49, 44, 49, 44, 49, 53, 48, 44, 50, 50, 48,
  44, 50, 53, 53, 44, 50, 48, 48, 44, 50, 53, 53, 44, 50, 53, 53,
  32, 45, 121, 91, 45, 50, 93, 32, 45, 97, 91, 45, 54, 45, 45, 49,
  93, 32, 121, 10, 45, 115, 112, 104, 101, 114, 105, 99, 97, 108, 51, 100,
  32, 52, 55, 44, 51, 52, 44, 34, 49, 48, 48, 42, 97, 98, 115, 40,
  49, 43, 48, 46, 54, 42, 99, 111, 115, 40, 51, 42, 112, 104, 105, 41,
  42, 115, 105, 110, 40, 52, 42, 116, 104, 101, 116, 97, 41, 41, 34, 10,
  45, 114, 51, 100, 91, 45, 50, 44, 45, 49, 93, 32, 48, 44, 49, 44,
  48, 44, 57, 48, 32, 45, 100, 98, 51, 100, 32, 48, 10, 120, 98, 61,
  48, 32, 120, 108, 61, 48, 32, 97, 110, 105, 109, 61, 48, 10, 45, 119,
  91, 93, 32, 50, 53, 54, 44, 50, 53, 54, 44, 48, 44, 34, 91, 71,
  39, 77, 73, 67, 93, 32, 51, 100, 32, 114, 101, 102, 108, 101, 99, 116,
  105, 111, 110, 34, 10, 45, 100, 111, 10, 116, 105, 99, 61, 64, 124, 10,
  45, 45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 56, 44, 123, 56, 43,
  51, 42, 105, 91, 54, 93, 45, 49, 125, 32, 45, 45, 106, 91, 45, 51,
  93, 32, 91, 45, 49, 93, 44, 48, 44, 56, 44, 48, 44, 48, 44, 123,
  105, 102, 40, 36, 97, 110, 105, 109, 60, 50, 53, 48, 44, 48, 44, 48,
  46, 53, 45, 48, 46, 53, 42, 99, 111, 115, 40, 40, 36, 97, 110, 105,
  109, 45, 50, 53, 48, 41, 47, 49, 48, 48, 41, 41, 125, 32, 45, 114,
  109, 91, 45, 50, 93, 10, 45, 45, 122, 91, 45, 54, 93, 32, 36, 120,
  98, 44, 48, 44, 123, 36, 120, 98, 43, 50, 53, 53, 125, 44, 50, 53,
  53, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32,
  91, 45, 50, 93, 44, 55, 53, 37, 44, 53, 48, 37, 44, 48, 44, 49,
  44, 51, 44, 48, 44, 48, 10, 45, 45, 122, 91, 45, 54, 93, 32, 36,
  120, 108, 44, 48, 44, 123, 36, 120, 108, 43, 50, 53, 53, 125, 44, 50,
  53, 53, 10, 120, 102, 61, 123, 109, 105, 110, 40, 51, 48, 44, 36, 97,
  110, 105, 109, 45, 55, 48, 41, 43, 50, 48, 42, 99, 111, 115, 40, 49,
  46, 56, 42, 64, 124, 41, 125, 10, 121, 102, 61, 123, 53, 48, 43, 50,
  48, 42, 115, 105, 110, 40, 50, 46, 55, 42, 64, 124, 41, 125, 10, 45,
  111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 54,
  93, 44, 123, 50, 48, 43, 36, 120, 102, 125, 37, 44, 36, 121, 102, 37,
  44, 48, 44, 49, 44, 52, 44, 48, 44, 48, 10, 45, 108, 51, 100, 32,
  91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 45, 111,
  98, 106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  44, 55, 53, 37, 44, 53, 48, 37, 44, 48, 44, 49, 44, 53, 44, 48,
  44, 48, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 48, 46, 54, 32, 45, 114, 109, 91, 45,
  51, 44, 45, 49, 93, 10, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91,
  45, 49, 93, 32, 91, 45, 52, 93, 44, 36, 120, 102, 37, 44, 36, 121,
  102, 37, 44, 48, 44, 49, 44, 52, 44, 48, 44, 48, 10, 45, 119, 91,
  45, 49, 93, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82,
  76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 68, 125, 125, 32,
  45, 119, 91, 93, 32, 123, 50, 42, 119, 125, 44, 123, 50, 42, 104, 125,
  32, 45, 101, 108, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82, 76,
  76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 67, 125, 125, 32, 45,
  119, 91, 93, 32, 123, 119, 125, 44, 123, 104, 125, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 114, 109, 91, 45, 49, 93, 10, 120, 98, 61, 123, 40,
  36, 120, 98, 43, 54, 41, 38, 50, 53, 53, 125, 10, 120, 108, 61, 123,
  40, 36, 120, 108, 45, 54, 41, 38, 50, 53, 53, 125, 10, 97, 110, 105,
  109, 61, 123, 36, 97, 110, 105, 109, 43, 49, 125, 10, 45, 114, 51, 100,
  91, 45, 50, 44, 45, 49, 93, 32, 123, 115, 105, 110, 40, 48, 46, 53,
  42, 64, 124, 41, 125, 44, 123, 99, 111, 115, 40, 64, 124, 41, 125, 44,
  49, 44, 123, 40, 64, 124, 45, 36, 116, 105, 99, 41, 42, 51, 51, 125,
  10, 45, 114, 51, 100, 91, 45, 51, 93, 32, 45, 49, 44, 48, 46, 51,
  44, 48, 46, 56, 44, 123, 40, 64, 124, 45, 36, 116, 105, 99, 41, 42,
  49, 48, 48, 125, 10, 45, 119, 97, 105, 116, 32, 50, 48, 10, 45, 119,
  104, 105, 108, 101, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34, 33, 64,
  123, 33, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123,
  33, 44, 81, 125, 125, 10, 45, 114, 109, 91, 45, 53, 45, 45, 49, 93,
  32, 45, 119, 91, 93, 32, 48, 32, 45, 118, 32, 43, 10, 120, 95, 114,
  117, 98, 98, 101, 114, 51, 100, 32, 58, 10, 45, 101, 91, 93, 32, 34,
  92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 51, 100, 32, 114, 117, 98,
  98, 101, 114, 32, 111, 98, 106, 101, 99, 116, 32, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45,
  45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32,
  39, 67, 84, 82, 76, 43, 68, 39, 32, 116, 111, 32, 100, 111, 117, 98,
  108, 101, 32, 119, 105, 110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92,
  110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82,
  76, 43, 67, 39, 32, 116, 111, 32, 114, 101, 115, 101, 116, 32, 119, 105,
  110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45,
  45, 32, 75, 101, 121, 115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32,
  39, 81, 39, 32, 116, 111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45,
  45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 109, 10, 45, 115, 112, 104, 101, 114,
  101, 51, 100, 32, 49, 53, 48, 44, 48, 32, 45, 116, 111, 114, 117, 115,
  51, 100, 32, 55, 48, 44, 49, 53, 32, 45, 99, 121, 108, 105, 110, 100,
  101, 114, 51, 100, 32, 50, 48, 44, 52, 48, 10, 45, 99, 111, 108, 51,
  100, 91, 45, 51, 93, 32, 50, 48, 48, 44, 50, 48, 48, 44, 50, 48,
  48, 44, 48, 46, 51, 32, 45, 99, 111, 108, 51, 100, 91, 45, 50, 93,
  32, 49, 50, 56, 44, 50, 48, 48, 44, 55, 54, 32, 45, 99, 111, 108,
  51, 100, 91, 45, 49, 93, 32, 50, 48, 48, 44, 49, 50, 56, 44, 55,
  54, 10, 45, 99, 51, 100, 91, 45, 51, 45, 45, 49, 93, 32, 45, 114,
  51, 100, 91, 45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 55, 48, 32,
  45, 43, 51, 100, 91, 45, 51, 45, 45, 49, 93, 32, 45, 43, 51, 100,
  91, 45, 49, 93, 32, 49, 48, 44, 45, 56, 44, 50, 48, 10, 50, 53,
  54, 44, 50, 53, 54, 44, 54, 52, 44, 51, 10, 123, 119, 125, 44, 123,
  104, 125, 44, 49, 44, 51, 44, 39, 105, 102, 40, 99, 61, 61, 48, 44,
  120, 44, 105, 102, 40, 99, 61, 61, 49, 44, 121, 44, 121, 42, 64, 123,
  49, 44, 100, 125, 47, 104, 41, 41, 39, 10, 123, 119, 125, 44, 123, 104,
  125, 44, 49, 44, 51, 10, 45, 119, 91, 93, 32, 123, 119, 125, 44, 123,
  104, 125, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 51, 100,
  32, 114, 117, 98, 98, 101, 114, 32, 111, 98, 106, 101, 99, 116, 34, 10,
  102, 114, 97, 109, 101, 61, 48, 10, 45, 100, 111, 10, 123, 119, 125, 44,
  123, 104, 125, 44, 49, 44, 51, 32, 45, 102, 99, 91, 45, 49, 93, 32,
  49, 54, 44, 51, 50, 44, 51, 50, 32, 45, 111, 98, 106, 101, 99, 116,
  51, 100, 91, 45, 49, 93, 32, 91, 48, 93, 44, 53, 48, 37, 44, 53,
  48, 37, 44, 48, 44, 49, 44, 51, 44, 48, 44, 48, 32, 45, 106, 91,
  49, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 44, 36, 102, 114, 97,
  109, 101, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 114, 51, 100, 91,
  48, 93, 32, 48, 46, 49, 44, 49, 44, 48, 46, 54, 44, 123, 51, 42,
  99, 111, 115, 40, 64, 124, 42, 49, 46, 50, 53, 41, 125, 32, 45, 114,
  51, 100, 91, 48, 93, 32, 49, 44, 48, 46, 50, 44, 48, 46, 54, 44,
  45, 49, 10, 45, 45, 119, 97, 114, 112, 91, 49, 93, 32, 91, 50, 93,
  44, 48, 44, 48, 32, 45, 42, 91, 51, 93, 32, 48, 46, 56, 32, 45,
  42, 91, 45, 49, 93, 32, 48, 46, 50, 32, 45, 43, 91, 51, 44, 45,
  49, 93, 10, 45, 119, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 64,
  123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123,
  33, 44, 68, 125, 125, 32, 45, 119, 91, 93, 32, 123, 50, 42, 119, 125,
  44, 123, 50, 42, 104, 125, 32, 45, 101, 108, 105, 102, 32, 123, 64, 123,
  33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33,
  44, 67, 125, 125, 32, 45, 119, 91, 93, 32, 123, 119, 125, 44, 123, 104,
  125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 119, 97, 105, 116, 32, 50,
  48, 10, 45, 115, 104, 91, 50, 93, 32, 50, 44, 50, 32, 45, 45, 91,
  45, 49, 93, 32, 49, 32, 45, 97, 110, 100, 91, 45, 49, 93, 32, 123,
  64, 123, 49, 44, 100, 125, 45, 49, 125, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 102, 114, 97, 109, 101, 61, 123, 40, 36, 102, 114, 97, 109, 101,
  45, 49, 41, 37, 64, 123, 49, 44, 100, 125, 125, 10, 45, 119, 104, 105,
  108, 101, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33,
  44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44,
  81, 125, 125, 10, 45, 114, 109, 32, 45, 119, 32, 48, 32, 45, 118, 32,
  43, 10, 120, 95, 115, 104, 97, 100, 101, 98, 111, 98, 115, 32, 58, 10,
  45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32,
  83, 104, 97, 100, 101, 32, 98, 111, 98, 115, 32, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45,
  45, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 69,
  83, 67, 39, 32, 111, 114, 32, 39, 81, 39, 32, 116, 111, 32, 101, 120,
  105, 116, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 109, 32, 116, 61, 49, 48, 48, 32, 45,
  119, 32, 53, 49, 50, 44, 53, 49, 50, 44, 48, 44, 34, 91, 71, 39,
  77, 73, 67, 93, 32, 83, 104, 97, 100, 101, 32, 98, 111, 98, 115, 34,
  10, 45, 100, 111, 10, 116, 61, 123, 36, 116, 43, 48, 46, 48, 49, 53,
  125, 10, 45, 105, 102, 32, 123, 36, 116, 62, 52, 42, 112, 105, 34, 32,
  124, 124, 32, 34, 64, 123, 33, 44, 98, 125, 125, 10, 114, 120, 61, 123,
  63, 40, 45, 49, 44, 49, 41, 125, 32, 114, 121, 61, 123, 63, 40, 45,
  49, 44, 49, 41, 125, 32, 114, 122, 61, 123, 63, 40, 45, 49, 44, 49,
  41, 125, 32, 114, 116, 61, 123, 63, 40, 45, 49, 44, 49, 41, 125, 32,
  114, 99, 120, 61, 123, 63, 40, 45, 48, 46, 54, 42, 48, 46, 54, 41,
  125, 32, 116, 61, 48, 10, 78, 61, 123, 50, 48, 43, 114, 111, 117, 110,
  100, 40, 63, 40, 56, 48, 41, 41, 125, 32, 82, 61, 123, 40, 50, 43,
  114, 111, 117, 110, 100, 40, 63, 40, 52, 48, 41, 41, 41, 42, 109, 105,
  110, 40, 64, 123, 33, 44, 119, 125, 44, 64, 123, 33, 44, 104, 125, 41,
  47, 51, 48, 48, 125, 10, 45, 105, 102, 32, 36, 111, 98, 106, 51, 100,
  32, 45, 114, 109, 91, 99, 111, 108, 111, 114, 109, 97, 112, 44, 105, 109,
  103, 44, 111, 98, 106, 51, 100, 93, 32, 45, 101, 110, 100, 105, 102, 10,
  123, 52, 43, 114, 111, 117, 110, 100, 40, 63, 40, 49, 50, 41, 41, 125,
  44, 49, 44, 49, 44, 51, 32, 45, 110, 111, 105, 115, 101, 91, 48, 93,
  32, 50, 53, 53, 44, 50, 32, 45, 114, 91, 48, 93, 32, 50, 53, 54,
  44, 49, 44, 49, 44, 51, 44, 51, 32, 45, 42, 91, 48, 93, 32, 50,
  53, 53, 32, 45, 115, 104, 105, 102, 116, 91, 48, 93, 32, 49, 32, 45,
  110, 109, 91, 45, 49, 93, 32, 99, 111, 108, 111, 114, 109, 97, 112, 10,
  40, 54, 55, 46, 53, 59, 55, 51, 46, 53, 59, 49, 48, 57, 46, 53,
  59, 49, 48, 51, 46, 53, 59, 53, 49, 46, 53, 59, 49, 48, 48, 46,
  53, 59, 123, 50, 42, 36, 78, 125, 59, 36, 78, 41, 32, 51, 44, 123,
  50, 42, 36, 78, 125, 44, 49, 44, 49, 44, 48, 10, 49, 44, 36, 78,
  44, 49, 44, 49, 44, 53, 32, 50, 44, 36, 78, 44, 49, 44, 49, 44,
  39, 121, 43, 120, 42, 36, 78, 39, 32, 45, 97, 91, 45, 50, 45, 45,
  49, 93, 32, 120, 32, 45, 122, 91, 45, 49, 93, 32, 48, 44, 53, 10,
  52, 44, 36, 78, 44, 49, 44, 49, 44, 49, 32, 45, 121, 91, 45, 51,
  45, 45, 49, 93, 32, 45, 97, 91, 45, 52, 45, 45, 49, 93, 32, 121,
  32, 45, 110, 109, 91, 45, 49, 93, 32, 111, 98, 106, 51, 100, 10, 64,
  123, 33, 44, 119, 125, 44, 64, 123, 33, 44, 104, 125, 32, 45, 110, 109,
  91, 45, 49, 93, 32, 105, 109, 103, 10, 45, 119, 97, 105, 116, 32, 45,
  49, 10, 45, 101, 110, 100, 105, 102, 10, 114, 61, 123, 36, 114, 121, 43,
  36, 114, 120, 42, 99, 111, 115, 40, 54, 42, 36, 114, 122, 42, 36, 116,
  41, 43, 40, 49, 45, 36, 114, 120, 41, 42, 115, 105, 110, 40, 54, 42,
  36, 114, 116, 42, 36, 116, 41, 125, 10, 40, 48, 59, 123, 51, 48, 42,
  36, 114, 121, 42, 40, 36, 78, 45, 49, 41, 125, 41, 32, 40, 36, 116,
  59, 123, 50, 42, 112, 105, 42, 40, 36, 78, 45, 49, 41, 47, 36, 78,
  43, 36, 116, 125, 41, 32, 45, 114, 91, 45, 50, 44, 45, 49, 93, 32,
  49, 44, 36, 78, 44, 49, 44, 49, 44, 51, 10, 45, 43, 91, 45, 50,
  93, 32, 123, 51, 54, 48, 42, 115, 105, 110, 40, 36, 114, 122, 42, 36,
  116, 41, 125, 32, 45, 42, 91, 45, 50, 93, 32, 123, 112, 105, 47, 49,
  56, 48, 125, 10, 45, 45, 115, 105, 110, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 99, 111, 115, 91, 45, 52, 44, 45, 51, 93, 32, 45, 42, 91,
  45, 52, 44, 45, 50, 93, 32, 36, 114, 32, 45, 42, 91, 45, 51, 44,
  45, 49, 93, 32, 36, 114, 99, 120, 32, 45, 43, 91, 45, 52, 44, 45,
  51, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 42, 91,
  45, 50, 93, 32, 123, 64, 123, 33, 44, 119, 125, 47, 50, 125, 32, 45,
  42, 91, 45, 49, 93, 32, 123, 64, 123, 33, 44, 104, 125, 47, 50, 125,
  32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 10, 45, 45, 43,
  91, 45, 49, 93, 32, 36, 82, 32, 45, 45, 91, 45, 50, 93, 32, 36,
  82, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 32, 45, 122,
  91, 45, 49, 93, 32, 48, 44, 50, 32, 45, 121, 91, 45, 49, 93, 32,
  45, 106, 91, 111, 98, 106, 51, 100, 93, 32, 91, 45, 49, 93, 44, 48,
  44, 56, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 111, 98, 106, 101,
  99, 116, 51, 100, 91, 105, 109, 103, 93, 32, 91, 111, 98, 106, 51, 100,
  93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 45, 49, 44, 50,
  44, 48, 44, 48, 10, 45, 97, 110, 100, 91, 105, 109, 103, 93, 32, 50,
  53, 53, 32, 45, 45, 109, 97, 112, 91, 105, 109, 103, 93, 32, 91, 99,
  111, 108, 111, 114, 109, 97, 112, 93, 32, 45, 119, 91, 45, 49, 93, 32,
  45, 114, 109, 91, 45, 49, 93, 32, 45, 119, 97, 105, 116, 32, 50, 48,
  10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34, 32, 38, 38, 32,
  34, 33, 64, 123, 33, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34,
  33, 64, 123, 33, 44, 81, 125, 125, 10, 45, 114, 109, 32, 45, 119, 32,
  48, 32, 45, 118, 32, 43, 10, 120, 95, 115, 112, 108, 105, 110, 101, 32,
  58, 10, 45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45,
  45, 32, 83, 112, 108, 105, 110, 101, 32, 99, 117, 114, 118, 101, 32, 101,
  100, 105, 116, 111, 114, 32, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 32, 77,
  111, 117, 115, 101, 32, 116, 111, 32, 105, 110, 115, 101, 114, 116, 47, 109,
  111, 118, 101, 47, 100, 101, 108, 101, 116, 101, 32, 112, 111, 105, 110, 116,
  115, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 32, 39, 82,
  39, 32, 116, 111, 32, 114, 101, 115, 101, 116, 32, 116, 104, 101, 32, 99,
  117, 114, 118, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121,
  32, 39, 83, 80, 65, 67, 69, 39, 32, 116, 111, 32, 115, 104, 111, 119,
  115, 47, 104, 105, 100, 101, 32, 115, 112, 108, 105, 110, 101, 32, 99, 117,
  114, 118, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 32,
  39, 80, 39, 32, 116, 111, 32, 115, 104, 111, 119, 115, 47, 104, 105, 100,
  101, 32, 99, 111, 110, 116, 114, 111, 108, 32, 112, 111, 105, 110, 116, 115,
  46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 32, 39, 69, 78,
  84, 69, 82, 39, 32, 116, 111, 32, 115, 104, 111, 119, 115, 47, 104, 105,
  100, 101, 32, 99, 111, 110, 116, 114, 111, 108, 32, 112, 111, 108, 121, 103,
  111, 110, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 32, 39,
  84, 39, 32, 116, 111, 32, 115, 104, 111, 119, 115, 47, 104, 105, 100, 101,
  32, 112, 111, 105, 110, 116, 32, 116, 97, 110, 103, 101, 110, 116, 115, 46,
  92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 32, 39, 73, 39, 32,
  116, 111, 32, 115, 104, 111, 119, 115, 47, 104, 105, 100, 101, 32, 112, 111,
  105, 110, 116, 32, 105, 110, 100, 105, 99, 101, 115, 46, 92, 110, 10, 45,
  45, 45, 45, 32, 75, 101, 121, 32, 39, 67, 39, 32, 116, 111, 32, 115,
  104, 111, 119, 115, 47, 104, 105, 100, 101, 32, 112, 111, 105, 110, 116, 32,
  99, 111, 111, 114, 100, 105, 110, 97, 116, 101, 115, 46, 92, 110, 10, 45,
  45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 43, 39, 32, 97, 110, 100,
  32, 39, 45, 39, 32, 116, 111, 32, 105, 110, 99, 114, 101, 97, 115, 101,
  47, 100, 101, 99, 114, 101, 97, 115, 101, 32, 114, 111, 117, 110, 100, 110,
  101, 115, 115, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115,
  32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81, 39, 32, 116, 111,
  32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32,
  64, 35, 32, 45, 97, 32, 120, 32, 45, 110, 32, 48, 44, 50, 53, 53,
  32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 101, 108, 115, 101, 32, 40,
  48, 59, 48, 94, 48, 59, 49, 50, 56, 94, 48, 59, 48, 41, 32, 45,
  114, 91, 45, 49, 93, 32, 53, 49, 50, 44, 53, 49, 50, 44, 49, 44,
  51, 44, 51, 32, 45, 110, 97, 109, 101, 91, 45, 49, 93, 32, 34, 91,
  71, 39, 77, 73, 67, 93, 32, 83, 112, 108, 105, 110, 101, 32, 69, 100,
  105, 116, 111, 114, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 119, 91,
  48, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125,
  44, 48, 44, 48, 44, 45, 49, 44, 45, 49, 44, 64, 123, 45, 49, 44,
  110, 125, 32, 45, 114, 91, 48, 93, 32, 64, 123, 33, 44, 119, 125, 44,
  64, 123, 33, 44, 104, 125, 44, 49, 44, 51, 44, 49, 10, 45, 105, 91,
  49, 93, 32, 49, 10, 114, 111, 117, 110, 100, 110, 101, 115, 115, 61, 48,
  46, 53, 10, 118, 105, 115, 117, 102, 108, 97, 103, 115, 61, 50, 51, 10,
  110, 101, 97, 114, 101, 115, 116, 61, 45, 49, 10, 97, 99, 116, 105, 118,
  101, 61, 45, 49, 10, 45, 100, 111, 10, 45, 105, 102, 32, 123, 64, 123,
  49, 44, 35, 125, 61, 61, 49, 125, 10, 45, 114, 109, 91, 49, 93, 32,
  114, 111, 117, 110, 100, 110, 101, 115, 115, 61, 48, 46, 53, 32, 110, 101,
  97, 114, 101, 115, 116, 61, 45, 49, 32, 97, 99, 116, 105, 118, 101, 61,
  45, 49, 10, 45, 105, 91, 49, 93, 32, 40, 123, 48, 46, 50, 42, 119,
  125, 44, 123, 48, 46, 50, 42, 104, 125, 59, 92, 10, 123, 48, 46, 50,
  42, 119, 125, 44, 123, 48, 46, 56, 42, 104, 125, 59, 92, 10, 123, 48,
  46, 56, 42, 119, 125, 44, 123, 48, 46, 56, 42, 104, 125, 59, 92, 10,
  123, 48, 46, 56, 42, 119, 125, 44, 123, 48, 46, 50, 42, 104, 125, 41,
  10, 45, 101, 110, 100, 105, 102, 10, 91, 49, 93, 32, 40, 123, 64, 123,
  33, 44, 119, 125, 47, 64, 123, 48, 44, 119, 125, 125, 44, 123, 64, 123,
  33, 44, 104, 125, 47, 64, 123, 48, 44, 104, 125, 125, 41, 32, 45, 42,
  91, 45, 50, 44, 45, 49, 93, 10, 45, 45, 115, 104, 105, 102, 116, 91,
  50, 93, 32, 48, 44, 45, 49, 44, 48, 44, 48, 44, 50, 32, 45, 45,
  115, 104, 105, 102, 116, 91, 50, 93, 32, 48, 44, 49, 44, 48, 44, 48,
  44, 50, 32, 45, 45, 91, 45, 50, 44, 45, 49, 93, 32, 45, 42, 91,
  45, 49, 93, 32, 36, 114, 111, 117, 110, 100, 110, 101, 115, 115, 10, 45,
  45, 115, 91, 45, 49, 93, 32, 120, 32, 45, 115, 113, 114, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  115, 113, 114, 116, 91, 45, 49, 93, 32, 45, 114, 91, 45, 49, 93, 32,
  50, 32, 45, 45, 47, 91, 45, 50, 44, 45, 49, 93, 32, 45, 114, 109,
  91, 45, 50, 93, 10, 45, 45, 114, 91, 48, 93, 32, 64, 123, 33, 44,
  119, 125, 44, 64, 123, 33, 44, 104, 125, 44, 49, 44, 51, 10, 45, 105,
  102, 32, 123, 36, 118, 105, 115, 117, 102, 108, 97, 103, 115, 38, 52, 125,
  32, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 64, 123,
  50, 44, 104, 125, 44, 64, 50, 44, 48, 46, 51, 44, 49, 50, 56, 44,
  50, 48, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 123, 49, 44, 104, 125, 10, 45, 108,
  105, 110, 101, 91, 45, 49, 93, 32, 64, 123, 50, 44, 48, 45, 51, 125,
  44, 48, 46, 51, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 10, 45,
  105, 102, 32, 123, 36, 118, 105, 115, 117, 102, 108, 97, 103, 115, 38, 49,
  125, 32, 45, 115, 112, 108, 105, 110, 101, 91, 45, 49, 93, 32, 64, 123,
  50, 44, 48, 45, 49, 125, 44, 64, 123, 51, 44, 48, 45, 49, 125, 44,
  64, 123, 50, 44, 50, 45, 51, 125, 44, 64, 123, 51, 44, 50, 45, 51,
  125, 44, 51, 50, 44, 49, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 118, 105, 115, 117, 102, 108, 97, 103,
  115, 38, 56, 125, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 123,
  64, 123, 50, 44, 48, 125, 45, 64, 123, 52, 44, 48, 125, 42, 50, 48,
  125, 44, 123, 64, 123, 50, 44, 49, 125, 45, 64, 123, 52, 44, 49, 125,
  42, 50, 48, 125, 44, 123, 64, 123, 50, 44, 48, 125, 43, 64, 123, 52,
  44, 48, 125, 42, 50, 48, 125, 44, 123, 64, 123, 50, 44, 49, 125, 43,
  64, 123, 52, 44, 49, 125, 42, 50, 48, 125, 44, 49, 44, 48, 44, 50,
  53, 53, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 118, 105, 115, 117, 102, 108, 97, 103, 115, 38, 49, 54, 125, 32,
  45, 116, 91, 45, 49, 93, 32, 36, 62, 44, 123, 64, 123, 50, 44, 48,
  125, 45, 51, 125, 44, 123, 64, 123, 50, 44, 49, 125, 45, 49, 56, 125,
  44, 49, 51, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 118, 105, 115,
  117, 102, 108, 97, 103, 115, 38, 51, 50, 125, 32, 45, 116, 91, 45, 49,
  93, 32, 34, 40, 34, 123, 114, 111, 117, 110, 100, 40, 64, 123, 49, 44,
  48, 125, 41, 125, 34, 44, 34, 123, 114, 111, 117, 110, 100, 40, 64, 123,
  49, 44, 49, 125, 41, 125, 34, 41, 34, 44, 123, 64, 123, 50, 44, 48,
  125, 45, 49, 54, 125, 44, 123, 64, 123, 50, 44, 49, 125, 43, 49, 48,
  125, 44, 49, 51, 44, 49, 44, 49, 48, 48, 44, 50, 48, 48, 44, 50,
  53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 115, 104, 105, 102, 116,
  91, 49, 45, 52, 93, 32, 48, 44, 45, 49, 44, 48, 44, 48, 44, 50,
  10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 118, 105, 115,
  117, 102, 108, 97, 103, 115, 34, 38, 50, 34, 125, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 123, 49, 44, 104, 125, 10, 45, 101, 108, 108, 105,
  112, 115, 101, 91, 45, 49, 93, 32, 64, 123, 50, 44, 48, 45, 49, 125,
  44, 52, 44, 52, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 32, 45,
  101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 64, 123, 50, 44,
  48, 45, 49, 125, 44, 50, 44, 50, 44, 48, 44, 49, 44, 50, 53, 53,
  44, 49, 48, 48, 44, 49, 53, 53, 32, 45, 115, 104, 105, 102, 116, 91,
  50, 93, 32, 48, 44, 49, 44, 48, 44, 48, 44, 50, 10, 45, 100, 111,
  110, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 119, 91, 45, 49, 93,
  32, 45, 114, 109, 91, 51, 44, 52, 44, 45, 49, 93, 32, 45, 119, 97,
  105, 116, 10, 45, 105, 102, 32, 64, 123, 33, 44, 83, 80, 65, 67, 69,
  125, 32, 118, 105, 115, 117, 102, 108, 97, 103, 115, 61, 123, 36, 118, 105,
  115, 117, 102, 108, 97, 103, 115, 43, 105, 102, 40, 36, 118, 105, 115, 117,
  102, 108, 97, 103, 115, 38, 49, 44, 45, 49, 44, 49, 41, 125, 32, 45,
  119, 97, 105, 116, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 64, 123, 33, 44, 80, 125, 32, 118, 105, 115, 117, 102, 108,
  97, 103, 115, 61, 123, 36, 118, 105, 115, 117, 102, 108, 97, 103, 115, 43,
  105, 102, 40, 36, 118, 105, 115, 117, 102, 108, 97, 103, 115, 38, 50, 44,
  45, 50, 44, 50, 41, 125, 32, 45, 119, 97, 105, 116, 32, 45, 49, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 64, 123, 33, 44, 69,
  78, 84, 69, 82, 125, 32, 118, 105, 115, 117, 102, 108, 97, 103, 115, 61,
  123, 36, 118, 105, 115, 117, 102, 108, 97, 103, 115, 43, 105, 102, 40, 36,
  118, 105, 115, 117, 102, 108, 97, 103, 115, 38, 52, 44, 45, 52, 44, 52,
  41, 125, 32, 45, 119, 97, 105, 116, 32, 45, 49, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 64, 123, 33, 44, 84, 125, 32, 118, 105,
  115, 117, 102, 108, 97, 103, 115, 61, 123, 36, 118, 105, 115, 117, 102, 108,
  97, 103, 115, 43, 105, 102, 40, 36, 118, 105, 115, 117, 102, 108, 97, 103,
  115, 38, 56, 44, 45, 56, 44, 56, 41, 125, 32, 45, 119, 97, 105, 116,
  32, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 64,
  123, 33, 44, 73, 125, 32, 118, 105, 115, 117, 102, 108, 97, 103, 115, 61,
  123, 36, 118, 105, 115, 117, 102, 108, 97, 103, 115, 43, 105, 102, 40, 36,
  118, 105, 115, 117, 102, 108, 97, 103, 115, 38, 49, 54, 44, 45, 49, 54,
  44, 49, 54, 41, 125, 32, 45, 119, 97, 105, 116, 32, 45, 49, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 67,
  125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 67, 84, 82, 76,
  76, 69, 70, 84, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44,
  67, 84, 82, 76, 82, 73, 71, 72, 84, 125, 125, 32, 118, 105, 115, 117,
  102, 108, 97, 103, 115, 61, 123, 36, 118, 105, 115, 117, 102, 108, 97, 103,
  115, 43, 105, 102, 40, 36, 118, 105, 115, 117, 102, 108, 97, 103, 115, 38,
  51, 50, 44, 45, 51, 50, 44, 51, 50, 41, 125, 32, 45, 119, 97, 105,
  116, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 64, 123, 33, 44, 80, 65, 68, 65, 68, 68, 125, 34, 32, 38, 38,
  32, 34, 36, 114, 111, 117, 110, 100, 110, 101, 115, 115, 60, 49, 125, 32,
  114, 111, 117, 110, 100, 110, 101, 115, 115, 61, 123, 36, 114, 111, 117, 110,
  100, 110, 101, 115, 115, 42, 49, 46, 49, 125, 32, 45, 119, 97, 105, 116,
  32, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  64, 123, 33, 44, 80, 65, 68, 83, 85, 66, 125, 34, 32, 38, 38, 32,
  34, 36, 114, 111, 117, 110, 100, 110, 101, 115, 115, 62, 48, 46, 49, 125,
  32, 114, 111, 117, 110, 100, 110, 101, 115, 115, 61, 123, 36, 114, 111, 117,
  110, 100, 110, 101, 115, 115, 42, 48, 46, 57, 125, 32, 45, 119, 97, 105,
  116, 32, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 64, 123, 33, 44, 82, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123,
  33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 34, 32, 38, 38, 32,
  34, 33, 64, 123, 33, 44, 67, 84, 82, 76, 82, 73, 71, 72, 84, 125,
  125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 105, 91, 49, 93, 32,
  49, 32, 45, 119, 97, 105, 116, 32, 45, 49, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 40, 64, 123, 33, 44, 67, 84, 82, 76,
  76, 69, 70, 84, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 44, 67,
  84, 82, 76, 82, 73, 71, 72, 84, 125, 41, 34, 32, 38, 38, 32, 34,
  64, 123, 33, 44, 68, 125, 125, 32, 45, 119, 91, 93, 32, 123, 64, 123,
  33, 44, 119, 125, 42, 49, 46, 53, 125, 44, 123, 64, 123, 33, 44, 104,
  125, 42, 49, 46, 53, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 40, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84,
  125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 44, 67, 84, 82, 76, 82,
  73, 71, 72, 84, 125, 41, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44,
  67, 125, 125, 32, 45, 119, 91, 93, 32, 123, 64, 123, 33, 44, 119, 125,
  47, 49, 46, 53, 125, 44, 123, 64, 123, 33, 44, 104, 125, 47, 49, 46,
  53, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 40,
  64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 34, 32, 124,
  124, 32, 34, 64, 123, 33, 44, 67, 84, 82, 76, 82, 73, 71, 72, 84,
  125, 41, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 82, 125, 125, 32,
  45, 119, 91, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44,
  104, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 64, 123,
  33, 44, 114, 125, 32, 45, 119, 91, 93, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 98, 125, 61, 61, 48, 125,
  32, 97, 99, 116, 105, 118, 101, 61, 45, 49, 10, 45, 101, 108, 105, 102,
  32, 123, 64, 123, 33, 44, 120, 125, 62, 61, 48, 34, 32, 38, 38, 32,
  34, 64, 123, 33, 44, 98, 125, 34, 32, 38, 38, 32, 34, 36, 97, 99,
  116, 105, 118, 101, 61, 61, 45, 49, 125, 10, 91, 50, 93, 32, 40, 64,
  123, 33, 44, 120, 125, 44, 64, 123, 33, 44, 121, 125, 41, 32, 45, 45,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 115, 113, 114, 91, 45, 49, 93,
  32, 45, 115, 91, 45, 49, 93, 32, 120, 32, 45, 43, 91, 45, 50, 44,
  45, 49, 93, 10, 40, 64, 123, 45, 49, 44, 99, 125, 41, 32, 110, 101,
  97, 114, 101, 115, 116, 61, 64, 123, 45, 49, 44, 49, 125, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 64, 123, 45, 49, 44,
  109, 125, 60, 54, 52, 125, 32, 97, 99, 116, 105, 118, 101, 61, 36, 110,
  101, 97, 114, 101, 115, 116, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109,
  91, 50, 93, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 98, 125, 38,
  49, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 120, 125, 62, 61, 48,
  34, 32, 38, 38, 32, 34, 36, 97, 99, 116, 105, 118, 101, 33, 61, 45,
  49, 125, 10, 45, 61, 91, 49, 93, 32, 123, 64, 123, 33, 44, 120, 125,
  42, 64, 123, 48, 44, 119, 125, 47, 64, 123, 33, 44, 119, 125, 125, 44,
  48, 44, 36, 97, 99, 116, 105, 118, 101, 10, 45, 61, 91, 49, 93, 32,
  123, 64, 123, 33, 44, 121, 125, 42, 64, 123, 48, 44, 104, 125, 47, 64,
  123, 33, 44, 104, 125, 125, 44, 49, 44, 36, 97, 99, 116, 105, 118, 101,
  10, 45, 101, 108, 105, 102, 32, 123, 64, 123, 33, 44, 98, 125, 38, 50,
  34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 120, 125, 62, 61, 48, 34,
  32, 38, 38, 32, 34, 64, 123, 49, 44, 104, 125, 62, 51, 125, 10, 45,
  108, 91, 49, 93, 32, 45, 115, 32, 121, 32, 45, 114, 109, 91, 36, 110,
  101, 97, 114, 101, 115, 116, 93, 32, 45, 97, 32, 121, 32, 45, 101, 110,
  100, 108, 32, 45, 119, 97, 105, 116, 32, 45, 49, 10, 45, 101, 108, 105,
  102, 32, 123, 64, 123, 33, 44, 98, 125, 38, 49, 34, 32, 38, 38, 32,
  34, 64, 123, 33, 44, 120, 125, 62, 61, 48, 125, 10, 120, 121, 61, 40,
  123, 64, 123, 33, 44, 120, 125, 42, 64, 123, 48, 44, 119, 125, 47, 64,
  123, 33, 44, 119, 125, 125, 44, 123, 64, 123, 33, 44, 121, 125, 42, 64,
  123, 48, 44, 104, 125, 47, 64, 123, 33, 44, 104, 125, 125, 41, 10, 45,
  45, 115, 104, 105, 102, 116, 91, 49, 93, 32, 48, 44, 45, 49, 44, 48,
  44, 48, 44, 50, 32, 45, 43, 91, 45, 49, 93, 32, 91, 49, 93, 32,
  45, 47, 91, 45, 49, 93, 32, 50, 10, 36, 120, 121, 32, 45, 45, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 115, 113, 114, 91, 45, 49, 93, 32,
  45, 115, 91, 45, 49, 93, 32, 120, 32, 45, 43, 91, 45, 50, 44, 45,
  49, 93, 10, 40, 64, 123, 45, 49, 44, 99, 125, 41, 32, 110, 115, 61,
  64, 123, 45, 49, 44, 49, 125, 32, 45, 114, 109, 91, 45, 50, 44, 45,
  49, 93, 10, 45, 108, 91, 49, 93, 32, 45, 115, 32, 121, 32, 45, 105,
  91, 123, 36, 110, 115, 43, 49, 125, 93, 32, 36, 120, 121, 32, 45, 97,
  32, 121, 32, 45, 101, 110, 100, 108, 10, 97, 99, 116, 105, 118, 101, 61,
  123, 36, 110, 115, 43, 49, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  119, 104, 105, 108, 101, 32, 123, 64, 33, 34, 32, 38, 38, 32, 34, 33,
  64, 123, 33, 44, 69, 83, 67, 125, 34, 32, 38, 38, 32, 34, 33, 64,
  123, 33, 44, 81, 125, 125, 10, 45, 45, 115, 104, 105, 102, 116, 91, 49,
  93, 32, 48, 44, 45, 49, 44, 48, 44, 48, 44, 50, 32, 45, 45, 115,
  104, 105, 102, 116, 91, 49, 93, 32, 48, 44, 49, 44, 48, 44, 48, 44,
  50, 32, 45, 45, 91, 45, 50, 44, 45, 49, 93, 32, 45, 42, 91, 45,
  49, 93, 32, 36, 114, 111, 117, 110, 100, 110, 101, 115, 115, 10, 91, 48,
  93, 44, 91, 48, 93, 44, 49, 44, 49, 44, 50, 32, 45, 114, 109, 91,
  48, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 123, 49, 44, 104,
  125, 32, 45, 115, 112, 108, 105, 110, 101, 91, 45, 49, 93, 32, 64, 123,
  48, 44, 48, 45, 49, 125, 44, 64, 123, 49, 44, 48, 45, 49, 125, 44,
  64, 123, 48, 44, 50, 45, 51, 125, 44, 64, 123, 49, 44, 50, 45, 51,
  125, 44, 49, 50, 56, 44, 49, 44, 49, 32, 45, 115, 104, 105, 102, 116,
  91, 48, 93, 32, 48, 44, 45, 49, 44, 48, 44, 48, 44, 50, 32, 45,
  115, 104, 105, 102, 116, 91, 49, 93, 32, 48, 44, 45, 49, 44, 48, 44,
  48, 44, 50, 32, 45, 100, 111, 110, 101, 10, 45, 102, 108, 111, 111, 100,
  91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49,
  44, 48, 10, 45, 114, 109, 91, 48, 44, 49, 93, 32, 45, 119, 32, 48,
  32, 45, 118, 32, 43, 10, 120, 95, 116, 101, 116, 114, 105, 115, 32, 58,
  10, 45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45, 45, 45,
  32, 84, 101, 116, 114, 105, 115, 32, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45, 45,
  45, 45, 32, 84, 104, 105, 115, 32, 105, 115, 32, 97, 32, 71, 39, 77,
  73, 67, 32, 105, 109, 112, 108, 101, 109, 101, 110, 116, 97, 116, 105, 111,
  110, 32, 111, 102, 32, 116, 104, 101, 32, 84, 101, 116, 114, 105, 115, 32,
  103, 97, 109, 101, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45,
  45, 45, 45, 32, 65, 114, 114, 111, 119, 32, 107, 101, 121, 115, 32, 116,
  111, 32, 109, 111, 118, 101, 47, 114, 111, 116, 97, 116, 101, 32, 116, 104,
  101, 32, 116, 114, 105, 111, 109, 105, 110, 111, 115, 46, 92, 110, 10, 45,
  45, 45, 45, 32, 75, 101, 121, 32, 39, 83, 80, 65, 67, 69, 39, 32,
  116, 111, 32, 109, 97, 107, 101, 32, 116, 104, 101, 32, 99, 117, 114, 114,
  101, 110, 116, 32, 116, 114, 105, 111, 109, 105, 110, 111, 32, 102, 97, 108,
  108, 105, 110, 103, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121,
  115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81, 39, 32, 116,
  111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110,
  10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 109, 10, 45, 105, 91, 109, 48, 93,
  32, 52, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  10, 45, 105, 91, 109, 52, 93, 32, 51, 44, 50, 44, 49, 44, 49, 44,
  49, 44, 48, 44, 48, 44, 49, 44, 49, 44, 49, 10, 45, 105, 91, 109,
  56, 93, 32, 51, 44, 50, 44, 49, 44, 49, 44, 48, 44, 48, 44, 49,
  44, 49, 44, 49, 44, 49, 10, 45, 105, 91, 109, 49, 50, 93, 32, 50,
  44, 50, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 10, 45,
  105, 91, 109, 49, 54, 93, 32, 51, 44, 50, 44, 49, 44, 49, 44, 48,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 48, 10, 45, 105, 91, 109, 50,
  48, 93, 32, 51, 44, 50, 44, 49, 44, 49, 44, 48, 44, 49, 44, 48,
  44, 49, 44, 49, 44, 49, 10, 45, 105, 91, 109, 50, 52, 93, 32, 51,
  44, 50, 44, 49, 44, 49, 44, 49, 44, 49, 44, 48, 44, 48, 44, 49,
  44, 49, 10, 45, 105, 102, 32, 123, 63, 60, 48, 46, 50, 53, 125, 10,
  45, 105, 91, 109, 50, 56, 93, 32, 50, 44, 49, 44, 49, 44, 49, 44,
  49, 44, 49, 10, 45, 105, 91, 109, 51, 50, 93, 32, 50, 44, 50, 44,
  49, 44, 49, 44, 49, 44, 49, 44, 48, 44, 49, 10, 45, 105, 91, 109,
  51, 54, 93, 32, 51, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44,
  49, 10, 45, 105, 91, 109, 52, 48, 93, 32, 49, 44, 49, 44, 49, 44,
  49, 44, 49, 10, 45, 105, 91, 109, 52, 52, 93, 32, 51, 44, 50, 44,
  49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 48, 44, 49, 10,
  45, 105, 91, 109, 52, 56, 93, 32, 51, 44, 51, 44, 49, 44, 49, 44,
  49, 44, 49, 44, 49, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49, 44,
  49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 105, 61, 123, 52, 42, 36, 62, 125, 32, 45, 108, 91,
  109, 36, 105, 93, 32, 45, 114, 101, 112, 101, 97, 116, 32, 51, 32, 45,
  45, 114, 111, 116, 97, 116, 101, 91, 48, 93, 32, 123, 57, 48, 42, 40,
  36, 62, 43, 49, 41, 125, 32, 45, 110, 109, 91, 45, 49, 93, 32, 109,
  123, 36, 105, 43, 36, 62, 43, 49, 125, 32, 45, 100, 111, 110, 101, 32,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 78, 61, 64, 35,
  10, 45, 105, 91, 99, 111, 108, 111, 114, 115, 93, 32, 51, 44, 36, 78,
  44, 49, 44, 49, 44, 39, 63, 40, 49, 54, 44, 50, 50, 52, 41, 39,
  32, 45, 114, 91, 45, 49, 93, 32, 51, 44, 52, 48, 48, 37, 32, 45,
  105, 91, 109, 97, 115, 107, 93, 32, 40, 48, 44, 45, 49, 44, 48, 59,
  49, 44, 48, 44, 45, 49, 59, 48, 44, 49, 44, 48, 41, 32, 45, 42,
  91, 45, 49, 93, 32, 49, 50, 48, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 36, 78, 10, 45, 45, 114, 91, 109, 36, 62, 93, 32, 53, 48, 48,
  37, 44, 53, 48, 48, 37, 44, 49, 44, 51, 32, 45, 45, 99, 111, 114,
  114, 101, 108, 97, 116, 101, 91, 45, 49, 93, 32, 91, 109, 97, 115, 107,
  93, 44, 48, 32, 45, 114, 91, 45, 49, 93, 32, 50, 48, 48, 37, 44,
  50, 48, 48, 37, 44, 49, 44, 49, 44, 51, 32, 45, 114, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 99, 91, 45, 49, 93, 32, 51, 48, 37, 44, 49, 48, 48, 37,
  10, 45, 45, 114, 91, 109, 36, 62, 93, 32, 91, 45, 49, 93, 44, 91,
  45, 49, 93, 44, 49, 44, 51, 32, 45, 45, 114, 101, 112, 108, 97, 99,
  101, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44,
  49, 44, 49, 44, 49, 44, 64, 123, 99, 111, 108, 111, 114, 115, 44, 123,
  51, 42, 36, 62, 125, 45, 123, 51, 42, 36, 62, 43, 50, 125, 125, 32,
  45, 114, 118, 91, 45, 51, 44, 45, 49, 93, 32, 45, 43, 91, 45, 51,
  44, 45, 49, 93, 32, 45, 99, 91, 45, 50, 93, 32, 48, 44, 50, 53,
  53, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32,
  48, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 97, 91,
  45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 110, 109, 91, 45, 49, 93,
  32, 115, 36, 62, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 99,
  111, 108, 111, 114, 115, 44, 109, 97, 115, 107, 93, 10, 102, 97, 99, 116,
  61, 123, 64, 123, 115, 48, 44, 119, 125, 47, 64, 123, 109, 48, 44, 119,
  125, 125, 10, 87, 61, 49, 50, 32, 72, 61, 50, 48, 10, 45, 105, 91,
  98, 111, 97, 114, 100, 93, 32, 36, 87, 44, 36, 72, 32, 45, 105, 91,
  99, 117, 114, 114, 95, 98, 111, 97, 114, 100, 93, 32, 91, 98, 111, 97,
  114, 100, 93, 10, 45, 105, 91, 114, 101, 110, 100, 101, 114, 93, 32, 123,
  36, 102, 97, 99, 116, 42, 36, 87, 125, 44, 123, 36, 102, 97, 99, 116,
  42, 36, 72, 125, 44, 49, 44, 51, 32, 45, 105, 91, 99, 117, 114, 114,
  95, 114, 101, 110, 100, 101, 114, 93, 32, 91, 114, 101, 110, 100, 101, 114,
  93, 32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93,
  32, 48, 32, 45, 110, 109, 91, 45, 49, 93, 32, 99, 117, 114, 114, 95,
  114, 101, 110, 100, 101, 114, 95, 109, 97, 115, 107, 10, 45, 45, 114, 111,
  119, 115, 91, 114, 101, 110, 100, 101, 114, 93, 32, 48, 44, 53, 48, 37,
  32, 45, 112, 108, 97, 115, 109, 97, 91, 45, 49, 93, 32, 49, 44, 50,
  32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 50, 48, 32, 45,
  98, 108, 117, 114, 95, 121, 91, 45, 49, 93, 32, 52, 48, 37, 44, 49,
  32, 45, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 121, 32,
  45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 32, 45, 114, 91, 45,
  49, 93, 32, 91, 114, 101, 110, 100, 101, 114, 93, 10, 45, 110, 91, 45,
  49, 93, 32, 48, 44, 54, 52, 32, 45, 98, 108, 117, 114, 95, 120, 91,
  45, 49, 93, 32, 49, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32,
  45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 48, 46, 53, 44, 50,
  32, 45, 98, 91, 45, 49, 93, 32, 49, 32, 45, 42, 91, 45, 49, 93,
  32, 51, 48, 48, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 110, 109, 91,
  45, 49, 93, 32, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 10, 116,
  105, 109, 101, 61, 64, 124, 32, 115, 99, 111, 114, 101, 61, 48, 32, 102,
  97, 108, 108, 95, 109, 111, 100, 101, 61, 48, 32, 103, 97, 109, 101, 111,
  118, 101, 114, 61, 48, 32, 110, 61, 45, 49, 32, 110, 110, 61, 123, 114,
  111, 117, 110, 100, 40, 63, 40, 48, 44, 36, 78, 45, 49, 41, 41, 125,
  10, 45, 100, 111, 10, 45, 119, 97, 105, 116, 32, 123, 105, 102, 40, 36,
  102, 97, 108, 108, 95, 109, 111, 100, 101, 44, 45, 49, 44, 45, 50, 48,
  41, 125, 10, 45, 105, 102, 32, 36, 103, 97, 109, 101, 111, 118, 101, 114,
  10, 45, 45, 106, 91, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 93,
  32, 91, 99, 117, 114, 114, 95, 114, 101, 110, 100, 101, 114, 93, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 48, 46, 55, 44, 91, 99, 117, 114, 114,
  95, 114, 101, 110, 100, 101, 114, 95, 109, 97, 115, 107, 93, 44, 50, 53,
  53, 10, 45, 116, 101, 120, 116, 95, 111, 117, 116, 108, 105, 110, 101, 91,
  45, 49, 93, 32, 34, 71, 97, 109, 101, 92, 110, 79, 118, 101, 114, 33,
  34, 44, 51, 48, 44, 51, 48, 37, 44, 51, 50, 44, 50, 44, 49, 44,
  50, 53, 53, 32, 45, 119, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 99, 111, 110, 116, 105, 110, 117, 101, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 110, 60, 48, 125, 10, 45,
  108, 91, 98, 111, 97, 114, 100, 93, 32, 45, 115, 32, 121, 32, 105, 61,
  45, 49, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 105,
  102, 32, 64, 123, 36, 60, 44, 109, 125, 32, 105, 61, 36, 60, 44, 36,
  105, 32, 45, 101, 110, 100, 105, 102, 32, 45, 100, 111, 110, 101, 10, 48,
  32, 45, 114, 109, 91, 36, 105, 93, 32, 45, 97, 32, 121, 32, 115, 99,
  111, 114, 101, 61, 123, 36, 115, 99, 111, 114, 101, 43, 50, 94, 40, 110,
  97, 114, 103, 40, 36, 105, 41, 45, 49, 41, 45, 49, 125, 32, 45, 114,
  32, 36, 87, 44, 36, 72, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48,
  44, 49, 32, 45, 110, 109, 32, 98, 111, 97, 114, 100, 32, 45, 101, 110,
  100, 108, 10, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40, 36, 105, 41,
  62, 49, 125, 32, 45, 108, 91, 114, 101, 110, 100, 101, 114, 93, 32, 45,
  115, 32, 121, 44, 36, 72, 32, 48, 32, 45, 114, 109, 91, 36, 105, 93,
  32, 45, 97, 32, 121, 32, 45, 114, 32, 123, 36, 102, 97, 99, 116, 42,
  36, 87, 125, 44, 123, 36, 102, 97, 99, 116, 42, 36, 72, 125, 44, 49,
  44, 51, 44, 48, 44, 48, 44, 48, 44, 49, 32, 45, 110, 109, 32, 114,
  101, 110, 100, 101, 114, 32, 45, 101, 110, 100, 108, 32, 45, 101, 110, 100,
  105, 102, 10, 110, 61, 36, 110, 110, 32, 110, 110, 61, 123, 114, 111, 117,
  110, 100, 40, 63, 40, 48, 44, 36, 78, 45, 49, 41, 41, 125, 32, 120,
  61, 123, 36, 87, 47, 50, 125, 32, 121, 61, 48, 32, 100, 111, 95, 114,
  101, 110, 100, 101, 114, 61, 49, 32, 102, 97, 108, 108, 95, 109, 111, 100,
  101, 61, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36,
  100, 111, 95, 114, 101, 110, 100, 101, 114, 10, 45, 114, 109, 91, 99, 117,
  114, 114, 95, 98, 111, 97, 114, 100, 44, 99, 117, 114, 114, 95, 114, 101,
  110, 100, 101, 114, 44, 99, 117, 114, 114, 95, 114, 101, 110, 100, 101, 114,
  95, 109, 97, 115, 107, 93, 10, 45, 105, 91, 99, 117, 114, 114, 95, 98,
  111, 97, 114, 100, 93, 32, 91, 98, 111, 97, 114, 100, 93, 32, 45, 106,
  91, 99, 117, 114, 114, 95, 98, 111, 97, 114, 100, 93, 32, 91, 109, 36,
  110, 93, 44, 123, 36, 120, 45, 105, 110, 116, 40, 64, 123, 109, 36, 110,
  44, 119, 125, 47, 50, 41, 125, 44, 36, 121, 44, 48, 44, 48, 44, 49,
  44, 91, 109, 36, 110, 93, 10, 45, 105, 91, 99, 117, 114, 114, 95, 114,
  101, 110, 100, 101, 114, 93, 32, 91, 114, 101, 110, 100, 101, 114, 93, 32,
  45, 115, 104, 91, 115, 36, 110, 93, 32, 51, 44, 51, 32, 45, 106, 91,
  99, 117, 114, 114, 95, 114, 101, 110, 100, 101, 114, 93, 32, 91, 115, 36,
  110, 93, 44, 123, 36, 102, 97, 99, 116, 42, 40, 36, 120, 45, 105, 110,
  116, 40, 64, 123, 109, 36, 110, 44, 119, 125, 47, 50, 41, 41, 125, 44,
  123, 36, 102, 97, 99, 116, 42, 36, 121, 125, 44, 48, 44, 48, 44, 49,
  44, 91, 45, 49, 93, 44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 45, 42, 91, 99, 117, 114, 114, 95, 98, 111, 97, 114, 100,
  93, 32, 50, 53, 53, 32, 45, 114, 91, 45, 49, 93, 32, 91, 99, 117,
  114, 114, 95, 114, 101, 110, 100, 101, 114, 93, 44, 91, 99, 117, 114, 114,
  95, 114, 101, 110, 100, 101, 114, 93, 32, 45, 110, 109, 91, 45, 49, 93,
  32, 99, 117, 114, 114, 95, 114, 101, 110, 100, 101, 114, 95, 109, 97, 115,
  107, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 83, 99, 111, 114,
  101, 32, 58, 32, 34, 36, 115, 99, 111, 114, 101, 34, 32, 32, 32, 32,
  78, 101, 120, 116, 32, 58, 34, 44, 52, 44, 48, 44, 51, 50, 44, 49,
  44, 49, 54, 52, 32, 45, 114, 91, 45, 49, 93, 32, 52, 48, 37, 44,
  52, 48, 37, 44, 49, 44, 51, 44, 50, 32, 45, 45, 110, 101, 113, 91,
  45, 49, 93, 32, 48, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53,
  10, 45, 106, 91, 99, 117, 114, 114, 95, 114, 101, 110, 100, 101, 114, 93,
  32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44,
  91, 45, 49, 93, 44, 50, 53, 53, 32, 45, 106, 91, 99, 117, 114, 114,
  95, 114, 101, 110, 100, 101, 114, 95, 109, 97, 115, 107, 93, 32, 91, 45,
  49, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49,
  93, 44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93,
  10, 45, 45, 42, 91, 109, 36, 110, 110, 93, 32, 49, 57, 54, 32, 45,
  114, 91, 45, 49, 93, 32, 51, 48, 48, 37, 44, 51, 48, 48, 37, 44,
  49, 44, 51, 32, 45, 106, 91, 99, 117, 114, 114, 95, 114, 101, 110, 100,
  101, 114, 44, 99, 117, 114, 114, 95, 114, 101, 110, 100, 101, 114, 95, 109,
  97, 115, 107, 93, 32, 91, 45, 49, 93, 44, 123, 64, 123, 99, 117, 114,
  114, 95, 114, 101, 110, 100, 101, 114, 44, 119, 125, 45, 119, 45, 52, 125,
  44, 51, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 44, 49, 57,
  54, 32, 45, 114, 109, 91, 45, 49, 93, 10, 100, 111, 95, 114, 101, 110,
  100, 101, 114, 61, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 45, 115,
  104, 105, 102, 116, 91, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 93,
  32, 48, 44, 123, 45, 49, 51, 42, 64, 124, 42, 49, 46, 48, 52, 94,
  36, 115, 99, 111, 114, 101, 125, 44, 48, 44, 48, 44, 50, 10, 45, 106,
  91, 45, 49, 93, 32, 91, 99, 117, 114, 114, 95, 114, 101, 110, 100, 101,
  114, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 99, 117,
  114, 114, 95, 114, 101, 110, 100, 101, 114, 95, 109, 97, 115, 107, 93, 44,
  50, 53, 53, 10, 45, 119, 91, 45, 49, 93, 32, 123, 50, 42, 119, 125,
  44, 123, 50, 42, 104, 125, 44, 48, 44, 34, 91, 71, 39, 77, 73, 67,
  93, 32, 84, 101, 116, 114, 105, 115, 34, 32, 45, 114, 109, 91, 45, 49,
  93, 32, 45, 99, 117, 114, 115, 111, 114, 91, 48, 93, 32, 48, 10, 45,
  105, 102, 32, 64, 123, 33, 44, 83, 80, 65, 67, 69, 125, 32, 102, 97,
  108, 108, 95, 109, 111, 100, 101, 61, 49, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 65, 82, 82, 79, 87, 85,
  80, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 44, 65, 82, 82, 79,
  87, 76, 69, 70, 84, 125, 34, 32, 124, 124, 32, 34, 64, 123, 33, 44,
  65, 82, 82, 79, 87, 82, 73, 71, 72, 84, 125, 125, 10, 97, 110, 61,
  123, 105, 102, 40, 64, 123, 33, 44, 65, 82, 82, 79, 87, 85, 80, 125,
  44, 110, 61, 36, 110, 43, 49, 59, 105, 102, 40, 110, 37, 52, 44, 110,
  44, 110, 45, 52, 41, 44, 36, 110, 41, 125, 10, 110, 120, 61, 123, 119,
  50, 61, 105, 110, 116, 40, 64, 123, 109, 36, 97, 110, 44, 119, 125, 47,
  50, 41, 59, 109, 97, 120, 40, 119, 50, 44, 109, 105, 110, 40, 36, 120,
  45, 64, 123, 33, 44, 65, 82, 82, 79, 87, 76, 69, 70, 84, 125, 43,
  64, 123, 33, 44, 65, 82, 82, 79, 87, 82, 73, 71, 72, 84, 125, 44,
  36, 87, 45, 40, 64, 123, 109, 36, 97, 110, 44, 119, 125, 37, 50, 41,
  45, 119, 50, 41, 41, 125, 10, 45, 45, 106, 91, 98, 111, 97, 114, 100,
  93, 32, 91, 109, 36, 97, 110, 93, 44, 123, 36, 110, 120, 45, 105, 110,
  116, 40, 64, 123, 109, 36, 97, 110, 44, 119, 125, 47, 50, 41, 125, 44,
  36, 121, 44, 48, 44, 48, 44, 45, 49, 44, 91, 109, 36, 97, 110, 93,
  10, 45, 105, 102, 32, 123, 64, 123, 45, 49, 44, 77, 125, 61, 61, 49,
  125, 32, 120, 61, 36, 110, 120, 32, 110, 61, 36, 97, 110, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 49, 93, 10, 100, 111, 95,
  114, 101, 110, 100, 101, 114, 61, 49, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 64, 123, 33, 44, 65, 82, 82, 79, 87, 68, 79,
  87, 78, 125, 34, 32, 124, 124, 32, 34, 64, 124, 45, 36, 116, 105, 109,
  101, 62, 48, 46, 57, 94, 105, 110, 116, 40, 36, 115, 99, 111, 114, 101,
  47, 50, 41, 34, 32, 124, 124, 32, 34, 36, 102, 97, 108, 108, 95, 109,
  111, 100, 101, 125, 10, 121, 61, 123, 36, 121, 43, 49, 125, 10, 45, 45,
  106, 91, 98, 111, 97, 114, 100, 93, 32, 91, 109, 36, 110, 93, 44, 123,
  36, 120, 45, 105, 110, 116, 40, 64, 123, 109, 36, 110, 44, 119, 125, 47,
  50, 41, 125, 44, 36, 121, 44, 48, 44, 48, 44, 45, 49, 44, 91, 109,
  36, 110, 93, 10, 45, 105, 102, 32, 123, 64, 123, 45, 49, 44, 77, 125,
  62, 49, 34, 32, 124, 124, 32, 34, 36, 121, 43, 64, 123, 109, 36, 110,
  44, 104, 125, 62, 36, 72, 125, 10, 45, 105, 102, 32, 123, 36, 121, 60,
  61, 49, 125, 32, 103, 97, 109, 101, 111, 118, 101, 114, 61, 49, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 106, 91, 98, 111, 97, 114, 100, 93, 32,
  91, 99, 117, 114, 114, 95, 98, 111, 97, 114, 100, 93, 32, 45, 106, 91,
  114, 101, 110, 100, 101, 114, 93, 32, 91, 99, 117, 114, 114, 95, 114, 101,
  110, 100, 101, 114, 93, 32, 110, 61, 45, 49, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 114, 109, 91, 45, 49, 93, 10, 116, 105, 109, 101, 61, 64,
  124, 32, 100, 111, 95, 114, 101, 110, 100, 101, 114, 61, 49, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34,
  32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67, 125, 34, 32,
  38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125, 10, 45, 114, 109,
  32, 45, 119, 32, 48, 32, 45, 118, 32, 43, 10, 120, 95, 116, 105, 99,
  116, 97, 99, 116, 111, 101, 32, 58, 10, 45, 101, 91, 93, 32, 34, 92,
  110, 10, 45, 45, 45, 45, 45, 45, 32, 84, 105, 99, 45, 84, 97, 99,
  45, 84, 111, 101, 32, 103, 97, 109, 101, 32, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45,
  45, 45, 92, 110, 10, 45, 45, 45, 45, 32, 85, 115, 101, 32, 109, 111,
  117, 115, 101, 32, 116, 111, 32, 115, 101, 108, 101, 99, 116, 32, 112, 111,
  115, 105, 116, 105, 111, 110, 115, 32, 111, 102, 32, 116, 104, 101, 92, 110,
  10, 45, 45, 45, 45, 32, 115, 121, 109, 98, 111, 108, 115, 46, 32, 67,
  108, 111, 115, 101, 32, 119, 105, 110, 100, 111, 119, 32, 116, 111, 32, 101,
  120, 105, 116, 32, 103, 97, 109, 101, 46, 92, 110, 10, 45, 45, 45, 45,
  92, 110, 10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 34, 10, 45, 118,
  32, 45, 10, 109, 101, 115, 115, 97, 103, 101, 61, 48, 10, 99, 111, 117,
  110, 116, 101, 114, 61, 48, 10, 112, 108, 97, 121, 101, 114, 61, 48, 10,
  115, 116, 97, 116, 101, 61, 48, 10, 116, 109, 112, 51, 61, 48, 10, 116,
  109, 112, 50, 61, 48, 10, 116, 109, 112, 49, 61, 48, 10, 45, 95, 120,
  95, 116, 105, 99, 116, 97, 99, 116, 111, 101, 50, 10, 45, 119, 91, 45,
  49, 93, 32, 45, 49, 44, 45, 49, 44, 48, 44, 34, 32, 34, 10, 45,
  100, 111, 10, 45, 105, 102, 32, 36, 112, 108, 97, 121, 101, 114, 32, 109,
  101, 115, 115, 97, 103, 101, 61, 34, 84, 105, 99, 45, 84, 97, 99, 45,
  84, 111, 101, 32, 40, 79, 32, 116, 111, 32, 112, 108, 97, 121, 41, 34,
  10, 45, 101, 108, 115, 101, 32, 109, 101, 115, 115, 97, 103, 101, 61, 34,
  84, 105, 99, 45, 84, 97, 99, 45, 84, 111, 101, 32, 40, 88, 32, 116,
  111, 32, 112, 108, 97, 121, 41, 34, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 100, 111, 10, 45, 119, 91, 93, 32, 123, 119, 125, 44, 123, 104, 125,
  44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 34, 36, 109, 101,
  115, 115, 97, 103, 101, 32, 45, 119, 97, 105, 116, 10, 45, 105, 102, 32,
  123, 33, 64, 33, 125, 32, 45, 119, 91, 93, 32, 48, 32, 45, 114, 109,
  32, 45, 118, 32, 43, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 98, 125,
  38, 49, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 120, 125, 62, 50,
  48, 34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 121, 125, 62, 50, 48,
  34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 120, 125, 60, 52, 48, 48,
  34, 32, 38, 38, 32, 34, 64, 123, 33, 44, 121, 125, 60, 52, 48, 48,
  125, 10, 116, 109, 112, 51, 61, 123, 105, 110, 116, 40, 40, 64, 123, 33,
  44, 120, 125, 45, 49, 53, 41, 47, 49, 51, 48, 41, 125, 10, 116, 109,
  112, 50, 61, 123, 105, 110, 116, 40, 40, 64, 123, 33, 44, 121, 125, 45,
  49, 53, 41, 47, 49, 51, 48, 41, 125, 10, 116, 109, 112, 49, 61, 123,
  52, 94, 40, 36, 116, 109, 112, 50, 42, 51, 43, 36, 116, 109, 112, 51,
  41, 125, 10, 45, 105, 102, 32, 123, 105, 110, 116, 40, 36, 115, 116, 97,
  116, 101, 47, 36, 116, 109, 112, 49, 41, 37, 52, 125, 32, 116, 109, 112,
  49, 61, 45, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115,
  101, 32, 116, 109, 112, 49, 61, 45, 49, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 119, 104, 105, 108, 101, 32, 123, 36, 116, 109, 112, 49, 60, 48,
  125, 10, 45, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116, 111, 101, 123,
  36, 112, 108, 97, 121, 101, 114, 37, 50, 125, 10, 45, 106, 91, 45, 51,
  93, 32, 91, 45, 50, 93, 44, 123, 34, 49, 51, 48, 42, 34, 36, 116,
  109, 112, 51, 34, 32, 43, 32, 49, 53, 43, 63, 40, 45, 53, 44, 53,
  41, 34, 125, 44, 92, 10, 123, 34, 49, 51, 48, 42, 34, 36, 116, 109,
  112, 50, 34, 32, 43, 32, 49, 53, 43, 63, 40, 45, 53, 44, 53, 41,
  34, 125, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 10, 45, 114,
  109, 91, 45, 50, 45, 45, 49, 93, 10, 45, 119, 91, 45, 49, 93, 10,
  115, 116, 97, 116, 101, 61, 123, 36, 115, 116, 97, 116, 101, 43, 40, 49,
  43, 36, 112, 108, 97, 121, 101, 114, 41, 42, 36, 116, 109, 112, 49, 125,
  10, 40, 50, 49, 44, 49, 51, 52, 52, 44, 56, 54, 48, 49, 54, 44,
  52, 49, 54, 49, 44, 49, 54, 54, 52, 52, 44, 54, 54, 53, 55, 54,
  44, 54, 53, 55, 57, 51, 44, 52, 51, 54, 56, 59, 92, 10, 48, 44,
  48, 44, 48, 44, 48, 44, 49, 44, 50, 44, 48, 44, 48, 59, 92, 10,
  48, 44, 49, 44, 50, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 59,
  92, 10, 51, 44, 51, 44, 51, 44, 52, 44, 52, 44, 52, 44, 53, 44,
  54, 41, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 119, 125, 10, 116,
  109, 112, 49, 61, 64, 123, 45, 49, 44, 36, 62, 125, 10, 45, 105, 102,
  32, 123, 40, 36, 115, 116, 97, 116, 101, 38, 36, 116, 109, 112, 49, 41,
  61, 61, 36, 116, 109, 112, 49, 124, 124, 40, 36, 115, 116, 97, 116, 101,
  38, 40, 50, 42, 36, 116, 109, 112, 49, 41, 41, 61, 61, 50, 42, 36,
  116, 109, 112, 49, 125, 10, 45, 95, 120, 95, 116, 105, 99, 116, 97, 99,
  116, 111, 101, 64, 123, 45, 49, 44, 40, 36, 62, 44, 51, 41, 125, 10,
  45, 106, 91, 45, 52, 93, 32, 91, 45, 50, 93, 44, 123, 49, 51, 48,
  42, 64, 123, 45, 51, 44, 40, 36, 62, 44, 49, 41, 125, 43, 63, 40,
  45, 53, 44, 53, 41, 125, 44, 92, 10, 123, 49, 51, 48, 42, 64, 123,
  45, 51, 44, 40, 36, 62, 44, 50, 41, 125, 43, 63, 40, 45, 53, 44,
  53, 41, 125, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 32, 45,
  114, 109, 91, 45, 50, 45, 45, 49, 93, 10, 45, 105, 102, 32, 123, 40,
  36, 115, 116, 97, 116, 101, 38, 36, 116, 109, 112, 49, 41, 61, 61, 36,
  116, 109, 112, 49, 125, 32, 45, 119, 91, 45, 50, 93, 32, 45, 49, 44,
  45, 49, 44, 48, 44, 34, 84, 105, 99, 45, 84, 97, 99, 45, 84, 111,
  101, 32, 40, 88, 32, 119, 111, 110, 33, 41, 34, 10, 45, 101, 108, 115,
  101, 32, 45, 119, 91, 45, 50, 93, 32, 45, 49, 44, 45, 49, 44, 48,
  44, 34, 84, 105, 99, 45, 84, 97, 99, 45, 84, 111, 101, 32, 40, 79,
  32, 119, 111, 110, 33, 41, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  100, 111, 32, 45, 119, 97, 105, 116, 32, 45, 119, 91, 93, 32, 64, 123,
  33, 44, 119, 125, 44, 64, 123, 33, 44, 104, 125, 32, 45, 119, 104, 105,
  108, 101, 32, 64, 33, 10, 45, 114, 109, 32, 45, 119, 91, 93, 32, 48,
  32, 45, 118, 32, 43, 32, 45, 114, 101, 116, 117, 114, 110, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 45,
  49, 93, 10, 112, 108, 97, 121, 101, 114, 61, 123, 40, 36, 112, 108, 97,
  121, 101, 114, 43, 49, 41, 37, 50, 125, 10, 99, 111, 117, 110, 116, 101,
  114, 61, 123, 36, 99, 111, 117, 110, 116, 101, 114, 43, 49, 125, 10, 45,
  119, 104, 105, 108, 101, 32, 123, 36, 99, 111, 117, 110, 116, 101, 114, 60,
  57, 125, 10, 45, 119, 91, 93, 32, 45, 49, 44, 45, 49, 44, 48, 44,
  48, 44, 34, 84, 105, 99, 45, 84, 97, 99, 45, 84, 111, 101, 32, 40,
  84, 105, 101, 100, 32, 103, 97, 109, 101, 33, 41, 34, 10, 45, 100, 111,
  32, 45, 119, 97, 105, 116, 32, 45, 119, 91, 93, 32, 64, 123, 33, 44,
  119, 125, 44, 64, 123, 33, 44, 104, 125, 32, 45, 119, 104, 105, 108, 101,
  32, 64, 33, 10, 45, 119, 91, 93, 32, 48, 32, 45, 114, 109, 32, 45,
  118, 32, 43, 10, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116, 111, 101,
  32, 58, 10, 45, 115, 112, 114, 101, 97, 100, 91, 45, 49, 93, 32, 52,
  32, 45, 98, 91, 45, 49, 93, 32, 54, 32, 45, 115, 104, 97, 114, 112,
  101, 110, 91, 45, 49, 93, 32, 48, 46, 56, 32, 45, 110, 91, 45, 49,
  93, 32, 48, 44, 49, 10, 95, 95, 120, 95, 116, 105, 99, 116, 97, 99,
  116, 111, 101, 32, 58, 10, 45, 45, 102, 91, 45, 49, 93, 32, 49, 45,
  105, 32, 45, 45, 110, 91, 45, 50, 93, 32, 36, 50, 44, 50, 53, 53,
  32, 45, 45, 110, 91, 45, 51, 93, 32, 36, 51, 44, 50, 53, 53, 32,
  45, 110, 91, 45, 52, 93, 32, 36, 49, 44, 50, 53, 53, 32, 45, 97,
  91, 45, 52, 44, 45, 50, 44, 45, 49, 93, 32, 99, 10, 95, 120, 95,
  116, 105, 99, 116, 97, 99, 116, 111, 101, 48, 32, 58, 10, 49, 50, 56,
  44, 49, 50, 56, 44, 49, 44, 49, 44, 49, 32, 45, 108, 105, 110, 101,
  91, 45, 49, 93, 32, 49, 53, 37, 44, 49, 53, 37, 44, 56, 53, 37,
  44, 56, 53, 37, 44, 49, 44, 48, 32, 45, 108, 105, 110, 101, 91, 45,
  49, 93, 32, 49, 53, 37, 44, 56, 53, 37, 44, 56, 53, 37, 44, 49,
  53, 37, 44, 49, 44, 48, 32, 45, 101, 114, 111, 100, 101, 91, 45, 49,
  93, 32, 49, 50, 32, 45, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116,
  111, 101, 32, 45, 100, 101, 102, 111, 114, 109, 91, 45, 49, 93, 32, 52,
  32, 45, 95, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116, 111, 101, 32,
  52, 48, 44, 52, 48, 44, 49, 54, 48, 10, 95, 120, 95, 116, 105, 99,
  116, 97, 99, 116, 111, 101, 49, 32, 58, 10, 49, 50, 56, 44, 49, 50,
  56, 44, 49, 44, 49, 44, 49, 32, 45, 101, 108, 108, 105, 112, 115, 101,
  91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 50, 50, 37,
  44, 50, 50, 37, 44, 48, 44, 49, 44, 48, 32, 45, 101, 108, 108, 105,
  112, 115, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44,
  49, 53, 37, 44, 49, 53, 37, 44, 48, 44, 49, 44, 49, 32, 45, 95,
  120, 95, 116, 105, 99, 116, 97, 99, 116, 111, 101, 32, 45, 100, 101, 102,
  111, 114, 109, 91, 45, 49, 93, 32, 52, 32, 45, 95, 95, 120, 95, 116,
  105, 99, 116, 97, 99, 116, 111, 101, 32, 49, 54, 48, 44, 52, 48, 44,
  49, 54, 48, 10, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116, 111, 101,
  50, 32, 58, 10, 51, 57, 49, 44, 51, 57, 49, 44, 49, 44, 49, 44,
  34, 33, 40, 120, 37, 49, 51, 48, 41, 32, 124, 124, 32, 33, 40, 121,
  37, 49, 51, 48, 41, 34, 32, 45, 114, 91, 45, 49, 93, 32, 52, 50,
  49, 44, 52, 50, 49, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49,
  93, 32, 51, 32, 45, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116, 111,
  101, 32, 45, 102, 91, 45, 49, 93, 32, 49, 45, 105, 10, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49,
  93, 32, 49, 48, 32, 45, 98, 91, 45, 49, 93, 32, 56, 44, 48, 32,
  45, 115, 104, 97, 114, 112, 101, 110, 91, 45, 49, 93, 32, 49, 46, 53,
  32, 45, 110, 91, 45, 49, 93, 32, 50, 50, 48, 44, 50, 53, 53, 32,
  45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 116, 111, 95, 114, 103,
  98, 91, 45, 49, 93, 10, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116,
  111, 101, 51, 32, 58, 10, 52, 50, 49, 44, 49, 51, 48, 44, 49, 44,
  49, 44, 49, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 49, 48,
  37, 44, 54, 48, 37, 44, 57, 48, 37, 44, 54, 48, 37, 44, 49, 44,
  48, 32, 45, 101, 114, 111, 100, 101, 91, 45, 49, 93, 32, 54, 32, 45,
  95, 120, 95, 116, 105, 99, 116, 97, 99, 116, 111, 101, 32, 45, 114, 111,
  116, 97, 116, 101, 91, 45, 49, 93, 32, 123, 63, 40, 45, 54, 44, 54,
  41, 125, 44, 49, 44, 49, 44, 53, 48, 37, 44, 53, 48, 37, 32, 45,
  95, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116, 111, 101, 32, 49, 56,
  48, 44, 49, 48, 44, 49, 48, 10, 95, 120, 95, 116, 105, 99, 116, 97,
  99, 116, 111, 101, 52, 32, 58, 10, 45, 95, 120, 95, 116, 105, 99, 116,
  97, 99, 116, 111, 101, 51, 32, 45, 116, 114, 97, 110, 115, 112, 111, 115,
  101, 91, 45, 50, 45, 45, 49, 93, 10, 95, 120, 95, 116, 105, 99, 116,
  97, 99, 116, 111, 101, 53, 32, 58, 10, 52, 50, 49, 44, 52, 50, 49,
  44, 49, 44, 49, 44, 49, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93,
  32, 49, 48, 37, 44, 49, 48, 37, 44, 57, 48, 37, 44, 57, 48, 37,
  44, 49, 44, 48, 32, 45, 101, 114, 111, 100, 101, 91, 45, 49, 93, 32,
  54, 32, 45, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116, 111, 101, 32,
  45, 95, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116, 111, 101, 32, 49,
  56, 48, 44, 49, 48, 44, 49, 48, 10, 95, 120, 95, 116, 105, 99, 116,
  97, 99, 116, 111, 101, 54, 32, 58, 10, 52, 50, 49, 44, 52, 50, 49,
  44, 49, 44, 49, 44, 49, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93,
  32, 49, 48, 37, 44, 57, 48, 37, 44, 57, 48, 37, 44, 49, 48, 37,
  44, 49, 44, 48, 32, 45, 101, 114, 111, 100, 101, 91, 45, 49, 93, 32,
  54, 32, 45, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116, 111, 101, 32,
  45, 95, 95, 120, 95, 116, 105, 99, 116, 97, 99, 116, 111, 101, 32, 49,
  56, 48, 44, 49, 48, 44, 49, 48, 10, 120, 95, 119, 97, 118, 101, 115,
  32, 58, 10, 45, 101, 91, 93, 32, 34, 92, 110, 10, 45, 45, 45, 45,
  45, 45, 32, 73, 109, 97, 103, 101, 32, 119, 97, 118, 101, 115, 32, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10, 45,
  45, 45, 45, 32, 76, 101, 102, 116, 32, 109, 111, 117, 115, 101, 32, 98,
  117, 116, 116, 111, 110, 32, 116, 111, 32, 100, 114, 111, 112, 32, 98, 97,
  108, 108, 115, 46, 92, 110, 10, 45, 45, 45, 45, 32, 82, 105, 103, 104,
  116, 32, 109, 111, 117, 115, 101, 32, 98, 117, 116, 116, 111, 110, 32, 116,
  111, 32, 114, 111, 116, 97, 116, 101, 32, 118, 105, 101, 119, 46, 92, 110,
  10, 45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76,
  43, 68, 39, 32, 116, 111, 32, 100, 111, 117, 98, 108, 101, 32, 119, 105,
  110, 100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45,
  45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76, 43, 67, 39, 32,
  116, 111, 32, 114, 101, 115, 101, 116, 32, 119, 105, 110, 100, 111, 119, 32,
  115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121,
  115, 32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81, 39, 32, 116,
  111, 32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110,
  10, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 34, 10, 45, 118, 32, 45,
  10, 45, 105, 102, 32, 123, 33, 64, 35, 125, 32, 45, 108, 91, 93, 10,
  50, 48, 48, 44, 50, 48, 48, 32, 120, 61, 123, 45, 49, 46, 48, 54,
  45, 63, 42, 48, 46, 49, 125, 32, 121, 61, 123, 45, 48, 46, 50, 54,
  45, 63, 42, 48, 46, 49, 125, 10, 45, 109, 97, 110, 100, 101, 108, 98,
  114, 111, 116, 32, 36, 120, 44, 36, 121, 44, 123, 36, 120, 43, 48, 46,
  49, 125, 44, 123, 36, 121, 43, 48, 46, 49, 125, 44, 50, 53, 54, 10,
  49, 54, 44, 49, 44, 49, 44, 51, 44, 63, 32, 45, 114, 91, 45, 49,
  93, 32, 50, 53, 54, 44, 49, 44, 49, 44, 51, 44, 51, 32, 45, 115,
  104, 105, 102, 116, 91, 45, 49, 93, 32, 49, 10, 45, 109, 97, 112, 91,
  48, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 114, 50, 100, 120, 32, 49, 48, 48, 10, 45, 45, 109, 105, 114, 114,
  111, 114, 32, 121, 32, 45, 45, 109, 105, 114, 114, 111, 114, 32, 120, 32,
  45, 43, 32, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100,
  108, 32, 45, 101, 108, 115, 101, 32, 45, 107, 91, 48, 93, 32, 45, 114,
  91, 48, 93, 32, 49, 48, 48, 44, 49, 48, 48, 44, 49, 44, 51, 44,
  50, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 91, 48, 93, 32, 40,
  50, 48, 59, 56, 48, 59, 48, 94, 50, 48, 59, 56, 48, 59, 48, 94,
  50, 48, 59, 56, 48, 59, 48, 41, 32, 45, 114, 91, 48, 93, 32, 52,
  48, 48, 44, 51, 48, 48, 44, 49, 44, 51, 44, 51, 32, 45, 119, 97,
  116, 101, 114, 91, 48, 93, 32, 49, 48, 48, 44, 50, 10, 45, 119, 91,
  48, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125,
  44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 73, 109, 97, 103,
  101, 32, 119, 97, 118, 101, 115, 34, 10, 119, 61, 123, 119, 125, 32, 45,
  101, 108, 101, 118, 97, 116, 105, 111, 110, 51, 100, 91, 45, 49, 93, 32,
  48, 32, 45, 114, 118, 51, 100, 91, 45, 49, 93, 10, 45, 115, 104, 91,
  45, 49, 93, 32, 56, 44, 123, 55, 43, 51, 42, 105, 91, 54, 93, 125,
  44, 48, 44, 48, 32, 45, 114, 91, 45, 49, 93, 32, 51, 44, 123, 104,
  47, 51, 125, 44, 49, 44, 49, 44, 45, 49, 10, 40, 48, 44, 49, 44,
  48, 59, 49, 44, 48, 44, 49, 59, 48, 44, 49, 44, 48, 41, 32, 45,
  47, 91, 45, 49, 93, 32, 50, 10, 45, 98, 97, 108, 108, 91, 93, 32,
  50, 48, 44, 50, 48, 48, 44, 50, 53, 53, 44, 49, 50, 56, 44, 49,
  44, 48, 46, 55, 44, 51, 46, 53, 10, 48, 32, 36, 119, 44, 36, 119,
  32, 91, 45, 49, 93, 10, 45, 108, 51, 100, 32, 123, 36, 119, 47, 50,
  125, 44, 45, 50, 48, 48, 44, 45, 49, 48, 48, 48, 32, 45, 115, 108,
  51, 100, 32, 48, 46, 52, 32, 45, 115, 115, 51, 100, 32, 48, 46, 56,
  32, 45, 102, 51, 100, 32, 53, 48, 48, 32, 116, 105, 109, 101, 48, 61,
  64, 124, 10, 45, 100, 111, 10, 45, 45, 99, 111, 110, 118, 111, 108, 118,
  101, 91, 45, 49, 93, 32, 91, 51, 93, 44, 49, 32, 45, 45, 91, 45,
  49, 93, 32, 91, 45, 51, 93, 32, 45, 114, 109, 91, 45, 51, 93, 32,
  45, 98, 91, 45, 49, 93, 32, 48, 46, 56, 32, 45, 45, 91, 45, 49,
  93, 32, 123, 105, 97, 125, 10, 45, 114, 91, 45, 49, 93, 32, 49, 44,
  123, 36, 119, 42, 36, 119, 125, 44, 49, 44, 49, 44, 45, 49, 32, 45,
  106, 91, 50, 93, 32, 91, 45, 49, 93, 44, 50, 44, 48, 32, 45, 114,
  91, 45, 49, 93, 32, 36, 119, 44, 36, 119, 44, 49, 44, 49, 44, 45,
  49, 10, 91, 49, 93, 10, 45, 105, 102, 32, 64, 123, 53, 44, 104, 125,
  32, 45, 45, 108, 91, 53, 93, 32, 45, 114, 111, 119, 115, 32, 48, 44,
  50, 10, 110, 98, 61, 123, 119, 125, 10, 45, 105, 91, 48, 93, 32, 40,
  123, 39, 67, 73, 109, 103, 51, 100, 39, 125, 41, 32, 45, 105, 91, 49,
  93, 32, 40, 36, 110, 98, 44, 36, 110, 98, 41, 32, 45, 116, 114, 97,
  110, 115, 112, 111, 115, 101, 91, 50, 93, 10, 40, 49, 44, 48, 59, 49,
  44, 123, 36, 110, 98, 45, 49, 125, 41, 32, 45, 114, 91, 45, 49, 93,
  32, 50, 44, 36, 110, 98, 44, 49, 44, 49, 44, 51, 32, 45, 114, 111,
  117, 110, 100, 91, 45, 49, 93, 10, 49, 44, 123, 52, 42, 36, 110, 98,
  125, 44, 49, 44, 49, 44, 49, 32, 45, 121, 32, 45, 97, 32, 121, 10,
  45, 101, 110, 100, 108, 32, 91, 52, 93, 32, 45, 115, 112, 114, 105, 116,
  101, 115, 51, 100, 91, 45, 50, 44, 45, 49, 93, 32, 45, 43, 51, 100,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  45, 51, 100, 91, 45, 49, 93, 32, 123, 36, 119, 47, 50, 125, 44, 123,
  36, 119, 47, 50, 125, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 64,
  123, 48, 44, 48, 46, 57, 42, 109, 97, 120, 40, 119, 44, 104, 41, 47,
  36, 119, 125, 10, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 48,
  44, 49, 44, 123, 105, 102, 40, 64, 123, 33, 44, 98, 125, 38, 50, 44,
  45, 64, 123, 33, 44, 120, 125, 42, 51, 54, 48, 47, 64, 123, 33, 44,
  119, 125, 44, 64, 124, 42, 51, 48, 41, 125, 32, 45, 114, 51, 100, 91,
  45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 45, 49, 50, 48, 10, 45,
  45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 48, 93, 32, 91, 45, 49,
  93, 44, 53, 48, 37, 44, 54, 53, 37, 44, 51, 48, 44, 49, 44, 51,
  44, 48, 44, 48, 32, 45, 119, 91, 45, 49, 93, 10, 45, 105, 102, 32,
  123, 64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38,
  64, 123, 33, 44, 68, 125, 125, 32, 45, 119, 91, 93, 32, 123, 50, 42,
  119, 125, 44, 123, 50, 42, 104, 125, 32, 45, 101, 108, 105, 102, 32, 123,
  64, 123, 33, 44, 67, 84, 82, 76, 76, 69, 70, 84, 125, 38, 38, 64,
  123, 33, 44, 67, 125, 125, 32, 45, 119, 91, 93, 32, 123, 119, 125, 44,
  123, 104, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 119, 97, 105, 116, 32, 50, 48, 10, 45,
  105, 102, 32, 123, 64, 123, 33, 44, 98, 125, 38, 49, 124, 124, 40, 64,
  124, 45, 36, 116, 105, 109, 101, 48, 41, 62, 49, 125, 32, 40, 123, 63,
  42, 36, 119, 125, 59, 123, 63, 42, 36, 119, 125, 59, 55, 48, 59, 48,
  41, 32, 45, 97, 91, 53, 44, 45, 49, 93, 32, 120, 32, 116, 105, 109,
  101, 48, 61, 123, 64, 124, 45, 63, 125, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 64, 123, 53, 44, 104, 125, 32, 45, 108, 91, 53,
  44, 45, 49, 93, 10, 45, 115, 104, 91, 48, 93, 32, 50, 44, 50, 44,
  48, 44, 48, 32, 45, 115, 104, 91, 48, 93, 32, 51, 44, 51, 44, 48,
  44, 48, 32, 45, 45, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45,
  43, 91, 45, 49, 93, 32, 48, 46, 50, 32, 45, 114, 109, 91, 45, 50,
  44, 45, 49, 93, 10, 45, 115, 91, 48, 93, 32, 120, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 99, 111, 111, 114,
  100, 115, 61, 64, 123, 36, 60, 44, 48, 45, 49, 125, 32, 45, 105, 102,
  32, 123, 64, 123, 36, 60, 44, 50, 125, 60, 105, 40, 36, 99, 111, 111,
  114, 100, 115, 41, 125, 32, 45, 61, 91, 45, 49, 93, 32, 123, 56, 48,
  43, 64, 123, 45, 49, 44, 40, 36, 99, 111, 111, 114, 100, 115, 41, 125,
  125, 44, 36, 99, 111, 111, 114, 100, 115, 32, 45, 114, 109, 91, 36, 60,
  93, 32, 45, 101, 110, 100, 105, 102, 32, 45, 100, 111, 110, 101, 10, 45,
  105, 102, 32, 123, 64, 35, 61, 61, 49, 125, 32, 45, 105, 91, 48, 93,
  32, 48, 32, 45, 101, 108, 115, 101, 32, 45, 97, 91, 48, 45, 45, 50,
  93, 32, 120, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123,
  64, 33, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67,
  125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125, 10,
  45, 114, 109, 32, 45, 119, 32, 48, 32, 45, 118, 32, 43, 10, 120, 95,
  119, 104, 105, 114, 108, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 36,
  123, 49, 61, 48, 46, 50, 125, 62, 61, 48, 10, 45, 101, 91, 93, 32,
  34, 92, 110, 10, 45, 45, 45, 45, 45, 45, 32, 70, 114, 97, 99, 116,
  97, 108, 32, 119, 104, 105, 114, 108, 115, 32, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10,
  45, 45, 45, 45, 32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76, 43,
  68, 39, 32, 116, 111, 32, 100, 111, 117, 98, 108, 101, 32, 119, 105, 110,
  100, 111, 119, 32, 115, 105, 122, 101, 46, 92, 110, 10, 45, 45, 45, 45,
  32, 75, 101, 121, 115, 32, 39, 67, 84, 82, 76, 43, 67, 39, 32, 116,
  111, 32, 114, 101, 115, 101, 116, 32, 119, 105, 110, 100, 111, 119, 32, 115,
  105, 122, 101, 46, 92, 110, 10, 45, 45, 45, 45, 32, 75, 101, 121, 115,
  32, 39, 69, 83, 67, 39, 32, 111, 114, 32, 39, 81, 39, 32, 116, 111,
  32, 101, 120, 105, 116, 46, 92, 110, 10, 45, 45, 45, 45, 92, 110, 10,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 34, 10, 45, 118, 32, 45, 10, 53, 44, 53, 44, 49, 44, 51,
  32, 50, 53, 54, 44, 50, 53, 54, 44, 49, 44, 51, 32, 91, 45, 49,
  93, 32, 45, 119, 91, 45, 49, 93, 32, 51, 56, 52, 44, 51, 56, 52,
  44, 48, 44, 34, 91, 71, 39, 77, 73, 67, 93, 32, 70, 114, 97, 99,
  116, 97, 108, 32, 119, 104, 105, 114, 108, 115, 34, 10, 116, 97, 110, 103,
  108, 101, 61, 48, 32, 116, 122, 111, 111, 109, 61, 48, 32, 120, 99, 61,
  123, 40, 119, 45, 64, 123, 45, 51, 44, 119, 125, 41, 47, 50, 125, 32,
  121, 99, 61, 123, 40, 104, 45, 64, 123, 45, 51, 44, 104, 125, 41, 47,
  50, 125, 10, 45, 100, 111, 10, 45, 114, 97, 110, 100, 91, 45, 51, 93,
  32, 48, 44, 50, 53, 53, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45,
  51, 93, 44, 36, 120, 99, 44, 36, 121, 99, 44, 48, 44, 48, 10, 45,
  114, 111, 116, 97, 116, 101, 91, 45, 50, 93, 32, 123, 56, 42, 115, 105,
  110, 40, 36, 116, 97, 110, 103, 108, 101, 41, 125, 44, 48, 44, 48, 44,
  123, 119, 47, 50, 43, 63, 40, 45, 50, 44, 50, 41, 125, 44, 123, 104,
  47, 50, 125, 44, 123, 49, 46, 48, 51, 43, 48, 46, 48, 50, 42, 115,
  105, 110, 40, 36, 116, 122, 111, 111, 109, 41, 125, 10, 116, 97, 110, 103,
  108, 101, 61, 123, 36, 116, 97, 110, 103, 108, 101, 43, 48, 46, 48, 48,
  49, 125, 32, 116, 122, 111, 111, 109, 61, 123, 36, 116, 122, 111, 111, 109,
  43, 48, 46, 48, 50, 125, 10, 45, 106, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 36, 49, 32, 45, 119,
  91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84,
  82, 76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 68, 125, 125,
  32, 45, 119, 91, 93, 32, 123, 51, 42, 119, 125, 44, 123, 51, 42, 104,
  125, 32, 45, 101, 108, 105, 102, 32, 123, 64, 123, 33, 44, 67, 84, 82,
  76, 76, 69, 70, 84, 125, 38, 38, 64, 123, 33, 44, 67, 125, 125, 32,
  45, 119, 91, 93, 32, 123, 49, 46, 53, 42, 119, 125, 44, 123, 49, 46,
  53, 42, 104, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 119, 97, 105,
  116, 32, 50, 48, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 33, 34,
  32, 38, 38, 32, 34, 33, 64, 123, 33, 44, 69, 83, 67, 125, 34, 32,
  38, 38, 32, 34, 33, 64, 123, 33, 44, 81, 125, 125, 10, 45, 114, 109,
  91, 45, 51, 44, 45, 50, 93, 32, 45, 119, 91, 93, 32, 48, 32, 45,
  118, 32, 43, 10, 95, 119, 114, 98, 121, 116, 101, 112, 110, 107, 32, 58,
  10, 45, 111, 117, 116, 112, 117, 116, 95, 112, 105, 110, 107, 51, 100, 32,
  36, 123, 49, 125, 46, 112, 110, 107, 10, 95, 120, 112, 105, 110, 107, 32,
  58, 10, 102, 105, 108, 101, 110, 97, 109, 101, 61, 64, 123, 45, 102, 105,
  108, 101, 95, 114, 97, 110, 100, 125, 10, 112, 114, 101, 102, 105, 120, 61,
  112, 105, 110, 107, 46, 10, 45, 105, 102, 32, 123, 33, 64, 123, 45, 105,
  115, 95, 119, 105, 110, 100, 111, 119, 115, 125, 125, 10, 45, 120, 32, 34,
  119, 104, 105, 99, 104, 32, 34, 36, 123, 112, 114, 101, 102, 105, 120, 125,
  36, 123, 49, 125, 34, 32, 62, 47, 100, 101, 118, 47, 110, 117, 108, 108,
  32, 50, 62, 38, 49, 34, 10, 45, 105, 102, 32, 123, 64, 123, 125, 33,
  61, 48, 125, 32, 112, 114, 101, 102, 105, 120, 61, 34, 34, 32, 45, 120,
  32, 34, 119, 104, 105, 99, 104, 32, 34, 36, 49, 34, 32, 62, 47, 100,
  101, 118, 47, 110, 117, 108, 108, 32, 50, 62, 38, 49, 34, 10, 45, 105,
  102, 32, 123, 64, 123, 125, 33, 61, 48, 125, 32, 45, 101, 114, 114, 111,
  114, 32, 34, 101, 120, 101, 99, 117, 116, 97, 98, 108, 101, 32, 40, 112,
  105, 110, 107, 46, 41, 34, 36, 49, 34, 32, 110, 111, 116, 32, 102, 111,
  117, 110, 100, 32, 105, 110, 32, 80, 65, 84, 72, 44, 32, 115, 116, 97,
  116, 117, 115, 32, 61, 32, 34, 64, 123, 125, 34, 33, 33, 32, 82, 101,
  116, 117, 114, 110, 105, 110, 103, 33, 33, 92, 110, 34, 32, 45, 114, 101,
  116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 111, 117, 116, 112, 117, 116, 95, 112, 105, 110, 107, 51,
  100, 32, 36, 123, 102, 105, 108, 101, 110, 97, 109, 101, 125, 46, 112, 110,
  107, 32, 45, 120, 32, 36, 123, 112, 114, 101, 102, 105, 120, 125, 36, 123,
  49, 125, 34, 32, 34, 36, 123, 102, 105, 108, 101, 110, 97, 109, 101, 125,
  34, 46, 112, 110, 107, 32, 36, 50, 32, 34, 36, 123, 102, 105, 108, 101,
  110, 97, 109, 101, 125, 34, 95, 111, 46, 112, 110, 107, 32, 62, 47, 100,
  101, 118, 47, 110, 117, 108, 108, 32, 50, 62, 38, 49, 34, 10, 45, 101,
  108, 115, 101, 10, 45, 111, 117, 116, 112, 117, 116, 95, 112, 105, 110, 107,
  51, 100, 32, 36, 123, 102, 105, 108, 101, 110, 97, 109, 101, 125, 46, 112,
  110, 107, 32, 45, 120, 32, 36, 49, 34, 32, 34, 36, 123, 102, 105, 108,
  101, 110, 97, 109, 101, 125, 34, 46, 112, 110, 107, 32, 36, 50, 32, 34,
  36, 123, 102, 105, 108, 101, 110, 97, 109, 101, 125, 34, 95, 111, 46, 112,
  110, 107, 34, 10, 45, 101, 110, 100, 105, 102, 10, 115, 116, 97, 116, 117,
  115, 61, 64, 123, 125, 10, 45, 102, 105, 108, 101, 95, 114, 109, 32, 36,
  123, 102, 105, 108, 101, 110, 97, 109, 101, 125, 46, 112, 110, 107, 10, 45,
  105, 102, 32, 123, 36, 115, 116, 97, 116, 117, 115, 33, 61, 48, 92, 32,
  38, 38, 92, 32, 123, 36, 49, 39, 33, 61, 39, 115, 101, 117, 105, 108,
  97, 117, 116, 111, 125, 32, 45, 101, 114, 114, 111, 114, 32, 34, 101, 120,
  101, 99, 32, 83, 116, 97, 116, 117, 115, 32, 105, 115, 32, 34, 36, 123,
  115, 116, 97, 116, 117, 115, 125, 34, 46, 34, 32, 45, 114, 101, 116, 117,
  114, 110, 10, 45, 101, 108, 105, 102, 32, 36, 123, 102, 105, 108, 101, 110,
  97, 109, 101, 125, 95, 111, 46, 112, 110, 107, 32, 45, 105, 32, 36, 123,
  102, 105, 108, 101, 110, 97, 109, 101, 125, 95, 111, 46, 112, 110, 107, 32,
  45, 102, 105, 108, 101, 95, 114, 109, 32, 36, 123, 102, 105, 108, 101, 110,
  97, 109, 101, 125, 95, 111, 46, 112, 110, 107, 32, 45, 107, 91, 45, 49,
  93, 10, 45, 101, 108, 115, 101, 32, 45, 101, 114, 114, 111, 114, 32, 34,
  101, 120, 101, 99, 32, 69, 114, 114, 111, 114, 33, 33, 34, 32, 45, 101,
  110, 100, 105, 102, 10, 95, 120, 112, 105, 110, 107, 115, 32, 58, 10, 115,
  61, 64, 123, 45, 49, 44, 115, 125, 32, 45, 105, 102, 32, 123, 36, 115,
  62, 49, 125, 32, 45, 115, 91, 45, 49, 93, 32, 99, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 64, 123, 62, 44, 45, 49, 125, 93, 32, 32, 45, 95, 120, 112,
  105, 110, 107, 32, 36, 49, 44, 34, 36, 50, 34, 32, 45, 107, 91, 45,
  49, 93, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45,
  105, 102, 32, 123, 36, 115, 62, 49, 125, 32, 45, 97, 91, 45, 36, 115,
  45, 45, 49, 93, 32, 99, 32, 45, 101, 110, 100, 105, 102, 10, 95, 120,
  102, 114, 97, 109, 101, 32, 58, 10, 45, 108, 105, 110, 101, 32, 48, 37,
  44, 48, 37, 44, 49, 48, 48, 37, 44, 48, 37, 32, 45, 108, 105, 110,
  101, 32, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 32, 45, 108, 105, 110, 101, 32, 48, 37, 44, 48, 37, 44,
  48, 37, 44, 49, 48, 48, 37, 32, 45, 108, 105, 110, 101, 32, 49, 48,
  48, 37, 44, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 10,
  111, 117, 116, 112, 117, 116, 95, 112, 105, 110, 107, 51, 100, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 79, 117, 116, 112, 117, 116, 32,
  105, 109, 97, 103, 101, 36, 63, 32, 97, 115, 32, 102, 105, 108, 101, 32,
  39, 36, 49, 39, 32, 40, 105, 110, 32, 51, 100, 32, 112, 105, 110, 107,
  32, 101, 120, 116, 101, 110, 115, 105, 111, 110, 32, 111, 102, 32, 80, 53,
  45, 99, 111, 100, 101, 100, 32, 80, 80, 77, 32, 102, 111, 114, 109, 97,
  116, 41, 46, 34, 10, 45, 118, 32, 45, 32, 45, 105, 102, 32, 123, 64,
  35, 61, 61, 49, 125, 32, 102, 105, 108, 101, 110, 97, 109, 101, 48, 61,
  34, 36, 49, 34, 10, 45, 101, 108, 115, 101, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 102, 105, 108, 101, 110, 97, 109, 101, 36, 62,
  61, 64, 123, 45, 102, 105, 108, 101, 110, 97, 109, 101, 92, 32, 34, 92,
  34, 36, 49, 92, 34, 34, 44, 36, 62, 125, 32, 45, 100, 111, 110, 101,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 100,
  61, 61, 49, 125, 32, 45, 111, 91, 45, 49, 93, 32, 112, 112, 109, 58,
  36, 123, 102, 105, 108, 101, 110, 97, 109, 101, 36, 62, 125, 10, 45, 101,
  108, 115, 101, 10, 40, 123, 39, 80, 53, 92, 110, 123, 119, 125, 92, 32,
  123, 104, 125, 92, 32, 123, 100, 125, 92, 110, 50, 53, 53, 92, 110, 39,
  125, 41, 10, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 50,
  93, 32, 48, 32, 45, 121, 91, 45, 49, 93, 32, 120, 32, 45, 97, 91,
  45, 50, 44, 45, 49, 93, 32, 120, 10, 45, 111, 91, 45, 49, 93, 32,
  114, 97, 119, 58, 36, 123, 102, 105, 108, 101, 110, 97, 109, 101, 36, 62,
  125, 44, 117, 99, 104, 97, 114, 10, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 112, 105, 110, 107, 32, 58, 32, 45,
  118, 32, 45, 10, 45, 105, 102, 32, 123, 36, 35, 62, 49, 125, 32, 40,
  123, 34, 39, 36, 123, 50, 45, 45, 49, 125, 39, 34, 125, 41, 32, 45,
  114, 101, 112, 108, 97, 99, 101, 91, 45, 49, 93, 32, 123, 39, 44, 39,
  125, 44, 123, 34, 39, 32, 39, 34, 125, 32, 112, 61, 64, 123, 45, 49,
  44, 116, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 108, 115,
  101, 32, 112, 61, 34, 32, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  118, 32, 43, 32, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 97, 108,
  108, 32, 112, 105, 110, 107, 32, 112, 97, 99, 107, 97, 103, 101, 32, 119,
  105, 116, 104, 32, 99, 109, 100, 58, 32, 92, 34, 36, 49, 36, 63, 32,
  34, 36, 112, 34, 36, 63, 92, 34, 46, 34, 32, 45, 118, 32, 45, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 64, 123,
  62, 44, 45, 49, 125, 93, 32, 45, 95, 120, 112, 105, 110, 107, 115, 32,
  36, 49, 44, 36, 112, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 112, 105, 110, 107, 95, 103, 114, 97, 121,
  115, 107, 101, 108, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49,
  61, 52, 125, 44, 36, 123, 50, 61, 48, 125, 10, 45, 99, 104, 101, 99,
  107, 32, 34, 36, 123, 49, 61, 52, 125, 61, 61, 52, 32, 124, 124, 32,
  36, 49, 61, 61, 56, 32, 124, 124, 32, 36, 49, 61, 61, 54, 32, 124,
  124, 32, 36, 49, 61, 61, 50, 54, 34, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 64, 123, 62, 44, 45, 49, 125, 93,
  32, 45, 95, 120, 112, 105, 110, 107, 115, 32, 34, 103, 114, 97, 121, 115,
  107, 101, 108, 34, 44, 34, 110, 117, 108, 108, 32, 36, 49, 32, 36, 50,
  34, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 112, 105,
  110, 107, 95, 104, 101, 105, 103, 104, 116, 109, 97, 120, 105, 109, 97, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 52, 125,
  61, 61, 52, 32, 124, 124, 32, 36, 49, 61, 61, 56, 32, 124, 124, 32,
  36, 49, 61, 61, 54, 32, 124, 124, 32, 36, 49, 61, 61, 50, 54, 34,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 49, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 70, 105, 108, 116, 101, 114, 32, 98, 121,
  32, 104, 101, 105, 103, 104, 116, 109, 97, 120, 105, 109, 97, 32, 101, 120,
  101, 99, 32, 119, 105, 116, 104, 32, 99, 111, 110, 110, 101, 99, 116, 105,
  118, 105, 116, 121, 32, 36, 49, 32, 104, 101, 105, 103, 104, 116, 32, 36,
  50, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 64, 123, 62, 44, 45, 49, 125, 93, 10,
  115, 61, 64, 123, 45, 49, 44, 115, 125, 32, 45, 105, 102, 32, 123, 36,
  115, 62, 49, 125, 32, 45, 115, 91, 45, 49, 93, 32, 99, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 64, 123, 62, 44, 45, 49, 125, 93, 32, 45, 95, 120, 112,
  105, 110, 107, 32, 34, 104, 101, 105, 103, 104, 116, 109, 97, 120, 105, 109,
  97, 34, 44, 34, 36, 49, 32, 36, 50, 34, 32, 45, 107, 91, 45, 49,
  93, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 105,
  102, 32, 123, 36, 115, 62, 49, 125, 32, 45, 97, 91, 45, 36, 115, 45,
  45, 49, 93, 32, 99, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 112, 105,
  110, 107, 95, 104, 101, 105, 103, 104, 116, 109, 105, 110, 105, 109, 97, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 52, 125,
  61, 61, 52, 32, 124, 124, 32, 36, 49, 61, 61, 56, 32, 124, 124, 32,
  36, 49, 61, 61, 54, 32, 124, 124, 32, 36, 49, 61, 61, 50, 54, 34,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 49, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 102, 105, 108,
  116, 101, 114, 32, 98, 121, 32, 104, 101, 105, 103, 104, 116, 109, 105, 110,
  105, 109, 97, 32, 101, 120, 101, 99, 32, 119, 105, 116, 104, 32, 99, 111,
  110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 32, 36, 49, 32, 104, 101,
  105, 103, 104, 116, 32, 36, 50, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 64, 123, 62,
  44, 45, 49, 125, 93, 10, 115, 61, 64, 123, 45, 49, 44, 115, 125, 32,
  45, 105, 102, 32, 123, 36, 115, 62, 49, 125, 32, 45, 115, 91, 45, 49,
  93, 32, 99, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 64, 123, 62, 44, 45, 49, 125,
  93, 32, 45, 95, 120, 112, 105, 110, 107, 32, 34, 104, 101, 105, 103, 104,
  116, 109, 105, 110, 105, 109, 97, 34, 44, 34, 36, 49, 32, 36, 50, 34,
  32, 45, 107, 91, 45, 49, 93, 32, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 115, 62, 49, 125, 32, 45,
  97, 91, 45, 36, 115, 45, 45, 49, 93, 32, 99, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 112, 105, 110, 107, 95, 104, 116, 107, 101, 114, 110, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 52, 125, 44, 36,
  123, 50, 61, 34, 34, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 64, 123, 62, 44, 45, 49, 125, 93, 32, 45, 95,
  120, 112, 105, 110, 107, 115, 32, 104, 116, 107, 101, 114, 110, 36, 50, 44,
  34, 110, 117, 108, 108, 32, 36, 49, 34, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 112, 105, 110, 107, 95, 108, 118, 107, 101, 114,
  110, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 52, 125,
  44, 36, 123, 50, 61, 34, 34, 125, 10, 45, 99, 104, 101, 99, 107, 32,
  34, 36, 123, 49, 61, 52, 125, 61, 61, 52, 32, 124, 124, 32, 36, 49,
  61, 61, 56, 32, 124, 124, 32, 36, 49, 61, 61, 54, 32, 124, 124, 32,
  36, 49, 61, 61, 50, 54, 34, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 64, 123, 62, 44, 45, 49, 125, 93, 32, 45,
  95, 120, 112, 105, 110, 107, 115, 32, 108, 118, 107, 101, 114, 110, 36, 123,
  50, 125, 44, 34, 110, 117, 108, 108, 32, 36, 49, 34, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 112, 105, 110, 107, 95, 114, 101,
  103, 95, 109, 105, 110, 105, 109, 97, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 34, 36, 123, 49, 61, 52, 125, 61, 61, 52, 32, 124, 124, 32,
  36, 49, 61, 61, 56, 32, 124, 124, 32, 36, 49, 61, 61, 54, 32, 124,
  124, 32, 36, 49, 61, 61, 50, 54, 34, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 114, 101, 103, 105, 111,
  110, 97, 108, 32, 109, 105, 110, 105, 109, 97, 32, 101, 120, 101, 99, 32,
  119, 105, 116, 104, 32, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116,
  121, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 64, 123, 62, 44, 45, 49,
  125, 93, 10, 115, 61, 64, 123, 45, 49, 44, 115, 125, 32, 45, 105, 102,
  32, 123, 36, 115, 62, 49, 125, 32, 45, 115, 91, 45, 49, 93, 32, 99,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 64, 123, 62, 44, 45, 49, 125, 93, 32, 32,
  45, 95, 120, 112, 105, 110, 107, 32, 34, 109, 105, 110, 105, 109, 97, 34,
  44, 34, 36, 49, 34, 32, 45, 107, 91, 45, 49, 93, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 115,
  62, 49, 125, 32, 45, 97, 91, 45, 36, 115, 45, 45, 49, 93, 32, 99,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 112, 105, 110, 107, 95, 115, 107,
  101, 108, 99, 117, 114, 118, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 49, 61, 48, 125, 44, 36, 123, 50, 61, 52, 125, 44, 36, 123, 51,
  61, 34, 34, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 117,
  114, 118, 105, 108, 105, 110, 101, 97, 114, 32, 98, 105, 110, 97, 114, 121,
  32, 115, 107, 101, 108, 101, 116, 111, 110, 32, 103, 117, 105, 100, 101, 100,
  32, 98, 121, 32, 97, 32, 112, 114, 105, 111, 114, 105, 116, 121, 32, 102,
  117, 110, 99, 116, 105, 111, 110, 32, 111, 114, 32, 105, 109, 97, 103, 101,
  32, 102, 114, 111, 109, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 112,
  114, 105, 111, 61, 36, 49, 44, 32, 99, 111, 110, 110, 101, 99, 116, 105,
  118, 105, 116, 121, 61, 36, 50, 44, 32, 105, 110, 104, 105, 98, 105, 116,
  61, 36, 51, 46, 34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 64, 123, 62, 44, 45, 49, 125, 93, 32, 45, 95, 120,
  112, 105, 110, 107, 115, 32, 34, 115, 107, 101, 108, 99, 117, 114, 118, 34,
  44, 34, 36, 49, 32, 36, 50, 32, 36, 51, 34, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 112, 105, 110, 107, 95, 115, 107, 101,
  108, 101, 110, 100, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49,
  61, 52, 125, 44, 36, 123, 50, 61, 48, 125, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 64, 123, 62, 44, 45, 49, 125,
  93, 32, 45, 95, 120, 112, 105, 110, 107, 115, 32, 34, 115, 107, 101, 108,
  101, 110, 100, 34, 44, 34, 36, 49, 32, 36, 50, 34, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 112, 105, 110, 107, 95, 115, 107,
  101, 108, 101, 116, 111, 110, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 49, 61, 48, 125, 44, 36, 123, 50, 61, 52, 125, 44, 36, 123, 51,
  61, 34, 34, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 64, 123, 62, 44, 45, 49, 125, 93, 32, 45, 95, 120, 112,
  105, 110, 107, 115, 32, 34, 115, 107, 101, 108, 101, 116, 111, 110, 34, 44,
  34, 36, 49, 32, 36, 50, 32, 36, 51, 34, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 112, 105, 110, 107, 95, 115, 107, 101, 108,
  112, 97, 114, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  52, 125, 44, 36, 123, 50, 61, 45, 49, 125, 44, 36, 123, 51, 61, 34,
  34, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 64, 123, 62, 44, 45, 49, 125, 93, 32, 45, 95, 120, 102, 114, 97,
  109, 101, 32, 45, 95, 120, 112, 105, 110, 107, 115, 32, 34, 115, 107, 101,
  108, 112, 97, 114, 34, 44, 34, 36, 49, 32, 36, 50, 32, 36, 51, 34,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 112, 105, 110,
  107, 95, 119, 115, 104, 101, 100, 32, 58, 32, 45, 99, 104, 101, 99, 107,
  32, 34, 36, 123, 49, 61, 52, 125, 61, 61, 52, 32, 124, 124, 32, 36,
  49, 61, 61, 56, 32, 124, 124, 32, 36, 49, 61, 61, 54, 32, 124, 124,
  32, 36, 49, 61, 61, 50, 54, 34, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 50, 61, 48, 125, 44, 36, 123, 51, 61, 48, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 119, 115,
  104, 101, 100, 116, 111, 112, 111, 32, 101, 120, 101, 99, 32, 119, 105, 116,
  104, 32, 99, 111, 110, 110, 101, 99, 116, 105, 118, 105, 116, 121, 32, 36,
  49, 32, 105, 110, 118, 101, 114, 115, 105, 111, 110, 32, 36, 50, 32, 104,
  101, 105, 103, 104, 116, 32, 36, 51, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 64, 123,
  62, 44, 45, 49, 125, 93, 10, 115, 61, 64, 123, 45, 49, 44, 115, 125,
  32, 45, 105, 102, 32, 123, 36, 115, 62, 49, 125, 32, 45, 115, 91, 45,
  49, 93, 32, 99, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 100, 61, 61, 49, 125, 10, 45, 99, 104, 101, 99, 107, 32, 34, 36,
  123, 49, 61, 52, 125, 61, 61, 52, 32, 124, 124, 32, 36, 49, 61, 61,
  56, 34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 64, 123, 62, 44, 45, 49, 125, 93, 10, 45, 105, 102, 32, 123, 36,
  50, 33, 61, 48, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 102, 32, 109, 97, 120, 40, 109, 105,
  110, 40, 105, 44, 50, 53, 53, 41, 44, 48, 41, 10, 45, 105, 102, 32,
  123, 36, 51, 62, 61, 48, 125, 32, 45, 112, 105, 110, 107, 32, 104, 101,
  105, 103, 104, 116, 109, 105, 110, 105, 109, 97, 44, 36, 49, 44, 36, 51,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 112, 105, 110, 107, 32, 119, 115,
  104, 101, 100, 116, 111, 112, 111, 44, 36, 49, 10, 45, 105, 102, 32, 123,
  36, 50, 33, 61, 48, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 45, 101, 108, 115, 101, 10, 45, 99, 104, 101, 99, 107,
  32, 34, 36, 49, 61, 61, 54, 32, 124, 124, 32, 36, 49, 61, 61, 50,
  54, 34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 64, 123, 62, 44, 45, 49, 125, 93, 10, 45, 105, 102, 32, 123, 36,
  50, 33, 61, 48, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 102, 32, 109, 97, 120, 40, 109, 105,
  110, 40, 105, 44, 50, 53, 53, 41, 44, 48, 41, 10, 45, 105, 102, 32,
  123, 36, 51, 62, 61, 48, 125, 10, 45, 112, 105, 110, 107, 32, 104, 101,
  105, 103, 104, 116, 109, 105, 110, 105, 109, 97, 44, 36, 49, 44, 36, 51,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 112, 105, 110, 107, 32, 119, 115,
  104, 101, 100, 116, 111, 112, 111, 44, 36, 49, 10, 45, 105, 102, 32, 123,
  36, 50, 33, 61, 48, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 115, 62, 49, 125, 32, 45, 97, 91, 45, 36, 115, 45, 45, 49, 93,
  32, 99, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 97, 108, 101, 114, 116,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36, 123, 49, 61, 91, 71,
  39, 77, 73, 67, 32, 65, 108, 101, 114, 116, 93, 125, 44, 36, 123, 50,
  61, 84, 104, 105, 115, 32, 105, 115, 32, 97, 110, 32, 97, 108, 101, 114,
  116, 32, 98, 111, 120, 46, 125, 44, 36, 123, 51, 61, 79, 75, 125, 34,
  10, 45, 105, 102, 32, 123, 64, 35, 61, 61, 49, 125, 10, 45, 101, 91,
  48, 45, 45, 51, 93, 32, 34, 68, 105, 115, 112, 108, 97, 121, 32, 97,
  108, 101, 114, 116, 32, 98, 111, 120, 44, 32, 119, 105, 116, 104, 32, 105,
  109, 97, 103, 101, 36, 63, 44, 32, 116, 105, 116, 108, 101, 32, 39, 36,
  49, 39, 44, 32, 109, 101, 115, 115, 97, 103, 101, 32, 39, 36, 50, 39,
  32, 97, 110, 100, 32, 98, 117, 116, 116, 111, 110, 115, 32, 39, 36, 123,
  51, 45, 45, 49, 125, 39, 46, 34, 10, 45, 101, 108, 115, 101, 10, 45,
  101, 91, 48, 45, 45, 51, 93, 32, 34, 68, 105, 115, 112, 108, 97, 121,
  32, 97, 108, 101, 114, 116, 32, 98, 111, 120, 44, 32, 119, 105, 116, 104,
  32, 116, 105, 116, 108, 101, 32, 39, 36, 49, 39, 44, 32, 109, 101, 115,
  115, 97, 103, 101, 32, 39, 36, 50, 39, 32, 97, 110, 100, 32, 98, 117,
  116, 116, 111, 110, 115, 32, 39, 36, 123, 51, 45, 45, 49, 125, 39, 46,
  34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45, 10, 45, 105,
  102, 32, 123, 64, 35, 61, 61, 49, 125, 32, 108, 111, 103, 111, 61, 32,
  45, 101, 108, 115, 101, 32, 108, 111, 103, 111, 61, 91, 93, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 45, 108, 36, 108, 111, 103, 111, 10, 45, 105,
  102, 32, 123, 64, 35, 61, 61, 49, 125, 32, 45, 116, 111, 95, 114, 103,
  98, 10, 45, 101, 108, 115, 101, 10, 54, 52, 44, 54, 52, 32, 45, 112,
  111, 108, 121, 103, 111, 110, 32, 51, 44, 53, 48, 37, 44, 49, 48, 37,
  44, 49, 48, 37, 44, 57, 48, 37, 44, 57, 48, 37, 44, 57, 48, 37,
  44, 49, 44, 49, 32, 45, 98, 32, 51, 32, 45, 103, 101, 32, 53, 48,
  37, 10, 45, 45, 101, 114, 111, 100, 101, 91, 45, 49, 93, 32, 53, 32,
  45, 45, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 61, 61, 91,
  45, 49, 93, 32, 48, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45,
  49, 93, 32, 52, 44, 52, 55, 37, 44, 52, 51, 37, 44, 53, 51, 37,
  44, 52, 51, 37, 44, 53, 51, 37, 44, 54, 54, 37, 44, 52, 55, 37,
  44, 54, 54, 37, 44, 49, 44, 48, 32, 45, 99, 105, 114, 99, 108, 101,
  91, 45, 49, 93, 32, 53, 48, 37, 44, 55, 54, 37, 44, 50, 44, 49,
  44, 48, 10, 45, 45, 42, 91, 48, 93, 32, 50, 53, 53, 32, 91, 45,
  49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 97, 91,
  45, 51, 45, 45, 49, 93, 32, 99, 32, 45, 45, 91, 45, 49, 93, 32,
  39, 51, 42, 40, 121, 45, 104, 47, 50, 41, 39, 10, 45, 42, 91, 45,
  49, 93, 32, 91, 45, 50, 93, 32, 45, 114, 109, 91, 45, 50, 93, 32,
  45, 42, 91, 48, 93, 32, 50, 53, 53, 32, 45, 114, 118, 32, 45, 97,
  32, 99, 10, 45, 100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119, 32,
  51, 44, 51, 44, 49, 32, 45, 105, 91, 48, 93, 32, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 44, 51, 44, 50, 48, 48, 32, 45, 98,
  108, 101, 110, 100, 32, 97, 108, 112, 104, 97, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 45, 49, 44, 50,
  10, 36, 61, 97, 114, 103, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  36, 35, 45, 50, 125, 32, 108, 97, 98, 101, 108, 61, 36, 123, 97, 114,
  103, 123, 36, 62, 43, 51, 125, 125, 32, 48, 32, 45, 116, 101, 120, 116,
  91, 45, 49, 93, 32, 36, 108, 97, 98, 101, 108, 44, 48, 44, 48, 44,
  49, 52, 44, 49, 44, 45, 50, 48, 48, 32, 45, 100, 111, 110, 101, 10,
  45, 114, 91, 94, 48, 93, 32, 123, 109, 105, 110, 40, 49, 50, 56, 44,
  109, 97, 120, 40, 54, 52, 44, 64, 123, 45, 109, 97, 120, 95, 119, 91,
  94, 48, 93, 125, 43, 49, 50, 41, 41, 125, 44, 123, 109, 105, 110, 40,
  52, 56, 44, 109, 97, 120, 40, 50, 52, 44, 64, 123, 45, 109, 97, 120,
  95, 104, 91, 94, 48, 93, 125, 43, 49, 50, 41, 41, 125, 44, 49, 44,
  49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 43,
  91, 94, 48, 93, 32, 50, 48, 48, 32, 45, 116, 111, 95, 114, 103, 98,
  91, 94, 48, 93, 10, 45, 109, 118, 91, 48, 93, 32, 64, 35, 10, 91,
  48, 93, 44, 91, 48, 93, 44, 49, 44, 49, 44, 39, 40, 121, 45, 104,
  47, 50, 41, 39, 32, 45, 42, 91, 45, 49, 93, 32, 45, 50, 32, 45,
  99, 91, 45, 49, 93, 32, 45, 51, 48, 44, 51, 48, 32, 45, 43, 91,
  48, 45, 45, 51, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45,
  49, 93, 32, 45, 99, 91, 94, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 32,
  45, 108, 91, 36, 60, 93, 10, 45, 45, 114, 101, 99, 116, 97, 110, 103,
  108, 101, 32, 48, 44, 48, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 10,
  45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 49,
  44, 49, 44, 123, 119, 45, 50, 125, 44, 123, 104, 45, 50, 125, 44, 49,
  44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 10, 45, 108,
  105, 110, 101, 91, 45, 49, 93, 32, 50, 44, 123, 104, 45, 51, 125, 44,
  123, 119, 45, 51, 125, 44, 123, 104, 45, 51, 125, 44, 49, 44, 49, 53,
  48, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 123, 119, 45, 51,
  125, 44, 123, 104, 45, 51, 125, 44, 123, 119, 45, 51, 125, 44, 50, 44,
  49, 44, 49, 53, 48, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32,
  49, 44, 49, 44, 123, 119, 45, 51, 125, 44, 49, 44, 49, 44, 50, 53,
  53, 32, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 49, 44, 49, 44,
  49, 44, 123, 104, 45, 51, 125, 44, 49, 44, 50, 53, 53, 10, 45, 114,
  101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 52, 44, 52,
  44, 123, 119, 45, 53, 125, 44, 123, 104, 45, 53, 125, 44, 49, 44, 48,
  120, 65, 65, 65, 65, 65, 65, 65, 65, 44, 48, 10, 45, 45, 115, 104,
  105, 102, 116, 91, 45, 50, 93, 32, 49, 44, 49, 44, 48, 44, 48, 44,
  50, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93,
  32, 48, 44, 48, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 10, 45, 114,
  101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 49, 44, 49,
  44, 123, 119, 45, 50, 125, 44, 123, 104, 45, 50, 125, 44, 49, 44, 48,
  120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 49, 53, 48, 10, 45, 114,
  101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 52, 44, 52,
  44, 123, 119, 45, 53, 125, 44, 123, 104, 45, 53, 125, 44, 49, 44, 48,
  120, 65, 65, 65, 65, 65, 65, 65, 65, 44, 48, 10, 45, 114, 101, 99,
  116, 97, 110, 103, 108, 101, 91, 45, 51, 93, 32, 48, 44, 48, 44, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 48, 120, 70, 70, 70,
  70, 70, 70, 70, 70, 44, 48, 10, 45, 108, 105, 110, 101, 91, 45, 51,
  93, 32, 49, 44, 123, 104, 45, 50, 125, 44, 123, 119, 45, 50, 125, 44,
  123, 104, 45, 50, 125, 44, 49, 44, 49, 53, 48, 32, 45, 108, 105, 110,
  101, 91, 45, 51, 93, 32, 123, 119, 45, 50, 125, 44, 123, 104, 45, 50,
  125, 44, 123, 119, 45, 50, 125, 44, 49, 44, 49, 44, 49, 53, 48, 10,
  45, 108, 105, 110, 101, 91, 45, 51, 93, 32, 48, 44, 48, 44, 123, 119,
  45, 50, 125, 44, 48, 44, 49, 44, 50, 53, 53, 32, 45, 108, 105, 110,
  101, 91, 45, 51, 93, 32, 48, 44, 48, 44, 48, 44, 123, 104, 45, 50,
  125, 44, 49, 44, 50, 53, 53, 10, 45, 105, 91, 48, 93, 32, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 32, 45, 61, 91, 48, 93, 32, 49, 44,
  48, 44, 48, 10, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 45, 45, 108, 10, 45, 99, 104, 97, 110, 110, 101,
  108, 115, 32, 48, 44, 51, 32, 45, 115, 104, 32, 49, 44, 49, 48, 48,
  37, 32, 45, 45, 91, 53, 48, 37, 45, 45, 49, 93, 32, 50, 48, 48,
  32, 45, 114, 109, 91, 53, 48, 37, 45, 45, 49, 93, 32, 45, 102, 114,
  97, 109, 101, 32, 56, 44, 56, 44, 48, 10, 45, 105, 102, 32, 123, 64,
  35, 60, 54, 125, 32, 45, 97, 91, 94, 45, 49, 93, 32, 120, 32, 45,
  101, 108, 115, 101, 32, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108,
  101, 115, 91, 94, 45, 49, 93, 32, 44, 32, 45, 101, 110, 100, 105, 102,
  10, 48, 32, 45, 116, 101, 120, 116, 91, 45, 49, 93, 32, 34, 36, 50,
  34, 44, 48, 44, 48, 44, 49, 52, 44, 49, 44, 48, 44, 45, 50, 48,
  48, 44, 45, 50, 48, 48, 44, 45, 50, 48, 48, 32, 45, 114, 91, 45,
  49, 93, 32, 123, 119, 43, 49, 54, 125, 44, 123, 104, 43, 56, 125, 44,
  49, 44, 52, 44, 48, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32,
  120, 44, 48, 46, 53, 32, 45, 114, 118, 32, 45, 97, 32, 121, 44, 48,
  46, 53, 10, 45, 115, 104, 32, 49, 44, 49, 48, 48, 37, 32, 45, 43,
  91, 45, 49, 93, 32, 50, 48, 48, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 32, 48, 44, 48, 44,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 48, 120, 70, 70,
  70, 70, 70, 70, 70, 70, 44, 48, 10, 45, 108, 105, 110, 101, 32, 48,
  44, 48, 44, 123, 119, 45, 50, 125, 44, 48, 44, 49, 44, 48, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 108, 105, 110, 101,
  32, 48, 44, 48, 44, 48, 44, 123, 104, 45, 50, 125, 44, 49, 44, 48,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 101, 110,
  100, 108, 10, 45, 114, 109, 91, 45, 50, 93, 10, 45, 45, 99, 104, 97,
  110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 10, 40, 48, 44, 123,
  119, 45, 49, 125, 41, 32, 40, 48, 59, 64, 123, 45, 50, 44, 104, 45,
  49, 125, 41, 32, 45, 114, 91, 45, 50, 44, 45, 49, 93, 32, 91, 45,
  51, 93, 44, 51, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99,
  32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 45, 114, 118, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93,
  10, 45, 100, 105, 115, 99, 97, 114, 100, 91, 45, 49, 93, 32, 48, 32,
  45, 114, 91, 45, 49, 93, 32, 123, 104, 47, 50, 125, 44, 50, 44, 49,
  44, 49, 44, 45, 49, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91,
  45, 50, 93, 32, 49, 44, 51, 32, 45, 114, 118, 91, 45, 50, 44, 45,
  49, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 123, 45, 51, 44, 119, 125, 32, 120, 48, 61,
  64, 123, 45, 51, 44, 40, 36, 62, 44, 48, 41, 125, 32, 121, 48, 61,
  64, 123, 45, 51, 44, 40, 36, 62, 44, 49, 41, 125, 32, 45, 114, 101,
  99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 36, 120, 48, 44,
  36, 121, 48, 44, 123, 36, 120, 48, 43, 64, 123, 48, 44, 119, 125, 45,
  49, 125, 44, 123, 36, 121, 48, 43, 64, 123, 48, 44, 104, 125, 45, 49,
  125, 44, 49, 44, 123, 49, 43, 36, 62, 125, 32, 45, 100, 111, 110, 101,
  10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 57, 32, 45, 105, 102, 32, 123, 33, 64, 123, 33,
  36, 62, 125, 125, 32, 100, 105, 115, 112, 61, 36, 62, 32, 45, 98, 114,
  101, 97, 107, 32, 45, 101, 110, 100, 105, 102, 32, 45, 100, 111, 110, 101,
  10, 45, 105, 102, 32, 123, 33, 110, 97, 114, 103, 40, 36, 100, 105, 115,
  112, 41, 125, 32, 45, 101, 114, 114, 111, 114, 91, 48, 45, 45, 52, 93,
  32, 34, 67, 97, 110, 110, 111, 116, 32, 111, 112, 101, 110, 32, 100, 105,
  115, 112, 108, 97, 121, 32, 119, 105, 110, 100, 111, 119, 32, 102, 111, 114,
  32, 97, 108, 101, 114, 116, 32, 98, 111, 120, 46, 34, 32, 45, 101, 110,
  100, 105, 102, 10, 115, 101, 108, 101, 99, 116, 101, 100, 61, 123, 105, 102,
  40, 36, 35, 61, 61, 51, 44, 48, 44, 45, 49, 41, 125, 32, 99, 108,
  105, 99, 107, 101, 100, 61, 45, 49, 10, 45, 100, 111, 10, 45, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 44, 50, 10,
  45, 105, 102, 32, 123, 36, 99, 108, 105, 99, 107, 101, 100, 62, 61, 48,
  125, 10, 120, 48, 61, 64, 123, 45, 51, 44, 40, 36, 99, 108, 105, 99,
  107, 101, 100, 44, 48, 41, 125, 32, 121, 48, 61, 64, 123, 45, 51, 44,
  40, 36, 99, 108, 105, 99, 107, 101, 100, 44, 49, 41, 125, 10, 45, 115,
  104, 91, 36, 99, 108, 105, 99, 107, 101, 100, 93, 32, 55, 44, 57, 10,
  45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 120, 48, 44,
  36, 121, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 115, 101, 108, 101, 99, 116, 101, 100, 62, 61, 48, 125,
  10, 120, 48, 61, 64, 123, 45, 51, 44, 40, 36, 115, 101, 108, 101, 99,
  116, 101, 100, 44, 48, 41, 125, 32, 121, 48, 61, 64, 123, 45, 51, 44,
  40, 36, 115, 101, 108, 101, 99, 116, 101, 100, 44, 49, 41, 125, 10, 45,
  115, 104, 91, 36, 115, 101, 108, 101, 99, 116, 101, 100, 93, 32, 52, 44,
  54, 10, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 120,
  48, 44, 36, 121, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 119, 36, 100, 105, 115, 112, 91, 45, 49, 93,
  32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48, 44, 34, 36, 49,
  34, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 119, 97, 105, 116, 10,
  120, 109, 61, 64, 123, 33, 36, 100, 105, 115, 112, 44, 120, 125, 32, 121,
  109, 61, 64, 123, 33, 36, 100, 105, 115, 112, 44, 121, 125, 32, 98, 109,
  61, 123, 64, 123, 33, 36, 100, 105, 115, 112, 44, 98, 125, 38, 49, 125,
  32, 118, 97, 108, 61, 123, 105, 40, 36, 120, 109, 44, 36, 121, 109, 44,
  48, 44, 51, 41, 125, 10, 45, 105, 102, 32, 123, 36, 98, 109, 34, 32,
  38, 38, 32, 34, 36, 118, 97, 108, 125, 32, 99, 108, 105, 99, 107, 101,
  100, 61, 123, 36, 118, 97, 108, 45, 49, 125, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 98, 109, 34, 32, 38, 38, 32, 34, 33, 36, 118, 97, 108,
  34, 32, 38, 38, 32, 34, 36, 99, 108, 105, 99, 107, 101, 100, 62, 61,
  48, 125, 32, 115, 101, 108, 101, 99, 116, 101, 100, 61, 36, 99, 108, 105,
  99, 107, 101, 100, 32, 99, 108, 105, 99, 107, 101, 100, 61, 45, 49, 10,
  45, 101, 108, 105, 102, 32, 123, 33, 36, 98, 109, 34, 32, 38, 38, 32,
  34, 36, 99, 108, 105, 99, 107, 101, 100, 62, 61, 48, 34, 32, 38, 38,
  32, 34, 36, 99, 108, 105, 99, 107, 101, 100, 61, 61, 36, 118, 97, 108,
  45, 49, 125, 32, 45, 98, 114, 101, 97, 107, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 64, 123, 33, 36, 100, 105, 115, 112, 44, 65,
  82, 82, 79, 87, 82, 73, 71, 72, 84, 125, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 61, 123, 40, 36, 115, 101, 108, 101, 99, 116, 101, 100, 43,
  49, 41, 37, 64, 123, 45, 50, 44, 119, 125, 125, 32, 45, 119, 97, 105,
  116, 32, 45, 49, 10, 45, 101, 108, 105, 102, 32, 64, 123, 33, 36, 100,
  105, 115, 112, 44, 65, 82, 82, 79, 87, 76, 69, 70, 84, 125, 32, 115,
  101, 108, 101, 99, 116, 101, 100, 61, 123, 40, 36, 115, 101, 108, 101, 99,
  116, 101, 100, 45, 49, 41, 37, 64, 123, 45, 50, 44, 119, 125, 43, 40,
  36, 115, 101, 108, 101, 99, 116, 101, 100, 61, 61, 45, 49, 41, 125, 32,
  45, 119, 97, 105, 116, 32, 45, 49, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 115, 101, 108, 101, 99, 116, 101, 100, 62, 61, 48, 34, 32, 38, 38,
  32, 34, 64, 123, 33, 36, 100, 105, 115, 112, 44, 69, 78, 84, 69, 82,
  125, 125, 32, 99, 108, 105, 99, 107, 101, 100, 61, 36, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 45, 98, 114, 101, 97, 107, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123, 64, 123, 33, 36, 100,
  105, 115, 112, 125, 34, 32, 38, 38, 32, 34, 33, 64, 123, 33, 36, 100,
  105, 115, 112, 44, 69, 83, 67, 125, 125, 10, 45, 119, 36, 100, 105, 115,
  112, 32, 48, 32, 45, 114, 109, 32, 45, 117, 32, 36, 99, 108, 105, 99,
  107, 101, 100, 10, 45, 101, 110, 100, 108, 10, 45, 118, 32, 43, 10, 97,
  114, 103, 32, 58, 10, 45, 118, 32, 45, 32, 36, 61, 97, 114, 103, 32,
  45, 117, 32, 36, 123, 97, 114, 103, 123, 49, 43, 40, 36, 49, 41, 125,
  125, 32, 45, 118, 32, 43, 10, 97, 116, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 49, 61, 48, 125, 44, 36, 123, 50, 61, 48, 125, 44,
  36, 123, 51, 61, 48, 125, 10, 45, 118, 32, 45, 32, 45, 45, 122, 91,
  45, 49, 93, 32, 36, 123, 49, 45, 51, 125, 44, 36, 123, 49, 45, 51,
  125, 32, 45, 117, 32, 64, 45, 49, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 118, 32, 43, 10, 97, 117, 116, 111, 99, 114, 111, 112, 95, 99,
  111, 111, 114, 100, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  49, 61, 97, 117, 116, 111, 125, 10, 45, 118, 32, 45, 10, 105, 115, 95,
  97, 117, 116, 111, 61, 123, 36, 49, 39, 61, 61, 39, 97, 117, 116, 111,
  125, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 32, 100, 61,
  123, 100, 125, 10, 118, 97, 108, 117, 101, 61, 123, 105, 40, 119, 45, 49,
  44, 104, 45, 49, 44, 100, 45, 49, 41, 125, 32, 45, 45, 61, 91, 45,
  49, 93, 32, 123, 49, 43, 36, 118, 97, 108, 117, 101, 125, 44, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 95, 97,
  117, 116, 111, 99, 114, 111, 112, 36, 105, 115, 95, 97, 117, 116, 111, 91,
  45, 49, 93, 32, 36, 123, 49, 45, 45, 49, 125, 32, 45, 61, 91, 45,
  49, 93, 32, 36, 118, 97, 108, 117, 101, 44, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 10, 120, 48, 61, 123, 36, 119, 45,
  119, 125, 32, 121, 48, 61, 123, 36, 104, 45, 104, 125, 32, 122, 48, 61,
  123, 36, 100, 45, 100, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  45, 95, 97, 117, 116, 111, 99, 114, 111, 112, 36, 105, 115, 95, 97, 117,
  116, 111, 91, 45, 49, 93, 32, 36, 123, 49, 45, 45, 49, 125, 10, 120,
  49, 61, 123, 36, 120, 48, 43, 119, 45, 49, 125, 32, 121, 49, 61, 123,
  36, 121, 48, 43, 104, 45, 49, 125, 32, 122, 49, 61, 123, 36, 122, 48,
  43, 100, 45, 49, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 117,
  32, 36, 120, 48, 44, 36, 121, 48, 44, 36, 122, 48, 44, 36, 120, 49,
  44, 36, 121, 49, 44, 36, 122, 49, 10, 45, 118, 32, 43, 10, 95, 97,
  117, 116, 111, 99, 114, 111, 112, 48, 32, 58, 32, 45, 97, 117, 116, 111,
  99, 114, 111, 112, 32, 36, 42, 10, 95, 97, 117, 116, 111, 99, 114, 111,
  112, 49, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 42, 32, 45, 97,
  117, 116, 111, 99, 114, 111, 112, 10, 97, 118, 101, 114, 97, 103, 101, 95,
  99, 111, 108, 111, 114, 32, 58, 10, 45, 118, 32, 45, 10, 114, 101, 115,
  61, 34, 34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 115, 45, 49,
  125, 32, 45, 115, 104, 91, 45, 49, 93, 32, 123, 49, 43, 36, 62, 125,
  44, 123, 49, 43, 36, 62, 125, 32, 114, 101, 115, 61, 36, 114, 101, 115,
  44, 123, 105, 97, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 100,
  111, 110, 101, 10, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 48, 32,
  45, 117, 32, 123, 105, 97, 125, 36, 114, 101, 115, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 118, 32, 43, 10, 98, 97, 115, 101, 110, 97, 109,
  101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 117, 110,
  117, 115, 101, 100, 125, 10, 45, 118, 32, 45, 10, 45, 108, 91, 93, 32,
  40, 123, 34, 39, 36, 49, 39, 34, 125, 41, 32, 45, 114, 101, 112, 108,
  97, 99, 101, 32, 57, 50, 44, 52, 55, 32, 45, 115, 32, 43, 44, 52,
  55, 10, 45, 105, 102, 32, 123, 105, 61, 61, 52, 55, 125, 32, 45, 97,
  32, 121, 32, 36, 50, 61, 64, 123, 45, 49, 44, 116, 125, 32, 45, 117,
  32, 34, 34, 10, 45, 101, 108, 105, 102, 32, 123, 64, 35, 61, 61, 49,
  125, 32, 45, 117, 32, 64, 123, 45, 49, 44, 116, 125, 32, 36, 50, 61,
  34, 34, 10, 45, 101, 108, 115, 101, 32, 45, 97, 91, 94, 45, 49, 93,
  32, 121, 32, 45, 117, 32, 64, 123, 45, 49, 44, 116, 125, 32, 36, 50,
  61, 64, 123, 45, 50, 44, 116, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 114, 109, 32, 45, 101, 110, 100, 108, 10, 45, 118, 32, 43, 10, 98,
  105, 110, 32, 58, 10, 45, 118, 32, 45, 32, 100, 101, 99, 61, 64, 123,
  45, 98, 105, 110, 50, 100, 101, 99, 92, 32, 36, 123, 94, 48, 125, 125,
  32, 45, 118, 32, 43, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67,
  111, 110, 118, 101, 114, 116, 32, 98, 105, 110, 97, 114, 121, 32, 105, 110,
  116, 101, 103, 101, 114, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43,
  40, 36, 35, 62, 49, 41, 44, 34, 34, 44, 115, 125, 34, 32, 39, 36,
  123, 94, 48, 125, 39, 32, 116, 111, 32, 111, 99, 116, 97, 108, 32, 39,
  34, 64, 123, 45, 100, 101, 99, 50, 111, 99, 116, 92, 32, 36, 100, 101,
  99, 125, 34, 39, 44, 10, 100, 101, 99, 105, 109, 97, 108, 32, 39, 34,
  36, 100, 101, 99, 34, 39, 44, 32, 104, 101, 120, 97, 100, 101, 99, 105,
  109, 97, 108, 32, 39, 34, 64, 123, 45, 100, 101, 99, 50, 104, 101, 120,
  92, 32, 36, 100, 101, 99, 125, 34, 39, 32, 97, 110, 100, 32, 115, 116,
  114, 105, 110, 103, 32, 39, 34, 64, 123, 45, 100, 101, 99, 50, 115, 116,
  114, 92, 32, 36, 100, 101, 99, 125, 34, 39, 46, 34, 10, 98, 105, 110,
  50, 100, 101, 99, 32, 58, 10, 45, 118, 32, 45, 32, 114, 101, 115, 61,
  64, 123, 45, 95, 36, 48, 92, 32, 36, 49, 125, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 36, 35, 45, 49, 125, 32, 114, 101, 115, 61, 36,
  114, 101, 115, 44, 64, 123, 45, 95, 36, 48, 92, 32, 64, 123, 45, 97,
  114, 103, 92, 32, 36, 62, 43, 50, 44, 36, 123, 94, 48, 125, 125, 125,
  32, 45, 100, 111, 110, 101, 32, 45, 117, 32, 36, 114, 101, 115, 32, 45,
  118, 32, 43, 10, 95, 98, 105, 110, 50, 100, 101, 99, 32, 58, 10, 40,
  123, 39, 64, 123, 45, 115, 116, 114, 117, 110, 99, 97, 115, 101, 92, 32,
  36, 49, 125, 39, 125, 41, 10, 105, 115, 95, 110, 101, 103, 97, 116, 105,
  118, 101, 61, 48, 10, 45, 105, 102, 32, 123, 64, 123, 45, 49, 44, 48,
  125, 61, 61, 52, 53, 125, 32, 45, 122, 91, 45, 49, 93, 32, 49, 44,
  49, 48, 48, 37, 32, 105, 115, 95, 110, 101, 103, 97, 116, 105, 118, 101,
  61, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 102, 91, 45, 49, 93,
  32, 34, 105, 102, 40, 105, 62, 61, 52, 56, 32, 38, 38, 32, 105, 60,
  61, 52, 57, 44, 40, 105, 45, 52, 56, 41, 42, 50, 94, 40, 119, 45,
  49, 45, 120, 41, 44, 110, 97, 110, 41, 34, 10, 45, 117, 32, 123, 105,
  102, 40, 36, 105, 115, 95, 110, 101, 103, 97, 116, 105, 118, 101, 44, 45,
  49, 44, 49, 41, 42, 64, 123, 45, 49, 44, 43, 125, 125, 10, 45, 114,
  109, 91, 45, 49, 93, 10, 99, 111, 109, 112, 114, 101, 115, 115, 95, 103,
  109, 105, 99, 32, 58, 10, 45, 101, 91, 93, 32, 34, 34, 32, 45, 118,
  32, 45, 10, 104, 101, 97, 100, 95, 115, 116, 100, 61, 123, 39, 34, 35,
  64, 103, 109, 105, 99, 34, 39, 125, 10, 45, 115, 32, 45, 44, 49, 48,
  32, 78, 61, 64, 35, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  10, 45, 105, 102, 32, 123, 33, 40, 36, 62, 37, 49, 48, 48, 41, 125,
  32, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 114, 32, 32,
  80, 114, 111, 99, 101, 115, 115, 32, 58, 32, 34, 123, 114, 111, 117, 110,
  100, 40, 36, 62, 47, 36, 78, 42, 49, 48, 48, 41, 125, 37, 32, 45,
  118, 32, 45, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  105, 61, 61, 123, 39, 35, 39, 125, 125, 10, 104, 101, 97, 100, 61, 64,
  123, 45, 49, 44, 48, 45, 123, 109, 105, 110, 40, 53, 44, 104, 45, 49,
  41, 125, 125, 10, 45, 105, 102, 32, 123, 123, 36, 104, 101, 97, 100, 39,
  33, 61, 39, 36, 104, 101, 97, 100, 95, 115, 116, 100, 125, 34, 32, 124,
  124, 32, 34, 40, 105, 91, 54, 93, 33, 61, 123, 39, 34, 32, 34, 39,
  125, 34, 32, 38, 38, 32, 34, 105, 91, 54, 93, 33, 61, 123, 39, 58,
  39, 125, 41, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 99, 111,
  110, 116, 105, 110, 117, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  108, 115, 101, 10, 45, 108, 91, 45, 49, 93, 32, 45, 115, 112, 108, 105,
  116, 32, 43, 44, 51, 50, 44, 51, 53, 32, 45, 105, 102, 32, 123, 64,
  35, 62, 50, 125, 32, 45, 107, 91, 48, 93, 32, 45, 101, 110, 100, 105,
  102, 32, 45, 97, 32, 121, 32, 45, 101, 110, 100, 108, 10, 45, 97, 117,
  116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 51, 50, 32, 45, 105,
  102, 32, 123, 33, 119, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  99, 111, 110, 116, 105, 110, 117, 101, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48,
  32, 45, 100, 111, 110, 101, 10, 45, 105, 91, 49, 45, 45, 50, 93, 32,
  40, 49, 48, 41, 32, 45, 97, 32, 121, 10, 45, 118, 32, 43, 32, 45,
  101, 91, 93, 32, 34, 92, 114, 32, 80, 114, 111, 99, 101, 115, 115, 32,
  58, 32, 49, 48, 48, 37, 34, 10, 99, 111, 109, 112, 114, 101, 115, 115,
  95, 103, 109, 105, 99, 95, 103, 105, 109, 112, 32, 58, 10, 45, 101, 91,
  93, 32, 34, 34, 32, 45, 118, 32, 45, 10, 104, 101, 97, 100, 95, 115,
  116, 100, 61, 123, 39, 34, 35, 64, 103, 105, 109, 112, 34, 39, 125, 10,
  45, 115, 32, 45, 44, 49, 48, 32, 78, 61, 64, 35, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 10, 45, 105, 102, 32, 123, 33, 40, 36,
  62, 37, 49, 48, 48, 41, 125, 32, 45, 118, 32, 43, 32, 45, 101, 91,
  93, 32, 34, 92, 114, 32, 32, 80, 114, 111, 99, 101, 115, 115, 32, 58,
  32, 34, 123, 114, 111, 117, 110, 100, 40, 36, 62, 47, 36, 78, 42, 49,
  48, 48, 41, 125, 37, 32, 45, 118, 32, 45, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 105, 61, 61, 123, 39, 35, 39, 125, 125,
  10, 104, 101, 97, 100, 61, 64, 123, 45, 49, 44, 48, 45, 123, 109, 105,
  110, 40, 53, 44, 104, 45, 49, 41, 125, 125, 10, 45, 105, 102, 32, 123,
  36, 104, 101, 97, 100, 39, 33, 61, 39, 36, 104, 101, 97, 100, 95, 115,
  116, 100, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 99, 111, 110,
  116, 105, 110, 117, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108,
  115, 101, 10, 45, 108, 91, 45, 49, 93, 32, 45, 115, 112, 108, 105, 116,
  32, 43, 44, 51, 50, 44, 51, 53, 32, 45, 105, 102, 32, 123, 64, 35,
  62, 50, 125, 32, 45, 107, 91, 48, 93, 32, 45, 101, 110, 100, 105, 102,
  32, 45, 97, 32, 121, 32, 45, 101, 110, 100, 108, 10, 45, 97, 117, 116,
  111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 51, 50, 32, 45, 105, 102,
  32, 123, 33, 119, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 99,
  111, 110, 116, 105, 110, 117, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32,
  45, 100, 111, 110, 101, 10, 45, 105, 91, 49, 45, 45, 50, 93, 32, 40,
  49, 48, 41, 32, 45, 97, 32, 121, 10, 45, 118, 32, 43, 32, 45, 101,
  91, 93, 32, 34, 92, 114, 32, 80, 114, 111, 99, 101, 115, 115, 32, 58,
  32, 49, 48, 48, 37, 34, 10, 100, 101, 99, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 100, 101,
  99, 105, 109, 97, 108, 32, 105, 110, 116, 101, 103, 101, 114, 34, 64, 123,
  45, 97, 114, 103, 92, 32, 49, 43, 40, 36, 35, 62, 49, 41, 44, 34,
  34, 44, 115, 125, 34, 32, 39, 36, 123, 94, 48, 125, 39, 32, 116, 111,
  32, 98, 105, 110, 97, 114, 121, 32, 39, 34, 64, 123, 45, 100, 101, 99,
  50, 98, 105, 110, 92, 32, 36, 123, 94, 48, 125, 125, 34, 39, 44, 10,
  111, 99, 116, 97, 108, 32, 39, 34, 64, 123, 45, 100, 101, 99, 50, 111,
  99, 116, 92, 32, 36, 123, 94, 48, 125, 125, 34, 39, 44, 32, 104, 101,
  120, 97, 100, 101, 99, 105, 109, 97, 108, 32, 39, 34, 64, 123, 45, 100,
  101, 99, 50, 104, 101, 120, 92, 32, 36, 123, 94, 48, 125, 125, 34, 39,
  32, 97, 110, 100, 32, 115, 116, 114, 105, 110, 103, 32, 39, 34, 64, 123,
  45, 100, 101, 99, 50, 115, 116, 114, 92, 32, 36, 123, 94, 48, 125, 125,
  34, 39, 46, 34, 10, 100, 101, 99, 50, 115, 116, 114, 32, 58, 10, 45,
  118, 32, 45, 32, 45, 117, 32, 123, 96, 36, 123, 94, 48, 125, 96, 125,
  32, 45, 118, 32, 43, 10, 100, 101, 99, 50, 98, 105, 110, 32, 58, 10,
  45, 118, 32, 45, 32, 114, 101, 115, 61, 64, 123, 45, 95, 36, 48, 92,
  32, 36, 49, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 35,
  45, 49, 125, 32, 114, 101, 115, 61, 36, 114, 101, 115, 44, 64, 123, 45,
  95, 36, 48, 92, 32, 64, 123, 45, 97, 114, 103, 92, 32, 36, 62, 43,
  50, 44, 36, 123, 94, 48, 125, 125, 125, 32, 45, 100, 111, 110, 101, 32,
  45, 117, 32, 36, 114, 101, 115, 32, 45, 118, 32, 43, 10, 95, 100, 101,
  99, 50, 98, 105, 110, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 105,
  115, 105, 110, 116, 40, 36, 49, 41, 10, 114, 101, 115, 61, 34, 34, 32,
  114, 61, 123, 97, 98, 115, 40, 36, 49, 41, 125, 10, 45, 100, 111, 32,
  114, 101, 115, 61, 123, 36, 114, 37, 50, 125, 36, 114, 101, 115, 32, 114,
  61, 123, 105, 110, 116, 40, 36, 114, 47, 50, 41, 125, 32, 45, 119, 104,
  105, 108, 101, 32, 36, 114, 10, 45, 117, 32, 64, 123, 45, 97, 114, 103,
  92, 32, 49, 43, 40, 36, 49, 62, 61, 48, 41, 44, 45, 44, 34, 34,
  125, 36, 114, 101, 115, 10, 100, 101, 99, 50, 104, 101, 120, 32, 58, 10,
  45, 118, 32, 45, 32, 114, 101, 115, 61, 64, 123, 45, 95, 36, 48, 92,
  32, 36, 49, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 35,
  45, 49, 125, 32, 114, 101, 115, 61, 36, 114, 101, 115, 44, 64, 123, 45,
  95, 36, 48, 92, 32, 64, 123, 45, 97, 114, 103, 92, 32, 36, 62, 43,
  50, 44, 36, 123, 94, 48, 125, 125, 125, 32, 45, 100, 111, 110, 101, 32,
  45, 117, 32, 36, 114, 101, 115, 32, 45, 118, 32, 43, 10, 95, 100, 101,
  99, 50, 104, 101, 120, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 105,
  115, 105, 110, 116, 40, 36, 49, 41, 10, 114, 101, 115, 61, 34, 34, 32,
  114, 61, 123, 97, 98, 115, 40, 36, 49, 41, 125, 10, 45, 100, 111, 32,
  114, 101, 115, 61, 64, 123, 45, 95, 100, 101, 99, 50, 104, 101, 120, 95,
  123, 36, 114, 37, 49, 54, 125, 125, 36, 114, 101, 115, 32, 114, 61, 123,
  105, 110, 116, 40, 36, 114, 47, 49, 54, 41, 125, 32, 45, 119, 104, 105,
  108, 101, 32, 36, 114, 10, 45, 117, 32, 64, 123, 45, 97, 114, 103, 92,
  32, 49, 43, 40, 36, 49, 62, 61, 48, 41, 44, 45, 44, 34, 34, 125,
  36, 114, 101, 115, 10, 95, 100, 101, 99, 50, 104, 101, 120, 95, 48, 32,
  58, 32, 45, 117, 32, 48, 10, 95, 100, 101, 99, 50, 104, 101, 120, 95,
  49, 32, 58, 32, 45, 117, 32, 49, 10, 95, 100, 101, 99, 50, 104, 101,
  120, 95, 50, 32, 58, 32, 45, 117, 32, 50, 10, 95, 100, 101, 99, 50,
  104, 101, 120, 95, 51, 32, 58, 32, 45, 117, 32, 51, 10, 95, 100, 101,
  99, 50, 104, 101, 120, 95, 52, 32, 58, 32, 45, 117, 32, 52, 10, 95,
  100, 101, 99, 50, 104, 101, 120, 95, 53, 32, 58, 32, 45, 117, 32, 53,
  10, 95, 100, 101, 99, 50, 104, 101, 120, 95, 54, 32, 58, 32, 45, 117,
  32, 54, 10, 95, 100, 101, 99, 50, 104, 101, 120, 95, 55, 32, 58, 32,
  45, 117, 32, 55, 10, 95, 100, 101, 99, 50, 104, 101, 120, 95, 56, 32,
  58, 32, 45, 117, 32, 56, 10, 95, 100, 101, 99, 50, 104, 101, 120, 95,
  57, 32, 58, 32, 45, 117, 32, 57, 10, 95, 100, 101, 99, 50, 104, 101,
  120, 95, 49, 48, 32, 58, 32, 45, 117, 32, 97, 10, 95, 100, 101, 99,
  50, 104, 101, 120, 95, 49, 49, 32, 58, 32, 45, 117, 32, 98, 10, 95,
  100, 101, 99, 50, 104, 101, 120, 95, 49, 50, 32, 58, 32, 45, 117, 32,
  99, 10, 95, 100, 101, 99, 50, 104, 101, 120, 95, 49, 51, 32, 58, 32,
  45, 117, 32, 100, 10, 95, 100, 101, 99, 50, 104, 101, 120, 95, 49, 52,
  32, 58, 32, 45, 117, 32, 101, 10, 95, 100, 101, 99, 50, 104, 101, 120,
  95, 49, 53, 32, 58, 32, 45, 117, 32, 102, 10, 100, 101, 99, 50, 111,
  99, 116, 32, 58, 10, 45, 118, 32, 45, 32, 114, 101, 115, 61, 64, 123,
  45, 95, 36, 48, 92, 32, 36, 49, 125, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 36, 35, 45, 49, 125, 32, 114, 101, 115, 61, 36, 114, 101,
  115, 44, 64, 123, 45, 95, 36, 48, 92, 32, 64, 123, 45, 97, 114, 103,
  92, 32, 36, 62, 43, 50, 44, 36, 123, 94, 48, 125, 125, 125, 32, 45,
  100, 111, 110, 101, 32, 45, 117, 32, 36, 114, 101, 115, 32, 45, 118, 32,
  43, 10, 95, 100, 101, 99, 50, 111, 99, 116, 32, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 105, 115, 105, 110, 116, 40, 36, 49, 41, 10, 114, 101,
  115, 61, 34, 34, 32, 114, 61, 123, 97, 98, 115, 40, 36, 49, 41, 125,
  10, 45, 100, 111, 32, 114, 101, 115, 61, 123, 36, 114, 37, 56, 125, 36,
  114, 101, 115, 32, 114, 61, 123, 105, 110, 116, 40, 36, 114, 47, 56, 41,
  125, 32, 45, 119, 104, 105, 108, 101, 32, 36, 114, 10, 45, 117, 32, 64,
  123, 45, 97, 114, 103, 92, 32, 49, 43, 40, 36, 49, 62, 61, 48, 41,
  44, 45, 44, 34, 34, 125, 36, 114, 101, 115, 10, 102, 97, 99, 116, 32,
  58, 32, 45, 99, 104, 101, 99, 107, 32, 105, 115, 105, 110, 116, 40, 36,
  49, 41, 10, 45, 118, 32, 45, 32, 114, 101, 115, 61, 49, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 49, 32, 114, 101, 115, 61, 123, 36, 114,
  101, 115, 42, 40, 36, 62, 43, 49, 41, 125, 32, 45, 100, 111, 110, 101,
  32, 45, 117, 32, 36, 114, 101, 115, 32, 45, 118, 32, 43, 10, 102, 105,
  108, 101, 95, 109, 118, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 77, 111, 118, 101, 32, 102, 105, 108, 101, 32, 39, 36, 49, 39, 32,
  116, 111, 32, 108, 111, 99, 97, 116, 105, 111, 110, 32, 39, 36, 50, 39,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 105, 102, 32, 64, 123, 45, 105,
  115, 95, 119, 105, 110, 100, 111, 119, 115, 125, 32, 45, 120, 32, 34, 109,
  111, 118, 101, 32, 34, 36, 49, 34, 32, 34, 36, 50, 32, 45, 101, 108,
  115, 101, 32, 45, 120, 32, 34, 109, 118, 32, 34, 36, 49, 34, 32, 34,
  36, 50, 32, 45, 101, 110, 100, 105, 102, 32, 45, 118, 32, 43, 10, 102,
  105, 108, 101, 95, 114, 97, 110, 100, 32, 58, 10, 45, 118, 32, 45, 10,
  45, 100, 111, 32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 64, 123, 45,
  112, 97, 116, 104, 95, 116, 109, 112, 125, 64, 123, 45, 102, 105, 108, 101,
  95, 115, 108, 97, 115, 104, 125, 103, 109, 105, 99, 64, 37, 123, 114, 111,
  117, 110, 100, 40, 63, 40, 48, 44, 57, 41, 41, 125, 123, 114, 111, 117,
  110, 100, 40, 63, 40, 48, 44, 57, 41, 41, 125, 123, 114, 111, 117, 110,
  100, 40, 63, 40, 48, 44, 57, 41, 41, 125, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 48, 44, 57, 41, 41, 125, 123, 114, 111, 117, 110, 100, 40,
  63, 40, 48, 44, 57, 41, 41, 125, 123, 114, 111, 117, 110, 100, 40, 63,
  40, 48, 44, 57, 41, 41, 125, 10, 45, 119, 104, 105, 108, 101, 32, 36,
  102, 105, 108, 101, 110, 97, 109, 101, 10, 45, 117, 32, 36, 102, 105, 108,
  101, 110, 97, 109, 101, 10, 45, 118, 32, 43, 10, 102, 105, 108, 101, 95,
  114, 109, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101,
  109, 111, 118, 101, 32, 102, 105, 108, 101, 32, 39, 36, 49, 39, 46, 34,
  10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 64, 123, 45, 105, 115, 95,
  119, 105, 110, 100, 111, 119, 115, 125, 10, 49, 32, 45, 110, 109, 91, 45,
  49, 93, 32, 34, 36, 49, 34, 32, 100, 105, 114, 61, 64, 123, 45, 49,
  44, 102, 125, 32, 98, 97, 115, 101, 61, 64, 123, 45, 49, 44, 98, 125,
  32, 101, 120, 116, 61, 64, 123, 45, 49, 44, 120, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 99, 111, 109, 61, 34, 34, 10, 45, 105, 102, 32,
  123, 110, 97, 114, 103, 40, 36, 100, 105, 114, 41, 125, 32, 99, 111, 109,
  61, 34, 99, 100, 32, 92, 34, 34, 36, 100, 105, 114, 34, 92, 92, 92,
  34, 32, 38, 38, 32, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 110, 97, 114, 103, 40, 36, 101, 120, 116, 41, 125, 32, 99,
  111, 109, 61, 36, 123, 99, 111, 109, 125, 34, 100, 101, 108, 32, 92, 34,
  34, 36, 98, 97, 115, 101, 46, 36, 101, 120, 116, 34, 92, 34, 34, 32,
  45, 101, 108, 115, 101, 32, 99, 111, 109, 61, 36, 123, 99, 111, 109, 125,
  34, 100, 101, 108, 32, 92, 34, 34, 36, 98, 97, 115, 101, 34, 92, 34,
  34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 120, 32, 36, 99, 111, 109,
  10, 45, 101, 108, 115, 101, 10, 45, 120, 32, 34, 114, 109, 32, 45, 102,
  32, 92, 34, 36, 49, 92, 34, 34, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 118, 32, 43, 10, 102, 105, 108, 101, 95, 115, 108, 97, 115, 104, 32,
  58, 10, 45, 118, 32, 45, 32, 45, 105, 102, 32, 64, 123, 45, 105, 115,
  95, 119, 105, 110, 100, 111, 119, 115, 125, 32, 45, 117, 32, 34, 92, 92,
  34, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 34, 47, 34, 32, 45,
  101, 110, 100, 105, 102, 32, 45, 118, 32, 43, 10, 102, 105, 108, 101, 110,
  97, 109, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36, 123, 49,
  61, 100, 101, 102, 97, 117, 108, 116, 125, 34, 10, 45, 118, 32, 45, 10,
  45, 105, 102, 32, 123, 36, 35, 61, 61, 49, 125, 32, 45, 117, 32, 34,
  36, 49, 34, 10, 45, 101, 108, 115, 101, 10, 40, 36, 123, 50, 45, 45,
  49, 125, 41, 32, 45, 110, 97, 109, 101, 91, 45, 49, 93, 32, 34, 36,
  49, 34, 32, 45, 117, 32, 64, 123, 45, 49, 44, 102, 125, 64, 123, 45,
  49, 44, 98, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 119, 125,
  10, 45, 117, 32, 64, 123, 125, 95, 123, 105, 110, 116, 40, 105, 47, 49,
  48, 48, 48, 48, 48, 41, 37, 49, 48, 125, 123, 105, 110, 116, 40, 105,
  47, 49, 48, 48, 48, 48, 41, 37, 49, 48, 125, 123, 105, 110, 116, 40,
  105, 47, 49, 48, 48, 48, 41, 37, 49, 48, 125, 123, 105, 110, 116, 40,
  105, 47, 49, 48, 48, 41, 37, 49, 48, 125, 123, 105, 110, 116, 40, 105,
  47, 49, 48, 41, 37, 49, 48, 125, 123, 105, 37, 49, 48, 125, 10, 45,
  115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 45, 49, 10, 45, 100, 111,
  110, 101, 10, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40, 123, 39, 64,
  123, 45, 49, 44, 120, 125, 39, 125, 41, 125, 32, 45, 117, 32, 64, 123,
  125, 46, 64, 123, 45, 49, 44, 120, 125, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 118, 32, 43, 10, 102, 105, 116, 114, 97, 116, 105, 111, 95, 119, 104,
  32, 58, 10, 45, 118, 32, 45, 32, 45, 105, 102, 32, 123, 36, 51, 42,
  36, 50, 62, 36, 49, 125, 32, 45, 117, 32, 123, 105, 110, 116, 40, 36,
  51, 42, 36, 50, 41, 125, 44, 36, 50, 32, 45, 101, 108, 115, 101, 32,
  45, 117, 32, 36, 49, 44, 123, 105, 110, 116, 40, 36, 49, 47, 36, 51,
  41, 125, 32, 45, 101, 110, 100, 105, 102, 32, 45, 118, 32, 43, 10, 102,
  105, 116, 115, 99, 114, 101, 101, 110, 32, 58, 32, 45, 99, 104, 101, 99,
  107, 32, 34, 36, 49, 62, 48, 32, 38, 38, 32, 36, 50, 62, 48, 32,
  38, 38, 32, 36, 123, 51, 61, 49, 125, 62, 48, 34, 10, 45, 118, 32,
  45, 10, 119, 61, 123, 105, 102, 40, 36, 51, 62, 49, 44, 36, 49, 43,
  36, 51, 44, 36, 49, 41, 125, 10, 104, 61, 123, 105, 102, 40, 36, 51,
  62, 49, 44, 36, 50, 43, 36, 51, 44, 36, 50, 41, 125, 10, 77, 119,
  61, 123, 105, 110, 116, 40, 48, 46, 56, 53, 42, 64, 123, 33, 44, 117,
  125, 41, 125, 10, 77, 104, 61, 123, 105, 110, 116, 40, 48, 46, 56, 53,
  42, 64, 123, 33, 44, 118, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36,
  119, 60, 49, 50, 56, 125, 32, 104, 61, 123, 105, 110, 116, 40, 36, 104,
  42, 49, 50, 56, 47, 36, 119, 41, 125, 32, 119, 61, 49, 50, 56, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 104, 60, 49,
  50, 56, 125, 32, 119, 61, 123, 105, 110, 116, 40, 36, 119, 42, 49, 50,
  56, 47, 36, 104, 41, 125, 32, 104, 61, 49, 50, 56, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 119, 62, 36, 77, 119, 125,
  32, 104, 61, 123, 109, 97, 120, 40, 49, 44, 105, 110, 116, 40, 36, 104,
  42, 36, 77, 119, 47, 36, 119, 41, 41, 125, 32, 119, 61, 36, 77, 119,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 104, 62,
  36, 77, 104, 125, 32, 119, 61, 123, 109, 97, 120, 40, 49, 44, 105, 110,
  116, 40, 36, 119, 42, 36, 77, 104, 47, 36, 104, 41, 41, 125, 32, 104,
  61, 36, 77, 119, 32, 45, 101, 110, 100, 105, 102, 10, 119, 61, 123, 109,
  97, 120, 40, 36, 119, 44, 49, 50, 56, 41, 125, 10, 104, 61, 123, 109,
  97, 120, 40, 36, 104, 44, 49, 50, 56, 41, 125, 10, 45, 117, 32, 36,
  119, 44, 36, 104, 10, 45, 118, 32, 43, 10, 103, 99, 100, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110, 116, 40, 36, 49,
  41, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 50, 41, 32, 38,
  38, 32, 36, 49, 42, 36, 50, 33, 61, 48, 34, 10, 45, 118, 32, 45,
  32, 45, 95, 103, 99, 100, 32, 123, 109, 97, 120, 40, 97, 98, 115, 40,
  36, 49, 41, 44, 97, 98, 115, 40, 36, 50, 41, 41, 125, 44, 123, 109,
  105, 110, 40, 97, 98, 115, 40, 36, 49, 41, 44, 97, 98, 115, 40, 36,
  50, 41, 41, 125, 32, 45, 118, 32, 43, 10, 95, 103, 99, 100, 32, 58,
  10, 114, 61, 123, 36, 49, 37, 36, 50, 125, 32, 45, 105, 102, 32, 36,
  114, 32, 45, 117, 32, 64, 123, 45, 95, 103, 99, 100, 92, 32, 36, 50,
  44, 36, 114, 125, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 36, 50,
  32, 45, 101, 110, 100, 105, 102, 10, 104, 101, 120, 32, 58, 10, 45, 118,
  32, 45, 32, 100, 101, 99, 61, 64, 123, 45, 104, 101, 120, 50, 100, 101,
  99, 92, 32, 36, 123, 94, 48, 125, 125, 32, 45, 118, 32, 43, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32,
  104, 101, 120, 97, 100, 101, 99, 105, 109, 97, 108, 32, 105, 110, 116, 101,
  103, 101, 114, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 40, 36,
  35, 62, 49, 41, 44, 115, 44, 34, 34, 125, 34, 32, 39, 36, 123, 94,
  48, 125, 39, 32, 116, 111, 32, 98, 105, 110, 97, 114, 121, 32, 39, 34,
  64, 123, 45, 100, 101, 99, 50, 98, 105, 110, 92, 32, 36, 100, 101, 99,
  125, 34, 39, 44, 10, 111, 99, 116, 97, 108, 32, 39, 34, 64, 123, 45,
  100, 101, 99, 50, 111, 99, 116, 92, 32, 36, 100, 101, 99, 125, 34, 39,
  44, 32, 100, 101, 99, 105, 109, 97, 108, 32, 39, 34, 36, 100, 101, 99,
  34, 39, 32, 97, 110, 100, 32, 115, 116, 114, 105, 110, 103, 32, 39, 34,
  64, 123, 45, 100, 101, 99, 50, 115, 116, 114, 92, 32, 36, 100, 101, 99,
  125, 34, 39, 46, 34, 10, 104, 101, 120, 50, 100, 101, 99, 32, 58, 10,
  45, 118, 32, 45, 32, 114, 101, 115, 61, 64, 123, 45, 95, 36, 48, 92,
  32, 36, 49, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 35,
  45, 49, 125, 32, 114, 101, 115, 61, 36, 114, 101, 115, 44, 64, 123, 45,
  95, 36, 48, 92, 32, 64, 123, 45, 97, 114, 103, 92, 32, 36, 62, 43,
  50, 44, 36, 123, 94, 48, 125, 125, 125, 32, 45, 100, 111, 110, 101, 32,
  45, 117, 32, 36, 114, 101, 115, 32, 45, 118, 32, 43, 10, 95, 104, 101,
  120, 50, 100, 101, 99, 32, 58, 10, 40, 123, 39, 64, 123, 45, 115, 116,
  114, 117, 110, 99, 97, 115, 101, 92, 32, 36, 49, 125, 39, 125, 41, 10,
  105, 115, 95, 110, 101, 103, 97, 116, 105, 118, 101, 61, 48, 10, 45, 105,
  102, 32, 123, 64, 123, 45, 49, 44, 48, 125, 61, 61, 52, 53, 125, 32,
  45, 122, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48, 37, 32, 105, 115,
  95, 110, 101, 103, 97, 116, 105, 118, 101, 61, 49, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 102, 91, 45, 49, 93, 32, 34, 105, 102, 40, 105, 62,
  61, 52, 56, 32, 38, 38, 32, 105, 60, 61, 53, 55, 44, 105, 45, 52,
  56, 44, 105, 102, 40, 105, 62, 61, 57, 55, 32, 38, 38, 32, 105, 60,
  61, 49, 48, 50, 44, 105, 45, 56, 55, 44, 110, 97, 110, 41, 41, 42,
  49, 54, 94, 40, 119, 45, 49, 45, 120, 41, 34, 10, 45, 117, 32, 123,
  105, 102, 40, 36, 105, 115, 95, 110, 101, 103, 97, 116, 105, 118, 101, 44,
  45, 49, 44, 49, 41, 42, 64, 123, 45, 49, 44, 43, 125, 125, 10, 45,
  114, 109, 91, 45, 49, 93, 10, 104, 101, 120, 50, 115, 116, 114, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 34, 34, 125, 10, 45,
  118, 32, 45, 10, 45, 105, 102, 32, 123, 33, 110, 97, 114, 103, 40, 34,
  36, 49, 34, 41, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101,
  110, 100, 105, 102, 10, 40, 123, 39, 36, 42, 39, 125, 41, 10, 45, 105,
  102, 32, 123, 119, 60, 50, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 117, 32, 34, 34, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 91, 45, 49, 93, 32, 50, 44, 123, 119,
  47, 50, 125, 44, 49, 44, 49, 44, 45, 49, 32, 45, 102, 91, 45, 49,
  93, 32, 39, 105, 102, 40, 105, 62, 61, 57, 55, 44, 105, 45, 56, 55,
  44, 105, 45, 52, 56, 41, 39, 32, 45, 102, 91, 45, 49, 93, 32, 39,
  105, 102, 40, 120, 61, 61, 48, 44, 105, 42, 49, 54, 43, 105, 40, 120,
  43, 49, 41, 44, 48, 41, 39, 32, 45, 99, 111, 108, 117, 109, 110, 115,
  91, 45, 49, 93, 32, 48, 10, 45, 117, 32, 64, 123, 45, 49, 44, 116,
  125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 118, 32, 43, 10, 105,
  109, 103, 50, 115, 116, 114, 32, 58, 10, 45, 118, 32, 45, 10, 45, 117,
  32, 34, 40, 34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 115, 125,
  32, 99, 61, 36, 62, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 100,
  125, 32, 122, 61, 36, 62, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  104, 125, 32, 121, 61, 36, 62, 10, 45, 45, 99, 114, 111, 112, 91, 45,
  49, 93, 32, 48, 44, 36, 121, 44, 36, 122, 44, 36, 99, 44, 49, 48,
  48, 37, 44, 36, 121, 44, 36, 122, 44, 36, 99, 10, 45, 117, 32, 64,
  123, 125, 64, 45, 49, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 105,
  102, 32, 123, 36, 121, 33, 61, 104, 45, 49, 125, 32, 45, 117, 32, 64,
  123, 125, 59, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 32, 64, 123,
  125, 10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 122, 33,
  61, 100, 45, 49, 125, 32, 45, 117, 32, 64, 123, 125, 47, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123,
  36, 99, 33, 61, 115, 45, 49, 125, 32, 45, 117, 32, 64, 123, 125, 94,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 117,
  32, 64, 123, 125, 34, 41, 34, 10, 45, 118, 32, 43, 10, 105, 109, 103,
  50, 116, 101, 120, 116, 32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36,
  123, 49, 61, 32, 125, 34, 10, 45, 118, 32, 45, 32, 45, 45, 108, 32,
  45, 115, 32, 121, 32, 45, 115, 32, 45, 44, 48, 32, 45, 121, 32, 120,
  32, 45, 105, 102, 32, 123, 64, 35, 62, 49, 125, 32, 45, 105, 91, 49,
  45, 45, 50, 93, 32, 40, 123, 39, 34, 36, 49, 34, 39, 125, 41, 32,
  45, 101, 110, 100, 105, 102, 32, 45, 97, 32, 120, 32, 45, 117, 32, 64,
  123, 48, 44, 116, 125, 32, 45, 114, 109, 32, 45, 101, 110, 100, 108, 32,
  45, 118, 32, 43, 10, 105, 109, 103, 56, 50, 104, 101, 120, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 110, 118, 101, 114, 116,
  32, 56, 98, 105, 116, 115, 45, 118, 97, 108, 117, 101, 100, 32, 118, 101,
  99, 116, 111, 114, 36, 63, 32, 105, 110, 116, 111, 32, 104, 101, 120, 97,
  100, 101, 99, 105, 109, 97, 108, 32, 114, 101, 112, 114, 101, 115, 101, 110,
  116, 97, 116, 105, 111, 110, 115, 32, 40, 97, 115, 99, 105, 105, 45, 101,
  110, 99, 111, 100, 101, 100, 41, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  109, 111, 100, 32, 50, 53, 54, 32, 45, 121, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 10, 45, 45, 102, 91, 36, 62, 93, 32, 39, 118,
  61, 105, 110, 116, 40, 105, 41, 38, 49, 53, 59, 118, 43, 105, 102, 40,
  118, 60, 49, 48, 44, 52, 56, 44, 56, 55, 41, 39, 10, 45, 102, 91,
  36, 62, 93, 32, 39, 118, 61, 105, 110, 116, 40, 105, 41, 62, 62, 52,
  59, 118, 43, 105, 102, 40, 118, 60, 49, 48, 44, 52, 56, 44, 56, 55,
  41, 39, 10, 45, 97, 91, 36, 62, 44, 45, 49, 93, 32, 120, 10, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 104, 101, 120, 50, 105, 109,
  103, 56, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111,
  110, 118, 101, 114, 116, 32, 104, 101, 120, 97, 100, 101, 99, 105, 109, 97,
  108, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 97, 116, 105, 111, 110,
  36, 63, 32, 40, 97, 115, 99, 105, 105, 45, 101, 110, 99, 111, 100, 101,
  100, 41, 32, 105, 110, 116, 111, 32, 56, 98, 105, 116, 115, 45, 118, 97,
  108, 117, 101, 100, 32, 118, 101, 99, 116, 111, 114, 115, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45,
  115, 91, 45, 49, 93, 32, 120, 44, 50, 32, 45, 102, 91, 45, 50, 44,
  45, 49, 93, 32, 39, 105, 102, 40, 105, 62, 61, 57, 55, 44, 105, 45,
  56, 55, 44, 105, 45, 52, 56, 41, 39, 32, 45, 42, 91, 45, 50, 93,
  32, 49, 54, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 109,
  118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 105, 115, 95, 51, 100, 32, 58, 10, 45, 118, 32, 45, 32,
  45, 117, 32, 49, 32, 45, 108, 32, 45, 99, 104, 101, 99, 107, 51, 100,
  32, 49, 32, 45, 111, 110, 102, 97, 105, 108, 32, 45, 117, 32, 48, 32,
  45, 101, 110, 100, 108, 32, 45, 118, 32, 43, 10, 105, 115, 95, 112, 101,
  114, 99, 101, 110, 116, 32, 58, 10, 45, 118, 32, 45, 32, 45, 117, 32,
  123, 97, 114, 103, 40, 45, 49, 44, 123, 39, 34, 36, 49, 34, 39, 125,
  41, 61, 61, 51, 55, 125, 32, 45, 118, 32, 43, 10, 105, 115, 95, 119,
  105, 110, 100, 111, 119, 115, 32, 58, 10, 45, 118, 32, 45, 32, 45, 117,
  32, 123, 110, 97, 114, 103, 40, 36, 79, 83, 41, 61, 61, 49, 34, 32,
  38, 38, 32, 34, 110, 97, 114, 103, 40, 36, 87, 73, 78, 68, 73, 82,
  41, 61, 61, 49, 125, 32, 45, 118, 32, 43, 10, 109, 97, 100, 32, 58,
  10, 45, 118, 32, 45, 32, 45, 45, 45, 91, 45, 49, 93, 32, 64, 123,
  45, 109, 101, 100, 91, 45, 49, 93, 125, 32, 45, 97, 98, 115, 91, 45,
  49, 93, 32, 45, 109, 101, 100, 91, 45, 49, 93, 32, 45, 117, 32, 123,
  49, 46, 52, 56, 50, 54, 42, 64, 123, 125, 125, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 118, 32, 43, 10, 109, 97, 120, 95, 119, 32, 58,
  10, 45, 118, 32, 45, 32, 45, 117, 32, 123, 97, 114, 103, 40, 49, 44,
  64, 123, 45, 95, 109, 97, 120, 95, 119, 104, 100, 115, 92, 32, 52, 125,
  41, 125, 32, 45, 118, 32, 43, 10, 109, 97, 120, 95, 104, 32, 58, 10,
  45, 118, 32, 45, 32, 45, 117, 32, 123, 97, 114, 103, 40, 50, 44, 64,
  123, 45, 95, 109, 97, 120, 95, 119, 104, 100, 115, 92, 32, 52, 125, 41,
  125, 32, 45, 118, 32, 43, 10, 109, 97, 120, 95, 100, 32, 58, 10, 45,
  118, 32, 45, 32, 45, 117, 32, 123, 97, 114, 103, 40, 51, 44, 64, 123,
  45, 95, 109, 97, 120, 95, 119, 104, 100, 115, 92, 32, 52, 125, 41, 125,
  32, 45, 118, 32, 43, 10, 109, 97, 120, 95, 115, 32, 58, 10, 45, 118,
  32, 45, 32, 45, 117, 32, 123, 97, 114, 103, 40, 52, 44, 64, 123, 45,
  95, 109, 97, 120, 95, 119, 104, 100, 115, 92, 32, 52, 125, 41, 125, 32,
  45, 118, 32, 43, 10, 109, 97, 120, 95, 119, 104, 32, 58, 10, 45, 118,
  32, 45, 32, 45, 95, 109, 97, 120, 95, 119, 104, 100, 115, 32, 50, 32,
  45, 118, 32, 43, 10, 109, 97, 120, 95, 119, 104, 100, 32, 58, 10, 45,
  118, 32, 45, 32, 45, 95, 109, 97, 120, 95, 119, 104, 100, 115, 32, 51,
  32, 45, 118, 32, 43, 10, 109, 97, 120, 95, 119, 104, 100, 115, 32, 58,
  10, 45, 118, 32, 45, 32, 45, 95, 109, 97, 120, 95, 119, 104, 100, 115,
  32, 52, 32, 45, 118, 32, 43, 10, 95, 109, 97, 120, 95, 119, 104, 100,
  115, 32, 58, 10, 119, 61, 48, 32, 104, 61, 48, 32, 100, 61, 48, 32,
  115, 61, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 119,
  61, 123, 109, 97, 120, 40, 36, 119, 44, 119, 41, 125, 10, 104, 61, 123,
  109, 97, 120, 40, 36, 104, 44, 104, 41, 125, 10, 100, 61, 123, 109, 97,
  120, 40, 36, 100, 44, 100, 41, 125, 10, 115, 61, 123, 109, 97, 120, 40,
  36, 115, 44, 115, 41, 125, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48,
  32, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 49, 62, 61,
  52, 125, 32, 45, 117, 32, 36, 119, 44, 36, 104, 44, 36, 100, 44, 36,
  115, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 51, 125, 32,
  45, 117, 32, 36, 119, 44, 36, 104, 44, 36, 100, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 61, 61, 50, 125, 32, 45, 117, 32, 36, 119, 44,
  36, 104, 10, 45, 101, 108, 115, 101, 32, 45, 117, 32, 36, 119, 10, 45,
  101, 110, 100, 105, 102, 10, 109, 101, 100, 32, 58, 10, 45, 118, 32, 45,
  32, 45, 45, 115, 111, 114, 116, 91, 45, 49, 93, 32, 45, 117, 32, 64,
  123, 45, 49, 44, 123, 119, 42, 104, 42, 100, 42, 115, 47, 50, 125, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 118, 32, 43, 10, 99, 111,
  108, 111, 114, 95, 109, 101, 100, 32, 58, 10, 45, 118, 32, 45, 32, 45,
  117, 32, 34, 34, 32, 115, 61, 34, 34, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 115, 125, 32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115,
  91, 45, 49, 93, 32, 36, 62, 32, 45, 117, 32, 64, 123, 125, 36, 115,
  64, 123, 45, 109, 101, 100, 91, 45, 49, 93, 125, 32, 115, 61, 44, 32,
  45, 114, 109, 91, 45, 49, 93, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 109, 105, 110, 95, 119, 32, 58, 10, 45, 118, 32, 45, 32,
  45, 117, 32, 123, 97, 114, 103, 40, 49, 44, 64, 123, 45, 95, 109, 105,
  110, 95, 119, 104, 100, 115, 92, 32, 52, 125, 41, 125, 32, 45, 118, 32,
  43, 10, 109, 105, 110, 95, 104, 32, 58, 10, 45, 118, 32, 45, 32, 45,
  117, 32, 123, 97, 114, 103, 40, 50, 44, 64, 123, 45, 95, 109, 105, 110,
  95, 119, 104, 100, 115, 92, 32, 52, 125, 41, 125, 32, 45, 118, 32, 43,
  10, 109, 105, 110, 95, 100, 32, 58, 10, 45, 118, 32, 45, 32, 45, 117,
  32, 123, 97, 114, 103, 40, 51, 44, 64, 123, 45, 95, 109, 105, 110, 95,
  119, 104, 100, 115, 92, 32, 52, 125, 41, 125, 32, 45, 118, 32, 43, 10,
  109, 105, 110, 95, 115, 32, 58, 10, 45, 118, 32, 45, 32, 45, 95, 109,
  105, 110, 95, 115, 32, 64, 123, 45, 95, 109, 105, 110, 95, 119, 104, 100,
  115, 92, 32, 52, 125, 32, 45, 118, 32, 43, 10, 95, 109, 105, 110, 95,
  115, 32, 58, 10, 45, 117, 32, 36, 52, 10, 109, 105, 110, 95, 119, 104,
  32, 58, 10, 45, 118, 32, 45, 32, 45, 95, 109, 105, 110, 95, 119, 104,
  100, 115, 32, 50, 32, 45, 118, 32, 43, 10, 109, 105, 110, 95, 119, 104,
  100, 32, 58, 10, 45, 118, 32, 45, 32, 45, 95, 109, 105, 110, 95, 119,
  104, 100, 115, 32, 51, 32, 45, 118, 32, 43, 10, 109, 105, 110, 95, 119,
  104, 100, 115, 32, 58, 10, 45, 118, 32, 45, 32, 45, 95, 109, 105, 110,
  95, 119, 104, 100, 115, 32, 52, 32, 45, 118, 32, 43, 10, 95, 109, 105,
  110, 95, 119, 104, 100, 115, 32, 58, 10, 119, 61, 123, 119, 125, 32, 104,
  61, 123, 104, 125, 32, 100, 61, 123, 100, 125, 32, 115, 61, 123, 115, 125,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 119, 61, 123, 109,
  105, 110, 40, 36, 119, 44, 119, 41, 125, 10, 104, 61, 123, 109, 105, 110,
  40, 36, 104, 44, 104, 41, 125, 10, 100, 61, 123, 109, 105, 110, 40, 36,
  100, 44, 100, 41, 125, 10, 115, 61, 123, 109, 105, 110, 40, 36, 115, 44,
  115, 41, 125, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100,
  111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 49, 62, 61, 52, 125, 32,
  45, 117, 32, 36, 119, 44, 36, 104, 44, 36, 100, 44, 36, 115, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 51, 125, 32, 45, 117, 32,
  36, 119, 44, 36, 104, 44, 36, 100, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 61, 61, 50, 125, 32, 45, 117, 32, 36, 119, 44, 36, 104, 10,
  45, 101, 108, 115, 101, 32, 45, 117, 32, 36, 119, 10, 45, 101, 110, 100,
  105, 102, 10, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 102, 105, 108,
  101, 110, 97, 109, 101, 32, 58, 10, 45, 118, 32, 45, 32, 40, 123, 39,
  34, 36, 49, 34, 39, 125, 41, 32, 45, 102, 91, 45, 49, 93, 32, 39,
  105, 102, 40, 105, 62, 61, 54, 53, 38, 38, 105, 60, 61, 57, 48, 44,
  105, 43, 51, 50, 44, 105, 102, 40, 105, 61, 61, 51, 50, 44, 57, 53,
  44, 105, 41, 41, 39, 32, 45, 117, 32, 64, 123, 45, 49, 44, 116, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 118, 32, 43, 10, 111, 99,
  116, 32, 58, 10, 45, 118, 32, 45, 32, 100, 101, 99, 61, 64, 123, 45,
  111, 99, 116, 50, 100, 101, 99, 92, 32, 36, 123, 94, 48, 125, 125, 32,
  45, 118, 32, 43, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111,
  110, 118, 101, 114, 116, 32, 111, 99, 116, 97, 108, 32, 105, 110, 116, 101,
  103, 101, 114, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 40, 36,
  35, 62, 49, 41, 44, 34, 34, 44, 115, 125, 34, 32, 39, 36, 123, 94,
  48, 125, 39, 32, 116, 111, 32, 98, 105, 110, 97, 114, 121, 32, 39, 34,
  64, 123, 45, 100, 101, 99, 50, 98, 105, 110, 92, 32, 36, 100, 101, 99,
  125, 34, 39, 44, 32, 100, 101, 99, 105, 109, 97, 108, 32, 39, 34, 36,
  100, 101, 99, 34, 39, 44, 10, 104, 101, 120, 97, 100, 101, 99, 105, 109,
  97, 108, 32, 39, 34, 64, 123, 45, 100, 101, 99, 50, 104, 101, 120, 92,
  32, 36, 100, 101, 99, 125, 34, 39, 32, 97, 110, 100, 32, 115, 116, 114,
  105, 110, 103, 32, 39, 34, 64, 123, 45, 100, 101, 99, 50, 115, 116, 114,
  92, 32, 36, 100, 101, 99, 125, 34, 39, 46, 34, 10, 111, 99, 116, 50,
  100, 101, 99, 32, 58, 10, 45, 118, 32, 45, 32, 114, 101, 115, 61, 64,
  123, 45, 95, 36, 48, 92, 32, 36, 49, 125, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 36, 35, 45, 49, 125, 32, 114, 101, 115, 61, 36, 114,
  101, 115, 44, 64, 123, 45, 95, 36, 48, 92, 32, 64, 123, 45, 97, 114,
  103, 92, 32, 36, 62, 43, 50, 44, 36, 123, 94, 48, 125, 125, 125, 32,
  45, 100, 111, 110, 101, 32, 45, 117, 32, 36, 114, 101, 115, 32, 45, 118,
  32, 43, 10, 95, 111, 99, 116, 50, 100, 101, 99, 32, 58, 10, 40, 123,
  39, 64, 123, 45, 115, 116, 114, 117, 110, 99, 97, 115, 101, 92, 32, 36,
  49, 125, 39, 125, 41, 10, 105, 115, 95, 110, 101, 103, 97, 116, 105, 118,
  101, 61, 48, 10, 45, 105, 102, 32, 123, 64, 123, 45, 49, 44, 48, 125,
  61, 61, 52, 53, 125, 32, 45, 122, 91, 45, 49, 93, 32, 49, 44, 49,
  48, 48, 37, 32, 105, 115, 95, 110, 101, 103, 97, 116, 105, 118, 101, 61,
  49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 102, 91, 45, 49, 93, 32,
  34, 105, 102, 40, 105, 62, 61, 52, 56, 32, 38, 38, 32, 105, 60, 61,
  53, 53, 44, 40, 105, 45, 52, 56, 41, 42, 56, 94, 40, 119, 45, 49,
  45, 120, 41, 44, 110, 97, 110, 41, 34, 10, 45, 117, 32, 123, 105, 102,
  40, 36, 105, 115, 95, 110, 101, 103, 97, 116, 105, 118, 101, 44, 45, 49,
  44, 49, 41, 42, 64, 123, 45, 49, 44, 43, 125, 125, 10, 45, 114, 109,
  91, 45, 49, 93, 10, 112, 97, 100, 105, 110, 116, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 50, 61, 52, 125, 10, 45, 118, 32, 45, 32,
  45, 117, 32, 34, 34, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 50,
  32, 45, 117, 32, 64, 123, 125, 123, 105, 110, 116, 40, 36, 49, 47, 49,
  48, 94, 36, 60, 41, 37, 49, 48, 125, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 112, 97, 116, 104, 95, 103, 105, 109, 112, 32, 58,
  10, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40, 123, 39, 36, 123, 71,
  73, 77, 80, 50, 95, 68, 73, 82, 69, 67, 84, 79, 82, 89, 125, 39,
  125, 41, 125, 32, 45, 117, 32, 36, 123, 71, 73, 77, 80, 50, 95, 68,
  73, 82, 69, 67, 84, 79, 82, 89, 125, 32, 45, 114, 101, 116, 117, 114,
  110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 110, 97,
  114, 103, 40, 123, 39, 36, 123, 85, 83, 69, 82, 80, 82, 79, 70, 73,
  76, 69, 125, 39, 125, 41, 125, 32, 45, 117, 32, 36, 123, 85, 83, 69,
  82, 80, 82, 79, 70, 73, 76, 69, 125, 10, 45, 101, 108, 105, 102, 32,
  123, 110, 97, 114, 103, 40, 123, 39, 36, 123, 72, 79, 77, 69, 125, 39,
  125, 41, 125, 32, 45, 117, 32, 36, 123, 72, 79, 77, 69, 125, 10, 45,
  101, 108, 115, 101, 32, 45, 117, 32, 34, 34, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 64, 123, 125, 47, 46, 103, 105, 109, 112, 45,
  50, 46, 56, 47, 112, 108, 117, 103, 105, 110, 114, 99, 32, 45, 117, 32,
  64, 123, 125, 47, 46, 103, 105, 109, 112, 45, 50, 46, 56, 10, 45, 101,
  108, 105, 102, 32, 64, 123, 125, 47, 46, 103, 105, 109, 112, 45, 50, 46,
  54, 47, 112, 108, 117, 103, 105, 110, 114, 99, 32, 45, 117, 32, 64, 123,
  125, 47, 46, 103, 105, 109, 112, 45, 50, 46, 54, 10, 45, 101, 108, 115,
  101, 32, 45, 117, 32, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109, 112,
  125, 10, 45, 101, 110, 100, 105, 102, 32, 45, 118, 32, 43, 10, 112, 97,
  116, 104, 95, 116, 109, 112, 32, 58, 10, 45, 118, 32, 45, 32, 45, 117,
  32, 34, 34, 10, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40, 123, 39,
  36, 123, 84, 77, 80, 125, 39, 125, 41, 125, 32, 45, 117, 32, 36, 123,
  84, 77, 80, 125, 10, 45, 101, 108, 105, 102, 32, 123, 110, 97, 114, 103,
  40, 123, 39, 36, 123, 84, 69, 77, 80, 125, 39, 125, 41, 125, 32, 45,
  117, 32, 36, 123, 84, 69, 77, 80, 125, 10, 45, 101, 108, 105, 102, 32,
  123, 110, 97, 114, 103, 40, 123, 39, 36, 123, 84, 77, 80, 68, 73, 82,
  125, 39, 125, 41, 125, 32, 45, 117, 32, 36, 123, 84, 77, 80, 68, 73,
  82, 125, 10, 45, 101, 108, 105, 102, 32, 123, 110, 97, 114, 103, 40, 123,
  39, 36, 123, 72, 79, 77, 69, 125, 39, 125, 41, 125, 32, 45, 117, 32,
  34, 47, 116, 109, 112, 34, 10, 45, 101, 108, 115, 101, 32, 45, 117, 32,
  34, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 112,
  97, 116, 104, 95, 117, 115, 101, 114, 32, 58, 10, 45, 118, 32, 45, 32,
  45, 117, 32, 34, 34, 10, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40,
  123, 39, 36, 123, 65, 80, 80, 68, 65, 84, 65, 125, 39, 125, 41, 125,
  32, 45, 117, 32, 36, 123, 65, 80, 80, 68, 65, 84, 65, 125, 10, 45,
  101, 108, 105, 102, 32, 123, 110, 97, 114, 103, 40, 123, 39, 36, 123, 72,
  79, 77, 69, 125, 39, 125, 41, 125, 32, 45, 117, 32, 36, 123, 72, 79,
  77, 69, 125, 10, 45, 101, 108, 115, 101, 32, 45, 117, 32, 34, 34, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 113, 117, 111, 116,
  101, 32, 58, 10, 45, 118, 32, 45, 32, 45, 117, 32, 34, 36, 42, 34,
  32, 45, 118, 32, 43, 10, 114, 101, 103, 105, 111, 110, 95, 102, 101, 97,
  116, 117, 114, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36, 123,
  51, 61, 48, 125, 34, 10, 45, 118, 32, 45, 10, 115, 61, 64, 123, 45,
  50, 44, 115, 125, 32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91,
  45, 49, 93, 32, 48, 32, 45, 61, 61, 91, 45, 49, 93, 32, 36, 49,
  32, 45, 94, 91, 45, 49, 93, 32, 45, 49, 32, 45, 45, 91, 45, 49,
  93, 32, 49, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 51, 93, 32,
  45, 43, 91, 45, 49, 93, 32, 91, 45, 51, 93, 10, 45, 108, 91, 45,
  49, 93, 10, 45, 115, 91, 45, 49, 93, 32, 45, 44, 105, 110, 102, 32,
  45, 97, 32, 121, 10, 45, 105, 102, 32, 64, 35, 32, 45, 114, 91, 45,
  49, 93, 32, 49, 44, 123, 104, 47, 36, 115, 125, 44, 49, 44, 36, 115,
  44, 45, 49, 32, 45, 117, 32, 36, 50, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 101, 108, 115, 101, 32, 45, 117, 32, 36, 51, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 10, 45, 118, 32, 43, 10,
  114, 101, 115, 101, 116, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 82, 101, 115, 101, 116, 32, 103, 108, 111, 98, 97, 108, 32, 112, 97,
  114, 97, 109, 101, 116, 101, 114, 115, 32, 111, 102, 32, 116, 104, 101, 32,
  105, 110, 116, 101, 114, 112, 114, 101, 116, 101, 114, 32, 101, 110, 118, 105,
  114, 111, 110, 109, 101, 110, 116, 46, 34, 10, 45, 118, 32, 45, 49, 32,
  45, 100, 98, 51, 100, 32, 45, 98, 51, 100, 32, 45, 109, 51, 100, 32,
  45, 109, 100, 51, 100, 32, 45, 102, 51, 100, 32, 45, 108, 51, 100, 32,
  45, 115, 108, 51, 100, 32, 45, 115, 115, 51, 100, 32, 45, 118, 10, 82,
  71, 66, 32, 58, 10, 45, 118, 32, 45, 32, 45, 117, 32, 123, 114, 111,
  117, 110, 100, 40, 63, 40, 50, 53, 53, 41, 41, 125, 44, 123, 114, 111,
  117, 110, 100, 40, 63, 40, 50, 53, 53, 41, 41, 125, 44, 123, 114, 111,
  117, 110, 100, 40, 63, 40, 50, 53, 53, 41, 41, 125, 32, 45, 118, 32,
  43, 10, 82, 71, 66, 65, 32, 58, 10, 45, 118, 32, 45, 32, 45, 117,
  32, 123, 114, 111, 117, 110, 100, 40, 63, 40, 50, 53, 53, 41, 41, 125,
  44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 50, 53, 53, 41, 41, 125,
  44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 50, 53, 53, 41, 41, 125,
  44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 50, 53, 53, 41, 41, 125,
  32, 45, 118, 32, 43, 10, 115, 116, 114, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 36, 49, 10, 45, 118, 32, 45, 32, 100, 101, 99, 61, 123, 39,
  36, 42, 39, 125, 32, 45, 118, 32, 43, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 111, 110, 118, 101, 114, 116, 32, 115, 116, 114, 105, 110,
  103, 32, 39, 36, 42, 39, 32, 116, 111, 32, 98, 105, 110, 97, 114, 121,
  32, 39, 34, 64, 123, 45, 100, 101, 99, 50, 98, 105, 110, 92, 32, 36,
  100, 101, 99, 125, 34, 39, 44, 32, 111, 99, 116, 97, 108, 32, 39, 34,
  64, 123, 45, 100, 101, 99, 50, 111, 99, 116, 92, 32, 36, 100, 101, 99,
  125, 34, 39, 44, 32, 100, 101, 99, 105, 109, 97, 108, 32, 39, 34, 36,
  100, 101, 99, 34, 39, 32, 97, 110, 100, 10, 104, 101, 120, 97, 100, 101,
  99, 105, 109, 97, 108, 32, 39, 34, 64, 123, 45, 100, 101, 99, 50, 104,
  101, 120, 92, 32, 36, 100, 101, 99, 125, 34, 39, 46, 34, 10, 115, 116,
  114, 50, 104, 101, 120, 32, 58, 10, 45, 118, 32, 45, 32, 40, 123, 39,
  34, 36, 42, 34, 39, 125, 41, 32, 45, 114, 111, 119, 115, 91, 45, 49,
  93, 32, 48, 44, 49, 32, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102,
  40, 121, 61, 61, 48, 44, 105, 110, 116, 40, 105, 47, 49, 54, 41, 44,
  105, 40, 120, 44, 121, 45, 49, 41, 37, 49, 54, 41, 39, 32, 45, 102,
  91, 45, 49, 93, 32, 39, 105, 102, 40, 105, 60, 61, 57, 44, 52, 56,
  43, 105, 44, 56, 55, 43, 105, 41, 39, 32, 45, 116, 114, 97, 110, 115,
  112, 111, 115, 101, 91, 45, 49, 93, 32, 45, 117, 32, 64, 123, 45, 49,
  44, 116, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 118, 32, 43,
  10, 115, 116, 114, 101, 115, 99, 32, 58, 10, 45, 118, 32, 45, 32, 40,
  36, 42, 41, 32, 45, 99, 91, 45, 49, 93, 32, 51, 50, 44, 50, 53,
  53, 32, 45, 121, 91, 45, 49, 93, 32, 91, 45, 49, 93, 10, 45, 102,
  91, 45, 50, 93, 32, 39, 105, 102, 40, 105, 61, 61, 51, 50, 124, 124,
  105, 61, 61, 51, 52, 124, 124, 105, 61, 61, 51, 54, 124, 124, 105, 61,
  61, 52, 52, 124, 124, 105, 61, 61, 54, 52, 124, 124, 105, 61, 61, 57,
  50, 124, 124, 105, 61, 61, 49, 50, 51, 124, 124, 105, 61, 61, 49, 50,
  53, 44, 57, 50, 44, 45, 49, 41, 39, 32, 45, 97, 91, 45, 50, 44,
  45, 49, 93, 32, 120, 10, 45, 100, 105, 115, 99, 97, 114, 100, 91, 45,
  49, 93, 32, 45, 49, 32, 45, 117, 32, 64, 123, 45, 49, 44, 116, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 118, 32, 43, 10, 115, 116,
  114, 99, 97, 116, 32, 58, 10, 45, 118, 32, 45, 32, 36, 61, 115, 32,
  114, 101, 115, 61, 34, 36, 49, 34, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 123, 36, 35, 45, 49, 125, 32, 114, 101, 115, 61, 36, 114, 101, 115,
  36, 123, 115, 123, 36, 62, 43, 50, 125, 125, 32, 45, 100, 111, 110, 101,
  10, 45, 117, 32, 36, 114, 101, 115, 32, 45, 118, 32, 43, 10, 115, 116,
  114, 99, 109, 112, 32, 58, 10, 45, 118, 32, 45, 32, 40, 48, 44, 123,
  39, 34, 36, 49, 34, 39, 125, 41, 32, 40, 123, 119, 125, 44, 123, 39,
  34, 36, 50, 34, 39, 125, 41, 32, 45, 61, 91, 45, 50, 93, 32, 123,
  119, 125, 32, 45, 45, 91, 45, 50, 44, 45, 49, 93, 32, 45, 97, 98,
  115, 91, 45, 49, 93, 32, 45, 117, 32, 123, 33, 64, 123, 45, 49, 44,
  43, 125, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 118, 32, 43,
  10, 115, 116, 114, 108, 101, 110, 32, 58, 10, 45, 118, 32, 45, 32, 40,
  123, 39, 34, 36, 49, 34, 39, 125, 41, 32, 45, 117, 32, 123, 119, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 118, 32, 43, 10, 115, 116,
  114, 114, 101, 112, 108, 97, 99, 101, 32, 58, 10, 45, 118, 32, 45, 10,
  108, 115, 61, 64, 123, 45, 115, 116, 114, 108, 101, 110, 92, 32, 34, 36,
  50, 34, 125, 10, 108, 114, 61, 123, 64, 123, 45, 115, 116, 114, 108, 101,
  110, 92, 32, 34, 36, 51, 34, 125, 45, 49, 125, 10, 45, 108, 91, 93,
  32, 40, 123, 39, 34, 36, 49, 34, 39, 125, 41, 32, 45, 115, 32, 43,
  44, 123, 39, 34, 36, 50, 34, 39, 125, 32, 45, 115, 32, 121, 44, 45,
  36, 108, 115, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  105, 102, 32, 123, 64, 123, 36, 62, 44, 116, 125, 39, 61, 61, 39, 34,
  36, 50, 34, 125, 32, 45, 114, 111, 119, 115, 91, 36, 62, 93, 32, 48,
  44, 36, 108, 114, 32, 45, 102, 91, 36, 62, 93, 32, 123, 39, 34, 36,
  51, 34, 39, 125, 32, 45, 101, 110, 100, 105, 102, 32, 45, 100, 111, 110,
  101, 10, 45, 97, 32, 121, 32, 45, 117, 32, 64, 123, 45, 49, 44, 116,
  125, 32, 45, 114, 109, 32, 45, 101, 110, 100, 108, 10, 45, 118, 32, 43,
  10, 115, 116, 114, 117, 110, 99, 97, 115, 101, 32, 58, 10, 45, 118, 32,
  45, 32, 40, 123, 39, 34, 36, 42, 34, 39, 125, 41, 32, 45, 43, 91,
  45, 49, 93, 32, 39, 105, 102, 40, 105, 62, 61, 54, 53, 38, 38, 105,
  60, 61, 57, 48, 44, 51, 50, 44, 48, 41, 39, 32, 45, 117, 32, 64,
  123, 45, 49, 44, 116, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  118, 32, 43, 10, 115, 116, 114, 118, 101, 114, 32, 58, 10, 45, 118, 32,
  45, 32, 40, 123, 39, 64, 46, 39, 125, 41, 32, 45, 114, 91, 45, 49,
  93, 32, 55, 32, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102, 40, 120,
  37, 50, 44, 123, 39, 46, 39, 125, 44, 105, 41, 39, 32, 45, 117, 32,
  64, 123, 45, 49, 44, 116, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 118, 32, 43, 10, 116, 105, 99, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 73, 110, 105, 116, 105, 97, 108, 105, 122, 101, 32, 116,
  105, 109, 101, 114, 46, 34, 10, 45, 118, 32, 45, 32, 45, 105, 102, 32,
  123, 33, 110, 97, 114, 103, 40, 36, 95, 95, 116, 105, 99, 112, 111, 115,
  41, 125, 32, 95, 95, 116, 105, 99, 112, 111, 115, 61, 48, 32, 45, 101,
  110, 100, 105, 102, 32, 95, 95, 116, 105, 99, 36, 95, 95, 116, 105, 99,
  112, 111, 115, 61, 64, 124, 32, 95, 95, 116, 105, 99, 112, 111, 115, 61,
  123, 36, 95, 95, 116, 105, 99, 112, 111, 115, 43, 49, 125, 32, 45, 118,
  32, 43, 10, 116, 111, 99, 32, 58, 10, 45, 118, 32, 45, 32, 95, 95,
  116, 105, 99, 112, 111, 115, 61, 123, 36, 95, 95, 116, 105, 99, 112, 111,
  115, 45, 49, 125, 32, 45, 118, 32, 43, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 69, 108, 97, 112, 115, 101, 100, 32, 116, 105, 109, 101, 32,
  58, 32, 34, 123, 95, 64, 124, 45, 36, 123, 95, 95, 116, 105, 99, 36,
  95, 95, 116, 105, 99, 112, 111, 115, 125, 125, 34, 32, 115, 34, 46, 10,
  118, 97, 114, 105, 97, 110, 99, 101, 95, 110, 111, 105, 115, 101, 32, 58,
  10, 45, 118, 32, 45, 32, 45, 45, 108, 97, 112, 108, 97, 99, 105, 97,
  110, 91, 45, 49, 93, 32, 45, 117, 32, 123, 64, 123, 45, 109, 97, 100,
  91, 45, 49, 93, 125, 47, 115, 113, 114, 116, 40, 105, 102, 40, 100, 61,
  61, 49, 44, 50, 48, 44, 52, 50, 41, 41, 125, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 118, 32, 43, 10, 103, 112, 116, 32, 58, 32, 45,
  115, 107, 105, 112, 32, 34, 36, 123, 49, 61, 104, 116, 116, 112, 115, 58,
  47, 47, 116, 115, 99, 104, 117, 109, 112, 101, 114, 108, 101, 46, 117, 115,
  101, 114, 115, 46, 103, 114, 101, 121, 99, 46, 102, 114, 47, 103, 112, 116,
  46, 114, 97, 119, 125, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50,
  61, 48, 125, 44, 36, 123, 51, 61, 48, 125, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 71, 101, 110, 101, 114, 97, 116, 101, 32, 115, 99, 111,
  114, 101, 32, 98, 111, 97, 114, 100, 32, 102, 111, 114, 32, 71, 80, 84,
  45, 108, 105, 107, 101, 32, 99, 104, 97, 109, 112, 105, 111, 110, 115, 104,
  105, 112, 32, 40, 71, 82, 69, 89, 67, 32, 80, 111, 107, 101, 114, 32,
  84, 111, 117, 114, 41, 44, 32, 102, 114, 111, 109, 32, 102, 105, 108, 101,
  32, 39, 36, 49, 39, 46, 34, 10, 45, 118, 32, 45, 10, 45, 114, 109,
  32, 45, 105, 32, 114, 97, 119, 58, 36, 49, 44, 117, 99, 104, 97, 114,
  32, 45, 115, 91, 45, 49, 93, 32, 45, 44, 49, 48, 32, 45, 116, 114,
  97, 110, 115, 112, 111, 115, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 105, 102, 32, 123, 105, 61, 61, 123, 39, 35, 39, 125,
  125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 108, 115, 101, 32,
  45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 101, 110, 100, 105, 102,
  32, 45, 100, 111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 32, 45, 44, 123, 39,
  92, 32, 39, 125, 10, 45, 105, 102, 32, 64, 35, 10, 45, 105, 102, 32,
  123, 64, 35, 33, 61, 52, 125, 32, 45, 101, 114, 114, 111, 114, 91, 48,
  45, 45, 52, 93, 32, 34, 73, 110, 118, 97, 108, 105, 100, 32, 115, 99,
  111, 114, 101, 32, 102, 105, 108, 101, 32, 40, 108, 105, 110, 101, 32, 34,
  123, 36, 62, 43, 49, 125, 34, 32, 100, 101, 102, 105, 110, 101, 115, 32,
  34, 64, 35, 34, 32, 105, 116, 101, 109, 115, 32, 105, 110, 115, 116, 101,
  97, 100, 32, 111, 102, 32, 52, 41, 46, 34, 32, 45, 101, 110, 100, 105,
  102, 10, 112, 108, 97, 121, 101, 114, 36, 62, 95, 110, 97, 109, 101, 61,
  64, 123, 48, 44, 116, 125, 10, 112, 108, 97, 121, 101, 114, 36, 62, 95,
  117, 114, 108, 61, 64, 123, 49, 44, 116, 125, 10, 112, 108, 97, 121, 101,
  114, 36, 62, 95, 102, 105, 108, 101, 61, 64, 123, 50, 44, 116, 125, 10,
  40, 64, 123, 51, 44, 116, 125, 41, 32, 45, 114, 109, 91, 48, 45, 51,
  93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 45, 43, 32, 49, 32, 45, 97, 32, 121, 44, 49,
  32, 45, 45, 32, 49, 10, 45, 105, 102, 32, 123, 36, 50, 62, 48, 125,
  32, 45, 122, 91, 45, 49, 93, 32, 123, 109, 97, 120, 40, 48, 44, 119,
  45, 36, 50, 41, 125, 44, 49, 48, 48, 37, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 50, 60, 48, 125, 32, 45, 122, 91, 45, 49, 93, 32, 123,
  119, 45, 49, 45, 40, 40, 119, 45, 49, 41, 37, 45, 36, 50, 41, 125,
  44, 49, 48, 48, 37, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 36, 50, 32, 45, 115, 32, 121, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 105, 102, 32, 123, 64, 123, 36, 60, 44, 77, 125,
  60, 48, 125, 10, 105, 61, 36, 60, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 123, 64, 35, 45, 36, 105, 125, 10, 112, 108, 97, 121, 101, 114, 123,
  36, 105, 43, 36, 62, 125, 95, 110, 97, 109, 101, 61, 36, 123, 112, 108,
  97, 121, 101, 114, 123, 36, 105, 43, 36, 62, 43, 49, 125, 95, 110, 97,
  109, 101, 125, 10, 112, 108, 97, 121, 101, 114, 123, 36, 105, 43, 36, 62,
  125, 95, 117, 114, 108, 61, 36, 123, 112, 108, 97, 121, 101, 114, 123, 36,
  105, 43, 36, 62, 43, 49, 125, 95, 117, 114, 108, 125, 10, 112, 108, 97,
  121, 101, 114, 123, 36, 105, 43, 36, 62, 125, 95, 102, 105, 108, 101, 61,
  36, 123, 112, 108, 97, 121, 101, 114, 123, 36, 105, 43, 36, 62, 43, 49,
  125, 95, 102, 105, 108, 101, 125, 10, 45, 100, 111, 110, 101, 10, 45, 114,
  109, 91, 36, 60, 93, 32, 45, 101, 110, 100, 105, 102, 32, 45, 100, 111,
  110, 101, 32, 45, 97, 32, 121, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  110, 109, 91, 45, 49, 93, 32, 115, 99, 111, 114, 101, 115, 10, 114, 111,
  119, 95, 104, 101, 105, 103, 104, 116, 61, 123, 105, 102, 40, 36, 50, 44,
  50, 52, 44, 52, 56, 41, 125, 10, 45, 45, 108, 91, 115, 99, 111, 114,
  101, 115, 93, 32, 45, 115, 32, 121, 32, 45, 109, 97, 120, 32, 45, 101,
  110, 100, 108, 32, 45, 45, 61, 61, 91, 115, 99, 111, 114, 101, 115, 44,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 110, 109, 91,
  45, 49, 93, 32, 119, 105, 110, 110, 101, 114, 115, 10, 45, 45, 108, 91,
  115, 99, 111, 114, 101, 115, 93, 32, 45, 114, 101, 112, 108, 97, 99, 101,
  91, 45, 49, 93, 32, 45, 49, 44, 49, 101, 56, 32, 45, 115, 32, 121,
  32, 45, 109, 105, 110, 32, 45, 101, 110, 100, 108, 32, 45, 45, 61, 61,
  91, 115, 99, 111, 114, 101, 115, 44, 45, 49, 93, 32, 45, 114, 109, 91,
  45, 50, 93, 10, 45, 110, 109, 91, 45, 49, 93, 32, 108, 111, 115, 101,
  114, 115, 10, 45, 45, 108, 91, 119, 105, 110, 110, 101, 114, 115, 93, 32,
  45, 115, 32, 121, 32, 45, 43, 32, 45, 101, 110, 100, 108, 10, 45, 110,
  109, 91, 45, 49, 93, 32, 110, 98, 95, 119, 105, 110, 110, 101, 114, 115,
  10, 45, 45, 108, 91, 108, 111, 115, 101, 114, 115, 93, 32, 45, 115, 32,
  121, 32, 45, 43, 32, 45, 101, 110, 100, 108, 10, 45, 110, 109, 91, 45,
  49, 93, 32, 110, 98, 95, 108, 111, 115, 101, 114, 115, 10, 45, 45, 108,
  91, 115, 99, 111, 114, 101, 115, 93, 32, 45, 115, 32, 120, 32, 45, 114,
  32, 50, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 48, 32, 45, 102,
  32, 39, 105, 102, 40, 120, 44, 121, 44, 105, 41, 39, 32, 45, 115, 111,
  114, 116, 32, 45, 44, 121, 10, 45, 114, 32, 51, 44, 49, 48, 48, 37,
  44, 49, 44, 49, 44, 48, 44, 48, 44, 49, 44, 48, 32, 45, 102, 32,
  39, 105, 102, 40, 120, 44, 105, 44, 121, 43, 49, 41, 39, 10, 45, 102,
  32, 39, 62, 105, 102, 40, 120, 44, 105, 44, 105, 102, 40, 105, 40, 49,
  44, 121, 41, 61, 61, 105, 40, 49, 44, 121, 45, 49, 41, 44, 105, 40,
  48, 44, 121, 45, 49, 41, 44, 105, 41, 41, 39, 10, 45, 109, 105, 114,
  114, 111, 114, 32, 120, 32, 45, 115, 111, 114, 116, 32, 43, 44, 121, 32,
  45, 122, 32, 49, 44, 50, 32, 45, 102, 32, 39, 105, 102, 40, 105, 40,
  48, 44, 121, 41, 61, 61, 45, 49, 44, 45, 49, 44, 105, 41, 39, 10,
  45, 122, 32, 49, 44, 49, 32, 45, 97, 32, 120, 32, 45, 101, 110, 100,
  108, 10, 45, 110, 109, 91, 45, 49, 93, 32, 114, 97, 110, 107, 115, 10,
  45, 114, 111, 117, 110, 100, 91, 115, 99, 111, 114, 101, 115, 93, 10, 45,
  45, 108, 91, 115, 99, 111, 114, 101, 115, 93, 32, 45, 115, 32, 120, 32,
  45, 100, 105, 115, 99, 97, 114, 100, 32, 45, 49, 32, 45, 102, 32, 104,
  32, 45, 114, 111, 119, 115, 32, 48, 32, 45, 97, 32, 120, 32, 45, 101,
  110, 100, 108, 10, 45, 110, 109, 91, 45, 49, 93, 32, 110, 98, 95, 112,
  108, 97, 121, 101, 114, 115, 10, 45, 45, 108, 91, 115, 99, 111, 114, 101,
  115, 93, 32, 45, 115, 32, 121, 32, 45, 109, 97, 120, 32, 45, 101, 110,
  100, 108, 10, 45, 110, 109, 91, 45, 49, 93, 32, 109, 97, 120, 95, 115,
  99, 111, 114, 101, 115, 10, 45, 45, 108, 91, 115, 99, 111, 114, 101, 115,
  93, 32, 45, 114, 101, 112, 108, 97, 99, 101, 91, 45, 49, 93, 32, 45,
  49, 44, 49, 101, 56, 32, 45, 115, 32, 121, 32, 45, 109, 105, 110, 32,
  45, 101, 110, 100, 108, 10, 45, 110, 109, 91, 45, 49, 93, 32, 109, 105,
  110, 95, 115, 99, 111, 114, 101, 115, 10, 45, 45, 108, 91, 115, 99, 111,
  114, 101, 115, 93, 32, 45, 103, 101, 32, 48, 32, 45, 115, 32, 120, 32,
  45, 43, 32, 45, 101, 110, 100, 108, 10, 45, 110, 109, 91, 45, 49, 93,
  32, 110, 98, 95, 103, 97, 109, 101, 115, 10, 45, 45, 108, 91, 115, 99,
  111, 114, 101, 115, 93, 32, 45, 110, 101, 113, 32, 45, 49, 32, 45, 115,
  32, 121, 32, 45, 42, 32, 39, 119, 45, 120, 39, 32, 45, 102, 32, 120,
  77, 32, 45, 97, 32, 121, 32, 45, 122, 32, 48, 44, 48, 32, 45, 101,
  110, 100, 108, 10, 45, 110, 109, 91, 45, 49, 93, 32, 102, 105, 114, 115,
  116, 95, 103, 97, 109, 101, 10, 45, 45, 108, 116, 91, 115, 99, 111, 114,
  101, 115, 93, 32, 48, 10, 45, 45, 108, 91, 45, 49, 93, 32, 45, 115,
  32, 120, 32, 45, 43, 32, 45, 101, 110, 100, 108, 32, 45, 45, 91, 45,
  49, 93, 32, 91, 102, 105, 114, 115, 116, 95, 103, 97, 109, 101, 93, 10,
  45, 108, 91, 45, 50, 93, 32, 45, 102, 32, 39, 105, 102, 40, 105, 44,
  105, 44, 45, 120, 41, 39, 32, 45, 115, 32, 121, 32, 45, 108, 97, 98,
  101, 108, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 110, 61,
  123, 64, 123, 36, 62, 44, 77, 125, 125, 32, 45, 105, 102, 32, 36, 110,
  32, 45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 36, 62, 93, 32,
  36, 110, 44, 49, 44, 36, 110, 32, 45, 101, 108, 115, 101, 32, 45, 102,
  91, 36, 62, 93, 32, 48, 32, 45, 101, 110, 100, 105, 102, 32, 45, 100,
  111, 110, 101, 10, 45, 114, 32, 49, 44, 49, 44, 49, 44, 49, 44, 50,
  32, 45, 97, 32, 121, 32, 45, 45, 32, 49, 32, 45, 109, 97, 120, 32,
  48, 32, 45, 114, 111, 117, 110, 100, 32, 45, 101, 110, 100, 108, 32, 45,
  42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 114, 111, 117, 110, 100, 91,
  45, 49, 93, 10, 45, 110, 109, 91, 45, 49, 93, 32, 97, 98, 115, 95,
  109, 97, 108, 117, 115, 10, 45, 45, 108, 91, 115, 99, 111, 114, 101, 115,
  93, 32, 45, 102, 32, 39, 105, 102, 40, 105, 61, 61, 45, 49, 44, 48,
  44, 105, 45, 49, 48, 48, 41, 39, 32, 45, 115, 32, 120, 32, 45, 43,
  32, 45, 101, 110, 100, 108, 10, 45, 105, 102, 32, 36, 51, 32, 45, 97,
  98, 115, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45,
  91, 45, 49, 93, 32, 91, 97, 98, 115, 95, 109, 97, 108, 117, 115, 93,
  10, 45, 45, 102, 91, 45, 49, 93, 32, 121, 32, 45, 97, 91, 45, 50,
  44, 45, 49, 93, 32, 120, 32, 45, 115, 111, 114, 116, 91, 45, 49, 93,
  32, 45, 44, 121, 10, 49, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44,
  39, 121, 43, 49, 39, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32,
  120, 32, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 120, 10,
  45, 102, 91, 45, 49, 93, 32, 39, 62, 105, 102, 40, 120, 44, 105, 44,
  105, 102, 40, 105, 40, 50, 44, 121, 41, 61, 61, 105, 40, 50, 44, 121,
  45, 49, 41, 44, 105, 40, 48, 44, 121, 45, 49, 41, 44, 105, 41, 41,
  39, 10, 45, 110, 109, 91, 45, 49, 93, 32, 114, 97, 110, 107, 10, 45,
  45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 45, 49, 44, 48, 44,
  48, 44, 48, 44, 50, 32, 45, 115, 111, 114, 116, 91, 45, 49, 93, 32,
  43, 44, 121, 32, 45, 99, 111, 108, 117, 109, 110, 115, 91, 45, 49, 93,
  32, 49, 44, 49, 48, 48, 37, 10, 45, 110, 109, 91, 45, 49, 93, 32,
  115, 99, 111, 114, 101, 10, 115, 117, 109, 95, 115, 99, 111, 114, 101, 61,
  64, 123, 115, 99, 111, 114, 101, 44, 43, 125, 10, 45, 45, 108, 91, 115,
  99, 111, 114, 101, 115, 93, 32, 45, 115, 32, 120, 32, 45, 109, 97, 120,
  32, 45, 45, 32, 49, 48, 48, 32, 45, 101, 110, 100, 108, 10, 45, 45,
  102, 91, 45, 49, 93, 32, 121, 32, 45, 97, 91, 45, 50, 44, 45, 49,
  93, 32, 120, 32, 45, 115, 111, 114, 116, 91, 45, 49, 93, 32, 45, 44,
  121, 10, 49, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 39, 121, 43,
  49, 39, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45,
  109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 120, 10, 45, 102, 91,
  45, 49, 93, 32, 39, 62, 105, 102, 40, 120, 44, 105, 44, 105, 102, 40,
  105, 40, 50, 44, 121, 41, 61, 61, 105, 40, 50, 44, 121, 45, 49, 41,
  44, 105, 40, 48, 44, 121, 45, 49, 41, 44, 105, 41, 41, 39, 10, 45,
  115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 45, 49, 44, 48, 44, 48,
  44, 48, 44, 50, 32, 45, 115, 111, 114, 116, 91, 45, 49, 93, 32, 43,
  44, 121, 32, 45, 99, 111, 108, 117, 109, 110, 115, 91, 45, 49, 93, 32,
  49, 44, 49, 48, 48, 37, 10, 45, 110, 109, 91, 45, 49, 93, 32, 98,
  101, 115, 116, 95, 115, 99, 111, 114, 101, 10, 45, 45, 108, 91, 115, 99,
  111, 114, 101, 115, 93, 32, 45, 99, 111, 108, 117, 109, 110, 115, 32, 48,
  44, 123, 119, 45, 50, 125, 32, 45, 102, 32, 39, 105, 102, 40, 105, 61,
  61, 45, 49, 44, 48, 44, 105, 45, 49, 48, 48, 41, 39, 32, 45, 115,
  32, 120, 32, 45, 43, 32, 45, 101, 110, 100, 108, 32, 45, 45, 91, 45,
  49, 93, 32, 91, 97, 98, 115, 95, 109, 97, 108, 117, 115, 93, 10, 45,
  105, 102, 32, 36, 51, 32, 45, 97, 98, 115, 91, 45, 49, 93, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 45, 102, 91, 45, 49, 93, 32, 121, 32,
  45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 115, 111, 114,
  116, 91, 45, 49, 93, 32, 45, 44, 121, 10, 49, 44, 49, 48, 48, 37,
  44, 49, 44, 49, 44, 39, 121, 43, 49, 39, 32, 45, 97, 91, 45, 50,
  44, 45, 49, 93, 32, 120, 32, 45, 109, 105, 114, 114, 111, 114, 91, 45,
  49, 93, 32, 120, 10, 45, 102, 91, 45, 49, 93, 32, 39, 62, 105, 102,
  40, 120, 44, 105, 44, 105, 102, 40, 105, 40, 50, 44, 121, 41, 61, 61,
  105, 40, 50, 44, 121, 45, 49, 41, 44, 105, 40, 48, 44, 121, 45, 49,
  41, 44, 105, 41, 41, 39, 10, 45, 115, 104, 105, 102, 116, 91, 45, 49,
  93, 32, 45, 49, 44, 48, 44, 48, 44, 48, 44, 50, 32, 45, 115, 111,
  114, 116, 91, 45, 49, 93, 32, 43, 44, 121, 32, 45, 99, 111, 108, 117,
  109, 110, 115, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48, 37, 10, 45,
  110, 109, 91, 45, 49, 93, 32, 112, 114, 101, 118, 105, 111, 117, 115, 95,
  115, 99, 111, 114, 101, 10, 45, 45, 108, 91, 115, 99, 111, 114, 101, 115,
  93, 32, 45, 102, 32, 39, 105, 102, 40, 105, 61, 61, 45, 49, 44, 48,
  44, 105, 45, 49, 48, 48, 41, 39, 32, 45, 115, 32, 120, 32, 45, 43,
  32, 45, 101, 110, 100, 108, 10, 45, 110, 109, 91, 45, 49, 93, 32, 99,
  104, 105, 112, 115, 10, 115, 117, 109, 95, 99, 104, 105, 112, 115, 61, 64,
  123, 99, 104, 105, 112, 115, 44, 43, 125, 10, 45, 118, 32, 43, 10, 45,
  101, 32, 34, 83, 117, 109, 32, 111, 102, 32, 99, 104, 105, 112, 115, 32,
  58, 32, 34, 36, 115, 117, 109, 95, 99, 104, 105, 112, 115, 10, 45, 101,
  32, 34, 83, 117, 109, 32, 111, 102, 32, 115, 99, 111, 114, 101, 115, 32,
  58, 32, 34, 36, 115, 117, 109, 95, 115, 99, 111, 114, 101, 10, 45, 118,
  32, 45, 10, 45, 45, 45, 91, 112, 114, 101, 118, 105, 111, 117, 115, 95,
  115, 99, 111, 114, 101, 44, 115, 99, 111, 114, 101, 93, 32, 45, 99, 111,
  108, 117, 109, 110, 115, 91, 45, 49, 93, 32, 49, 10, 45, 110, 109, 91,
  45, 49, 93, 32, 116, 114, 101, 110, 100, 10, 45, 45, 108, 91, 115, 99,
  111, 114, 101, 115, 93, 32, 45, 115, 32, 121, 32, 45, 100, 105, 115, 99,
  97, 114, 100, 32, 45, 49, 32, 45, 117, 110, 114, 111, 108, 108, 32, 120,
  32, 45, 45, 32, 49, 48, 48, 32, 45, 99, 117, 109, 117, 108, 32, 45,
  102, 32, 105, 77, 32, 45, 97, 32, 121, 32, 45, 122, 32, 48, 44, 48,
  32, 45, 101, 110, 100, 108, 10, 45, 45, 102, 91, 45, 49, 93, 32, 121,
  32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 115, 111,
  114, 116, 91, 45, 49, 93, 32, 45, 44, 121, 10, 49, 44, 49, 48, 48,
  37, 44, 49, 44, 49, 44, 39, 121, 43, 49, 39, 32, 45, 97, 91, 45,
  50, 44, 45, 49, 93, 32, 120, 32, 45, 109, 105, 114, 114, 111, 114, 91,
  45, 49, 93, 32, 120, 10, 45, 102, 91, 45, 49, 93, 32, 39, 62, 105,
  102, 40, 120, 44, 105, 44, 105, 102, 40, 105, 40, 50, 44, 121, 41, 61,
  61, 105, 40, 50, 44, 121, 45, 49, 41, 44, 105, 40, 48, 44, 121, 45,
  49, 41, 44, 105, 41, 41, 39, 10, 45, 115, 104, 105, 102, 116, 91, 45,
  49, 93, 32, 45, 49, 44, 48, 44, 48, 44, 48, 44, 50, 32, 45, 115,
  111, 114, 116, 91, 45, 49, 93, 32, 43, 44, 121, 32, 45, 99, 111, 108,
  117, 109, 110, 115, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48, 37, 10,
  45, 110, 109, 91, 45, 49, 93, 32, 104, 105, 103, 104, 101, 115, 116, 95,
  99, 104, 105, 112, 115, 10, 45, 45, 108, 91, 115, 99, 111, 114, 101, 115,
  93, 32, 45, 115, 32, 121, 32, 45, 100, 105, 115, 99, 97, 114, 100, 32,
  45, 49, 32, 45, 117, 110, 114, 111, 108, 108, 32, 120, 32, 45, 45, 32,
  49, 48, 48, 32, 45, 99, 117, 109, 117, 108, 32, 45, 102, 32, 105, 109,
  32, 45, 97, 32, 121, 32, 45, 122, 32, 48, 44, 48, 32, 45, 101, 110,
  100, 108, 10, 45, 45, 102, 91, 45, 49, 93, 32, 121, 32, 45, 97, 91,
  45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 115, 111, 114, 116, 91, 45,
  49, 93, 32, 45, 44, 121, 10, 49, 44, 49, 48, 48, 37, 44, 49, 44,
  49, 44, 39, 121, 43, 49, 39, 32, 45, 97, 91, 45, 50, 44, 45, 49,
  93, 32, 120, 32, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32,
  120, 10, 45, 102, 91, 45, 49, 93, 32, 39, 62, 105, 102, 40, 120, 44,
  105, 44, 105, 102, 40, 105, 40, 50, 44, 121, 41, 61, 61, 105, 40, 50,
  44, 121, 45, 49, 41, 44, 105, 40, 48, 44, 121, 45, 49, 41, 44, 105,
  41, 41, 39, 10, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 45,
  49, 44, 48, 44, 48, 44, 48, 44, 50, 32, 45, 115, 111, 114, 116, 91,
  45, 49, 93, 32, 43, 44, 121, 32, 45, 99, 111, 108, 117, 109, 110, 115,
  91, 45, 49, 93, 32, 49, 44, 49, 48, 48, 37, 10, 45, 110, 109, 91,
  45, 49, 93, 32, 108, 111, 119, 101, 115, 116, 95, 99, 104, 105, 112, 115,
  10, 45, 45, 45, 91, 115, 99, 111, 114, 101, 115, 93, 32, 91, 109, 105,
  110, 95, 115, 99, 111, 114, 101, 115, 93, 32, 91, 109, 97, 120, 95, 115,
  99, 111, 114, 101, 115, 93, 32, 45, 45, 91, 45, 49, 93, 32, 91, 109,
  105, 110, 95, 115, 99, 111, 114, 101, 115, 93, 32, 45, 47, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 49, 48, 48, 10,
  45, 108, 91, 45, 49, 93, 32, 45, 102, 32, 39, 105, 102, 40, 105, 60,
  48, 44, 45, 49, 44, 105, 41, 39, 32, 45, 115, 32, 121, 32, 45, 100,
  105, 115, 99, 97, 114, 100, 32, 45, 49, 32, 45, 102, 32, 39, 105, 102,
  40, 105, 97, 60, 48, 44, 48, 44, 105, 97, 41, 39, 32, 45, 114, 111,
  119, 115, 32, 48, 32, 45, 97, 32, 121, 32, 45, 114, 111, 117, 110, 100,
  32, 49, 32, 45, 101, 110, 100, 108, 10, 45, 45, 102, 91, 45, 49, 93,
  32, 121, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45,
  115, 111, 114, 116, 91, 45, 49, 93, 32, 45, 44, 121, 10, 49, 44, 49,
  48, 48, 37, 44, 49, 44, 49, 44, 121, 43, 49, 32, 45, 97, 91, 45,
  50, 44, 45, 49, 93, 32, 120, 32, 45, 109, 105, 114, 114, 111, 114, 91,
  45, 49, 93, 32, 120, 10, 45, 102, 91, 45, 49, 93, 32, 39, 62, 105,
  102, 40, 120, 44, 105, 44, 105, 102, 40, 105, 40, 50, 44, 121, 41, 61,
  61, 105, 40, 50, 44, 121, 45, 49, 41, 44, 105, 40, 48, 44, 121, 45,
  49, 41, 44, 105, 41, 41, 39, 10, 45, 115, 104, 105, 102, 116, 91, 45,
  49, 93, 32, 45, 49, 44, 48, 44, 48, 44, 48, 44, 50, 32, 45, 115,
  111, 114, 116, 91, 45, 49, 93, 32, 43, 44, 121, 32, 45, 99, 111, 108,
  117, 109, 110, 115, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48, 37, 10,
  45, 110, 109, 91, 45, 49, 93, 32, 112, 101, 114, 102, 111, 114, 109, 97,
  110, 99, 101, 10, 45, 45, 108, 91, 115, 99, 111, 114, 101, 115, 93, 32,
  45, 115, 32, 121, 32, 45, 100, 105, 115, 99, 97, 114, 100, 32, 45, 49,
  32, 45, 45, 32, 49, 48, 48, 32, 45, 114, 32, 49, 44, 49, 44, 49,
  44, 49, 44, 50, 32, 45, 97, 32, 121, 32, 45, 101, 110, 100, 108, 10,
  45, 45, 102, 91, 45, 49, 93, 32, 121, 32, 45, 97, 91, 45, 50, 44,
  45, 49, 93, 32, 120, 32, 45, 115, 111, 114, 116, 91, 45, 49, 93, 32,
  45, 44, 121, 10, 49, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 121,
  43, 49, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45,
  109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 120, 10, 45, 102, 91,
  45, 49, 93, 32, 39, 62, 105, 102, 40, 120, 44, 105, 44, 105, 102, 40,
  105, 40, 50, 44, 121, 41, 61, 61, 105, 40, 50, 44, 121, 45, 49, 41,
  44, 105, 40, 48, 44, 121, 45, 49, 41, 44, 105, 41, 41, 39, 10, 45,
  115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 45, 49, 44, 48, 44, 48,
  44, 48, 44, 50, 32, 45, 115, 111, 114, 116, 91, 45, 49, 93, 32, 43,
  44, 121, 32, 45, 99, 111, 108, 117, 109, 110, 115, 91, 45, 49, 93, 32,
  49, 44, 49, 48, 48, 37, 10, 45, 110, 109, 91, 45, 49, 93, 32, 97,
  118, 101, 114, 97, 103, 101, 10, 45, 45, 33, 61, 91, 115, 99, 111, 114,
  101, 115, 93, 32, 45, 49, 10, 45, 45, 42, 91, 108, 111, 115, 101, 114,
  115, 44, 110, 98, 95, 112, 108, 97, 121, 101, 114, 115, 93, 32, 45, 47,
  91, 45, 49, 93, 32, 91, 110, 98, 95, 108, 111, 115, 101, 114, 115, 93,
  10, 45, 45, 91, 45, 50, 44, 45, 49, 93, 32, 45, 108, 91, 45, 49,
  93, 32, 45, 115, 32, 120, 32, 45, 43, 32, 45, 101, 110, 100, 108, 32,
  45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 45, 42, 91, 45, 49,
  93, 32, 48, 46, 52, 10, 45, 45, 102, 91, 45, 49, 93, 32, 121, 32,
  45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 115, 111, 114,
  116, 91, 45, 49, 93, 32, 45, 44, 121, 10, 49, 44, 49, 48, 48, 37,
  44, 49, 44, 49, 44, 121, 43, 49, 32, 45, 97, 91, 45, 50, 44, 45,
  49, 93, 32, 120, 32, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93,
  32, 120, 10, 45, 102, 91, 45, 49, 93, 32, 39, 62, 105, 102, 40, 120,
  44, 105, 44, 105, 102, 40, 105, 40, 50, 44, 121, 41, 61, 61, 105, 40,
  50, 44, 121, 45, 49, 41, 44, 105, 40, 48, 44, 121, 45, 49, 41, 44,
  105, 41, 41, 39, 10, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32,
  45, 49, 44, 48, 44, 48, 44, 48, 44, 50, 32, 45, 115, 111, 114, 116,
  91, 45, 49, 93, 32, 43, 44, 121, 32, 45, 99, 111, 108, 117, 109, 110,
  115, 91, 45, 49, 93, 32, 49, 44, 49, 48, 48, 37, 10, 45, 110, 109,
  91, 45, 49, 93, 32, 99, 111, 102, 102, 101, 101, 95, 98, 97, 108, 97,
  110, 99, 101, 10, 45, 99, 111, 110, 101, 51, 100, 32, 49, 46, 53, 44,
  50, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 49, 44, 48,
  44, 57, 48, 32, 45, 98, 111, 120, 51, 100, 32, 52, 44, 49, 44, 48,
  32, 45, 43, 51, 100, 91, 45, 49, 93, 32, 48, 44, 45, 48, 46, 53,
  32, 45, 43, 51, 100, 91, 45, 50, 44, 45, 49, 93, 32, 45, 114, 51,
  100, 91, 45, 49, 93, 32, 48, 44, 49, 44, 48, 44, 49, 56, 48, 10,
  45, 99, 51, 100, 91, 45, 49, 93, 32, 45, 42, 51, 100, 91, 45, 49,
  93, 32, 49, 55, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32,
  49, 10, 49, 50, 56, 44, 49, 50, 56, 32, 45, 111, 98, 106, 101, 99,
  116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 53, 48, 37,
  44, 53, 48, 37, 44, 48, 44, 49, 44, 50, 32, 45, 110, 109, 91, 45,
  49, 93, 32, 97, 114, 114, 111, 119, 95, 101, 113, 95, 109, 97, 115, 107,
  10, 45, 45, 42, 91, 45, 49, 93, 32, 50, 48, 48, 32, 45, 45, 42,
  91, 45, 50, 93, 32, 50, 48, 48, 32, 45, 45, 42, 91, 45, 51, 93,
  32, 50, 48, 48, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 99,
  32, 45, 110, 109, 91, 45, 49, 93, 32, 97, 114, 114, 111, 119, 95, 101,
  113, 10, 45, 114, 51, 100, 91, 45, 51, 93, 32, 48, 44, 48, 44, 49,
  44, 51, 53, 10, 49, 50, 56, 44, 49, 50, 56, 32, 45, 111, 98, 106,
  101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 52, 93, 44, 53,
  48, 37, 44, 53, 48, 37, 44, 48, 44, 49, 44, 50, 32, 45, 110, 109,
  91, 45, 49, 93, 32, 97, 114, 114, 111, 119, 95, 117, 112, 95, 109, 97,
  115, 107, 10, 45, 45, 42, 91, 45, 49, 93, 32, 54, 52, 32, 45, 45,
  42, 91, 45, 50, 93, 32, 50, 53, 53, 32, 45, 45, 42, 91, 45, 51,
  93, 32, 54, 52, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 99,
  32, 45, 110, 109, 91, 45, 49, 93, 32, 97, 114, 114, 111, 119, 95, 117,
  112, 10, 45, 114, 51, 100, 91, 45, 53, 93, 32, 48, 44, 48, 44, 49,
  44, 45, 55, 48, 10, 49, 50, 56, 44, 49, 50, 56, 32, 45, 111, 98,
  106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 54, 93, 44,
  53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 49, 44, 50, 32, 45, 110,
  109, 91, 45, 49, 93, 32, 97, 114, 114, 111, 119, 95, 100, 111, 119, 110,
  95, 109, 97, 115, 107, 10, 45, 45, 42, 91, 45, 49, 93, 32, 50, 53,
  53, 32, 45, 45, 42, 91, 45, 50, 93, 32, 54, 52, 32, 45, 45, 42,
  91, 45, 51, 93, 32, 51, 50, 32, 45, 97, 91, 45, 51, 45, 45, 49,
  93, 32, 99, 32, 45, 110, 109, 91, 45, 49, 93, 32, 97, 114, 114, 111,
  119, 95, 100, 111, 119, 110, 10, 45, 100, 105, 108, 97, 116, 101, 91, 97,
  114, 114, 111, 119, 95, 101, 113, 95, 109, 97, 115, 107, 44, 97, 114, 114,
  111, 119, 95, 117, 112, 95, 109, 97, 115, 107, 44, 97, 114, 114, 111, 119,
  95, 100, 111, 119, 110, 95, 109, 97, 115, 107, 93, 32, 51, 10, 45, 114,
  109, 91, 45, 55, 93, 10, 98, 111, 97, 114, 100, 61, 64, 35, 10, 105,
  61, 64, 35, 10, 45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32,
  34, 82, 97, 110, 107, 34, 44, 52, 56, 44, 36, 114, 111, 119, 95, 104,
  101, 105, 103, 104, 116, 44, 49, 54, 44, 49, 44, 54, 10, 45, 95, 103,
  112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 32, 34, 44, 36, 114, 111,
  119, 95, 104, 101, 105, 103, 104, 116, 44, 36, 114, 111, 119, 95, 104, 101,
  105, 103, 104, 116, 44, 49, 54, 44, 49, 44, 54, 10, 45, 95, 103, 112,
  116, 95, 102, 105, 101, 108, 100, 32, 34, 78, 97, 109, 101, 34, 44, 49,
  53, 48, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 49,
  54, 44, 49, 44, 54, 10, 45, 95, 103, 112, 116, 95, 102, 105, 101, 108,
  100, 32, 34, 83, 99, 111, 114, 101, 34, 44, 56, 48, 44, 36, 114, 111,
  119, 95, 104, 101, 105, 103, 104, 116, 44, 49, 54, 44, 49, 44, 54, 10,
  45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 67, 104, 105,
  112, 115, 92, 110, 91, 109, 97, 108, 117, 115, 93, 34, 44, 56, 48, 44,
  36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 50, 52, 44, 49,
  44, 54, 10, 45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 34,
  80, 108, 97, 121, 101, 100, 34, 44, 52, 56, 44, 36, 114, 111, 119, 95,
  104, 101, 105, 103, 104, 116, 44, 49, 50, 44, 49, 44, 54, 10, 45, 95,
  103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 87, 111, 110, 47, 92,
  110, 76, 111, 115, 116, 34, 44, 52, 56, 44, 36, 114, 111, 119, 95, 104,
  101, 105, 103, 104, 116, 44, 50, 52, 44, 49, 44, 54, 10, 45, 105, 102,
  32, 36, 50, 32, 45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32,
  34, 84, 114, 100, 34, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104,
  116, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 49, 50,
  44, 49, 44, 54, 10, 45, 101, 108, 115, 101, 32, 45, 95, 103, 112, 116,
  95, 102, 105, 101, 108, 100, 32, 34, 84, 114, 101, 110, 100, 34, 44, 36,
  114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 36, 114, 111, 119, 95,
  104, 101, 105, 103, 104, 116, 44, 49, 50, 44, 49, 44, 54, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 50, 32, 45, 95, 103, 112,
  116, 95, 102, 105, 101, 108, 100, 32, 34, 83, 116, 97, 116, 115, 34, 44,
  123, 50, 42, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 125, 44,
  36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 49, 50, 44, 49,
  44, 54, 10, 45, 101, 108, 115, 101, 32, 45, 95, 103, 112, 116, 95, 102,
  105, 101, 108, 100, 32, 34, 83, 116, 97, 116, 105, 115, 116, 105, 99, 115,
  34, 44, 123, 52, 42, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116,
  43, 50, 125, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44,
  49, 50, 44, 49, 44, 54, 10, 45, 101, 110, 100, 105, 102, 10, 45, 95,
  103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 76, 97, 115, 116, 92,
  110, 40, 114, 97, 110, 107, 41, 34, 44, 54, 52, 44, 36, 114, 111, 119,
  95, 104, 101, 105, 103, 104, 116, 44, 50, 52, 44, 49, 44, 54, 10, 45,
  95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 66, 101, 115, 116,
  92, 110, 40, 114, 97, 110, 107, 41, 34, 44, 54, 52, 44, 36, 114, 111,
  119, 95, 104, 101, 105, 103, 104, 116, 44, 50, 52, 44, 49, 44, 54, 10,
  45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 72, 105, 103,
  104, 101, 115, 116, 92, 110, 99, 104, 105, 112, 115, 32, 40, 114, 97, 110,
  107, 41, 34, 44, 54, 52, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103,
  104, 116, 44, 50, 52, 44, 49, 44, 54, 10, 45, 95, 103, 112, 116, 95,
  102, 105, 101, 108, 100, 32, 34, 76, 111, 119, 101, 115, 116, 92, 110, 99,
  104, 105, 112, 115, 32, 40, 114, 97, 110, 107, 41, 34, 44, 54, 52, 44,
  36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 50, 52, 44, 49,
  44, 54, 10, 45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 34,
  80, 101, 114, 102, 111, 114, 109, 97, 110, 99, 101, 92, 110, 32, 32, 32,
  40, 114, 97, 110, 107, 41, 34, 44, 54, 52, 44, 36, 114, 111, 119, 95,
  104, 101, 105, 103, 104, 116, 44, 50, 52, 44, 49, 44, 54, 10, 45, 95,
  103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 65, 118, 101, 114, 97,
  103, 101, 92, 110, 91, 115, 116, 100, 93, 32, 40, 114, 97, 110, 107, 41,
  34, 44, 49, 48, 48, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104,
  116, 44, 50, 52, 44, 49, 44, 54, 10, 45, 95, 103, 112, 116, 95, 102,
  105, 101, 108, 100, 32, 34, 67, 111, 102, 102, 101, 101, 32, 98, 97, 108,
  97, 110, 99, 101, 92, 110, 32, 32, 32, 32, 32, 40, 114, 97, 110, 107,
  41, 34, 44, 56, 48, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104,
  116, 44, 50, 52, 44, 49, 44, 54, 10, 45, 97, 91, 36, 105, 45, 45,
  49, 93, 32, 120, 10, 109, 97, 120, 95, 112, 108, 97, 121, 101, 114, 115,
  61, 64, 123, 110, 98, 95, 112, 108, 97, 121, 101, 114, 115, 44, 77, 125,
  10, 45, 45, 122, 91, 114, 97, 110, 107, 93, 32, 48, 44, 48, 32, 109,
  97, 120, 95, 114, 97, 110, 107, 61, 123, 105, 77, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 45, 122, 91, 112, 101, 114, 102, 111, 114, 109,
  97, 110, 99, 101, 93, 32, 49, 44, 49, 32, 109, 97, 120, 95, 112, 101,
  114, 102, 111, 114, 109, 97, 110, 99, 101, 95, 114, 97, 110, 107, 61, 123,
  105, 77, 45, 49, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 45,
  122, 91, 98, 101, 115, 116, 95, 115, 99, 111, 114, 101, 93, 32, 49, 44,
  49, 32, 109, 97, 120, 95, 98, 101, 115, 116, 95, 115, 99, 111, 114, 101,
  95, 114, 97, 110, 107, 61, 123, 105, 77, 45, 49, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 45, 122, 91, 97, 118, 101, 114, 97, 103, 101,
  93, 32, 49, 44, 49, 32, 109, 97, 120, 95, 97, 118, 101, 114, 97, 103,
  101, 95, 114, 97, 110, 107, 61, 123, 105, 77, 45, 49, 125, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 45, 122, 91, 99, 111, 102, 102, 101, 101,
  95, 98, 97, 108, 97, 110, 99, 101, 93, 32, 49, 44, 49, 32, 109, 97,
  120, 95, 99, 111, 102, 102, 101, 101, 95, 98, 97, 108, 97, 110, 99, 101,
  95, 114, 97, 110, 107, 61, 123, 105, 77, 125, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 123, 114, 97, 110,
  107, 44, 104, 125, 10, 112, 61, 64, 123, 114, 97, 110, 107, 44, 40, 49,
  44, 36, 62, 41, 125, 10, 110, 61, 64, 123, 110, 98, 95, 103, 97, 109,
  101, 115, 44, 40, 48, 44, 36, 112, 41, 125, 10, 99, 61, 123, 105, 102,
  40, 64, 123, 110, 98, 95, 103, 97, 109, 101, 115, 44, 40, 48, 44, 36,
  112, 41, 125, 61, 61, 48, 44, 48, 44, 118, 61, 64, 123, 115, 99, 111,
  114, 101, 44, 40, 49, 44, 36, 112, 41, 125, 59, 105, 102, 40, 118, 62,
  61, 49, 38, 38, 118, 60, 61, 51, 44, 118, 44, 105, 102, 40, 118, 61,
  61, 36, 109, 97, 120, 95, 114, 97, 110, 107, 45, 49, 44, 52, 44, 105,
  102, 40, 118, 61, 61, 36, 109, 97, 120, 95, 114, 97, 110, 107, 44, 53,
  44, 48, 41, 41, 41, 41, 125, 10, 105, 61, 64, 35, 10, 116, 95, 114,
  97, 110, 107, 61, 64, 123, 115, 99, 111, 114, 101, 44, 40, 49, 44, 36,
  112, 41, 125, 10, 45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32,
  36, 116, 95, 114, 97, 110, 107, 44, 52, 56, 44, 36, 114, 111, 119, 95,
  104, 101, 105, 103, 104, 116, 44, 49, 54, 44, 49, 44, 36, 99, 10, 45,
  105, 102, 32, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109, 112, 125, 47,
  36, 123, 112, 108, 97, 121, 101, 114, 36, 123, 112, 125, 95, 102, 105, 108,
  101, 125, 32, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109, 112, 125, 47,
  36, 123, 112, 108, 97, 121, 101, 114, 36, 123, 112, 125, 95, 102, 105, 108,
  101, 125, 10, 45, 101, 108, 115, 101, 32, 36, 123, 112, 108, 97, 121, 101,
  114, 36, 123, 112, 125, 95, 117, 114, 108, 125, 36, 123, 112, 108, 97, 121,
  101, 114, 36, 123, 112, 125, 95, 102, 105, 108, 101, 125, 32, 45, 111, 91,
  45, 49, 93, 32, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109, 112, 125,
  47, 36, 123, 112, 108, 97, 121, 101, 114, 36, 123, 112, 125, 95, 102, 105,
  108, 101, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 114,
  103, 98, 91, 45, 49, 93, 32, 45, 45, 91, 45, 49, 93, 32, 50, 53,
  53, 32, 45, 114, 114, 50, 100, 91, 45, 49, 93, 32, 123, 36, 114, 111,
  119, 95, 104, 101, 105, 103, 104, 116, 45, 50, 125, 44, 123, 36, 114, 111,
  119, 95, 104, 101, 105, 103, 104, 116, 45, 50, 125, 44, 50, 44, 50, 32,
  45, 43, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 102, 114, 97, 109,
  101, 91, 45, 49, 93, 32, 49, 44, 49, 44, 48, 10, 116, 95, 110, 97,
  109, 101, 61, 64, 123, 45, 95, 103, 112, 116, 95, 114, 101, 109, 111, 118,
  101, 95, 117, 110, 100, 101, 114, 115, 99, 111, 114, 101, 92, 32, 36, 123,
  112, 108, 97, 121, 101, 114, 36, 123, 112, 125, 95, 110, 97, 109, 101, 125,
  125, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32, 36, 116, 95, 110, 97,
  109, 101, 44, 48, 44, 48, 44, 51, 50, 44, 49, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 10, 45, 114, 91, 45, 49, 93, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 52, 10, 45, 115, 104,
  91, 45, 49, 93, 32, 48, 44, 50, 32, 45, 42, 91, 45, 49, 93, 32,
  39, 40, 50, 45, 99, 41, 42, 48, 46, 57, 42, 121, 47, 104, 39, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 100, 114, 111, 112, 95, 115, 104,
  97, 100, 111, 119, 91, 45, 49, 93, 32, 49, 44, 49, 44, 49, 10, 45,
  95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 32, 34, 44, 50,
  50, 53, 44, 123, 49, 46, 53, 42, 36, 114, 111, 119, 95, 104, 101, 105,
  103, 104, 116, 125, 44, 50, 48, 44, 49, 44, 36, 99, 32, 45, 109, 118,
  91, 45, 49, 93, 32, 45, 50, 10, 45, 98, 108, 101, 110, 100, 91, 45,
  50, 44, 45, 49, 93, 32, 97, 108, 112, 104, 97, 10, 45, 114, 50, 100,
  121, 91, 45, 49, 93, 32, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104,
  116, 10, 45, 122, 91, 45, 49, 93, 32, 49, 44, 49, 44, 123, 119, 45,
  50, 125, 44, 123, 104, 45, 50, 125, 32, 45, 102, 114, 97, 109, 101, 91,
  45, 49, 93, 32, 49, 44, 49, 44, 48, 10, 116, 95, 115, 99, 111, 114,
  101, 61, 64, 123, 115, 99, 111, 114, 101, 44, 40, 48, 44, 36, 112, 41,
  125, 10, 45, 105, 102, 32, 123, 36, 116, 95, 115, 99, 111, 114, 101, 62,
  48, 125, 32, 116, 95, 115, 99, 111, 114, 101, 61, 43, 36, 116, 95, 115,
  99, 111, 114, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103, 112,
  116, 95, 102, 105, 101, 108, 100, 32, 36, 116, 95, 115, 99, 111, 114, 101,
  44, 56, 48, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44,
  50, 48, 44, 36, 110, 44, 36, 99, 10, 116, 95, 99, 104, 105, 112, 115,
  61, 64, 123, 99, 104, 105, 112, 115, 44, 40, 48, 44, 36, 112, 41, 125,
  10, 116, 95, 109, 97, 108, 117, 115, 61, 123, 45, 64, 123, 97, 98, 115,
  95, 109, 97, 108, 117, 115, 44, 40, 48, 44, 36, 112, 41, 125, 125, 10,
  45, 105, 102, 32, 123, 36, 116, 95, 99, 104, 105, 112, 115, 62, 48, 125,
  32, 116, 95, 99, 104, 105, 112, 115, 61, 43, 36, 116, 95, 99, 104, 105,
  112, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103, 112, 116, 95,
  102, 105, 101, 108, 100, 32, 36, 116, 95, 99, 104, 105, 112, 115, 92, 32,
  91, 36, 116, 95, 109, 97, 108, 117, 115, 93, 44, 56, 48, 44, 36, 114,
  111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 49, 54, 44, 36, 110, 44,
  36, 99, 10, 116, 95, 110, 98, 95, 103, 97, 109, 101, 115, 61, 64, 123,
  110, 98, 95, 103, 97, 109, 101, 115, 44, 40, 48, 44, 36, 112, 41, 125,
  10, 45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 36, 116, 95,
  110, 98, 95, 103, 97, 109, 101, 115, 44, 52, 56, 44, 36, 114, 111, 119,
  95, 104, 101, 105, 103, 104, 116, 44, 49, 54, 44, 36, 110, 44, 36, 99,
  10, 45, 45, 114, 111, 119, 115, 91, 119, 105, 110, 110, 101, 114, 115, 93,
  32, 36, 112, 10, 116, 95, 119, 111, 110, 61, 64, 123, 45, 49, 44, 43,
  125, 10, 45, 45, 114, 111, 119, 115, 91, 108, 111, 115, 101, 114, 115, 93,
  32, 36, 112, 10, 116, 95, 108, 111, 115, 116, 61, 64, 123, 45, 49, 44,
  43, 125, 10, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 95,
  103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 36, 116, 95, 119, 111, 110,
  47, 36, 116, 95, 108, 111, 115, 116, 44, 52, 56, 44, 36, 114, 111, 119,
  95, 104, 101, 105, 103, 104, 116, 44, 49, 54, 44, 36, 110, 44, 36, 99,
  10, 45, 105, 102, 32, 123, 33, 36, 110, 125, 32, 123, 36, 114, 111, 119,
  95, 104, 101, 105, 103, 104, 116, 45, 50, 125, 44, 123, 36, 114, 111, 119,
  95, 104, 101, 105, 103, 104, 116, 45, 50, 125, 44, 49, 44, 51, 44, 50,
  53, 53, 32, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93, 32, 49, 44,
  49, 44, 48, 10, 45, 101, 108, 115, 101, 10, 116, 95, 116, 114, 101, 110,
  100, 61, 123, 45, 64, 123, 116, 114, 101, 110, 100, 44, 40, 48, 44, 36,
  112, 41, 125, 125, 10, 45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100,
  32, 34, 32, 34, 44, 49, 50, 56, 44, 49, 50, 56, 44, 49, 54, 44,
  36, 110, 44, 36, 99, 10, 45, 105, 102, 32, 123, 36, 116, 95, 116, 114,
  101, 110, 100, 62, 48, 125, 32, 116, 95, 116, 114, 101, 110, 100, 61, 43,
  36, 116, 95, 116, 114, 101, 110, 100, 32, 45, 106, 91, 45, 49, 93, 32,
  91, 97, 114, 114, 111, 119, 95, 117, 112, 93, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 49, 44, 91, 97, 114, 114, 111, 119, 95, 117, 112, 95, 109,
  97, 115, 107, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 116, 95, 116,
  114, 101, 110, 100, 60, 48, 125, 32, 45, 106, 91, 45, 49, 93, 32, 91,
  97, 114, 114, 111, 119, 95, 100, 111, 119, 110, 93, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 49, 44, 91, 97, 114, 114, 111, 119, 95, 100, 111, 119,
  110, 95, 109, 97, 115, 107, 93, 10, 45, 101, 108, 115, 101, 32, 45, 106,
  91, 45, 49, 93, 32, 91, 97, 114, 114, 111, 119, 95, 101, 113, 93, 44,
  48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 97, 114, 114, 111, 119,
  95, 101, 113, 95, 109, 97, 115, 107, 93, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 114, 50, 100, 121, 91, 45, 49, 93, 32, 36, 114, 111, 119, 95,
  104, 101, 105, 103, 104, 116, 10, 45, 105, 102, 32, 36, 50, 10, 45, 122,
  91, 45, 49, 93, 32, 49, 44, 49, 44, 123, 119, 45, 50, 125, 44, 123,
  104, 45, 50, 125, 32, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93, 32,
  49, 44, 49, 44, 48, 10, 45, 101, 108, 115, 101, 10, 45, 105, 102, 32,
  123, 36, 116, 95, 116, 114, 101, 110, 100, 62, 48, 125, 32, 45, 95, 103,
  112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 92, 110, 92, 110, 32, 32,
  32, 32, 34, 36, 116, 95, 116, 114, 101, 110, 100, 44, 36, 114, 111, 119,
  95, 104, 101, 105, 103, 104, 116, 44, 36, 114, 111, 119, 95, 104, 101, 105,
  103, 104, 116, 44, 52, 56, 44, 36, 110, 44, 48, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 116, 95, 116, 114, 101, 110, 100, 60, 48, 125, 32, 45,
  95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 34, 92, 110, 92, 110,
  34, 36, 116, 95, 116, 114, 101, 110, 100, 34, 32, 32, 32, 32, 32, 34,
  44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 36, 114, 111,
  119, 95, 104, 101, 105, 103, 104, 116, 44, 52, 56, 44, 36, 110, 44, 48,
  10, 45, 101, 108, 115, 101, 32, 45, 95, 103, 112, 116, 95, 102, 105, 101,
  108, 100, 32, 34, 32, 34, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103,
  104, 116, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 52,
  56, 44, 36, 110, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 47,
  91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 42, 91, 45, 50, 44, 45,
  49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 33, 36, 110, 125, 32, 123, 105, 102, 40, 36,
  50, 44, 50, 42, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44,
  52, 42, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 43, 50, 41,
  125, 44, 123, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 125, 44,
  49, 44, 51, 44, 50, 53, 53, 10, 45, 101, 108, 115, 101, 10, 123, 51,
  42, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 125, 44, 123, 49,
  46, 53, 42, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 125, 44,
  49, 44, 51, 44, 50, 53, 53, 10, 45, 45, 114, 111, 119, 115, 91, 114,
  97, 110, 107, 115, 93, 32, 36, 112, 44, 36, 112, 32, 45, 104, 105, 115,
  116, 111, 103, 114, 97, 109, 91, 45, 49, 93, 32, 36, 109, 97, 120, 95,
  112, 108, 97, 121, 101, 114, 115, 44, 49, 44, 36, 109, 97, 120, 95, 112,
  108, 97, 121, 101, 114, 115, 10, 45, 103, 114, 97, 112, 104, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 44, 51, 44, 48, 44, 48, 44, 48, 44, 48,
  46, 50, 44, 48, 44, 54, 52, 44, 50, 53, 53, 10, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 45, 114, 111, 119, 115, 91, 115, 99, 111, 114, 101,
  115, 93, 32, 36, 112, 10, 45, 100, 105, 115, 99, 97, 114, 100, 91, 45,
  49, 93, 32, 45, 49, 32, 45, 45, 91, 45, 49, 93, 32, 49, 48, 48,
  32, 45, 99, 117, 109, 117, 108, 91, 45, 49, 93, 32, 115, 97, 61, 123,
  105, 97, 125, 32, 115, 109, 61, 123, 105, 109, 125, 32, 115, 77, 61, 123,
  105, 77, 125, 10, 45, 103, 114, 105, 100, 91, 45, 50, 93, 32, 123, 109,
  97, 120, 40, 50, 48, 44, 49, 48, 48, 47, 109, 97, 120, 40, 49, 44,
  104, 45, 49, 41, 41, 125, 37, 44, 49, 48, 44, 48, 44, 48, 44, 48,
  46, 54, 44, 48, 120, 67, 67, 67, 67, 67, 67, 67, 67, 44, 48, 10,
  40, 48, 44, 48, 41, 32, 45, 103, 114, 97, 112, 104, 91, 45, 51, 93,
  32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 123, 36, 115, 77, 43, 49,
  48, 125, 44, 123, 36, 115, 109, 45, 49, 48, 125, 44, 49, 44, 48, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 40, 36, 115, 97, 44, 36, 115, 97,
  41, 32, 45, 103, 114, 97, 112, 104, 91, 45, 51, 93, 32, 91, 45, 49,
  93, 44, 49, 44, 48, 44, 123, 36, 115, 77, 43, 49, 48, 125, 44, 123,
  36, 115, 109, 45, 49, 48, 125, 44, 49, 44, 48, 120, 53, 53, 53, 53,
  53, 53, 53, 53, 44, 48, 44, 49, 53, 48, 44, 48, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 103, 114, 97, 112, 104, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 50, 44, 48, 44, 123, 36, 115, 77, 43, 49, 48,
  125, 44, 123, 36, 115, 109, 45, 49, 48, 125, 44, 49, 44, 50, 53, 53,
  44, 51, 50, 44, 52, 56, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  114, 50, 100, 121, 91, 45, 49, 93, 32, 123, 36, 114, 111, 119, 95, 104,
  101, 105, 103, 104, 116, 125, 10, 45, 105, 102, 32, 123, 33, 36, 50, 125,
  10, 49, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 49,
  44, 51, 44, 48, 10, 45, 45, 114, 111, 119, 115, 91, 114, 97, 110, 107,
  115, 93, 32, 36, 112, 32, 45, 104, 105, 115, 116, 111, 103, 114, 97, 109,
  91, 45, 49, 93, 32, 36, 109, 97, 120, 95, 112, 108, 97, 121, 101, 114,
  115, 44, 49, 44, 36, 109, 97, 120, 95, 112, 108, 97, 121, 101, 114, 115,
  32, 45, 121, 91, 45, 49, 93, 10, 105, 112, 61, 64, 35, 10, 40, 49,
  44, 49, 48, 44, 50, 53, 53, 44, 50, 52, 50, 44, 49, 53, 51, 41,
  10, 40, 50, 44, 49, 48, 44, 50, 50, 50, 44, 50, 50, 50, 44, 50,
  50, 50, 41, 10, 40, 51, 44, 49, 48, 44, 50, 51, 50, 44, 50, 48,
  57, 44, 49, 57, 54, 41, 10, 40, 123, 36, 109, 97, 120, 95, 112, 108,
  97, 121, 101, 114, 115, 45, 49, 125, 44, 49, 48, 44, 50, 53, 53, 44,
  50, 48, 52, 44, 50, 48, 52, 41, 10, 40, 36, 109, 97, 120, 95, 112,
  108, 97, 121, 101, 114, 115, 44, 49, 48, 44, 50, 53, 53, 44, 49, 53,
  51, 44, 49, 53, 51, 41, 10, 45, 105, 102, 32, 123, 36, 109, 97, 120,
  95, 112, 108, 97, 121, 101, 114, 115, 61, 61, 49, 125, 32, 45, 114, 109,
  91, 45, 52, 45, 45, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  109, 97, 120, 95, 112, 108, 97, 121, 101, 114, 115, 61, 61, 50, 125, 32,
  45, 114, 109, 91, 45, 51, 45, 45, 49, 93, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 109, 97, 120, 95, 112, 108, 97, 121, 101, 114, 115, 61, 61,
  51, 125, 32, 45, 114, 109, 91, 45, 50, 45, 45, 49, 93, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 109, 97, 120, 95, 112, 108, 97, 121, 101, 114,
  115, 61, 61, 52, 125, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 109, 97, 120, 95, 112, 108, 97, 121, 101, 114,
  115, 62, 53, 125, 32, 45, 97, 91, 45, 51, 44, 45, 50, 93, 32, 121,
  32, 45, 114, 91, 45, 50, 93, 32, 49, 48, 48, 37, 44, 123, 36, 109,
  97, 120, 95, 112, 108, 97, 121, 101, 114, 115, 45, 51, 125, 44, 49, 44,
  49, 44, 51, 32, 45, 114, 111, 117, 110, 100, 91, 45, 50, 93, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 97, 91, 36, 105, 112, 45, 45, 49, 93,
  32, 121, 10, 45, 106, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 49,
  44, 48, 32, 45, 114, 109, 91, 45, 50, 93, 10, 50, 53, 54, 44, 50,
  53, 54, 44, 49, 44, 51, 44, 50, 53, 53, 32, 45, 112, 105, 101, 99,
  104, 97, 114, 116, 91, 45, 49, 93, 32, 53, 55, 44, 48, 44, 48, 44,
  48, 44, 64, 45, 50, 44, 34, 97, 98, 115, 46, 34, 44, 123, 64, 123,
  115, 99, 111, 114, 101, 115, 44, 119, 125, 45, 64, 123, 110, 98, 95, 103,
  97, 109, 101, 115, 44, 40, 48, 44, 36, 112, 41, 125, 125, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 102, 114, 97, 109, 101,
  91, 45, 49, 93, 32, 49, 48, 44, 49, 48, 44, 50, 53, 53, 10, 49,
  44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 49, 44, 51,
  44, 48, 10, 50, 53, 54, 44, 50, 53, 54, 44, 49, 44, 51, 44, 50,
  53, 53, 32, 45, 112, 105, 101, 99, 104, 97, 114, 116, 91, 45, 49, 93,
  32, 53, 55, 44, 48, 44, 48, 44, 48, 44, 64, 45, 52, 32, 45, 102,
  114, 97, 109, 101, 91, 45, 49, 93, 32, 49, 48, 44, 49, 48, 44, 50,
  53, 53, 10, 45, 114, 109, 91, 45, 52, 93, 32, 45, 114, 50, 100, 121,
  91, 45, 51, 44, 45, 49, 93, 32, 36, 114, 111, 119, 95, 104, 101, 105,
  103, 104, 116, 10, 45, 97, 91, 45, 53, 45, 45, 49, 93, 32, 120, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 122,
  91, 45, 49, 93, 32, 49, 44, 49, 44, 123, 119, 45, 50, 125, 44, 123,
  104, 45, 50, 125, 32, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93, 32,
  49, 44, 49, 44, 48, 10, 116, 95, 108, 97, 115, 116, 95, 115, 99, 111,
  114, 101, 61, 64, 123, 115, 99, 111, 114, 101, 115, 44, 40, 49, 48, 48,
  37, 44, 36, 112, 41, 125, 10, 45, 105, 102, 32, 123, 36, 116, 95, 108,
  97, 115, 116, 95, 115, 99, 111, 114, 101, 61, 61, 45, 49, 125, 32, 116,
  95, 108, 97, 115, 116, 61, 97, 98, 115, 46, 10, 45, 101, 108, 115, 101,
  10, 116, 95, 108, 97, 115, 116, 95, 115, 99, 111, 114, 101, 61, 123, 36,
  116, 95, 108, 97, 115, 116, 95, 115, 99, 111, 114, 101, 45, 49, 48, 48,
  125, 10, 45, 105, 102, 32, 123, 36, 116, 95, 108, 97, 115, 116, 95, 115,
  99, 111, 114, 101, 62, 48, 125, 32, 116, 95, 108, 97, 115, 116, 95, 115,
  99, 111, 114, 101, 61, 43, 36, 116, 95, 108, 97, 115, 116, 95, 115, 99,
  111, 114, 101, 32, 45, 101, 110, 100, 105, 102, 10, 116, 95, 108, 97, 115,
  116, 95, 114, 97, 110, 107, 61, 64, 123, 114, 97, 110, 107, 115, 44, 40,
  49, 48, 48, 37, 44, 36, 112, 41, 125, 10, 116, 95, 108, 97, 115, 116,
  61, 36, 116, 95, 108, 97, 115, 116, 95, 115, 99, 111, 114, 101, 92, 32,
  40, 36, 116, 95, 108, 97, 115, 116, 95, 114, 97, 110, 107, 41, 10, 45,
  101, 110, 100, 105, 102, 10, 99, 61, 123, 118, 61, 64, 123, 114, 97, 110,
  107, 115, 44, 40, 49, 48, 48, 37, 44, 36, 112, 41, 125, 59, 105, 102,
  40, 118, 62, 61, 49, 38, 38, 118, 60, 61, 51, 44, 118, 44, 105, 102,
  40, 118, 61, 61, 64, 123, 110, 98, 95, 112, 108, 97, 121, 101, 114, 115,
  44, 45, 49, 125, 45, 49, 44, 52, 44, 105, 102, 40, 118, 61, 61, 64,
  123, 110, 98, 95, 112, 108, 97, 121, 101, 114, 115, 44, 45, 49, 125, 44,
  53, 44, 48, 41, 41, 41, 125, 10, 45, 95, 103, 112, 116, 95, 102, 105,
  101, 108, 100, 32, 36, 116, 95, 108, 97, 115, 116, 44, 54, 52, 44, 36,
  114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 49, 54, 44, 36, 110,
  44, 36, 99, 10, 116, 95, 98, 101, 115, 116, 95, 115, 99, 111, 114, 101,
  61, 123, 118, 61, 64, 123, 98, 101, 115, 116, 95, 115, 99, 111, 114, 101,
  44, 40, 48, 44, 36, 112, 41, 125, 59, 105, 102, 40, 118, 61, 61, 45,
  49, 44, 45, 49, 44, 118, 41, 125, 10, 116, 95, 98, 101, 115, 116, 95,
  114, 97, 110, 107, 61, 64, 123, 98, 101, 115, 116, 95, 115, 99, 111, 114,
  101, 44, 40, 49, 44, 36, 112, 41, 125, 10, 45, 105, 102, 32, 123, 36,
  116, 95, 98, 101, 115, 116, 95, 115, 99, 111, 114, 101, 62, 48, 125, 32,
  116, 95, 98, 101, 115, 116, 95, 115, 99, 111, 114, 101, 61, 43, 36, 116,
  95, 98, 101, 115, 116, 95, 115, 99, 111, 114, 101, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 116, 95, 98, 101, 115, 116, 95, 115, 99, 111, 114, 101,
  61, 61, 45, 49, 125, 32, 116, 95, 98, 101, 115, 116, 95, 115, 99, 111,
  114, 101, 61, 97, 98, 115, 46, 10, 45, 101, 110, 100, 105, 102, 10, 99,
  61, 123, 118, 61, 64, 123, 98, 101, 115, 116, 95, 115, 99, 111, 114, 101,
  44, 40, 49, 44, 36, 112, 41, 125, 59, 105, 102, 40, 118, 62, 61, 49,
  38, 38, 118, 60, 61, 51, 44, 118, 44, 105, 102, 40, 118, 61, 61, 36,
  109, 97, 120, 95, 98, 101, 115, 116, 95, 115, 99, 111, 114, 101, 95, 114,
  97, 110, 107, 45, 49, 44, 52, 44, 105, 102, 40, 118, 61, 61, 36, 109,
  97, 120, 95, 98, 101, 115, 116, 95, 115, 99, 111, 114, 101, 95, 114, 97,
  110, 107, 44, 53, 44, 48, 41, 41, 41, 125, 10, 45, 95, 103, 112, 116,
  95, 102, 105, 101, 108, 100, 32, 36, 116, 95, 98, 101, 115, 116, 95, 115,
  99, 111, 114, 101, 92, 32, 40, 36, 116, 95, 98, 101, 115, 116, 95, 114,
  97, 110, 107, 41, 44, 54, 52, 44, 36, 114, 111, 119, 95, 104, 101, 105,
  103, 104, 116, 44, 49, 54, 44, 36, 110, 44, 36, 99, 10, 116, 95, 104,
  105, 103, 104, 101, 115, 116, 95, 99, 104, 105, 112, 115, 61, 123, 118, 61,
  64, 123, 104, 105, 103, 104, 101, 115, 116, 95, 99, 104, 105, 112, 115, 44,
  40, 48, 44, 36, 112, 41, 125, 59, 105, 102, 40, 118, 61, 61, 45, 49,
  44, 45, 49, 44, 118, 41, 125, 10, 116, 95, 104, 105, 103, 104, 101, 115,
  116, 95, 114, 97, 110, 107, 61, 64, 123, 104, 105, 103, 104, 101, 115, 116,
  95, 99, 104, 105, 112, 115, 44, 40, 49, 44, 36, 112, 41, 125, 10, 45,
  105, 102, 32, 123, 36, 116, 95, 104, 105, 103, 104, 101, 115, 116, 95, 99,
  104, 105, 112, 115, 62, 48, 125, 32, 116, 95, 104, 105, 103, 104, 101, 115,
  116, 95, 99, 104, 105, 112, 115, 61, 43, 36, 116, 95, 104, 105, 103, 104,
  101, 115, 116, 95, 99, 104, 105, 112, 115, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 116, 95, 104, 105, 103, 104, 101, 115, 116, 95, 99, 104, 105, 112,
  115, 61, 61, 45, 49, 125, 32, 116, 95, 104, 105, 103, 104, 101, 115, 116,
  95, 99, 104, 105, 112, 115, 61, 97, 98, 115, 46, 10, 45, 101, 110, 100,
  105, 102, 10, 99, 61, 123, 118, 61, 64, 123, 104, 105, 103, 104, 101, 115,
  116, 95, 99, 104, 105, 112, 115, 44, 40, 49, 44, 36, 112, 41, 125, 59,
  105, 102, 40, 118, 62, 61, 49, 38, 38, 118, 60, 61, 51, 44, 118, 44,
  105, 102, 40, 118, 61, 61, 36, 109, 97, 120, 95, 98, 101, 115, 116, 95,
  115, 99, 111, 114, 101, 95, 114, 97, 110, 107, 45, 49, 44, 52, 44, 105,
  102, 40, 118, 61, 61, 36, 109, 97, 120, 95, 98, 101, 115, 116, 95, 115,
  99, 111, 114, 101, 95, 114, 97, 110, 107, 44, 53, 44, 48, 41, 41, 41,
  125, 10, 45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 36, 116,
  95, 104, 105, 103, 104, 101, 115, 116, 95, 99, 104, 105, 112, 115, 92, 32,
  40, 36, 116, 95, 104, 105, 103, 104, 101, 115, 116, 95, 114, 97, 110, 107,
  41, 44, 54, 52, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116,
  44, 49, 54, 44, 36, 110, 44, 36, 99, 10, 116, 95, 108, 111, 119, 101,
  115, 116, 95, 99, 104, 105, 112, 115, 61, 123, 118, 61, 64, 123, 108, 111,
  119, 101, 115, 116, 95, 99, 104, 105, 112, 115, 44, 40, 48, 44, 36, 112,
  41, 125, 59, 105, 102, 40, 118, 61, 61, 45, 49, 44, 45, 49, 44, 118,
  41, 125, 10, 116, 95, 108, 111, 119, 101, 115, 116, 95, 114, 97, 110, 107,
  61, 64, 123, 108, 111, 119, 101, 115, 116, 95, 99, 104, 105, 112, 115, 44,
  40, 49, 44, 36, 112, 41, 125, 10, 45, 105, 102, 32, 123, 36, 116, 95,
  108, 111, 119, 101, 115, 116, 95, 99, 104, 105, 112, 115, 62, 48, 125, 32,
  116, 95, 108, 111, 119, 101, 115, 116, 95, 99, 104, 105, 112, 115, 61, 43,
  36, 116, 95, 108, 111, 119, 101, 115, 116, 95, 99, 104, 105, 112, 115, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 116, 95, 108, 111, 119, 101, 115, 116,
  95, 99, 104, 105, 112, 115, 61, 61, 45, 49, 125, 32, 116, 95, 108, 111,
  119, 101, 115, 116, 95, 99, 104, 105, 112, 115, 61, 97, 98, 115, 46, 10,
  45, 101, 110, 100, 105, 102, 10, 99, 61, 123, 118, 61, 64, 123, 108, 111,
  119, 101, 115, 116, 95, 99, 104, 105, 112, 115, 44, 40, 49, 44, 36, 112,
  41, 125, 59, 105, 102, 40, 118, 62, 61, 49, 38, 38, 118, 60, 61, 51,
  44, 118, 44, 105, 102, 40, 118, 61, 61, 36, 109, 97, 120, 95, 112, 101,
  114, 102, 111, 114, 109, 97, 110, 99, 101, 95, 114, 97, 110, 107, 44, 52,
  44, 105, 102, 40, 118, 61, 61, 36, 109, 97, 120, 95, 112, 101, 114, 102,
  111, 114, 109, 97, 110, 99, 101, 95, 114, 97, 110, 107, 43, 49, 44, 53,
  44, 48, 41, 41, 41, 125, 10, 45, 95, 103, 112, 116, 95, 102, 105, 101,
  108, 100, 32, 36, 116, 95, 108, 111, 119, 101, 115, 116, 95, 99, 104, 105,
  112, 115, 92, 32, 40, 36, 116, 95, 108, 111, 119, 101, 115, 116, 95, 114,
  97, 110, 107, 41, 44, 54, 52, 44, 36, 114, 111, 119, 95, 104, 101, 105,
  103, 104, 116, 44, 49, 54, 44, 36, 110, 44, 36, 99, 10, 116, 95, 112,
  101, 114, 102, 111, 114, 109, 97, 110, 99, 101, 61, 64, 123, 112, 101, 114,
  102, 111, 114, 109, 97, 110, 99, 101, 44, 40, 48, 44, 36, 112, 41, 125,
  10, 116, 95, 112, 101, 114, 102, 111, 114, 109, 97, 110, 99, 101, 95, 114,
  97, 110, 107, 61, 64, 123, 112, 101, 114, 102, 111, 114, 109, 97, 110, 99,
  101, 44, 40, 49, 44, 36, 112, 41, 125, 10, 99, 61, 123, 118, 61, 64,
  123, 112, 101, 114, 102, 111, 114, 109, 97, 110, 99, 101, 44, 40, 49, 44,
  36, 112, 41, 125, 59, 105, 102, 40, 118, 62, 61, 49, 38, 38, 118, 60,
  61, 51, 44, 118, 44, 105, 102, 40, 118, 61, 61, 36, 109, 97, 120, 95,
  112, 101, 114, 102, 111, 114, 109, 97, 110, 99, 101, 95, 114, 97, 110, 107,
  45, 49, 44, 52, 44, 105, 102, 40, 118, 61, 61, 36, 109, 97, 120, 95,
  112, 101, 114, 102, 111, 114, 109, 97, 110, 99, 101, 95, 114, 97, 110, 107,
  44, 53, 44, 48, 41, 41, 41, 125, 10, 45, 95, 103, 112, 116, 95, 102,
  105, 101, 108, 100, 32, 36, 116, 95, 112, 101, 114, 102, 111, 114, 109, 97,
  110, 99, 101, 37, 92, 32, 40, 36, 116, 95, 112, 101, 114, 102, 111, 114,
  109, 97, 110, 99, 101, 95, 114, 97, 110, 107, 41, 44, 54, 52, 44, 36,
  114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 49, 54, 44, 36, 110,
  44, 36, 99, 10, 45, 45, 114, 111, 119, 115, 91, 115, 99, 111, 114, 101,
  115, 93, 32, 36, 112, 32, 45, 100, 105, 115, 99, 97, 114, 100, 91, 45,
  49, 93, 32, 45, 49, 10, 116, 95, 97, 118, 101, 114, 97, 103, 101, 61,
  123, 105, 102, 40, 105, 61, 61, 45, 49, 44, 48, 44, 114, 111, 117, 110,
  100, 40, 105, 97, 45, 49, 48, 48, 41, 41, 125, 10, 45, 105, 102, 32,
  123, 36, 116, 95, 97, 118, 101, 114, 97, 103, 101, 62, 48, 125, 32, 116,
  95, 97, 118, 101, 114, 97, 103, 101, 61, 43, 36, 116, 95, 97, 118, 101,
  114, 97, 103, 101, 32, 45, 101, 110, 100, 105, 102, 10, 116, 95, 97, 118,
  101, 114, 97, 103, 101, 95, 115, 116, 100, 61, 123, 105, 102, 40, 105, 61,
  61, 45, 49, 44, 48, 44, 114, 111, 117, 110, 100, 40, 115, 113, 114, 116,
  40, 105, 118, 41, 41, 41, 125, 10, 45, 114, 109, 91, 45, 49, 93, 10,
  116, 95, 97, 118, 101, 114, 97, 103, 101, 95, 114, 97, 110, 107, 61, 64,
  123, 97, 118, 101, 114, 97, 103, 101, 44, 40, 49, 44, 36, 112, 41, 125,
  10, 99, 61, 123, 118, 61, 64, 123, 97, 118, 101, 114, 97, 103, 101, 44,
  40, 49, 44, 36, 112, 41, 125, 59, 105, 102, 40, 118, 62, 61, 49, 38,
  38, 118, 60, 61, 51, 44, 118, 44, 105, 102, 40, 118, 61, 61, 36, 109,
  97, 120, 95, 97, 118, 101, 114, 97, 103, 101, 95, 114, 97, 110, 107, 45,
  49, 44, 52, 44, 105, 102, 40, 118, 61, 61, 36, 109, 97, 120, 95, 97,
  118, 101, 114, 97, 103, 101, 95, 114, 97, 110, 107, 44, 53, 44, 48, 41,
  41, 41, 125, 10, 45, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32,
  36, 116, 95, 97, 118, 101, 114, 97, 103, 101, 92, 32, 91, 36, 116, 95,
  97, 118, 101, 114, 97, 103, 101, 95, 115, 116, 100, 93, 92, 32, 40, 36,
  116, 95, 97, 118, 101, 114, 97, 103, 101, 95, 114, 97, 110, 107, 41, 44,
  49, 48, 48, 44, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44,
  49, 54, 44, 36, 110, 44, 36, 99, 10, 116, 95, 99, 111, 102, 102, 101,
  101, 95, 98, 97, 108, 97, 110, 99, 101, 61, 123, 95, 64, 123, 99, 111,
  102, 102, 101, 101, 95, 98, 97, 108, 97, 110, 99, 101, 44, 40, 48, 44,
  36, 112, 41, 125, 125, 10, 45, 105, 102, 32, 123, 36, 116, 95, 99, 111,
  102, 102, 101, 101, 95, 98, 97, 108, 97, 110, 99, 101, 62, 48, 125, 32,
  116, 95, 99, 111, 102, 102, 101, 101, 95, 98, 97, 108, 97, 110, 99, 101,
  61, 43, 36, 116, 95, 99, 111, 102, 102, 101, 101, 95, 98, 97, 108, 97,
  110, 99, 101, 32, 45, 101, 110, 100, 105, 102, 10, 116, 95, 99, 111, 102,
  102, 101, 101, 95, 114, 97, 110, 107, 61, 64, 123, 99, 111, 102, 102, 101,
  101, 95, 98, 97, 108, 97, 110, 99, 101, 44, 40, 49, 44, 36, 112, 41,
  125, 10, 99, 61, 123, 118, 61, 64, 123, 99, 111, 102, 102, 101, 101, 95,
  98, 97, 108, 97, 110, 99, 101, 44, 40, 49, 44, 36, 112, 41, 125, 59,
  105, 102, 40, 118, 62, 61, 49, 38, 38, 118, 60, 61, 51, 44, 118, 44,
  105, 102, 40, 118, 61, 61, 36, 109, 97, 120, 95, 99, 111, 102, 102, 101,
  101, 95, 98, 97, 108, 97, 110, 99, 101, 95, 114, 97, 110, 107, 45, 49,
  44, 52, 44, 105, 102, 40, 118, 61, 61, 36, 109, 97, 120, 95, 99, 111,
  102, 102, 101, 101, 95, 98, 97, 108, 97, 110, 99, 101, 95, 114, 97, 110,
  107, 44, 53, 44, 48, 41, 41, 41, 125, 10, 45, 95, 103, 112, 116, 95,
  102, 105, 101, 108, 100, 32, 36, 116, 95, 99, 111, 102, 102, 101, 101, 95,
  98, 97, 108, 97, 110, 99, 101, 92, 36, 92, 32, 40, 36, 116, 95, 99,
  111, 102, 102, 101, 101, 95, 114, 97, 110, 107, 41, 44, 56, 48, 44, 36,
  114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 44, 49, 54, 44, 36, 110,
  44, 36, 99, 10, 45, 105, 102, 32, 123, 33, 36, 110, 125, 32, 45, 102,
  91, 36, 105, 44, 123, 36, 105, 43, 50, 125, 45, 45, 49, 93, 32, 34,
  105, 42, 40, 48, 46, 55, 43, 48, 46, 51, 42, 40, 40, 40, 120, 43,
  121, 41, 37, 56, 41, 33, 61, 48, 41, 41, 34, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 97, 91, 36, 105, 45, 45, 49, 93, 32, 120, 10, 45,
  100, 111, 110, 101, 10, 97, 118, 103, 95, 110, 98, 95, 112, 108, 97, 121,
  101, 114, 115, 61, 123, 114, 111, 117, 110, 100, 40, 64, 123, 110, 98, 95,
  112, 108, 97, 121, 101, 114, 115, 44, 97, 125, 44, 48, 46, 53, 41, 125,
  10, 45, 105, 102, 32, 123, 36, 50, 61, 61, 48, 125, 32, 116, 95, 116,
  105, 116, 108, 101, 61, 34, 42, 42, 32, 71, 82, 69, 89, 67, 32, 80,
  111, 107, 101, 114, 32, 84, 111, 117, 114, 32, 42, 42, 32, 83, 101, 115,
  115, 105, 111, 110, 32, 92, 35, 34, 64, 123, 115, 99, 111, 114, 101, 115,
  44, 119, 125, 34, 32, 32, 32, 40, 97, 118, 103, 46, 32, 92, 35, 112,
  108, 97, 121, 101, 114, 32, 61, 32, 34, 36, 97, 118, 103, 95, 110, 98,
  95, 112, 108, 97, 121, 101, 114, 115, 34, 41, 34, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 50, 62, 48, 125, 32, 116, 95, 116, 105, 116, 108, 101,
  61, 34, 42, 42, 32, 71, 82, 69, 89, 67, 32, 80, 111, 107, 101, 114,
  32, 84, 111, 117, 114, 32, 42, 42, 32, 76, 97, 115, 116, 32, 34, 64,
  123, 115, 99, 111, 114, 101, 115, 44, 119, 125, 34, 32, 115, 101, 115, 115,
  105, 111, 110, 115, 32, 32, 40, 97, 118, 103, 46, 32, 92, 35, 112, 108,
  97, 121, 101, 114, 32, 61, 32, 34, 36, 97, 118, 103, 95, 110, 98, 95,
  112, 108, 97, 121, 101, 114, 115, 34, 41, 34, 10, 45, 101, 108, 115, 101,
  32, 116, 95, 116, 105, 116, 108, 101, 61, 34, 42, 42, 32, 71, 82, 69,
  89, 67, 32, 80, 111, 107, 101, 114, 32, 84, 111, 117, 114, 32, 42, 42,
  32, 83, 101, 115, 115, 105, 111, 110, 32, 92, 35, 34, 64, 123, 115, 99,
  111, 114, 101, 115, 44, 119, 125, 34, 47, 34, 123, 45, 36, 50, 125, 34,
  32, 40, 97, 118, 103, 46, 32, 92, 35, 112, 108, 97, 121, 101, 114, 32,
  61, 32, 34, 36, 97, 118, 103, 95, 110, 98, 95, 112, 108, 97, 121, 101,
  114, 115, 34, 41, 34, 10, 45, 101, 110, 100, 105, 102, 10, 48, 32, 45,
  116, 91, 45, 49, 93, 32, 36, 116, 95, 116, 105, 116, 108, 101, 44, 48,
  44, 48, 44, 53, 55, 44, 49, 44, 50, 53, 53, 32, 45, 114, 91, 45,
  49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 52,
  32, 45, 100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119, 91, 45, 49,
  93, 32, 53, 44, 53, 44, 50, 10, 45, 114, 50, 100, 121, 91, 45, 49,
  93, 32, 50, 52, 32, 45, 114, 91, 45, 49, 93, 32, 123, 64, 123, 36,
  98, 111, 97, 114, 100, 44, 119, 125, 45, 50, 125, 44, 123, 49, 46, 53,
  42, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 45, 50, 125, 44,
  49, 44, 52, 44, 48, 44, 48, 44, 48, 46, 53, 44, 123, 105, 102, 40,
  36, 50, 44, 48, 46, 57, 44, 48, 46, 54, 41, 125, 10, 45, 105, 91,
  45, 50, 93, 32, 49, 44, 51, 44, 49, 44, 51, 44, 51, 50, 44, 48,
  44, 54, 52, 44, 51, 50, 44, 54, 52, 44, 49, 50, 56, 44, 54, 52,
  44, 50, 48, 48, 44, 50, 53, 54, 32, 45, 114, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 91, 45, 49, 93, 44, 49, 44, 51, 44, 51, 32,
  45, 98, 108, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 97, 108,
  112, 104, 97, 10, 45, 105, 102, 32, 123, 36, 50, 62, 48, 125, 32, 45,
  115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44,
  49, 44, 50, 32, 45, 101, 108, 105, 102, 32, 123, 36, 50, 60, 48, 125,
  32, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 99, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93,
  32, 49, 44, 49, 44, 48, 10, 45, 109, 118, 91, 45, 49, 93, 32, 36,
  98, 111, 97, 114, 100, 10, 45, 105, 102, 32, 123, 33, 36, 50, 125, 10,
  45, 45, 99, 111, 108, 117, 109, 110, 115, 91, 115, 99, 111, 114, 101, 115,
  93, 32, 49, 48, 48, 37, 32, 45, 45, 102, 91, 45, 49, 93, 32, 121,
  32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 115, 111,
  114, 116, 91, 45, 49, 93, 32, 45, 44, 121, 10, 45, 102, 91, 45, 49,
  93, 32, 39, 105, 102, 40, 105, 40, 48, 44, 121, 41, 61, 61, 105, 40,
  48, 44, 48, 41, 44, 105, 44, 45, 49, 41, 39, 32, 45, 97, 117, 116,
  111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 45, 49, 32, 45, 110, 109,
  91, 45, 49, 93, 32, 115, 101, 115, 115, 105, 111, 110, 95, 119, 105, 110,
  110, 101, 114, 115, 10, 110, 98, 95, 115, 101, 115, 115, 105, 111, 110, 95,
  119, 105, 110, 110, 101, 114, 115, 61, 123, 104, 125, 10, 116, 95, 115, 101,
  115, 115, 105, 111, 110, 95, 119, 105, 110, 110, 101, 114, 115, 61, 34, 34,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 110, 98, 95, 115, 101, 115,
  115, 105, 111, 110, 95, 119, 105, 110, 110, 101, 114, 115, 10, 105, 61, 64,
  123, 115, 101, 115, 115, 105, 111, 110, 95, 119, 105, 110, 110, 101, 114, 115,
  44, 40, 49, 44, 36, 62, 41, 125, 10, 116, 95, 115, 101, 115, 115, 105,
  111, 110, 95, 119, 105, 110, 110, 101, 114, 115, 61, 36, 123, 112, 108, 97,
  121, 101, 114, 36, 123, 105, 125, 95, 110, 97, 109, 101, 125, 34, 95, 95,
  34, 36, 123, 116, 95, 115, 101, 115, 115, 105, 111, 110, 95, 119, 105, 110,
  110, 101, 114, 115, 125, 10, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109,
  112, 125, 47, 36, 123, 112, 108, 97, 121, 101, 114, 123, 64, 123, 115, 101,
  115, 115, 105, 111, 110, 95, 119, 105, 110, 110, 101, 114, 115, 44, 40, 49,
  44, 36, 62, 41, 125, 125, 95, 102, 105, 108, 101, 125, 32, 45, 45, 91,
  45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 114, 50, 100, 91, 45, 49,
  93, 32, 53, 54, 44, 53, 54, 44, 50, 44, 50, 32, 45, 43, 91, 45,
  49, 93, 32, 50, 53, 53, 32, 45, 102, 114, 97, 109, 101, 91, 45, 49,
  93, 32, 49, 44, 49, 44, 48, 10, 45, 100, 111, 110, 101, 10, 116, 95,
  115, 101, 115, 115, 105, 111, 110, 95, 119, 105, 110, 110, 101, 114, 115, 61,
  64, 123, 45, 95, 103, 112, 116, 95, 114, 101, 109, 111, 118, 101, 95, 117,
  110, 100, 101, 114, 115, 99, 111, 114, 101, 92, 32, 36, 116, 95, 115, 101,
  115, 115, 105, 111, 110, 95, 119, 105, 110, 110, 101, 114, 115, 125, 10, 48,
  32, 45, 116, 91, 45, 49, 93, 32, 34, 83, 101, 115, 115, 105, 111, 110,
  32, 119, 105, 110, 110, 101, 114, 34, 64, 123, 45, 105, 102, 92, 32, 123,
  36, 110, 98, 95, 115, 101, 115, 115, 105, 111, 110, 95, 119, 105, 110, 110,
  101, 114, 115, 61, 61, 49, 125, 92, 32, 45, 117, 92, 32, 92, 34, 92,
  34, 92, 32, 45, 101, 108, 115, 101, 92, 32, 45, 117, 92, 32, 115, 92,
  32, 45, 101, 110, 100, 105, 102, 125, 34, 32, 58, 32, 34, 36, 116, 95,
  115, 101, 115, 115, 105, 111, 110, 95, 119, 105, 110, 110, 101, 114, 115, 44,
  48, 44, 48, 44, 53, 55, 44, 49, 44, 50, 53, 53, 10, 45, 114, 91,
  45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44,
  52, 32, 45, 100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119, 91, 45,
  49, 93, 32, 53, 44, 53, 44, 50, 10, 45, 114, 50, 100, 121, 91, 45,
  49, 93, 32, 50, 52, 32, 45, 114, 91, 45, 49, 93, 32, 123, 64, 123,
  36, 98, 111, 97, 114, 100, 44, 119, 125, 45, 50, 125, 44, 123, 49, 46,
  53, 42, 36, 114, 111, 119, 95, 104, 101, 105, 103, 104, 116, 45, 50, 125,
  44, 49, 44, 52, 44, 48, 44, 48, 44, 48, 46, 49, 44, 48, 46, 53,
  10, 45, 105, 91, 45, 50, 93, 32, 49, 44, 50, 44, 49, 44, 51, 44,
  48, 44, 49, 50, 56, 44, 49, 50, 56, 44, 50, 53, 53, 44, 54, 52,
  44, 49, 50, 56, 32, 45, 114, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  44, 91, 45, 49, 93, 44, 49, 44, 51, 44, 51, 32, 45, 98, 108, 101,
  110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 97, 108, 112, 104, 97, 10,
  45, 105, 102, 32, 123, 36, 50, 62, 48, 125, 32, 45, 115, 104, 105, 102,
  116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 49, 44, 50, 32,
  45, 101, 108, 105, 102, 32, 123, 36, 50, 60, 48, 125, 32, 45, 109, 105,
  114, 114, 111, 114, 91, 45, 49, 93, 32, 99, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 110, 98, 95, 115, 101,
  115, 115, 105, 111, 110, 95, 119, 105, 110, 110, 101, 114, 115, 32, 45, 106,
  91, 45, 49, 93, 32, 91, 123, 45, 50, 45, 36, 60, 125, 93, 44, 123,
  119, 45, 54, 52, 45, 36, 62, 42, 54, 52, 125, 44, 55, 32, 45, 100,
  111, 110, 101, 10, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93, 32, 49,
  44, 49, 44, 48, 10, 45, 109, 118, 91, 45, 49, 93, 32, 123, 36, 98,
  111, 97, 114, 100, 43, 49, 125, 10, 45, 114, 109, 91, 45, 123, 36, 110,
  98, 95, 115, 101, 115, 115, 105, 111, 110, 95, 119, 105, 110, 110, 101, 114,
  115, 43, 49, 125, 45, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 33, 36, 50, 125, 10, 45, 45, 99, 111, 108, 117,
  109, 110, 115, 91, 108, 111, 115, 101, 114, 115, 93, 32, 49, 48, 48, 37,
  32, 45, 45, 102, 91, 45, 49, 93, 32, 121, 32, 45, 97, 91, 45, 50,
  44, 45, 49, 93, 32, 120, 32, 45, 115, 111, 114, 116, 91, 45, 49, 93,
  32, 45, 44, 121, 10, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102, 40,
  105, 40, 48, 44, 121, 41, 44, 105, 44, 45, 49, 41, 39, 32, 45, 97,
  117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 45, 49, 32, 45,
  110, 109, 91, 45, 49, 93, 32, 115, 101, 115, 115, 105, 111, 110, 95, 108,
  111, 115, 101, 114, 115, 10, 110, 98, 95, 115, 101, 115, 115, 105, 111, 110,
  95, 108, 111, 115, 101, 114, 115, 61, 123, 104, 125, 10, 116, 95, 115, 101,
  115, 115, 105, 111, 110, 95, 108, 111, 115, 101, 114, 115, 61, 34, 34, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 36, 110, 98, 95, 115, 101, 115, 115,
  105, 111, 110, 95, 108, 111, 115, 101, 114, 115, 10, 105, 61, 64, 123, 115,
  101, 115, 115, 105, 111, 110, 95, 108, 111, 115, 101, 114, 115, 44, 40, 49,
  44, 36, 62, 41, 125, 10, 116, 95, 115, 101, 115, 115, 105, 111, 110, 95,
  108, 111, 115, 101, 114, 115, 61, 36, 123, 112, 108, 97, 121, 101, 114, 36,
  123, 105, 125, 95, 110, 97, 109, 101, 125, 34, 95, 95, 34, 36, 123, 116,
  95, 115, 101, 115, 115, 105, 111, 110, 95, 108, 111, 115, 101, 114, 115, 125,
  10, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109, 112, 125, 47, 36, 123,
  112, 108, 97, 121, 101, 114, 123, 64, 123, 115, 101, 115, 115, 105, 111, 110,
  95, 108, 111, 115, 101, 114, 115, 44, 40, 49, 44, 36, 62, 41, 125, 125,
  95, 102, 105, 108, 101, 125, 32, 45, 45, 91, 45, 49, 93, 32, 50, 53,
  53, 32, 45, 114, 114, 50, 100, 91, 45, 49, 93, 32, 53, 54, 44, 53,
  54, 44, 50, 44, 50, 32, 45, 43, 91, 45, 49, 93, 32, 50, 53, 53,
  32, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93, 32, 49, 44, 49, 44,
  48, 10, 45, 100, 111, 110, 101, 10, 116, 95, 115, 101, 115, 115, 105, 111,
  110, 95, 108, 111, 115, 101, 114, 115, 61, 64, 123, 45, 95, 103, 112, 116,
  95, 114, 101, 109, 111, 118, 101, 95, 117, 110, 100, 101, 114, 115, 99, 111,
  114, 101, 92, 32, 36, 116, 95, 115, 101, 115, 115, 105, 111, 110, 95, 108,
  111, 115, 101, 114, 115, 125, 10, 48, 32, 45, 116, 91, 45, 49, 93, 32,
  34, 83, 101, 115, 115, 105, 111, 110, 32, 108, 111, 115, 101, 114, 34, 64,
  123, 45, 105, 102, 92, 32, 123, 36, 110, 98, 95, 115, 101, 115, 115, 105,
  111, 110, 95, 108, 111, 115, 101, 114, 115, 61, 61, 49, 125, 92, 32, 45,
  117, 92, 32, 92, 34, 92, 34, 92, 32, 45, 101, 108, 115, 101, 92, 32,
  45, 117, 92, 32, 115, 92, 32, 45, 101, 110, 100, 105, 102, 125, 34, 32,
  58, 32, 34, 36, 116, 95, 115, 101, 115, 115, 105, 111, 110, 95, 108, 111,
  115, 101, 114, 115, 44, 48, 44, 48, 44, 53, 55, 44, 49, 44, 50, 53,
  53, 10, 45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 44, 52, 32, 45, 100, 114, 111, 112, 95, 115, 104, 97,
  100, 111, 119, 91, 45, 49, 93, 32, 53, 44, 53, 44, 50, 10, 45, 114,
  50, 100, 121, 91, 45, 49, 93, 32, 50, 52, 32, 45, 114, 91, 45, 49,
  93, 32, 123, 64, 123, 36, 98, 111, 97, 114, 100, 44, 119, 125, 45, 50,
  125, 44, 123, 49, 46, 53, 42, 36, 114, 111, 119, 95, 104, 101, 105, 103,
  104, 116, 45, 50, 125, 44, 49, 44, 52, 44, 48, 44, 48, 44, 48, 46,
  49, 44, 48, 46, 53, 10, 45, 105, 91, 45, 50, 93, 32, 49, 44, 50,
  44, 49, 44, 51, 44, 49, 50, 56, 44, 50, 53, 53, 44, 48, 44, 49,
  50, 56, 44, 54, 52, 44, 49, 50, 56, 32, 45, 114, 91, 45, 50, 93,
  32, 91, 45, 49, 93, 44, 91, 45, 49, 93, 44, 49, 44, 51, 44, 51,
  32, 45, 98, 108, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 97,
  108, 112, 104, 97, 10, 45, 105, 102, 32, 123, 36, 50, 62, 48, 125, 32,
  45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48,
  44, 49, 44, 50, 32, 45, 101, 108, 105, 102, 32, 123, 36, 50, 60, 48,
  125, 32, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 99, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36,
  110, 98, 95, 115, 101, 115, 115, 105, 111, 110, 95, 108, 111, 115, 101, 114,
  115, 32, 45, 106, 91, 45, 49, 93, 32, 91, 123, 45, 50, 45, 36, 60,
  125, 93, 44, 123, 119, 45, 54, 52, 45, 36, 62, 42, 54, 52, 125, 44,
  55, 32, 45, 100, 111, 110, 101, 10, 45, 102, 114, 97, 109, 101, 91, 45,
  49, 93, 32, 49, 44, 49, 44, 48, 10, 45, 114, 109, 91, 45, 123, 36,
  110, 98, 95, 115, 101, 115, 115, 105, 111, 110, 95, 108, 111, 115, 101, 114,
  115, 43, 50, 125, 45, 45, 50, 93, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 97, 91, 36, 98, 111, 97, 114, 100, 45, 45, 49, 93, 32, 121, 10,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 50, 53,
  53, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 100,
  114, 111, 112, 95, 115, 104, 97, 100, 111, 119, 91, 45, 49, 93, 32, 54,
  44, 54, 44, 52, 32, 45, 105, 91, 45, 50, 93, 32, 123, 119, 125, 44,
  123, 104, 125, 44, 49, 44, 51, 44, 50, 53, 53, 32, 45, 98, 108, 101,
  110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 97, 108, 112, 104, 97, 10,
  45, 107, 91, 36, 98, 111, 97, 114, 100, 93, 32, 45, 118, 32, 43, 10,
  95, 103, 112, 116, 95, 114, 101, 109, 111, 118, 101, 95, 117, 110, 100, 101,
  114, 115, 99, 111, 114, 101, 32, 58, 10, 40, 123, 39, 34, 36, 49, 34,
  39, 125, 41, 32, 45, 114, 101, 112, 108, 97, 99, 101, 91, 45, 49, 93,
  32, 123, 39, 95, 39, 125, 44, 123, 39, 92, 32, 39, 125, 32, 45, 117,
  32, 64, 123, 45, 49, 44, 116, 125, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 95, 103, 112, 116, 95, 102, 105, 101, 108, 100, 32, 58, 10, 45, 105,
  102, 32, 123, 33, 36, 53, 125, 32, 123, 36, 50, 45, 50, 125, 44, 123,
  36, 51, 45, 50, 125, 44, 49, 44, 51, 44, 50, 53, 53, 32, 45, 102,
  114, 97, 109, 101, 91, 45, 49, 93, 32, 49, 44, 49, 44, 48, 32, 45,
  114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 48, 32,
  45, 116, 91, 45, 49, 93, 32, 34, 36, 49, 34, 44, 48, 44, 48, 44,
  53, 55, 44, 49, 44, 49, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49,
  32, 45, 43, 91, 45, 49, 93, 32, 49, 10, 45, 114, 50, 100, 121, 91,
  45, 49, 93, 32, 36, 52, 32, 45, 45, 91, 45, 49, 93, 32, 49, 32,
  45, 114, 91, 45, 49, 93, 32, 123, 36, 50, 45, 50, 125, 44, 123, 36,
  51, 45, 50, 125, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53,
  44, 48, 46, 53, 32, 45, 43, 91, 45, 49, 93, 32, 49, 10, 45, 102,
  114, 97, 109, 101, 91, 45, 49, 93, 32, 49, 44, 49, 44, 48, 10, 91,
  45, 49, 93, 120, 50, 10, 45, 105, 102, 32, 123, 36, 54, 61, 61, 49,
  125, 32, 45, 42, 91, 45, 51, 93, 32, 50, 53, 53, 32, 45, 42, 91,
  45, 50, 93, 32, 50, 52, 50, 32, 45, 42, 91, 45, 49, 93, 32, 49,
  53, 51, 10, 45, 101, 108, 105, 102, 32, 123, 36, 54, 61, 61, 50, 125,
  32, 45, 42, 91, 45, 51, 93, 32, 50, 50, 50, 32, 45, 42, 91, 45,
  50, 93, 32, 50, 50, 50, 32, 45, 42, 91, 45, 49, 93, 32, 50, 50,
  50, 10, 45, 101, 108, 105, 102, 32, 123, 36, 54, 61, 61, 51, 125, 32,
  45, 42, 91, 45, 51, 93, 32, 50, 51, 50, 32, 45, 42, 91, 45, 50,
  93, 32, 50, 48, 57, 32, 45, 42, 91, 45, 49, 93, 32, 49, 57, 54,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 54, 61, 61, 52, 125, 32, 45,
  42, 91, 45, 51, 93, 32, 50, 53, 53, 32, 45, 42, 91, 45, 50, 93,
  32, 50, 48, 52, 32, 45, 42, 91, 45, 49, 93, 32, 50, 48, 52, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 54, 61, 61, 53, 125, 32, 45, 42,
  91, 45, 51, 93, 32, 50, 53, 53, 32, 45, 42, 91, 45, 50, 93, 32,
  49, 53, 51, 32, 45, 42, 91, 45, 49, 93, 32, 49, 53, 51, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 54, 61, 61, 54, 125, 32, 45, 42, 91,
  45, 51, 93, 32, 50, 52, 48, 32, 45, 42, 91, 45, 50, 93, 32, 50,
  52, 48, 32, 45, 42, 91, 45, 49, 93, 32, 50, 52, 48, 10, 45, 101,
  108, 115, 101, 32, 45, 42, 91, 45, 51, 45, 45, 49, 93, 32, 50, 53,
  53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 97, 91, 45, 51, 45, 45,
  49, 93, 32, 99, 10, 103, 105, 109, 112, 95, 102, 105, 108, 116, 101, 114,
  95, 115, 111, 117, 114, 99, 101, 115, 32, 58, 10, 40, 123, 39, 103, 109,
  105, 99, 39, 125, 41, 10, 40, 123, 39, 104, 116, 116, 112, 58, 47, 47,
  103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101,
  46, 110, 101, 116, 47, 117, 112, 100, 97, 116, 101, 64, 46, 46, 103, 109,
  105, 99, 39, 125, 44, 49, 41, 10, 103, 105, 109, 112, 95, 112, 97, 114,
  97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 32, 58, 10,
  45, 97, 112, 112, 108, 121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95,
  111, 118, 101, 114, 108, 97, 112, 32, 34, 36, 49, 34, 44, 36, 51, 44,
  123, 105, 102, 40, 36, 50, 44, 50, 94, 40, 36, 50, 45, 49, 41, 44,
  48, 41, 125, 10, 117, 112, 100, 97, 116, 101, 95, 103, 109, 105, 99, 95,
  103, 105, 109, 112, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49,
  61, 64, 46, 125, 44, 36, 123, 50, 61, 49, 125, 10, 45, 118, 32, 45,
  10, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103, 109, 105, 99, 95, 103,
  105, 109, 112, 95, 109, 111, 118, 101, 32, 34, 47, 84, 101, 115, 116, 105,
  110, 103, 47, 74, 38, 35, 50, 51, 51, 59, 74, 38, 35, 50, 51, 51,
  59, 47, 82, 97, 121, 115, 34, 44, 34, 47, 80, 97, 116, 116, 101, 114,
  110, 115, 34, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103, 109, 105,
  99, 95, 103, 105, 109, 112, 95, 109, 111, 118, 101, 32, 34, 47, 84, 101,
  115, 116, 105, 110, 103, 47, 73, 97, 105, 110, 126, 102, 101, 114, 103, 117,
  115, 115, 111, 110, 47, 72, 97, 108, 102, 116, 111, 110, 101, 126, 115, 104,
  97, 112, 101, 115, 34, 44, 34, 47, 80, 97, 116, 116, 101, 114, 110, 115,
  34, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103, 109, 105, 99, 95,
  103, 105, 109, 112, 95, 109, 111, 118, 101, 32, 34, 47, 84, 101, 115, 116,
  105, 110, 103, 47, 73, 97, 105, 110, 126, 102, 101, 114, 103, 117, 115, 115,
  111, 110, 47, 83, 105, 109, 112, 108, 101, 126, 108, 111, 99, 97, 108, 126,
  99, 111, 110, 116, 114, 97, 115, 116, 34, 44, 34, 47, 68, 101, 116, 97,
  105, 108, 115, 34, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103, 109,
  105, 99, 95, 103, 105, 109, 112, 95, 109, 111, 118, 101, 32, 34, 47, 84,
  101, 115, 116, 105, 110, 103, 47, 71, 97, 114, 97, 103, 101, 99, 111, 100,
  101, 114, 47, 65, 117, 114, 111, 114, 97, 34, 44, 34, 47, 65, 114, 116,
  105, 115, 116, 105, 99, 34, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95,
  103, 109, 105, 99, 95, 103, 105, 109, 112, 95, 109, 111, 118, 101, 32, 34,
  47, 84, 101, 115, 116, 105, 110, 103, 47, 71, 97, 114, 97, 103, 101, 99,
  111, 100, 101, 114, 47, 68, 101, 115, 112, 101, 99, 107, 108, 101, 34, 44,
  34, 47, 82, 101, 112, 97, 105, 114, 34, 10, 45, 95, 117, 112, 100, 97,
  116, 101, 95, 103, 109, 105, 99, 95, 103, 105, 109, 112, 95, 109, 111, 118,
  101, 32, 34, 47, 84, 101, 115, 116, 105, 110, 103, 47, 71, 97, 114, 97,
  103, 101, 99, 111, 100, 101, 114, 47, 72, 83, 76, 126, 97, 100, 106, 117,
  115, 116, 109, 101, 110, 116, 34, 44, 34, 47, 67, 111, 108, 111, 114, 115,
  34, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103, 109, 105, 99, 95,
  103, 105, 109, 112, 95, 109, 111, 118, 101, 32, 34, 47, 84, 101, 115, 116,
  105, 110, 103, 47, 71, 97, 114, 97, 103, 101, 99, 111, 100, 101, 114, 47,
  72, 83, 86, 126, 115, 101, 108, 101, 99, 116, 34, 44, 34, 47, 67, 111,
  108, 111, 114, 115, 34, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103,
  109, 105, 99, 95, 103, 105, 109, 112, 95, 109, 111, 118, 101, 32, 34, 47,
  84, 101, 115, 116, 105, 110, 103, 47, 71, 97, 114, 97, 103, 101, 99, 111,
  100, 101, 114, 47, 83, 116, 101, 114, 101, 111, 126, 105, 109, 97, 103, 101,
  34, 44, 34, 47, 83, 116, 101, 114, 101, 111, 115, 99, 111, 112, 105, 99,
  126, 51, 100, 34, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103, 109,
  105, 99, 95, 103, 105, 109, 112, 95, 109, 111, 118, 101, 32, 34, 47, 84,
  101, 115, 116, 105, 110, 103, 47, 71, 97, 114, 97, 103, 101, 99, 111, 100,
  101, 114, 47, 85, 110, 100, 111, 126, 97, 110, 97, 103, 108, 121, 112, 104,
  34, 44, 34, 47, 83, 116, 101, 114, 101, 111, 115, 99, 111, 112, 105, 99,
  126, 51, 100, 34, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103, 109,
  105, 99, 95, 103, 105, 109, 112, 95, 109, 111, 118, 101, 32, 34, 47, 84,
  101, 115, 116, 105, 110, 103, 47, 78, 97, 103, 103, 111, 98, 111, 116, 47,
  66, 108, 111, 99, 107, 105, 115, 109, 34, 44, 34, 47, 65, 114, 116, 105,
  115, 116, 105, 99, 34, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103,
  109, 105, 99, 95, 103, 105, 109, 112, 95, 109, 111, 118, 101, 32, 34, 47,
  84, 101, 115, 116, 105, 110, 103, 47, 83, 97, 109, 106, 47, 67, 104, 97,
  108, 107, 126, 105, 116, 126, 117, 112, 34, 44, 34, 47, 65, 114, 116, 105,
  115, 116, 105, 99, 34, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103,
  109, 105, 99, 95, 103, 105, 109, 112, 95, 109, 111, 118, 101, 32, 34, 47,
  84, 101, 115, 116, 105, 110, 103, 47, 83, 97, 109, 106, 47, 68, 101, 110,
  105, 109, 126, 116, 101, 120, 116, 117, 114, 101, 34, 44, 34, 47, 80, 97,
  116, 116, 101, 114, 110, 115, 34, 10, 45, 95, 117, 112, 100, 97, 116, 101,
  95, 103, 109, 105, 99, 95, 103, 105, 109, 112, 95, 109, 111, 118, 101, 32,
  34, 47, 84, 101, 115, 116, 105, 110, 103, 47, 90, 111, 110, 100, 101, 114,
  114, 47, 83, 112, 105, 114, 97, 108, 34, 44, 34, 47, 82, 101, 110, 100,
  101, 114, 105, 110, 103, 34, 10, 45, 109, 32, 34, 112, 97, 114, 101, 110,
  116, 32, 58, 32, 45, 108, 91, 93, 32, 40, 123, 39, 36, 34, 34, 49,
  39, 125, 41, 32, 45, 115, 32, 45, 44, 123, 39, 47, 39, 125, 32, 45,
  105, 102, 32, 64, 35, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101,
  110, 100, 105, 102, 32, 45, 105, 91, 48, 45, 45, 49, 93, 32, 40, 52,
  55, 41, 32, 45, 97, 32, 121, 32, 45, 117, 32, 64, 123, 48, 44, 116,
  125, 32, 45, 114, 109, 32, 45, 101, 110, 100, 108, 34, 10, 45, 109, 32,
  34, 95, 109, 97, 120, 32, 58, 32, 40, 123, 39, 92, 34, 36, 34, 34,
  49, 92, 34, 39, 125, 41, 32, 40, 123, 39, 92, 34, 36, 34, 34, 50,
  92, 34, 39, 125, 41, 32, 45, 102, 91, 45, 50, 44, 45, 49, 93, 32,
  39, 105, 102, 40, 105, 62, 61, 57, 55, 38, 38, 105, 60, 61, 49, 50,
  50, 44, 105, 45, 51, 50, 44, 105, 41, 39, 32, 45, 114, 91, 45, 50,
  44, 45, 49, 93, 32, 123, 109, 97, 120, 40, 119, 44, 64, 123, 45, 50,
  44, 119, 125, 41, 125, 44, 49, 44, 49, 44, 49, 44, 48, 32, 45, 45,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 97, 117, 116, 111, 99, 114, 111,
  112, 91, 45, 49, 93, 32, 48, 32, 34, 92, 10, 34, 45, 117, 32, 123,
  105, 62, 48, 125, 32, 45, 114, 109, 91, 45, 49, 93, 34, 10, 45, 109,
  32, 34, 108, 111, 97, 100, 95, 103, 109, 105, 99, 32, 58, 32, 34, 92,
  10, 34, 95, 110, 98, 95, 115, 111, 117, 114, 99, 101, 115, 61, 123, 36,
  95, 110, 98, 95, 115, 111, 117, 114, 99, 101, 115, 43, 49, 125, 32, 102,
  105, 108, 101, 110, 97, 109, 101, 61, 64, 123, 92, 34, 45, 98, 97, 115,
  101, 110, 97, 109, 101, 32, 36, 34, 34, 49, 92, 34, 125, 32, 34, 92,
  10, 34, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 92, 34, 32, 32,
  92, 34, 36, 95, 110, 98, 95, 115, 111, 117, 114, 99, 101, 115, 92, 34,
  46, 32, 92, 34, 36, 102, 105, 108, 101, 110, 97, 109, 101, 92, 34, 32,
  32, 92, 34, 32, 45, 118, 32, 45, 32, 34, 92, 10, 34, 45, 108, 91,
  93, 32, 34, 92, 10, 34, 32, 32, 45, 105, 32, 114, 97, 119, 58, 36,
  34, 34, 49, 44, 117, 99, 104, 97, 114, 32, 45, 118, 32, 43, 32, 45,
  101, 91, 93, 32, 92, 34, 32, 32, 32, 32, 32, 32, 91, 114, 101, 116,
  114, 105, 101, 118, 101, 100, 32, 102, 114, 111, 109, 32, 115, 111, 117, 114,
  99, 101, 32, 39, 36, 34, 34, 49, 39, 93, 92, 110, 92, 34, 32, 45,
  118, 32, 45, 32, 34, 92, 10, 34, 32, 32, 45, 108, 32, 34, 92, 10,
  34, 32, 32, 32, 32, 45, 111, 32, 114, 97, 119, 58, 47, 116, 109, 112,
  47, 36, 102, 105, 108, 101, 110, 97, 109, 101, 44, 117, 99, 104, 97, 114,
  32, 34, 92, 10, 34, 32, 32, 32, 32, 45, 120, 32, 92, 34, 115, 99,
  112, 32, 47, 116, 109, 112, 47, 92, 34, 36, 102, 105, 108, 101, 110, 97,
  109, 101, 92, 34, 32, 114, 111, 110, 111, 117, 110, 111, 117, 114, 115, 44,
  103, 109, 105, 99, 64, 119, 101, 98, 46, 115, 111, 117, 114, 99, 101, 102,
  111, 114, 103, 101, 46, 110, 101, 116, 58, 104, 116, 100, 111, 99, 115, 47,
  105, 110, 99, 108, 117, 100, 101, 47, 92, 34, 32, 34, 92, 10, 34, 32,
  32, 32, 32, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 92, 34, 32,
  32, 32, 32, 32, 32, 91, 97, 114, 99, 104, 105, 118, 101, 100, 93, 92,
  110, 92, 34, 32, 45, 118, 32, 45, 32, 34, 92, 10, 34, 32, 32, 45,
  111, 110, 102, 97, 105, 108, 32, 45, 118, 32, 43, 32, 45, 101, 91, 93,
  32, 92, 34, 32, 32, 32, 32, 32, 32, 91, 99, 111, 117, 108, 100, 32,
  110, 111, 116, 32, 98, 101, 32, 97, 114, 99, 104, 105, 118, 101, 100, 33,
  93, 92, 110, 92, 34, 32, 45, 118, 32, 45, 32, 45, 101, 110, 100, 108,
  32, 34, 92, 10, 34, 45, 111, 110, 102, 97, 105, 108, 32, 45, 108, 91,
  93, 32, 34, 92, 10, 34, 32, 32, 115, 111, 117, 114, 99, 101, 61, 104,
  116, 116, 112, 58, 47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99,
  101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 105, 110, 99, 108, 117,
  100, 101, 47, 36, 102, 105, 108, 101, 110, 97, 109, 101, 32, 34, 92, 10,
  34, 32, 32, 45, 105, 32, 114, 97, 119, 58, 36, 115, 111, 117, 114, 99,
  101, 44, 117, 99, 104, 97, 114, 32, 45, 118, 32, 43, 32, 45, 101, 91,
  93, 32, 92, 34, 32, 32, 32, 32, 32, 32, 91, 114, 101, 116, 114, 105,
  101, 118, 101, 100, 32, 102, 114, 111, 109, 32, 97, 114, 99, 104, 105, 118,
  101, 32, 39, 92, 34, 36, 115, 111, 117, 114, 99, 101, 92, 34, 39, 93,
  92, 110, 92, 34, 32, 45, 118, 32, 45, 32, 34, 92, 10, 34, 32, 32,
  45, 111, 110, 102, 97, 105, 108, 32, 45, 118, 32, 43, 32, 45, 101, 91,
  93, 32, 92, 34, 32, 32, 32, 32, 32, 32, 91, 101, 114, 114, 111, 114,
  44, 32, 110, 111, 116, 32, 114, 101, 97, 99, 104, 97, 98, 108, 101, 33,
  93, 92, 110, 92, 34, 32, 45, 118, 32, 45, 34, 92, 10, 34, 32, 32,
  45, 101, 110, 100, 108, 32, 45, 101, 110, 100, 108, 34, 10, 45, 109, 32,
  34, 99, 97, 108, 105, 98, 114, 97, 116, 101, 95, 110, 97, 109, 101, 32,
  58, 32, 34, 92, 10, 34, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32,
  51, 50, 32, 34, 92, 10, 34, 45, 102, 32, 39, 105, 102, 40, 105, 62,
  61, 54, 53, 38, 38, 105, 60, 61, 57, 48, 44, 105, 43, 51, 50, 44,
  105, 41, 39, 32, 34, 92, 10, 34, 45, 114, 101, 112, 108, 97, 99, 101,
  32, 123, 39, 95, 39, 125, 44, 51, 50, 32, 45, 97, 117, 116, 111, 99,
  114, 111, 112, 32, 51, 50, 32, 34, 92, 10, 34, 45, 114, 101, 112, 108,
  97, 99, 101, 95, 115, 101, 113, 32, 92, 34, 34, 123, 39, 114, 103, 98,
  39, 125, 34, 92, 34, 44, 92, 34, 34, 123, 39, 82, 71, 66, 39, 125,
  34, 92, 34, 32, 34, 92, 10, 34, 45, 114, 101, 112, 108, 97, 99, 101,
  95, 115, 101, 113, 32, 92, 34, 34, 123, 39, 108, 97, 98, 39, 125, 34,
  92, 34, 44, 92, 34, 34, 123, 39, 76, 97, 98, 39, 125, 34, 92, 34,
  32, 34, 92, 10, 34, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101,
  113, 32, 92, 34, 34, 123, 39, 104, 115, 118, 39, 125, 34, 92, 34, 44,
  92, 34, 34, 123, 39, 72, 83, 86, 39, 125, 34, 92, 34, 32, 34, 92,
  10, 34, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 92,
  34, 34, 123, 39, 104, 115, 108, 39, 125, 34, 92, 34, 44, 92, 34, 34,
  123, 39, 72, 83, 76, 39, 125, 34, 92, 34, 32, 34, 92, 10, 34, 45,
  114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 92, 34, 34, 123,
  39, 121, 99, 98, 99, 114, 39, 125, 34, 92, 34, 44, 92, 34, 34, 123,
  39, 89, 67, 98, 67, 114, 39, 125, 34, 92, 34, 32, 34, 92, 10, 34,
  45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 92, 34, 34,
  123, 39, 99, 109, 121, 107, 39, 125, 34, 92, 34, 44, 92, 34, 34, 123,
  39, 67, 77, 89, 75, 39, 125, 34, 92, 34, 32, 34, 92, 10, 34, 45,
  114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 92, 34, 34, 123,
  39, 98, 38, 97, 109, 112, 59, 119, 39, 125, 34, 92, 34, 44, 92, 34,
  34, 123, 39, 66, 38, 97, 109, 112, 59, 87, 39, 125, 34, 92, 34, 32,
  34, 92, 10, 34, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113,
  32, 92, 34, 34, 123, 39, 103, 105, 109, 112, 39, 125, 34, 92, 34, 44,
  92, 34, 34, 123, 39, 71, 73, 77, 80, 39, 125, 34, 92, 34, 32, 34,
  92, 10, 34, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32,
  92, 34, 34, 123, 39, 114, 111, 100, 100, 121, 39, 125, 34, 92, 34, 44,
  92, 34, 34, 123, 39, 82, 111, 100, 100, 121, 39, 125, 34, 92, 34, 32,
  34, 92, 10, 34, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113,
  32, 92, 34, 34, 123, 39, 99, 114, 116, 39, 125, 34, 92, 34, 44, 92,
  34, 34, 123, 39, 67, 82, 84, 39, 125, 34, 92, 34, 32, 34, 92, 10,
  34, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 32, 92, 34,
  34, 123, 39, 99, 111, 108, 111, 114, 97, 98, 115, 116, 114, 97, 99, 116,
  105, 111, 110, 112, 97, 105, 110, 116, 39, 125, 34, 92, 34, 44, 92, 34,
  34, 123, 39, 34, 67, 111, 108, 111, 114, 32, 97, 98, 115, 116, 114, 97,
  99, 116, 105, 111, 110, 32, 112, 97, 105, 110, 116, 34, 39, 125, 34, 92,
  34, 32, 34, 92, 10, 34, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115,
  101, 113, 32, 92, 34, 34, 123, 39, 103, 39, 125, 44, 51, 57, 44, 123,
  39, 109, 105, 99, 39, 125, 34, 92, 34, 44, 92, 34, 34, 123, 39, 71,
  39, 125, 44, 51, 57, 44, 123, 39, 77, 73, 67, 39, 125, 34, 92, 34,
  32, 34, 92, 10, 34, 45, 102, 32, 39, 105, 102, 40, 121, 61, 61, 48,
  38, 38, 105, 62, 61, 57, 55, 38, 38, 105, 60, 61, 49, 50, 50, 44,
  105, 45, 51, 50, 44, 105, 41, 39, 32, 34, 10, 45, 105, 102, 32, 123,
  36, 49, 61, 61, 64, 46, 125, 10, 45, 118, 32, 43, 32, 45, 101, 91,
  93, 32, 34, 62, 32, 85, 112, 108, 111, 97, 100, 32, 108, 97, 116, 101,
  115, 116, 32, 118, 101, 114, 115, 105, 111, 110, 32, 40, 34, 64, 123, 45,
  115, 116, 114, 118, 101, 114, 125, 34, 41, 32, 111, 102, 32, 99, 111, 109,
  109, 97, 110, 100, 115, 32, 111, 110, 32, 83, 111, 117, 114, 99, 101, 102,
  111, 114, 103, 101, 32, 115, 101, 114, 118, 101, 114, 46, 92, 110, 34, 32,
  45, 118, 32, 45, 10, 45, 120, 32, 34, 115, 99, 112, 32, 34, 36, 72,
  79, 77, 69, 47, 119, 111, 114, 107, 47, 115, 114, 99, 47, 103, 109, 105,
  99, 47, 115, 114, 99, 47, 103, 109, 105, 99, 95, 100, 101, 102, 46, 103,
  109, 105, 99, 34, 32, 114, 111, 110, 111, 117, 110, 111, 117, 114, 115, 44,
  103, 109, 105, 99, 64, 119, 101, 98, 46, 115, 111, 117, 114, 99, 101, 102,
  111, 114, 103, 101, 46, 110, 101, 116, 58, 104, 116, 100, 111, 99, 115, 47,
  103, 109, 105, 99, 95, 100, 101, 102, 46, 34, 36, 49, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 62,
  32, 76, 111, 97, 100, 32, 97, 110, 100, 32, 97, 114, 99, 104, 105, 118,
  101, 32, 46, 103, 109, 105, 99, 32, 115, 111, 117, 114, 99, 101, 32, 102,
  105, 108, 101, 115, 46, 92, 110, 34, 32, 45, 118, 32, 45, 10, 95, 110,
  98, 95, 115, 111, 117, 114, 99, 101, 115, 61, 48, 10, 45, 108, 111, 97,
  100, 95, 103, 109, 105, 99, 32, 104, 116, 116, 112, 58, 47, 47, 103, 109,
  105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110,
  101, 116, 47, 103, 109, 105, 99, 95, 100, 101, 102, 46, 36, 49, 10, 45,
  108, 111, 97, 100, 95, 103, 109, 105, 99, 32, 104, 116, 116, 112, 58, 47,
  47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103,
  101, 46, 110, 101, 116, 47, 99, 111, 109, 112, 97, 116, 105, 98, 105, 108,
  105, 116, 121, 46, 103, 109, 105, 99, 10, 45, 108, 111, 97, 100, 95, 103,
  109, 105, 99, 32, 104, 116, 116, 112, 58, 47, 47, 115, 52, 48, 54, 56,
  51, 51, 50, 52, 55, 46, 119, 101, 98, 115, 105, 116, 101, 104, 111, 109,
  101, 46, 99, 111, 46, 117, 107, 47, 103, 109, 105, 99, 47, 103, 97, 114,
  97, 103, 101, 99, 111, 100, 101, 114, 46, 103, 109, 105, 99, 10, 45, 108,
  111, 97, 100, 95, 103, 109, 105, 99, 32, 104, 116, 116, 112, 58, 47, 47,
  103, 101, 110, 116, 108, 101, 109, 97, 110, 98, 101, 103, 103, 97, 114, 46,
  98, 112, 108, 97, 99, 101, 100, 46, 110, 101, 116, 47, 103, 101, 110, 116,
  108, 101, 109, 97, 110, 98, 101, 103, 103, 97, 114, 95, 103, 109, 105, 99,
  46, 103, 109, 105, 99, 10, 45, 108, 111, 97, 100, 95, 103, 109, 105, 99,
  32, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 105, 97, 105, 110,
  46, 98, 112, 108, 97, 99, 101, 100, 46, 110, 101, 116, 47, 105, 97, 105,
  110, 95, 102, 101, 114, 103, 117, 115, 115, 111, 110, 46, 103, 109, 105, 99,
  10, 45, 108, 111, 97, 100, 95, 103, 109, 105, 99, 32, 104, 116, 116, 112,
  58, 47, 47, 119, 119, 119, 46, 104, 45, 112, 115, 46, 100, 101, 109, 111,
  110, 46, 99, 111, 46, 117, 107, 47, 71, 77, 73, 67, 47, 106, 97, 121,
  112, 114, 105, 99, 104, 46, 103, 109, 105, 99, 10, 45, 108, 111, 97, 100,
  95, 103, 109, 105, 99, 32, 104, 116, 116, 112, 115, 58, 47, 47, 114, 97,
  119, 46, 103, 105, 116, 104, 117, 98, 46, 99, 111, 109, 47, 106, 98, 111,
  117, 108, 97, 110, 103, 101, 114, 47, 106, 98, 111, 117, 108, 97, 110, 103,
  101, 114, 45, 103, 109, 105, 99, 47, 109, 97, 115, 116, 101, 114, 47, 106,
  98, 111, 117, 108, 97, 110, 103, 101, 114, 46, 103, 109, 105, 99, 10, 45,
  108, 111, 97, 100, 95, 103, 109, 105, 99, 32, 104, 116, 116, 112, 58, 47,
  47, 107, 97, 114, 111, 48, 51, 46, 98, 112, 108, 97, 99, 101, 100, 46,
  110, 101, 116, 47, 103, 109, 105, 99, 47, 107, 97, 114, 111, 115, 46, 103,
  109, 105, 99, 10, 45, 108, 111, 97, 100, 95, 103, 109, 105, 99, 32, 104,
  116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 115, 97, 117, 110, 97, 108,
  97, 104, 116, 105, 46, 102, 105, 47, 110, 97, 103, 103, 111, 98, 111, 116,
  47, 110, 97, 103, 103, 111, 98, 111, 116, 46, 103, 109, 105, 99, 10, 45,
  108, 111, 97, 100, 95, 103, 109, 105, 99, 32, 104, 116, 116, 112, 58, 47,
  47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103,
  101, 46, 110, 101, 116, 47, 112, 104, 111, 116, 111, 99, 111, 109, 105, 120,
  46, 103, 109, 105, 99, 10, 45, 108, 111, 97, 100, 95, 103, 109, 105, 99,
  32, 104, 116, 116, 112, 58, 47, 47, 103, 109, 105, 99, 46, 115, 111, 117,
  114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 114, 111, 110,
  111, 117, 110, 111, 117, 114, 115, 46, 103, 109, 105, 99, 10, 45, 108, 111,
  97, 100, 95, 103, 109, 105, 99, 32, 104, 116, 116, 112, 58, 47, 47, 119,
  119, 119, 46, 97, 108, 106, 97, 99, 111, 109, 46, 99, 111, 109, 47, 126,
  103, 109, 105, 99, 47, 115, 97, 109, 106, 46, 103, 109, 105, 99, 10, 45,
  108, 111, 97, 100, 95, 103, 109, 105, 99, 32, 104, 116, 116, 112, 58, 47,
  47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103,
  101, 46, 110, 101, 116, 47, 116, 111, 109, 107, 101, 105, 108, 46, 103, 109,
  105, 99, 10, 45, 108, 111, 97, 100, 95, 103, 109, 105, 99, 32, 104, 116,
  116, 112, 58, 47, 47, 100, 111, 99, 103, 109, 105, 99, 46, 116, 117, 120,
  102, 97, 109, 105, 108, 121, 46, 111, 114, 103, 47, 122, 111, 110, 100, 101,
  114, 114, 46, 103, 109, 105, 99, 10, 45, 105, 91, 48, 93, 32, 40, 49,
  48, 41, 32, 45, 105, 91, 50, 45, 45, 49, 93, 32, 40, 123, 34, 39,
  92, 110, 35, 64, 103, 105, 109, 112, 32, 95, 95, 95, 95, 95, 95, 95,
  95, 95, 95, 95, 95, 95, 95, 95, 95, 92, 110, 39, 34, 125, 41, 32,
  45, 121, 32, 45, 97, 32, 121, 32, 45, 100, 105, 115, 99, 97, 114, 100,
  32, 49, 51, 32, 45, 114, 101, 112, 108, 97, 99, 101, 32, 57, 44, 51,
  50, 10, 45, 115, 32, 43, 44, 123, 39, 34, 35, 64, 103, 105, 109, 112,
  34, 39, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116,
  40, 40, 64, 35, 45, 49, 41, 47, 50, 41, 125, 32, 45, 97, 91, 123,
  36, 62, 43, 49, 125, 44, 123, 36, 62, 43, 50, 125, 93, 32, 121, 32,
  45, 100, 111, 110, 101, 10, 45, 110, 109, 91, 48, 93, 32, 33, 104, 101,
  97, 100, 101, 114, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34,
  62, 32, 83, 116, 97, 114, 116, 32, 115, 111, 117, 114, 99, 101, 32, 112,
  97, 114, 115, 105, 110, 103, 46, 92, 110, 34, 32, 45, 118, 32, 45, 10,
  112, 114, 111, 103, 114, 101, 115, 115, 95, 102, 97, 99, 116, 111, 114, 61,
  123, 49, 48, 48, 47, 40, 64, 35, 45, 49, 41, 125, 10, 109, 101, 114,
  103, 101, 95, 114, 101, 113, 117, 101, 115, 116, 61, 48, 10, 109, 101, 114,
  103, 101, 95, 115, 116, 97, 114, 116, 61, 48, 10, 110, 98, 95, 102, 105,
  108, 116, 101, 114, 115, 61, 48, 10, 111, 102, 102, 115, 101, 116, 61, 48,
  10, 112, 97, 116, 104, 61, 47, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 10, 105, 110, 100, 61, 123, 36, 62, 45, 36, 111, 102, 102, 115,
  101, 116, 125, 10, 45, 105, 102, 32, 123, 64, 123, 123, 36, 105, 110, 100,
  45, 49, 125, 44, 45, 49, 125, 61, 61, 49, 48, 34, 32, 38, 38, 32,
  34, 123, 123, 96, 64, 123, 36, 105, 110, 100, 44, 48, 45, 53, 125, 96,
  125, 39, 61, 61, 39, 34, 35, 64, 103, 105, 109, 112, 34, 125, 34, 32,
  38, 38, 32, 34, 40, 64, 123, 36, 105, 110, 100, 44, 54, 125, 61, 61,
  51, 50, 34, 32, 124, 124, 32, 34, 64, 123, 36, 105, 110, 100, 44, 54,
  125, 61, 61, 123, 39, 95, 39, 125, 41, 125, 32, 45, 108, 91, 36, 105,
  110, 100, 93, 10, 105, 115, 95, 102, 111, 108, 100, 101, 114, 61, 48, 10,
  45, 115, 32, 43, 44, 49, 48, 10, 45, 105, 102, 32, 123, 64, 123, 48,
  44, 54, 125, 61, 61, 123, 39, 95, 39, 125, 125, 32, 45, 45, 114, 111,
  119, 115, 91, 48, 93, 32, 57, 44, 49, 48, 48, 37, 32, 45, 114, 111,
  119, 115, 91, 48, 93, 32, 48, 44, 56, 10, 45, 101, 108, 115, 101, 32,
  45, 45, 114, 111, 119, 115, 91, 48, 93, 32, 54, 44, 49, 48, 48, 37,
  32, 45, 114, 111, 119, 115, 91, 48, 93, 32, 48, 44, 53, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45,
  49, 93, 32, 51, 50, 32, 45, 109, 118, 91, 45, 49, 93, 32, 49, 10,
  45, 105, 102, 32, 123, 64, 123, 49, 44, 48, 125, 33, 61, 123, 39, 58,
  39, 125, 125, 10, 45, 108, 91, 49, 93, 10, 45, 115, 32, 43, 44, 123,
  39, 58, 39, 125, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101,
  113, 91, 48, 93, 32, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 123,
  39, 60, 98, 62, 39, 125, 125, 44, 51, 50, 10, 45, 114, 101, 112, 108,
  97, 99, 101, 95, 115, 101, 113, 91, 48, 93, 32, 64, 123, 45, 113, 117,
  111, 116, 101, 92, 32, 123, 39, 60, 47, 98, 62, 39, 125, 125, 44, 51,
  50, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 91, 48,
  93, 32, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 60, 105,
  62, 39, 125, 125, 44, 51, 50, 10, 45, 114, 101, 112, 108, 97, 99, 101,
  95, 115, 101, 113, 91, 48, 93, 32, 64, 123, 45, 113, 117, 111, 116, 101,
  92, 32, 123, 39, 60, 47, 105, 62, 39, 125, 125, 44, 51, 50, 10, 45,
  114, 101, 112, 108, 97, 99, 101, 91, 48, 93, 32, 123, 39, 47, 39, 125,
  44, 123, 39, 45, 39, 125, 10, 45, 114, 101, 112, 108, 97, 99, 101, 91,
  48, 93, 32, 123, 39, 44, 39, 125, 44, 123, 39, 59, 39, 125, 10, 45,
  97, 117, 116, 111, 99, 114, 111, 112, 91, 48, 93, 32, 51, 50, 10, 45,
  105, 102, 32, 123, 64, 35, 62, 49, 125, 10, 45, 99, 97, 108, 105, 98,
  114, 97, 116, 101, 95, 110, 97, 109, 101, 91, 48, 93, 32, 45, 45, 114,
  101, 112, 108, 97, 99, 101, 91, 48, 93, 32, 51, 50, 44, 123, 39, 126,
  39, 125, 10, 110, 97, 109, 101, 61, 36, 112, 97, 116, 104, 64, 123, 45,
  49, 44, 116, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 109, 101, 114,
  103, 101, 95, 114, 101, 113, 117, 101, 115, 116, 61, 49, 10, 110, 98, 95,
  102, 105, 108, 116, 101, 114, 115, 61, 123, 36, 110, 98, 95, 102, 105, 108,
  116, 101, 114, 115, 43, 49, 125, 10, 45, 105, 91, 48, 44, 49, 93, 32,
  40, 51, 50, 41, 32, 45, 97, 32, 121, 10, 45, 118, 32, 43, 32, 45,
  101, 91, 93, 32, 34, 32, 32, 34, 36, 110, 98, 95, 102, 105, 108, 116,
  101, 114, 115, 34, 46, 32, 34, 36, 110, 97, 109, 101, 34, 32, 40, 34,
  123, 114, 111, 117, 110, 100, 40, 36, 62, 42, 36, 112, 114, 111, 103, 114,
  101, 115, 115, 95, 102, 97, 99, 116, 111, 114, 41, 125, 34, 37, 41, 46,
  34, 32, 45, 118, 32, 45, 10, 45, 101, 108, 115, 101, 10, 45, 105, 102,
  32, 123, 105, 61, 61, 123, 39, 95, 39, 125, 125, 10, 45, 100, 111, 32,
  112, 97, 116, 104, 61, 64, 123, 34, 45, 112, 97, 114, 101, 110, 116, 91,
  93, 32, 34, 36, 112, 97, 116, 104, 125, 32, 45, 115, 104, 105, 102, 116,
  32, 48, 44, 45, 49, 44, 48, 44, 48, 32, 45, 119, 104, 105, 108, 101,
  32, 123, 105, 61, 61, 123, 39, 95, 39, 125, 125, 10, 45, 97, 117, 116,
  111, 99, 114, 111, 112, 32, 48, 32, 45, 97, 117, 116, 111, 99, 114, 111,
  112, 32, 51, 50, 10, 45, 105, 102, 32, 123, 119, 125, 32, 45, 99, 97,
  108, 105, 98, 114, 97, 116, 101, 95, 110, 97, 109, 101, 32, 45, 114, 101,
  112, 108, 97, 99, 101, 32, 51, 50, 44, 123, 39, 126, 39, 125, 32, 112,
  97, 116, 104, 61, 36, 112, 97, 116, 104, 64, 123, 48, 44, 116, 125, 47,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101, 10, 45, 97,
  117, 116, 111, 99, 114, 111, 112, 32, 51, 50, 32, 45, 99, 97, 108, 105,
  98, 114, 97, 116, 101, 95, 110, 97, 109, 101, 32, 45, 114, 101, 112, 108,
  97, 99, 101, 32, 51, 50, 44, 123, 39, 126, 39, 125, 32, 112, 97, 116,
  104, 61, 36, 112, 97, 116, 104, 64, 123, 48, 44, 116, 125, 47, 10, 45,
  101, 110, 100, 105, 102, 10, 105, 115, 95, 102, 111, 108, 100, 101, 114, 61,
  49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 10, 45,
  105, 102, 32, 36, 105, 115, 95, 102, 111, 108, 100, 101, 114, 32, 45, 114,
  109, 91, 48, 44, 49, 93, 32, 45, 105, 91, 48, 93, 32, 40, 49, 48,
  41, 10, 45, 101, 108, 115, 101, 32, 45, 110, 109, 91, 48, 93, 32, 36,
  110, 97, 109, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115,
  101, 10, 45, 105, 102, 32, 123, 64, 35, 62, 61, 51, 125, 32, 45, 108,
  91, 49, 93, 10, 45, 115, 32, 43, 44, 123, 39, 61, 39, 125, 10, 45,
  105, 102, 32, 123, 64, 35, 62, 61, 51, 125, 32, 45, 105, 102, 32, 123,
  64, 123, 49, 44, 48, 125, 61, 61, 123, 39, 61, 39, 125, 125, 10, 45,
  114, 111, 119, 115, 91, 48, 93, 32, 49, 44, 49, 48, 48, 37, 32, 45,
  99, 97, 108, 105, 98, 114, 97, 116, 101, 95, 110, 97, 109, 101, 91, 48,
  93, 10, 45, 105, 91, 48, 93, 32, 40, 123, 39, 58, 39, 125, 59, 51,
  50, 41, 32, 45, 105, 91, 50, 93, 32, 40, 51, 50, 41, 10, 45, 101,
  110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  108, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 91, 49, 93, 32, 40,
  51, 50, 41, 10, 45, 101, 110, 100, 105, 102, 10, 45, 97, 32, 121, 10,
  45, 101, 110, 100, 108, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 109, 101, 114, 103, 101, 95, 114, 101, 113, 117, 101, 115, 116,
  34, 32, 38, 38, 32, 34, 36, 105, 110, 100, 62, 48, 125, 10, 45, 97,
  91, 36, 109, 101, 114, 103, 101, 95, 115, 116, 97, 114, 116, 45, 123, 36,
  105, 110, 100, 45, 49, 125, 93, 32, 121, 10, 111, 102, 102, 115, 101, 116,
  61, 123, 36, 111, 102, 102, 115, 101, 116, 43, 36, 105, 110, 100, 45, 36,
  109, 101, 114, 103, 101, 95, 115, 116, 97, 114, 116, 45, 49, 125, 10, 109,
  101, 114, 103, 101, 95, 115, 116, 97, 114, 116, 61, 123, 36, 109, 101, 114,
  103, 101, 95, 115, 116, 97, 114, 116, 43, 49, 125, 10, 109, 101, 114, 103,
  101, 95, 114, 101, 113, 117, 101, 115, 116, 61, 48, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 97, 91, 36, 109, 101, 114,
  103, 101, 95, 115, 116, 97, 114, 116, 45, 45, 49, 93, 32, 121, 10, 45,
  118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 110, 62, 32, 70, 111,
  114, 99, 101, 32, 102, 105, 108, 116, 101, 114, 115, 32, 116, 111, 32, 109,
  111, 118, 101, 44, 32, 105, 102, 32, 110, 101, 99, 101, 115, 115, 97, 114,
  121, 46, 34, 32, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 105, 110, 100, 61, 36, 62, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 36, 95, 110, 98, 109, 32, 45, 105, 102, 32, 123, 64, 123,
  36, 105, 110, 100, 44, 110, 125, 39, 61, 61, 39, 36, 123, 95, 116, 111,
  95, 109, 111, 118, 101, 36, 62, 125, 125, 10, 45, 118, 32, 43, 32, 45,
  101, 91, 93, 32, 34, 32, 32, 34, 36, 105, 110, 100, 34, 46, 32, 77,
  111, 118, 101, 32, 39, 34, 64, 123, 36, 105, 110, 100, 44, 110, 125, 34,
  39, 32, 116, 111, 32, 39, 34, 36, 123, 95, 109, 111, 118, 101, 95, 116,
  111, 36, 62, 125, 34, 39, 46, 34, 32, 45, 118, 32, 45, 10, 45, 110,
  97, 109, 101, 91, 36, 105, 110, 100, 93, 32, 36, 123, 95, 109, 111, 118,
  101, 95, 116, 111, 36, 62, 125, 47, 64, 123, 36, 105, 110, 100, 44, 98,
  125, 10, 45, 101, 110, 100, 105, 102, 32, 45, 100, 111, 110, 101, 32, 45,
  100, 111, 110, 101, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34,
  92, 110, 62, 32, 83, 111, 114, 116, 32, 102, 105, 108, 116, 101, 114, 115,
  32, 98, 121, 32, 108, 101, 120, 105, 99, 111, 103, 114, 97, 112, 104, 105,
  99, 32, 111, 114, 100, 101, 114, 46, 34, 32, 45, 118, 32, 45, 10, 45,
  95, 117, 112, 100, 97, 116, 101, 95, 103, 109, 105, 99, 95, 103, 105, 109,
  112, 95, 115, 111, 114, 116, 32, 48, 44, 123, 64, 35, 45, 49, 125, 10,
  45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 110, 62, 32, 82,
  101, 109, 111, 118, 101, 32, 100, 117, 112, 108, 105, 99, 97, 116, 101, 32,
  102, 105, 108, 116, 101, 114, 115, 46, 34, 32, 45, 118, 32, 45, 10, 112,
  110, 97, 109, 101, 61, 64, 123, 45, 49, 44, 110, 125, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 99, 110, 97, 109,
  101, 61, 64, 123, 36, 60, 44, 110, 125, 10, 45, 105, 102, 32, 123, 36,
  99, 110, 97, 109, 101, 39, 61, 61, 39, 36, 112, 110, 97, 109, 101, 125,
  10, 45, 118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 32, 32, 34, 36,
  60, 34, 46, 32, 82, 101, 109, 111, 118, 101, 32, 100, 117, 112, 108, 105,
  99, 97, 116, 101, 32, 39, 34, 36, 99, 110, 97, 109, 101, 34, 39, 46,
  34, 32, 45, 118, 32, 45, 10, 45, 114, 109, 91, 36, 60, 93, 10, 45,
  101, 108, 115, 101, 32, 112, 110, 97, 109, 101, 61, 36, 99, 110, 97, 109,
  101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45,
  118, 32, 43, 32, 45, 101, 91, 93, 32, 34, 92, 110, 62, 32, 82, 101,
  98, 117, 105, 108, 100, 32, 102, 111, 108, 100, 101, 114, 32, 115, 116, 114,
  117, 99, 116, 117, 114, 101, 46, 34, 32, 45, 118, 32, 45, 10, 45, 109,
  32, 34, 110, 98, 95, 108, 101, 118, 101, 108, 115, 32, 58, 32, 45, 108,
  91, 93, 32, 40, 123, 39, 36, 34, 34, 49, 39, 125, 41, 32, 45, 115,
  32, 45, 44, 123, 39, 47, 39, 125, 32, 45, 117, 32, 64, 35, 32, 45,
  114, 109, 32, 45, 101, 110, 100, 108, 34, 10, 112, 97, 116, 104, 61, 47,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 110, 112, 97, 116, 104, 61, 64, 123, 34, 45, 112, 97, 114,
  101, 110, 116, 32, 34, 64, 123, 48, 44, 110, 125, 125, 10, 45, 105, 102,
  32, 123, 36, 112, 97, 116, 104, 39, 33, 61, 39, 36, 110, 112, 97, 116,
  104, 125, 10, 110, 99, 61, 64, 123, 34, 45, 110, 98, 95, 108, 101, 118,
  101, 108, 115, 91, 93, 32, 34, 36, 112, 97, 116, 104, 125, 10, 110, 110,
  61, 64, 123, 34, 45, 110, 98, 95, 108, 101, 118, 101, 108, 115, 91, 93,
  32, 34, 36, 110, 112, 97, 116, 104, 125, 10, 110, 98, 95, 117, 112, 61,
  48, 10, 110, 98, 95, 100, 111, 119, 110, 61, 48, 10, 98, 97, 115, 105,
  115, 61, 36, 112, 97, 116, 104, 32, 110, 98, 97, 115, 105, 115, 61, 36,
  110, 112, 97, 116, 104, 10, 45, 100, 111, 10, 110, 99, 61, 64, 123, 34,
  45, 110, 98, 95, 108, 101, 118, 101, 108, 115, 91, 93, 32, 34, 36, 98,
  97, 115, 105, 115, 125, 10, 110, 110, 61, 64, 123, 34, 45, 110, 98, 95,
  108, 101, 118, 101, 108, 115, 91, 93, 32, 34, 36, 110, 98, 97, 115, 105,
  115, 125, 10, 45, 105, 102, 32, 123, 36, 110, 99, 62, 36, 110, 110, 125,
  32, 98, 97, 115, 105, 115, 61, 64, 123, 34, 45, 112, 97, 114, 101, 110,
  116, 91, 93, 32, 34, 36, 98, 97, 115, 105, 115, 125, 32, 110, 98, 95,
  117, 112, 61, 123, 36, 110, 98, 95, 117, 112, 43, 49, 125, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 110, 110, 62, 36, 110, 99, 125, 32, 110, 98,
  97, 115, 105, 115, 61, 64, 123, 34, 45, 112, 97, 114, 101, 110, 116, 91,
  93, 32, 34, 36, 110, 98, 97, 115, 105, 115, 125, 32, 110, 98, 95, 100,
  111, 119, 110, 61, 123, 36, 110, 98, 95, 100, 111, 119, 110, 43, 49, 125,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 110, 98, 97, 115, 105, 115, 39,
  33, 61, 39, 36, 98, 97, 115, 105, 115, 125, 32, 98, 97, 115, 105, 115,
  61, 64, 123, 34, 45, 112, 97, 114, 101, 110, 116, 91, 93, 32, 34, 36,
  98, 97, 115, 105, 115, 125, 32, 110, 98, 95, 117, 112, 61, 123, 36, 110,
  98, 95, 117, 112, 43, 49, 125, 32, 110, 98, 97, 115, 105, 115, 61, 64,
  123, 34, 45, 112, 97, 114, 101, 110, 116, 91, 93, 32, 34, 36, 110, 98,
  97, 115, 105, 115, 125, 32, 110, 98, 95, 100, 111, 119, 110, 61, 123, 36,
  110, 98, 95, 100, 111, 119, 110, 43, 49, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 119, 104, 105, 108, 101, 32, 123, 36, 110, 98, 97, 115, 105,
  115, 39, 33, 61, 39, 36, 98, 97, 115, 105, 115, 125, 10, 99, 111, 109,
  109, 97, 110, 100, 61, 10, 45, 105, 102, 32, 36, 110, 98, 95, 117, 112,
  32, 49, 44, 36, 110, 98, 95, 117, 112, 44, 49, 44, 49, 44, 123, 39,
  95, 39, 125, 32, 99, 111, 109, 109, 97, 110, 100, 61, 34, 35, 64, 103,
  105, 109, 112, 32, 34, 64, 123, 45, 49, 44, 116, 125, 34, 92, 110, 34,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 36, 110, 98, 95, 100, 111, 119, 110, 32, 45, 108, 91,
  93, 10, 40, 123, 39, 36, 110, 112, 97, 116, 104, 39, 125, 41, 32, 45,
  115, 32, 45, 44, 123, 39, 47, 39, 125, 32, 45, 107, 91, 45, 36, 110,
  98, 95, 100, 111, 119, 110, 45, 45, 49, 93, 32, 45, 114, 101, 112, 108,
  97, 99, 101, 32, 123, 39, 126, 39, 125, 44, 51, 50, 10, 108, 101, 118,
  101, 108, 61, 123, 64, 123, 34, 45, 110, 98, 95, 108, 101, 118, 101, 108,
  115, 32, 34, 36, 112, 97, 116, 104, 125, 45, 36, 110, 98, 95, 117, 112,
  125, 10, 98, 97, 108, 105, 115, 101, 61, 64, 123, 34, 45, 105, 102, 32,
  34, 123, 36, 108, 101, 118, 101, 108, 60, 61, 48, 34, 32, 38, 38, 32,
  34, 123, 36, 110, 112, 97, 116, 104, 39, 33, 61, 39, 47, 65, 98, 111,
  117, 116, 47, 125, 125, 34, 32, 45, 117, 32, 98, 32, 45, 101, 108, 115,
  101, 32, 45, 117, 32, 105, 32, 45, 101, 110, 100, 105, 102, 34, 125, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 99, 111, 109, 109, 97,
  110, 100, 61, 36, 99, 111, 109, 109, 97, 110, 100, 34, 35, 64, 103, 105,
  109, 112, 32, 60, 34, 36, 98, 97, 108, 105, 115, 101, 34, 62, 34, 64,
  123, 36, 62, 44, 116, 125, 34, 60, 47, 34, 36, 98, 97, 108, 105, 115,
  101, 34, 62, 92, 110, 34, 10, 98, 97, 108, 105, 115, 101, 61, 34, 105,
  34, 10, 45, 100, 111, 110, 101, 32, 45, 114, 109, 10, 45, 101, 110, 100,
  108, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 110, 97,
  114, 103, 40, 36, 99, 111, 109, 109, 97, 110, 100, 41, 125, 32, 110, 97,
  109, 101, 61, 64, 123, 48, 44, 110, 125, 32, 45, 105, 91, 48, 93, 32,
  40, 123, 39, 36, 99, 111, 109, 109, 97, 110, 100, 39, 125, 41, 32, 45,
  121, 91, 48, 93, 32, 45, 97, 32, 121, 32, 45, 110, 109, 32, 36, 110,
  97, 109, 101, 10, 45, 101, 110, 100, 105, 102, 10, 112, 97, 116, 104, 61,
  36, 110, 112, 97, 116, 104, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 118, 32, 43, 32, 45,
  101, 91, 93, 32, 34, 62, 32, 83, 97, 118, 101, 32, 111, 117, 116, 112,
  117, 116, 32, 46, 103, 109, 105, 99, 32, 102, 105, 108, 101, 46, 92, 110,
  34, 32, 45, 118, 32, 45, 10, 45, 45, 97, 32, 121, 32, 45, 105, 102,
  32, 123, 104, 62, 49, 125, 32, 45, 114, 91, 45, 49, 93, 32, 49, 44,
  123, 104, 45, 49, 125, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 44,
  49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 111, 91, 45, 49, 93, 32,
  114, 97, 119, 58, 36, 72, 79, 77, 69, 47, 46, 117, 112, 100, 97, 116,
  101, 36, 49, 46, 103, 109, 105, 99, 44, 117, 99, 104, 97, 114, 10, 45,
  120, 32, 34, 115, 99, 112, 32, 34, 36, 72, 79, 77, 69, 47, 46, 117,
  112, 100, 97, 116, 101, 36, 49, 46, 103, 109, 105, 99, 34, 32, 114, 111,
  110, 111, 117, 110, 111, 117, 114, 115, 44, 103, 109, 105, 99, 64, 119, 101,
  98, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101,
  116, 58, 104, 116, 100, 111, 99, 115, 47, 34, 117, 112, 100, 97, 116, 101,
  36, 49, 46, 103, 109, 105, 99, 10, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 105, 102, 32, 36, 50, 10, 45, 118, 32, 43, 32, 45, 101, 91, 93,
  32, 34, 62, 32, 79, 117, 116, 112, 117, 116, 32, 108, 105, 115, 116, 32,
  111, 102, 32, 102, 105, 108, 116, 101, 114, 115, 32, 105, 110, 32, 115, 116,
  100, 111, 117, 116, 46, 92, 110, 34, 32, 45, 118, 32, 45, 10, 45, 101,
  120, 101, 99, 32, 34, 100, 97, 116, 101, 32, 43, 37, 89, 44, 37, 109,
  44, 37, 100, 32, 62, 34, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109,
  112, 125, 47, 100, 97, 116, 101, 46, 100, 108, 109, 10, 64, 123, 45, 112,
  97, 116, 104, 95, 116, 109, 112, 125, 47, 100, 97, 116, 101, 46, 100, 108,
  109, 10, 45, 101, 99, 104, 111, 95, 115, 116, 100, 111, 117, 116, 32, 34,
  42, 42, 42, 32, 76, 105, 115, 116, 32, 111, 102, 32, 102, 105, 108, 116,
  101, 114, 115, 32, 105, 110, 32, 116, 104, 101, 32, 71, 39, 77, 73, 67,
  32, 112, 108, 117, 103, 45, 105, 110, 32, 102, 111, 114, 32, 71, 73, 77,
  80, 32, 40, 34, 36, 110, 98, 95, 102, 105, 108, 116, 101, 114, 115, 34,
  32, 102, 105, 108, 116, 101, 114, 115, 44, 32, 111, 110, 32, 34, 123, 105,
  125, 47, 123, 105, 40, 49, 41, 125, 47, 123, 105, 40, 50, 41, 125, 34,
  41, 32, 42, 42, 42, 92, 110, 34, 10, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 101, 99, 104, 111, 95, 115, 116, 100, 111, 117, 116, 32, 34, 42,
  32, 76, 105, 115, 116, 32, 111, 102, 32, 102, 105, 108, 116, 101, 114, 115,
  44, 32, 115, 111, 114, 116, 101, 100, 32, 98, 121, 32, 112, 97, 116, 104,
  58, 92, 110, 34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 40, 123, 39, 64, 123, 48, 44, 110, 125,
  39, 125, 41, 32, 45, 105, 102, 32, 123, 105, 33, 61, 123, 39, 33, 39,
  125, 125, 10, 45, 114, 91, 45, 49, 93, 32, 123, 119, 45, 49, 125, 44,
  49, 44, 49, 44, 49, 44, 48, 44, 48, 44, 49, 10, 45, 114, 101, 112,
  108, 97, 99, 101, 95, 115, 101, 113, 91, 45, 49, 93, 32, 64, 123, 45,
  113, 117, 111, 116, 101, 92, 32, 123, 39, 38, 97, 109, 112, 59, 39, 125,
  125, 44, 123, 39, 38, 39, 125, 10, 45, 114, 101, 112, 108, 97, 99, 101,
  95, 115, 101, 113, 91, 45, 49, 93, 32, 64, 123, 45, 113, 117, 111, 116,
  101, 92, 32, 123, 39, 34, 38, 35, 50, 51, 51, 59, 34, 39, 125, 125,
  44, 123, 39, 101, 39, 125, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95,
  115, 101, 113, 91, 45, 49, 93, 32, 123, 39, 47, 39, 125, 44, 64, 123,
  45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 126, 47, 126, 39, 125, 125,
  10, 45, 114, 101, 112, 108, 97, 99, 101, 91, 45, 49, 93, 32, 123, 39,
  126, 39, 125, 44, 51, 50, 10, 45, 101, 99, 104, 111, 95, 115, 116, 100,
  111, 117, 116, 91, 93, 32, 34, 32, 32, 34, 64, 123, 45, 49, 44, 116,
  125, 10, 45, 101, 110, 100, 105, 102, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 99,
  104, 111, 95, 115, 116, 100, 111, 117, 116, 32, 34, 92, 110, 42, 32, 76,
  105, 115, 116, 32, 111, 102, 32, 102, 105, 108, 116, 101, 114, 115, 44, 32,
  115, 111, 114, 116, 101, 100, 32, 97, 108, 112, 104, 97, 98, 101, 116, 105,
  99, 97, 108, 108, 121, 58, 92, 110, 34, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 10, 110, 97, 109, 101, 61, 64, 123, 36, 62, 44, 98,
  125, 10, 112, 97, 116, 104, 61, 64, 123, 36, 62, 44, 102, 125, 10, 45,
  110, 109, 91, 36, 62, 93, 32, 36, 110, 97, 109, 101, 34, 126, 40, 105,
  110, 126, 39, 34, 36, 112, 97, 116, 104, 34, 39, 41, 34, 10, 45, 100,
  111, 110, 101, 10, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103, 109, 105,
  99, 95, 103, 105, 109, 112, 95, 115, 111, 114, 116, 32, 48, 44, 123, 64,
  35, 45, 49, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 40, 123, 39, 64, 123, 48, 44, 110, 125,
  39, 125, 41, 32, 45, 105, 102, 32, 123, 105, 33, 61, 123, 39, 33, 39,
  125, 125, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 91,
  45, 49, 93, 32, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 123, 39,
  38, 97, 109, 112, 59, 39, 125, 125, 44, 123, 39, 38, 39, 125, 10, 45,
  114, 101, 112, 108, 97, 99, 101, 95, 115, 101, 113, 91, 45, 49, 93, 32,
  64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 123, 39, 34, 38, 35, 50,
  51, 51, 59, 34, 39, 125, 125, 44, 123, 39, 101, 39, 125, 10, 45, 114,
  101, 112, 108, 97, 99, 101, 91, 45, 49, 93, 32, 123, 39, 126, 39, 125,
  44, 51, 50, 10, 45, 101, 99, 104, 111, 95, 115, 116, 100, 111, 117, 116,
  91, 93, 32, 34, 32, 32, 34, 64, 123, 45, 49, 44, 116, 125, 10, 45,
  101, 110, 100, 105, 102, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 99, 104, 111, 95,
  115, 116, 100, 111, 117, 116, 32, 34, 92, 110, 42, 42, 42, 32, 69, 110,
  100, 32, 111, 102, 32, 108, 105, 115, 116, 32, 42, 42, 42, 92, 110, 34,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 32, 45, 118, 32, 43,
  32, 45, 101, 91, 93, 32, 34, 62, 32, 65, 108, 108, 32, 100, 111, 110,
  101, 32, 33, 92, 110, 34, 10, 95, 117, 112, 100, 97, 116, 101, 95, 103,
  109, 105, 99, 95, 103, 105, 109, 112, 95, 115, 111, 114, 116, 32, 58, 10,
  109, 105, 100, 61, 123, 105, 110, 116, 40, 40, 36, 49, 43, 36, 50, 41,
  47, 50, 41, 125, 10, 45, 105, 102, 32, 64, 123, 34, 45, 95, 109, 97,
  120, 91, 93, 32, 34, 64, 123, 36, 49, 44, 110, 125, 44, 64, 123, 36,
  109, 105, 100, 44, 110, 125, 125, 32, 45, 114, 118, 91, 36, 49, 44, 36,
  109, 105, 100, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  64, 123, 34, 45, 95, 109, 97, 120, 91, 93, 32, 34, 64, 123, 36, 109,
  105, 100, 44, 110, 125, 44, 64, 123, 36, 50, 44, 110, 125, 125, 32, 45,
  114, 118, 91, 36, 50, 44, 36, 109, 105, 100, 93, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 64, 123, 34, 45, 95, 109, 97, 120, 91,
  93, 32, 34, 64, 123, 36, 49, 44, 110, 125, 44, 64, 123, 36, 109, 105,
  100, 44, 110, 125, 125, 32, 45, 114, 118, 91, 36, 49, 44, 36, 109, 105,
  100, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  50, 45, 36, 49, 62, 61, 51, 125, 10, 112, 105, 118, 111, 116, 61, 64,
  123, 36, 109, 105, 100, 44, 110, 125, 10, 105, 61, 36, 49, 32, 106, 61,
  36, 50, 10, 45, 100, 111, 10, 45, 105, 102, 32, 64, 123, 34, 45, 95,
  109, 97, 120, 91, 93, 32, 34, 36, 112, 105, 118, 111, 116, 44, 64, 123,
  36, 105, 44, 110, 125, 125, 32, 45, 100, 111, 32, 105, 61, 123, 36, 105,
  43, 49, 125, 32, 45, 119, 104, 105, 108, 101, 32, 64, 123, 34, 45, 95,
  109, 97, 120, 91, 93, 32, 34, 36, 112, 105, 118, 111, 116, 44, 64, 123,
  36, 105, 44, 110, 125, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 64, 123, 34, 45, 95, 109, 97, 120, 91, 93, 32, 34, 64, 123,
  36, 106, 44, 110, 125, 44, 36, 112, 105, 118, 111, 116, 125, 32, 45, 100,
  111, 32, 106, 61, 123, 36, 106, 45, 49, 125, 32, 45, 119, 104, 105, 108,
  101, 32, 64, 123, 34, 45, 95, 109, 97, 120, 91, 93, 32, 34, 64, 123,
  36, 106, 44, 110, 125, 44, 36, 112, 105, 118, 111, 116, 125, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 105, 60, 61, 36, 106,
  125, 32, 45, 114, 118, 91, 36, 105, 44, 36, 106, 93, 32, 105, 61, 123,
  36, 105, 43, 49, 125, 32, 106, 61, 123, 36, 106, 45, 49, 125, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32, 123, 36, 105,
  60, 61, 36, 106, 125, 10, 45, 105, 102, 32, 123, 36, 49, 60, 36, 106,
  125, 32, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103, 109, 105, 99, 95,
  103, 105, 109, 112, 95, 115, 111, 114, 116, 32, 36, 49, 44, 36, 106, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 105, 60, 36,
  50, 125, 32, 45, 95, 117, 112, 100, 97, 116, 101, 95, 103, 109, 105, 99,
  95, 103, 105, 109, 112, 95, 115, 111, 114, 116, 32, 36, 105, 44, 36, 50,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 95,
  117, 112, 100, 97, 116, 101, 95, 103, 109, 105, 99, 95, 103, 105, 109, 112,
  95, 109, 111, 118, 101, 32, 58, 10, 45, 105, 102, 32, 123, 33, 110, 97,
  114, 103, 40, 36, 95, 110, 98, 109, 41, 125, 32, 95, 110, 98, 109, 61,
  48, 32, 45, 101, 110, 100, 105, 102, 10, 95, 116, 111, 95, 109, 111, 118,
  101, 36, 123, 95, 110, 98, 109, 125, 61, 34, 36, 49, 34, 32, 95, 109,
  111, 118, 101, 95, 116, 111, 36, 123, 95, 110, 98, 109, 125, 61, 34, 36,
  50, 34, 32, 95, 110, 98, 109, 61, 123, 36, 95, 110, 98, 109, 43, 49,
  125, 10, 95, 98, 101, 102, 111, 114, 101, 32, 58, 10, 51, 51, 44, 49,
  49, 32, 45, 116, 91, 45, 49, 93, 32, 34, 66, 101, 102, 111, 114, 101,
  34, 44, 49, 44, 45, 49, 44, 49, 51, 44, 49, 44, 49, 10, 95, 97,
  102, 116, 101, 114, 32, 58, 10, 50, 54, 44, 49, 49, 32, 45, 116, 91,
  45, 49, 93, 32, 34, 65, 102, 116, 101, 114, 34, 44, 49, 44, 45, 49,
  44, 49, 51, 44, 49, 44, 49, 10, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 10, 45, 105, 102, 32, 123, 36, 50, 61,
  61, 48, 125, 32, 45, 101, 91, 93, 32, 34, 36, 49, 34, 32, 45, 108,
  91, 45, 49, 93, 32, 36, 49, 32, 45, 101, 110, 100, 108, 32, 45, 109,
  118, 91, 45, 49, 93, 32, 48, 32, 45, 99, 111, 110, 116, 105, 110, 117,
  101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 33, 40,
  36, 50, 37, 50, 41, 125, 10, 45, 115, 91, 45, 49, 93, 32, 120, 44,
  50, 10, 45, 105, 102, 32, 123, 36, 50, 61, 61, 50, 125, 32, 45, 108,
  91, 45, 49, 93, 32, 36, 49, 32, 45, 101, 110, 100, 108, 32, 45, 116,
  111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 91, 45, 50, 44, 45,
  49, 93, 32, 48, 32, 45, 95, 98, 101, 102, 111, 114, 101, 32, 45, 95,
  97, 102, 116, 101, 114, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 61,
  61, 52, 125, 32, 45, 108, 91, 45, 50, 93, 32, 36, 49, 32, 45, 101,
  110, 100, 108, 32, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100,
  101, 91, 45, 50, 44, 45, 49, 93, 32, 48, 32, 45, 95, 97, 102, 116,
  101, 114, 32, 45, 95, 98, 101, 102, 111, 114, 101, 10, 45, 101, 108, 115,
  101, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 45, 108, 91, 45, 49,
  93, 32, 36, 49, 32, 45, 101, 110, 100, 108, 32, 45, 116, 111, 95, 99,
  111, 108, 111, 114, 109, 111, 100, 101, 91, 45, 50, 44, 45, 49, 93, 32,
  48, 32, 45, 95, 98, 101, 102, 111, 114, 101, 32, 45, 95, 97, 102, 116,
  101, 114, 10, 45, 101, 110, 100, 105, 102, 10, 45, 108, 105, 110, 101, 91,
  45, 51, 93, 32, 48, 44, 48, 44, 48, 44, 64, 123, 45, 51, 44, 104,
  125, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 32, 45, 97,
  91, 45, 52, 44, 45, 51, 93, 32, 120, 10, 45, 101, 108, 115, 101, 10,
  45, 115, 91, 45, 49, 93, 32, 121, 44, 50, 10, 45, 105, 102, 32, 123,
  36, 50, 61, 61, 49, 125, 32, 45, 108, 91, 45, 49, 93, 32, 36, 49,
  32, 45, 101, 110, 100, 108, 32, 45, 116, 111, 95, 99, 111, 108, 111, 114,
  109, 111, 100, 101, 91, 45, 50, 44, 45, 49, 93, 32, 123, 109, 97, 120,
  40, 64, 123, 45, 50, 44, 115, 125, 44, 115, 41, 125, 32, 45, 95, 98,
  101, 102, 111, 114, 101, 32, 45, 95, 97, 102, 116, 101, 114, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 50, 61, 61, 51, 125, 32, 45, 108, 91, 45,
  50, 93, 32, 36, 49, 32, 45, 101, 110, 100, 108, 32, 45, 116, 111, 95,
  99, 111, 108, 111, 114, 109, 111, 100, 101, 91, 45, 50, 44, 45, 49, 93,
  32, 123, 109, 97, 120, 40, 64, 123, 45, 50, 44, 115, 125, 44, 115, 41,
  125, 32, 45, 95, 97, 102, 116, 101, 114, 32, 45, 95, 98, 101, 102, 111,
  114, 101, 10, 45, 101, 108, 115, 101, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 45, 108, 91, 45, 49, 93, 32, 36, 49, 32, 45, 101, 110, 100,
  108, 32, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 91,
  45, 50, 44, 45, 49, 93, 32, 48, 32, 45, 95, 98, 101, 102, 111, 114,
  101, 32, 45, 95, 97, 102, 116, 101, 114, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 108, 105, 110, 101, 91, 45, 51, 93, 32, 48, 44, 48, 44, 64,
  123, 45, 51, 44, 119, 125, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48,
  44, 50, 53, 53, 32, 45, 97, 91, 45, 52, 44, 45, 51, 93, 32, 121,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 45, 100, 105, 108, 97, 116, 101,
  91, 45, 50, 44, 45, 49, 93, 32, 51, 32, 45, 42, 91, 45, 52, 44,
  45, 51, 93, 32, 50, 53, 53, 32, 45, 116, 111, 95, 99, 111, 108, 111,
  114, 109, 111, 100, 101, 91, 45, 52, 44, 45, 51, 93, 32, 64, 123, 45,
  53, 44, 115, 125, 10, 45, 106, 91, 45, 53, 93, 32, 91, 45, 52, 93,
  44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46, 56, 44, 91, 45, 50,
  93, 32, 45, 106, 91, 45, 53, 93, 32, 91, 45, 51, 93, 44, 123, 64,
  123, 45, 53, 44, 119, 125, 45, 119, 45, 49, 125, 44, 123, 64, 123, 45,
  53, 44, 104, 125, 45, 104, 45, 49, 125, 44, 48, 44, 48, 44, 48, 46,
  56, 44, 91, 45, 49, 93, 10, 45, 114, 109, 91, 45, 52, 45, 45, 49,
  93, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110,
  101, 10, 103, 105, 109, 112, 95, 110, 111, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 110, 111, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 78, 111, 32, 112, 114, 101, 118, 105, 101,
  119, 92, 110, 97, 118, 97, 105, 108, 97, 98, 108, 101, 34, 44, 34, 36,
  42, 34, 10, 95, 103, 105, 109, 112, 95, 110, 111, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 105, 102, 32, 123, 64, 35, 62, 48, 125,
  32, 45, 107, 91, 48, 93, 32, 45, 101, 108, 115, 101, 32, 50, 53, 54,
  44, 50, 53, 54, 44, 49, 44, 49, 44, 49, 50, 56, 32, 45, 101, 110,
  100, 105, 102, 10, 49, 49, 56, 44, 53, 48, 32, 45, 116, 91, 45, 49,
  93, 32, 34, 36, 49, 34, 44, 50, 44, 49, 44, 50, 52, 44, 49, 44,
  50, 53, 53, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44,
  91, 45, 50, 93, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53,
  44, 48, 46, 53, 32, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111,
  100, 101, 91, 45, 49, 93, 32, 64, 123, 45, 50, 44, 115, 125, 10, 40,
  49, 46, 53, 44, 48, 44, 49, 46, 53, 59, 48, 44, 48, 44, 48, 59,
  49, 46, 53, 44, 48, 44, 49, 46, 53, 41, 32, 45, 114, 91, 45, 49,
  93, 32, 91, 45, 51, 93, 44, 51, 32, 45, 42, 91, 45, 51, 44, 45,
  49, 93, 32, 45, 99, 91, 45, 50, 93, 32, 48, 44, 50, 53, 53, 32,
  45, 111, 114, 10, 45, 115, 107, 105, 112, 32, 34, 36, 42, 34, 10, 35,
  64, 103, 105, 109, 112, 32, 60, 105, 62, 65, 98, 111, 117, 116, 60, 47,
  105, 62, 10, 35, 64, 103, 105, 109, 112, 32, 67, 111, 110, 116, 114, 105,
  98, 117, 116, 111, 114, 115, 32, 58, 32, 95, 110, 111, 110, 101, 95, 44,
  32, 95, 110, 111, 110, 101, 95, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 87, 101, 32, 119, 111, 117, 108, 100,
  32, 108, 105, 107, 101, 32, 116, 111, 32, 116, 104, 97, 110, 107, 32, 97,
  108, 108, 32, 116, 104, 101, 115, 101, 32, 112, 101, 111, 112, 108, 101, 32,
  119, 104, 111, 32, 99, 111, 110, 116, 114, 105, 98, 117, 116, 101, 100, 32,
  116, 111, 32, 60, 98, 62, 71, 39, 77, 73, 67, 60, 47, 98, 62, 32,
  105, 110, 32, 111, 110, 101, 32, 119, 97, 121, 32, 111, 114, 32, 97, 110,
  111, 116, 104, 101, 114, 46, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  65, 32, 98, 105, 103, 32, 104, 117, 103, 32, 116, 111, 32, 58, 32, 92,
  110, 92, 110, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 98, 62,
  32, 45, 60, 47, 98, 62, 32, 60, 105, 62, 83, 121, 108, 118, 105, 101,
  32, 65, 108, 101, 120, 97, 110, 100, 114, 101, 60, 47, 105, 62, 32, 60,
  115, 109, 97, 108, 108, 62, 40, 112, 97, 99, 107, 97, 103, 105, 110, 103,
  44, 32, 116, 101, 115, 116, 105, 110, 103, 32, 38, 97, 109, 112, 59, 32,
  102, 105, 108, 116, 101, 114, 115, 41, 60, 47, 115, 109, 97, 108, 108, 62,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 98, 62, 32, 45, 60,
  47, 98, 62, 32, 60, 105, 62, 80, 97, 114, 116, 104, 97, 32, 66, 97,
  103, 99, 104, 105, 60, 47, 105, 62, 32, 60, 115, 109, 97, 108, 108, 62,
  40, 112, 97, 99, 107, 97, 103, 105, 110, 103, 41, 60, 47, 115, 109, 97,
  108, 108, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 98, 62,
  32, 45, 60, 47, 98, 62, 32, 60, 105, 62, 83, 38, 35, 50, 51, 51,
  59, 98, 97, 115, 116, 105, 101, 110, 32, 66, 111, 117, 103, 108, 101, 117,
  120, 60, 47, 105, 62, 32, 60, 115, 109, 97, 108, 108, 62, 40, 100, 101,
  98, 117, 103, 103, 105, 110, 103, 41, 60, 47, 115, 109, 97, 108, 108, 62,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 98, 62, 32, 45, 60,
  47, 98, 62, 32, 60, 105, 62, 74, 38, 35, 50, 51, 51, 59, 114, 111,
  109, 101, 32, 66, 111, 117, 108, 97, 110, 103, 101, 114, 60, 47, 105, 62,
  32, 60, 115, 109, 97, 108, 108, 62, 40, 116, 101, 115, 116, 105, 110, 103,
  32, 38, 97, 109, 112, 59, 32, 99, 111, 100, 101, 41, 60, 47, 115, 109,
  97, 108, 108, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 98,
  62, 32, 45, 60, 47, 98, 62, 32, 60, 105, 62, 67, 108, 97, 117, 100,
  101, 32, 66, 117, 108, 105, 110, 60, 47, 105, 62, 32, 60, 115, 109, 97,
  108, 108, 62, 40, 112, 97, 99, 107, 97, 103, 105, 110, 103, 41, 60, 47,
  115, 109, 97, 108, 108, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  60, 98, 62, 32, 45, 60, 47, 98, 62, 32, 60, 105, 62, 65, 117, 114,
  38, 35, 50, 51, 51, 59, 108, 105, 101, 110, 32, 67, 101, 121, 100, 101,
  110, 60, 47, 105, 62, 32, 60, 115, 109, 97, 108, 108, 62, 40, 112, 97,
  99, 107, 97, 103, 105, 110, 103, 41, 60, 47, 115, 109, 97, 108, 108, 62,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 98, 62, 32, 45, 60,
  47, 98, 62, 32, 60, 105, 62, 70, 114, 97, 110, 38, 35, 50, 51, 49,
  59, 111, 105, 115, 32, 67, 111, 108, 108, 97, 114, 100, 60, 47, 105, 62,
  32, 60, 115, 109, 97, 108, 108, 62, 40, 116, 101, 115, 116, 105, 110, 103,
  41, 60, 47, 115, 109, 97, 108, 108, 62, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 60, 98, 62, 32, 45, 60, 47, 98, 62, 32, 60, 105, 62,
  80, 97, 116, 114, 105, 99, 107, 32, 68, 97, 118, 105, 100, 60, 47, 105,
  62, 32, 60, 115, 109, 97, 108, 108, 62, 40, 116, 101, 115, 116, 105, 110,
  103, 32, 38, 97, 109, 112, 59, 32, 102, 105, 108, 116, 101, 114, 115, 41,
  60, 47, 115, 109, 97, 108, 108, 62, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 60, 98, 62, 32, 45, 60, 47, 98, 62, 32, 60, 105, 62, 77,
  97, 120, 105, 109, 101, 32, 68, 97, 105, 115, 121, 60, 47, 105, 62, 32,
  60, 115, 109, 97, 108, 108, 62, 40, 99, 111, 100, 101, 32, 38, 97, 109,
  112, 59, 32, 116, 101, 115, 116, 105, 110, 103, 41, 60, 47, 115, 109, 97,
  108, 108, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 98, 62,
  32, 45, 60, 47, 98, 62, 32, 60, 105, 62, 73, 97, 105, 110, 32, 70,
  101, 114, 103, 117, 115, 115, 111, 110, 60, 47, 105, 62, 32, 60, 115, 109,
  97, 108, 108, 62, 40, 102, 105, 108, 116, 101, 114, 115, 41, 60, 47, 115,
  109, 97, 108, 108, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60,
  98, 62, 32, 45, 60, 47, 98, 62, 32, 60, 105, 62, 82, 111, 98, 101,
  114, 116, 111, 32, 70, 101, 114, 114, 97, 109, 111, 115, 99, 97, 60, 47,
  105, 62, 32, 60, 115, 109, 97, 108, 108, 62, 40, 112, 97, 99, 107, 97,
  103, 105, 110, 103, 41, 60, 47, 115, 109, 97, 108, 108, 62, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 60, 98, 62, 32, 45, 60, 47, 98, 62,
  32, 60, 105, 62, 74, 38, 35, 50, 51, 51, 59, 114, 111, 109, 101, 32,
  70, 101, 114, 114, 97, 114, 105, 60, 47, 105, 62, 32, 60, 115, 109, 97,
  108, 108, 62, 40, 116, 101, 115, 116, 105, 110, 103, 44, 32, 99, 111, 100,
  101, 32, 38, 97, 109, 112, 59, 32, 116, 117, 116, 111, 114, 105, 97, 108,
  115, 41, 60, 47, 115, 109, 97, 108, 108, 62, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 60, 98, 62, 32, 45, 60, 47, 98, 62, 32, 60, 105,
  62, 67, 104, 114, 105, 115, 32, 70, 105, 101, 100, 108, 101, 114, 60, 47,
  105, 62, 32, 60, 115, 109, 97, 108, 108, 62, 40, 103, 102, 120, 41, 60,
  47, 115, 109, 97, 108, 108, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 60, 98, 62, 32, 45, 60, 47, 98, 62, 32, 60, 105, 62, 83, 38,
  35, 50, 51, 51, 59, 98, 97, 115, 116, 105, 101, 110, 32, 70, 111, 117,
  114, 101, 121, 60, 47, 105, 62, 32, 60, 115, 109, 97, 108, 108, 62, 40,
  90, 65, 114, 116, 32, 99, 111, 100, 101, 32, 38, 97, 109, 112, 59, 32,
  71, 39, 77, 73, 67, 32, 111, 110, 108, 105, 110, 101, 41, 60, 47, 115,
  109, 97, 108, 108, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60,
  98, 62, 32, 45, 60, 47, 98, 62, 32, 60, 105, 62, 71, 101, 110, 116,
  108, 101, 109, 97, 110, 98, 101, 103, 103, 97, 114, 60, 47, 105, 62, 32,
  60, 115, 109, 97, 108, 108, 62, 40, 102, 105, 108, 116, 101, 114, 115, 41,
  60, 47, 115, 109, 97, 108, 108, 62, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 60, 98, 62, 32, 45, 60, 47, 98, 62, 32, 60, 105, 62, 67,
  108, 97, 101, 115, 32, 72, 111, 108, 109, 101, 114, 115, 111, 110, 60, 47,
  105, 62, 32, 60, 115, 109, 97, 108, 108, 62, 40, 116, 117, 116, 111, 114,
  105, 97, 108, 115, 41, 60, 47, 115, 109, 97, 108, 108, 62, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 60, 98, 62, 32, 45, 60, 47, 98, 62,
  32, 60, 105, 62, 65, 114, 116, 111, 32, 72, 117, 111, 116, 97, 114, 105,
  60, 47, 105, 62, 32, 60, 115, 109, 97, 108, 108, 62, 40, 102, 105, 108,
  116, 101, 114, 115, 41, 60, 47, 115, 109, 97, 108, 108, 62, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 60, 98, 62, 32, 45, 60, 47, 98, 62,
  32, 60, 105, 62, 68, 97, 110, 32, 76, 101, 105, 110, 105, 114, 32, 84,
  117, 114, 116, 104, 114, 97, 32, 74, 101, 110, 115, 101, 110, 60, 47, 105,
  62, 32, 60, 115, 109, 97, 108, 108, 62, 40, 100, 101, 98, 117, 103, 103,
  105, 110, 103, 41, 60, 47, 115, 109, 97, 108, 108, 62, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 60, 98, 62, 32, 45, 60, 47, 98, 62, 32,
  60, 105, 62, 84, 111, 109, 32, 75, 101, 105, 108, 60, 47, 105, 62, 32,
  60, 115, 109, 97, 108, 108, 62, 40, 116, 101, 115, 116, 105, 110, 103, 44,
  32, 102, 105, 108, 116, 101, 114, 115, 32, 38, 97, 109, 112, 59, 32, 116,
  117, 116, 111, 114, 105, 97, 108, 115, 41, 60, 47, 115, 109, 97, 108, 108,
  62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 98, 62, 32, 45,
  60, 47, 98, 62, 32, 60, 105, 62, 65, 110, 100, 121, 32, 75, 101, 108,
  100, 97, 121, 60, 47, 105, 62, 32, 60, 115, 109, 97, 108, 108, 62, 40,
  116, 101, 115, 116, 105, 110, 103, 32, 38, 97, 109, 112, 59, 32, 102, 105,
  108, 116, 101, 114, 115, 41, 60, 47, 115, 109, 97, 108, 108, 62, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 60, 98, 62, 32, 45, 60, 47, 98,
  62, 32, 60, 105, 62, 65, 110, 103, 101, 108, 111, 32, 76, 97, 109, 97,
  60, 47, 105, 62, 32, 60, 115, 109, 97, 108, 108, 62, 40, 116, 101, 115,
  116, 105, 110, 103, 32, 38, 97, 109, 112, 59, 32, 69, 75, 68, 32, 105,
  110, 116, 101, 103, 114, 97, 116, 105, 111, 110, 41, 60, 47, 115, 109, 97,
  108, 108, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 98, 62,
  32, 45, 60, 47, 98, 62, 32, 60, 105, 62, 74, 111, 104, 110, 32, 76,
  97, 107, 107, 97, 115, 60, 47, 105, 62, 32, 60, 115, 109, 97, 108, 108,
  62, 40, 102, 105, 108, 116, 101, 114, 115, 41, 60, 47, 115, 109, 97, 108,
  108, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 98, 62, 32,
  45, 60, 47, 98, 62, 32, 60, 105, 62, 83, 116, 38, 35, 50, 51, 51,
  59, 112, 104, 97, 110, 101, 32, 100, 101, 32, 108, 97, 32, 76, 105, 110,
  117, 120, 101, 114, 105, 101, 60, 47, 105, 62, 32, 60, 115, 109, 97, 108,
  108, 62, 40, 100, 101, 115, 105, 103, 110, 41, 60, 47, 115, 109, 97, 108,
  108, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 98, 62, 32,
  45, 60, 47, 98, 62, 32, 60, 105, 62, 77, 97, 114, 107, 60, 47, 105,
  62, 32, 60, 115, 109, 97, 108, 108, 62, 40, 116, 114, 97, 110, 115, 108,
  97, 116, 105, 111, 110, 41, 60, 47, 115, 109, 97, 108, 108, 62, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 60, 98, 62, 32, 45, 60, 47, 98,
  62, 32, 60, 105, 62, 77, 97, 104, 118, 105, 110, 60, 47, 105, 62, 32,
  60, 115, 109, 97, 108, 108, 62, 40, 116, 101, 115, 116, 105, 110, 103, 32,
  38, 97, 109, 112, 59, 32, 100, 101, 115, 105, 103, 110, 41, 60, 47, 115,
  109, 97, 108, 108, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60,
  98, 62, 32, 45, 60, 47, 98, 62, 32, 60, 105, 62, 77, 97, 114, 101,
  114, 111, 81, 60, 47, 105, 62, 32, 60, 115, 109, 97, 108, 108, 62, 40,
  116, 114, 97, 110, 115, 108, 97, 116, 105, 111, 110, 41, 60, 47, 115, 109,
  97, 108, 108, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 98,
  62, 32, 45, 60, 47, 98, 62, 32, 60, 105, 62, 82, 97, 109, 111, 110,
  32, 77, 105, 114, 97, 110, 100, 97, 60, 47, 105, 62, 32, 60, 115, 109,
  97, 108, 108, 62, 40, 116, 114, 97, 110, 115, 108, 97, 116, 105, 111, 110,
  41, 60, 47, 115, 109, 97, 108, 108, 62, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 60, 98, 62, 32, 45, 60, 47, 98, 62, 32, 60, 105, 62,
  77, 97, 117, 114, 111, 32, 81, 117, 101, 114, 99, 105, 97, 60, 47, 105,
  62, 32, 60, 115, 109, 97, 108, 108, 62, 40, 116, 114, 97, 110, 115, 108,
  97, 116, 105, 111, 110, 41, 60, 47, 115, 109, 97, 108, 108, 62, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 60, 98, 62, 32, 45, 60, 47, 98,
  62, 32, 60, 105, 62, 80, 104, 111, 116, 111, 67, 111, 109, 105, 88, 60,
  47, 105, 62, 32, 60, 115, 109, 97, 108, 108, 62, 40, 116, 101, 115, 116,
  105, 110, 103, 44, 32, 116, 114, 97, 110, 115, 108, 97, 116, 105, 111, 110,
  32, 38, 97, 109, 112, 59, 32, 102, 105, 108, 116, 101, 114, 115, 41, 60,
  47, 115, 109, 97, 108, 108, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 60, 98, 62, 32, 45, 60, 47, 98, 62, 32, 60, 105, 62, 74, 97,
  109, 101, 115, 32, 80, 114, 105, 99, 104, 97, 114, 100, 60, 47, 105, 62,
  32, 60, 115, 109, 97, 108, 108, 62, 40, 116, 101, 115, 116, 105, 110, 103,
  32, 38, 97, 109, 112, 59, 32, 102, 105, 108, 116, 101, 114, 115, 41, 60,
  47, 115, 109, 97, 108, 108, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 60, 98, 62, 32, 45, 60, 47, 98, 62, 32, 60, 105, 62, 71, 117,
  105, 108, 104, 101, 114, 109, 101, 32, 82, 97, 122, 103, 114, 105, 122, 60,
  47, 105, 62, 32, 60, 115, 109, 97, 108, 108, 62, 40, 116, 114, 97, 110,
  115, 108, 97, 116, 105, 111, 110, 41, 60, 47, 115, 109, 97, 108, 108, 62,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 98, 62, 32, 45, 60,
  47, 98, 62, 32, 60, 105, 62, 75, 97, 114, 115, 116, 101, 110, 32, 82,
  111, 100, 101, 110, 97, 99, 107, 101, 114, 60, 47, 105, 62, 32, 60, 115,
  109, 97, 108, 108, 62, 40, 112, 97, 99, 107, 97, 103, 105, 110, 103, 32,
  38, 97, 109, 112, 59, 32, 99, 111, 100, 101, 41, 60, 47, 115, 109, 97,
  108, 108, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 98, 62,
  32, 45, 60, 47, 98, 62, 32, 60, 105, 62, 68, 97, 110, 105, 32, 83,
  97, 114, 100, 38, 35, 50, 50, 52, 59, 60, 47, 105, 62, 32, 60, 115,
  109, 97, 108, 108, 62, 40, 116, 114, 97, 110, 115, 108, 97, 116, 105, 111,
  110, 41, 60, 47, 115, 109, 97, 108, 108, 62, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 60, 98, 62, 32, 45, 60, 47, 98, 62, 32, 60, 105,
  62, 89, 117, 114, 105, 32, 83, 104, 101, 109, 97, 110, 105, 110, 60, 47,
  105, 62, 32, 60, 115, 109, 97, 108, 108, 62, 40, 100, 101, 98, 117, 103,
  103, 105, 110, 103, 41, 60, 47, 115, 109, 97, 108, 108, 62, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 60, 98, 62, 32, 45, 60, 47, 98, 62,
  32, 60, 105, 62, 84, 104, 111, 114, 115, 116, 101, 110, 32, 34, 111, 116,
  116, 111, 34, 32, 83, 116, 101, 116, 116, 105, 110, 60, 47, 105, 62, 32,
  60, 115, 109, 97, 108, 108, 62, 40, 112, 97, 99, 107, 97, 103, 105, 110,
  103, 41, 60, 47, 115, 109, 97, 108, 108, 62, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 60, 98, 62, 32, 45, 60, 47, 98, 62, 32, 60, 105,
  62, 83, 116, 101, 112, 97, 110, 101, 107, 111, 115, 60, 47, 105, 62, 32,
  60, 115, 109, 97, 108, 108, 62, 40, 116, 114, 97, 110, 115, 108, 97, 116,
  105, 111, 110, 41, 60, 47, 115, 109, 97, 108, 108, 62, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 60, 98, 62, 32, 45, 60, 47, 98, 62, 32,
  60, 105, 62, 66, 101, 114, 110, 100, 32, 90, 101, 105, 109, 101, 116, 122,
  60, 47, 105, 62, 32, 60, 115, 109, 97, 108, 108, 62, 40, 112, 97, 99,
  107, 97, 103, 105, 110, 103, 41, 60, 47, 115, 109, 97, 108, 108, 62, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 98, 62, 32, 45, 60, 47,
  98, 62, 32, 60, 105, 62, 77, 97, 116, 116, 104, 105, 97, 115, 32, 90,
  101, 112, 112, 101, 114, 60, 47, 105, 62, 32, 60, 115, 109, 97, 108, 108,
  62, 40, 116, 101, 115, 116, 105, 110, 103, 41, 60, 47, 115, 109, 97, 108,
  108, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 98, 62, 32,
  45, 60, 47, 98, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32,
  60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112,
  101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48, 51, 47, 51, 48,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 70, 105, 108, 116, 101, 114, 32, 100, 101,
  115, 105, 103, 110, 32, 58, 32, 95, 110, 111, 110, 101, 95, 44, 32, 95,
  110, 111, 110, 101, 95, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 60, 98, 62, 71, 39, 77, 73, 67, 60, 47,
  98, 62, 32, 105, 115, 32, 97, 110, 32, 60, 98, 62, 111, 112, 101, 110,
  60, 47, 98, 62, 32, 105, 109, 97, 103, 101, 32, 112, 114, 111, 99, 101,
  115, 115, 105, 110, 103, 32, 102, 114, 97, 109, 101, 119, 111, 114, 107, 46,
  32, 84, 104, 117, 115, 44, 32, 105, 110, 99, 108, 117, 100, 105, 110, 103,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 98, 62, 117, 115, 101,
  114, 45, 100, 101, 102, 105, 110, 101, 100, 32, 102, 105, 108, 116, 101, 114,
  115, 60, 47, 98, 62, 32, 105, 110, 116, 111, 32, 116, 104, 105, 115, 32,
  112, 108, 117, 103, 45, 105, 110, 32, 105, 115, 32, 112, 111, 115, 115, 105,
  98, 108, 101, 46, 92, 110, 92, 110, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 84, 111, 32, 100, 111, 32, 115, 111, 44, 32, 121, 111, 117, 32,
  110, 101, 101, 100, 32, 116, 111, 32, 99, 114, 101, 97, 116, 101, 32, 97,
  32, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110,
  100, 32, 61, 34, 112, 117, 114, 112, 108, 101, 34, 32, 115, 116, 121, 108,
  101, 61, 34, 105, 116, 97, 108, 105, 99, 34, 62, 46, 103, 109, 105, 99,
  60, 47, 115, 112, 97, 110, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 102, 105, 108, 101, 32, 105, 110, 32, 121, 111, 117, 114, 32, 60, 105,
  62, 72, 111, 109, 101, 60, 47, 105, 62, 32, 102, 111, 108, 100, 101, 114,
  32, 40, 111, 114, 32, 60, 105, 62, 65, 112, 112, 108, 105, 99, 97, 116,
  105, 111, 110, 115, 32, 68, 97, 116, 97, 47, 60, 47, 105, 62, 32, 111,
  110, 32, 87, 105, 110, 100, 111, 119, 115, 44, 32, 119, 105, 116, 104, 111,
  117, 116, 32, 116, 104, 101, 32, 102, 105, 114, 115, 116, 32, 100, 111, 116,
  41, 46, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 32, 119,
  105, 108, 108, 32, 98, 101, 32, 114, 101, 97, 100, 32, 101, 97, 99, 104,
  32, 116, 105, 109, 101, 32, 116, 104, 101, 32, 112, 108, 117, 103, 45, 105,
  110, 32, 105, 115, 32, 108, 97, 117, 110, 99, 104, 101, 100, 44, 32, 111,
  114, 32, 119, 104, 101, 110, 32, 116, 104, 101, 32, 60, 105, 62, 82, 101,
  102, 114, 101, 115, 104, 60, 47, 105, 62, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 98, 117, 116, 116, 111, 110, 32, 40, 117, 110, 100, 101, 114,
  32, 116, 104, 101, 32, 99, 101, 110, 116, 114, 97, 108, 32, 112, 97, 110,
  101, 41, 32, 105, 115, 32, 112, 114, 101, 115, 115, 101, 100, 46, 32, 73,
  116, 32, 109, 117, 115, 116, 32, 98, 101, 32, 97, 32, 114, 101, 103, 117,
  108, 97, 114, 32, 65, 83, 67, 73, 73, 32, 102, 105, 108, 101, 44, 32,
  99, 111, 110, 116, 97, 105, 110, 105, 110, 103, 32, 116, 104, 101, 32, 100,
  101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 115, 32, 97, 110, 100, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 105, 109, 112, 108, 101, 109, 101,
  110, 116, 97, 116, 105, 111, 110, 115, 32, 111, 102, 32, 116, 104, 101, 32,
  102, 105, 108, 116, 101, 114, 115, 32, 40, 119, 114, 105, 116, 116, 101, 110,
  32, 105, 110, 32, 116, 104, 101, 32, 60, 98, 62, 71, 39, 77, 73, 67,
  60, 47, 98, 62, 32, 108, 97, 110, 103, 117, 97, 103, 101, 41, 32, 116,
  104, 97, 116, 32, 119, 105, 108, 108, 32, 98, 101, 32, 97, 100, 100, 101,
  100, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 116, 111, 32, 116, 104,
  101, 32, 108, 105, 115, 116, 32, 111, 102, 32, 97, 118, 97, 105, 108, 97,
  98, 108, 101, 32, 111, 110, 101, 115, 46, 34, 125, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  123, 34, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 120, 105, 115,
  116, 105, 110, 103, 32, 102, 105, 108, 116, 101, 114, 115, 32, 97, 114, 101,
  32, 97, 108, 114, 101, 97, 100, 121, 32, 100, 101, 102, 105, 110, 101, 100,
  32, 116, 104, 105, 115, 32, 119, 97, 121, 46, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 87, 114, 105, 116, 105, 110, 103, 32, 97, 32, 102, 105,
  108, 116, 101, 114, 32, 102, 114, 111, 109, 32, 115, 99, 114, 97, 116, 99,
  104, 32, 105, 110, 32, 60, 98, 62, 71, 39, 77, 73, 67, 60, 47, 98,
  62, 32, 114, 101, 113, 117, 105, 114, 101, 115, 32, 115, 111, 109, 101, 32,
  115, 107, 105, 108, 108, 115, 44, 32, 98, 117, 116, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 99, 97, 110, 32, 98, 101, 32, 103, 101, 110, 101,
  114, 97, 108, 108, 121, 32, 100, 111, 110, 101, 32, 105, 110, 32, 118, 101,
  114, 121, 32, 102, 101, 119, 32, 108, 105, 110, 101, 115, 46, 92, 110, 92,
  110, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 115, 112, 97, 110,
  32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 32, 61, 34, 112, 117,
  114, 112, 108, 101, 34, 32, 117, 110, 100, 101, 114, 108, 105, 110, 101, 61,
  34, 115, 105, 110, 103, 108, 101, 34, 62, 69, 120, 97, 109, 112, 108, 101,
  32, 111, 102, 32, 97, 32, 118, 97, 108, 105, 100, 32, 60, 105, 62, 46,
  103, 109, 105, 99, 60, 47, 105, 62, 32, 101, 110, 116, 114, 121, 32, 58,
  60, 47, 115, 112, 97, 110, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34,
  60, 116, 116, 62, 35, 64, 103, 105, 109, 112, 32, 77, 121, 32, 101, 102,
  102, 101, 99, 116, 32, 58, 32, 109, 121, 95, 101, 102, 102, 101, 99, 116,
  44, 32, 109, 121, 95, 101, 102, 102, 101, 99, 116, 60, 47, 116, 116, 62,
  34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 116, 116, 62, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 105, 103, 109, 97, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 50, 44, 48, 44, 49, 48, 41, 60, 47, 116, 116, 62,
  34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 116, 116, 62, 109, 121, 95,
  101, 102, 102, 101, 99, 116, 32, 58, 92, 110, 32, 32, 32, 32, 32, 45,
  45, 98, 108, 117, 114, 32, 36, 49, 32, 45, 110, 32, 48, 44, 50, 53,
  53, 32, 45, 120, 111, 114, 60, 47, 116, 116, 62, 34, 125, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 123, 34, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 111,
  111, 107, 32, 97, 116, 32, 116, 104, 101, 32, 114, 101, 102, 101, 114, 101,
  110, 99, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 97, 116, 105, 111,
  110, 32, 116, 111, 32, 108, 101, 97, 114, 110, 32, 109, 111, 114, 101, 46,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 121, 32, 116, 104, 101,
  32, 119, 97, 121, 44, 32, 121, 111, 117, 32, 97, 114, 101, 32, 101, 110,
  99, 111, 117, 114, 97, 103, 101, 100, 32, 116, 111, 32, 115, 104, 97, 114,
  101, 32, 121, 111, 117, 114, 32, 110, 105, 99, 101, 32, 99, 117, 115, 116,
  111, 109, 32, 102, 105, 108, 116, 101, 114, 115, 32, 119, 105, 116, 104, 32,
  117, 115, 32, 111, 110, 32, 111, 117, 114, 32, 102, 111, 114, 117, 109, 115,
  44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 102, 111, 114, 32, 105,
  110, 99, 108, 117, 115, 105, 111, 110, 32, 105, 110, 116, 111, 32, 110, 101,
  120, 116, 32, 114, 101, 108, 101, 97, 115, 101, 115, 32, 111, 102, 32, 60,
  98, 62, 71, 39, 77, 73, 67, 60, 47, 98, 62, 46, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 108, 105, 110, 107, 40, 48, 44, 34, 91, 49, 93, 32,
  71, 39, 77, 73, 67, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32,
  100, 111, 99, 117, 109, 101, 110, 116, 97, 116, 105, 111, 110, 34, 44, 34,
  104, 116, 116, 112, 58, 47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114,
  99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 114, 101, 102, 101,
  114, 101, 110, 99, 101, 46, 115, 104, 116, 109, 108, 34, 41, 59, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108,
  105, 110, 107, 40, 48, 44, 34, 91, 50, 93, 32, 71, 39, 77, 73, 67,
  32, 111, 110, 32, 70, 108, 105, 99, 107, 114, 34, 44, 34, 104, 116, 116,
  112, 58, 47, 47, 119, 119, 119, 46, 102, 108, 105, 99, 107, 114, 46, 99,
  111, 109, 47, 103, 114, 111, 117, 112, 115, 47, 103, 109, 105, 99, 47, 100,
  105, 115, 99, 117, 115, 115, 47, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 48,
  44, 34, 91, 51, 93, 32, 71, 39, 77, 73, 67, 32, 111, 110, 32, 71,
  105, 109, 112, 67, 104, 97, 116, 34, 44, 34, 104, 116, 116, 112, 58, 47,
  47, 119, 119, 119, 46, 103, 105, 109, 112, 99, 104, 97, 116, 46, 99, 111,
  109, 47, 118, 105, 101, 119, 102, 111, 114, 117, 109, 46, 112, 104, 112, 63,
  102, 61, 50, 56, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 48, 44, 34, 91,
  52, 93, 32, 71, 39, 77, 73, 67, 32, 111, 110, 32, 71, 111, 111, 103,
  108, 101, 43, 34, 44, 34, 104, 116, 116, 112, 115, 58, 47, 47, 112, 108,
  117, 115, 46, 103, 111, 111, 103, 108, 101, 46, 99, 111, 109, 47, 49, 49,
  55, 52, 52, 49, 50, 51, 55, 57, 56, 50, 50, 56, 51, 48, 49, 49,
  51, 49, 56, 47, 112, 111, 115, 116, 115, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 70, 105, 108, 116, 101, 114, 32, 115, 111, 117, 114, 99, 101,
  115, 32, 58, 32, 95, 110, 111, 110, 101, 95, 44, 32, 103, 105, 109, 112,
  95, 100, 105, 115, 112, 108, 97, 121, 95, 102, 105, 108, 116, 101, 114, 95,
  115, 111, 117, 114, 99, 101, 115, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 72, 101,
  114, 101, 32, 121, 111, 117, 32, 99, 97, 110, 32, 115, 101, 101, 32, 116,
  104, 101, 32, 102, 105, 108, 116, 101, 114, 32, 115, 111, 117, 114, 99, 101,
  115, 32, 99, 117, 114, 114, 101, 110, 116, 108, 121, 32, 101, 110, 97, 98,
  108, 101, 100, 32, 105, 110, 32, 121, 111, 117, 114, 32, 112, 108, 117, 103,
  45, 105, 110, 46, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 111,
  114, 32, 109, 111, 115, 116, 32, 117, 115, 101, 114, 115, 44, 32, 116, 104,
  101, 114, 101, 32, 119, 105, 108, 108, 32, 98, 101, 32, 111, 110, 108, 121,
  32, 111, 110, 101, 32, 85, 82, 76, 32, 108, 105, 115, 116, 101, 100, 32,
  116, 104, 101, 114, 101, 46, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109,
  112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 54, 47, 48,
  51, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 103, 105, 109, 112, 95, 100, 105, 115, 112, 108, 97, 121, 95, 102, 105,
  108, 116, 101, 114, 95, 115, 111, 117, 114, 99, 101, 115, 32, 58, 10, 45,
  105, 102, 32, 64, 35, 32, 45, 107, 91, 48, 93, 32, 45, 114, 101, 109,
  111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 102, 32, 48,
  32, 45, 101, 108, 115, 101, 32, 50, 53, 54, 44, 50, 53, 54, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 108, 91, 93, 32, 45, 103, 105, 109, 112,
  95, 102, 105, 108, 116, 101, 114, 95, 115, 111, 117, 114, 99, 101, 115, 32,
  45, 121, 32, 120, 32, 45, 97, 32, 121, 32, 45, 111, 110, 102, 97, 105,
  108, 32, 40, 48, 41, 32, 45, 101, 110, 100, 108, 10, 45, 116, 101, 120,
  116, 91, 48, 93, 32, 34, 69, 110, 97, 98, 108, 101, 100, 32, 101, 120,
  116, 101, 114, 110, 97, 108, 32, 115, 111, 117, 114, 99, 101, 115, 58, 92,
  110, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45,
  45, 34, 44, 53, 44, 53, 44, 49, 51, 44, 49, 44, 50, 53, 53, 10,
  45, 105, 102, 32, 64, 123, 45, 105, 115, 95, 119, 105, 110, 100, 111, 119,
  115, 125, 32, 112, 97, 116, 104, 61, 64, 123, 45, 112, 97, 116, 104, 95,
  117, 115, 101, 114, 125, 47, 32, 45, 101, 108, 115, 101, 32, 112, 97, 116,
  104, 61, 64, 123, 45, 112, 97, 116, 104, 95, 117, 115, 101, 114, 125, 47,
  46, 32, 45, 101, 110, 100, 105, 102, 10, 105, 61, 49, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 104, 125, 10, 45, 45, 114, 111, 119, 115, 91,
  45, 49, 93, 32, 36, 62, 10, 45, 105, 102, 32, 123, 64, 123, 45, 49,
  44, 48, 45, 51, 125, 39, 61, 61, 39, 123, 39, 104, 116, 116, 112, 39,
  125, 125, 10, 45, 116, 101, 120, 116, 91, 48, 93, 32, 91, 36, 105, 93,
  34, 32, 34, 64, 123, 45, 49, 44, 116, 125, 44, 53, 44, 123, 51, 50,
  43, 49, 53, 42, 36, 105, 125, 44, 49, 51, 44, 49, 44, 50, 53, 53,
  32, 105, 61, 123, 36, 105, 43, 49, 125, 10, 45, 101, 108, 115, 101, 10,
  45, 105, 102, 32, 36, 112, 97, 116, 104, 64, 123, 45, 49, 44, 116, 125,
  32, 45, 116, 101, 120, 116, 91, 48, 93, 32, 91, 36, 105, 93, 34, 32,
  34, 64, 123, 45, 49, 44, 116, 125, 34, 32, 40, 108, 111, 99, 97, 108,
  32, 102, 105, 108, 101, 41, 34, 44, 53, 44, 123, 51, 50, 43, 49, 53,
  42, 36, 105, 125, 44, 49, 51, 44, 49, 44, 50, 53, 53, 32, 105, 61,
  123, 36, 105, 43, 49, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 100, 111,
  110, 101, 10, 45, 114, 109, 91, 45, 49, 93, 10, 35, 64, 103, 105, 109,
  112, 32, 70, 114, 105, 101, 110, 100, 115, 32, 104, 97, 108, 108, 32, 111,
  102, 32, 102, 97, 109, 101, 32, 58, 32, 95, 110, 111, 110, 101, 95, 44,
  32, 103, 105, 109, 112, 95, 102, 114, 105, 101, 110, 100, 115, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 123, 34, 92, 110, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101,
  103, 114, 111, 117, 110, 100, 61, 34, 112, 117, 114, 112, 108, 101, 34, 32,
  117, 110, 100, 101, 114, 108, 105, 110, 101, 61, 34, 115, 105, 110, 103, 108,
  101, 34, 62, 68, 111, 110, 97, 116, 111, 114, 115, 32, 58, 60, 47, 115,
  112, 97, 110, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 32, 60, 98,
  62, 45, 60, 47, 98, 62, 32, 87, 101, 39, 118, 101, 32, 114, 101, 99,
  101, 105, 118, 101, 100, 32, 60, 98, 62, 49, 56, 60, 47, 98, 62, 32,
  100, 111, 110, 97, 116, 105, 111, 110, 115, 32, 102, 114, 111, 109, 32, 60,
  98, 62, 71, 39, 77, 73, 67, 60, 47, 98, 62, 32, 109, 101, 103, 97,
  45, 101, 110, 116, 104, 117, 115, 105, 97, 115, 116, 115, 32, 115, 111, 32,
  102, 97, 114, 46, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 89, 111, 117, 32,
  99, 111, 117, 108, 100, 32, 98, 101, 32, 116, 104, 101, 32, 49, 57, 116,
  104, 32, 100, 111, 110, 97, 116, 111, 114, 32, 58, 41, 34, 125, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 123, 34, 60, 98, 62, 60, 115, 109, 97, 108, 108, 62, 78,
  111, 116, 101, 58, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 98, 62,
  32, 68, 111, 110, 97, 116, 105, 111, 110, 115, 32, 97, 114, 101, 32, 109,
  97, 105, 110, 108, 121, 32, 117, 115, 101, 100, 32, 116, 111, 32, 104, 101,
  108, 112, 32, 117, 115, 32, 109, 97, 107, 105, 110, 103, 32, 71, 39, 77,
  73, 67, 32, 109, 111, 114, 101, 32, 118, 105, 115, 105, 98, 108, 101, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 40, 99, 111, 118, 101, 114, 32, 101, 120, 112,
  101, 110, 115, 101, 115, 32, 102, 111, 114, 32, 111, 112, 101, 110, 45, 115,
  111, 117, 114, 99, 101, 32, 101, 118, 101, 110, 116, 115, 44, 32, 102, 111,
  114, 32, 105, 110, 115, 116, 97, 110, 99, 101, 41, 46, 32, 65, 108, 115,
  111, 44, 32, 105, 116, 32, 119, 105, 108, 108, 32, 109, 111, 116, 105, 118,
  97, 116, 101, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 117, 115, 32, 116, 111, 32,
  100, 101, 115, 105, 103, 110, 32, 109, 111, 114, 101, 32, 110, 101, 119, 32,
  105, 109, 97, 103, 101, 32, 102, 105, 108, 116, 101, 114, 115, 32, 97, 110,
  100, 32, 101, 102, 102, 101, 99, 116, 115, 46, 32, 70, 101, 101, 108, 32,
  102, 114, 101, 101, 32, 116, 111, 32, 100, 111, 110, 97, 116, 101, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 105, 102, 32, 121, 111, 117, 32, 97, 112, 112, 114,
  101, 99, 105, 97, 116, 101, 32, 71, 39, 77, 73, 67, 44, 32, 98, 121,
  32, 99, 108, 105, 99, 107, 105, 110, 103, 32, 111, 110, 58, 34, 125, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32, 61, 32,
  108, 105, 110, 107, 123, 34, 77, 97, 107, 101, 32, 97, 32, 100, 111, 110,
  97, 116, 105, 111, 110, 32, 116, 111, 32, 116, 104, 101, 32, 71, 39, 77,
  73, 67, 32, 112, 114, 111, 106, 101, 99, 116, 34, 44, 34, 104, 116, 116,
  112, 58, 47, 47, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46,
  110, 101, 116, 47, 100, 111, 110, 97, 116, 101, 47, 105, 110, 100, 101, 120,
  46, 112, 104, 112, 63, 103, 114, 111, 117, 112, 95, 105, 100, 61, 50, 51,
  52, 57, 51, 49, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 123, 34, 32, 60, 98, 62, 45, 60, 47, 98,
  62, 32, 65, 32, 98, 105, 103, 32, 104, 117, 103, 32, 103, 111, 101, 115,
  32, 116, 111, 32, 116, 104, 101, 115, 101, 32, 100, 111, 110, 97, 116, 111,
  114, 115, 32, 40, 114, 101, 99, 101, 110, 116, 108, 121, 32, 114, 101, 99,
  101, 105, 118, 101, 100, 32, 102, 105, 114, 115, 116, 41, 32, 58, 34, 125,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32, 61,
  32, 108, 105, 110, 107, 40, 48, 44, 34, 91, 49, 93, 32, 83, 105, 109,
  111, 110, 32, 67, 104, 97, 110, 115, 111, 110, 34, 44, 34, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32, 61, 32,
  108, 105, 110, 107, 40, 48, 44, 34, 91, 50, 93, 32, 72, 101, 114, 98,
  101, 114, 116, 32, 77, 97, 108, 108, 101, 34, 44, 34, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32, 61, 32, 108,
  105, 110, 107, 40, 48, 44, 34, 91, 51, 93, 32, 77, 97, 116, 116, 104,
  105, 97, 115, 32, 90, 101, 112, 112, 101, 114, 34, 44, 34, 104, 116, 116,
  112, 58, 47, 47, 119, 119, 119, 46, 109, 97, 116, 116, 104, 105, 97, 115,
  45, 122, 101, 112, 112, 101, 114, 46, 100, 101, 47, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32, 61, 32, 108, 105,
  110, 107, 40, 48, 44, 34, 91, 52, 93, 32, 67, 104, 114, 105, 115, 116,
  105, 97, 110, 32, 77, 97, 114, 105, 117, 99, 99, 105, 34, 44, 34, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32,
  61, 32, 108, 105, 110, 107, 40, 48, 44, 34, 91, 53, 93, 32, 77, 46,
  32, 82, 46, 34, 44, 34, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 76, 105, 110, 107, 32, 61, 32, 108, 105, 110, 107, 40, 48, 44,
  34, 91, 54, 93, 32, 77, 97, 114, 107, 32, 76, 105, 110, 107, 34, 44,
  34, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110,
  107, 32, 61, 32, 108, 105, 110, 107, 40, 48, 44, 34, 91, 55, 93, 32,
  82, 111, 108, 102, 32, 83, 116, 101, 105, 110, 111, 114, 116, 34, 44, 34,
  104, 116, 116, 112, 58, 47, 47, 98, 108, 111, 103, 46, 109, 101, 101, 116,
  116, 104, 101, 103, 105, 109, 112, 46, 111, 114, 103, 47, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32, 61, 32, 108,
  105, 110, 107, 40, 48, 44, 34, 91, 56, 93, 32, 80, 97, 116, 32, 68,
  97, 118, 105, 100, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 98, 108,
  111, 103, 46, 112, 97, 116, 100, 97, 118, 105, 100, 46, 110, 101, 116, 47,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107,
  32, 61, 32, 108, 105, 110, 107, 40, 48, 44, 34, 91, 57, 93, 32, 68,
  97, 110, 105, 101, 108, 32, 84, 97, 117, 114, 111, 34, 44, 34, 104, 116,
  116, 112, 115, 58, 47, 47, 112, 108, 117, 115, 46, 103, 111, 111, 103, 108,
  101, 46, 99, 111, 109, 47, 49, 49, 50, 51, 53, 55, 48, 56, 56, 53,
  48, 53, 52, 56, 56, 55, 53, 54, 56, 50, 51, 47, 112, 111, 115, 116,
  115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110,
  107, 32, 61, 32, 108, 105, 110, 107, 40, 48, 44, 34, 91, 49, 48, 93,
  32, 66, 101, 110, 32, 76, 97, 110, 103, 104, 105, 110, 114, 105, 99, 104,
  115, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 103, 101, 110, 105, 105,
  115, 111, 102, 116, 46, 99, 111, 109, 47, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 76, 105, 110, 107, 32, 61, 32, 108, 105, 110, 107,
  40, 48, 44, 34, 91, 49, 49, 93, 32, 80, 97, 111, 108, 111, 32, 80,
  101, 100, 97, 108, 101, 116, 116, 105, 34, 44, 34, 104, 116, 116, 112, 58,
  47, 47, 119, 119, 119, 46, 111, 112, 101, 110, 108, 97, 98, 115, 46, 105,
  116, 47, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105,
  110, 107, 32, 61, 32, 108, 105, 110, 107, 40, 48, 44, 34, 91, 49, 50,
  93, 32, 82, 105, 99, 97, 114, 100, 111, 32, 67, 111, 114, 105, 110, 34,
  44, 34, 104, 116, 116, 112, 58, 47, 47, 98, 108, 111, 103, 46, 112, 104,
  111, 116, 111, 109, 111, 110, 116, 97, 103, 101, 114, 46, 99, 111, 109, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32,
  61, 32, 108, 105, 110, 107, 40, 48, 44, 34, 91, 49, 51, 93, 32, 74,
  97, 109, 101, 115, 32, 80, 114, 105, 99, 104, 97, 114, 100, 34, 44, 34,
  104, 116, 116, 112, 115, 58, 47, 47, 112, 108, 117, 115, 46, 103, 111, 111,
  103, 108, 101, 46, 99, 111, 109, 47, 49, 49, 53, 57, 53, 51, 54, 54,
  54, 50, 55, 57, 53, 48, 57, 57, 53, 57, 50, 53, 56, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32, 61, 32,
  108, 105, 110, 107, 40, 48, 44, 34, 91, 49, 52, 93, 32, 77, 97, 116,
  116, 32, 74, 111, 110, 101, 115, 34, 44, 34, 104, 116, 116, 112, 115, 58,
  47, 47, 112, 108, 117, 115, 46, 103, 111, 111, 103, 108, 101, 46, 99, 111,
  109, 47, 49, 49, 54, 54, 53, 56, 50, 50, 49, 52, 54, 49, 48, 52,
  55, 51, 49, 51, 54, 52, 55, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 76, 105, 110, 107, 32, 61, 32, 108, 105, 110, 107, 40, 48,
  44, 34, 91, 49, 53, 93, 32, 69, 100, 100, 121, 32, 86, 101, 114, 118,
  101, 115, 116, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119,
  46, 102, 108, 105, 99, 107, 114, 46, 99, 111, 109, 47, 112, 101, 111, 112,
  108, 101, 47, 116, 119, 101, 107, 107, 101, 108, 47, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32, 61, 32, 108, 105,
  110, 107, 40, 48, 44, 34, 91, 49, 54, 93, 32, 83, 116, 101, 118, 101,
  110, 32, 83, 104, 117, 112, 101, 34, 44, 34, 104, 116, 116, 112, 58, 47,
  47, 119, 119, 119, 46, 102, 108, 105, 99, 107, 114, 46, 99, 111, 109, 47,
  112, 104, 111, 116, 111, 115, 47, 115, 115, 115, 104, 117, 112, 101, 47, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32,
  61, 32, 108, 105, 110, 107, 40, 48, 44, 34, 91, 49, 55, 93, 32, 70,
  108, 97, 118, 105, 111, 32, 67, 97, 115, 97, 100, 101, 105, 32, 68, 101,
  108, 108, 97, 32, 67, 104, 105, 101, 115, 97, 34, 44, 34, 104, 116, 116,
  112, 58, 47, 47, 119, 119, 119, 46, 102, 108, 97, 118, 105, 111, 99, 100,
  99, 46, 110, 101, 116, 47, 119, 105, 107, 105, 47, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32, 61, 32, 108, 105,
  110, 107, 40, 48, 44, 34, 91, 49, 56, 93, 32, 76, 121, 108, 101, 32,
  75, 114, 111, 108, 108, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 119,
  119, 119, 46, 97, 114, 116, 119, 97, 110, 116, 101, 100, 46, 99, 111, 109,
  47, 97, 114, 116, 105, 115, 116, 46, 99, 102, 109, 63, 97, 114, 116, 105,
  100, 61, 49, 48, 57, 49, 56, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 92, 110, 60, 115, 112,
  97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 112,
  117, 114, 112, 108, 101, 34, 32, 117, 110, 100, 101, 114, 108, 105, 110, 101,
  61, 34, 115, 105, 110, 103, 108, 101, 34, 62, 80, 111, 115, 116, 99, 97,
  114, 100, 32, 115, 101, 110, 100, 101, 114, 115, 32, 58, 60, 47, 115, 112,
  97, 110, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 32, 60, 98, 62,
  45, 60, 47, 98, 62, 32, 87, 101, 39, 118, 101, 32, 114, 101, 99, 101,
  105, 118, 101, 100, 32, 60, 98, 62, 50, 49, 60, 47, 98, 62, 32, 112,
  111, 115, 116, 99, 97, 114, 100, 115, 32, 102, 114, 111, 109, 32, 60, 98,
  62, 71, 39, 77, 73, 67, 60, 47, 98, 62, 32, 101, 110, 116, 104, 117,
  115, 105, 97, 115, 116, 115, 32, 115, 111, 32, 102, 97, 114, 46, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 89, 111, 117, 32, 99, 111, 117, 108, 100, 32,
  98, 101, 32, 116, 104, 101, 32, 50, 50, 116, 104, 32, 115, 101, 110, 100,
  101, 114, 32, 58, 41, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 32, 60,
  98, 62, 45, 60, 47, 98, 62, 32, 65, 32, 98, 105, 103, 32, 104, 117,
  103, 32, 103, 111, 101, 115, 32, 116, 111, 32, 116, 104, 101, 115, 101, 32,
  112, 111, 115, 116, 99, 97, 114, 100, 32, 115, 101, 110, 100, 101, 114, 115,
  32, 40, 114, 101, 99, 101, 110, 116, 108, 121, 32, 114, 101, 99, 101, 105,
  118, 101, 100, 32, 102, 105, 114, 115, 116, 41, 32, 58, 34, 125, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32, 61, 32, 108,
  105, 110, 107, 40, 48, 44, 34, 91, 49, 93, 32, 65, 107, 107, 121, 32,
  91, 71, 105, 109, 112, 99, 104, 97, 116, 93, 32, 45, 32, 65, 117, 115,
  116, 114, 97, 108, 105, 97, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47,
  99, 105, 109, 103, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101,
  46, 110, 101, 116, 47, 105, 109, 103, 47, 112, 111, 115, 116, 99, 97, 114,
  100, 52, 55, 46, 106, 112, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 76, 105, 110, 107, 32, 61, 32, 108, 105, 110, 107, 40, 48,
  44, 34, 91, 50, 93, 32, 77, 105, 99, 104, 101, 108, 32, 84, 104, 111,
  109, 97, 115, 32, 45, 32, 71, 101, 114, 109, 97, 110, 121, 34, 44, 34,
  104, 116, 116, 112, 58, 47, 47, 99, 105, 109, 103, 46, 115, 111, 117, 114,
  99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 105, 109, 103, 47,
  112, 111, 115, 116, 99, 97, 114, 100, 52, 53, 46, 106, 112, 103, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32, 61,
  32, 108, 105, 110, 107, 40, 48, 44, 34, 91, 51, 93, 32, 80, 105, 101,
  114, 114, 101, 45, 89, 118, 101, 115, 32, 45, 32, 73, 108, 101, 32, 100,
  101, 32, 66, 97, 116, 122, 47, 70, 114, 97, 110, 99, 101, 34, 44, 34,
  104, 116, 116, 112, 58, 47, 47, 99, 105, 109, 103, 46, 115, 111, 117, 114,
  99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 105, 109, 103, 47,
  112, 111, 115, 116, 99, 97, 114, 100, 52, 52, 46, 106, 112, 103, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32, 61,
  32, 108, 105, 110, 107, 40, 48, 44, 34, 91, 52, 93, 32, 70, 97, 109,
  105, 108, 121, 32, 72, 97, 109, 97, 99, 104, 101, 114, 32, 45, 32, 84,
  114, 105, 101, 114, 47, 71, 101, 114, 109, 97, 110, 121, 34, 44, 34, 104,
  116, 116, 112, 58, 47, 47, 99, 105, 109, 103, 46, 115, 111, 117, 114, 99,
  101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 105, 109, 103, 47, 112,
  111, 115, 116, 99, 97, 114, 100, 52, 51, 46, 106, 112, 103, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32, 61, 32,
  108, 105, 110, 107, 40, 48, 44, 34, 91, 53, 93, 32, 66, 101, 110, 111,
  105, 116, 32, 71, 97, 117, 122, 101, 114, 101, 32, 97, 110, 100, 32, 70,
  114, 97, 110, 99, 111, 105, 115, 32, 76, 111, 122, 101, 115, 32, 45, 32,
  72, 111, 107, 117, 115, 97, 105, 47, 74, 97, 112, 97, 110, 34, 44, 34,
  104, 116, 116, 112, 58, 47, 47, 99, 105, 109, 103, 46, 115, 111, 117, 114,
  99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 105, 109, 103, 47,
  112, 111, 115, 116, 99, 97, 114, 100, 52, 49, 46, 106, 112, 103, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32, 61,
  32, 108, 105, 110, 107, 40, 48, 44, 34, 91, 54, 93, 32, 68, 114, 46,
  32, 82, 97, 105, 110, 101, 114, 32, 84, 101, 117, 98, 110, 101, 114, 32,
  45, 32, 83, 101, 108, 105, 103, 101, 110, 115, 116, 97, 100, 116, 47, 71,
  101, 114, 109, 97, 110, 121, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47,
  99, 105, 109, 103, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101,
  46, 110, 101, 116, 47, 105, 109, 103, 47, 112, 111, 115, 116, 99, 97, 114,
  100, 52, 48, 46, 106, 112, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 76, 105, 110, 107, 32, 61, 32, 108, 105, 110, 107, 40, 48,
  44, 34, 91, 55, 93, 32, 77, 97, 117, 114, 111, 32, 77, 105, 116, 114,
  105, 110, 111, 32, 45, 32, 77, 97, 110, 116, 111, 118, 97, 47, 73, 116,
  97, 108, 121, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 99, 105, 109,
  103, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101,
  116, 47, 105, 109, 103, 47, 112, 111, 115, 116, 99, 97, 114, 100, 51, 57,
  46, 106, 112, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  76, 105, 110, 107, 32, 61, 32, 108, 105, 110, 107, 40, 48, 44, 34, 91,
  56, 93, 32, 87, 101, 114, 110, 101, 114, 32, 77, 101, 105, 101, 114, 32,
  45, 32, 77, 101, 116, 116, 108, 97, 99, 104, 47, 71, 101, 114, 109, 97,
  110, 121, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 99, 105, 109, 103,
  46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116,
  47, 105, 109, 103, 47, 112, 111, 115, 116, 99, 97, 114, 100, 51, 55, 46,
  106, 112, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76,
  105, 110, 107, 32, 61, 32, 108, 105, 110, 107, 40, 48, 44, 34, 91, 57,
  93, 32, 65, 114, 116, 111, 32, 72, 117, 111, 116, 97, 114, 105, 32, 45,
  32, 72, 101, 108, 115, 105, 110, 107, 105, 47, 70, 105, 110, 108, 97, 110,
  100, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 99, 105, 109, 103, 46,
  115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47,
  105, 109, 103, 47, 112, 111, 115, 116, 99, 97, 114, 100, 51, 54, 46, 106,
  112, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105,
  110, 107, 32, 61, 32, 108, 105, 110, 107, 40, 48, 44, 34, 91, 49, 48,
  93, 32, 66, 101, 110, 111, 105, 116, 32, 71, 97, 117, 122, 101, 114, 101,
  32, 45, 32, 67, 97, 108, 105, 102, 111, 114, 110, 105, 97, 47, 85, 83,
  65, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 99, 105, 109, 103, 46,
  115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47,
  105, 109, 103, 47, 112, 111, 115, 116, 99, 97, 114, 100, 51, 51, 46, 106,
  112, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105,
  110, 107, 32, 61, 32, 108, 105, 110, 107, 40, 48, 44, 34, 91, 49, 49,
  93, 32, 65, 114, 107, 97, 100, 105, 32, 71, 101, 108, 102, 111, 110, 100,
  32, 45, 32, 70, 111, 115, 116, 101, 114, 32, 67, 105, 116, 121, 32, 45,
  32, 67, 97, 108, 105, 102, 111, 114, 110, 105, 97, 47, 85, 83, 65, 34,
  44, 34, 104, 116, 116, 112, 58, 47, 47, 99, 105, 109, 103, 46, 115, 111,
  117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 105, 109,
  103, 47, 112, 111, 115, 116, 99, 97, 114, 100, 51, 48, 46, 106, 112, 103,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107,
  32, 61, 32, 108, 105, 110, 107, 40, 48, 44, 34, 91, 49, 50, 93, 32,
  67, 111, 114, 105, 110, 110, 101, 32, 77, 97, 115, 105, 109, 97, 110, 110,
  32, 45, 32, 78, 101, 117, 99, 104, 97, 116, 101, 108, 47, 83, 119, 105,
  116, 122, 101, 114, 108, 97, 110, 100, 34, 44, 34, 104, 116, 116, 112, 58,
  47, 47, 99, 105, 109, 103, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114,
  103, 101, 46, 110, 101, 116, 47, 105, 109, 103, 47, 112, 111, 115, 116, 99,
  97, 114, 100, 50, 57, 46, 106, 112, 103, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 76, 105, 110, 107, 32, 61, 32, 108, 105, 110, 107,
  40, 48, 44, 34, 91, 49, 51, 93, 32, 77, 97, 104, 118, 105, 110, 32,
  45, 32, 80, 111, 114, 116, 108, 97, 110, 100, 47, 85, 83, 65, 34, 44,
  34, 104, 116, 116, 112, 58, 47, 47, 99, 105, 109, 103, 46, 115, 111, 117,
  114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 105, 109, 103,
  47, 112, 111, 115, 116, 99, 97, 114, 100, 50, 55, 46, 106, 112, 103, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32,
  61, 32, 108, 105, 110, 107, 40, 48, 44, 34, 91, 49, 52, 93, 32, 86,
  105, 110, 99, 101, 110, 116, 32, 82, 111, 117, 108, 108, 105, 101, 114, 32,
  45, 32, 67, 97, 101, 110, 47, 70, 114, 97, 110, 99, 101, 34, 44, 34,
  104, 116, 116, 112, 58, 47, 47, 99, 105, 109, 103, 46, 115, 111, 117, 114,
  99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 105, 109, 103, 47,
  112, 111, 115, 116, 99, 97, 114, 100, 50, 54, 46, 106, 112, 103, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32, 61,
  32, 108, 105, 110, 107, 40, 48, 44, 34, 91, 49, 53, 93, 32, 77, 63,
  63, 63, 63, 32, 45, 32, 77, 117, 110, 105, 99, 104, 47, 71, 101, 114,
  109, 97, 110, 121, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 99, 105,
  109, 103, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110,
  101, 116, 47, 105, 109, 103, 47, 112, 111, 115, 116, 99, 97, 114, 100, 50,
  52, 46, 106, 112, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 76, 105, 110, 107, 32, 61, 32, 108, 105, 110, 107, 40, 48, 44, 34,
  91, 49, 54, 93, 32, 70, 46, 32, 65, 108, 98, 105, 111, 114, 32, 45,
  32, 74, 97, 99, 97, 47, 83, 112, 97, 105, 110, 34, 44, 34, 104, 116,
  116, 112, 58, 47, 47, 99, 105, 109, 103, 46, 115, 111, 117, 114, 99, 101,
  102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 105, 109, 103, 47, 112, 111,
  115, 116, 99, 97, 114, 100, 50, 51, 46, 106, 112, 103, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32, 61, 32, 108,
  105, 110, 107, 40, 48, 44, 34, 91, 49, 55, 93, 32, 80, 104, 111, 116,
  111, 67, 111, 109, 73, 88, 32, 45, 32, 70, 114, 97, 115, 99, 97, 116,
  105, 47, 73, 116, 97, 108, 121, 34, 44, 34, 104, 116, 116, 112, 58, 47,
  47, 99, 105, 109, 103, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103,
  101, 46, 110, 101, 116, 47, 105, 109, 103, 47, 112, 111, 115, 116, 99, 97,
  114, 100, 50, 50, 46, 106, 112, 103, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 76, 105, 110, 107, 32, 61, 32, 108, 105, 110, 107, 40,
  48, 44, 34, 91, 49, 56, 93, 32, 71, 117, 121, 32, 80, 111, 105, 122,
  97, 116, 32, 45, 32, 67, 97, 98, 101, 115, 116, 97, 110, 121, 47, 70,
  114, 97, 110, 99, 101, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 99,
  105, 109, 103, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46,
  110, 101, 116, 47, 105, 109, 103, 47, 112, 111, 115, 116, 99, 97, 114, 100,
  50, 49, 46, 106, 112, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 76, 105, 110, 107, 32, 61, 32, 108, 105, 110, 107, 40, 48, 44,
  34, 91, 49, 57, 93, 32, 73, 110, 115, 116, 105, 116, 117, 116, 32, 102,
  111, 114, 32, 66, 105, 111, 109, 97, 116, 104, 101, 109, 97, 116, 105, 107,
  32, 117, 110, 100, 32, 66, 105, 111, 109, 101, 116, 114, 105, 101, 32, 45,
  32, 78, 101, 117, 104, 101, 114, 98, 101, 114, 103, 47, 71, 101, 114, 109,
  97, 110, 121, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 99, 105, 109,
  103, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101,
  116, 47, 105, 109, 103, 47, 112, 111, 115, 116, 99, 97, 114, 100, 50, 48,
  46, 106, 112, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  76, 105, 110, 107, 32, 61, 32, 108, 105, 110, 107, 40, 48, 44, 34, 91,
  50, 48, 93, 32, 74, 97, 105, 109, 101, 32, 45, 32, 66, 97, 114, 99,
  101, 108, 111, 110, 97, 47, 83, 112, 97, 105, 110, 34, 44, 34, 104, 116,
  116, 112, 58, 47, 47, 99, 105, 109, 103, 46, 115, 111, 117, 114, 99, 101,
  102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 105, 109, 103, 47, 112, 111,
  115, 116, 99, 97, 114, 100, 49, 52, 46, 106, 112, 103, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32, 61, 32, 108,
  105, 110, 107, 40, 48, 44, 34, 91, 50, 49, 93, 32, 74, 101, 97, 110,
  45, 77, 105, 99, 104, 101, 108, 32, 87, 101, 98, 98, 101, 32, 45, 32,
  71, 117, 97, 100, 101, 108, 111, 117, 112, 101, 47, 70, 114, 97, 110, 99,
  101, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 99, 105, 109, 103, 46,
  115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47,
  105, 109, 103, 47, 112, 111, 115, 116, 99, 97, 114, 100, 49, 53, 46, 106,
  112, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 123, 34, 92, 110, 77, 97, 121, 32, 116, 104, 101, 32,
  102, 111, 114, 99, 101, 32, 98, 101, 32, 119, 105, 116, 104, 32, 121, 111,
  117, 33, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 51, 47, 48, 52, 47, 50, 54, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 102, 114, 105, 101, 110, 100, 115, 32, 58, 10, 45, 105, 102, 32,
  64, 35, 32, 114, 97, 116, 105, 111, 61, 123, 119, 47, 104, 125, 32, 45,
  101, 108, 115, 101, 32, 114, 97, 116, 105, 111, 61, 49, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 114, 109, 32, 45, 95, 104, 101, 97, 114, 116, 56,
  48, 120, 55, 51, 32, 45, 115, 99, 97, 108, 101, 51, 120, 32, 45, 114,
  32, 49, 53, 48, 37, 44, 49, 53, 48, 37, 44, 49, 44, 49, 44, 48,
  44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45, 42, 91, 45,
  49, 93, 32, 55, 48, 32, 45, 45, 42, 91, 45, 50, 93, 32, 49, 49,
  48, 32, 45, 45, 42, 91, 45, 51, 93, 32, 50, 53, 53, 32, 45, 42,
  91, 45, 52, 93, 32, 50, 53, 53, 32, 45, 97, 32, 99, 10, 45, 98,
  108, 117, 114, 95, 114, 97, 100, 105, 97, 108, 32, 52, 32, 45, 115, 104,
  97, 114, 112, 101, 110, 32, 51, 48, 48, 10, 45, 105, 91, 45, 50, 93,
  32, 64, 123, 45, 102, 105, 116, 114, 97, 116, 105, 111, 95, 119, 104, 92,
  32, 123, 119, 125, 44, 123, 104, 125, 44, 36, 114, 97, 116, 105, 111, 125,
  44, 49, 44, 51, 10, 45, 114, 97, 110, 100, 91, 45, 50, 93, 32, 48,
  44, 50, 53, 53, 32, 45, 115, 104, 91, 45, 50, 93, 32, 49, 44, 50,
  32, 45, 47, 91, 45, 49, 93, 32, 50, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 98, 108, 117, 114, 95, 114, 97, 100, 105, 97, 108, 91, 45,
  50, 93, 32, 49, 48, 32, 45, 115, 104, 97, 114, 112, 101, 110, 91, 45,
  50, 93, 32, 54, 48, 48, 10, 45, 114, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 52, 44, 48, 44, 48, 44,
  48, 46, 53, 44, 48, 46, 53, 32, 45, 98, 108, 101, 110, 100, 32, 97,
  108, 112, 104, 97, 10, 49, 51, 53, 44, 54, 55, 44, 49, 44, 49, 44,
  48, 32, 45, 116, 91, 45, 49, 93, 32, 34, 71, 114, 101, 101, 116, 105,
  110, 103, 115, 32, 116, 111, 92, 110, 32, 32, 97, 108, 108, 32, 71, 39,
  77, 73, 67, 92, 110, 32, 32, 102, 114, 105, 101, 110, 100, 115, 33, 34,
  44, 50, 44, 45, 50, 44, 50, 52, 44, 49, 44, 49, 10, 45, 45, 100,
  105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51, 32, 45, 42, 91, 45,
  50, 93, 32, 50, 53, 53, 32, 45, 116, 111, 95, 114, 103, 98, 91, 45,
  50, 93, 32, 45, 106, 91, 45, 51, 93, 32, 91, 45, 50, 93, 44, 123,
  40, 64, 123, 45, 51, 44, 119, 125, 45, 64, 123, 45, 50, 44, 119, 125,
  41, 47, 50, 125, 44, 123, 40, 64, 123, 45, 51, 44, 104, 125, 45, 64,
  123, 45, 50, 44, 104, 125, 41, 47, 50, 46, 50, 125, 44, 48, 44, 48,
  44, 49, 44, 91, 45, 49, 93, 10, 45, 114, 109, 91, 45, 50, 44, 45,
  49, 93, 10, 95, 104, 101, 97, 114, 116, 56, 48, 120, 55, 51, 32, 58,
  10, 52, 48, 44, 55, 51, 44, 49, 44, 49, 44, 48, 32, 45, 101, 108,
  108, 105, 112, 115, 101, 32, 50, 50, 44, 50, 50, 44, 50, 48, 44, 50,
  48, 44, 48, 44, 49, 44, 49, 32, 45, 112, 111, 108, 121, 103, 111, 110,
  32, 51, 44, 55, 44, 51, 55, 44, 52, 50, 44, 55, 50, 44, 52, 50,
  44, 50, 55, 44, 49, 44, 49, 32, 45, 45, 109, 105, 114, 114, 111, 114,
  32, 120, 32, 45, 97, 32, 120, 10, 35, 64, 103, 105, 109, 112, 95, 101,
  110, 32, 71, 39, 77, 73, 67, 32, 102, 111, 114, 32, 71, 73, 77, 80,
  32, 58, 32, 95, 110, 111, 110, 101, 95, 44, 32, 103, 105, 109, 112, 95,
  108, 111, 103, 111, 95, 101, 110, 10, 35, 64, 103, 105, 109, 112, 95, 101,
  110, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123,
  34, 10, 35, 64, 103, 105, 109, 112, 95, 101, 110, 32, 58, 32, 60, 115,
  112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 32, 61,
  34, 112, 117, 114, 112, 108, 101, 34, 62, 40, 32, 60, 98, 62, 71, 60,
  47, 98, 62, 82, 69, 89, 67, 39, 115, 32, 60, 98, 62, 77, 60, 47,
  98, 62, 97, 103, 105, 99, 32, 102, 111, 114, 32, 60, 98, 62, 73, 60,
  47, 98, 62, 109, 97, 103, 101, 32, 60, 98, 62, 67, 60, 47, 98, 62,
  111, 109, 112, 117, 116, 105, 110, 103, 32, 41, 60, 47, 115, 112, 97, 110,
  62, 92, 110, 92, 110, 105, 115, 32, 112, 114, 111, 112, 111, 115, 101, 100,
  32, 116, 111, 32, 121, 111, 117, 32, 98, 121, 34, 125, 10, 35, 64, 103,
  105, 109, 112, 95, 101, 110, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  108, 105, 110, 107, 40, 34, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104,
  117, 109, 112, 101, 114, 108, 92, 51, 48, 51, 92, 50, 53, 49, 34, 44,
  34, 104, 116, 116, 112, 58, 47, 47, 116, 115, 99, 104, 117, 109, 112, 101,
  114, 108, 101, 46, 117, 115, 101, 114, 115, 46, 103, 114, 101, 121, 99, 46,
  102, 114, 47, 34, 41, 10, 35, 64, 103, 105, 109, 112, 95, 101, 110, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 123, 34, 40,
  32, 73, 77, 65, 71, 69, 32, 84, 101, 97, 109, 32, 47, 32, 71, 82,
  69, 89, 67, 32, 76, 97, 98, 111, 114, 97, 116, 111, 114, 121, 32, 45,
  32, 67, 78, 82, 83, 32, 85, 77, 82, 32, 54, 48, 55, 50, 32, 41,
  34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 103, 114,
  101, 121, 99, 46, 101, 110, 115, 105, 99, 97, 101, 110, 46, 102, 114, 47,
  69, 113, 117, 105, 112, 101, 73, 109, 97, 103, 101, 34, 125, 10, 35, 64,
  103, 105, 109, 112, 95, 101, 110, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 123, 34, 10, 35, 64, 103, 105, 109, 112, 95, 101,
  110, 32, 58, 32, 84, 104, 105, 115, 32, 112, 108, 117, 103, 45, 105, 110,
  32, 105, 115, 32, 98, 97, 115, 101, 100, 32, 111, 110, 32, 111, 117, 114,
  32, 111, 112, 101, 110, 45, 115, 111, 117, 114, 99, 101, 32, 108, 105, 98,
  114, 97, 114, 105, 101, 115, 32, 60, 98, 62, 71, 39, 77, 73, 67, 60,
  47, 98, 62, 32, 97, 110, 100, 32, 60, 98, 62, 67, 73, 109, 103, 60,
  47, 98, 62, 32, 40, 67, 43, 43, 32, 84, 101, 109, 112, 108, 97, 116,
  101, 32, 73, 109, 97, 103, 101, 32, 80, 114, 111, 99, 101, 115, 115, 105,
  110, 103, 32, 76, 105, 98, 114, 97, 114, 121, 41, 44, 10, 35, 64, 103,
  105, 109, 112, 95, 101, 110, 32, 58, 32, 97, 118, 97, 105, 108, 97, 98,
  108, 101, 32, 97, 116, 58, 34, 125, 10, 35, 64, 103, 105, 109, 112, 95,
  101, 110, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107,
  40, 34, 104, 116, 116, 112, 58, 47, 47, 103, 109, 105, 99, 46, 115, 111,
  117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 95, 101, 110, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 97, 110, 100, 34, 125, 10,
  35, 64, 103, 105, 109, 112, 95, 101, 110, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 108, 105, 110, 107, 40, 34, 104, 116, 116, 112, 58, 47, 47,
  99, 105, 109, 103, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101,
  46, 110, 101, 116, 47, 34, 41, 10, 35, 64, 103, 105, 109, 112, 95, 101,
  110, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123,
  34, 92, 110, 10, 35, 64, 103, 105, 109, 112, 95, 101, 110, 32, 58, 32,
  73, 102, 32, 121, 111, 117, 32, 97, 112, 112, 114, 101, 99, 105, 97, 116,
  101, 32, 60, 98, 62, 71, 39, 77, 73, 67, 60, 47, 98, 62, 44, 32,
  121, 111, 117, 32, 97, 114, 101, 32, 119, 101, 108, 99, 111, 109, 101, 32,
  116, 111, 32, 115, 101, 110, 100, 32, 117, 115, 32, 97, 32, 110, 105, 99,
  101, 32, 112, 111, 115, 116, 99, 97, 114, 100, 32, 102, 114, 111, 109, 32,
  121, 111, 117, 114, 32, 112, 108, 97, 99, 101, 44, 32, 97, 116, 58, 92,
  110, 92, 110, 10, 35, 64, 103, 105, 109, 112, 95, 101, 110, 32, 58, 32,
  60, 115, 109, 97, 108, 108, 62, 60, 116, 116, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 44, 92, 110, 32, 76, 97, 98, 111, 114, 97, 116, 111, 105, 114, 101,
  32, 71, 82, 69, 89, 67, 32, 40, 67, 78, 82, 83, 32, 85, 77, 82,
  32, 54, 48, 55, 50, 41, 44, 32, 69, 113, 117, 105, 112, 101, 32, 73,
  109, 97, 103, 101, 44, 92, 110, 10, 35, 64, 103, 105, 109, 112, 95, 101,
  110, 32, 58, 32, 32, 54, 32, 66, 100, 32, 100, 117, 32, 77, 97, 114,
  38, 35, 50, 51, 51, 59, 99, 104, 97, 108, 32, 74, 117, 105, 110, 44,
  92, 110, 32, 49, 52, 48, 53, 48, 32, 67, 97, 101, 110, 32, 67, 101,
  100, 101, 120, 32, 47, 32, 70, 114, 97, 110, 99, 101, 46, 60, 47, 116,
  116, 62, 60, 47, 115, 109, 97, 108, 108, 62, 92, 110, 92, 110, 10, 35,
  64, 103, 105, 109, 112, 95, 101, 110, 32, 58, 32, 80, 111, 115, 116, 99,
  97, 114, 100, 115, 32, 115, 101, 110, 100, 101, 114, 115, 32, 97, 117, 116,
  111, 109, 97, 116, 105, 99, 97, 108, 108, 121, 32, 101, 110, 116, 101, 114,
  32, 116, 104, 101, 32, 60, 105, 62, 70, 114, 105, 101, 110, 100, 115, 32,
  72, 97, 108, 108, 32, 111, 102, 32, 70, 97, 109, 101, 60, 47, 105, 62,
  32, 58, 41, 32, 33, 10, 35, 64, 103, 105, 109, 112, 95, 101, 110, 32,
  58, 32, 34, 125, 10, 103, 105, 109, 112, 95, 108, 111, 103, 111, 95, 118,
  101, 114, 115, 105, 111, 110, 51, 32, 58, 32, 45, 115, 107, 105, 112, 32,
  34, 36, 123, 49, 61, 80, 108, 117, 103, 45, 105, 110, 32, 102, 111, 114,
  32, 71, 73, 77, 80, 125, 34, 10, 45, 114, 109, 32, 115, 61, 34, 71,
  39, 77, 73, 67, 34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 110,
  97, 114, 103, 40, 123, 39, 36, 115, 39, 125, 41, 125, 10, 48, 32, 45,
  116, 101, 120, 116, 91, 45, 49, 93, 32, 123, 96, 123, 97, 114, 103, 40,
  49, 43, 36, 62, 44, 123, 39, 36, 115, 39, 125, 41, 125, 96, 125, 44,
  48, 44, 48, 44, 53, 55, 44, 49, 44, 49, 32, 45, 102, 114, 97, 109,
  101, 91, 45, 49, 93, 32, 51, 44, 48, 44, 48, 10, 45, 114, 91, 45,
  49, 93, 32, 53, 48, 48, 37, 44, 53, 48, 48, 37, 44, 49, 44, 49,
  44, 51, 32, 45, 98, 91, 45, 49, 93, 32, 51, 37, 32, 45, 103, 101,
  91, 45, 49, 93, 32, 53, 48, 37, 10, 45, 100, 105, 115, 116, 97, 110,
  99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 108, 101, 91, 45, 49, 93,
  32, 49, 48, 10, 91, 45, 49, 93, 120, 51, 32, 45, 119, 104, 105, 114,
  108, 115, 91, 45, 52, 45, 45, 50, 93, 32, 44, 10, 114, 36, 62, 61,
  123, 63, 40, 48, 46, 52, 44, 49, 41, 125, 32, 103, 36, 62, 61, 123,
  63, 40, 48, 46, 50, 44, 49, 41, 125, 32, 98, 36, 62, 61, 123, 63,
  40, 48, 46, 54, 44, 49, 41, 125, 10, 45, 42, 91, 45, 52, 93, 32,
  36, 123, 114, 36, 62, 125, 32, 45, 42, 91, 45, 51, 93, 32, 36, 123,
  103, 36, 62, 125, 32, 45, 42, 91, 45, 50, 93, 32, 36, 123, 98, 36,
  62, 125, 10, 45, 97, 91, 45, 52, 45, 45, 50, 93, 32, 99, 32, 45,
  110, 91, 45, 50, 93, 32, 48, 44, 50, 53, 53, 32, 45, 42, 91, 45,
  49, 93, 32, 50, 53, 53, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93,
  32, 99, 10, 45, 100, 111, 110, 101, 10, 45, 97, 91, 45, 53, 45, 45,
  49, 93, 32, 120, 10, 45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37,
  44, 49, 50, 48, 37, 44, 49, 44, 52, 44, 48, 44, 48, 44, 48, 46,
  53, 44, 49, 10, 45, 98, 97, 108, 108, 32, 54, 52, 44, 123, 50, 53,
  53, 42, 36, 114, 51, 125, 44, 123, 50, 53, 53, 42, 36, 103, 51, 125,
  44, 123, 50, 53, 53, 42, 36, 98, 51, 125, 32, 45, 106, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 44, 52, 50, 48, 44, 49, 53, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 45, 49, 93, 32, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 32, 45, 100, 105, 108, 97, 116, 101, 91,
  45, 49, 93, 32, 55, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 97,
  117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 10, 45, 100, 114, 111,
  112, 95, 115, 104, 97, 100, 111, 119, 91, 45, 49, 93, 32, 49, 48, 44,
  49, 48, 44, 49, 37, 44, 48, 46, 53, 10, 48, 32, 45, 116, 101, 120,
  116, 91, 45, 49, 93, 32, 34, 36, 49, 34, 44, 48, 44, 48, 44, 53,
  55, 44, 49, 44, 50, 53, 53, 32, 45, 102, 114, 97, 109, 101, 91, 45,
  49, 93, 32, 52, 44, 52, 44, 48, 32, 91, 45, 49, 93, 120, 51, 32,
  45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 55, 32, 45, 97,
  91, 45, 52, 45, 45, 49, 93, 32, 99, 10, 45, 97, 91, 45, 50, 44,
  45, 49, 93, 32, 121, 44, 48, 46, 53, 10, 45, 114, 50, 100, 121, 91,
  45, 49, 93, 32, 53, 48, 37, 10, 45, 105, 91, 45, 50, 93, 32, 49,
  50, 48, 37, 44, 49, 50, 48, 37, 44, 49, 44, 51, 44, 50, 53, 53,
  32, 45, 112, 108, 97, 115, 109, 97, 91, 45, 50, 93, 32, 49, 44, 49,
  32, 45, 115, 91, 45, 50, 93, 32, 99, 10, 45, 110, 91, 45, 52, 93,
  32, 49, 53, 48, 44, 50, 53, 53, 32, 45, 110, 91, 45, 51, 93, 32,
  49, 56, 48, 44, 50, 53, 53, 32, 45, 110, 91, 45, 50, 93, 32, 50,
  48, 48, 44, 50, 53, 53, 32, 45, 97, 91, 45, 52, 45, 45, 50, 93,
  32, 99, 10, 45, 98, 108, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93,
  32, 97, 108, 112, 104, 97, 10, 45, 102, 114, 97, 109, 101, 32, 48, 44,
  49, 44, 48, 44, 48, 44, 48, 32, 45, 102, 114, 97, 109, 101, 32, 48,
  44, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 103,
  105, 109, 112, 95, 108, 111, 103, 111, 95, 118, 101, 114, 115, 105, 111, 110,
  50, 32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36, 123, 49, 61, 80,
  108, 117, 103, 45, 105, 110, 32, 102, 111, 114, 32, 71, 73, 77, 80, 125,
  34, 10, 45, 105, 102, 32, 64, 35, 32, 45, 107, 91, 48, 93, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 114, 103, 98, 32, 48, 32,
  45, 116, 91, 45, 49, 93, 32, 34, 71, 39, 77, 73, 67, 34, 44, 48,
  44, 48, 44, 53, 55, 44, 49, 44, 49, 32, 45, 108, 97, 98, 101, 108,
  91, 45, 49, 93, 10, 54, 44, 49, 44, 49, 44, 51, 32, 45, 114, 97,
  110, 100, 91, 45, 49, 93, 32, 49, 53, 48, 44, 50, 53, 53, 32, 45,
  112, 111, 105, 110, 116, 91, 45, 49, 93, 32, 48, 32, 45, 109, 97, 112,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 91, 45, 49, 93,
  32, 49, 48, 44, 48, 32, 45, 98, 91, 45, 49, 93, 32, 50, 32, 45,
  114, 91, 45, 49, 93, 32, 50, 48, 48, 37, 44, 50, 48, 48, 37, 44,
  49, 44, 51, 44, 54, 32, 45, 115, 113, 114, 91, 45, 49, 93, 32, 45,
  99, 91, 45, 49, 93, 32, 48, 44, 54, 48, 37, 32, 45, 110, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 119, 97, 114, 112, 95, 112,
  101, 114, 115, 112, 101, 99, 116, 105, 118, 101, 91, 45, 49, 93, 32, 48,
  46, 53, 44, 48, 44, 49, 44, 53, 48, 44, 53, 48, 44, 48, 32, 45,
  115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 48, 44, 45, 49, 48, 10,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 110, 111, 105, 115, 101,
  91, 45, 49, 93, 32, 48, 46, 56, 44, 50, 32, 45, 42, 91, 45, 49,
  93, 32, 49, 56, 48, 32, 45, 45, 98, 108, 117, 114, 95, 108, 105, 110,
  101, 97, 114, 91, 45, 49, 93, 32, 50, 48, 44, 48, 44, 52, 53, 44,
  48, 32, 45, 42, 91, 45, 49, 93, 32, 50, 48, 32, 45, 109, 97, 120,
  91, 45, 51, 45, 45, 49, 93, 10, 45, 115, 104, 91, 45, 49, 93, 32,
  50, 44, 50, 32, 40, 48, 59, 49, 50, 56, 41, 32, 45, 114, 91, 45,
  49, 93, 32, 91, 45, 50, 93, 44, 51, 32, 45, 43, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 109, 105, 110, 91, 45, 49, 93, 32, 50, 53, 53,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 116, 101, 120, 116, 95, 111,
  117, 116, 108, 105, 110, 101, 91, 45, 49, 93, 32, 34, 36, 49, 34, 44,
  51, 50, 37, 44, 55, 53, 37, 44, 49, 51, 44, 51, 44, 49, 44, 50,
  53, 53, 32, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93, 32, 49, 44,
  49, 44, 49, 50, 56, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 10,
  45, 105, 102, 32, 123, 64, 35, 62, 49, 125, 32, 45, 42, 91, 94, 48,
  93, 32, 48, 46, 52, 53, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  64, 35, 45, 49, 125, 32, 45, 106, 91, 45, 49, 93, 32, 91, 48, 93,
  44, 123, 40, 119, 45, 64, 123, 48, 44, 119, 125, 41, 47, 50, 125, 44,
  123, 40, 104, 45, 64, 123, 48, 44, 104, 125, 41, 47, 50, 125, 32, 45,
  109, 118, 91, 45, 49, 93, 32, 49, 32, 45, 100, 111, 110, 101, 32, 45,
  114, 109, 91, 48, 93, 32, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109,
  112, 95, 108, 111, 103, 111, 95, 118, 101, 114, 115, 105, 111, 110, 49, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 34, 36, 123, 49, 61, 80, 108, 117,
  103, 45, 105, 110, 32, 102, 111, 114, 32, 71, 73, 77, 80, 125, 34, 10,
  45, 105, 102, 32, 64, 35, 32, 114, 97, 116, 105, 111, 61, 123, 119, 47,
  104, 125, 32, 45, 101, 108, 115, 101, 32, 114, 97, 116, 105, 111, 61, 49,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 32, 49, 49, 56, 44,
  52, 52, 44, 49, 44, 49, 32, 45, 116, 32, 34, 71, 39, 77, 73, 67,
  34, 44, 51, 44, 45, 54, 44, 53, 55, 44, 49, 44, 50, 53, 53, 32,
  45, 114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 44,
  49, 32, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 50,
  48, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 44,
  48, 46, 53, 32, 45, 98, 32, 49, 46, 53, 10, 45, 105, 115, 111, 115,
  117, 114, 102, 97, 99, 101, 51, 100, 32, 53, 48, 37, 10, 45, 99, 111,
  108, 51, 100, 32, 123, 63, 40, 49, 53, 48, 44, 50, 53, 53, 41, 125,
  44, 123, 63, 40, 49, 53, 48, 44, 50, 53, 53, 41, 125, 44, 123, 63,
  40, 49, 53, 48, 44, 50, 53, 53, 41, 125, 10, 45, 115, 112, 104, 101,
  114, 101, 51, 100, 32, 56, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49,
  93, 32, 123, 63, 40, 49, 53, 48, 44, 50, 53, 53, 41, 125, 44, 123,
  63, 40, 49, 53, 48, 44, 50, 53, 53, 41, 125, 44, 123, 63, 40, 49,
  53, 48, 44, 50, 53, 53, 41, 125, 32, 45, 43, 51, 100, 91, 45, 49,
  93, 32, 55, 50, 44, 45, 54, 32, 45, 43, 51, 100, 32, 45, 99, 51,
  100, 91, 45, 49, 93, 32, 45, 114, 118, 51, 100, 10, 45, 100, 98, 51,
  100, 32, 48, 32, 45, 115, 108, 51, 100, 32, 48, 46, 50, 32, 45, 115,
  115, 51, 100, 32, 49, 46, 51, 32, 45, 114, 51, 100, 91, 45, 49, 93,
  32, 49, 44, 48, 44, 48, 44, 51, 48, 32, 45, 102, 51, 100, 32, 49,
  50, 48, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 49, 46, 53, 10,
  50, 51, 48, 44, 49, 50, 48, 44, 49, 44, 51, 32, 45, 111, 98, 106,
  101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 53,
  48, 37, 44, 51, 48, 37, 44, 48, 44, 49, 44, 52, 32, 45, 114, 109,
  91, 45, 50, 93, 32, 45, 116, 32, 34, 36, 49, 34, 44, 51, 54, 37,
  44, 55, 53, 37, 44, 49, 51, 44, 49, 44, 50, 53, 53, 10, 45, 116,
  111, 95, 114, 103, 98, 97, 32, 45, 114, 101, 112, 108, 97, 99, 101, 95,
  99, 111, 108, 111, 114, 32, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44,
  50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 48, 32, 45, 100, 114, 111,
  112, 95, 115, 104, 97, 100, 111, 119, 32, 54, 44, 54, 44, 50, 10, 45,
  105, 91, 45, 50, 93, 32, 64, 123, 45, 102, 105, 116, 114, 97, 116, 105,
  111, 95, 119, 104, 92, 32, 50, 51, 48, 44, 49, 50, 48, 44, 36, 114,
  97, 116, 105, 111, 125, 44, 49, 44, 51, 10, 45, 114, 97, 110, 100, 91,
  45, 50, 93, 32, 48, 44, 50, 53, 53, 32, 45, 115, 104, 91, 45, 50,
  93, 32, 48, 44, 48, 32, 45, 47, 91, 45, 49, 93, 32, 50, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 98, 108, 117, 114, 95, 114, 97, 100,
  105, 97, 108, 91, 45, 50, 93, 32, 49, 48, 32, 45, 115, 104, 97, 114,
  112, 101, 110, 91, 45, 50, 93, 32, 54, 48, 48, 10, 45, 114, 91, 45,
  49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 52,
  44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 98, 108,
  101, 110, 100, 32, 97, 108, 112, 104, 97, 10, 103, 105, 109, 112, 95, 108,
  111, 103, 111, 95, 101, 110, 32, 58, 10, 45, 103, 105, 109, 112, 95, 108,
  111, 103, 111, 95, 118, 101, 114, 115, 105, 111, 110, 123, 114, 111, 117, 110,
  100, 40, 63, 40, 49, 44, 51, 41, 41, 125, 32, 34, 80, 108, 117, 103,
  45, 105, 110, 32, 102, 111, 114, 32, 71, 73, 77, 80, 92, 110, 32, 32,
  32, 32, 34, 91, 34, 32, 34, 64, 123, 45, 115, 116, 114, 118, 101, 114,
  125, 34, 32, 34, 93, 10, 35, 64, 103, 105, 109, 112, 95, 99, 97, 32,
  71, 39, 77, 73, 67, 32, 112, 101, 114, 32, 97, 108, 32, 71, 73, 77,
  80, 32, 58, 32, 95, 110, 111, 110, 101, 95, 44, 32, 103, 105, 109, 112,
  95, 108, 111, 103, 111, 95, 99, 97, 10, 35, 64, 103, 105, 109, 112, 95,
  99, 97, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  123, 34, 10, 35, 64, 103, 105, 109, 112, 95, 99, 97, 32, 58, 32, 60,
  115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 32,
  61, 34, 112, 117, 114, 112, 108, 101, 34, 62, 40, 32, 60, 98, 62, 71,
  60, 47, 98, 62, 82, 69, 89, 67, 39, 115, 32, 60, 98, 62, 77, 60,
  47, 98, 62, 97, 103, 105, 99, 32, 102, 111, 114, 32, 60, 98, 62, 73,
  60, 47, 98, 62, 109, 97, 103, 101, 32, 60, 98, 62, 67, 60, 47, 98,
  62, 111, 109, 112, 117, 116, 105, 110, 103, 32, 41, 60, 47, 115, 112, 97,
  110, 62, 92, 110, 92, 110, 32, 38, 35, 50, 51, 51, 59, 115, 32, 117,
  110, 97, 32, 103, 101, 110, 116, 105, 108, 101, 115, 97, 32, 100, 101, 34,
  125, 10, 35, 64, 103, 105, 109, 112, 95, 99, 97, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 92, 51, 48, 51, 92,
  50, 53, 49, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 116, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 101, 46, 117, 115, 101, 114, 115, 46, 103,
  114, 101, 121, 99, 46, 102, 114, 47, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 95, 99, 97, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105,
  110, 107, 123, 34, 40, 32, 73, 77, 65, 71, 69, 32, 84, 101, 97, 109,
  32, 47, 32, 71, 82, 69, 89, 67, 32, 76, 97, 98, 111, 114, 97, 116,
  111, 114, 121, 32, 45, 32, 67, 78, 82, 83, 32, 85, 77, 82, 32, 54,
  48, 55, 50, 32, 41, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 119,
  119, 119, 46, 103, 114, 101, 121, 99, 46, 101, 110, 115, 105, 99, 97, 101,
  110, 46, 102, 114, 47, 69, 113, 117, 105, 112, 101, 73, 109, 97, 103, 101,
  34, 125, 10, 35, 64, 103, 105, 109, 112, 95, 99, 97, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 10, 35, 64, 103,
  105, 109, 112, 95, 99, 97, 32, 58, 32, 65, 113, 117, 101, 115, 116, 32,
  99, 111, 110, 110, 101, 99, 116, 111, 114, 32, 101, 115, 116, 38, 35, 50,
  50, 52, 59, 32, 98, 97, 115, 97, 116, 32, 101, 110, 32, 108, 101, 115,
  32, 98, 105, 98, 108, 105, 111, 116, 101, 113, 117, 101, 115, 32, 100, 101,
  32, 99, 111, 100, 105, 32, 111, 98, 101, 114, 116, 32, 60, 98, 62, 71,
  39, 77, 73, 67, 60, 47, 98, 62, 32, 105, 32, 60, 98, 62, 67, 73,
  109, 103, 60, 47, 98, 62, 32, 40, 67, 43, 43, 32, 84, 101, 109, 112,
  108, 97, 116, 101, 32, 73, 109, 97, 103, 101, 32, 80, 114, 111, 99, 101,
  115, 115, 105, 110, 103, 32, 76, 105, 98, 114, 97, 114, 121, 41, 44, 10,
  35, 64, 103, 105, 109, 112, 95, 99, 97, 32, 58, 32, 100, 105, 115, 112,
  111, 110, 105, 98, 108, 101, 115, 32, 97, 32, 58, 34, 125, 10, 35, 64,
  103, 105, 109, 112, 95, 99, 97, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 108, 105, 110, 107, 40, 34, 104, 116, 116, 112, 58, 47, 47, 103, 109,
  105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110,
  101, 116, 47, 34, 41, 10, 35, 64, 103, 105, 109, 112, 95, 99, 97, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 105,
  34, 125, 10, 35, 64, 103, 105, 109, 112, 95, 99, 97, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 104, 116, 116, 112,
  58, 47, 47, 99, 105, 109, 103, 46, 115, 111, 117, 114, 99, 101, 102, 111,
  114, 103, 101, 46, 110, 101, 116, 47, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 95, 99, 97, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 123, 34, 92, 110, 10, 35, 64, 103, 105, 109, 112, 95, 99, 97,
  32, 58, 32, 83, 105, 32, 116, 39, 97, 103, 114, 97, 100, 97, 32, 101,
  108, 32, 60, 98, 62, 71, 39, 77, 73, 67, 60, 47, 98, 62, 44, 32,
  112, 111, 116, 115, 32, 101, 110, 118, 105, 97, 114, 45, 110, 111, 115, 32,
  117, 110, 97, 32, 112, 111, 115, 116, 97, 108, 32, 100, 101, 108, 32, 108,
  108, 111, 99, 32, 111, 110, 32, 118, 105, 117, 115, 44, 32, 97, 32, 58,
  92, 110, 92, 110, 10, 35, 64, 103, 105, 109, 112, 95, 99, 97, 32, 58,
  32, 60, 115, 109, 97, 108, 108, 62, 60, 116, 116, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 44, 92, 110, 32, 76, 97, 98, 111, 114, 97, 116, 111, 105, 114,
  101, 32, 71, 82, 69, 89, 67, 32, 40, 67, 78, 82, 83, 32, 85, 77,
  82, 32, 54, 48, 55, 50, 41, 44, 32, 69, 113, 117, 105, 112, 101, 32,
  73, 109, 97, 103, 101, 44, 92, 110, 10, 35, 64, 103, 105, 109, 112, 95,
  99, 97, 32, 58, 32, 32, 54, 32, 66, 100, 32, 100, 117, 32, 77, 97,
  114, 38, 35, 50, 51, 51, 59, 99, 104, 97, 108, 32, 74, 117, 105, 110,
  44, 92, 110, 32, 49, 52, 48, 53, 48, 32, 67, 97, 101, 110, 32, 67,
  101, 100, 101, 120, 32, 47, 32, 70, 114, 97, 110, 99, 101, 46, 60, 47,
  116, 116, 62, 60, 47, 115, 109, 97, 108, 108, 62, 92, 110, 92, 110, 10,
  35, 64, 103, 105, 109, 112, 95, 99, 97, 32, 58, 32, 84, 111, 116, 32,
  97, 113, 117, 101, 108, 108, 32, 113, 117, 101, 32, 101, 110, 118, 105, 38,
  35, 50, 51, 57, 59, 32, 117, 110, 97, 32, 112, 111, 115, 116, 97, 108,
  32, 97, 112, 97, 114, 101, 105, 120, 101, 114, 38, 35, 50, 50, 52, 59,
  32, 97, 108, 32, 60, 105, 62, 70, 114, 105, 101, 110, 100, 115, 32, 72,
  97, 108, 108, 32, 111, 102, 32, 70, 97, 109, 101, 60, 47, 105, 62, 32,
  58, 41, 32, 33, 10, 35, 64, 103, 105, 109, 112, 95, 99, 97, 32, 58,
  32, 34, 125, 10, 103, 105, 109, 112, 95, 108, 111, 103, 111, 95, 99, 97,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 108, 111, 103, 111, 95, 118, 101,
  114, 115, 105, 111, 110, 123, 114, 111, 117, 110, 100, 40, 63, 40, 49, 44,
  51, 41, 41, 125, 32, 34, 32, 32, 112, 101, 114, 32, 97, 108, 32, 71,
  73, 77, 80, 92, 110, 32, 32, 32, 34, 91, 34, 32, 34, 64, 123, 45,
  115, 116, 114, 118, 101, 114, 125, 34, 32, 34, 93, 10, 35, 64, 103, 105,
  109, 112, 95, 102, 114, 32, 71, 39, 77, 73, 67, 32, 112, 111, 117, 114,
  32, 71, 73, 77, 80, 32, 58, 32, 95, 110, 111, 110, 101, 95, 44, 32,
  103, 105, 109, 112, 95, 108, 111, 103, 111, 95, 102, 114, 10, 35, 64, 103,
  105, 109, 112, 95, 102, 114, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 123, 34, 10, 35, 64, 103, 105, 109, 112, 95, 102, 114,
  32, 58, 32, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111,
  117, 110, 100, 32, 61, 34, 112, 117, 114, 112, 108, 101, 34, 62, 40, 32,
  60, 98, 62, 71, 60, 47, 98, 62, 82, 69, 89, 67, 39, 115, 32, 60,
  98, 62, 77, 60, 47, 98, 62, 97, 103, 105, 99, 32, 102, 111, 114, 32,
  60, 98, 62, 73, 60, 47, 98, 62, 109, 97, 103, 101, 32, 60, 98, 62,
  67, 60, 47, 98, 62, 111, 109, 112, 117, 116, 105, 110, 103, 32, 41, 60,
  47, 115, 112, 97, 110, 62, 92, 110, 92, 110, 118, 111, 117, 115, 32, 101,
  115, 116, 32, 112, 114, 111, 112, 111, 115, -61, -87, 32, 112, 97, 114, 34,
  125, 10, 35, 64, 103, 105, 109, 112, 95, 102, 114, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 92, 51, 48, 51, 92,
  50, 53, 49, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 116, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 101, 46, 117, 115, 101, 114, 115, 46, 103,
  114, 101, 121, 99, 46, 102, 114, 47, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 95, 102, 114, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105,
  110, 107, 123, 34, 40, 32, 69, 113, 117, 105, 112, 101, 32, 73, 77, 65,
  71, 69, 32, 47, 32, 76, 97, 98, 111, 114, 97, 116, 111, 105, 114, 101,
  32, 71, 82, 69, 89, 67, 32, 45, 32, 67, 78, 82, 83, 32, 85, 77,
  82, 32, 54, 48, 55, 50, 32, 41, 34, 44, 34, 104, 116, 116, 112, 58,
  47, 47, 119, 119, 119, 46, 103, 114, 101, 121, 99, 46, 101, 110, 115, 105,
  99, 97, 101, 110, 46, 102, 114, 47, 69, 113, 117, 105, 112, 101, 73, 109,
  97, 103, 101, 34, 125, 10, 35, 64, 103, 105, 109, 112, 95, 102, 114, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 10,
  35, 64, 103, 105, 109, 112, 95, 102, 114, 32, 58, 32, 67, 101, 32, 103,
  114, 101, 102, 102, 111, 110, 32, 101, 115, 116, 32, 98, 97, 115, 38, 35,
  50, 51, 51, 59, 32, 115, 117, 114, 32, 110, 111, 115, 32, 98, 105, 98,
  108, 105, 111, 116, 104, 38, 35, 50, 51, 50, 59, 113, 117, 101, 115, 32,
  108, 105, 98, 114, 101, 115, 32, 60, 98, 62, 71, 39, 77, 73, 67, 60,
  47, 98, 62, 32, 101, 116, 32, 60, 98, 62, 67, 73, 109, 103, 60, 47,
  98, 62, 32, 40, 67, 43, 43, 32, 84, 101, 109, 112, 108, 97, 116, 101,
  32, 73, 109, 97, 103, 101, 32, 80, 114, 111, 99, 101, 115, 115, 105, 110,
  103, 32, 76, 105, 98, 114, 97, 114, 121, 41, 44, 10, 35, 64, 103, 105,
  109, 112, 95, 102, 114, 32, 58, 32, 100, 105, 115, 112, 111, 110, 105, 98,
  108, 101, 115, 32, 97, 117, 120, 32, 97, 100, 114, 101, 115, 115, 101, 115,
  32, 58, 34, 125, 10, 35, 64, 103, 105, 109, 112, 95, 102, 114, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 104, 116,
  116, 112, 58, 47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101,
  102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 95, 102, 114, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 123, 34, 101, 116, 34, 125, 10, 35, 64, 103, 105, 109,
  112, 95, 102, 114, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105,
  110, 107, 40, 34, 104, 116, 116, 112, 58, 47, 47, 99, 105, 109, 103, 46,
  115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 95, 102, 114, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 92, 110, 10, 35,
  64, 103, 105, 109, 112, 95, 102, 114, 32, 58, 32, 83, 105, 32, 118, 111,
  117, 115, 32, 97, 112, 112, 114, 38, 35, 50, 51, 51, 59, 99, 105, 101,
  122, 32, 60, 98, 62, 71, 39, 77, 73, 67, 60, 47, 98, 62, 44, 32,
  118, 111, 117, 115, 32, 112, 111, 117, 118, 101, 122, 32, 110, 111, 117, 115,
  32, 108, 101, 32, 102, 97, 105, 114, 101, 32, 115, 97, 118, 111, 105, 114,
  32, 101, 110, 32, 110, 111, 117, 115, 32, 101, 110, 118, 111, 121, 97, 110,
  116, 32, 117, 110, 101, 32, 106, 111, 108, 105, 101, 32, 99, 97, 114, 116,
  101, 10, 35, 64, 103, 105, 109, 112, 95, 102, 114, 32, 58, 32, 112, 111,
  115, 116, 97, 108, 101, 32, 100, 101, 32, 118, 111, 116, 114, 101, 32, 118,
  105, 108, 108, 101, 32, 111, 117, 32, 114, 38, 35, 50, 51, 51, 59, 103,
  105, 111, 110, 44, 32, 38, 35, 50, 50, 52, 59, 32, 108, 39, 97, 100,
  114, 101, 115, 115, 101, 32, 58, 92, 110, 92, 110, 10, 35, 64, 103, 105,
  109, 112, 95, 102, 114, 32, 58, 32, 60, 115, 109, 97, 108, 108, 62, 60,
  116, 116, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112,
  101, 114, 108, 38, 35, 50, 51, 51, 59, 44, 92, 110, 32, 76, 97, 98,
  111, 114, 97, 116, 111, 105, 114, 101, 32, 71, 82, 69, 89, 67, 32, 40,
  67, 78, 82, 83, 32, 85, 77, 82, 32, 54, 48, 55, 50, 41, 44, 32,
  69, 113, 117, 105, 112, 101, 32, 73, 109, 97, 103, 101, 44, 92, 110, 10,
  35, 64, 103, 105, 109, 112, 95, 102, 114, 32, 58, 32, 32, 54, 32, 66,
  100, 32, 100, 117, 32, 77, 97, 114, 38, 35, 50, 51, 51, 59, 99, 104,
  97, 108, 32, 74, 117, 105, 110, 44, 92, 110, 32, 49, 52, 48, 53, 48,
  32, 67, 97, 101, 110, 32, 67, 101, 100, 101, 120, 32, 47, 32, 70, 114,
  97, 110, 99, 101, 46, 60, 47, 116, 116, 62, 60, 47, 115, 109, 97, 108,
  108, 62, 92, 110, 92, 110, 10, 35, 64, 103, 105, 109, 112, 95, 102, 114,
  32, 58, 32, 69, 110, 118, 111, 121, 101, 114, 32, 117, 110, 101, 32, 99,
  97, 114, 116, 101, 32, 112, 111, 115, 116, 97, 108, 101, 32, 118, 111, 117,
  115, 32, 102, 101, 114, 97, 32, 114, 101, 110, 116, 114, 101, 114, 32, 60,
  105, 62, 100, 101, 32, 102, 97, 99, 116, 111, 60, 47, 105, 62, 32, 100,
  97, 110, 115, 32, 108, 101, 32, 60, 105, 62, 70, 114, 105, 101, 110, 100,
  115, 32, 72, 97, 108, 108, 32, 111, 102, 32, 70, 97, 109, 101, 60, 47,
  105, 62, 32, 58, 41, 32, 33, 10, 35, 64, 103, 105, 109, 112, 95, 102,
  114, 32, 58, 32, 34, 125, 10, 103, 105, 109, 112, 95, 108, 111, 103, 111,
  95, 102, 114, 32, 58, 10, 45, 103, 105, 109, 112, 95, 108, 111, 103, 111,
  95, 118, 101, 114, 115, 105, 111, 110, 123, 114, 111, 117, 110, 100, 40, 63,
  40, 49, 44, 51, 41, 41, 125, 32, 34, 71, 114, 101, 102, 102, 111, 110,
  32, 112, 111, 117, 114, 32, 71, 73, 77, 80, 92, 110, 32, 32, 32, 34,
  91, 34, 32, 34, 64, 123, 45, 115, 116, 114, 118, 101, 114, 125, 34, 32,
  34, 93, 10, 35, 64, 103, 105, 109, 112, 32, 71, 109, 105, 99, 107, 121,
  32, 45, 32, 82, 111, 100, 100, 121, 32, 58, 32, 103, 105, 109, 112, 95,
  103, 109, 105, 99, 107, 121, 44, 32, 103, 105, 109, 112, 95, 103, 109, 105,
  99, 107, 121, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 77, 97, 115, 99, 111, 116, 32, 105, 109, 97, 103,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 71, 109, 105, 99,
  107, 121, 34, 44, 34, 71, 109, 105, 99, 107, 121, 32, 38, 32, 87, 105,
  108, 98, 101, 114, 34, 44, 34, 82, 111, 100, 100, 121, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34,
  60, 98, 62, 60, 105, 62, 71, 109, 105, 99, 107, 121, 60, 47, 105, 62,
  60, 47, 98, 62, 32, 105, 115, 32, 116, 104, 101, 32, 110, 97, 109, 101,
  32, 111, 102, 32, 116, 104, 101, 32, 60, 98, 62, 71, 39, 77, 73, 67,
  60, 47, 98, 62, 32, 109, 97, 115, 99, 111, 116, 46, 32, 72, 101, 32,
  105, 115, 32, 97, 32, 115, 109, 97, 108, 108, 32, 97, 110, 100, 32, 99,
  117, 116, 101, 32, 116, 105, 103, 101, 114, 32, 119, 104, 111, 32, 107, 110,
  111, 119, 115, 32, 104, 111, 119, 32, 116, 111, 32, 100, 111, 32, 109, 97,
  103, 105, 99, 46, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 98,
  62, 60, 105, 62, 71, 109, 105, 99, 107, 121, 60, 47, 105, 62, 60, 47,
  98, 62, 32, 105, 115, 32, 97, 32, 116, 105, 103, 101, 114, 44, 32, 105,
  46, 101, 46, 32, 102, 97, 115, 116, 44, 32, 97, 103, 105, 108, 101, 32,
  97, 110, 100, 32, 101, 108, 101, 103, 97, 110, 116, 44, 32, 106, 117, 115,
  116, 32, 97, 115, 32, 116, 104, 101, 32, 60, 98, 62, 71, 39, 77, 73,
  67, 60, 47, 98, 62, 32, 99, 111, 100, 101, 32, 105, 115, 32, 58, 41,
  46, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 115, 32, 109, 97,
  110, 121, 32, 109, 97, 103, 105, 99, 105, 97, 110, 115, 44, 32, 60, 98,
  62, 60, 105, 62, 71, 109, 105, 99, 107, 121, 60, 47, 105, 62, 60, 47,
  98, 62, 32, 107, 110, 111, 119, 115, 32, 108, 111, 116, 32, 111, 102, 32,
  103, 105, 109, 109, 105, 99, 107, 115, 32, 40, 60, 98, 62, 71, 39, 77,
  73, 67, 60, 47, 98, 62, 41, 44, 32, 97, 110, 100, 32, 104, 101, 32,
  105, 115, 32, 97, 32, 100, 105, 114, 101, 99, 116, 32, 97, 110, 100, 32,
  102, 114, 105, 101, 110, 100, 108, 121, 32, 99, 111, 109, 112, 101, 116, 105,
  116, 111, 114, 32, 111, 102, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  116, 104, 101, 32, 73, 109, 97, 103, 101, 77, 97, 103, 105, 99, 107, 39,
  115, 32, 119, 105, 122, 97, 114, 100, 44, 32, 111, 114, 32, 116, 104, 101,
  32, 71, 114, 97, 112, 104, 105, 99, 77, 97, 103, 105, 99, 107, 39, 115,
  32, 102, 114, 111, 103, 46, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60,
  98, 62, 60, 105, 62, 82, 111, 100, 100, 121, 60, 47, 105, 62, 60, 47,
  98, 62, 32, 105, 115, 32, 97, 110, 111, 116, 104, 101, 114, 32, 109, 97,
  115, 99, 111, 116, 32, 100, 101, 115, 105, 103, 110, 101, 100, 32, 115, 112,
  101, 99, 105, 102, 105, 99, 97, 108, 108, 121, 32, 102, 111, 114, 32, 116,
  104, 101, 32, 60, 105, 62, 65, 114, 116, 105, 115, 116, 105, 99, 32, 47,
  32, 82, 111, 100, 105, 108, 105, 117, 115, 60, 47, 105, 62, 32, 102, 105,
  108, 116, 101, 114, 32, 111, 102, 32, 60, 98, 62, 71, 39, 77, 73, 67,
  60, 47, 98, 62, 46, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 98,
  62, 60, 105, 62, 71, 109, 105, 99, 107, 121, 60, 47, 105, 62, 60, 47,
  98, 62, 32, 97, 110, 100, 32, 60, 98, 62, 60, 105, 62, 82, 111, 100,
  100, 121, 60, 47, 105, 62, 60, 47, 98, 62, 32, 104, 97, 118, 101, 32,
  98, 101, 101, 110, 32, 100, 101, 115, 105, 103, 110, 101, 100, 32, 98, 121,
  32, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110,
  107, 32, 61, 32, 108, 105, 110, 107, 40, 34, 77, 97, 104, 118, 101, 108,
  111, 117, 115, 32, 77, 97, 104, 118, 105, 110, 34, 44, 34, 104, 116, 116,
  112, 58, 47, 47, 119, 119, 119, 46, 109, 97, 104, 118, 105, 110, 46, 99,
  111, 109, 47, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 115, 58, 32, 60,
  105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101,
  114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 32, 97, 110, 100,
  32, 60, 105, 62, 77, 97, 104, 118, 105, 110, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48, 53, 47, 50,
  55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 103, 105, 109, 112, 95, 103, 109, 105, 99, 107, 121, 32, 58, 10, 45,
  114, 109, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 125, 32, 45,
  103, 109, 105, 99, 107, 121, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49,
  61, 61, 49, 125, 32, 45, 103, 109, 105, 99, 107, 121, 95, 119, 105, 108,
  98, 101, 114, 10, 45, 101, 108, 115, 101, 32, 45, 114, 111, 100, 100, 121,
  10, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 103, 109, 105,
  99, 107, 121, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 119, 61,
  123, 119, 125, 32, 104, 61, 123, 104, 125, 32, 45, 114, 109, 10, 45, 105,
  102, 32, 123, 36, 49, 61, 61, 48, 125, 10, 102, 105, 108, 101, 110, 97,
  109, 101, 61, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109, 112, 125, 47,
  103, 109, 105, 99, 107, 121, 95, 115, 109, 97, 108, 108, 46, 99, 105, 109,
  103, 122, 10, 117, 114, 108, 61, 104, 116, 116, 112, 58, 47, 47, 103, 109,
  105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110,
  101, 116, 47, 105, 109, 103, 47, 103, 109, 105, 99, 107, 121, 95, 115, 109,
  97, 108, 108, 46, 99, 105, 109, 103, 122, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 49, 61, 61, 49, 125, 10, 102, 105, 108, 101, 110, 97, 109, 101,
  61, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109, 112, 125, 47, 103, 109,
  105, 99, 107, 121, 95, 119, 105, 108, 98, 101, 114, 95, 115, 109, 97, 108,
  108, 46, 99, 105, 109, 103, 122, 10, 117, 114, 108, 61, 104, 116, 116, 112,
  58, 47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111,
  114, 103, 101, 46, 110, 101, 116, 47, 105, 109, 103, 47, 103, 109, 105, 99,
  107, 121, 95, 119, 105, 108, 98, 101, 114, 95, 115, 109, 97, 108, 108, 46,
  99, 105, 109, 103, 122, 10, 45, 101, 108, 115, 101, 10, 102, 105, 108, 101,
  110, 97, 109, 101, 61, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109, 112,
  125, 47, 114, 111, 100, 100, 121, 95, 115, 109, 97, 108, 108, 46, 99, 105,
  109, 103, 122, 10, 117, 114, 108, 61, 104, 116, 116, 112, 58, 47, 47, 103,
  109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46,
  110, 101, 116, 47, 105, 109, 103, 47, 114, 111, 100, 100, 121, 95, 115, 109,
  97, 108, 108, 46, 99, 105, 109, 103, 122, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 32, 36,
  102, 105, 108, 101, 110, 97, 109, 101, 32, 45, 101, 108, 115, 101, 32, 45,
  105, 32, 36, 117, 114, 108, 32, 45, 111, 32, 36, 102, 105, 108, 101, 110,
  97, 109, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 50, 100, 121,
  32, 36, 104, 32, 45, 45, 32, 50, 53, 53, 32, 45, 114, 32, 36, 119,
  44, 36, 104, 44, 49, 44, 51, 44, 48, 44, 48, 44, 48, 46, 53, 44,
  48, 46, 53, 32, 45, 43, 32, 50, 53, 53, 10, 35, 64, 103, 105, 109,
  112, 32, 76, 105, 110, 107, 115, 32, 58, 32, 95, 110, 111, 110, 101, 95,
  44, 32, 95, 110, 111, 110, 101, 95, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 101, 114, 101, 32, 105, 115,
  32, 97, 32, 108, 105, 115, 116, 32, 111, 102, 32, 108, 105, 110, 107, 115,
  32, 116, 104, 97, 116, 32, 109, 105, 103, 104, 116, 32, 104, 101, 108, 112,
  32, 121, 111, 117, 32, 105, 110, 32, 102, 105, 110, 100, 105, 110, 103, 32,
  97, 100, 100, 105, 116, 105, 111, 110, 97, 108, 32, 105, 110, 102, 111, 114,
  109, 97, 116, 105, 111, 110, 32, 97, 98, 111, 117, 116, 32, 116, 104, 101,
  32, 71, 39, 77, 73, 67, 32, 112, 114, 111, 106, 101, 99, 116, 46, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 125, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 60, 98, 62, 68, 111, 99, 117, 109, 101, 110, 116, 97,
  116, 105, 111, 110, 58, 60, 47, 98, 62, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 108, 105, 110, 107, 123, 48, 44, 34, 79, 102, 102, 105,
  99, 105, 97, 108, 32, 71, 39, 77, 73, 67, 32, 119, 105, 107, 105, 46,
  34, 44, 34, 104, 116, 116, 112, 115, 58, 47, 47, 115, 111, 117, 114, 99,
  101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 112, 47, 103, 109, 105,
  99, 47, 119, 105, 107, 105, 47, 72, 111, 109, 101, 47, 34, 125, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108,
  105, 110, 107, 123, 48, 44, 34, 83, 99, 114, 101, 101, 110, 115, 104, 111,
  116, 115, 32, 111, 102, 32, 115, 111, 109, 101, 32, 111, 102, 32, 116, 104,
  101, 32, 112, 108, 117, 103, 45, 105, 110, 32, 102, 105, 108, 116, 101, 114,
  115, 46, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 103, 109, 105, 99,
  46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116,
  47, 103, 105, 109, 112, 46, 115, 104, 116, 109, 108, 34, 125, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105,
  110, 107, 123, 48, 44, 34, 76, 105, 115, 116, 32, 111, 102, 32, 97, 118,
  97, 105, 108, 97, 98, 108, 101, 32, 112, 108, 117, 103, 45, 105, 110, 32,
  102, 105, 108, 116, 101, 114, 115, 46, 34, 44, 34, 104, 116, 116, 112, 58,
  47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114,
  103, 101, 46, 110, 101, 116, 47, 103, 105, 109, 112, 95, 102, 105, 108, 116,
  101, 114, 115, 46, 116, 120, 116, 34, 125, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 123, 48,
  44, 34, 82, 101, 102, 101, 114, 101, 110, 99, 101, 32, 100, 111, 99, 117,
  109, 101, 110, 116, 97, 116, 105, 111, 110, 32, 111, 102, 32, 116, 104, 101,
  32, 71, 39, 77, 73, 67, 32, 108, 97, 110, 103, 117, 97, 103, 101, 32,
  40, 104, 116, 109, 108, 41, 46, 34, 44, 34, 104, 116, 116, 112, 58, 47,
  47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103,
  101, 46, 110, 101, 116, 47, 114, 101, 102, 101, 114, 101, 110, 99, 101, 46,
  115, 104, 116, 109, 108, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 123, 48, 44, 34,
  82, 101, 102, 101, 114, 101, 110, 99, 101, 32, 100, 111, 99, 117, 109, 101,
  110, 116, 97, 116, 105, 111, 110, 32, 111, 102, 32, 116, 104, 101, 32, 71,
  39, 77, 73, 67, 32, 108, 97, 110, 103, 117, 97, 103, 101, 32, 40, 112,
  100, 102, 41, 46, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 103, 109,
  105, 99, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110,
  101, 116, 47, 103, 109, 105, 99, 95, 114, 101, 102, 101, 114, 101, 110, 99,
  101, 46, 112, 100, 102, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  60, 98, 62, 78, 101, 119, 115, 32, 47, 32, 67, 111, 109, 109, 117, 110,
  105, 116, 105, 101, 115, 58, 60, 47, 98, 62, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 108, 105, 110, 107, 123, 48, 44, 34, 71, 39, 77,
  73, 67, 32, 110, 101, 119, 115, 32, 111, 110, 32, 71, 111, 111, 103, 108,
  101, 43, 46, 34, 44, 34, 104, 116, 116, 112, 115, 58, 47, 47, 112, 108,
  117, 115, 46, 103, 111, 111, 103, 108, 101, 46, 99, 111, 109, 47, 49, 49,
  55, 52, 52, 49, 50, 51, 55, 57, 56, 50, 50, 56, 51, 48, 49, 49,
  51, 49, 56, 47, 112, 111, 115, 116, 115, 34, 125, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107,
  123, 48, 44, 34, 71, 39, 77, 73, 67, 32, 99, 111, 109, 109, 117, 110,
  105, 116, 121, 32, 111, 110, 32, 71, 111, 111, 103, 108, 101, 43, 46, 34,
  44, 34, 104, 116, 116, 112, 115, 58, 47, 47, 112, 108, 117, 115, 46, 103,
  111, 111, 103, 108, 101, 46, 99, 111, 109, 47, 117, 47, 48, 47, 98, 47,
  49, 49, 55, 52, 52, 49, 50, 51, 55, 57, 56, 50, 50, 56, 51, 48,
  49, 49, 51, 49, 56, 47, 99, 111, 109, 109, 117, 110, 105, 116, 105, 101,
  115, 47, 49, 48, 48, 51, 54, 55, 53, 57, 56, 52, 54, 49, 51, 56,
  50, 51, 52, 55, 52, 51, 57, 34, 125, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 123, 48,
  44, 34, 71, 39, 77, 73, 67, 32, 99, 111, 109, 109, 117, 110, 105, 116,
  121, 32, 111, 110, 32, 71, 105, 109, 112, 67, 104, 97, 116, 46, 34, 44,
  34, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 103, 105, 109, 112,
  99, 104, 97, 116, 46, 99, 111, 109, 47, 118, 105, 101, 119, 102, 111, 114,
  117, 109, 46, 112, 104, 112, 63, 102, 61, 50, 56, 34, 125, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105,
  110, 107, 123, 48, 44, 34, 71, 39, 77, 73, 67, 32, 99, 111, 109, 109,
  117, 110, 105, 116, 121, 32, 111, 110, 32, 70, 108, 105, 99, 107, 114, 46,
  34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 102, 108,
  105, 99, 107, 114, 46, 99, 111, 109, 47, 103, 114, 111, 117, 112, 115, 47,
  103, 109, 105, 99, 47, 100, 105, 115, 99, 117, 115, 115, 47, 34, 125, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 115, 58, 32, 60, 105, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 51, 47, 49, 50, 47, 49, 55, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  82, 101, 108, 101, 97, 115, 101, 32, 110, 111, 116, 101, 115, 32, 58, 32,
  95, 110, 111, 110, 101, 95, 44, 32, 95, 110, 111, 110, 101, 95, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 123, 34, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 45,
  32, 60, 98, 62, 50, 48, 48, 57, 47, 48, 49, 47, 49, 51, 60, 47,
  98, 62, 32, 58, 32, 118, 101, 114, 115, 105, 111, 110, 32, 60, 105, 62,
  49, 46, 51, 60, 47, 105, 62, 32, 40, 105, 110, 105, 116, 105, 97, 108,
  32, 112, 108, 117, 103, 45, 105, 110, 32, 114, 101, 108, 101, 97, 115, 101,
  41, 46, 92, 110, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 45, 32,
  60, 98, 62, 50, 48, 49, 48, 47, 48, 57, 47, 48, 51, 60, 47, 98,
  62, 32, 58, 32, 118, 101, 114, 115, 105, 111, 110, 32, 60, 105, 62, 49,
  46, 52, 60, 47, 105, 62, 46, 92, 110, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 45, 32, 60, 98, 62, 50, 48, 49, 49, 47, 48, 55, 47,
  48, 55, 60, 47, 98, 62, 32, 58, 32, 118, 101, 114, 115, 105, 111, 110,
  32, 60, 105, 62, 49, 46, 53, 46, 48, 46, 48, 60, 47, 105, 62, 46,
  92, 110, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 45, 32, 60, 98,
  62, 50, 48, 49, 50, 47, 48, 51, 47, 48, 49, 60, 47, 98, 62, 32,
  58, 32, 118, 101, 114, 115, 105, 111, 110, 32, 60, 105, 62, 49, 46, 53,
  46, 49, 46, 48, 60, 47, 105, 62, 46, 92, 110, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 45, 32, 60, 98, 62, 50, 48, 49, 50, 47, 49,
  48, 47, 49, 53, 60, 47, 98, 62, 32, 58, 32, 118, 101, 114, 115, 105,
  111, 110, 32, 60, 105, 62, 49, 46, 53, 46, 50, 46, 48, 60, 47, 105,
  62, 46, 92, 110, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 45, 32,
  60, 98, 62, 50, 48, 49, 51, 47, 48, 49, 47, 48, 55, 60, 47, 98,
  62, 32, 58, 32, 118, 101, 114, 115, 105, 111, 110, 32, 60, 105, 62, 49,
  46, 53, 46, 51, 46, 48, 60, 47, 105, 62, 46, 92, 110, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 45, 32, 60, 98, 62, 50, 48, 49, 51,
  47, 48, 49, 47, 50, 56, 60, 47, 98, 62, 32, 58, 32, 118, 101, 114,
  115, 105, 111, 110, 32, 60, 105, 62, 49, 46, 53, 46, 52, 46, 48, 60,
  47, 105, 62, 46, 92, 110, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  45, 32, 60, 98, 62, 50, 48, 49, 51, 47, 48, 51, 47, 48, 56, 60,
  47, 98, 62, 32, 58, 32, 118, 101, 114, 115, 105, 111, 110, 32, 60, 105,
  62, 49, 46, 53, 46, 53, 46, 48, 60, 47, 105, 62, 46, 92, 110, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 45, 32, 60, 98, 62, 50, 48,
  49, 51, 47, 48, 54, 47, 48, 51, 60, 47, 98, 62, 32, 58, 32, 118,
  101, 114, 115, 105, 111, 110, 32, 60, 105, 62, 49, 46, 53, 46, 54, 46,
  48, 60, 47, 105, 62, 46, 92, 110, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 45, 32, 60, 98, 62, 50, 48, 49, 51, 47, 48, 57, 47, 48,
  57, 60, 47, 98, 62, 32, 58, 32, 118, 101, 114, 115, 105, 111, 110, 32,
  60, 105, 62, 49, 46, 53, 46, 55, 46, 48, 60, 47, 105, 62, 46, 92,
  110, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 45, 32, 60, 98, 62,
  50, 48, 49, 51, 47, 49, 50, 47, 48, 55, 60, 47, 98, 62, 32, 58,
  32, 118, 101, 114, 115, 105, 111, 110, 32, 60, 105, 62, 49, 46, 53, 46,
  56, 46, 48, 60, 47, 105, 62, 46, 92, 110, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 45, 32, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101,
  103, 114, 111, 117, 110, 100, 32, 61, 34, 112, 117, 114, 112, 108, 101, 34,
  62, 60, 98, 62, 50, 48, 49, 52, 47, 48, 50, 47, 48, 55, 60, 47,
  98, 62, 32, 58, 32, 118, 101, 114, 115, 105, 111, 110, 32, 60, 105, 62,
  49, 46, 53, 46, 56, 46, 51, 60, 47, 105, 62, 32, 40, 67, 117, 114,
  114, 101, 110, 116, 32, 115, 116, 97, 98, 108, 101, 41, 46, 60, 47, 115,
  112, 97, 110, 62, 92, 110, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107,
  32, 61, 32, 108, 105, 110, 107, 40, 34, 86, 105, 101, 119, 32, 108, 97,
  116, 101, 115, 116, 32, 99, 104, 97, 110, 103, 101, 108, 111, 103, 34, 44,
  34, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 102, 108, 105, 99,
  107, 114, 46, 99, 111, 109, 47, 103, 114, 111, 117, 112, 115, 47, 103, 109,
  105, 99, 47, 100, 105, 115, 99, 117, 115, 115, 47, 55, 50, 49, 53, 55,
  54, 51, 57, 55, 50, 56, 48, 48, 52, 53, 56, 53, 47, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 52, 47, 48, 50, 47, 48, 55, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 95,
  10, 35, 64, 103, 105, 109, 112, 32, 60, 98, 62, 65, 114, 114, 97, 121,
  115, 32, 38, 97, 109, 112, 59, 32, 116, 105, 108, 101, 115, 60, 47, 98,
  62, 10, 35, 64, 103, 105, 109, 112, 32, 65, 114, 114, 97, 121, 32, 91,
  102, 97, 100, 101, 100, 93, 32, 58, 32, 103, 105, 109, 112, 95, 97, 114,
  114, 97, 121, 95, 102, 97, 100, 101, 44, 32, 103, 105, 109, 112, 95, 97,
  114, 114, 97, 121, 95, 102, 97, 100, 101, 95, 112, 114, 101, 118, 105, 101,
  119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45,
  116, 105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 50, 44, 49, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 116,
  105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 50, 44, 49, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 111, 102,
  102, 115, 101, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89,
  45, 111, 102, 102, 115, 101, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 70, 97, 100, 101, 32, 115, 116, 97, 114, 116, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 56, 48, 44, 49, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 70, 97, 100, 101, 32, 101, 110, 100,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 57, 48, 44, 49, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 105, 114, 114,
  111, 114, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 78, 111, 110,
  101, 34, 44, 34, 120, 45, 97, 120, 105, 115, 34, 44, 34, 121, 45, 97,
  120, 105, 115, 34, 44, 34, 120, 121, 45, 97, 120, 101, 115, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 105, 122, 101, 32, 61, 32,
  95, 99, 104, 111, 105, 99, 101, 40, 34, 83, 104, 114, 105, 110, 107, 34,
  44, 32, 34, 69, 120, 112, 97, 110, 100, 34, 44, 32, 34, 82, 101, 112,
  101, 97, 116, 32, 91, 77, 101, 109, 111, 114, 121, 32, 99, 111, 110, 115,
  117, 109, 105, 110, 103, 33, 93, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47,
  50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 97, 114, 114, 97, 121, 95, 102, 97, 100,
  101, 32, 58, 10, 45, 105, 102, 32, 123, 36, 55, 38, 49, 125, 32, 45,
  109, 105, 114, 114, 111, 114, 32, 120, 32, 45, 101, 110, 100, 105, 102, 32,
  45, 105, 102, 32, 123, 36, 55, 62, 49, 125, 32, 45, 109, 105, 114, 114,
  111, 114, 32, 121, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 114, 114,
  97, 121, 95, 102, 97, 100, 101, 32, 36, 49, 44, 36, 50, 44, 36, 53,
  44, 36, 54, 44, 36, 56, 10, 45, 115, 104, 105, 102, 116, 32, 45, 36,
  51, 37, 44, 45, 36, 52, 37, 44, 48, 44, 48, 44, 50, 10, 103, 105,
  109, 112, 95, 97, 114, 114, 97, 121, 95, 102, 97, 100, 101, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 97, 114,
  114, 97, 121, 95, 102, 97, 100, 101, 32, 36, 49, 44, 36, 50, 44, 36,
  51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 48, 10,
  35, 64, 103, 105, 109, 112, 32, 65, 114, 114, 97, 121, 32, 91, 109, 105,
  114, 114, 111, 114, 101, 100, 93, 32, 58, 32, 103, 105, 109, 112, 95, 97,
  114, 114, 97, 121, 95, 109, 105, 114, 114, 111, 114, 44, 32, 103, 105, 109,
  112, 95, 97, 114, 114, 97, 121, 95, 109, 105, 114, 114, 111, 114, 95, 112,
  114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32,
  105, 110, 116, 40, 49, 44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 88, 45, 111, 102, 102, 115, 101, 116, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 111, 102, 102, 115, 101, 116,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 114, 114, 97, 121,
  32, 109, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 50,
  44, 34, 120, 45, 97, 120, 105, 115, 34, 44, 34, 121, 45, 97, 120, 105,
  115, 34, 44, 34, 120, 121, 45, 97, 120, 101, 115, 34, 44, 34, 50, 120,
  121, 45, 97, 120, 101, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 73, 110, 105, 116, 105, 97, 108, 105, 122, 97, 116, 105, 111, 110,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 79, 114, 105, 103, 105,
  110, 97, 108, 34, 44, 34, 77, 105, 114, 114, 111, 114, 32, 88, 34, 44,
  34, 77, 105, 114, 114, 111, 114, 32, 89, 34, 44, 34, 82, 111, 116, 97,
  116, 101, 32, 57, 48, 32, 100, 101, 103, 46, 34, 44, 34, 82, 111, 116,
  97, 116, 101, 32, 49, 56, 48, 32, 100, 101, 103, 46, 34, 44, 34, 82,
  111, 116, 97, 116, 101, 32, 50, 55, 48, 32, 100, 101, 103, 46, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 120, 112, 97, 110, 100,
  32, 115, 105, 122, 101, 32, 61, 32, 95, 98, 111, 111, 108, 40, 102, 97,
  108, 115, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 114,
  111, 112, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118,
  105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50,
  51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62,
  50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 97,
  114, 114, 97, 121, 95, 109, 105, 114, 114, 111, 114, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 55, 61, 48, 125, 10, 45, 105, 102, 32, 123,
  36, 53, 61, 61, 49, 125, 32, 45, 109, 105, 114, 114, 111, 114, 32, 120,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 53, 61, 61, 50, 125, 32, 45,
  109, 105, 114, 114, 111, 114, 32, 121, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 53, 61, 61, 51, 125, 32, 45, 114, 111, 116, 97, 116, 101, 32, 57,
  48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 53, 61, 61, 52, 125, 32,
  45, 114, 111, 116, 97, 116, 101, 32, 49, 56, 48, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 53, 61, 61, 53, 125, 32, 45, 114, 111, 116, 97, 116,
  101, 32, 50, 55, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 36, 55, 10, 45, 105, 102, 32, 123, 36, 52, 61, 61, 48, 125, 32,
  45, 99, 111, 108, 117, 109, 110, 115, 32, 48, 44, 123, 49, 48, 48, 45,
  36, 55, 125, 37, 10, 45, 101, 108, 105, 102, 32, 123, 36, 52, 61, 61,
  49, 125, 32, 45, 114, 111, 119, 115, 32, 48, 44, 123, 49, 48, 48, 45,
  36, 55, 125, 37, 10, 45, 101, 108, 105, 102, 32, 123, 36, 52, 61, 61,
  50, 125, 32, 45, 122, 32, 48, 44, 48, 44, 123, 49, 48, 48, 45, 36,
  55, 125, 37, 44, 123, 49, 48, 48, 45, 36, 55, 125, 37, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 52, 61, 61, 51, 125, 32, 45, 122, 32, 123,
  36, 55, 47, 50, 125, 37, 44, 123, 36, 55, 47, 50, 125, 37, 44, 123,
  49, 48, 48, 45, 36, 55, 47, 50, 125, 37, 44, 123, 49, 48, 48, 45,
  36, 55, 47, 50, 125, 37, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 115, 104, 105, 102, 116, 32, 45, 36, 50, 37,
  44, 45, 36, 51, 37, 44, 48, 44, 48, 44, 50, 10, 45, 97, 114, 114,
  97, 121, 95, 109, 105, 114, 114, 111, 114, 32, 36, 49, 44, 36, 52, 44,
  36, 54, 10, 103, 105, 109, 112, 95, 97, 114, 114, 97, 121, 95, 109, 105,
  114, 114, 111, 114, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 97, 114, 114, 97, 121, 95, 109, 105, 114, 114, 111,
  114, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53,
  44, 48, 44, 36, 55, 10, 35, 64, 103, 105, 109, 112, 32, 65, 114, 114,
  97, 121, 32, 91, 114, 97, 110, 100, 111, 109, 93, 32, 58, 32, 97, 114,
  114, 97, 121, 95, 114, 97, 110, 100, 111, 109, 44, 32, 97, 114, 114, 97,
  121, 95, 114, 97, 110, 100, 111, 109, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 111, 117, 114, 99, 101, 32, 120, 45, 116, 105,
  108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 53, 44, 49, 44, 50, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 111, 117, 114, 99,
  101, 32, 121, 45, 116, 105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40,
  53, 44, 49, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 68, 101, 115, 116, 105, 110, 97, 116, 105, 111, 110, 32, 120, 45, 116,
  105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 55, 44, 49, 44, 50,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 115, 116,
  105, 110, 97, 116, 105, 111, 110, 32, 121, 45, 116, 105, 108, 101, 115, 32,
  61, 32, 105, 110, 116, 40, 55, 44, 49, 44, 50, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84,
  115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48,
  47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 65, 114, 114,
  97, 121, 32, 91, 114, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111, 114,
  115, 93, 32, 58, 32, 103, 105, 109, 112, 95, 97, 114, 114, 97, 121, 95,
  99, 111, 108, 111, 114, 44, 32, 103, 105, 109, 112, 95, 97, 114, 114, 97,
  121, 95, 99, 111, 108, 111, 114, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 88, 45, 116, 105, 108, 101, 115, 32, 61, 32, 105, 110,
  116, 40, 53, 44, 49, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 89, 45, 116, 105, 108, 101, 115, 32, 61, 32, 105, 110, 116,
  40, 53, 44, 49, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104,
  117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50,
  47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 103, 105, 109, 112, 95, 97, 114, 114, 97, 121, 95, 99, 111,
  108, 111, 114, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 45, 49, 93, 10, 36, 49, 44, 36, 50, 44, 49, 44,
  51, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 32, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 91,
  45, 49, 93, 32, 64, 123, 45, 50, 44, 115, 125, 32, 45, 114, 91, 45,
  49, 93, 32, 91, 45, 50, 93, 32, 45, 42, 91, 45, 49, 93, 32, 36,
  51, 32, 45, 42, 91, 45, 50, 93, 32, 123, 49, 45, 36, 51, 125, 32,
  45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32,
  45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10,
  35, 64, 103, 105, 109, 112, 32, 65, 114, 114, 97, 121, 32, 91, 114, 101,
  103, 117, 108, 97, 114, 93, 32, 58, 32, 103, 105, 109, 112, 95, 97, 114,
  114, 97, 121, 44, 32, 103, 105, 109, 112, 95, 97, 114, 114, 97, 121, 95,
  112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 88, 45, 116, 105, 108, 101, 115, 32, 61, 32, 105, 110,
  116, 40, 50, 44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 89, 45, 116, 105, 108, 101, 115, 32, 61, 32, 105, 110, 116,
  40, 50, 44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 45, 111, 102, 102, 115, 101, 116, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 89, 45, 111, 102, 102, 115, 101, 116, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 77, 105, 114, 114, 111, 114, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 78, 111, 110, 101, 34, 44, 34,
  120, 45, 97, 120, 105, 115, 34, 44, 34, 121, 45, 97, 120, 105, 115, 34,
  44, 34, 120, 121, 45, 97, 120, 101, 115, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 95, 99, 104, 111,
  105, 99, 101, 40, 34, 83, 104, 114, 105, 110, 107, 34, 44, 32, 34, 69,
  120, 112, 97, 110, 100, 34, 44, 32, 34, 82, 101, 112, 101, 97, 116, 32,
  91, 77, 101, 109, 111, 114, 121, 32, 99, 111, 110, 115, 117, 109, 105, 110,
  103, 33, 93, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105,
  62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114,
  108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 97, 114, 114, 97, 121, 32, 58, 10, 45, 115, 104, 105, 102,
  116, 32, 45, 36, 51, 37, 44, 45, 36, 52, 37, 44, 48, 44, 48, 44,
  50, 10, 45, 105, 102, 32, 123, 36, 53, 38, 49, 125, 32, 45, 109, 105,
  114, 114, 111, 114, 32, 120, 32, 45, 101, 110, 100, 105, 102, 32, 45, 105,
  102, 32, 123, 36, 53, 62, 49, 125, 32, 45, 109, 105, 114, 114, 111, 114,
  32, 121, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 114, 114, 97, 121,
  32, 36, 49, 44, 36, 50, 44, 36, 54, 10, 103, 105, 109, 112, 95, 97,
  114, 114, 97, 121, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 97, 114, 114, 97, 121, 32, 36, 49, 44, 36, 50,
  44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 48, 10, 35, 64, 103, 105,
  109, 112, 32, 67, 104, 101, 115, 115, 98, 111, 97, 114, 100, 32, 58, 32,
  103, 105, 109, 112, 95, 99, 104, 101, 115, 115, 98, 111, 97, 114, 100, 44,
  32, 103, 105, 109, 112, 95, 99, 104, 101, 115, 115, 98, 111, 97, 114, 100,
  95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 70, 105, 114, 115, 116, 32, 115, 105, 122, 101, 32,
  61, 32, 105, 110, 116, 40, 54, 52, 44, 49, 44, 53, 49, 50, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 99, 111, 110, 100, 32,
  115, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 54, 52, 44, 49, 44,
  53, 49, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 105,
  114, 115, 116, 32, 111, 102, 102, 115, 101, 116, 32, 61, 32, 105, 110, 116,
  40, 48, 44, 48, 44, 53, 49, 50, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 99, 111, 110, 100, 32, 111, 102, 102, 115, 101, 116,
  32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 53, 49, 50, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 56, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 105, 114, 115, 116,
  32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 48,
  44, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 99, 111, 110, 100, 32, 99, 111, 108, 111, 114, 32,
  61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108,
  105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 99, 104,
  101, 115, 115, 98, 111, 97, 114, 100, 32, 58, 10, 45, 116, 111, 95, 114,
  103, 98, 97, 32, 45, 99, 104, 101, 115, 115, 98, 111, 97, 114, 100, 32,
  36, 123, 49, 45, 49, 52, 125, 10, 103, 105, 109, 112, 95, 99, 104, 101,
  115, 115, 98, 111, 97, 114, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 99, 104, 101,
  115, 115, 98, 111, 97, 114, 100, 32, 36, 42, 34, 44, 36, 45, 49, 10,
  35, 64, 103, 105, 109, 112, 32, 68, 105, 99, 101, 115, 32, 58, 32, 103,
  105, 109, 112, 95, 100, 105, 99, 101, 115, 44, 32, 103, 105, 109, 112, 95,
  100, 105, 99, 101, 115, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 50, 44, 49, 44, 49, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 105, 110, 116,
  40, 50, 52, 44, 56, 44, 54, 52, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 111, 108, 111, 114, 32, 109, 111, 100, 101, 108, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 66, 108, 97, 99, 107,
  32, 100, 105, 99, 101, 115, 34, 44, 34, 87, 104, 105, 116, 101, 32, 100,
  105, 99, 101, 115, 34, 44, 34, 68, 105, 99, 101, 115, 32, 119, 105, 116,
  104, 32, 99, 111, 108, 111, 114, 101, 100, 32, 110, 117, 109, 98, 101, 114,
  115, 34, 44, 34, 68, 105, 99, 101, 115, 32, 119, 105, 116, 104, 32, 99,
  111, 108, 111, 114, 101, 100, 32, 115, 105, 100, 101, 115, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65,
  117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32,
  84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59,
  60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49,
  51, 47, 48, 54, 47, 50, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 100, 105, 99, 101,
  115, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 54, 32, 123, 50,
  42, 36, 50, 125, 44, 123, 50, 42, 36, 50, 125, 32, 45, 95, 100, 105,
  99, 101, 36, 62, 32, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123,
  36, 51, 37, 50, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91,
  45, 54, 45, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 102,
  114, 97, 109, 101, 95, 114, 111, 117, 110, 100, 91, 45, 54, 45, 45, 49,
  93, 32, 49, 48, 44, 49, 48, 44, 48, 44, 48, 44, 49, 50, 56, 44,
  49, 50, 56, 44, 49, 50, 56, 44, 48, 10, 45, 114, 50, 100, 121, 91,
  45, 54, 45, 45, 49, 93, 32, 36, 50, 32, 45, 97, 91, 45, 54, 45,
  45, 49, 93, 32, 120, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64,
  35, 45, 49, 125, 32, 45, 108, 91, 36, 62, 44, 45, 49, 93, 10, 45,
  45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 48, 93, 32, 45, 114,
  118, 91, 49, 44, 50, 93, 32, 45, 114, 91, 48, 44, 49, 93, 32, 123,
  49, 48, 48, 42, 36, 49, 47, 36, 50, 125, 37, 44, 123, 49, 48, 48,
  42, 36, 49, 47, 36, 50, 125, 37, 44, 49, 44, 49, 48, 48, 37, 44,
  50, 32, 45, 113, 117, 97, 110, 116, 105, 122, 101, 91, 49, 93, 32, 54,
  44, 48, 10, 45, 42, 91, 45, 50, 93, 32, 36, 50, 32, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 45, 50, 93, 32, 48, 44, 49, 32, 45,
  114, 91, 45, 50, 93, 32, 123, 36, 50, 42, 49, 48, 48, 125, 37, 44,
  123, 36, 50, 42, 49, 48, 48, 125, 37, 10, 36, 50, 44, 36, 50, 44,
  49, 44, 50, 44, 39, 105, 102, 40, 99, 44, 121, 44, 120, 41, 39, 32,
  45, 114, 91, 45, 49, 93, 32, 91, 45, 51, 93, 44, 91, 45, 51, 93,
  44, 49, 44, 50, 44, 48, 44, 50, 32, 45, 43, 91, 45, 51, 44, 45,
  49, 93, 32, 45, 45, 119, 97, 114, 112, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 51, 93, 10, 45,
  105, 102, 32, 123, 36, 51, 60, 50, 125, 32, 45, 114, 109, 91, 48, 93,
  32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 10, 45, 101, 108, 115, 101,
  32, 45, 114, 91, 48, 93, 32, 91, 50, 93, 44, 91, 50, 93, 44, 49,
  44, 49, 48, 48, 37, 32, 45, 114, 118, 91, 48, 44, 45, 49, 93, 32,
  45, 98, 108, 101, 110, 100, 91, 48, 44, 45, 49, 93, 32, 109, 117, 108,
  116, 105, 112, 108, 121, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 95, 100, 105, 99, 101, 48, 32, 58, 32, 45, 101, 108, 108, 105, 112,
  115, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 53,
  46, 50, 37, 44, 53, 46, 50, 37, 44, 48, 44, 49, 44, 50, 53, 53,
  10, 95, 100, 105, 99, 101, 49, 32, 58, 32, 45, 101, 108, 108, 105, 112,
  115, 101, 91, 45, 49, 93, 32, 50, 53, 37, 44, 50, 53, 37, 44, 53,
  46, 50, 37, 44, 53, 46, 50, 37, 44, 48, 44, 49, 44, 50, 53, 53,
  32, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 55, 53,
  37, 44, 55, 53, 37, 44, 53, 46, 50, 37, 44, 53, 46, 50, 37, 44,
  48, 44, 49, 44, 50, 53, 53, 10, 95, 100, 105, 99, 101, 50, 32, 58,
  32, 45, 95, 100, 105, 99, 101, 49, 32, 45, 95, 100, 105, 99, 101, 48,
  10, 95, 100, 105, 99, 101, 51, 32, 58, 32, 45, 95, 100, 105, 99, 101,
  49, 32, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 50,
  53, 37, 44, 55, 53, 37, 44, 53, 46, 50, 37, 44, 53, 46, 50, 37,
  44, 48, 44, 49, 44, 50, 53, 53, 32, 45, 101, 108, 108, 105, 112, 115,
  101, 91, 45, 49, 93, 32, 55, 53, 37, 44, 50, 53, 37, 44, 53, 46,
  50, 37, 44, 53, 46, 50, 37, 44, 48, 44, 49, 44, 50, 53, 53, 10,
  95, 100, 105, 99, 101, 52, 32, 58, 32, 45, 95, 100, 105, 99, 101, 51,
  32, 45, 95, 100, 105, 99, 101, 48, 10, 95, 100, 105, 99, 101, 53, 32,
  58, 32, 45, 95, 100, 105, 99, 101, 51, 32, 45, 101, 108, 108, 105, 112,
  115, 101, 91, 45, 49, 93, 32, 50, 53, 37, 44, 53, 48, 37, 44, 53,
  46, 50, 37, 44, 53, 46, 50, 37, 44, 48, 44, 49, 44, 50, 53, 53,
  32, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 55, 53,
  37, 44, 53, 48, 37, 44, 53, 46, 50, 37, 44, 53, 46, 50, 37, 44,
  48, 44, 49, 44, 50, 53, 53, 10, 35, 64, 103, 105, 109, 112, 32, 69,
  120, 116, 114, 97, 99, 116, 32, 111, 98, 106, 101, 99, 116, 115, 32, 58,
  32, 103, 105, 109, 112, 95, 101, 120, 116, 114, 97, 99, 116, 95, 111, 98,
  106, 101, 99, 116, 115, 44, 32, 103, 105, 109, 112, 95, 101, 120, 116, 114,
  97, 99, 116, 95, 111, 98, 106, 101, 99, 116, 115, 95, 112, 114, 101, 118,
  105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  88, 45, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 89, 45, 98, 97, 99, 107, 103, 114, 111,
  117, 110, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111,
  108, 111, 114, 32, 116, 111, 108, 101, 114, 97, 110, 99, 101, 32, 61, 32,
  105, 110, 116, 40, 50, 48, 44, 48, 44, 50, 53, 54, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 105, 110, 116, 40, 53,
  48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 77, 105, 110, 105, 109, 97, 108, 32, 97, 114, 101, 97, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 51, 44, 48, 44, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 110, 101, 99, 116,
  105, 118, 105, 116, 121, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  76, 111, 119, 34, 44, 34, 72, 105, 103, 104, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 116, 121, 112,
  101, 32, 61, 32, 95, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 67,
  114, 111, 112, 34, 44, 34, 83, 101, 103, 109, 101, 110, 116, 97, 116, 105,
  111, 110, 34, 44, 34, 76, 111, 99, 97, 116, 101, 100, 32, 99, 114, 111,
  112, 34, 44, 34, 76, 111, 99, 97, 116, 101, 100, 32, 115, 101, 103, 109,
  101, 110, 116, 97, 116, 105, 111, 110, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104,
  117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 50,
  47, 49, 52, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 108, 105, 110, 107, 40, 34, 70, 105, 108, 116, 101, 114, 32,
  101, 120, 112, 108, 97, 105, 110, 101, 100, 32, 104, 101, 114, 101, 34, 44,
  34, 104, 116, 116, 112, 58, 47, 47, 103, 105, 109, 112, 99, 104, 97, 116,
  46, 99, 111, 109, 47, 118, 105, 101, 119, 116, 111, 112, 105, 99, 46, 112,
  104, 112, 63, 102, 61, 50, 56, 38, 116, 61, 55, 57, 48, 53, 34, 41,
  10, 103, 105, 109, 112, 95, 101, 120, 116, 114, 97, 99, 116, 95, 111, 98,
  106, 101, 99, 116, 115, 32, 58, 10, 45, 105, 102, 32, 36, 53, 32, 109,
  105, 110, 95, 97, 114, 101, 97, 61, 36, 53, 37, 32, 45, 101, 108, 115,
  101, 32, 109, 105, 110, 95, 97, 114, 101, 97, 61, 53, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 60, 93, 32, 45, 116, 111, 95, 114, 103, 98, 97, 10, 119,
  61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 10, 120, 61, 123, 36, 49,
  37, 42, 40, 119, 45, 49, 41, 125, 10, 121, 61, 123, 36, 50, 37, 42,
  40, 104, 45, 49, 41, 125, 10, 99, 111, 108, 111, 114, 61, 64, 123, 45,
  97, 116, 92, 32, 36, 120, 44, 36, 121, 125, 10, 45, 105, 102, 32, 123,
  36, 55, 61, 61, 48, 125, 10, 45, 45, 114, 101, 112, 108, 97, 99, 101,
  95, 99, 111, 108, 111, 114, 32, 36, 51, 44, 48, 44, 36, 99, 111, 108,
  111, 114, 44, 48, 44, 48, 44, 48, 44, 48, 32, 45, 97, 117, 116, 111,
  99, 114, 111, 112, 95, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 91,
  45, 49, 93, 32, 36, 52, 37, 44, 36, 109, 105, 110, 95, 97, 114, 101,
  97, 44, 36, 54, 44, 50, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  119, 125, 32, 45, 45, 122, 91, 48, 93, 32, 64, 123, 49, 44, 105, 40,
  36, 62, 44, 48, 41, 125, 44, 64, 123, 49, 44, 105, 40, 36, 62, 44,
  49, 41, 125, 44, 64, 123, 49, 44, 105, 40, 36, 62, 44, 51, 41, 125,
  44, 64, 123, 49, 44, 105, 40, 36, 62, 44, 52, 41, 125, 32, 45, 100,
  111, 110, 101, 32, 45, 114, 109, 91, 48, 44, 49, 93, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 55, 61, 61, 49, 125, 10, 45, 114, 101, 112, 108,
  97, 99, 101, 95, 99, 111, 108, 111, 114, 32, 36, 51, 44, 48, 44, 36,
  99, 111, 108, 111, 114, 44, 48, 44, 48, 44, 48, 44, 48, 32, 45, 97,
  117, 116, 111, 99, 114, 111, 112, 95, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 115, 32, 36, 52, 37, 44, 36, 109, 105, 110, 95, 97, 114, 101, 97,
  44, 36, 54, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 55, 61,
  61, 50, 125, 10, 45, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111,
  108, 111, 114, 32, 36, 51, 44, 48, 44, 36, 99, 111, 108, 111, 114, 44,
  48, 44, 48, 44, 48, 44, 48, 32, 45, 97, 117, 116, 111, 99, 114, 111,
  112, 95, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 91, 45, 49, 93,
  32, 36, 52, 37, 44, 36, 109, 105, 110, 95, 97, 114, 101, 97, 44, 36,
  54, 44, 50, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 119, 125, 32,
  91, 48, 93, 44, 91, 48, 93, 44, 49, 44, 52, 32, 45, 45, 122, 91,
  48, 93, 32, 64, 123, 49, 44, 105, 40, 36, 62, 44, 48, 41, 125, 44,
  64, 123, 49, 44, 105, 40, 36, 62, 44, 49, 41, 125, 44, 64, 123, 49,
  44, 105, 40, 36, 62, 44, 51, 41, 125, 44, 64, 123, 49, 44, 105, 40,
  36, 62, 44, 52, 41, 125, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 44, 64, 123, 49, 44, 105, 40, 36, 62, 44, 48, 41, 125, 44,
  64, 123, 49, 44, 105, 40, 36, 62, 44, 49, 41, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48,
  44, 49, 93, 10, 36, 119, 44, 36, 104, 44, 49, 44, 52, 32, 45, 102,
  99, 91, 45, 49, 93, 32, 36, 99, 111, 108, 111, 114, 10, 45, 101, 108,
  115, 101, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111,
  114, 32, 36, 51, 44, 48, 44, 36, 99, 111, 108, 111, 114, 44, 48, 44,
  48, 44, 48, 44, 48, 32, 45, 45, 97, 117, 116, 111, 99, 114, 111, 112,
  95, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 32, 36, 52, 37, 44,
  36, 109, 105, 110, 95, 97, 114, 101, 97, 44, 36, 54, 44, 50, 32, 45,
  97, 117, 116, 111, 99, 114, 111, 112, 95, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 115, 91, 48, 93, 32, 36, 52, 37, 44, 36, 109, 105, 110, 95,
  97, 114, 101, 97, 44, 36, 54, 44, 49, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 119, 125, 32, 120, 61, 123, 105, 40, 36, 62, 44, 48, 41,
  125, 32, 121, 61, 123, 105, 40, 36, 62, 44, 49, 41, 125, 32, 45, 108,
  91, 36, 62, 93, 32, 45, 105, 91, 48, 93, 32, 36, 119, 44, 36, 104,
  44, 49, 44, 52, 32, 45, 106, 91, 48, 93, 32, 91, 49, 93, 44, 36,
  120, 44, 36, 121, 32, 45, 114, 109, 91, 49, 93, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  36, 119, 44, 36, 104, 44, 49, 44, 52, 32, 45, 102, 99, 91, 45, 49,
  93, 32, 36, 99, 111, 108, 111, 114, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112,
  95, 101, 120, 116, 114, 97, 99, 116, 95, 111, 98, 106, 101, 99, 116, 115,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 105, 102, 32, 36,
  53, 32, 109, 105, 110, 95, 97, 114, 101, 97, 61, 36, 53, 37, 32, 45,
  101, 108, 115, 101, 32, 109, 105, 110, 95, 97, 114, 101, 97, 61, 53, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 116, 111, 95, 114, 103, 98,
  97, 10, 120, 61, 123, 36, 49, 37, 42, 40, 119, 45, 49, 41, 125, 10,
  121, 61, 123, 36, 50, 37, 42, 40, 104, 45, 49, 41, 125, 10, 99, 111,
  108, 111, 114, 61, 64, 123, 45, 97, 116, 92, 32, 36, 120, 44, 36, 121,
  125, 10, 45, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111,
  114, 32, 36, 51, 44, 48, 44, 36, 99, 111, 108, 111, 114, 44, 48, 44,
  48, 44, 48, 44, 48, 10, 45, 97, 117, 116, 111, 99, 114, 111, 112, 95,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 91, 45, 49, 93, 32, 36,
  52, 37, 44, 36, 109, 105, 110, 95, 97, 114, 101, 97, 44, 36, 54, 44,
  50, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 119, 125, 10, 120, 121,
  99, 111, 111, 114, 100, 115, 61, 64, 123, 49, 44, 105, 40, 36, 62, 44,
  48, 41, 125, 44, 64, 123, 49, 44, 105, 40, 36, 62, 44, 49, 41, 125,
  44, 64, 123, 49, 44, 105, 40, 36, 62, 44, 51, 41, 125, 44, 64, 123,
  49, 44, 105, 40, 36, 62, 44, 52, 41, 125, 10, 45, 114, 101, 99, 116,
  97, 110, 103, 108, 101, 91, 48, 93, 32, 36, 120, 121, 99, 111, 111, 114,
  100, 115, 44, 48, 46, 51, 44, 48, 44, 48, 44, 50, 53, 53, 44, 50,
  53, 53, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 48, 93,
  32, 36, 120, 121, 99, 111, 111, 114, 100, 115, 44, 49, 44, 48, 120, 70,
  70, 70, 70, 70, 70, 70, 70, 44, 48, 44, 48, 44, 48, 44, 50, 53,
  53, 10, 45, 100, 111, 110, 101, 10, 45, 100, 114, 103, 98, 97, 91, 48,
  93, 10, 45, 116, 101, 120, 116, 95, 111, 117, 116, 108, 105, 110, 101, 91,
  48, 93, 32, 123, 119, 125, 34, 32, 111, 98, 106, 101, 99, 116, 115, 34,
  44, 50, 44, 50, 44, 49, 51, 44, 50, 44, 48, 46, 51, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 107,
  91, 48, 93, 10, 45, 99, 105, 114, 99, 108, 101, 32, 36, 120, 44, 36,
  121, 44, 51, 44, 49, 44, 48, 44, 50, 53, 53, 44, 48, 10, 45, 99,
  105, 114, 99, 108, 101, 32, 36, 120, 44, 36, 121, 44, 51, 44, 49, 44,
  48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32,
  71, 114, 105, 100, 32, 58, 32, 103, 105, 109, 112, 95, 105, 109, 97, 103,
  101, 103, 114, 105, 100, 44, 32, 103, 105, 109, 112, 95, 105, 109, 97, 103,
  101, 103, 114, 105, 100, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 45, 115, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 49,
  48, 44, 50, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 89, 45, 115, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 49,
  48, 44, 50, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109,
  112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50,
  57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 103, 114, 105, 100, 32,
  58, 10, 45, 105, 109, 97, 103, 101, 103, 114, 105, 100, 32, 36, 49, 44,
  36, 50, 10, 35, 64, 103, 105, 109, 112, 32, 80, 117, 122, 122, 108, 101,
  32, 58, 32, 103, 105, 109, 112, 95, 112, 117, 122, 122, 108, 101, 44, 32,
  103, 105, 109, 112, 95, 112, 117, 122, 122, 108, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 60, 98, 62, 80, 97, 116, 116, 101, 114, 110, 32, 112,
  97, 114, 97, 109, 101, 116, 101, 114, 115, 58, 60, 47, 98, 62, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 45, 116, 105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40,
  53, 44, 50, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 89, 45, 116, 105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 53,
  44, 50, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 117, 114, 118, 97, 116, 117, 114, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 53, 44, 48, 44, 49, 46, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 110, 110, 101, 99, 116, 111, 114, 115,
  32, 99, 101, 110, 116, 101, 114, 105, 110, 103, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 111, 110, 110, 101, 99, 116, 111, 114, 115, 32, 118, 97,
  114, 105, 97, 98, 105, 108, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 60, 98, 62, 66, 108, 101, 110, 100, 105, 110, 103, 32, 112, 97, 114,
  97, 109, 101, 116, 101, 114, 115, 58, 60, 47, 98, 62, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  82, 101, 108, 105, 101, 102, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 51, 44, 48, 44,
  51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 108, 105,
  101, 102, 32, 99, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 48, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 108, 105, 110, 101, 32,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 50, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 79, 117, 116, 108, 105, 110, 101, 32, 99, 111, 110,
  116, 114, 97, 115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 53,
  53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 60, 98, 62, 82, 101, 99, 111, 109, 112, 111, 115, 105, 116, 105, 111,
  110, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 58, 60, 47, 98,
  62, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 48, 48, 44, 48, 44, 49, 53, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 65, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 45, 49, 56, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 118, 97, 114, 105, 97,
  116, 105, 111, 110, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 104, 117, 102, 102, 108, 101, 32, 112, 105, 101, 99, 101, 115, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 65, 100, 100, 105, 116, 105, 111, 110, 97, 108, 32, 111, 117, 116,
  108, 105, 110, 101, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 101,
  97, 99, 104, 32, 112, 105, 101, 99, 101, 32, 111, 110, 32, 97, 32, 100,
  105, 102, 102, 101, 114, 101, 110, 116, 32, 108, 97, 121, 101, 114, 32, 61,
  32, 95, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47,
  48, 54, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 112, 117, 122, 122, 108, 101, 32, 58, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 60,
  93, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 32, 45, 116,
  111, 95, 114, 103, 98, 10, 45, 112, 117, 122, 122, 108, 101, 32, 36, 119,
  44, 36, 104, 44, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44,
  36, 53, 10, 45, 45, 98, 91, 45, 49, 93, 32, 36, 54, 37, 44, 48,
  32, 45, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32, 120,
  121, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 110, 91, 45,
  49, 93, 32, 45, 36, 55, 44, 36, 55, 32, 45, 43, 91, 48, 44, 45,
  49, 93, 10, 45, 45, 98, 91, 45, 49, 93, 32, 36, 56, 37, 44, 48,
  32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 42, 91, 45,
  49, 93, 32, 45, 49, 32, 45, 43, 91, 45, 49, 93, 32, 49, 32, 45,
  110, 91, 45, 49, 93, 32, 123, 40, 50, 53, 53, 45, 36, 57, 41, 47,
  50, 53, 53, 125, 44, 49, 32, 45, 42, 91, 48, 44, 45, 49, 93, 32,
  45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36, 49,
  48, 33, 61, 49, 48, 48, 124, 124, 36, 49, 49, 124, 124, 36, 49, 50,
  124, 124, 36, 49, 51, 124, 124, 36, 49, 52, 124, 124, 36, 49, 53, 124,
  124, 36, 49, 54, 125, 10, 45, 45, 45, 91, 45, 49, 93, 32, 49, 32,
  45, 108, 97, 98, 101, 108, 95, 102, 103, 91, 45, 49, 93, 32, 48, 10,
  45, 45, 97, 114, 101, 97, 95, 102, 103, 91, 45, 49, 93, 32, 48, 44,
  48, 32, 45, 108, 116, 91, 45, 49, 93, 32, 53, 48, 37, 32, 45, 111,
  114, 91, 45, 51, 93, 32, 91, 45, 49, 93, 32, 45, 101, 113, 91, 45,
  49, 93, 32, 48, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 10, 45,
  100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 50, 93, 32, 48, 32, 45,
  42, 91, 45, 50, 93, 32, 45, 49, 32, 45, 119, 97, 116, 101, 114, 115,
  104, 101, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 114, 109,
  91, 45, 50, 93, 32, 45, 108, 97, 98, 101, 108, 91, 45, 49, 93, 32,
  48, 44, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 77, 43,
  49, 125, 10, 45, 45, 61, 61, 91, 49, 93, 32, 36, 62, 10, 99, 111,
  111, 114, 100, 115, 61, 64, 123, 45, 97, 117, 116, 111, 99, 114, 111, 112,
  95, 99, 111, 111, 114, 100, 115, 91, 45, 49, 93, 92, 32, 48, 125, 10,
  45, 45, 122, 91, 48, 93, 32, 36, 99, 111, 111, 114, 100, 115, 32, 45,
  122, 91, 45, 50, 93, 32, 36, 99, 111, 111, 114, 100, 115, 32, 45, 114,
  118, 91, 45, 50, 44, 45, 49, 93, 32, 45, 42, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 32,
  45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 120, 36, 62, 61,
  123, 97, 114, 103, 40, 49, 44, 36, 99, 111, 111, 114, 100, 115, 41, 43,
  114, 111, 117, 110, 100, 40, 119, 47, 50, 41, 125, 32, 121, 36, 62, 61,
  123, 97, 114, 103, 40, 50, 44, 36, 99, 111, 111, 114, 100, 115, 41, 43,
  114, 111, 117, 110, 100, 40, 104, 47, 50, 41, 125, 10, 45, 100, 111, 110,
  101, 10, 45, 114, 109, 91, 48, 44, 49, 93, 10, 45, 105, 102, 32, 36,
  49, 52, 32, 45, 115, 111, 114, 116, 95, 108, 105, 115, 116, 32, 43, 44,
  63, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 49, 54,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  60, 93, 10, 45, 114, 50, 100, 121, 32, 123, 109, 97, 120, 40, 48, 46,
  49, 44, 36, 49, 48, 43, 36, 49, 49, 42, 63, 40, 45, 49, 44, 49,
  41, 41, 125, 37, 32, 45, 114, 111, 116, 97, 116, 101, 32, 123, 36, 49,
  50, 43, 36, 49, 51, 42, 63, 40, 45, 49, 44, 49, 41, 125, 10, 45,
  105, 102, 32, 36, 49, 53, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120,
  121, 32, 49, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 99, 120, 61,
  123, 114, 111, 117, 110, 100, 40, 119, 47, 50, 41, 125, 32, 99, 121, 61,
  123, 114, 111, 117, 110, 100, 40, 104, 47, 50, 41, 125, 10, 45, 115, 104,
  32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 105, 102, 32, 36,
  49, 53, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 91, 48, 93, 32, 36, 119,
  44, 36, 104, 44, 49, 44, 52, 10, 45, 106, 91, 48, 93, 32, 91, 45,
  50, 93, 44, 123, 36, 123, 120, 36, 60, 125, 45, 36, 99, 120, 125, 44,
  123, 36, 123, 121, 36, 60, 125, 45, 36, 99, 121, 125, 44, 48, 44, 48,
  44, 49, 44, 91, 45, 49, 93, 44, 50, 53, 53, 32, 45, 114, 109, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 45, 101, 108, 115, 101, 10, 45, 105, 91, 48, 93, 32, 36,
  119, 44, 36, 104, 44, 49, 44, 123, 115, 125, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 64, 35, 45, 49, 125, 10, 45, 114, 50, 100, 121, 91,
  45, 49, 93, 32, 123, 109, 97, 120, 40, 48, 46, 49, 44, 36, 49, 48,
  43, 36, 49, 49, 42, 63, 40, 45, 49, 44, 49, 41, 41, 125, 37, 32,
  45, 114, 111, 116, 97, 116, 101, 91, 45, 49, 93, 32, 123, 36, 49, 50,
  43, 36, 49, 51, 42, 63, 40, 45, 49, 44, 49, 41, 125, 10, 45, 105,
  102, 32, 36, 49, 53, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121,
  91, 45, 49, 93, 32, 49, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10,
  99, 120, 61, 123, 114, 111, 117, 110, 100, 40, 119, 47, 50, 41, 125, 32,
  99, 121, 61, 123, 114, 111, 117, 110, 100, 40, 104, 47, 50, 41, 125, 10,
  45, 115, 104, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 32, 45, 105, 102, 32, 36, 49, 53, 32, 45, 100, 105, 108, 97, 116,
  101, 91, 45, 49, 93, 32, 51, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  106, 91, 48, 93, 32, 91, 45, 50, 93, 44, 123, 36, 123, 120, 36, 60,
  125, 45, 36, 99, 120, 125, 44, 123, 36, 123, 121, 36, 60, 125, 45, 36,
  99, 121, 125, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 44, 50,
  53, 53, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 100,
  111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112,
  95, 112, 117, 122, 122, 108, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 112, 117, 122, 122, 108, 101, 32, 36,
  123, 49, 45, 49, 53, 125, 44, 48, 10, 35, 64, 103, 105, 109, 112, 32,
  84, 97, 113, 117, 105, 110, 32, 58, 32, 103, 105, 109, 112, 95, 116, 97,
  113, 117, 105, 110, 44, 32, 103, 105, 109, 112, 95, 116, 97, 113, 117, 105,
  110, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45,
  116, 105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 55, 44, 49, 44,
  50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 116,
  105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 55, 44, 49, 44, 50,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 109, 111,
  118, 101, 32, 116, 105, 108, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 78, 111, 110, 101, 34, 44, 34, 70, 105, 114, 115, 116, 34, 44,
  34, 76, 97, 115, 116, 34, 44, 34, 82, 97, 110, 100, 111, 109, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 82, 101, 108, 105, 101, 102, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 53, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 66, 111, 114, 100, 101, 114, 32, 116, 104,
  105, 99, 107, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  53, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 66, 111, 114, 100, 101, 114, 32, 111, 117, 116, 108, 105, 110, 101,
  32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 49, 54, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 108, 105, 110, 101, 32, 99,
  111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 48, 44, 48,
  44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32,
  60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112,
  101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 49, 51,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  103, 105, 109, 112, 95, 116, 97, 113, 117, 105, 110, 32, 58, 10, 45, 116,
  111, 95, 97, 32, 45, 116, 97, 113, 117, 105, 110, 32, 36, 49, 44, 36,
  50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 37, 44, 36, 54, 44, 36,
  123, 55, 45, 49, 48, 125, 10, 35, 64, 103, 105, 109, 112, 32, 84, 105,
  108, 101, 97, 98, 108, 101, 32, 114, 111, 116, 97, 116, 105, 111, 110, 32,
  58, 32, 103, 105, 109, 112, 95, 114, 111, 116, 97, 116, 101, 95, 116, 105,
  108, 101, 97, 98, 108, 101, 44, 32, 103, 105, 109, 112, 95, 114, 111, 116,
  97, 116, 101, 95, 116, 105, 108, 101, 97, 98, 108, 101, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 52, 53, 44, 48, 44, 51, 54, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 97, 120, 105, 109, 117,
  109, 32, 115, 105, 122, 101, 32, 102, 97, 99, 116, 111, 114, 32, 61, 32,
  105, 110, 116, 40, 56, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 114, 114, 97, 121, 32, 109, 111, 100, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 78, 111, 110, 101,
  34, 44, 34, 120, 45, 97, 120, 105, 115, 34, 44, 34, 121, 45, 97, 120,
  105, 115, 34, 44, 34, 120, 121, 45, 97, 120, 101, 115, 34, 44, 34, 50,
  120, 121, 45, 97, 120, 101, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 98, 62, 78, 111, 116, 101, 58, 60, 47, 98, 62, 32,
  84, 104, 105, 115, 32, 102, 105, 108, 116, 101, 114, 32, 105, 109, 112, 108,
  101, 109, 101, 110, 116, 115, 32, 116, 104, 101, 32, 116, 105, 108, 101, 97,
  98, 108, 101, 32, 114, 111, 116, 97, 116, 105, 111, 110, 32, 116, 101, 99,
  104, 110, 105, 113, 117, 101, 32, 100, 101, 115, 99, 114, 105, 98, 101, 100,
  32, 98, 121, 32, 60, 98, 62, 80, 101, 116, 101, 114, 32, 89, 117, 60,
  47, 98, 62, 44, 32, 97, 116, 58, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 76, 32, 61, 32, 108, 105, 110, 107, 40, 34, 91, 80,
  101, 116, 101, 114, 32, 89, 117, 93, 32, 67, 114, 101, 97, 116, 101, 32,
  114, 111, 116, 97, 116, 101, 100, 32, 116, 105, 108, 101, 97, 98, 108, 101,
  32, 112, 97, 116, 116, 101, 114, 110, 115, 34, 44, 34, 104, 116, 116, 112,
  58, 47, 47, 119, 119, 119, 46, 112, 101, 116, 101, 114, 121, 117, 46, 99,
  97, 47, 116, 117, 116, 111, 114, 105, 97, 108, 115, 47, 103, 105, 109, 112,
  47, 114, 111, 116, 97, 116, 101, 95, 116, 105, 108, 101, 97, 98, 108, 101,
  95, 112, 97, 116, 116, 101, 114, 110, 115, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48,
  53, 47, 50, 54, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 114, 111, 116, 97, 116, 101, 95,
  116, 105, 108, 101, 97, 98, 108, 101, 32, 58, 10, 45, 105, 102, 32, 36,
  51, 32, 45, 97, 114, 114, 97, 121, 95, 109, 105, 114, 114, 111, 114, 32,
  49, 44, 123, 36, 51, 45, 49, 125, 44, 49, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 114, 111, 116, 97, 116, 101, 95, 116, 105, 108, 101, 97, 98,
  108, 101, 32, 36, 49, 44, 123, 105, 102, 40, 36, 51, 61, 61, 48, 44,
  36, 50, 44, 36, 50, 47, 50, 41, 125, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 10, 45, 105, 102, 32, 123, 64, 123, 36, 62, 44, 119,
  125, 61, 61, 49, 34, 32, 38, 38, 32, 34, 64, 123, 36, 62, 44, 104,
  125, 61, 61, 49, 125, 32, 45, 114, 109, 32, 45, 95, 103, 105, 109, 112,
  95, 110, 111, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 32, 32, 73,
  110, 118, 97, 108, 105, 100, 92, 110, 105, 109, 97, 103, 101, 32, 115, 105,
  122, 101, 34, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32,
  84, 105, 108, 101, 100, 32, 105, 115, 111, 108, 97, 116, 105, 111, 110, 32,
  58, 32, 103, 105, 109, 112, 95, 105, 115, 111, 108, 97, 116, 101, 95, 116,
  105, 108, 101, 115, 44, 32, 103, 105, 109, 112, 95, 105, 115, 111, 108, 97,
  116, 101, 95, 116, 105, 108, 101, 115, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 88, 45, 115, 105, 122, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 89, 45, 115, 105, 122, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 98, 111, 114, 100, 101,
  114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 98, 111,
  114, 100, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 75,
  101, 101, 112, 32, 116, 105, 108, 101, 115, 32, 115, 113, 117, 97, 114, 101,
  32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 75, 101, 101, 112, 32, 98, 111, 114, 100, 101, 114, 115,
  32, 115, 113, 117, 97, 114, 101, 32, 61, 32, 98, 111, 111, 108, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118,
  105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50,
  51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62,
  50, 48, 49, 49, 47, 48, 52, 47, 49, 51, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 105,
  115, 111, 108, 97, 116, 101, 95, 116, 105, 108, 101, 115, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 45, 116, 111, 95, 114, 103, 98, 97, 10, 45, 105, 102, 32, 36, 53,
  32, 115, 120, 61, 123, 114, 111, 117, 110, 100, 40, 109, 105, 110, 40, 119,
  44, 104, 41, 42, 109, 97, 120, 40, 36, 49, 44, 36, 50, 41, 47, 49,
  48, 48, 41, 125, 32, 115, 121, 61, 36, 115, 120, 32, 45, 101, 108, 115,
  101, 32, 115, 120, 61, 123, 114, 111, 117, 110, 100, 40, 119, 42, 36, 49,
  47, 49, 48, 48, 41, 125, 32, 115, 121, 61, 123, 114, 111, 117, 110, 100,
  40, 104, 42, 36, 50, 47, 49, 48, 48, 41, 125, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 36, 54, 32, 98, 120, 61, 123, 109, 97,
  120, 40, 36, 51, 44, 36, 52, 41, 125, 32, 98, 121, 61, 36, 98, 120,
  32, 45, 101, 108, 115, 101, 32, 98, 120, 61, 36, 51, 32, 98, 121, 61,
  36, 52, 32, 45, 101, 110, 100, 105, 102, 10, 45, 115, 32, 120, 44, 45,
  36, 115, 120, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 32, 45, 115, 32, 121, 44, 45, 36, 115, 121, 32,
  45, 114, 32, 49, 48, 48, 37, 44, 123, 49, 48, 48, 43, 36, 98, 121,
  125, 37, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 32, 45, 97, 32, 121, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 45, 114, 32, 123, 49, 48, 48, 43, 36,
  98, 120, 125, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 48, 48, 37,
  44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 97, 32,
  120, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64,
  103, 105, 109, 112, 32, 84, 105, 108, 101, 100, 32, 110, 111, 114, 109, 97,
  108, 105, 122, 97, 116, 105, 111, 110, 32, 58, 32, 103, 105, 109, 112, 95,
  110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 116, 105, 108, 101, 115, 44,
  32, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95,
  116, 105, 108, 101, 115, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 45, 116, 105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40,
  50, 53, 44, 49, 44, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 89, 45, 116, 105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40,
  50, 53, 44, 49, 44, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 77, 105, 110, 105, 109, 97, 108, 32, 118, 97, 108, 117, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 97, 120, 105, 109, 97,
  108, 32, 118, 97, 108, 117, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 51, 44, 34, 65, 108, 108, 34, 44,
  34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114,
  101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34,
  44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115,
  34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115,
  34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72,
  117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34,
  44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34,
  71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34,
  82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108,
  117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115,
  99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47,
  49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 95, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97,
  108, 105, 122, 101, 95, 116, 105, 108, 101, 115, 32, 58, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 45, 49, 93, 32, 45,
  115, 112, 108, 105, 116, 95, 116, 105, 108, 101, 115, 32, 36, 49, 44, 36,
  50, 32, 45, 110, 32, 36, 51, 44, 36, 52, 32, 45, 97, 112, 112, 101,
  110, 100, 95, 116, 105, 108, 101, 115, 32, 36, 49, 44, 36, 50, 32, 45,
  101, 110, 100, 108, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45,
  100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97, 108,
  105, 122, 101, 95, 116, 105, 108, 101, 115, 32, 58, 10, 45, 97, 112, 112,
  108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 95, 103,
  105, 109, 112, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 116, 105,
  108, 101, 115, 32, 36, 123, 49, 45, 52, 125, 34, 44, 36, 45, 49, 10,
  35, 64, 103, 105, 109, 112, 32, 84, 105, 108, 101, 100, 32, 112, 97, 114,
  97, 109, 101, 116, 101, 114, 105, 122, 97, 116, 105, 111, 110, 32, 58, 32,
  103, 105, 109, 112, 95, 112, 97, 114, 97, 109, 101, 116, 101, 114, 105, 122,
  101, 95, 116, 105, 108, 101, 115, 44, 32, 103, 105, 109, 112, 95, 112, 97,
  114, 97, 109, 101, 116, 101, 114, 105, 122, 101, 95, 116, 105, 108, 101, 115,
  40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 116,
  105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 49, 48, 44, 49, 44,
  51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 116,
  105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 49, 48, 44, 49, 44,
  51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 105, 116,
  116, 105, 110, 103, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 76, 105, 110, 101, 97, 114, 34, 44,
  34, 81, 117, 97, 100, 114, 97, 116, 105, 99, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115,
  99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47,
  49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 112, 97, 114, 97, 109, 101,
  116, 101, 114, 105, 122, 101, 95, 116, 105, 108, 101, 115, 32, 58, 10, 45,
  105, 102, 32, 36, 51, 10, 45, 113, 117, 97, 100, 114, 97, 116, 105, 122,
  101, 95, 116, 105, 108, 101, 115, 32, 36, 49, 44, 36, 50, 10, 45, 101,
  108, 115, 101, 10, 45, 108, 105, 110, 101, 97, 114, 105, 122, 101, 95, 116,
  105, 108, 101, 115, 32, 36, 49, 44, 36, 50, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10, 35, 64, 103, 105, 109,
  112, 32, 84, 105, 108, 101, 100, 32, 114, 97, 110, 100, 111, 109, 32, 115,
  104, 105, 102, 116, 115, 32, 58, 32, 103, 105, 109, 112, 95, 115, 104, 105,
  102, 116, 95, 116, 105, 108, 101, 115, 44, 32, 103, 105, 109, 112, 95, 115,
  104, 105, 102, 116, 95, 116, 105, 108, 101, 115, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 88, 45, 116, 105, 108, 101, 115, 32, 61,
  32, 105, 110, 116, 40, 49, 48, 44, 49, 44, 51, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 89, 45, 116, 105, 108, 101, 115, 32, 61,
  32, 105, 110, 116, 40, 49, 48, 44, 49, 44, 51, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99,
  105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  115, 104, 105, 102, 116, 95, 116, 105, 108, 101, 115, 32, 58, 10, 45, 116,
  111, 95, 114, 103, 98, 97, 32, 45, 115, 104, 105, 102, 116, 95, 116, 105,
  108, 101, 115, 32, 36, 49, 44, 36, 50, 44, 36, 51, 10, 45, 105, 102,
  32, 123, 36, 52, 60, 49, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 115, 91, 45, 49, 93, 32, 99, 32, 45, 42, 91, 45,
  49, 93, 32, 36, 52, 32, 45, 97, 91, 45, 52, 45, 45, 49, 93, 32,
  99, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110,
  101, 32, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103, 105, 109, 112, 32,
  84, 105, 108, 101, 100, 32, 114, 111, 116, 97, 116, 105, 111, 110, 32, 58,
  32, 103, 105, 109, 112, 95, 114, 111, 116, 97, 116, 101, 95, 116, 105, 108,
  101, 115, 44, 32, 103, 105, 109, 112, 95, 114, 111, 116, 97, 116, 101, 95,
  116, 105, 108, 101, 115, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 45, 116, 105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40,
  53, 44, 49, 44, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 89, 45, 116, 105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 53,
  44, 49, 44, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  65, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 53,
  44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 88, 45, 115, 104, 97, 100, 111, 119, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 51, 44, 45, 50, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 89, 45, 115, 104, 97, 100, 111, 119, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 51, 44, 45, 50, 48, 44, 50, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 56, 44,
  48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 114, 111, 116, 97, 116, 101, 95, 116, 105, 108, 101, 115, 32, 58,
  10, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 114, 111, 116, 97, 116,
  101, 95, 116, 105, 108, 101, 115, 32, 36, 51, 44, 36, 49, 44, 36, 50,
  32, 45, 100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119, 32, 36, 52,
  37, 44, 36, 53, 37, 44, 36, 54, 37, 10, 35, 64, 103, 105, 109, 112,
  32, 95, 10, 35, 64, 103, 105, 109, 112, 32, 60, 98, 62, 65, 114, 116,
  105, 115, 116, 105, 99, 60, 47, 98, 62, 10, 35, 64, 103, 105, 109, 112,
  32, 65, 117, 114, 111, 114, 97, 32, 58, 32, 103, 99, 100, 95, 97, 117,
  114, 111, 114, 97, 44, 32, 103, 99, 100, 95, 97, 117, 114, 111, 114, 97,
  40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 105, 62, 83, 105, 109,
  112, 108, 101, 32, 97, 117, 114, 111, 114, 97, 32, 101, 102, 102, 101, 99,
  116, 32, 102, 105, 108, 116, 101, 114, 60, 47, 105, 62, 34, 41, 44, 32,
  115, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 101, 114, 116, 105,
  99, 97, 108, 32, 97, 109, 111, 117, 110, 116, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 54, 44, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 72, 111, 114, 105, 122, 111, 110, 116, 97, 108, 32, 97,
  109, 111, 117, 110, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44,
  48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66,
  108, 101, 110, 100, 32, 109, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 48, 44, 34, 78, 111, 110, 101, 34, 44, 34, 65, 118, 101,
  114, 97, 103, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32,
  60, 105, 62, 71, 97, 114, 97, 103, 101, 99, 111, 100, 101, 114, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51,
  47, 48, 50, 47, 48, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 103, 99, 100, 95, 97, 117, 114, 111, 114, 97,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 54, 125, 44,
  36, 123, 50, 61, 49, 125, 44, 36, 123, 51, 61, 48, 125, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 10, 45, 45, 100, 101, 114,
  105, 99, 104, 101, 91, 48, 93, 32, 36, 49, 37, 44, 50, 44, 121, 32,
  45, 100, 101, 114, 105, 99, 104, 101, 91, 45, 49, 93, 32, 36, 50, 37,
  44, 48, 44, 120, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45,
  105, 102, 32, 36, 51, 32, 45, 98, 108, 101, 110, 100, 91, 48, 44, 49,
  93, 32, 97, 118, 101, 114, 97, 103, 101, 32, 45, 101, 108, 115, 101, 32,
  45, 107, 101, 101, 112, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103,
  105, 109, 112, 32, 66, 108, 97, 99, 107, 32, 99, 114, 97, 121, 111, 110,
  32, 103, 114, 97, 102, 102, 105, 116, 105, 32, 58, 32, 103, 105, 109, 112,
  95, 99, 114, 97, 121, 111, 110, 103, 114, 97, 102, 102, 105, 116, 105, 50,
  44, 32, 103, 105, 109, 112, 95, 99, 114, 97, 121, 111, 110, 103, 114, 97,
  102, 102, 105, 116, 105, 50, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105,
  116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 48, 48,
  44, 48, 44, 52, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 68, 101, 110, 115, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 52, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 50, 44, 48, 44, 53, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 97, 115, 116, 32, 97,
  112, 112, 114, 111, 120, 105, 109, 97, 116, 105, 111, 110, 32, 61, 32, 98,
  111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 108, 111, 114, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  32, 61, 102, 108, 111, 97, 116, 40, 50, 44, 49, 44, 51, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 105, 120, 101, 114, 32, 115,
  116, 121, 108, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 50, 44,
  34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 86, 97, 108,
  117, 101, 34, 44, 34, 67, 111, 108, 111, 114, 32, 68, 111, 112, 105, 110,
  103, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 80, 104, 111, 116, 111,
  67, 111, 109, 105, 88, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32,
  60, 105, 62, 50, 48, 49, 49, 47, 49, 50, 47, 55, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112,
  95, 99, 114, 97, 121, 111, 110, 103, 114, 97, 102, 102, 105, 116, 105, 50,
  32, 58, 10, 45, 45, 98, 108, 117, 114, 32, 36, 51, 32, 45, 104, 97,
  114, 100, 115, 107, 101, 116, 99, 104, 98, 119, 91, 45, 49, 93, 32, 36,
  49, 44, 36, 50, 44, 36, 52, 44, 36, 53, 44, 36, 54, 32, 45, 116,
  111, 95, 114, 103, 98, 10, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91,
  45, 49, 93, 32, 45, 98, 108, 117, 114, 95, 120, 121, 91, 45, 50, 93,
  32, 36, 55, 44, 36, 55, 32, 45, 114, 101, 118, 101, 114, 115, 101, 10,
  45, 105, 102, 32, 123, 36, 56, 61, 61, 48, 125, 32, 45, 99, 111, 109,
  112, 111, 115, 101, 95, 108, 105, 103, 104, 116, 110, 101, 115, 115, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 56, 61, 61, 49, 125, 32, 45, 99, 111,
  109, 112, 111, 115, 101, 95, 118, 97, 108, 117, 101, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 56, 61, 61, 50, 125, 32, 45, 103, 105, 109, 112, 95,
  99, 111, 109, 112, 111, 115, 101, 95, 99, 111, 108, 111, 114, 100, 111, 112,
  105, 110, 103, 32, 49, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 103,
  105, 109, 112, 95, 99, 114, 97, 121, 111, 110, 103, 114, 97, 102, 102, 105,
  116, 105, 50, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 103, 105, 109, 112, 95, 99, 114, 97, 121, 111, 110, 103,
  114, 97, 102, 102, 105, 116, 105, 50, 32, 36, 123, 49, 45, 45, 50, 125,
  34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 66, 108, 111,
  99, 107, 105, 115, 109, 32, 58, 32, 103, 105, 109, 112, 95, 98, 108, 111,
  99, 107, 105, 115, 109, 44, 32, 103, 105, 109, 112, 95, 98, 108, 111, 99,
  107, 105, 115, 109, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 110,
  111, 116, 101, 40, 34, 82, 101, 110, 100, 101, 114, 115, 32, 114, 101, 99,
  116, 97, 110, 103, 108, 101, 115, 32, 111, 110, 32, 116, 111, 32, 116, 104,
  101, 32, 105, 109, 97, 103, 101, 46, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 110, 111, 116, 101, 40, 34,
  80, 97, 114, 97, 109, 101, 116, 101, 114, 115, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 82, 101, 108, 97, 116, 105, 118, 101, 32, 115,
  105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44, 48, 44,
  50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 116,
  105, 111, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 54, 44, 49,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 105,
  122, 101, 32, 118, 97, 114, 105, 97, 110, 99, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 101, 108, 97, 116, 105, 118, 101, 32,
  98, 108, 111, 99, 107, 32, 99, 111, 117, 110, 116, 32, 61, 32, 105, 110,
  116, 40, 53, 48, 44, 48, 44, 53, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 70, 108, 105, 112, 32, 116, 111, 108, 101,
  114, 97, 110, 99, 101, 32, 61, 32, 105, 110, 116, 40, 54, 52, 44, 48,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  101, 118, 101, 114, 115, 101, 32, 102, 108, 105, 112, 32, 61, 32, 98, 111,
  111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 81,
  117, 105, 99, 107, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40,
  34, 70, 105, 108, 116, 101, 114, 32, 69, 120, 112, 108, 97, 105, 110, 101,
  100, 32, 104, 101, 114, 101, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47,
  119, 119, 119, 46, 102, 108, 105, 99, 107, 114, 46, 99, 111, 109, 47, 112,
  104, 111, 116, 111, 115, 47, 110, 97, 103, 103, 111, 98, 111, 116, 47, 56,
  48, 54, 51, 48, 53, 56, 55, 48, 53, 47, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 32, 65, 117,
  116, 104, 111, 114, 58, 32, 65, 114, 116, 111, 32, 72, 117, 111, 116, 97,
  114, 105, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  32, 58, 32, 60, 105, 62, 50, 48, 49, 50, 47, 49, 48, 47, 48, 55,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  103, 105, 109, 112, 95, 98, 108, 111, 99, 107, 105, 115, 109, 58, 10, 88,
  83, 105, 122, 101, 61, 123, 105, 110, 116, 40, 36, 49, 47, 49, 48, 48,
  42, 64, 123, 45, 49, 44, 119, 125, 41, 125, 10, 45, 105, 102, 32, 123,
  36, 88, 83, 105, 122, 101, 61, 61, 48, 125, 32, 88, 83, 105, 122, 101,
  61, 49, 32, 45, 101, 110, 100, 105, 102, 10, 82, 97, 116, 105, 111, 61,
  36, 50, 10, 86, 97, 114, 105, 97, 110, 99, 101, 61, 123, 105, 110, 116,
  40, 36, 51, 42, 36, 88, 83, 105, 122, 101, 41, 125, 10, 82, 97, 110,
  100, 111, 109, 110, 101, 115, 115, 61, 45, 49, 44, 49, 10, 82, 101, 112,
  101, 97, 116, 115, 61, 123, 105, 110, 116, 40, 36, 52, 47, 49, 48, 48,
  42, 109, 97, 120, 40, 64, 123, 45, 49, 44, 119, 125, 44, 64, 123, 45,
  49, 44, 104, 125, 41, 41, 125, 10, 79, 112, 97, 99, 105, 116, 121, 61,
  36, 53, 10, 70, 108, 105, 112, 84, 111, 108, 61, 36, 54, 10, 82, 101,
  118, 101, 114, 115, 101, 70, 108, 105, 112, 61, 36, 55, 10, 76, 65, 66,
  61, 49, 45, 36, 56, 10, 89, 83, 105, 122, 101, 61, 123, 105, 110, 116,
  40, 36, 82, 97, 116, 105, 111, 42, 36, 88, 83, 105, 122, 101, 41, 125,
  10, 77, 97, 120, 88, 83, 105, 122, 101, 61, 123, 105, 110, 116, 40, 36,
  88, 83, 105, 122, 101, 43, 36, 86, 97, 114, 105, 97, 110, 99, 101, 41,
  125, 10, 77, 97, 120, 89, 83, 105, 122, 101, 61, 123, 105, 110, 116, 40,
  36, 77, 97, 120, 88, 83, 105, 122, 101, 42, 36, 82, 97, 116, 105, 111,
  41, 125, 10, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 10, 45, 105,
  102, 32, 123, 36, 76, 65, 66, 125, 10, 45, 114, 103, 98, 50, 108, 97,
  98, 91, 48, 93, 10, 45, 115, 112, 108, 105, 116, 91, 48, 93, 32, 99,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 10, 35, 84, 97, 107, 101, 32, 99, 111, 112, 121, 32, 111, 102,
  32, 116, 104, 101, 32, 108, 97, 115, 116, 32, 105, 109, 97, 103, 101, 32,
  105, 110, 32, 116, 104, 101, 32, 115, 116, 97, 99, 107, 32, 102, 111, 114,
  32, 103, 114, 101, 121, 32, 118, 97, 108, 117, 101, 32, 99, 104, 101, 99,
  107, 105, 110, 103, 10, 91, 45, 49, 93, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 36, 82, 101, 112, 101, 97, 116, 115, 10, 88, 61, 123, 105, 110,
  116, 40, 63, 40, 45, 49, 44, 119, 41, 41, 125, 10, 89, 61, 123, 105,
  110, 116, 40, 63, 40, 45, 49, 44, 104, 41, 41, 125, 10, 45, 105, 102,
  32, 123, 36, 82, 101, 118, 101, 114, 115, 101, 70, 108, 105, 112, 61, 61,
  48, 125, 10, 45, 105, 102, 32, 123, 64, 123, 45, 49, 44, 40, 36, 88,
  44, 36, 89, 44, 48, 44, 48, 41, 125, 62, 36, 70, 108, 105, 112, 84,
  111, 108, 125, 10, 66, 87, 61, 123, 105, 110, 116, 40, 97, 98, 115, 40,
  36, 88, 83, 105, 122, 101, 43, 40, 36, 77, 97, 120, 88, 83, 105, 122,
  101, 45, 36, 88, 83, 105, 122, 101, 41, 42, 40, 63, 40, 36, 82, 97,
  110, 100, 111, 109, 110, 101, 115, 115, 41, 41, 41, 41, 125, 10, 66, 72,
  61, 123, 105, 110, 116, 40, 97, 98, 115, 40, 36, 89, 83, 105, 122, 101,
  43, 40, 36, 77, 97, 120, 89, 83, 105, 122, 101, 45, 36, 89, 83, 105,
  122, 101, 41, 42, 40, 63, 40, 36, 82, 97, 110, 100, 111, 109, 110, 101,
  115, 115, 41, 41, 41, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 64, 123, 45, 49, 44, 40, 36, 88, 44, 36, 89, 44,
  48, 44, 48, 41, 125, 60, 61, 36, 70, 108, 105, 112, 84, 111, 108, 125,
  10, 66, 72, 61, 123, 105, 110, 116, 40, 97, 98, 115, 40, 36, 88, 83,
  105, 122, 101, 43, 40, 36, 77, 97, 120, 88, 83, 105, 122, 101, 45, 36,
  88, 83, 105, 122, 101, 41, 42, 40, 63, 40, 36, 82, 97, 110, 100, 111,
  109, 110, 101, 115, 115, 41, 41, 41, 41, 125, 10, 66, 87, 61, 123, 105,
  110, 116, 40, 97, 98, 115, 40, 36, 89, 83, 105, 122, 101, 43, 40, 36,
  77, 97, 120, 89, 83, 105, 122, 101, 45, 36, 89, 83, 105, 122, 101, 41,
  42, 40, 63, 40, 36, 82, 97, 110, 100, 111, 109, 110, 101, 115, 115, 41,
  41, 41, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 101, 118, 101, 114, 115, 101,
  70, 108, 105, 112, 61, 61, 49, 125, 10, 45, 105, 102, 32, 123, 64, 123,
  45, 49, 44, 40, 36, 88, 44, 36, 89, 44, 48, 44, 48, 41, 125, 60,
  36, 70, 108, 105, 112, 84, 111, 108, 125, 10, 66, 87, 61, 123, 105, 110,
  116, 40, 97, 98, 115, 40, 36, 88, 83, 105, 122, 101, 43, 40, 36, 77,
  97, 120, 88, 83, 105, 122, 101, 45, 36, 88, 83, 105, 122, 101, 41, 42,
  40, 63, 40, 36, 82, 97, 110, 100, 111, 109, 110, 101, 115, 115, 41, 41,
  41, 41, 125, 10, 66, 72, 61, 123, 105, 110, 116, 40, 97, 98, 115, 40,
  36, 89, 83, 105, 122, 101, 43, 40, 36, 77, 97, 120, 89, 83, 105, 122,
  101, 45, 36, 89, 83, 105, 122, 101, 41, 42, 40, 63, 40, 36, 82, 97,
  110, 100, 111, 109, 110, 101, 115, 115, 41, 41, 41, 41, 125, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64, 123, 45, 49, 44, 40,
  36, 88, 44, 36, 89, 44, 48, 44, 48, 41, 125, 62, 61, 36, 70, 108,
  105, 112, 84, 111, 108, 125, 10, 66, 72, 61, 123, 105, 110, 116, 40, 97,
  98, 115, 40, 36, 88, 83, 105, 122, 101, 43, 40, 36, 77, 97, 120, 88,
  83, 105, 122, 101, 45, 36, 88, 83, 105, 122, 101, 41, 42, 40, 63, 40,
  36, 82, 97, 110, 100, 111, 109, 110, 101, 115, 115, 41, 41, 41, 41, 125,
  10, 66, 87, 61, 123, 105, 110, 116, 40, 97, 98, 115, 40, 36, 89, 83,
  105, 122, 101, 43, 40, 36, 77, 97, 120, 89, 83, 105, 122, 101, 45, 36,
  89, 83, 105, 122, 101, 41, 42, 40, 63, 40, 36, 82, 97, 110, 100, 111,
  109, 110, 101, 115, 115, 41, 41, 41, 41, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 105, 102, 10, 120, 48, 61, 123, 105, 110, 116,
  40, 36, 88, 45, 36, 66, 87, 47, 50, 41, 125, 10, 121, 48, 61, 123,
  105, 110, 116, 40, 36, 89, 45, 36, 66, 72, 47, 50, 41, 125, 10, 120,
  49, 61, 123, 105, 110, 116, 40, 36, 120, 48, 43, 36, 66, 87, 41, 125,
  10, 121, 49, 61, 123, 105, 110, 116, 40, 36, 121, 48, 43, 36, 66, 72,
  41, 125, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 50,
  93, 32, 36, 120, 48, 44, 36, 121, 48, 44, 36, 120, 49, 44, 36, 121,
  49, 44, 36, 79, 112, 97, 99, 105, 116, 121, 44, 64, 123, 45, 49, 44,
  40, 36, 88, 44, 36, 89, 44, 48, 44, 48, 41, 125, 44, 64, 123, 45,
  49, 44, 40, 36, 88, 44, 36, 89, 44, 48, 44, 49, 41, 125, 44, 64,
  123, 45, 49, 44, 40, 36, 88, 44, 36, 89, 44, 48, 44, 50, 41, 125,
  44, 64, 123, 45, 49, 44, 40, 36, 88, 44, 36, 89, 44, 48, 44, 51,
  41, 10, 45, 100, 111, 110, 101, 10, 45, 114, 101, 109, 111, 118, 101, 91,
  45, 49, 93, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 10, 45, 100,
  111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 76, 65, 66, 125, 10, 45,
  97, 112, 112, 101, 110, 100, 91, 45, 51, 44, 45, 50, 44, 45, 49, 93,
  32, 99, 10, 45, 108, 97, 98, 50, 114, 103, 98, 91, 45, 49, 93, 10,
  45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 98, 108, 111, 99,
  107, 105, 115, 109, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 98, 108, 111, 99, 107, 105,
  115, 109, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 123, 36, 52, 42,
  49, 48, 125, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 34,
  44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 66, 111, 107, 101,
  104, 32, 58, 32, 98, 111, 107, 101, 104, 44, 32, 103, 105, 109, 112, 95,
  98, 111, 107, 101, 104, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 98, 62, 60, 115, 109, 97, 108, 108,
  62, 71, 108, 111, 98, 97, 108, 32, 112, 97, 114, 97, 109, 101, 116, 101,
  114, 115, 58, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 98, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105,
  116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 53, 48,
  44, 48, 44, 54, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 50, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 68, 101, 110, 115, 105, 116, 121, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 98, 62, 60, 115, 109, 97, 108, 108,
  62, 66, 111, 107, 101, 104, 32, 115, 104, 97, 112, 101, 58, 60, 47, 115,
  109, 97, 108, 108, 62, 60, 47, 98, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40,
  50, 52, 44, 49, 44, 54, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 79, 117, 116, 108, 105, 110, 101, 32, 115, 105, 122, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 108, 105, 110,
  101, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 50, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 44, 48, 44, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101,
  118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112,
  108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109,
  112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 52, 47, 50,
  52, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 103, 105, 109, 112, 95, 98, 111, 107, 101, 104, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 98, 111, 107, 101,
  104, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112,
  32, 67, 97, 114, 116, 111, 111, 110, 32, 58, 32, 99, 97, 114, 116, 111,
  111, 110, 44, 32, 103, 105, 109, 112, 95, 99, 97, 114, 116, 111, 111, 110,
  95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 51, 44, 48, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 114, 112, 101, 110,
  105, 110, 103, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 48, 44,
  48, 44, 52, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  69, 100, 103, 101, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 49, 44, 51, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101, 32, 116, 104,
  105, 99, 107, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 50, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 111, 108, 111, 114, 32, 115, 116, 114, 101, 110, 103, 116,
  104, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 53, 44, 48, 44,
  51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111,
  114, 32, 113, 117, 97, 110, 116, 105, 122, 97, 116, 105, 111, 110, 32, 61,
  32, 105, 110, 116, 40, 56, 44, 50, 44, 50, 53, 54, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101,
  119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99,
  97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105,
  62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114,
  108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 99, 97, 114, 116, 111, 111, 110, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 99, 97, 114, 116, 111,
  111, 110, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 67, 111, 108, 111, 114, 101, 100, 32, 112, 101, 110, 99, 105, 108,
  115, 32, 58, 32, 103, 105, 109, 112, 95, 99, 112, 101, 110, 99, 105, 108,
  44, 32, 103, 105, 109, 112, 95, 99, 112, 101, 110, 99, 105, 108, 95, 112,
  114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 46, 51, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 53, 48, 44, 48, 44, 50, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 81, 117, 97, 110, 116, 105, 122, 101, 32,
  99, 111, 108, 111, 114, 115, 32, 61, 32, 105, 110, 116, 32, 40, 50, 48,
  44, 50, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 111, 108, 111, 114, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 44, 51, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 105, 120, 101, 114,
  32, 109, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 50,
  44, 34, 67, 111, 108, 111, 114, 32, 68, 111, 112, 105, 110, 103, 34, 44,
  34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 72, 97, 114, 100, 32, 76,
  105, 103, 104, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 77, 101, 114,
  103, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44,
  34, 77, 117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 83, 111, 102, 116,
  32, 76, 105, 103, 104, 116, 34, 44, 34, 86, 97, 108, 117, 101, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32,
  105, 110, 116, 101, 110, 115, 105, 116, 121, 32, 61, 102, 108, 111, 97, 116,
  32, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  80, 104, 111, 116, 111, 67, 111, 109, 105, 88, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47,
  50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 99, 112, 101, 110, 99, 105, 108, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116,
  121, 32, 45, 108, 91, 48, 93, 10, 45, 45, 112, 101, 110, 99, 105, 108,
  98, 119, 32, 36, 49, 44, 36, 50, 32, 45, 98, 108, 117, 114, 95, 120,
  121, 91, 45, 49, 93, 32, 48, 46, 52, 44, 48, 46, 52, 10, 45, 113,
  117, 97, 110, 116, 105, 122, 101, 91, 45, 50, 93, 32, 36, 51, 32, 45,
  110, 111, 114, 109, 97, 108, 105, 122, 101, 32, 48, 44, 50, 53, 53, 32,
  45, 116, 111, 95, 114, 103, 98, 10, 45, 98, 108, 117, 114, 95, 120, 121,
  91, 45, 50, 93, 32, 36, 52, 44, 36, 52, 10, 45, 105, 102, 32, 123,
  36, 53, 61, 61, 48, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 99, 111, 108, 111, 114, 100, 111, 112, 105, 110, 103,
  32, 36, 54, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 53, 61,
  61, 49, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 100, 97, 114, 107, 101, 110, 32, 36, 54, 44, 49, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 53, 61, 61, 50, 125, 32, 45, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 104, 97, 114, 100, 108, 105,
  103, 104, 116, 32, 36, 54, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 53, 61, 61, 51, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 32,
  36, 54, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 53, 61, 61,
  52, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 36, 54, 44, 49, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 53, 61, 61, 53, 125, 32, 45, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108, 116,
  105, 112, 108, 121, 32, 36, 54, 44, 48, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 53, 61, 61, 54, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 115, 111, 102, 116, 108, 105, 103, 104, 116, 32,
  36, 54, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 53, 61, 61,
  55, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 118, 97, 108, 117, 101, 32, 36, 54, 44, 49, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 99,
  112, 101, 110, 99, 105, 108, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 99, 112, 101, 110,
  99, 105, 108, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 67, 111, 108, 111, 114, 32, 97, 98,
  115, 116, 114, 97, 99, 116, 105, 111, 110, 32, 112, 97, 105, 110, 116, 32,
  58, 32, 103, 105, 109, 112, 95, 67, 111, 108, 111, 114, 65, 98, 115, 116,
  114, 97, 99, 116, 105, 111, 110, 80, 97, 105, 110, 116, 44, 32, 103, 105,
  109, 112, 95, 67, 111, 108, 111, 114, 65, 98, 115, 116, 114, 97, 99, 116,
  105, 111, 110, 80, 97, 105, 110, 116, 95, 80, 114, 101, 118, 105, 101, 119,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 98, 115,
  116, 114, 97, 99, 116, 105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 53,
  44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  69, 108, 108, 105, 112, 115, 101, 32, 114, 97, 116, 105, 111, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 48, 44, 49, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 79, 112, 97, 99, 105, 116, 105, 101,
  115, 44, 32, 116, 114, 121, 32, 48, 32, 116, 111, 32, 115, 101, 101, 32,
  105, 110, 100, 105, 118, 105, 100, 117, 97, 108, 32, 101, 102, 102, 101, 99,
  116, 32, 108, 97, 121, 101, 114, 115, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 69, 108, 108, 105, 112, 115, 105, 111, 110, 105, 115, 109,
  32, 111, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 85, 115, 101, 32,
  97, 115, 32, 104, 117, 101, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 105, 110, 116, 105,
  110, 103, 32, 111, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 44, 45, 49, 44, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 85,
  115, 101, 32, 97, 115, 32, 115, 97, 116, 117, 114, 97, 116, 105, 111, 110,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 97, 98, 115, 116, 114, 97,
  99, 116, 105, 111, 110, 32, 111, 112, 97, 99, 105, 116, 121, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 45, 49, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 101, 103, 97, 116, 105, 118, 101, 32,
  99, 111, 108, 111, 114, 32, 97, 98, 115, 116, 114, 97, 99, 116, 105, 111,
  110, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 117, 98, 105, 115, 109, 32, 111, 110, 32, 99,
  111, 108, 111, 114, 32, 97, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 75, 117, 119, 97, 104, 97, 114, 97, 32, 111, 110, 32,
  112, 97, 105, 110, 116, 105, 110, 103, 32, 61, 32, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 111, 102, 116,
  101, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 111, 102,
  116, 101, 110, 32, 97, 108, 108, 32, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 68, 111, 110, 111, 116, 109, 101, 114, 103, 101, 108, 97,
  121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121,
  112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 70,
  117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 83, 97,
  109, 112, 108, 101, 32, 97, 114, 116, 32, 104, 101, 114, 101, 34, 44, 34,
  104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 102, 108, 105, 99, 107,
  114, 46, 99, 111, 109, 47, 112, 104, 111, 116, 111, 115, 47, 110, 97, 103,
  103, 111, 98, 111, 116, 47, 54, 54, 52, 48, 55, 52, 51, 49, 51, 51,
  47, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62,
  65, 114, 116, 111, 32, 72, 117, 111, 116, 97, 114, 105, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48,
  57, 47, 50, 56, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 67, 111, 108, 111, 114, 65, 98,
  115, 116, 114, 97, 99, 116, 105, 111, 110, 80, 97, 105, 110, 116, 32, 58,
  10, 112, 65, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 61, 36, 49,
  10, 69, 108, 108, 105, 112, 115, 101, 82, 97, 116, 105, 111, 61, 36, 50,
  10, 86, 97, 108, 117, 101, 79, 112, 97, 99, 105, 116, 121, 61, 36, 51,
  10, 85, 115, 101, 72, 117, 101, 61, 36, 52, 10, 77, 117, 108, 116, 105,
  112, 108, 121, 79, 112, 97, 99, 105, 116, 121, 61, 36, 53, 10, 85, 115,
  101, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 61, 36, 54, 10, 71,
  114, 97, 105, 110, 77, 101, 114, 103, 101, 79, 112, 97, 99, 105, 116, 121,
  61, 36, 55, 10, 78, 67, 65, 61, 36, 56, 10, 67, 117, 98, 101, 73,
  116, 61, 36, 57, 10, 75, 117, 119, 97, 73, 116, 61, 36, 49, 48, 10,
  83, 111, 102, 116, 101, 110, 61, 36, 49, 49, 10, 83, 111, 102, 116, 101,
  110, 65, 108, 108, 61, 36, 49, 50, 10, 68, 111, 78, 111, 116, 67, 111,
  109, 112, 111, 115, 101, 61, 36, 49, 51, 10, 82, 101, 118, 101, 114, 115,
  101, 79, 114, 100, 101, 114, 48, 61, 49, 10, 82, 101, 118, 101, 114, 115,
  101, 79, 114, 100, 101, 114, 49, 61, 49, 10, 82, 101, 118, 101, 114, 115,
  101, 79, 114, 100, 101, 114, 50, 61, 49, 10, 101, 83, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 61, 49, 10, 101, 79, 112, 97, 99, 105, 116, 121,
  61, 48, 46, 56, 10, 101, 79, 117, 116, 108, 105, 110, 101, 61, 49, 10,
  101, 68, 101, 110, 115, 105, 116, 121, 61, 123, 49, 46, 53, 42, 36, 101,
  83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 47, 49, 48, 125, 10, 112,
  68, 101, 116, 97, 105, 108, 115, 83, 99, 97, 108, 101, 61, 123, 36, 112,
  65, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 47, 50, 125, 10, 112,
  67, 111, 108, 111, 114, 61, 49, 46, 53, 10, 112, 83, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 61, 123, 49, 48, 42, 36, 112, 65, 98, 115, 116,
  114, 97, 99, 116, 105, 111, 110, 125, 10, 101, 83, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 61, 123, 49, 48, 43, 40, 36, 112, 65, 98, 115, 116,
  114, 97, 99, 116, 105, 111, 110, 45, 49, 41, 42, 40, 49, 45, 49, 48,
  41, 47, 40, 49, 48, 45, 49, 41, 125, 10, 101, 80, 114, 105, 109, 97,
  114, 121, 82, 97, 100, 105, 117, 115, 61, 123, 40, 36, 112, 65, 98, 115,
  116, 114, 97, 99, 116, 105, 111, 110, 47, 53, 41, 42, 40, 36, 112, 65,
  98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 47, 53, 41, 42, 115, 113,
  114, 116, 40, 64, 123, 48, 44, 104, 125, 41, 125, 10, 101, 83, 101, 99,
  111, 110, 100, 97, 114, 121, 82, 97, 100, 105, 117, 115, 61, 123, 36, 69,
  108, 108, 105, 112, 115, 101, 82, 97, 116, 105, 111, 47, 49, 48, 48, 42,
  36, 101, 80, 114, 105, 109, 97, 114, 121, 82, 97, 100, 105, 117, 115, 125,
  10, 99, 65, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 61, 123, 50,
  43, 40, 36, 112, 65, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 45,
  49, 41, 42, 40, 49, 48, 45, 50, 41, 47, 40, 49, 48, 45, 49, 41,
  125, 10, 67, 117, 98, 101, 83, 105, 122, 101, 61, 123, 52, 43, 40, 36,
  112, 65, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 45, 49, 41, 42,
  40, 49, 48, 45, 52, 41, 47, 40, 49, 48, 45, 49, 41, 125, 10, 45,
  45, 103, 105, 109, 112, 95, 101, 108, 108, 105, 112, 115, 105, 111, 110, 105,
  115, 109, 91, 48, 93, 32, 36, 101, 80, 114, 105, 109, 97, 114, 121, 82,
  97, 100, 105, 117, 115, 44, 36, 101, 83, 101, 99, 111, 110, 100, 97, 114,
  121, 82, 97, 100, 105, 117, 115, 44, 36, 101, 83, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 44, 36, 101, 79, 112, 97, 99, 105, 116, 121, 44, 49,
  44, 36, 101, 68, 101, 110, 115, 105, 116, 121, 44, 48, 10, 45, 105, 102,
  32, 123, 36, 83, 111, 102, 116, 101, 110, 65, 108, 108, 61, 61, 49, 34,
  32, 38, 38, 32, 34, 36, 83, 111, 102, 116, 101, 110, 62, 48, 125, 32,
  45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 83, 111, 102, 116, 101,
  110, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 103, 105, 109,
  112, 95, 112, 97, 105, 110, 116, 105, 110, 103, 91, 48, 93, 32, 36, 112,
  65, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 44, 36, 112, 68, 101,
  116, 97, 105, 108, 115, 83, 99, 97, 108, 101, 44, 36, 112, 67, 111, 108,
  111, 114, 44, 36, 112, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 44,
  49, 44, 48, 10, 45, 105, 102, 32, 123, 36, 75, 117, 119, 97, 73, 116,
  61, 61, 49, 125, 32, 45, 103, 105, 109, 112, 95, 107, 117, 119, 97, 104,
  97, 114, 97, 91, 45, 49, 93, 32, 50, 44, 36, 112, 65, 98, 115, 116,
  114, 97, 99, 116, 105, 111, 110, 44, 48, 44, 48, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 83, 111, 102, 116, 101, 110, 62,
  48, 125, 32, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 83, 111,
  102, 116, 101, 110, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45,
  103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 95, 97, 98, 115, 116, 114,
  97, 99, 116, 105, 111, 110, 91, 48, 93, 32, 36, 99, 65, 98, 115, 116,
  114, 97, 99, 116, 105, 111, 110, 44, 52, 53, 44, 48, 46, 51, 53, 44,
  48, 10, 45, 105, 102, 32, 123, 36, 78, 67, 65, 61, 61, 49, 125, 32,
  45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 67, 117, 98, 101, 73,
  116, 61, 61, 49, 125, 32, 45, 99, 117, 98, 105, 115, 109, 91, 45, 49,
  93, 32, 54, 48, 48, 44, 36, 67, 117, 98, 101, 83, 105, 122, 101, 44,
  52, 48, 44, 48, 46, 55, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 83, 111, 102, 116, 101, 110, 62, 48, 125, 32,
  45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 83, 111, 102, 116, 101,
  110, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 68, 111, 78, 111, 116, 67, 111, 109, 112, 111, 115, 101, 61, 61, 48,
  125, 10, 35, 67, 111, 109, 112, 111, 115, 101, 32, 79, 114, 105, 103, 105,
  110, 97, 108, 32, 97, 110, 100, 32, 69, 108, 108, 105, 112, 115, 105, 111,
  110, 105, 115, 109, 32, 119, 105, 116, 104, 32, 118, 97, 108, 117, 101, 10,
  45, 98, 108, 101, 110, 100, 91, 48, 44, 49, 93, 32, 118, 97, 108, 117,
  101, 44, 36, 86, 97, 108, 117, 101, 79, 112, 97, 99, 105, 116, 121, 44,
  36, 82, 101, 118, 101, 114, 115, 101, 79, 114, 100, 101, 114, 48, 10, 35,
  67, 111, 109, 112, 111, 115, 101, 32, 79, 114, 105, 103, 105, 110, 97, 108,
  43, 69, 108, 108, 105, 112, 115, 105, 111, 110, 105, 115, 109, 32, 119, 105,
  116, 104, 32, 112, 97, 105, 110, 116, 105, 110, 103, 10, 45, 105, 102, 32,
  123, 36, 77, 117, 108, 116, 105, 112, 108, 121, 79, 112, 97, 99, 105, 116,
  121, 60, 48, 125, 10, 82, 101, 118, 101, 114, 115, 101, 79, 114, 100, 101,
  114, 49, 61, 48, 10, 77, 117, 108, 116, 105, 112, 108, 121, 79, 112, 97,
  99, 105, 116, 121, 61, 123, 45, 49, 42, 36, 77, 117, 108, 116, 105, 112,
  108, 121, 79, 112, 97, 99, 105, 116, 121, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 85, 115, 101, 72, 117, 101, 61, 61,
  48, 125, 10, 45, 98, 108, 101, 110, 100, 91, 48, 44, 49, 93, 32, 109,
  117, 108, 116, 105, 112, 108, 121, 44, 36, 77, 117, 108, 116, 105, 112, 108,
  121, 79, 112, 97, 99, 105, 116, 121, 44, 36, 82, 101, 118, 101, 114, 115,
  101, 79, 114, 100, 101, 114, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  85, 115, 101, 72, 117, 101, 61, 61, 49, 125, 10, 45, 98, 108, 101, 110,
  100, 91, 48, 44, 49, 93, 32, 104, 117, 101, 44, 36, 77, 117, 108, 116,
  105, 112, 108, 121, 79, 112, 97, 99, 105, 116, 121, 44, 36, 82, 101, 118,
  101, 114, 115, 101, 79, 114, 100, 101, 114, 49, 10, 45, 101, 110, 100, 105,
  102, 10, 35, 67, 111, 109, 112, 111, 115, 101, 32, 79, 114, 105, 103, 105,
  110, 97, 108, 43, 69, 108, 108, 105, 112, 115, 105, 111, 110, 105, 115, 109,
  43, 80, 97, 105, 110, 116, 105, 110, 103, 32, 119, 105, 116, 104, 32, 67,
  111, 108, 111, 114, 32, 97, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110,
  10, 45, 105, 102, 32, 123, 36, 71, 114, 97, 105, 110, 77, 101, 114, 103,
  101, 79, 112, 97, 99, 105, 116, 121, 60, 48, 125, 10, 82, 101, 118, 101,
  114, 115, 101, 79, 114, 100, 101, 114, 50, 61, 48, 10, 71, 114, 97, 105,
  110, 77, 101, 114, 103, 101, 79, 112, 97, 99, 105, 116, 121, 61, 123, 45,
  49, 42, 36, 71, 114, 97, 105, 110, 77, 101, 114, 103, 101, 79, 112, 97,
  99, 105, 116, 121, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 85, 115, 101, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110,
  61, 61, 48, 125, 10, 45, 98, 108, 101, 110, 100, 91, 48, 44, 49, 93,
  32, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 44, 36, 71, 114, 97,
  105, 110, 77, 101, 114, 103, 101, 79, 112, 97, 99, 105, 116, 121, 44, 36,
  82, 101, 118, 101, 114, 115, 101, 79, 114, 100, 101, 114, 50, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 85, 115, 101, 83, 97, 116, 117, 114, 97, 116,
  105, 111, 110, 61, 61, 49, 125, 10, 45, 98, 108, 101, 110, 100, 91, 48,
  44, 49, 93, 32, 115, 97, 116, 117, 114, 97, 116, 105, 111, 110, 44, 36,
  71, 114, 97, 105, 110, 77, 101, 114, 103, 101, 79, 112, 97, 99, 105, 116,
  121, 44, 36, 82, 101, 118, 101, 114, 115, 101, 79, 114, 100, 101, 114, 50,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 107, 101, 101, 112, 91, 48, 93,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 68, 111,
  78, 111, 116, 67, 111, 109, 112, 111, 115, 101, 61, 61, 49, 125, 32, 45,
  114, 101, 109, 111, 118, 101, 91, 48, 93, 32, 45, 101, 110, 100, 105, 102,
  10, 103, 105, 109, 112, 95, 67, 111, 108, 111, 114, 65, 98, 115, 116, 114,
  97, 99, 116, 105, 111, 110, 80, 97, 105, 110, 116, 95, 80, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112,
  95, 67, 111, 108, 111, 114, 65, 98, 115, 116, 114, 97, 99, 116, 105, 111,
  110, 80, 97, 105, 110, 116, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44,
  36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 67, 111, 108, 111, 114,
  32, 115, 107, 101, 116, 99, 104, 32, 58, 32, 103, 105, 109, 112, 95, 99,
  111, 108, 111, 114, 115, 107, 101, 116, 99, 104, 98, 119, 44, 32, 103, 105,
  109, 112, 95, 99, 111, 108, 111, 114, 115, 107, 101, 116, 99, 104, 98, 119,
  95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 51, 48, 48, 44, 48, 44, 52, 48, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 110, 115,
  105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 69, 100, 103, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 50, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 70, 97, 115, 116, 32, 97, 112, 112, 114, 111, 120,
  105, 109, 97, 116, 105, 111, 110, 32, 61, 32, 98, 111, 111, 108, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 101, 103, 97, 116,
  105, 118, 101, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 81, 117, 97, 110, 116, 105, 122, 101, 32,
  99, 111, 108, 111, 114, 115, 32, 61, 32, 105, 110, 116, 32, 40, 50, 48,
  44, 50, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 111, 108, 111, 114, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 46, 53, 48,
  44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 105,
  120, 101, 114, 32, 109, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 32, 34, 67, 111, 108, 111, 114, 32, 68, 111, 112, 105, 110, 103,
  34, 44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 72, 97, 114, 100,
  32, 76, 105, 103, 104, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 77,
  101, 114, 103, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115,
  34, 44, 34, 77, 117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 86, 97,
  108, 117, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  111, 108, 111, 114, 32, 105, 110, 116, 101, 110, 115, 105, 116, 121, 32, 61,
  102, 108, 111, 97, 116, 32, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101,
  119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 80, 104, 111, 116, 111, 67, 111, 109, 105, 88, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49,
  48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 99, 111, 108, 111,
  114, 115, 107, 101, 116, 99, 104, 98, 119, 32, 58, 10, 45, 45, 98, 108,
  117, 114, 32, 36, 51, 32, 45, 104, 97, 114, 100, 115, 107, 101, 116, 99,
  104, 98, 119, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 52,
  44, 36, 53, 44, 36, 54, 10, 45, 105, 102, 32, 36, 55, 32, 45, 110,
  101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 113, 117, 97, 110, 116, 105, 122, 101, 91, 45, 50, 93,
  32, 36, 56, 32, 32, 45, 116, 111, 95, 114, 103, 98, 32, 32, 45, 98,
  108, 117, 114, 95, 120, 121, 91, 45, 50, 93, 32, 36, 57, 44, 36, 57,
  10, 45, 105, 102, 32, 123, 36, 49, 48, 61, 61, 48, 125, 32, 45, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 99, 111, 108, 111,
  114, 100, 111, 112, 105, 110, 103, 32, 36, 49, 49, 44, 48, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 49, 48, 61, 61, 49, 125, 32, 45, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101,
  110, 32, 36, 49, 49, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  49, 48, 61, 61, 50, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 104, 97, 114, 100, 108, 105, 103, 104, 116, 32, 36,
  49, 49, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 48, 61,
  61, 51, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 32, 36, 49, 49,
  44, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 48, 61, 61, 52,
  125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95,
  108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 36, 49, 49, 44, 49, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 48, 61, 61, 53, 125, 32, 45,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108,
  116, 105, 112, 108, 121, 32, 36, 49, 49, 44, 48, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 48, 61, 61, 54, 125, 32, 45, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 118, 97, 108, 117, 101, 32, 36,
  49, 49, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112,
  95, 99, 111, 108, 111, 114, 115, 107, 101, 116, 99, 104, 98, 119, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115,
  112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103,
  105, 109, 112, 95, 99, 111, 108, 111, 114, 115, 107, 101, 116, 99, 104, 98,
  119, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35,
  64, 103, 105, 109, 112, 32, 67, 111, 108, 111, 114, 32, 115, 116, 97, 109,
  112, 32, 58, 32, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 115, 116,
  97, 109, 112, 44, 32, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 115,
  116, 97, 109, 112, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 32, 40, 34, 66, 87, 32, 109, 111, 100, 117, 108, 101,
  44, 97, 110, 97, 108, 111, 103, 32, 116, 111, 32, 34, 83, 116, 97, 109,
  112, 34, 102, 105, 108, 116, 101, 114, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  117, 116, 111, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32,
  98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 105, 110, 116,
  40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 32, 40, 34, 67, 111, 108,
  111, 114, 32, 109, 111, 100, 117, 108, 101, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 99, 116, 105, 118, 97, 116, 101, 32, 99, 111,
  108, 111, 114, 32, 109, 111, 100, 117, 108, 101, 32, 61, 32, 98, 111, 111,
  108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 81, 117,
  97, 110, 116, 105, 122, 101, 32, 99, 111, 108, 111, 114, 115, 32, 61, 105,
  110, 116, 40, 50, 48, 44, 50, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 115, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50,
  44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 115, 58, 32, 60, 105, 62, 80,
  104, 111, 116, 111, 67, 111, 109, 105, 88, 32, 44, 32, 65, 110, 116, 97,
  114, 111, 110, 44, 32, 77, 97, 104, 118, 105, 110, 44, 32, 68, 97, 118,
  105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50,
  51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 32, 58, 32, 50, 48, 49, 49, 47, 48, 53, 47, 49, 55, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  99, 111, 108, 111, 114, 115, 116, 97, 109, 112, 32, 58, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45,
  115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108,
  91, 48, 93, 10, 45, 45, 110, 111, 114, 109, 10, 45, 105, 102, 32, 36,
  49, 32, 45, 111, 116, 115, 117, 91, 45, 49, 93, 32, 50, 53, 54, 32,
  45, 101, 108, 115, 101, 32, 45, 116, 91, 45, 49, 93, 32, 36, 50, 37,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 10, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118,
  101, 91, 45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 49, 48, 49, 44,
  51, 51, 44, 49, 55, 48, 44, 50, 50, 57, 44, 50, 53, 53, 44, 50,
  53, 53, 10, 45, 105, 102, 32, 123, 36, 51, 61, 61, 49, 125, 32, 45,
  113, 117, 97, 110, 116, 105, 122, 101, 91, 45, 50, 93, 32, 36, 52, 32,
  45, 116, 111, 95, 114, 103, 98, 32, 45, 98, 108, 117, 114, 95, 120, 121,
  91, 45, 50, 93, 32, 36, 53, 10, 45, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101, 110, 32, 49, 44, 48,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 97,
  32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103,
  105, 109, 112, 95, 99, 111, 108, 111, 114, 115, 116, 97, 109, 112, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115,
  112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103,
  105, 109, 112, 95, 99, 111, 108, 111, 114, 115, 116, 97, 109, 112, 32, 36,
  123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105,
  109, 112, 32, 67, 117, 98, 105, 115, 109, 32, 58, 32, 103, 105, 109, 112,
  95, 99, 117, 98, 105, 115, 109, 44, 32, 103, 105, 109, 112, 95, 99, 117,
  98, 105, 115, 109, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101, 114, 97, 116, 105,
  111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 50, 44, 48, 44, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 110, 115, 105,
  116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44,
  50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104,
  105, 99, 107, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 48, 44, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 65, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  57, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 55, 44, 48, 46, 48, 49, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117,
  112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 54, 47,
  48, 53, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 99, 117, 98, 105, 115, 109, 32, 58, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 32, 45, 99, 117, 98, 105,
  115, 109, 32, 36, 123, 50, 45, 45, 49, 125, 32, 45, 100, 111, 110, 101,
  10, 103, 105, 109, 112, 95, 99, 117, 98, 105, 115, 109, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109,
  112, 95, 99, 117, 98, 105, 115, 109, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 68, 114, 101, 97, 109, 32, 115, 109,
  111, 111, 116, 104, 105, 110, 103, 32, 58, 32, 103, 105, 109, 112, 95, 100,
  114, 101, 97, 109, 115, 109, 111, 111, 116, 104, 44, 32, 103, 105, 109, 112,
  95, 100, 114, 101, 97, 109, 115, 109, 111, 111, 116, 104, 95, 112, 114, 101,
  118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 85, 112,
  100, 97, 116, 101, 100, 32, 102, 111, 114, 32, 49, 46, 53, 46, 52, 46,
  48, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 65, 32, 114, 101, 108, 97,
  116, 105, 118, 101, 108, 121, 32, 115, 108, 111, 119, 32, 102, 105, 108, 116,
  101, 114, 32, 116, 104, 97, 116, 32, 117, 115, 101, 115, 32, 97, 110, 105,
  115, 111, 116, 114, 111, 112, 105, 99, 32, 102, 105, 108, 116, 101, 114, 105,
  110, 103, 32, 116, 111, 32, 115, 109, 111, 111, 116, 104, 32, 97, 110, 32,
  105, 109, 97, 103, 101, 46, 32, 77, 111, 114, 101, 32, 105, 116, 101, 114,
  97, 116, 105, 111, 110, 115, 32, 112, 114, 111, 100, 117, 99, 101, 115, 32,
  115, 111, 102, 116, 101, 114, 32, 105, 109, 97, 103, 101, 32, 97, 115, 32,
  100, 111, 101, 115, 32, 108, 111, 119, 101, 114, 32, 111, 112, 97, 99, 105,
  116, 121, 32, 118, 97, 108, 117, 101, 115, 46, 32, 80, 114, 97, 99, 116,
  105, 99, 97, 108, 32, 109, 111, 100, 101, 115, 32, 102, 111, 114, 32, 109,
  101, 114, 103, 105, 110, 103, 32, 97, 114, 101, 32, 65, 108, 112, 104, 97,
  32, 97, 110, 100, 32, 65, 118, 101, 114, 97, 103, 101, 46, 32, 78, 111,
  116, 101, 32, 116, 104, 97, 116, 32, 114, 101, 115, 117, 108, 116, 115, 32,
  97, 114, 101, 32, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 32, 100,
  101, 112, 101, 110, 100, 101, 110, 116, 46, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 71, 101, 110, 101, 114, 97, 108, 32, 115, 101, 116,
  116, 105, 110, 103, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110,
  116, 40, 51, 44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 69, 113, 117, 97, 108, 105, 122, 101, 32, 97, 116, 32, 101,
  97, 99, 104, 32, 115, 116, 101, 112, 32, 61, 32, 98, 111, 111, 108, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 77, 101, 114, 103,
  105, 110, 103, 32, 111, 102, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110,
  115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 101, 114,
  103, 105, 110, 103, 32, 111, 112, 116, 105, 111, 110, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 49, 44, 34, 97, 100, 100, 34, 44, 34, 97, 108,
  112, 104, 97, 34, 44, 34, 97, 110, 100, 34, 44, 34, 97, 118, 101, 114,
  97, 103, 101, 34, 44, 34, 98, 108, 117, 101, 34, 44, 34, 98, 117, 114,
  110, 34, 44, 34, 100, 97, 114, 107, 101, 110, 34, 44, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 34, 100, 105, 102, 102, 101, 114, 101, 110, 99,
  101, 34, 44, 34, 100, 105, 118, 105, 100, 101, 34, 44, 34, 100, 111, 100,
  103, 101, 34, 44, 34, 101, 120, 99, 108, 117, 115, 105, 111, 110, 34, 44,
  34, 102, 114, 101, 101, 122, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 34, 103, 114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116,
  34, 44, 34, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 34, 44, 34,
  103, 114, 101, 101, 110, 34, 44, 34, 104, 97, 114, 100, 108, 105, 103, 104,
  116, 34, 44, 34, 104, 97, 114, 100, 109, 105, 120, 34, 44, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 34, 104, 117, 101, 34, 44, 34, 105, 110,
  116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 34, 44, 34, 108, 105,
  103, 104, 116, 101, 110, 34, 44, 34, 108, 105, 103, 104, 116, 110, 101, 115,
  115, 34, 44, 34, 108, 105, 110, 101, 97, 114, 98, 117, 114, 110, 34, 44,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 108, 105, 110, 101, 97,
  114, 108, 105, 103, 104, 116, 34, 44, 34, 108, 117, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 34, 109, 117, 108, 116, 105, 112, 108, 121, 34, 44, 34,
  110, 101, 103, 97, 116, 105, 111, 110, 34, 44, 34, 111, 114, 34, 44, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 111, 118, 101, 114, 108, 97,
  121, 34, 44, 34, 112, 105, 110, 108, 105, 103, 104, 116, 34, 44, 34, 114,
  101, 100, 34, 44, 34, 114, 101, 102, 108, 101, 99, 116, 34, 44, 34, 115,
  97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 115, 99, 114, 101,
  101, 110, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 115,
  104, 97, 112, 101, 97, 118, 101, 114, 97, 103, 101, 34, 44, 34, 115, 111,
  102, 116, 98, 117, 114, 110, 34, 44, 34, 115, 111, 102, 116, 100, 111, 100,
  103, 101, 34, 44, 34, 115, 111, 102, 116, 108, 105, 103, 104, 116, 34, 44,
  34, 115, 116, 97, 109, 112, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 34, 115, 117, 98, 116, 114, 97, 99, 116, 34, 44, 34, 118, 97,
  108, 117, 101, 34, 44, 34, 118, 105, 118, 105, 100, 108, 105, 103, 104, 116,
  34, 44, 34, 120, 111, 114, 34, 44, 34, 101, 100, 103, 101, 115, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116,
  121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 56, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101,
  114, 115, 101, 32, 111, 114, 100, 101, 114, 32, 61, 32, 98, 111, 111, 108,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 83, 101, 116, 116, 105, 110,
  103, 115, 32, 102, 111, 114, 32, 108, 97, 121, 101, 114, 32, 109, 111, 100,
  101, 32, 101, 100, 103, 101, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 56, 44, 48, 44, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  80, 97, 114, 97, 108, 108, 101, 108, 32, 112, 114, 111, 99, 101, 115, 115,
  105, 110, 103, 32, 115, 101, 116, 116, 105, 110, 103, 115, 46, 32, 73, 110,
  99, 114, 101, 97, 115, 101, 32, 115, 112, 97, 116, 105, 97, 108, 32, 111,
  118, 101, 114, 108, 97, 112, 32, 105, 102, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 32, 98, 97, 110, 100, 115, 32, 97, 112, 112, 101, 97, 114, 46,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 114, 97,
  108, 108, 101, 108, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 65, 117, 116, 111,
  34, 44, 34, 79, 110, 101, 32, 116, 104, 114, 101, 97, 100, 34, 44, 34,
  84, 119, 111, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 70, 111,
  117, 114, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 69, 105, 103,
  104, 116, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 83, 105, 120,
  116, 101, 101, 110, 32, 116, 104, 114, 101, 97, 100, 115, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 97, 116, 105, 97, 108, 32,
  111, 118, 101, 114, 108, 97, 112, 32, 61, 32, 105, 110, 116, 40, 50, 52,
  44, 48, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 32, 65, 117, 116, 104, 111, 114, 58, 32, 65, 114, 116,
  111, 32, 72, 117, 111, 116, 97, 114, 105, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49,
  52, 47, 48, 50, 47, 50, 48, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 83, 97, 109,
  112, 108, 101, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 104,
  101, 114, 101, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119,
  46, 102, 108, 105, 99, 107, 114, 46, 99, 111, 109, 47, 112, 104, 111, 116,
  111, 115, 47, 110, 97, 103, 103, 111, 98, 111, 116, 47, 55, 54, 52, 52,
  48, 48, 54, 54, 48, 56, 47, 34, 41, 10, 103, 105, 109, 112, 95, 100,
  114, 101, 97, 109, 115, 109, 111, 111, 116, 104, 32, 58, 10, 45, 109, 32,
  34, 77, 101, 114, 103, 101, 67, 104, 111, 105, 115, 101, 32, 58, 32, 36,
  34, 34, 61, 95, 109, 111, 100, 101, 34, 32, 45, 77, 101, 114, 103, 101,
  67, 104, 111, 105, 115, 101, 32, 34, 97, 100, 100, 34, 44, 34, 97, 108,
  112, 104, 97, 34, 44, 34, 97, 110, 100, 34, 44, 34, 97, 118, 101, 114,
  97, 103, 101, 34, 44, 34, 98, 108, 117, 101, 34, 44, 34, 98, 117, 114,
  110, 34, 44, 34, 100, 97, 114, 107, 101, 110, 34, 44, 34, 100, 105, 102,
  102, 101, 114, 101, 110, 99, 101, 34, 44, 34, 100, 105, 118, 105, 100, 101,
  34, 44, 34, 100, 111, 100, 103, 101, 34, 44, 34, 101, 120, 99, 108, 117,
  115, 105, 111, 110, 34, 44, 34, 102, 114, 101, 101, 122, 101, 34, 44, 34,
  103, 114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116, 34, 44, 34, 103,
  114, 97, 105, 110, 109, 101, 114, 103, 101, 34, 44, 34, 103, 114, 101, 101,
  110, 34, 44, 34, 104, 97, 114, 100, 108, 105, 103, 104, 116, 34, 44, 34,
  104, 97, 114, 100, 109, 105, 120, 34, 44, 34, 104, 117, 101, 34, 44, 34,
  105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 34, 44, 34,
  108, 105, 103, 104, 116, 101, 110, 34, 44, 34, 108, 105, 103, 104, 116, 110,
  101, 115, 115, 34, 44, 34, 108, 105, 110, 101, 97, 114, 98, 117, 114, 110,
  34, 44, 34, 108, 105, 110, 101, 97, 114, 108, 105, 103, 104, 116, 34, 44,
  34, 108, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 109, 117, 108,
  116, 105, 112, 108, 121, 34, 44, 34, 110, 101, 103, 97, 116, 105, 111, 110,
  34, 44, 34, 111, 114, 34, 44, 34, 111, 118, 101, 114, 108, 97, 121, 34,
  44, 34, 112, 105, 110, 108, 105, 103, 104, 116, 34, 44, 34, 114, 101, 100,
  34, 44, 34, 114, 101, 102, 108, 101, 99, 116, 34, 44, 34, 115, 97, 116,
  117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 115, 99, 114, 101, 101, 110,
  34, 44, 34, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97, 103, 101, 34,
  44, 34, 115, 111, 102, 116, 98, 117, 114, 110, 34, 44, 34, 115, 111, 102,
  116, 100, 111, 100, 103, 101, 34, 44, 34, 115, 111, 102, 116, 108, 105, 103,
  104, 116, 34, 44, 34, 115, 116, 97, 109, 112, 34, 44, 34, 115, 117, 98,
  116, 114, 97, 99, 116, 34, 44, 34, 118, 97, 108, 117, 101, 34, 44, 34,
  118, 105, 118, 105, 100, 108, 105, 103, 104, 116, 34, 44, 34, 120, 111, 114,
  34, 44, 34, 101, 100, 103, 101, 115, 34, 44, 34, 101, 114, 114, 111, 114,
  34, 10, 45, 116, 111, 95, 114, 103, 98, 10, 73, 116, 101, 114, 97, 116,
  105, 111, 110, 115, 61, 36, 49, 10, 69, 113, 97, 61, 36, 50, 10, 77,
  101, 114, 103, 105, 110, 103, 79, 112, 116, 105, 111, 110, 61, 36, 51, 10,
  79, 112, 97, 99, 105, 116, 121, 61, 36, 52, 10, 82, 101, 118, 101, 114,
  115, 101, 79, 114, 100, 101, 114, 61, 36, 53, 10, 83, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 61, 36, 54, 10, 84, 104, 114, 101, 97, 100, 115,
  61, 36, 55, 10, 79, 118, 101, 114, 108, 97, 112, 61, 36, 56, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 73, 116, 101, 114, 97, 116,
  105, 111, 110, 115, 10, 35, 67, 97, 108, 99, 117, 108, 97, 116, 101, 32,
  119, 105, 100, 116, 104, 32, 97, 110, 100, 32, 104, 101, 105, 103, 104, 116,
  10, 73, 87, 105, 100, 116, 104, 61, 123, 114, 111, 117, 110, 100, 40, 64,
  123, 48, 44, 119, 125, 47, 40, 64, 123, 60, 44, 45, 49, 125, 43, 49,
  41, 41, 125, 10, 73, 72, 101, 105, 103, 104, 116, 61, 123, 114, 111, 117,
  110, 100, 40, 64, 123, 48, 44, 104, 125, 47, 40, 64, 123, 60, 44, 45,
  49, 125, 43, 49, 41, 41, 125, 10, 35, 82, 101, 115, 105, 122, 101, 32,
  112, 114, 101, 118, 105, 111, 117, 115, 108, 121, 32, 112, 114, 111, 99, 101,
  115, 115, 101, 100, 32, 105, 109, 97, 103, 101, 46, 32, 78, 111, 116, 32,
  100, 111, 110, 101, 32, 111, 110, 32, 102, 105, 114, 115, 116, 32, 114, 101,
  112, 101, 97, 116, 32, 108, 111, 111, 112, 32, 115, 105, 110, 99, 101, 32,
  116, 104, 101, 114, 101, 32, 105, 115, 32, 110, 111, 32, 115, 117, 99, 104,
  32, 105, 109, 97, 103, 101, 32, 121, 101, 116, 46, 10, 45, 105, 102, 32,
  123, 64, 123, 62, 44, 45, 49, 125, 33, 61, 48, 125, 10, 45, 114, 91,
  45, 49, 93, 32, 36, 73, 87, 105, 100, 116, 104, 44, 36, 73, 72, 101,
  105, 103, 104, 116, 44, 49, 44, 51, 44, 53, 44, 49, 10, 45, 101, 110,
  100, 105, 102, 10, 35, 82, 101, 115, 105, 122, 101, 32, 97, 110, 100, 32,
  109, 97, 107, 101, 32, 97, 32, 99, 111, 112, 121, 10, 45, 45, 114, 91,
  48, 93, 32, 36, 73, 87, 105, 100, 116, 104, 44, 36, 73, 72, 101, 105,
  103, 104, 116, 44, 49, 44, 51, 44, 53, 44, 49, 10, 35, 83, 109, 111,
  111, 116, 104, 105, 110, 103, 10, 45, 103, 105, 109, 112, 95, 97, 110, 105,
  115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105,
  110, 103, 91, 45, 49, 93, 32, 123, 52, 51, 48, 47, 36, 73, 116, 101,
  114, 97, 116, 105, 111, 110, 115, 42, 40, 64, 123, 60, 44, 45, 49, 125,
  43, 49, 41, 125, 44, 48, 46, 52, 44, 48, 46, 53, 44, 48, 46, 54,
  44, 50, 44, 48, 46, 56, 44, 51, 48, 44, 50, 44, 48, 44, 48, 44,
  49, 44, 48, 44, 36, 84, 104, 114, 101, 97, 100, 115, 44, 36, 79, 118,
  101, 114, 108, 97, 112, 44, 48, 10, 45, 103, 105, 109, 112, 95, 97, 110,
  105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104,
  105, 110, 103, 91, 45, 49, 93, 32, 123, 54, 48, 48, 47, 36, 73, 116,
  101, 114, 97, 116, 105, 111, 110, 115, 42, 40, 64, 123, 60, 44, 45, 49,
  125, 43, 49, 41, 125, 44, 48, 46, 52, 44, 49, 44, 48, 46, 54, 44,
  52, 44, 48, 46, 56, 44, 49, 53, 44, 53, 44, 48, 44, 49, 44, 49,
  44, 48, 44, 36, 84, 104, 114, 101, 97, 100, 115, 44, 36, 79, 118, 101,
  114, 108, 97, 112, 44, 48, 10, 35, 67, 111, 109, 98, 105, 110, 101, 32,
  105, 109, 97, 103, 101, 115, 32, 105, 102, 32, 110, 111, 116, 32, 102, 105,
  114, 115, 116, 32, 114, 111, 117, 110, 100, 10, 45, 105, 102, 32, 123, 64,
  123, 62, 44, 45, 49, 125, 33, 61, 48, 125, 10, 45, 105, 102, 32, 123,
  36, 51, 39, 33, 61, 39, 52, 50, 125, 10, 45, 98, 108, 101, 110, 100,
  91, 45, 49, 44, 45, 50, 93, 32, 36, 123, 95, 109, 111, 100, 101, 123,
  36, 77, 101, 114, 103, 105, 110, 103, 79, 112, 116, 105, 111, 110, 43, 49,
  125, 125, 44, 36, 79, 112, 97, 99, 105, 116, 121, 44, 36, 82, 101, 118,
  101, 114, 115, 101, 79, 114, 100, 101, 114, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 51, 39, 61, 61, 39, 52, 50, 125, 10,
  45, 98, 108, 101, 110, 100, 95, 101, 100, 103, 101, 115, 91, 45, 49, 44,
  45, 50, 93, 32, 36, 79, 112, 97, 99, 105, 116, 121, 44, 36, 83, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 44, 36, 82, 101, 118, 101, 114, 115,
  101, 79, 114, 100, 101, 114, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 69, 113, 97, 125, 10, 45, 101, 113, 117, 97, 108, 105,
  122, 101, 91, 45, 49, 93, 32, 50, 53, 54, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45,
  107, 101, 101, 112, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 100, 114, 101, 97, 109, 115,
  109, 111, 111, 116, 104, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 100, 114, 101, 97, 109,
  115, 109, 111, 111, 116, 104, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44,
  36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 69, 108, 108, 105, 112,
  115, 105, 111, 110, 105, 115, 109, 32, 58, 32, 103, 105, 109, 112, 95, 101,
  108, 108, 105, 112, 115, 105, 111, 110, 105, 115, 109, 44, 32, 103, 105, 109,
  112, 95, 101, 108, 108, 105, 112, 115, 105, 111, 110, 105, 115, 109, 95, 112,
  114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 80, 114, 105, 109, 97, 114, 121, 32, 114, 97, 100, 105, 117,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 49, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 99,
  111, 110, 100, 97, 114, 121, 32, 114, 97, 100, 105, 117, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 48, 44, 49, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44,
  48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79,
  112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  46, 55, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 79, 117, 116, 108, 105, 110, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 56, 44, 49, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 68, 101, 110, 115, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 53, 44, 48, 46, 49, 44, 50, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32,
  116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70,
  117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116,
  101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68,
  117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68,
  97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38,
  35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112,
  95, 101, 108, 108, 105, 112, 115, 105, 111, 110, 105, 115, 109, 32, 58, 10,
  45, 101, 108, 108, 105, 112, 115, 105, 111, 110, 105, 115, 109, 32, 36, 123,
  94, 48, 125, 10, 103, 105, 109, 112, 95, 101, 108, 108, 105, 112, 115, 105,
  111, 110, 105, 115, 109, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 101, 108, 108, 105, 112,
  115, 105, 111, 110, 105, 115, 109, 32, 36, 42, 34, 44, 36, 45, 49, 10,
  35, 64, 103, 105, 109, 112, 32, 70, 101, 108, 116, 32, 112, 101, 110, 32,
  58, 32, 103, 105, 109, 112, 95, 102, 101, 108, 116, 112, 101, 110, 44, 32,
  103, 105, 109, 112, 95, 102, 101, 108, 116, 112, 101, 110, 95, 112, 114, 101,
  118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 51, 48, 48, 44, 48, 44, 52, 48, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 110, 115, 105, 116, 121, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44,
  48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79,
  112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  46, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 69, 100, 103, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48,
  44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 84, 104, 105, 99, 107, 110, 101, 115, 115, 32, 61, 32, 105, 110, 116,
  40, 53, 44, 50, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108,
  105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 50, 47, 49, 48, 47, 50, 53, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 102, 101,
  108, 116, 112, 101, 110, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 45, 103, 105, 109, 112,
  95, 104, 97, 114, 100, 115, 107, 101, 116, 99, 104, 98, 119, 32, 36, 123,
  49, 45, 53, 125, 44, 48, 44, 48, 32, 45, 98, 108, 101, 110, 100, 32,
  104, 97, 114, 100, 108, 105, 103, 104, 116, 32, 45, 101, 114, 111, 100, 101,
  95, 111, 99, 116, 32, 36, 54, 32, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 103, 105, 109, 112, 95, 102, 101, 108, 116, 112, 101, 110,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 103, 105, 109, 112, 95, 102, 101, 108, 116, 112, 101, 110, 32, 36, 42,
  34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 71, 114, 97,
  112, 104, 105, 99, 32, 98, 111, 111, 115, 116, 32, 50, 32, 58, 32, 103,
  105, 109, 112, 95, 103, 114, 97, 112, 104, 105, 99, 95, 98, 111, 111, 115,
  116, 52, 44, 32, 103, 105, 109, 112, 95, 103, 114, 97, 112, 104, 105, 99,
  95, 98, 111, 111, 115, 116, 52, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 85, 110, 115,
  104, 97, 114, 112, 32, 77, 97, 115, 107, 32, 99, 111, 110, 116, 114, 111,
  108, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97,
  100, 105, 117, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 50,
  53, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 68, 97, 114, 107, 101, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  50, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 107, 105, 112,
  32, 111, 116, 104, 101, 114, 115, 32, 115, 116, 101, 112, 115, 32, 61, 32,
  98, 111, 111, 108, 40, 102, 97, 108, 115, 101, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 67, 104, 101, 99, 107, 32, 102, 111, 114, 32, 118, 105, 115, 117,
  97, 108, 32, 99, 111, 110, 116, 114, 111, 108, 44, 32, 85, 78, 99, 104,
  101, 99, 107, 32, 116, 111, 32, 114, 101, 97, 99, 116, 105, 118, 97, 116,
  101, 32, 116, 104, 101, 32, 111, 116, 104, 101, 114, 32, 99, 111, 110, 116,
  114, 111, 108, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 66, 87, 95, 80, 101, 110, 99, 105, 108, 32, 67, 111, 110,
  116, 114, 111, 108, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 80, 101, 110, 99, 105, 108, 32, 115, 105, 122, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 49, 53, 44, 48, 44, 52, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 80, 101, 110, 99, 105, 108, 32, 97,
  109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 52, 44, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  107, 105, 112, 32, 111, 116, 104, 101, 114, 115, 32, 115, 116, 101, 112, 115,
  32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108, 115, 101, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  65, 99, 116, 105, 118, 97, 116, 101, 32, 34, 112, 101, 110, 99, 105, 108,
  32, 115, 109, 111, 111, 116, 104, 101, 114, 34, 32, 61, 32, 98, 111, 111,
  108, 40, 116, 114, 117, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 32, 73,
  102, 32, 117, 110, 99, 104, 101, 99, 107, 101, 100, 32, 116, 104, 101, 32,
  51, 32, 115, 108, 105, 100, 101, 114, 115, 32, 98, 101, 108, 111, 119, 32,
  97, 114, 101, 32, 100, 105, 115, 97, 98, 108, 101, 100, 32, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 101, 110, 99, 105, 108, 32,
  115, 109, 111, 111, 116, 104, 101, 114, 32, 115, 104, 97, 114, 112, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48,
  44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 101, 110,
  99, 105, 108, 32, 115, 109, 111, 111, 116, 104, 101, 114, 32, 101, 100, 103,
  101, 32, 112, 114, 111, 116, 101, 99, 116, 105, 111, 110, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 52, 53, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 80, 101, 110, 99, 105, 108, 32, 115,
  109, 111, 111, 116, 104, 101, 114, 32, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 50, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 107, 105, 112, 32, 111, 116, 104,
  101, 114, 115, 32, 115, 116, 101, 112, 115, 32, 61, 32, 98, 111, 111, 108,
  40, 102, 97, 108, 115, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 77, 101, 114, 103, 105, 110, 103, 32, 79, 112,
  116, 105, 111, 110, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 119, 97, 112, 32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98,
  111, 111, 108, 32, 40, 84, 114, 117, 101, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 32,
  40, 34, 34, 83, 119, 97, 112, 34, 32, 99, 104, 97, 110, 103, 101, 32,
  116, 104, 101, 32, 101, 102, 102, 101, 99, 116, 32, 111, 102, 32, 77, 101,
  114, 103, 105, 110, 103, 32, 97, 110, 100, 32, 73, 110, 116, 101, 115, 105,
  116, 121, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 101,
  114, 103, 105, 110, 103, 32, 111, 112, 116, 105, 111, 110, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 32, 34, 72, 97, 114, 100, 32, 76, 105, 103,
  104, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 77, 101, 114, 103, 101,
  34, 44, 34, 77, 117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 67, 111,
  108, 111, 114, 32, 66, 117, 114, 110, 34, 44, 34, 79, 118, 101, 114, 108,
  97, 121, 34, 32, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 68, 97,
  114, 107, 101, 110, 34, 32, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115,
  115, 34, 44, 32, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 42, 67, 111, 108, 111, 114, 115, 32, 68, 111, 112, 105, 110, 103, 42,
  34, 44, 34, 67, 111, 109, 105, 120, 32, 67, 111, 108, 111, 114, 115, 34,
  32, 44, 34, 71, 114, 97, 112, 104, 105, 99, 32, 67, 111, 108, 111, 117,
  114, 115, 34, 44, 34, 71, 114, 97, 112, 104, 105, 120, 32, 67, 111, 108,
  111, 114, 115, 34, 44, 34, 86, 105, 118, 105, 100, 32, 69, 100, 103, 101,
  115, 42, 34, 44, 34, 68, 97, 114, 107, 32, 69, 100, 103, 101, 115, 34,
  44, 34, 68, 97, 114, 107, 32, 83, 99, 114, 101, 101, 110, 34, 44, 34,
  86, 105, 118, 105, 100, 32, 83, 99, 114, 101, 101, 110, 34, 44, 34, 73,
  110, 116, 101, 114, 112, 111, 108, 97, 116, 101, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 73, 110, 116, 101, 110, 115, 105, 116, 121, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 100, 100, 32, 112, 97, 105, 110, 116, 101, 114, 39,
  115, 32, 116, 111, 117, 99, 104, 32, 61, 32, 98, 111, 111, 108, 40, 116,
  114, 117, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 73, 102, 32, 117, 110,
  99, 104, 101, 99, 107, 101, 100, 32, 116, 104, 101, 32, 51, 32, 115, 108,
  105, 100, 101, 114, 115, 32, 98, 101, 108, 111, 119, 32, 97, 114, 101, 32,
  100, 105, 115, 97, 98, 108, 101, 100, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  80, 97, 105, 110, 116, 101, 114, 39, 115, 32, 116, 111, 117, 99, 104, 32,
  115, 104, 97, 114, 112, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 53, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 80, 97, 105, 110, 116, 101, 114, 39, 115, 32, 101, 100,
  103, 101, 32, 112, 114, 111, 116, 101, 99, 116, 105, 111, 110, 32, 102, 108,
  111, 119, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 52, 53, 44,
  48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97,
  105, 110, 116, 101, 114, 39, 115, 32, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 61, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 80, 104, 111,
  116, 111, 67, 111, 109, 105, 88, 60, 47, 105, 62, 46, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62,
  50, 48, 49, 49, 47, 49, 49, 47, 49, 51, 32, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40,
  34, 70, 105, 108, 116, 101, 114, 32, 101, 120, 112, 108, 97, 105, 110, 101,
  100, 32, 104, 101, 114, 101, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47,
  119, 119, 119, 46, 103, 105, 109, 112, 99, 104, 97, 116, 46, 99, 111, 109,
  47, 118, 105, 101, 119, 116, 111, 112, 105, 99, 46, 112, 104, 112, 63, 102,
  61, 57, 38, 116, 61, 55, 55, 53, 34, 41, 10, 103, 105, 109, 112, 95,
  103, 114, 97, 112, 104, 105, 99, 95, 98, 111, 111, 115, 116, 52, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116,
  121, 32, 45, 108, 91, 48, 93, 10, 45, 103, 105, 109, 112, 95, 117, 110,
  115, 104, 97, 114, 112, 32, 49, 44, 36, 49, 44, 51, 48, 44, 51, 44,
  48, 44, 36, 50, 44, 48, 46, 52, 48, 44, 49, 44, 48, 44, 48, 44,
  48, 10, 45, 105, 102, 32, 123, 36, 51, 61, 61, 49, 125, 32, 45, 98,
  114, 101, 97, 107, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 103, 105,
  109, 112, 95, 112, 101, 110, 99, 105, 108, 98, 119, 32, 36, 52, 44, 36,
  53, 44, 48, 44, 48, 44, 48, 10, 45, 105, 102, 32, 123, 36, 54, 61,
  61, 49, 125, 32, 45, 107, 101, 101, 112, 91, 45, 49, 93, 32, 45, 98,
  114, 101, 97, 107, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 55, 61, 61, 49, 125, 32, 45, 103, 105, 109, 112, 95, 97, 110,
  105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104,
  105, 110, 103, 91, 49, 93, 32, 54, 48, 44, 36, 56, 44, 36, 57, 44,
  36, 49, 48, 44, 49, 46, 49, 44, 48, 46, 56, 44, 51, 48, 44, 50,
  44, 48, 44, 49, 44, 49, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 49, 49, 61, 61, 49, 125, 32, 45, 107, 101,
  101, 112, 91, 45, 49, 93, 32, 45, 98, 114, 101, 97, 107, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 50, 61, 61, 49,
  125, 32, 32, 45, 114, 101, 118, 101, 114, 115, 101, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 51, 61, 61, 48, 125, 32,
  45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 104, 97,
  114, 100, 108, 105, 103, 104, 116, 32, 36, 49, 52, 44, 48, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 49, 51, 61, 61, 49, 125, 32, 45, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110,
  109, 101, 114, 103, 101, 32, 36, 49, 52, 44, 48, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 51, 61, 61, 50, 125, 32, 45, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108, 116, 105, 112, 108,
  121, 32, 36, 49, 52, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  49, 51, 61, 61, 51, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 99, 111, 108, 111, 114, 98, 117, 114, 110, 32, 36,
  49, 52, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 51, 61,
  61, 52, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 111, 118, 101, 114, 108, 97, 121, 32, 36, 49, 52, 44, 48, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 51, 61, 61, 53, 125, 32, 45,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 118, 97, 108,
  117, 101, 32, 36, 49, 52, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 51, 61, 61, 54, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101, 110, 32, 36, 49, 52,
  44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 51, 61, 61, 55,
  125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95,
  108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 36, 49, 52, 44, 49, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 51, 61, 61, 56, 125, 32, 45,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 108, 117, 109,
  105, 110, 97, 110, 99, 101, 32, 36, 49, 52, 44, 49, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 51, 61, 61, 57, 125, 32, 45, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 99, 111, 108, 111, 114, 100,
  111, 112, 105, 110, 103, 32, 36, 49, 52, 44, 48, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 51, 61, 61, 49, 48, 125, 32, 45, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 99, 111, 109, 105, 120, 95,
  99, 111, 108, 111, 114, 32, 36, 49, 52, 44, 48, 44, 36, 49, 53, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 51, 61, 61, 49, 49, 125, 32,
  45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114,
  97, 112, 104, 105, 99, 111, 108, 111, 114, 32, 36, 49, 52, 44, 48, 44,
  36, 49, 53, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 51, 61, 61,
  49, 50, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 103, 114, 97, 112, 104, 105, 120, 99, 111, 108, 111, 114, 32, 36,
  49, 52, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 51, 61,
  61, 49, 51, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 118, 105, 118, 105, 100, 101, 100, 103, 101, 115, 32, 36, 49,
  52, 44, 48, 46, 53, 48, 44, 48, 44, 36, 49, 53, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 51, 61, 61, 49, 52, 125, 32, 45, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101,
  100, 103, 101, 115, 32, 36, 49, 52, 44, 48, 46, 53, 48, 44, 48, 44,
  36, 49, 53, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 51, 61, 61,
  49, 53, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 118, 105, 118, 105, 100, 115, 99, 114, 101, 101, 110, 32, 36, 49,
  52, 44, 48, 44, 36, 49, 53, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  49, 51, 61, 61, 49, 54, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 115, 99, 114, 101, 101, 110,
  32, 36, 49, 52, 44, 48, 44, 36, 49, 53, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 51, 61, 61, 49, 55, 125, 32, 45, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 105, 110, 116, 101, 114, 112, 111,
  108, 97, 116, 105, 111, 110, 32, 36, 49, 52, 44, 48, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 54, 61, 61, 49, 125,
  32, 45, 103, 105, 109, 112, 95, 97, 110, 105, 115, 111, 116, 114, 111, 112,
  105, 99, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 32, 54, 48, 44,
  36, 49, 55, 44, 36, 49, 56, 44, 36, 49, 57, 44, 49, 46, 49, 44,
  48, 46, 56, 44, 51, 48, 44, 50, 44, 48, 44, 49, 44, 49, 44, 48,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 97,
  32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35,
  64, 103, 105, 109, 112, 32, 71, 114, 97, 112, 104, 105, 99, 32, 110, 111,
  118, 101, 108, 32, 58, 32, 103, 105, 109, 112, 95, 103, 114, 97, 112, 104,
  105, 99, 95, 110, 111, 118, 101, 108, 102, 120, 108, 44, 32, 103, 105, 109,
  112, 95, 103, 114, 97, 112, 104, 105, 99, 95, 110, 111, 118, 101, 108, 102,
  120, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 32, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 65, 112, 112, 108, 121, 32, 76, 111,
  99, 97, 108, 32, 78, 111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111,
  110, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 107, 105,
  112, 32, 116, 104, 105, 115, 32, 115, 116, 101, 112, 32, 61, 32, 98, 111,
  111, 108, 40, 102, 97, 108, 115, 101, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 32, 76, 111, 99,
  97, 108, 32, 78, 111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110,
  32, 67, 111, 110, 116, 114, 111, 108, 115, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 76, 110, 32, 97, 109, 112, 108, 105, 116, 105, 116,
  117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 44,
  54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 110, 32,
  115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 54, 44, 48,
  44, 54, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 110,
  32, 110, 101, 105, 103, 104, 116, 98, 111, 114, 104, 111, 111, 100, 45, 115,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 53, 44, 48, 44, 52, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 76, 110, 32, 97, 118, 101, 114, 97, 103, 101, 45, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 48, 44, 48, 44, 52, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 107,
  105, 112, 32, 97, 108, 108, 32, 111, 116, 104, 101, 114, 32, 115, 116, 101,
  112, 115, 32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108, 115, 101, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 32, 80, 101,
  110, 99, 105, 108, 32, 79, 112, 116, 105, 111, 110, 115, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 80, 101, 110, 99, 105, 108, 32, 115,
  105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 54, 50,
  44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80,
  101, 110, 99, 105, 108, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 52, 44, 48, 44, 50, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 107, 105, 112, 32, 97, 108, 108, 32, 111,
  116, 104, 101, 114, 32, 115, 116, 101, 112, 115, 32, 61, 32, 98, 111, 111,
  108, 40, 102, 97, 108, 115, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 99, 116, 105, 118, 97, 116, 101,
  32, 34, 112, 101, 110, 99, 105, 108, 32, 115, 109, 111, 111, 116, 104, 101,
  114, 34, 32, 61, 32, 98, 111, 111, 108, 40, 116, 114, 117, 101, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 32, 73, 102, 32, 117, 110, 99, 104, 101, 99,
  107, 101, 100, 32, 116, 104, 101, 32, 51, 32, 115, 108, 105, 100, 101, 114,
  115, 32, 98, 101, 108, 111, 119, 32, 97, 114, 101, 32, 100, 105, 115, 97,
  98, 108, 101, 100, 32, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 101, 110, 99,
  105, 108, 32, 115, 109, 111, 111, 116, 104, 101, 114, 32, 115, 104, 97, 114,
  112, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  53, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  80, 101, 110, 99, 105, 108, 32, 115, 109, 111, 111, 116, 104, 101, 114, 32,
  101, 100, 103, 101, 32, 112, 114, 111, 116, 101, 99, 116, 105, 111, 110, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 56, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 101, 110, 99, 105,
  108, 32, 115, 109, 111, 111, 116, 104, 101, 114, 32, 115, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46,
  57, 50, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 107, 105,
  112, 32, 97, 108, 108, 32, 111, 116, 104, 101, 114, 32, 115, 116, 101, 112,
  115, 32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108, 115, 101, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 32, 40, 34, 66, 111,
  111, 115, 116, 32, 77, 101, 114, 103, 105, 110, 103, 32, 79, 112, 116, 105,
  111, 110, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  119, 97, 112, 32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111,
  108, 32, 40, 102, 97, 108, 115, 101, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 77, 105, 120, 101, 114, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 79, 118, 101, 114, 108, 97, 121, 34, 44, 34, 77, 117, 108,
  116, 105, 112, 108, 121, 34, 44, 34, 83, 111, 102, 116, 32, 108, 105, 103,
  104, 116, 34, 44, 34, 67, 111, 108, 111, 114, 32, 66, 117, 114, 110, 34,
  44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 83, 116, 97, 109, 112,
  34, 44, 34, 72, 97, 114, 100, 32, 76, 105, 103, 104, 116, 34, 44, 34,
  86, 97, 108, 117, 101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 77, 101,
  114, 103, 101, 34, 44, 34, 70, 114, 101, 101, 122, 101, 34, 44, 34, 76,
  105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 32, 34, 76, 117, 109, 105,
  110, 97, 110, 99, 101, 34, 44, 34, 42, 67, 111, 108, 111, 114, 115, 32,
  68, 111, 112, 105, 110, 103, 34, 44, 34, 42, 67, 111, 109, 105, 120, 32,
  67, 111, 108, 111, 114, 115, 42, 34, 32, 44, 34, 71, 114, 97, 112, 104,
  105, 99, 32, 67, 111, 108, 111, 117, 114, 115, 34, 44, 34, 42, 71, 114,
  97, 112, 104, 105, 120, 32, 67, 111, 108, 111, 114, 115, 34, 44, 34, 42,
  86, 105, 118, 105, 100, 32, 69, 100, 103, 101, 115, 42, 34, 44, 34, 42,
  68, 97, 114, 107, 32, 69, 100, 103, 101, 115, 42, 34, 44, 34, 42, 68,
  97, 114, 107, 32, 83, 99, 114, 101, 101, 110, 42, 34, 44, 34, 42, 86,
  105, 118, 105, 100, 32, 83, 99, 114, 101, 101, 110, 42, 34, 44, 34, 73,
  110, 116, 101, 114, 112, 111, 108, 97, 116, 101, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 73, 110, 116, 101, 110, 115, 105, 116, 121, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 100, 100, 32, 112, 97, 105, 110, 116, 101, 114, 39,
  115, 32, 116, 111, 117, 99, 104, 32, 61, 32, 98, 111, 111, 108, 40, 116,
  114, 117, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 105, 110, 116, 101,
  114, 39, 115, 32, 116, 111, 117, 99, 104, 32, 115, 104, 97, 114, 112, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44,
  48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97,
  105, 110, 116, 101, 114, 39, 115, 32, 101, 100, 103, 101, 32, 112, 114, 111,
  116, 101, 99, 116, 105, 111, 110, 32, 102, 108, 111, 119, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 56, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 80, 97, 105, 110, 116, 101, 114, 39, 115,
  32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 102, 108, 111,
  97, 116, 40, 49, 46, 50, 56, 44, 48, 44, 49, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 58, 32, 60, 105, 62, 80, 104, 111, 116, 111, 67, 111,
  109, 105, 88, 60, 47, 105, 62, 46, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 49,
  47, 49, 49, 47, 49, 51, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 70, 105, 108, 116,
  101, 114, 32, 101, 120, 112, 108, 97, 105, 110, 101, 100, 32, 104, 101, 114,
  101, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 103,
  105, 109, 112, 99, 104, 97, 116, 46, 99, 111, 109, 47, 118, 105, 101, 119,
  116, 111, 112, 105, 99, 46, 112, 104, 112, 63, 102, 61, 57, 38, 116, 61,
  49, 53, 56, 50, 34, 41, 10, 103, 105, 109, 112, 95, 103, 114, 97, 112,
  104, 105, 99, 95, 110, 111, 118, 101, 108, 102, 120, 108, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32,
  45, 108, 91, 48, 93, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48,
  125, 32, 45, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97, 108, 105, 122,
  101, 95, 108, 111, 99, 97, 108, 32, 36, 50, 44, 36, 51, 44, 36, 52,
  44, 36, 53, 44, 49, 44, 51, 44, 48, 32, 45, 101, 108, 105, 102, 32,
  123, 36, 49, 61, 61, 49, 125, 32, 45, 103, 105, 109, 112, 95, 100, 111,
  95, 110, 111, 116, 104, 105, 110, 103, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 54, 61, 61, 48, 125, 32, 45, 45, 103, 105,
  109, 112, 95, 112, 101, 110, 99, 105, 108, 98, 119, 32, 36, 55, 44, 36,
  56, 44, 48, 44, 48, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 57, 61, 61, 49, 125, 32, 45, 107, 101, 101, 112,
  91, 45, 49, 93, 32, 45, 98, 114, 101, 97, 107, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 48, 61, 61, 49, 125, 32,
  45, 103, 105, 109, 112, 95, 97, 110, 105, 115, 111, 116, 114, 111, 112, 105,
  99, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 32,
  54, 48, 44, 36, 49, 49, 44, 36, 49, 50, 44, 36, 49, 51, 44, 49,
  46, 49, 44, 48, 46, 56, 44, 51, 48, 44, 50, 44, 48, 44, 49, 44,
  49, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 49, 52, 61, 61, 49, 125, 32, 45, 107, 101, 101, 112, 91, 45, 49,
  93, 32, 45, 98, 114, 101, 97, 107, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 49, 53, 61, 61, 49, 125, 32, 45, 114, 101,
  118, 101, 114, 115, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 49, 54, 61, 61, 48, 125, 32, 45, 103, 105, 109, 112, 95,
  99, 111, 109, 112, 111, 115, 101, 95, 111, 118, 101, 114, 108, 97, 121, 32,
  36, 49, 55, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 54,
  61, 61, 49, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 109, 117, 108, 116, 105, 112, 108, 121, 32, 36, 49, 55, 44,
  48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 54, 61, 61, 50, 125,
  32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 115,
  111, 102, 116, 108, 105, 103, 104, 116, 32, 36, 49, 55, 44, 48, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 49, 54, 61, 61, 51, 125, 32, 45, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 99, 111, 108, 111,
  114, 98, 117, 114, 110, 32, 36, 49, 55, 44, 48, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 54, 61, 61, 52, 125, 32, 45, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101, 110, 32,
  36, 49, 55, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 54,
  61, 61, 53, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 115, 116, 97, 109, 112, 32, 36, 49, 55, 44, 48, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 49, 54, 61, 61, 54, 125, 32, 45, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 104, 97, 114, 100,
  108, 105, 103, 104, 116, 32, 36, 49, 55, 44, 48, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 54, 61, 61, 55, 125, 32, 45, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 118, 97, 108, 117, 101, 32, 36,
  49, 55, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 54, 61,
  61, 56, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 32, 36, 49, 55,
  44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 54, 61, 61, 57,
  125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95,
  102, 114, 101, 101, 122, 101, 32, 36, 49, 55, 44, 48, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 54, 61, 61, 49, 48, 125, 32, 45, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103, 104, 116,
  110, 101, 115, 115, 32, 36, 49, 55, 44, 49, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 54, 61, 61, 49, 49, 125, 32, 45, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 108, 117, 109, 105, 110, 97, 110,
  99, 101, 32, 36, 49, 55, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 54, 61, 61, 49, 50, 125, 32, 45, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 99, 111, 108, 111, 114, 100, 111, 112, 105,
  110, 103, 32, 36, 49, 55, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 54, 61, 61, 49, 51, 125, 32, 45, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 99, 111, 109, 105, 120, 95, 99, 111, 108,
  111, 114, 32, 36, 49, 55, 44, 48, 44, 36, 49, 56, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 54, 61, 61, 49, 52, 125, 32, 45, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 112, 104,
  105, 99, 111, 108, 111, 114, 32, 36, 49, 55, 44, 48, 44, 36, 49, 56,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 54, 61, 61, 49, 53, 125,
  32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 103,
  114, 97, 112, 104, 105, 120, 99, 111, 108, 111, 114, 32, 36, 49, 55, 44,
  48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 54, 61, 61, 49, 54,
  125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95,
  118, 105, 118, 105, 100, 101, 100, 103, 101, 115, 32, 36, 49, 55, 44, 48,
  46, 53, 48, 44, 48, 44, 36, 49, 56, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 49, 54, 61, 61, 49, 55, 125, 32, 45, 103, 105, 109, 112, 95,
  99, 111, 109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101, 100, 103, 101,
  115, 32, 36, 49, 55, 44, 48, 46, 53, 48, 44, 48, 44, 36, 49, 56,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 54, 61, 61, 49, 56, 125,
  32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 118,
  105, 118, 105, 100, 115, 99, 114, 101, 101, 110, 32, 36, 49, 55, 44, 48,
  44, 36, 49, 56, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 54, 61,
  61, 49, 57, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 100, 97, 114, 107, 115, 99, 114, 101, 101, 110, 32, 36, 49,
  55, 44, 48, 44, 36, 49, 56, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  49, 54, 61, 61, 50, 48, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116,
  105, 111, 110, 32, 36, 49, 55, 44, 48, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 49, 57, 61, 61, 49, 125, 32, 45, 103,
  105, 109, 112, 95, 97, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 95,
  115, 109, 111, 111, 116, 104, 105, 110, 103, 32, 54, 48, 44, 36, 50, 48,
  44, 36, 50, 49, 44, 36, 50, 50, 44, 49, 46, 49, 44, 48, 46, 56,
  44, 51, 48, 44, 50, 44, 48, 44, 49, 44, 49, 44, 48, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105,
  109, 112, 32, 72, 111, 112, 101, 32, 112, 111, 115, 116, 101, 114, 32, 58,
  32, 103, 105, 109, 112, 95, 112, 111, 115, 116, 101, 114, 95, 104, 111, 112,
  101, 44, 32, 103, 105, 109, 112, 95, 112, 111, 115, 116, 101, 114, 95, 104,
  111, 112, 101, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 71, 97, 109, 109, 97, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 45, 51, 44, 51, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44, 48, 44, 50, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117,
  112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  115, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104,
  117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 49, 49,
  47, 48, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 103, 105, 109, 112, 95, 112, 111, 115, 116, 101, 114, 95, 104,
  111, 112, 101, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 103, 97, 109,
  109, 97, 32, 123, 49, 48, 94, 36, 49, 125, 32, 45, 112, 111, 115, 116,
  101, 114, 95, 104, 111, 112, 101, 32, 36, 50, 10, 103, 105, 109, 112, 95,
  112, 111, 115, 116, 101, 114, 95, 104, 111, 112, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112,
  95, 112, 111, 115, 116, 101, 114, 95, 104, 111, 112, 101, 32, 36, 42, 34,
  44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 75, 117, 119, 97,
  104, 97, 114, 97, 32, 58, 32, 103, 105, 109, 112, 95, 107, 117, 119, 97,
  104, 97, 114, 97, 44, 32, 103, 105, 109, 112, 95, 107, 117, 119, 97, 104,
  97, 114, 97, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101, 114, 97, 116, 105, 111,
  110, 115, 32, 61, 32, 105, 110, 116, 40, 50, 44, 49, 44, 50, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 100, 105, 117, 115,
  32, 61, 32, 105, 110, 116, 40, 53, 44, 49, 44, 51, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40,
  115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108,
  34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34,
  76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101,
  47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101,
  115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111,
  110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34,
  44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34,
  66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105,
  99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60,
  105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101,
  114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48, 53, 47, 51, 49, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103,
  105, 109, 112, 95, 107, 117, 119, 97, 104, 97, 114, 97, 32, 58, 10, 45,
  97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34,
  45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 32, 45, 107, 117, 119, 97,
  104, 97, 114, 97, 32, 36, 50, 32, 45, 100, 111, 110, 101, 34, 44, 36,
  51, 44, 48, 10, 103, 105, 109, 112, 95, 107, 117, 119, 97, 104, 97, 114,
  97, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 107, 117, 119, 97, 104, 97, 114, 97, 32,
  36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 76,
  121, 108, 101, 106, 107, 39, 115, 32, 112, 97, 105, 110, 116, 105, 110, 103,
  32, 58, 32, 103, 105, 109, 112, 95, 108, 121, 108, 101, 106, 107, 95, 112,
  97, 105, 110, 116, 105, 110, 103, 44, 32, 103, 105, 109, 112, 95, 108, 121,
  108, 101, 106, 107, 95, 112, 97, 105, 110, 116, 105, 110, 103, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105,
  110, 116, 40, 50, 44, 49, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 82, 97, 100, 105, 117, 115, 32, 61, 32, 105, 110, 116,
  40, 52, 44, 49, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 97, 110, 118, 97, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117,
  108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117,
  112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 115, 58, 32, 60, 105, 62, 76,
  121, 108, 101, 32, 75, 114, 111, 108, 108, 44, 32, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 49, 47, 48, 57, 47, 50, 49, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 70, 105,
  108, 116, 101, 114, 32, 69, 120, 112, 108, 97, 105, 110, 101, 100, 32, 104,
  101, 114, 101, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119,
  46, 103, 105, 109, 112, 99, 104, 97, 116, 46, 99, 111, 109, 47, 118, 105,
  101, 119, 116, 111, 112, 105, 99, 46, 112, 104, 112, 63, 102, 61, 49, 48,
  38, 116, 61, 50, 54, 50, 52, 34, 41, 10, 103, 105, 109, 112, 95, 108,
  121, 108, 101, 106, 107, 95, 112, 97, 105, 110, 116, 105, 110, 103, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 45, 95, 103,
  105, 109, 112, 95, 108, 121, 108, 101, 106, 107, 95, 112, 97, 105, 110, 116,
  105, 110, 103, 91, 45, 49, 93, 32, 49, 48, 44, 49, 48, 46, 52, 57,
  44, 48, 46, 55, 53, 44, 48, 10, 45, 115, 109, 111, 111, 116, 104, 91,
  45, 49, 93, 32, 51, 48, 48, 44, 48, 46, 50, 54, 44, 49, 44, 48,
  44, 55, 32, 45, 115, 104, 97, 114, 112, 101, 110, 91, 45, 49, 93, 32,
  36, 51, 10, 91, 45, 49, 93, 32, 45, 114, 118, 91, 45, 51, 45, 45,
  49, 93, 10, 45, 98, 108, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93,
  32, 108, 105, 103, 104, 116, 101, 110, 44, 48, 46, 53, 10, 45, 98, 108,
  101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 103, 114, 97, 105, 110,
  109, 101, 114, 103, 101, 44, 49, 10, 45, 103, 105, 109, 112, 95, 107, 117,
  119, 97, 104, 97, 114, 97, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50,
  44, 48, 10, 45, 116, 101, 120, 116, 117, 114, 105, 122, 101, 95, 99, 97,
  110, 118, 97, 115, 91, 45, 49, 93, 32, 36, 51, 44, 52, 10, 45, 109,
  118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 103, 105,
  109, 112, 95, 108, 121, 108, 101, 106, 107, 95, 112, 97, 105, 110, 116, 105,
  110, 103, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 108, 121, 108, 101, 106, 107, 95, 112,
  97, 105, 110, 116, 105, 110, 103, 32, 36, 42, 34, 44, 36, 45, 49, 10,
  95, 103, 105, 109, 112, 95, 108, 121, 108, 101, 106, 107, 95, 112, 97, 105,
  110, 116, 105, 110, 103, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 114, 101, 112, 101, 97, 116,
  32, 36, 49, 32, 45, 98, 32, 36, 51, 32, 45, 117, 110, 115, 104, 97,
  114, 112, 32, 36, 51, 44, 36, 50, 32, 45, 99, 32, 48, 44, 50, 53,
  53, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110,
  101, 34, 44, 36, 52, 44, 48, 10, 35, 64, 103, 105, 109, 112, 32, 77,
  97, 107, 101, 32, 115, 113, 117, 105, 103, 103, 108, 121, 32, 58, 32, 103,
  105, 109, 112, 95, 83, 113, 117, 105, 103, 103, 108, 121, 44, 32, 103, 105,
  109, 112, 95, 83, 113, 117, 105, 103, 103, 108, 121, 95, 80, 114, 101, 118,
  105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 83, 113, 117,
  105, 103, 108, 101, 115, 32, 97, 110, 32, 105, 109, 97, 103, 101, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 83, 113, 117, 105, 103, 108, 101, 32, 112,
  97, 114, 97, 109, 101, 116, 101, 114, 115, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 112, 114, 101, 97, 100, 32, 110, 111, 105, 115,
  101, 32, 97, 109, 111, 117, 110, 116, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111, 110, 32, 101,
  100, 103, 101, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 50, 44, 48, 44, 49, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 103, 109, 101, 110, 116, 97,
  116, 105, 111, 110, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 56, 44, 48, 44, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 97, 100, 105, 101,
  110, 110, 111, 114, 109, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 97, 100, 105, 101, 110,
  110, 111, 114, 109, 108, 105, 110, 101, 97, 114, 105, 116, 121, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 46, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 118, 101, 114, 116,
  32, 108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 61, 32, 98, 111, 111,
  108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 98, 62, 79, 112, 116, 105, 111, 110, 97, 108, 32, 99, 111, 108,
  111, 114, 32, 101, 110, 104, 97, 110, 99, 101, 109, 101, 110, 116, 60, 47,
  98, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 78, 111, 116, 101, 32,
  116, 104, 97, 116, 32, 116, 104, 101, 32, 101, 102, 102, 101, 99, 116, 32,
  111, 102, 32, 115, 108, 105, 100, 101, 114, 115, 32, 100, 101, 112, 101, 110,
  100, 115, 32, 111, 110, 32, 116, 104, 101, 32, 109, 101, 114, 103, 101, 32,
  115, 101, 116, 116, 105, 110, 103, 46, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 99, 116, 105, 118, 97, 116, 101, 32, 99, 111, 108,
  111, 114, 32, 101, 110, 104, 97, 110, 99, 101, 109, 101, 110, 116, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 84, 111, 103, 103, 108, 101, 32, 116, 111, 32, 118, 105, 101, 119,
  32, 98, 97, 115, 101, 32, 105, 109, 97, 103, 101, 32, 61, 32, 98, 111,
  111, 108, 40, 48, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 67, 104, 101, 99, 107, 32, 116, 104, 105, 115, 32, 116,
  111, 32, 118, 105, 101, 119, 32, 98, 97, 115, 101, 32, 105, 109, 97, 103,
  101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 99,
  114, 101, 97, 115, 101, 99, 104, 114, 111, 109, 97, 49, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 51, 44, 49, 44, 52, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 84, 111, 110, 101, 32, 116, 104, 114, 101, 115, 104,
  111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 50, 44,
  48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 111,
  110, 101, 32, 103, 97, 109, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 52, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  83, 101, 108, 101, 99, 116, 32, 109, 101, 114, 103, 105, 110, 103, 32, 109,
  111, 100, 101, 32, 116, 111, 32, 111, 114, 105, 103, 105, 110, 97, 108, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 101, 114, 103, 105,
  110, 103, 32, 111, 112, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 65, 108, 112, 104, 97, 34, 44, 34, 65, 110, 100, 34,
  44, 34, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 66, 117, 114, 110,
  34, 44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 68, 105, 102, 102,
  101, 114, 101, 110, 99, 101, 34, 44, 34, 68, 105, 118, 105, 100, 101, 34,
  44, 34, 68, 111, 100, 103, 101, 34, 44, 34, 69, 120, 99, 108, 117, 115,
  105, 111, 110, 34, 44, 34, 70, 114, 101, 101, 122, 101, 34, 44, 34, 71,
  114, 97, 105, 110, 32, 101, 120, 116, 114, 97, 99, 116, 34, 44, 34, 71,
  114, 97, 105, 110, 32, 109, 101, 114, 103, 101, 34, 44, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 34, 72, 97, 114, 100, 32, 108, 105, 103, 104,
  116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 73, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 105, 111, 110, 34, 44, 34, 76, 105, 103, 104, 116, 101,
  110, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34,
  76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 77, 117, 108, 116,
  105, 112, 108, 121, 34, 44, 34, 78, 101, 103, 97, 116, 105, 111, 110, 34,
  44, 34, 79, 114, 34, 44, 34, 79, 118, 101, 114, 108, 97, 121, 34, 44,
  34, 82, 101, 102, 108, 101, 99, 116, 34, 44, 34, 83, 97, 116, 117, 114,
  97, 116, 105, 111, 110, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 34, 83, 111, 102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83,
  99, 114, 101, 101, 110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34,
  86, 97, 108, 117, 101, 34, 44, 34, 88, 111, 114, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 115, 101, 32, 111,
  114, 100, 101, 114, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121,
  112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60,
  105, 62, 65, 114, 116, 111, 32, 72, 117, 111, 116, 97, 114, 105, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51,
  47, 48, 57, 47, 50, 56, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 70, 105, 108, 116,
  101, 114, 32, 69, 120, 112, 108, 97, 105, 110, 101, 100, 32, 104, 101, 114,
  101, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 102,
  108, 105, 99, 107, 114, 46, 99, 111, 109, 47, 112, 104, 111, 116, 111, 115,
  47, 110, 97, 103, 103, 111, 98, 111, 116, 47, 54, 54, 54, 55, 54, 55,
  51, 56, 52, 55, 47, 34, 41, 10, 103, 105, 109, 112, 95, 83, 113, 117,
  105, 103, 103, 108, 121, 32, 58, 10, 83, 112, 114, 101, 97, 100, 78, 111,
  105, 115, 101, 65, 109, 111, 117, 110, 116, 61, 36, 49, 10, 83, 69, 103,
  84, 104, 114, 115, 104, 108, 100, 61, 36, 50, 10, 83, 101, 103, 83, 109,
  111, 111, 116, 104, 61, 36, 51, 10, 71, 78, 83, 109, 111, 111, 116, 104,
  61, 36, 52, 10, 71, 78, 76, 105, 110, 61, 36, 53, 10, 73, 110, 118,
  101, 114, 116, 76, 117, 109, 105, 110, 97, 110, 99, 101, 61, 36, 54, 10,
  69, 110, 104, 97, 110, 99, 101, 67, 111, 108, 111, 114, 115, 61, 36, 55,
  10, 84, 111, 103, 103, 108, 101, 79, 114, 103, 61, 36, 56, 10, 67, 104,
  114, 111, 109, 97, 61, 36, 57, 10, 84, 111, 110, 101, 84, 114, 61, 36,
  49, 48, 10, 84, 111, 110, 101, 71, 109, 61, 36, 49, 49, 10, 79, 114,
  103, 77, 101, 114, 103, 101, 67, 104, 61, 36, 49, 50, 10, 79, 114, 103,
  79, 112, 97, 99, 105, 116, 121, 61, 36, 49, 51, 10, 79, 114, 103, 82,
  101, 118, 101, 114, 115, 101, 111, 114, 100, 101, 114, 61, 36, 49, 52, 10,
  45, 105, 102, 32, 123, 36, 84, 111, 103, 103, 108, 101, 79, 114, 103, 61,
  61, 49, 125, 10, 79, 114, 103, 77, 101, 114, 103, 101, 67, 104, 61, 51,
  48, 10, 79, 114, 103, 82, 101, 118, 101, 114, 115, 101, 111, 114, 100, 101,
  114, 61, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 114,
  103, 98, 10, 45, 45, 103, 105, 109, 112, 95, 115, 112, 114, 101, 97, 100,
  91, 48, 93, 32, 36, 83, 112, 114, 101, 97, 100, 78, 111, 105, 115, 101,
  65, 109, 111, 117, 110, 116, 44, 36, 83, 112, 114, 101, 97, 100, 78, 111,
  105, 115, 101, 65, 109, 111, 117, 110, 116, 44, 48, 44, 48, 10, 45, 103,
  105, 109, 112, 95, 115, 101, 103, 109, 101, 110, 116, 95, 119, 97, 116, 101,
  114, 115, 104, 101, 100, 91, 49, 93, 32, 36, 83, 69, 103, 84, 104, 114,
  115, 104, 108, 100, 44, 36, 83, 101, 103, 83, 109, 111, 111, 116, 104, 44,
  48, 44, 48, 10, 45, 45, 103, 105, 109, 112, 95, 103, 114, 97, 100, 105,
  101, 110, 116, 95, 110, 111, 114, 109, 91, 49, 93, 32, 36, 71, 78, 83,
  109, 111, 111, 116, 104, 44, 36, 71, 78, 76, 105, 110, 44, 48, 44, 49,
  48, 48, 44, 48, 44, 48, 10, 45, 45, 98, 108, 101, 110, 100, 91, 50,
  44, 49, 93, 32, 109, 117, 108, 116, 105, 112, 108, 121, 10, 45, 105, 102,
  32, 123, 36, 73, 110, 118, 101, 114, 116, 76, 117, 109, 105, 110, 97, 110,
  99, 101, 61, 61, 49, 125, 10, 35, 67, 111, 110, 118, 101, 114, 116, 32,
  116, 111, 32, 76, 65, 66, 10, 45, 114, 103, 98, 50, 108, 97, 98, 91,
  45, 49, 93, 10, 35, 83, 112, 108, 105, 116, 32, 99, 104, 97, 110, 110,
  101, 108, 115, 10, 45, 115, 112, 108, 105, 116, 91, 45, 49, 93, 32, 99,
  10, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 51, 93, 10, 45,
  97, 112, 112, 101, 110, 100, 91, 45, 51, 45, 45, 49, 93, 32, 99, 10,
  45, 108, 97, 98, 50, 114, 103, 98, 91, 45, 49, 93, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 69, 110, 104, 97, 110, 99,
  101, 67, 111, 108, 111, 114, 115, 61, 61, 49, 125, 10, 35, 73, 110, 99,
  114, 101, 97, 115, 101, 32, 99, 104, 114, 111, 109, 97, 10, 45, 103, 105,
  109, 112, 95, 109, 105, 120, 95, 121, 99, 98, 99, 114, 91, 51, 93, 32,
  49, 44, 48, 44, 48, 44, 36, 67, 104, 114, 111, 109, 97, 44, 48, 44,
  48, 44, 36, 67, 104, 114, 111, 109, 97, 44, 48, 44, 48, 44, 48, 44,
  50, 44, 48, 10, 35, 84, 111, 110, 101, 109, 97, 112, 32, 111, 114, 105,
  103, 105, 110, 97, 108, 10, 45, 103, 105, 109, 112, 95, 109, 97, 112, 95,
  116, 111, 110, 101, 115, 91, 48, 93, 32, 36, 84, 111, 110, 101, 84, 114,
  44, 36, 84, 111, 110, 101, 71, 109, 44, 48, 46, 49, 44, 51, 48, 44,
  48, 44, 48, 10, 35, 45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121,
  95, 99, 117, 114, 118, 101, 91, 48, 93, 32, 48, 44, 51, 48, 44, 49,
  50, 56, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50, 56,
  44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50, 56, 44, 50,
  53, 53, 44, 49, 44, 51, 44, 48, 44, 48, 44, 48, 10, 35, 67, 111,
  109, 112, 111, 115, 101, 32, 83, 113, 117, 105, 103, 103, 108, 105, 101, 115,
  32, 116, 111, 32, 111, 114, 105, 103, 105, 110, 97, 108, 10, 45, 103, 105,
  109, 112, 95, 98, 108, 101, 110, 100, 91, 48, 44, 51, 93, 32, 36, 79,
  114, 103, 77, 101, 114, 103, 101, 67, 104, 44, 36, 79, 114, 103, 79, 112,
  97, 99, 105, 116, 121, 44, 36, 79, 114, 103, 82, 101, 118, 101, 114, 115,
  101, 111, 114, 100, 101, 114, 10, 45, 107, 101, 101, 112, 91, 48, 93, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93,
  10, 103, 105, 109, 112, 95, 83, 113, 117, 105, 103, 103, 108, 121, 95, 80,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115,
  112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103,
  105, 109, 112, 95, 83, 113, 117, 105, 103, 103, 108, 121, 32, 36, 123, 49,
  45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112,
  32, 77, 111, 114, 112, 104, 111, 108, 111, 103, 121, 32, 112, 97, 105, 110,
  116, 105, 110, 103, 32, 58, 32, 103, 105, 109, 112, 95, 77, 111, 114, 112,
  104, 111, 80, 97, 105, 110, 116, 44, 32, 103, 105, 109, 112, 95, 77, 111,
  114, 112, 104, 111, 80, 97, 105, 110, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 67, 114, 101, 97, 116, 101, 115, 32, 97, 32,
  112, 97, 105, 110, 116, 105, 110, 103, 32, 117, 115, 105, 110, 103, 32, 77,
  111, 114, 112, 104, 111, 108, 111, 103, 121, 45, 44, 32, 83, 101, 103, 109,
  101, 110, 116, 97, 116, 105, 111, 110, 45, 32, 97, 110, 100, 32, 80, 97,
  105, 110, 116, 105, 110, 103, 45, 32, 102, 105, 108, 116, 101, 114, 115, 46,
  32, 67, 80, 85, 32, 105, 110, 116, 101, 110, 115, 105, 118, 101, 32, 102,
  105, 108, 116, 101, 114, 32, 116, 104, 97, 116, 32, 109, 97, 121, 32, 116,
  97, 107, 101, 32, 108, 111, 110, 103, 46, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 77, 111, 114,
  112, 104, 111, 108, 111, 103, 121, 32, 115, 101, 116, 116, 105, 110, 103, 115,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 77, 101, 116, 104, 111, 100, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 69, 114, 111, 115, 105, 111,
  110, 34, 44, 34, 68, 105, 108, 97, 116, 105, 111, 110, 34, 44, 34, 79,
  112, 101, 110, 105, 110, 103, 34, 44, 34, 67, 108, 111, 115, 105, 110, 103,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 114, 112,
  104, 111, 115, 116, 114, 101, 110, 103, 104, 116, 32, 61, 32, 105, 110, 116,
  40, 49, 56, 44, 50, 44, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 104, 97, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 50, 44, 34, 83, 113, 117, 97, 114, 101, 34, 44, 34, 79, 99,
  116, 97, 103, 111, 110, 97, 108, 34, 44, 34, 67, 105, 114, 99, 117, 108,
  97, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 32,
  102, 111, 114, 32, 77, 111, 114, 112, 104, 111, 108, 97, 121, 101, 114, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 97, 99, 107,
  32, 112, 111, 105, 110, 116, 32, 61, 32, 105, 110, 116, 40, 50, 53, 44,
  48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69,
  120, 112, 97, 110, 100, 32, 115, 104, 97, 100, 111, 119, 115, 32, 61, 32,
  105, 110, 116, 40, 49, 48, 48, 44, 53, 48, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 109, 112, 114, 101, 115,
  115, 32, 104, 105, 103, 104, 108, 105, 103, 104, 116, 115, 32, 61, 32, 105,
  110, 116, 40, 50, 51, 48, 44, 50, 48, 48, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 83, 109, 111, 111, 116, 104, 105, 110, 103, 32, 115, 116, 114, 101, 110,
  103, 116, 104, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  112, 114, 101, 97, 100, 32, 97, 109, 111, 117, 110, 116, 32, 61, 32, 105,
  110, 116, 40, 56, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 66, 108, 117, 114, 114, 32, 115, 116, 114, 101, 110, 103,
  116, 104, 32, 61, 32, 105, 110, 116, 40, 51, 44, 48, 44, 49, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 83, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111, 110, 32, 115,
  101, 116, 116, 105, 110, 103, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 69, 100, 103, 101, 32, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 44, 48, 44, 49, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  53, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 80, 97, 105, 110, 116, 105, 110, 103,
  32, 83, 101, 116, 116, 105, 110, 103, 115, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110,
  32, 61, 32, 105, 110, 116, 40, 50, 44, 49, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 116, 97, 105, 108, 115, 32,
  115, 99, 97, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  53, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 50, 48, 48, 44, 48, 44, 49, 48, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 77, 101, 114, 103, 101, 32, 108, 97, 121, 101, 114, 115, 63,
  32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 87, 104, 101, 110, 32, 117, 110, 99, 104, 101, 99, 107, 101, 100, 32,
  116, 104, 101, 32, 102, 105, 108, 116, 101, 114, 32, 119, 105, 108, 108, 32,
  111, 117, 116, 112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 32, 115, 101,
  112, 97, 114, 97, 116, 101, 108, 121, 32, 102, 111, 114, 32, 109, 97, 110,
  117, 97, 108, 32, 99, 111, 109, 112, 111, 115, 105, 110, 103, 46, 32, 83,
  101, 116, 32, 71, 39, 77, 105, 99, 32, 111, 117, 116, 112, 117, 116, 32,
  116, 111, 32, 110, 101, 119, 32, 108, 97, 121, 101, 114, 115, 46, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 69, 110, 97, 98, 108, 101, 32, 112, 97, 105, 110,
  116, 115, 116, 114, 111, 107, 101, 32, 61, 32, 98, 111, 111, 108, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 116, 114, 111, 107,
  101, 32, 115, 116, 114, 101, 110, 103, 116, 104, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 69, 110, 97, 98, 108, 101, 32, 115, 101, 103, 109, 101, 110,
  116, 97, 116, 105, 111, 110, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 103, 109, 101, 110,
  116, 115, 32, 115, 116, 114, 101, 110, 103, 116, 104, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 69, 110, 97, 98, 108, 101, 32, 109, 111, 114, 112, 104,
  111, 108, 111, 103, 121, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 114, 112, 104, 111, 108,
  111, 103, 121, 32, 115, 116, 114, 101, 110, 103, 116, 104, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 114, 109, 97, 108, 105, 122, 101, 32, 61,
  32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105,
  62, 65, 114, 116, 111, 32, 72, 117, 111, 116, 97, 114, 105, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47,
  48, 57, 47, 50, 56, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 70, 105, 108, 116, 101,
  114, 32, 69, 120, 112, 108, 97, 105, 110, 101, 100, 32, 104, 101, 114, 101,
  34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 102, 108,
  105, 99, 107, 114, 46, 99, 111, 109, 47, 112, 104, 111, 116, 111, 115, 47,
  110, 97, 103, 103, 111, 98, 111, 116, 47, 54, 49, 48, 56, 54, 51, 55,
  57, 51, 53, 47, 34, 41, 10, 103, 105, 109, 112, 95, 77, 111, 114, 112,
  104, 111, 80, 97, 105, 110, 116, 32, 58, 10, 45, 116, 111, 95, 114, 103,
  98, 91, 48, 93, 10, 45, 45, 103, 105, 109, 112, 95, 109, 111, 114, 112,
  104, 111, 91, 48, 93, 32, 36, 49, 44, 36, 50, 44, 48, 44, 50, 44,
  48, 44, 36, 51, 44, 48, 10, 45, 45, 103, 105, 109, 112, 95, 97, 112,
  112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 49, 93, 32, 36, 52, 44,
  53, 48, 44, 36, 53, 44, 50, 48, 48, 44, 36, 54, 44, 45, 49, 44,
  49, 50, 56, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50,
  56, 44, 50, 53, 53, 44, 49, 44, 51, 44, 48, 44, 48, 44, 48, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 114, 101, 97, 100, 91, 49, 93, 32,
  36, 55, 44, 36, 55, 44, 48, 44, 48, 10, 45, 103, 105, 109, 112, 95,
  103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 50, 93,
  32, 36, 56, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 10,
  45, 103, 105, 109, 112, 95, 115, 101, 103, 109, 101, 110, 116, 95, 119, 97,
  116, 101, 114, 115, 104, 101, 100, 91, 49, 93, 32, 36, 57, 44, 36, 49,
  48, 44, 48, 44, 48, 10, 45, 45, 103, 105, 109, 112, 95, 112, 97, 105,
  110, 116, 105, 110, 103, 91, 48, 93, 32, 36, 49, 49, 44, 36, 49, 50,
  44, 49, 46, 53, 44, 36, 49, 51, 44, 49, 44, 48, 10, 45, 114, 101,
  109, 111, 118, 101, 91, 48, 93, 10, 45, 114, 101, 118, 101, 114, 115, 101,
  91, 48, 44, 50, 93, 10, 45, 114, 101, 118, 101, 114, 115, 101, 91, 49,
  44, 50, 93, 10, 45, 105, 102, 32, 36, 49, 52, 10, 45, 105, 102, 32,
  123, 36, 49, 57, 61, 61, 48, 125, 32, 77, 111, 114, 112, 104, 111, 83,
  116, 114, 101, 110, 103, 116, 104, 61, 123, 48, 125, 32, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 57, 61, 61, 49, 125, 32, 77, 111, 114, 112, 104,
  111, 83, 116, 114, 101, 110, 103, 116, 104, 61, 123, 36, 50, 48, 125, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 109, 117, 108, 91, 50, 93, 32, 123,
  36, 77, 111, 114, 112, 104, 111, 83, 116, 114, 101, 110, 103, 116, 104, 47,
  51, 125, 10, 45, 105, 102, 32, 123, 36, 49, 53, 61, 61, 48, 125, 32,
  83, 116, 114, 111, 107, 101, 83, 116, 114, 101, 110, 103, 116, 104, 61, 123,
  48, 125, 32, 45, 101, 108, 105, 102, 32, 123, 36, 49, 53, 61, 61, 49,
  125, 32, 83, 116, 114, 111, 107, 101, 83, 116, 114, 101, 110, 103, 116, 104,
  61, 123, 36, 49, 54, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 109,
  117, 108, 91, 48, 93, 32, 123, 36, 83, 116, 114, 111, 107, 101, 83, 116,
  114, 101, 110, 103, 116, 104, 47, 51, 125, 10, 45, 105, 102, 32, 123, 36,
  49, 55, 61, 61, 48, 125, 32, 83, 101, 103, 109, 101, 110, 116, 83, 116,
  114, 101, 110, 103, 116, 104, 61, 123, 48, 125, 32, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 55, 61, 61, 49, 125, 32, 83, 101, 103, 109, 101, 110,
  116, 83, 116, 114, 101, 110, 103, 116, 104, 61, 123, 36, 49, 56, 125, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 109, 117, 108, 91, 49, 93, 32, 123,
  36, 83, 101, 103, 109, 101, 110, 116, 83, 116, 114, 101, 110, 103, 116, 104,
  47, 51, 125, 10, 45, 97, 100, 100, 91, 49, 93, 32, 91, 50, 93, 10,
  45, 97, 100, 100, 91, 49, 93, 32, 91, 48, 93, 10, 45, 105, 102, 32,
  36, 50, 49, 32, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 91, 49,
  93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 101, 109, 111, 118, 101, 91, 48, 44, 50, 93, 10, 45, 101, 110, 100,
  105, 102, 10, 103, 105, 109, 112, 95, 77, 111, 114, 112, 104, 111, 80, 97,
  105, 110, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 103, 105, 109, 112, 95, 77, 111, 114, 112, 104, 111, 80,
  97, 105, 110, 116, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45,
  49, 10, 35, 64, 103, 105, 109, 112, 32, 80, 97, 105, 110, 116, 105, 110,
  103, 32, 58, 32, 103, 105, 109, 112, 95, 112, 97, 105, 110, 116, 105, 110,
  103, 44, 32, 103, 105, 109, 112, 95, 112, 97, 105, 110, 116, 105, 110, 103,
  95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110,
  32, 61, 32, 105, 110, 116, 40, 53, 44, 49, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 116, 97, 105, 108, 115, 32,
  115, 99, 97, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 46,
  53, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 108, 111, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46,
  53, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 114, 112, 101, 110, 32, 115,
  104, 97, 100, 101, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108,
  105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 115, 58,
  32, 60, 105, 62, 76, 121, 108, 101, 32, 75, 114, 111, 108, 108, 44, 32,
  65, 110, 103, 101, 108, 111, 32, 76, 97, 109, 97, 44, 32, 68, 97, 118,
  105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50,
  51, 51, 59, 60, 47, 105, 62, 46, 92, 110, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49,
  47, 48, 50, 47, 50, 56, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 112, 97, 105, 110, 116,
  105, 110, 103, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 52, 61,
  48, 125, 44, 36, 123, 53, 61, 48, 125, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 116, 111, 95,
  99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 123, 109, 97, 120, 40, 51,
  44, 115, 41, 125, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99,
  105, 116, 121, 32, 45, 114, 118, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  36, 49, 32, 45, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97, 108, 105,
  122, 101, 95, 108, 111, 99, 97, 108, 91, 45, 49, 93, 32, 49, 48, 44,
  54, 44, 53, 44, 50, 48, 44, 49, 44, 51, 32, 45, 100, 111, 110, 101,
  10, 45, 103, 105, 109, 112, 95, 97, 110, 105, 115, 111, 116, 114, 111, 112,
  105, 99, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93,
  32, 123, 49, 48, 48, 42, 36, 50, 125, 44, 48, 46, 50, 44, 49, 44,
  36, 50, 44, 123, 50, 42, 36, 50, 125, 44, 48, 46, 56, 44, 57, 48,
  44, 50, 44, 48, 44, 49, 44, 49, 44, 50, 44, 49, 44, 49, 54, 10,
  45, 103, 105, 109, 112, 95, 109, 105, 120, 95, 108, 97, 98, 91, 45, 49,
  93, 32, 49, 44, 48, 44, 48, 44, 36, 51, 44, 48, 44, 48, 46, 53,
  44, 36, 51, 44, 48, 44, 48, 46, 53, 44, 48, 44, 50, 44, 48, 10,
  45, 105, 102, 32, 36, 53, 32, 45, 103, 105, 109, 112, 95, 115, 101, 103,
  109, 101, 110, 116, 95, 119, 97, 116, 101, 114, 115, 104, 101, 100, 91, 45,
  49, 93, 32, 49, 48, 44, 49, 44, 48, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 115, 109, 111, 111, 116, 104, 91, 45, 49, 93, 32, 36, 52, 44,
  48, 44, 49, 44, 49, 44, 49, 10, 45, 114, 118, 32, 45, 97, 32, 99,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109,
  112, 95, 112, 97, 105, 110, 116, 105, 110, 103, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95,
  112, 97, 105, 110, 116, 105, 110, 103, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 80, 97, 115, 116, 101, 108, 108, 32,
  97, 114, 116, 32, 58, 32, 103, 105, 109, 112, 95, 112, 97, 115, 116, 101,
  108, 108, 44, 32, 103, 105, 109, 112, 95, 112, 97, 115, 116, 101, 108, 108,
  95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 77, 97, 115, 116, 101, 114, 111, 112, 97, 99, 105,
  116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 54, 44, 48,
  46, 51, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66,
  103, 32, 116, 101, 120, 116, 117, 114, 101, 100, 32, 61, 32, 98, 111, 111,
  108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101,
  118, 101, 114, 115, 101, 32, 101, 102, 102, 101, 99, 116, 32, 61, 32, 98,
  111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 82,
  111, 100, 105, 108, 105, 117, 115, 32, 115, 101, 116, 116, 105, 110, 103, 115,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108,
  105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48,
  44, 48, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  84, 104, 105, 99, 107, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 51, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 104, 97, 114, 112, 110, 101, 115, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 51, 48, 48, 44, 48, 44, 49, 48, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 114, 105, 101,
  110, 116, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 49,
  44, 49, 44, 51, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  79, 102, 102, 115, 101, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51,
  48, 44, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 111, 108, 111, 114, 32, 109, 111, 100, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 49, 44, 34, 68, 97, 114, 107, 101, 114, 34,
  44, 34, 76, 105, 103, 104, 116, 101, 114, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 71, 114, 97, 100, 105, 101, 110, 116, 32, 115, 101, 116,
  116, 105, 110, 103, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 76, 105, 110, 101, 97, 114, 105, 116, 121, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 46, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 101, 103, 97, 116,
  105, 118, 101, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  65, 99, 116, 105, 118, 97, 116, 101, 32, 83, 104, 97, 107, 101, 115, 32,
  61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 109, 111, 117, 110, 116, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 48, 44, 48, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 116, 114, 101, 110, 116, 104, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 51, 44, 49, 44, 51, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 65, 99, 116, 105, 118, 97, 116, 101,
  32, 76, 105, 122, 97, 114, 100, 115, 32, 61, 32, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 111, 101, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 57, 44, 48, 44, 51, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 105, 118, 101,
  114, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44, 48, 44, 52,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 65, 99, 116,
  105, 118, 97, 116, 101, 32, 80, 105, 110, 107, 32, 101, 108, 101, 112, 104,
  97, 110, 116, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 84, 114, 117, 110, 107, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 50, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32,
  116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44,
  34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  32, 58, 32, 60, 105, 62, 65, 114, 116, 111, 32, 72, 117, 111, 116, 97,
  114, 105, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62,
  50, 48, 49, 51, 47, 48, 57, 47, 50, 56, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34,
  70, 105, 108, 116, 101, 114, 32, 69, 120, 112, 108, 97, 105, 110, 101, 100,
  32, 104, 101, 114, 101, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 119,
  119, 119, 46, 102, 108, 105, 99, 107, 114, 46, 99, 111, 109, 47, 112, 104,
  111, 116, 111, 115, 47, 110, 97, 103, 103, 111, 98, 111, 116, 47, 54, 50,
  57, 52, 48, 55, 53, 48, 55, 51, 47, 34, 41, 10, 103, 105, 109, 112,
  95, 112, 97, 115, 116, 101, 108, 108, 32, 58, 10, 77, 97, 115, 116, 101,
  114, 79, 112, 97, 99, 105, 116, 121, 61, 36, 49, 10, 66, 103, 84, 101,
  120, 116, 117, 114, 101, 100, 61, 36, 50, 10, 82, 101, 118, 101, 114, 115,
  101, 69, 102, 102, 101, 99, 116, 61, 36, 51, 10, 82, 65, 109, 112, 108,
  105, 116, 117, 100, 101, 61, 36, 52, 10, 82, 84, 104, 105, 99, 107, 110,
  101, 115, 115, 61, 36, 53, 10, 82, 83, 104, 97, 114, 112, 110, 101, 115,
  115, 61, 36, 54, 10, 82, 79, 114, 105, 101, 110, 116, 97, 116, 105, 111,
  110, 115, 61, 36, 55, 10, 82, 79, 102, 102, 115, 101, 116, 61, 36, 56,
  10, 82, 67, 111, 108, 111, 114, 109, 111, 100, 101, 61, 36, 57, 10, 71,
  83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 36, 49, 48, 10, 71,
  76, 105, 110, 101, 97, 114, 105, 116, 121, 61, 36, 49, 49, 10, 71, 78,
  101, 103, 97, 116, 105, 118, 101, 67, 111, 108, 111, 114, 115, 61, 36, 49,
  50, 10, 65, 99, 116, 105, 118, 97, 116, 101, 83, 104, 97, 107, 101, 115,
  61, 36, 49, 51, 10, 82, 105, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  61, 36, 49, 52, 10, 82, 105, 83, 105, 122, 101, 61, 36, 49, 53, 10,
  65, 99, 116, 105, 118, 97, 116, 101, 76, 105, 122, 97, 114, 100, 115, 61,
  36, 49, 54, 10, 87, 65, 109, 112, 108, 105, 116, 117, 100, 101, 61, 36,
  49, 55, 10, 87, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 36,
  49, 56, 10, 65, 99, 116, 105, 118, 97, 116, 101, 80, 105, 110, 107, 61,
  36, 49, 57, 10, 82, 68, 101, 102, 111, 114, 109, 61, 36, 50, 48, 10,
  82, 67, 104, 97, 110, 110, 101, 108, 115, 61, 48, 10, 71, 77, 105, 110,
  84, 104, 114, 101, 115, 104, 111, 108, 100, 61, 48, 10, 71, 77, 97, 120,
  84, 104, 114, 101, 115, 104, 111, 108, 100, 61, 49, 48, 48, 10, 82, 105,
  83, 104, 97, 112, 101, 61, 51, 10, 82, 105, 65, 110, 103, 108, 101, 61,
  49, 51, 53, 10, 45, 105, 102, 32, 123, 36, 65, 99, 116, 105, 118, 97,
  116, 101, 80, 105, 110, 107, 61, 61, 49, 125, 32, 45, 100, 101, 102, 111,
  114, 109, 91, 48, 93, 32, 36, 82, 68, 101, 102, 111, 114, 109, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 45, 103, 105, 109, 112, 95, 114, 111, 100,
  105, 108, 105, 117, 115, 91, 48, 93, 32, 36, 82, 65, 109, 112, 108, 105,
  116, 117, 100, 101, 44, 36, 82, 84, 104, 105, 99, 107, 110, 101, 115, 115,
  44, 36, 82, 83, 104, 97, 114, 112, 110, 101, 115, 115, 44, 36, 82, 79,
  114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 115, 44, 36, 82, 79, 102,
  102, 115, 101, 116, 44, 36, 82, 67, 111, 108, 111, 114, 109, 111, 100, 101,
  44, 36, 82, 67, 104, 97, 110, 110, 101, 108, 115, 44, 48, 10, 45, 45,
  103, 105, 109, 112, 95, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111,
  114, 109, 91, 48, 93, 32, 36, 71, 83, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 44, 36, 71, 76, 105, 110, 101, 97, 114, 105, 116, 121, 44, 36,
  71, 77, 105, 110, 84, 104, 114, 101, 115, 104, 111, 108, 100, 44, 36, 71,
  77, 97, 120, 84, 104, 114, 101, 115, 104, 111, 108, 100, 44, 36, 71, 78,
  101, 103, 97, 116, 105, 118, 101, 67, 111, 108, 111, 114, 115, 44, 48, 10,
  45, 103, 105, 109, 112, 95, 98, 105, 108, 97, 116, 101, 114, 97, 108, 91,
  48, 93, 32, 49, 53, 44, 49, 48, 44, 51, 44, 51, 44, 48, 10, 45,
  105, 102, 32, 123, 36, 65, 99, 116, 105, 118, 97, 116, 101, 76, 105, 122,
  97, 114, 100, 115, 61, 61, 49, 125, 32, 45, 119, 97, 116, 101, 114, 91,
  48, 44, 50, 93, 32, 36, 87, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  44, 36, 87, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 65, 99, 116, 105, 118,
  97, 116, 101, 83, 104, 97, 107, 101, 115, 61, 61, 49, 125, 32, 45, 114,
  105, 112, 112, 108, 101, 91, 48, 44, 50, 93, 32, 36, 82, 105, 65, 109,
  112, 108, 105, 116, 117, 100, 101, 44, 36, 82, 105, 83, 105, 122, 101, 44,
  36, 82, 105, 83, 104, 97, 112, 101, 44, 36, 82, 105, 65, 110, 103, 108,
  101, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 82, 101, 118, 101, 114, 115, 101, 69, 102, 102, 101, 99, 116, 61, 61,
  49, 125, 32, 45, 114, 101, 118, 101, 114, 115, 101, 91, 48, 44, 50, 93,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 98, 108, 101, 110, 100, 91,
  48, 44, 50, 93, 32, 100, 105, 118, 105, 100, 101, 44, 49, 44, 48, 10,
  45, 114, 101, 118, 101, 114, 115, 101, 91, 49, 44, 51, 93, 10, 45, 98,
  108, 101, 110, 100, 91, 49, 44, 51, 93, 32, 118, 97, 108, 117, 101, 44,
  49, 44, 48, 10, 45, 105, 102, 32, 123, 36, 66, 103, 84, 101, 120, 116,
  117, 114, 101, 100, 61, 61, 49, 125, 32, 45, 103, 105, 109, 112, 95, 101,
  108, 108, 105, 112, 115, 105, 111, 110, 105, 115, 109, 91, 48, 93, 32, 50,
  48, 44, 50, 44, 49, 48, 44, 48, 46, 53, 44, 49, 44, 49, 44, 48,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 98, 108, 101, 110, 100, 91, 48,
  44, 49, 93, 32, 97, 108, 112, 104, 97, 44, 36, 77, 97, 115, 116, 101,
  114, 79, 112, 97, 99, 105, 116, 121, 44, 48, 10, 45, 107, 101, 101, 112,
  91, 48, 93, 10, 103, 105, 109, 112, 95, 112, 97, 115, 116, 101, 108, 108,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 103, 105, 109, 112, 95, 112, 97, 115, 116, 101, 108, 108, 32, 36, 123,
  49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 80, 101, 110, 32, 100, 114, 97, 119, 105, 110, 103, 32, 58, 32,
  103, 105, 109, 112, 95, 112, 101, 110, 95, 100, 114, 97, 119, 105, 110, 103,
  44, 32, 103, 105, 109, 112, 95, 112, 101, 110, 95, 100, 114, 97, 119, 105,
  110, 103, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 51, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117,
  112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47,
  50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 112, 101, 110, 95, 100, 114, 97, 119, 105,
  110, 103, 32, 58, 10, 45, 100, 114, 97, 119, 105, 110, 103, 32, 36, 49,
  10, 103, 105, 109, 112, 95, 112, 101, 110, 95, 100, 114, 97, 119, 105, 110,
  103, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 112, 101, 110, 95, 100, 114, 97, 119, 105,
  110, 103, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 80, 104, 111, 101, 110, 105, 120, 32, 115, 116, 101, 97, 109, 45,
  112, 101, 110, 99, 105, 108, 32, 58, 32, 103, 105, 109, 112, 95, 112, 104,
  111, 101, 110, 105, 120, 44, 32, 103, 105, 109, 112, 95, 112, 104, 111, 101,
  110, 105, 120, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 32,
  34, 67, 111, 110, 116, 114, 111, 108, 115, 32, 102, 111, 114, 32, 34, 80,
  101, 110, 99, 105, 108, 34, 32, 97, 112, 112, 108, 105, 101, 100, 32, 111,
  110, 32, 97, 32, 99, 111, 112, 121, 32, 111, 102, 32, 111, 114, 105, 103,
  105, 110, 97, 108, 32, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 100, 105, 117,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 57, 53, 44, 48,
  44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112,
  108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  52, 44, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 32, 34, 67, 111, 110, 116, 114,
  111, 108, 115, 32, 102, 111, 114, 32, 34, 83, 116, 101, 97, 109, 34, 32,
  97, 112, 112, 108, 105, 101, 100, 32, 111, 110, 32, 116, 104, 101, 32, 80,
  101, 110, 99, 105, 108, 32, 108, 97, 121, 101, 114, 32, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105,
  110, 116, 40, 50, 44, 49, 44, 55, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 116, 101, 97, 109, 32, 112, 114, 101, 115, 115, 117, 114,
  101, 32, 61, 32, 105, 110, 116, 40, 50, 44, 49, 44, 55, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 76, 117, 98, 114, 105, 99, 97, 116,
  105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 57, 44,
  48, 44, 49, 46, 57, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 32, 34, 84, 111, 32, 101, 120, 105, 116,
  32, 104, 101, 114, 101, 32, 111, 114, 32, 109, 101, 114, 103, 101, 32, 119,
  105, 116, 104, 32, 116, 104, 101, 32, 111, 114, 105, 103, 105, 110, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 119, 32, 111,
  114, 32, 99, 111, 108, 111, 117, 114, 115, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 32, 40, 32, 34, 66, 108, 97, 99, 107, 32, 97, 110, 100, 32,
  87, 104, 105, 116, 101, 34, 44, 32, 34, 67, 111, 108, 111, 117, 114, 115,
  34, 32, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 32, 116, 111, 32, 97, 99,
  116, 105, 118, 97, 116, 101, 32, 116, 104, 101, 32, 77, 101, 114, 103, 105,
  110, 103, 32, 79, 112, 116, 105, 111, 110, 115, 32, 98, 101, 108, 111, 119,
  32, 99, 104, 111, 115, 101, 32, 34, 67, 111, 108, 111, 117, 114, 115, 34,
  34, 32, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 119, 97, 112, 32, 108, 97, 121,
  101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 77, 101, 114, 103, 105, 110, 103, 32, 111,
  112, 116, 105, 111, 110, 115, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 86, 97, 108, 117, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101,
  115, 115, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 42, 67, 111, 108, 111, 114, 115, 32, 68, 111, 112, 105, 110, 103, 42,
  34, 44, 34, 42, 67, 111, 109, 105, 120, 32, 67, 111, 108, 111, 114, 115,
  42, 34, 44, 34, 71, 114, 97, 112, 104, 105, 99, 32, 67, 111, 108, 111,
  114, 115, 42, 34, 32, 44, 42, 68, 97, 114, 107, 32, 69, 100, 103, 101,
  115, 42, 34, 44, 32, 34, 42, 86, 105, 118, 105, 100, 32, 69, 100, 103,
  101, 115, 42, 34, 44, 34, 77, 117, 108, 116, 105, 112, 108, 121, 34, 44,
  34, 67, 111, 108, 111, 114, 32, 66, 117, 114, 110, 34, 44, 34, 68, 97,
  114, 107, 101, 110, 34, 44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44,
  34, 72, 97, 114, 100, 32, 76, 105, 103, 104, 116, 34, 44, 34, 83, 111,
  102, 116, 32, 76, 105, 103, 104, 116, 34, 44, 34, 79, 118, 101, 114, 108,
  97, 121, 34, 44, 34, 71, 114, 97, 105, 110, 32, 77, 101, 114, 103, 101,
  34, 44, 34, 69, 100, 103, 101, 115, 34, 44, 34, 73, 110, 116, 101, 114,
  112, 111, 108, 97, 116, 105, 111, 110, 34, 32, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102,
  108, 111, 97, 116, 32, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 42, 105, 110, 116, 101, 110, 115, 105, 116, 121,
  42, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 49, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101,
  119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 80, 104, 111, 116, 111, 67, 111, 109, 105, 88, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47,
  49, 49, 47, 49, 52, 32, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 70, 105, 108, 116,
  101, 114, 32, 104, 111, 119, 32, 116, 111, 32, 97, 110, 100, 32, 104, 101,
  108, 112, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46,
  103, 105, 109, 112, 99, 104, 97, 116, 46, 99, 111, 109, 47, 118, 105, 101,
  119, 116, 111, 112, 105, 99, 46, 112, 104, 112, 63, 102, 61, 57, 38, 116,
  61, 50, 57, 56, 51, 34, 41, 10, 103, 105, 109, 112, 95, 112, 104, 111,
  101, 110, 105, 120, 32, 58, 10, 45, 45, 103, 105, 109, 112, 95, 112, 101,
  110, 99, 105, 108, 98, 119, 32, 36, 49, 44, 36, 50, 44, 48, 44, 48,
  44, 48, 10, 45, 103, 105, 109, 112, 95, 107, 117, 119, 97, 104, 97, 114,
  97, 91, 49, 93, 32, 36, 51, 44, 36, 52, 44, 48, 44, 48, 10, 45,
  116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 32, 45, 98, 108, 117, 114,
  95, 120, 121, 91, 49, 93, 32, 36, 53, 10, 45, 105, 102, 32, 123, 36,
  54, 61, 61, 48, 125, 32, 45, 114, 101, 109, 111, 118, 101, 91, 48, 93,
  32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 56, 61, 61, 48, 125, 32, 45, 114, 101, 118,
  101, 114, 115, 101, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 118, 97, 108, 117, 101, 32, 36, 57, 44, 36, 55, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 56, 61, 61, 49, 125, 32, 45, 114, 101,
  118, 101, 114, 115, 101, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 36, 57,
  44, 36, 55, 10, 45, 101, 108, 105, 102, 32, 123, 36, 56, 61, 61, 50,
  125, 32, 45, 114, 101, 118, 101, 114, 115, 101, 32, 45, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 108, 117, 109, 105, 110, 97, 110,
  99, 101, 32, 36, 57, 44, 36, 55, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 56, 61, 61, 51, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 99, 111, 108, 111, 114, 100, 111, 112, 105, 110, 103,
  32, 36, 57, 44, 36, 55, 10, 45, 101, 108, 105, 102, 32, 123, 36, 56,
  61, 61, 52, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 99, 111, 109, 105, 120, 95, 99, 111, 108, 111, 114, 32, 36,
  57, 44, 36, 55, 44, 36, 49, 48, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 56, 61, 61, 53, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 103, 114, 97, 112, 104, 105, 99, 111, 108, 111, 114,
  32, 36, 57, 44, 48, 44, 36, 55, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 56, 61, 61, 54, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 103, 114, 97, 112, 104, 105, 120, 99, 111, 108, 111,
  114, 32, 36, 57, 44, 36, 55, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  56, 61, 61, 55, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 118, 105, 118, 105, 100, 101, 100, 103, 101, 115, 32, 36,
  57, 44, 48, 46, 53, 48, 44, 36, 55, 44, 36, 49, 48, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 56, 61, 61, 56, 125, 32, 45, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101, 100,
  103, 101, 115, 32, 36, 57, 44, 48, 46, 53, 48, 44, 36, 55, 44, 36,
  49, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 56, 61, 61, 54, 125,
  32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 109,
  117, 108, 116, 105, 112, 108, 121, 32, 36, 57, 44, 36, 55, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 56, 61, 61, 55, 125, 32, 45, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 99, 111, 108, 111, 114, 98,
  117, 114, 110, 32, 36, 57, 44, 36, 55, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 56, 61, 61, 56, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101, 110, 32, 36, 57, 44,
  36, 55, 10, 45, 101, 108, 105, 102, 32, 123, 36, 56, 61, 61, 57, 125,
  32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 108,
  105, 103, 104, 116, 101, 110, 32, 36, 57, 44, 36, 55, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 56, 61, 61, 49, 48, 125, 32, 45, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 115, 99, 114, 101, 101, 110,
  32, 36, 57, 44, 36, 55, 10, 45, 101, 108, 105, 102, 32, 123, 36, 56,
  61, 61, 49, 49, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 104, 97, 114, 100, 108, 105, 103, 104, 116, 32, 36, 57,
  44, 36, 55, 10, 45, 101, 108, 105, 102, 32, 123, 36, 56, 61, 61, 49,
  50, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 115, 111, 102, 116, 108, 105, 103, 104, 116, 32, 36, 57, 44, 36, 55,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 56, 61, 61, 49, 51, 125, 32,
  45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 111, 118,
  101, 114, 108, 97, 121, 32, 36, 57, 44, 36, 55, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 56, 61, 61, 49, 52, 125, 32, 45, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 109, 101,
  114, 103, 101, 32, 36, 57, 44, 36, 55, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 56, 61, 61, 49, 53, 125, 32, 45, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 101, 100, 103, 101, 115, 32, 36, 57, 44,
  48, 46, 56, 48, 44, 36, 55, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  56, 61, 61, 49, 54, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105,
  111, 110, 32, 36, 57, 44, 36, 55, 32, 32, 45, 101, 110, 100, 105, 102,
  10, 103, 105, 109, 112, 95, 112, 104, 111, 101, 110, 105, 120, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112,
  108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105,
  109, 112, 95, 112, 104, 111, 101, 110, 105, 120, 32, 36, 123, 49, 45, 45,
  50, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 80,
  104, 111, 116, 111, 105, 108, 108, 117, 115, 116, 114, 97, 116, 105, 111, 110,
  32, 58, 32, 103, 105, 109, 112, 95, 116, 107, 95, 112, 104, 111, 116, 111,
  105, 108, 108, 117, 115, 116, 114, 97, 116, 105, 111, 110, 44, 32, 32, 103,
  105, 109, 112, 95, 116, 107, 95, 112, 104, 111, 116, 111, 105, 108, 108, 117,
  115, 116, 114, 97, 116, 105, 111, 110, 95, 112, 114, 101, 118, 105, 101, 119,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 97, 100, 100, 105, 110, 103,
  32, 97, 110, 32, 105, 108, 108, 117, 115, 116, 114, 97, 116, 105, 118, 101,
  32, 101, 102, 102, 101, 99, 116, 32, 116, 111, 32, 97, 110, 121, 32, 112,
  104, 111, 116, 111, 103, 114, 97, 112, 104, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  76, 111, 99, 97, 108, 32, 99, 111, 110, 116, 114, 97, 115, 116, 32, 115,
  116, 121, 108, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 116,
  111, 110, 101, 32, 109, 97, 112, 112, 105, 110, 103, 34, 44, 34, 116, 111,
  110, 101, 32, 109, 97, 112, 112, 105, 110, 103, 32, 115, 111, 102, 116, 34,
  44, 34, 116, 111, 110, 101, 32, 109, 97, 112, 112, 105, 110, 103, 32, 102,
  97, 115, 116, 34, 44, 34, 108, 111, 99, 97, 108, 32, 32, 110, 111, 114,
  109, 97, 108, 105, 115, 97, 116, 105, 111, 110, 34, 44, 34, 117, 110, 115,
  104, 97, 114, 112, 32, 109, 97, 115, 107, 34, 44, 34, 103, 108, 111, 98,
  97, 108, 32, 109, 97, 112, 112, 105, 110, 103, 34, 44, 34, 100, 121, 110,
  97, 109, 105, 99, 32, 114, 97, 110, 103, 101, 32, 105, 110, 99, 114, 101,
  97, 115, 101, 34, 44, 34, 110, 111, 110, 101, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 76, 111, 99, 97, 108, 32, 99, 111, 110, 116,
  114, 97, 115, 116, 32, 101, 102, 102, 101, 99, 116, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 50, 53, 44, 48, 46, 48, 48, 44, 50, 46,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111,
  116, 104, 105, 110, 103, 32, 115, 116, 121, 108, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 97, 110, 105, 115, 111, 116, 114, 111, 112, 105,
  99, 34, 44, 34, 98, 105, 108, 97, 116, 101, 114, 97, 108, 34, 44, 34,
  99, 111, 108, 111, 114, 32, 99, 104, 97, 110, 110, 101, 108, 32, 32, 115,
  109, 111, 111, 116, 104, 105, 110, 103, 34, 44, 34, 115, 101, 103, 109, 101,
  110, 116, 97, 116, 105, 111, 110, 34, 44, 34, 109, 111, 114, 112, 104, 111,
  108, 111, 103, 105, 99, 97, 108, 32, 99, 108, 111, 115, 105, 110, 103, 34,
  44, 34, 115, 101, 108, 101, 99, 116, 105, 118, 101, 32, 103, 97, 117, 115,
  115, 105, 97, 110, 34, 44, 34, 119, 97, 118, 101, 108, 101, 116, 34, 44,
  34, 75, 117, 119, 97, 104, 97, 114, 97, 34, 44, 34, 110, 111, 110, 101,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116,
  111, 117, 114, 32, 112, 114, 101, 99, 105, 115, 105, 111, 110, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 51, 48, 44, 48, 46, 48, 48, 44,
  49, 46, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  114, 101, 97, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 48, 44, 48, 46, 48, 48,
  44, 49, 48, 46, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 104, 97, 114, 112, 101, 110, 105, 110, 103, 32, 114, 97, 100, 105,
  117, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 48, 44,
  48, 46, 48, 48, 44, 49, 48, 46, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 104, 97, 114, 112, 101, 110, 105, 110, 103, 32,
  115, 116, 114, 101, 110, 103, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 46, 48, 48, 44, 48, 46, 48, 48, 44, 53, 46, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 101, 99, 105, 97,
  108, 32, 101, 102, 102, 101, 99, 116, 115, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 110, 111, 110, 101, 34, 44, 34, 115, 111, 102, 116, 32,
  103, 108, 111, 119, 34, 44, 34, 100, 117, 115, 116, 121, 34, 44, 34, 79,
  114, 116, 111, 110, 32, 103, 108, 111, 119, 34, 44, 34, 101, 120, 116, 114,
  97, 32, 32, 115, 109, 111, 111, 116, 104, 34, 44, 34, 98, 108, 111, 111,
  109, 34, 44, 34, 112, 97, 105, 110, 116, 115, 116, 114, 111, 107, 101, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 102, 102, 101, 99,
  116, 32, 115, 116, 114, 101, 110, 103, 116, 104, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 53, 46, 48, 48, 44, 48, 46, 48, 48, 44, 50, 48, 46,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 118, 101,
  114, 97, 108, 108, 32, 108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 53, 48, 44, 53, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 118, 101, 114, 97, 108,
  108, 32, 99, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 44, 48, 46, 53, 44, 49, 46, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 100, 111, 119, 115, 32, 108,
  105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 72, 105, 103, 104, 108, 105, 103, 104, 116, 115,
  32, 108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 77, 105, 100, 32, 116, 111, 110, 101,
  32, 99, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 44, 48, 46, 53, 44, 52, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 103, 114, 101, 101, 110, 45,
  109, 97, 103, 101, 110, 116, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 45, 50, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 111, 108, 111, 114, 32, 98, 108, 117, 101, 45, 121, 101,
  108, 108, 111, 119, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45,
  50, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 108, 111, 114, 32, 98, 111, 111, 115, 116, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 46, 50, 44, 48, 44, 52, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 101, 116, 97, 105, 108, 32, 114, 101, 99,
  111, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 32, 100, 101, 116, 101,
  99, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 57,
  56, 46, 53, 44, 53, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 68, 101, 116, 97, 105, 108, 32, 114, 101, 99, 111,
  110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 32, 115, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44,
  48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68,
  101, 116, 97, 105, 108, 32, 114, 101, 99, 111, 110, 115, 116, 114, 117, 99,
  116, 105, 111, 110, 32, 115, 116, 114, 101, 110, 103, 116, 104, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 116, 97, 105, 108, 32, 114,
  101, 99, 111, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 32, 115, 116,
  121, 108, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 109, 105,
  99, 114, 111, 47, 109, 97, 99, 114, 111, 32, 100, 101, 116, 97, 105, 108,
  115, 32, 32, 97, 100, 106, 117, 115, 116, 101, 100, 34, 44, 34, 102, 105,
  110, 101, 34, 44, 34, 115, 116, 114, 111, 110, 103, 34, 44, 34, 104, 105,
  103, 104, 32, 112, 97, 115, 115, 34, 44, 34, 97, 114, 116, 105, 115, 116,
  105, 99, 32, 114, 111, 117, 110, 100, 34, 44, 34, 97, 114, 116, 105, 115,
  116, 105, 99, 32, 104, 97, 114, 100, 34, 44, 34, 97, 114, 116, 105, 115,
  116, 105, 99, 32, 32, 109, 111, 100, 101, 114, 110, 34, 44, 34, 99, 111,
  109, 105, 99, 32, 83, 116, 121, 108, 101, 34, 44, 34, 103, 114, 105, 116,
  116, 121, 34, 44, 34, 110, 111, 110, 101, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 75, 101, 101, 112, 32, 100, 101, 116, 97, 105, 108,
  32, 108, 97, 121, 101, 114, 32, 115, 101, 112, 101, 114, 97, 116, 101, 32,
  61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 82, 101, 109, 111, 118, 101, 32, 97, 114, 116, 105, 102, 97,
  99, 116, 115, 32, 102, 114, 111, 109, 32, 109, 105, 99, 114, 111, 47, 109,
  97, 99, 114, 111, 32, 100, 101, 116, 97, 105, 108, 32, 61, 32, 98, 111,
  111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  107, 105, 110, 32, 116, 111, 110, 101, 32, 112, 114, 111, 116, 101, 99, 116,
  105, 111, 110, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 114, 112, 101, 110, 32, 101,
  100, 103, 101, 115, 32, 111, 110, 108, 121, 32, 61, 32, 98, 111, 111, 108,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 109,
  112, 117, 116, 97, 116, 105, 111, 110, 32, 109, 111, 100, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 104, 105, 103, 104, 32, 113,
  117, 97, 108, 105, 116, 121, 34, 44, 34, 110, 111, 114, 109, 97, 108, 34,
  44, 34, 104, 105, 103, 104, 32, 115, 112, 101, 101, 100, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 84, 111, 109, 32, 75, 101, 105, 108, 60,
  47, 105, 62, 32, 32, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49,
  50, 47, 50, 56, 47, 48, 56, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 70, 105, 108,
  116, 101, 114, 32, 101, 120, 112, 108, 97, 105, 110, 101, 100, 32, 32, 104,
  101, 114, 101, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119,
  46, 116, 107, 102, 105, 108, 116, 101, 114, 46, 98, 112, 108, 97, 99, 101,
  100, 46, 110, 101, 116, 47, 84, 75, 70, 105, 108, 116, 101, 114, 37, 50,
  48, 116, 117, 116, 111, 114, 105, 97, 108, 115, 37, 50, 48, 80, 104, 111,
  116, 111, 105, 108, 108, 117, 115, 116, 114, 97, 116, 105, 111, 110, 46, 104,
  116, 109, 108, 34, 41, 10, 103, 105, 109, 112, 95, 116, 107, 95, 112, 104,
  111, 116, 111, 105, 108, 108, 117, 115, 116, 114, 97, 116, 105, 111, 110, 32,
  58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 105, 102, 32, 123, 36, 50, 54, 61, 61, 49, 125,
  32, 115, 99, 100, 111, 61, 53, 48, 32, 115, 99, 117, 112, 61, 50, 48,
  48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 50,
  54, 61, 61, 50, 125, 32, 115, 99, 100, 111, 61, 50, 53, 32, 115, 99,
  117, 112, 61, 52, 48, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 50, 54, 33, 61, 48, 125, 32, 45, 114, 32, 36, 115,
  99, 100, 111, 37, 44, 36, 115, 99, 100, 111, 37, 32, 45, 101, 108, 115,
  101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 50,
  49, 61, 61, 48, 125, 32, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95,
  110, 111, 116, 104, 105, 110, 103, 32, 45, 45, 110, 101, 103, 97, 116, 105,
  118, 101, 91, 49, 93, 32, 32, 45, 45, 103, 105, 109, 112, 95, 100, 111,
  95, 110, 111, 116, 104, 105, 110, 103, 91, 48, 93, 32, 45, 45, 110, 101,
  103, 97, 116, 105, 118, 101, 91, 48, 93, 10, 45, 103, 105, 109, 112, 95,
  103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 50, 93,
  32, 123, 123, 123, 49, 48, 48, 45, 36, 49, 56, 125, 47, 53, 125, 43,
  48, 46, 53, 125, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48,
  32, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95,
  100, 111, 100, 103, 101, 91, 49, 44, 50, 93, 32, 49, 10, 45, 105, 102,
  32, 123, 36, 50, 51, 61, 61, 49, 125, 32, 45, 103, 105, 109, 112, 95,
  103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 49, 93,
  32, 123, 123, 123, 49, 48, 48, 45, 36, 49, 56, 125, 47, 49, 48, 125,
  43, 48, 46, 53, 125, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 44,
  48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 103,
  97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 51, 93, 32,
  123, 123, 123, 123, 123, 49, 48, 48, 45, 36, 49, 56, 125, 47, 53, 125,
  43, 49, 125, 42, 49, 48, 125, 43, 49, 48, 125, 44, 48, 44, 48, 44,
  49, 44, 48, 44, 48, 44, 48, 10, 45, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 100, 111, 100, 103, 101, 91, 50, 44, 51, 93,
  32, 49, 10, 45, 105, 102, 32, 123, 36, 50, 51, 61, 61, 49, 125, 32,
  45, 103, 105, 109, 112, 95, 103, 97, 117, 115, 115, 105, 97, 110, 95, 98,
  108, 117, 114, 91, 50, 93, 32, 123, 123, 123, 123, 49, 48, 48, 45, 36,
  49, 56, 125, 47, 49, 48, 125, 43, 48, 46, 53, 125, 42, 51, 125, 44,
  48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 114, 101, 118, 101, 114, 115, 101, 91, 49, 44, 50, 93,
  32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 109,
  117, 108, 116, 105, 112, 108, 121, 91, 49, 44, 50, 93, 32, 123, 49, 45,
  123, 36, 49, 57, 47, 49, 48, 125, 125, 10, 45, 116, 107, 95, 103, 105,
  109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101,
  115, 115, 105, 110, 103, 91, 49, 93, 32, 123, 123, 49, 45, 36, 50, 48,
  125, 43, 48, 46, 49, 125, 44, 49, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 49, 48, 48, 44, 50, 53, 54, 44, 48, 44, 48, 44, 48, 44, 50,
  44, 55, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 49, 61,
  61, 49, 125, 32, 45, 45, 103, 105, 109, 112, 95, 108, 97, 112, 108, 97,
  99, 105, 97, 110, 32, 36, 49, 57, 44, 123, 57, 57, 46, 57, 57, 45,
  36, 49, 56, 125, 44, 36, 49, 56, 44, 49, 44, 49, 44, 48, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 50, 49, 61, 61, 50, 125, 32, 45, 45,
  103, 105, 109, 112, 95, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111,
  114, 109, 32, 36, 49, 57, 44, 48, 46, 53, 44, 123, 57, 57, 46, 57,
  57, 45, 36, 49, 56, 125, 44, 36, 49, 56, 44, 49, 44, 48, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 50, 49, 61, 61, 51, 125, 32, 45, 45,
  103, 105, 109, 112, 95, 104, 105, 103, 104, 112, 97, 115, 115, 32, 123, 45,
  123, 36, 49, 56, 45, 49, 48, 48, 46, 51, 125, 125, 44, 123, 123, 49,
  48, 45, 36, 49, 57, 125, 42, 48, 46, 55, 125, 44, 48, 44, 49, 44,
  48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 49, 61, 61, 52, 125,
  32, 45, 45, 103, 105, 109, 112, 95, 112, 101, 110, 99, 105, 108, 98, 119,
  32, 123, 49, 48, 48, 45, 36, 49, 56, 125, 44, 123, 36, 49, 57, 42,
  50, 48, 125, 44, 48, 44, 48, 44, 48, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 50, 49, 61, 61, 53, 125, 10, 45, 45, 103, 105, 109, 112, 95,
  104, 97, 114, 100, 115, 107, 101, 116, 99, 104, 98, 119, 32, 123, 51, 48,
  48, 43, 123, 123, 36, 49, 56, 45, 53, 48, 125, 42, 49, 53, 125, 125,
  44, 123, 36, 49, 57, 42, 49, 48, 125, 44, 36, 49, 57, 44, 49, 44,
  123, 53, 48, 45, 123, 36, 49, 56, 47, 50, 125, 125, 44, 48, 44, 48,
  44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 49, 61, 61, 54,
  125, 32, 45, 45, 103, 105, 109, 112, 95, 116, 104, 105, 110, 95, 101, 100,
  103, 101, 115, 32, 36, 49, 57, 44, 123, 123, 36, 49, 56, 47, 53, 125,
  45, 49, 48, 125, 44, 48, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 50, 49, 61, 61, 55, 125, 32, 45, 45, 103, 105, 109, 112, 95, 101,
  100, 103, 101, 115, 32, 123, 36, 49, 57, 47, 51, 46, 53, 125, 44, 123,
  57, 53, 45, 36, 49, 56, 125, 44, 48, 44, 48, 10, 45, 45, 103, 105,
  109, 112, 95, 109, 105, 120, 95, 104, 115, 118, 91, 48, 93, 32, 49, 44,
  48, 44, 48, 44, 49, 44, 45, 49, 44, 48, 44, 49, 44, 48, 44, 48,
  44, 48, 44, 50, 44, 48, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95,
  99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105,
  110, 103, 91, 50, 93, 32, 49, 44, 49, 44, 48, 44, 123, 36, 49, 57,
  47, 49, 48, 125, 44, 52, 44, 123, 123, 36, 49, 56, 45, 53, 48, 125,
  42, 50, 125, 44, 49, 48, 48, 44, 50, 53, 54, 44, 48, 44, 48, 44,
  48, 44, 50, 44, 55, 44, 48, 10, 45, 114, 101, 118, 101, 114, 115, 101,
  91, 49, 44, 50, 93, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 109, 117, 108, 116, 105, 112, 108, 121, 91, 49, 44, 50,
  93, 32, 123, 48, 46, 53, 43, 123, 36, 50, 48, 47, 50, 125, 125, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 50, 49, 61, 61, 56, 125, 32, 45,
  45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 50, 10, 45, 105, 102, 32,
  123, 36, 49, 57, 60, 61, 53, 125, 32, 32, 32, 45, 103, 105, 109, 112,
  95, 117, 110, 115, 104, 97, 114, 112, 91, 49, 93, 32, 32, 49, 44, 123,
  50, 45, 123, 123, 36, 49, 57, 42, 48, 46, 51, 125, 43, 48, 46, 53,
  125, 125, 44, 50, 48, 44, 123, 53, 45, 36, 49, 57, 125, 44, 48, 46,
  48, 48, 44, 49, 46, 48, 48, 44, 48, 46, 53, 44, 49, 44, 48, 44,
  55, 44, 48, 10, 45, 101, 108, 115, 101, 32, 45, 103, 105, 109, 112, 95,
  103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 49, 93,
  32, 123, 36, 49, 57, 45, 53, 125, 44, 48, 44, 48, 44, 49, 44, 48,
  44, 48, 44, 48, 32, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 33, 61, 51, 125, 10,
  45, 116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108,
  95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 91, 48, 93, 32, 49,
  44, 49, 44, 36, 49, 50, 44, 48, 44, 48, 44, 48, 44, 49, 48, 48,
  44, 50, 53, 54, 44, 48, 44, 48, 44, 49, 44, 123, 97, 98, 115, 40,
  36, 49, 50, 47, 49, 48, 41, 125, 44, 55, 44, 48, 10, 45, 116, 107,
  95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114,
  111, 99, 101, 115, 115, 105, 110, 103, 91, 48, 93, 32, 49, 44, 49, 44,
  36, 49, 51, 44, 48, 44, 48, 44, 48, 44, 49, 48, 48, 44, 50, 53,
  54, 44, 48, 44, 48, 44, 51, 44, 123, 97, 98, 115, 40, 36, 49, 50,
  47, 49, 48, 41, 125, 44, 55, 44, 48, 32, 32, 32, 32, 32, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 50, 52, 61, 61,
  48, 125, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 125, 32, 45,
  103, 105, 109, 112, 95, 109, 97, 112, 95, 116, 111, 110, 101, 115, 91, 48,
  93, 32, 123, 36, 50, 47, 50, 46, 53, 125, 44, 123, 49, 45, 123, 36,
  50, 47, 50, 46, 53, 125, 125, 44, 36, 50, 44, 123, 50, 43, 123, 36,
  50, 42, 56, 48, 125, 125, 44, 51, 44, 48, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 61, 61, 49, 125, 32, 45, 103, 105, 109, 112, 95, 109,
  97, 112, 95, 116, 111, 110, 101, 115, 91, 48, 93, 32, 123, 36, 50, 47,
  49, 48, 125, 44, 48, 46, 53, 44, 123, 49, 48, 45, 123, 36, 50, 42,
  50, 125, 125, 44, 51, 48, 48, 44, 51, 44, 48, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 61, 61, 50, 125, 32, 45, 103, 105, 109, 112, 95,
  109, 97, 112, 95, 116, 111, 110, 101, 115, 95, 102, 97, 115, 116, 91, 48,
  93, 32, 123, 36, 50, 42, 50, 125, 44, 123, 36, 50, 47, 50, 46, 53,
  125, 44, 51, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61,
  61, 51, 125, 10, 45, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97, 108,
  105, 122, 101, 95, 108, 111, 99, 97, 108, 91, 48, 93, 32, 123, 36, 50,
  42, 50, 125, 44, 123, 49, 43, 123, 36, 50, 42, 50, 53, 46, 50, 125,
  125, 44, 123, 36, 50, 42, 49, 54, 125, 44, 123, 36, 50, 42, 49, 54,
  125, 44, 48, 44, 51, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  49, 61, 61, 52, 125, 32, 45, 103, 105, 109, 112, 95, 117, 110, 115, 104,
  97, 114, 112, 91, 48, 93, 32, 48, 44, 123, 123, 119, 43, 104, 125, 47,
  49, 48, 48, 125, 44, 48, 44, 36, 50, 44, 48, 44, 49, 44, 49, 44,
  49, 44, 48, 44, 55, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  49, 61, 61, 53, 125, 32, 45, 45, 110, 101, 103, 97, 116, 105, 118, 101,
  91, 48, 93, 10, 45, 105, 102, 32, 123, 36, 50, 49, 33, 61, 57, 125,
  32, 45, 114, 101, 118, 101, 114, 115, 101, 91, 49, 44, 50, 93, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 103, 97, 117, 115,
  115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 49, 93, 32, 123, 123, 123,
  119, 43, 104, 125, 47, 53, 125, 45, 123, 36, 50, 42, 123, 123, 119, 43,
  104, 125, 47, 49, 50, 46, 53, 125, 125, 125, 44, 48, 44, 48, 44, 49,
  44, 48, 44, 48, 44, 48, 10, 45, 116, 111, 95, 103, 114, 97, 121, 91,
  49, 93, 32, 45, 114, 101, 118, 101, 114, 115, 101, 91, 48, 44, 49, 93,
  32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 115,
  111, 102, 116, 108, 105, 103, 104, 116, 91, 48, 44, 49, 93, 32, 123, 36,
  50, 47, 50, 46, 53, 125, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49,
  61, 61, 54, 125, 32, 45, 103, 105, 109, 112, 95, 116, 107, 95, 100, 114,
  105, 91, 48, 93, 32, 123, 36, 50, 47, 50, 46, 53, 125, 44, 123, 36,
  50, 47, 53, 125, 44, 123, 36, 50, 47, 50, 46, 53, 125, 44, 123, 36,
  50, 42, 50, 125, 44, 123, 36, 50, 47, 50, 46, 53, 125, 44, 49, 44,
  49, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101,
  10, 45, 45, 116, 111, 95, 114, 103, 98, 97, 91, 48, 93, 32, 45, 45,
  99, 104, 97, 110, 110, 101, 108, 115, 91, 48, 93, 32, 48, 32, 45, 105,
  102, 32, 123, 36, 50, 49, 33, 61, 57, 125, 32, 45, 109, 111, 118, 101,
  91, 49, 93, 32, 52, 32, 45, 101, 110, 100, 105, 102, 10, 45, 110, 101,
  103, 97, 116, 105, 118, 101, 91, 50, 93, 10, 45, 116, 107, 95, 103, 105,
  109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101,
  115, 115, 105, 110, 103, 91, 50, 93, 32, 49, 44, 49, 44, 50, 44, 48,
  44, 48, 44, 48, 44, 49, 48, 48, 44, 50, 53, 54, 44, 48, 44, 48,
  44, 48, 44, 50, 44, 55, 44, 48, 10, 45, 103, 105, 109, 112, 95, 103,
  97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 50, 93, 32,
  123, 123, 119, 43, 104, 125, 47, 53, 48, 48, 125, 44, 48, 44, 48, 44,
  49, 44, 48, 44, 48, 44, 48, 10, 45, 116, 111, 95, 103, 114, 97, 121,
  91, 50, 93, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 125, 32,
  45, 103, 105, 109, 112, 95, 109, 97, 112, 95, 116, 111, 110, 101, 115, 91,
  49, 93, 32, 123, 36, 50, 47, 50, 46, 53, 125, 44, 123, 49, 45, 123,
  36, 50, 47, 50, 46, 53, 125, 125, 44, 36, 50, 44, 123, 50, 43, 123,
  36, 50, 42, 56, 48, 125, 125, 44, 51, 44, 48, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 61, 61, 49, 125, 32, 45, 103, 105, 109, 112, 95,
  109, 97, 112, 95, 116, 111, 110, 101, 115, 91, 49, 93, 32, 123, 36, 50,
  47, 49, 48, 125, 44, 48, 46, 53, 44, 123, 49, 48, 45, 123, 36, 50,
  42, 50, 125, 125, 44, 51, 48, 48, 44, 51, 44, 48, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 61, 61, 50, 125, 32, 45, 103, 105, 109, 112,
  95, 109, 97, 112, 95, 116, 111, 110, 101, 115, 95, 102, 97, 115, 116, 91,
  49, 93, 32, 123, 36, 50, 42, 50, 125, 44, 123, 36, 50, 47, 50, 46,
  53, 125, 44, 51, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49,
  61, 61, 51, 125, 32, 32, 32, 45, 103, 105, 109, 112, 95, 110, 111, 114,
  109, 97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 91, 49, 93, 32,
  32, 123, 36, 50, 42, 50, 125, 44, 123, 49, 43, 123, 36, 50, 42, 50,
  53, 46, 50, 125, 125, 44, 123, 36, 50, 42, 49, 54, 125, 44, 123, 36,
  50, 42, 49, 54, 125, 44, 48, 44, 51, 44, 48, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 61, 61, 52, 125, 32, 45, 103, 105, 109, 112, 95,
  117, 110, 115, 104, 97, 114, 112, 91, 49, 93, 32, 48, 44, 49, 48, 48,
  44, 48, 44, 36, 50, 44, 48, 44, 49, 44, 49, 44, 49, 44, 48, 44,
  55, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 53,
  125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 49, 93, 32, 45,
  103, 105, 109, 112, 95, 103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108,
  117, 114, 91, 49, 93, 32, 32, 123, 123, 123, 119, 43, 104, 125, 47, 53,
  125, 45, 123, 36, 50, 42, 123, 123, 119, 43, 104, 125, 47, 49, 50, 46,
  53, 125, 125, 125, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48,
  10, 45, 116, 111, 95, 103, 114, 97, 121, 91, 49, 93, 32, 45, 116, 111,
  95, 114, 103, 98, 97, 91, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 61, 61, 54, 125, 32, 45, 103, 105, 109, 112, 95, 116, 107, 95,
  100, 114, 105, 91, 49, 93, 32, 123, 36, 50, 47, 50, 46, 53, 125, 44,
  123, 36, 50, 47, 53, 125, 44, 123, 36, 50, 47, 50, 46, 53, 125, 44,
  123, 36, 50, 42, 50, 125, 44, 123, 36, 50, 47, 50, 46, 53, 125, 44,
  49, 44, 49, 44, 48, 32, 32, 32, 32, 45, 116, 111, 95, 114, 103, 98,
  97, 91, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 115, 112, 108,
  105, 116, 91, 49, 93, 32, 99, 10, 45, 105, 102, 32, 123, 36, 50, 49,
  33, 61, 57, 125, 32, 45, 114, 101, 118, 101, 114, 115, 101, 91, 52, 44,
  53, 93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108, 116,
  105, 112, 108, 121, 91, 52, 44, 53, 93, 32, 45, 97, 112, 112, 101, 110,
  100, 91, 45, 53, 44, 45, 52, 44, 45, 51, 44, 45, 50, 93, 32, 99,
  10, 45, 101, 108, 115, 101, 32, 45, 114, 101, 118, 101, 114, 115, 101, 91,
  51, 44, 52, 93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117,
  108, 116, 105, 112, 108, 121, 91, 51, 44, 52, 93, 32, 45, 97, 112, 112,
  101, 110, 100, 91, 45, 52, 44, 45, 51, 44, 45, 50, 44, 45, 49, 93,
  32, 99, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  49, 33, 61, 51, 125, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 114,
  103, 98, 97, 91, 48, 44, 49, 93, 32, 45, 101, 108, 115, 101, 32, 45,
  114, 101, 118, 101, 114, 115, 101, 91, 48, 44, 49, 93, 10, 45, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 115, 111, 102, 116, 108,
  105, 103, 104, 116, 91, 48, 44, 49, 93, 32, 123, 36, 50, 47, 50, 46,
  53, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101,
  108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 91, 48, 93, 32,
  49, 44, 36, 49, 49, 44, 36, 49, 48, 44, 48, 44, 48, 44, 48, 44,
  49, 48, 48, 44, 50, 53, 54, 44, 48, 44, 48, 44, 48, 44, 50, 44,
  55, 44, 48, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97,
  110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 91,
  48, 93, 32, 49, 44, 36, 49, 52, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 49, 48, 48, 44, 50, 53, 54, 44, 48, 44, 48, 44, 50, 44, 123,
  97, 98, 115, 40, 36, 49, 52, 42, 50, 46, 53, 41, 125, 44, 55, 44,
  48, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 51, 125, 10, 45, 116,
  107, 95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112,
  114, 111, 99, 101, 115, 115, 105, 110, 103, 91, 48, 93, 32, 49, 44, 49,
  44, 36, 49, 50, 44, 48, 44, 48, 44, 48, 44, 49, 48, 48, 44, 50,
  53, 54, 44, 48, 44, 48, 44, 49, 44, 123, 97, 98, 115, 40, 36, 49,
  50, 47, 49, 48, 41, 125, 44, 55, 44, 48, 10, 45, 116, 107, 95, 103,
  105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111, 99,
  101, 115, 115, 105, 110, 103, 91, 48, 93, 32, 49, 44, 49, 44, 36, 49,
  51, 44, 48, 44, 48, 44, 48, 44, 49, 48, 48, 44, 50, 53, 54, 44,
  48, 44, 48, 44, 51, 44, 123, 97, 98, 115, 40, 36, 49, 50, 47, 49,
  48, 41, 125, 44, 55, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 51, 61, 61, 48, 125, 32, 45, 103, 105, 109, 112,
  95, 97, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111,
  111, 116, 104, 105, 110, 103, 91, 48, 93, 32, 32, 123, 36, 53, 42, 49,
  48, 48, 125, 44, 123, 36, 52, 42, 50, 125, 44, 36, 52, 44, 36, 53,
  44, 36, 53, 44, 48, 46, 56, 48, 44, 51, 48, 46, 48, 48, 44, 50,
  46, 48, 44, 48, 44, 49, 44, 49, 44, 48, 44, 49, 44, 48, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 51, 61, 61, 49, 125, 32, 45, 103, 105,
  109, 112, 95, 98, 105, 108, 97, 116, 101, 114, 97, 108, 91, 48, 93, 32,
  123, 49, 48, 48, 45, 123, 36, 52, 42, 49, 48, 48, 125, 125, 44, 123,
  36, 53, 42, 50, 53, 125, 44, 49, 44, 48, 44, 48, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 51, 61, 61, 50, 125, 32, 45, 103, 105, 109, 112,
  95, 103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 48,
  93, 32, 123, 36, 53, 42, 49, 48, 125, 44, 48, 44, 48, 44, 49, 44,
  56, 44, 48, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 51, 61,
  61, 51, 125, 32, 45, 103, 105, 109, 112, 95, 115, 101, 103, 109, 101, 110,
  116, 95, 119, 97, 116, 101, 114, 115, 104, 101, 100, 91, 48, 93, 32, 123,
  36, 52, 42, 53, 125, 44, 123, 36, 53, 47, 50, 125, 44, 48, 44, 48,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 51, 61, 61, 52, 125, 32, 45,
  103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111, 91, 48, 93, 32, 51,
  44, 123, 36, 53, 42, 50, 43, 50, 125, 44, 48, 44, 50, 44, 48, 44,
  49, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 51, 61, 61, 53,
  125, 32, 45, 103, 105, 109, 112, 95, 115, 101, 108, 101, 99, 116, 105, 118,
  101, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 91, 48, 93, 32, 123,
  36, 53, 42, 52, 125, 44, 123, 36, 52, 42, 50, 125, 44, 49, 48, 44,
  49, 48, 44, 48, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 51,
  61, 61, 54, 125, 32, 45, 103, 105, 109, 112, 95, 104, 97, 97, 114, 95,
  115, 109, 111, 111, 116, 104, 105, 110, 103, 91, 48, 93, 32, 123, 49, 48,
  45, 123, 36, 52, 42, 49, 48, 125, 125, 44, 123, 114, 111, 117, 110, 100,
  40, 36, 53, 42, 53, 44, 49, 41, 125, 44, 48, 44, 48, 44, 48, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 51, 61, 61, 55, 125, 32, 45, 116,
  111, 95, 114, 103, 98, 91, 48, 93, 32, 45, 103, 105, 109, 112, 95, 107,
  117, 119, 97, 104, 97, 114, 97, 91, 48, 93, 32, 123, 54, 45, 123, 36,
  52, 42, 53, 125, 125, 44, 123, 49, 43, 123, 36, 53, 42, 50, 46, 57,
  125, 125, 44, 48, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 103,
  105, 109, 112, 95, 109, 105, 120, 95, 108, 97, 98, 91, 48, 93, 32, 49,
  44, 48, 44, 48, 44, 36, 49, 55, 44, 36, 49, 53, 44, 48, 44, 36,
  49, 55, 44, 36, 49, 54, 44, 48, 44, 48, 44, 50, 44, 48, 10, 45,
  105, 102, 32, 123, 36, 50, 53, 61, 61, 48, 125, 10, 45, 103, 105, 109,
  112, 95, 117, 110, 115, 104, 97, 114, 112, 91, 48, 93, 32, 49, 44, 36,
  54, 44, 50, 48, 44, 36, 55, 44, 48, 46, 48, 48, 44, 49, 46, 48,
  48, 44, 48, 46, 53, 44, 49, 44, 48, 44, 55, 44, 48, 10, 45, 101,
  108, 115, 101, 10, 45, 45, 116, 111, 95, 114, 103, 98, 97, 91, 48, 93,
  32, 45, 45, 103, 105, 109, 112, 95, 101, 100, 103, 101, 115, 91, 48, 93,
  32, 36, 54, 44, 123, 51, 48, 45, 123, 36, 55, 42, 53, 125, 125, 44,
  49, 44, 48, 32, 45, 105, 102, 32, 123, 36, 50, 49, 33, 61, 57, 125,
  32, 45, 109, 111, 118, 101, 91, 49, 93, 32, 52, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112,
  91, 49, 93, 32, 49, 44, 36, 54, 44, 50, 48, 44, 36, 55, 44, 48,
  46, 48, 48, 44, 49, 46, 48, 48, 44, 48, 46, 53, 44, 49, 44, 48,
  44, 55, 44, 48, 10, 45, 103, 105, 109, 112, 95, 103, 97, 117, 115, 115,
  105, 97, 110, 95, 98, 108, 117, 114, 91, 50, 93, 32, 123, 123, 119, 43,
  104, 125, 47, 53, 48, 48, 125, 44, 48, 44, 48, 44, 49, 44, 48, 44,
  48, 44, 48, 10, 45, 116, 111, 95, 103, 114, 97, 121, 91, 50, 93, 10,
  45, 115, 112, 108, 105, 116, 91, 49, 93, 32, 99, 10, 45, 105, 102, 32,
  123, 36, 50, 49, 33, 61, 57, 125, 32, 45, 114, 101, 118, 101, 114, 115,
  101, 91, 52, 44, 53, 93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  109, 117, 108, 116, 105, 112, 108, 121, 91, 52, 44, 53, 93, 32, 45, 97,
  112, 112, 101, 110, 100, 91, 45, 53, 44, 45, 52, 44, 45, 51, 44, 45,
  50, 93, 32, 99, 10, 45, 101, 108, 115, 101, 32, 45, 114, 101, 118, 101,
  114, 115, 101, 91, 51, 44, 52, 93, 32, 45, 99, 111, 109, 112, 111, 115,
  101, 95, 109, 117, 108, 116, 105, 112, 108, 121, 91, 51, 44, 52, 93, 32,
  45, 97, 112, 112, 101, 110, 100, 91, 45, 52, 44, 45, 51, 44, 45, 50,
  44, 45, 49, 93, 32, 99, 32, 45, 101, 110, 100, 105, 102, 10, 45, 99,
  111, 109, 112, 111, 115, 101, 95, 114, 103, 98, 97, 91, 48, 44, 49, 93,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 50, 50,
  61, 61, 48, 125, 10, 45, 105, 102, 32, 123, 36, 50, 49, 61, 61, 51,
  125, 32, 32, 45, 114, 101, 118, 101, 114, 115, 101, 32, 45, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 111, 118, 101, 114, 108, 97,
  121, 32, 36, 50, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 49,
  61, 61, 56, 125, 32, 45, 114, 101, 118, 101, 114, 115, 101, 32, 45, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 104, 97, 114, 100,
  108, 105, 103, 104, 116, 32, 36, 50, 48, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 50, 49, 33, 61, 57, 125, 32, 45, 114, 101, 118, 101, 114, 115,
  101, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95,
  109, 117, 108, 116, 105, 112, 108, 121, 32, 36, 50, 48, 10, 45, 101, 110,
  100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 56, 61, 61, 49, 125, 10, 45, 103, 105, 109, 112, 95, 103, 108, 111,
  119, 91, 48, 93, 32, 36, 57, 44, 48, 44, 48, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 56, 61, 61, 50, 125, 32, 45, 45, 103, 105, 109, 112,
  95, 104, 105, 103, 104, 112, 97, 115, 115, 91, 48, 93, 32, 123, 36, 57,
  42, 51, 125, 44, 50, 44, 49, 44, 48, 44, 48, 10, 45, 105, 102, 32,
  123, 123, 36, 50, 50, 61, 61, 49, 125, 38, 38, 123, 36, 50, 49, 33,
  61, 57, 125, 125, 32, 45, 114, 101, 118, 101, 114, 115, 101, 91, 49, 44,
  50, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 118, 101, 114,
  115, 101, 91, 48, 44, 49, 93, 32, 45, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 111, 118, 101, 114, 108, 97, 121, 91, 48, 44,
  49, 93, 32, 123, 36, 57, 47, 52, 48, 125, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 56, 61, 61, 51, 125, 32, 45, 45, 103, 105, 109, 112, 95,
  100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 48, 93, 32, 45, 45,
  103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91,
  48, 93, 10, 45, 105, 102, 32, 123, 123, 36, 50, 50, 61, 61, 49, 125,
  38, 38, 123, 36, 50, 49, 33, 61, 57, 125, 125, 32, 45, 114, 101, 118,
  101, 114, 115, 101, 91, 49, 44, 51, 93, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 115,
  99, 114, 101, 101, 110, 91, 49, 44, 50, 93, 32, 49, 32, 32, 45, 103,
  105, 109, 112, 95, 103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117,
  114, 91, 49, 93, 32, 123, 36, 57, 42, 51, 125, 44, 48, 44, 48, 44,
  49, 44, 48, 44, 48, 44, 48, 10, 45, 114, 101, 118, 101, 114, 115, 101,
  91, 48, 44, 49, 93, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 115, 111, 102, 116, 108, 105, 103, 104, 116, 91, 48, 44,
  49, 93, 32, 123, 36, 57, 47, 50, 48, 125, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 56, 61, 61, 52, 125, 10, 45, 103, 105, 109, 112, 95, 97,
  110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116,
  104, 105, 110, 103, 91, 48, 93, 32, 48, 44, 49, 46, 53, 44, 48, 46,
  51, 44, 123, 36, 57, 47, 52, 125, 44, 49, 46, 49, 48, 44, 48, 46,
  56, 48, 44, 51, 48, 46, 48, 48, 44, 50, 46, 48, 44, 48, 44, 49,
  44, 49, 44, 48, 44, 49, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 56, 61, 61, 53, 125, 10, 45, 45, 103, 105, 109, 112, 95, 109, 105,
  120, 95, 104, 115, 118, 91, 48, 93, 32, 49, 44, 48, 44, 48, 44, 49,
  44, 45, 49, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 44,
  48, 10, 45, 105, 102, 32, 123, 123, 36, 50, 50, 61, 61, 49, 125, 38,
  38, 123, 36, 50, 49, 33, 61, 57, 125, 125, 32, 45, 114, 101, 118, 101,
  114, 115, 101, 91, 49, 44, 50, 93, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108,
  95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 91, 49, 93, 32, 49,
  44, 49, 44, 48, 44, 48, 44, 52, 44, 48, 44, 123, 49, 48, 48, 45,
  123, 36, 57, 42, 50, 46, 53, 125, 125, 44, 50, 53, 54, 44, 48, 44,
  49, 44, 48, 44, 50, 44, 48, 44, 48, 10, 45, 103, 105, 109, 112, 95,
  103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 49, 93,
  32, 36, 57, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 10,
  45, 116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108,
  95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 91, 49, 93, 32, 49,
  44, 49, 44, 48, 44, 48, 44, 52, 44, 48, 44, 123, 53, 48, 45, 123,
  36, 57, 42, 50, 125, 125, 44, 50, 53, 54, 44, 48, 44, 49, 44, 48,
  44, 50, 44, 48, 44, 48, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95,
  114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 49, 93,
  32, 49, 44, 48, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 48,
  44, 48, 44, 48, 44, 48, 10, 45, 103, 105, 109, 112, 95, 103, 97, 117,
  115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 49, 93, 32, 123, 36,
  57, 42, 50, 125, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48,
  10, 45, 114, 101, 118, 101, 114, 115, 101, 91, 48, 44, 49, 93, 32, 45,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 115, 111, 102,
  116, 108, 105, 103, 104, 116, 91, 48, 44, 49, 93, 32, 123, 48, 46, 50,
  53, 43, 123, 36, 57, 47, 49, 53, 48, 125, 125, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 56, 61, 61, 54, 125, 10, 45, 103, 105, 109, 112, 95,
  97, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111,
  116, 104, 105, 110, 103, 91, 48, 93, 32, 32, 54, 48, 44, 48, 46, 49,
  54, 44, 123, 123, 36, 57, 47, 53, 48, 125, 43, 48, 46, 54, 125, 44,
  123, 123, 36, 57, 47, 57, 125, 43, 48, 46, 54, 125, 44, 50, 46, 51,
  53, 44, 48, 46, 56, 44, 51, 48, 44, 50, 44, 48, 44, 49, 44, 49,
  44, 48, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 50, 54, 33, 61, 48, 125, 32, 45, 114, 32, 36, 115, 99, 117,
  112, 37, 44, 36, 115, 99, 117, 112, 37, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109,
  112, 95, 116, 107, 95, 112, 104, 111, 116, 111, 105, 108, 108, 117, 115, 116,
  114, 97, 116, 105, 111, 110, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 116, 107, 95, 112,
  104, 111, 116, 111, 105, 108, 108, 117, 115, 116, 114, 97, 116, 105, 111, 110,
  32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35, 64,
  103, 105, 109, 112, 32, 80, 111, 108, 121, 103, 111, 110, 105, 122, 101, 32,
  58, 32, 103, 105, 109, 112, 95, 112, 111, 108, 121, 103, 111, 110, 105, 122,
  101, 44, 32, 103, 105, 109, 112, 95, 112, 111, 108, 121, 103, 111, 110, 105,
  122, 101, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  32, 61, 32, 105, 110, 116, 40, 51, 48, 48, 44, 48, 44, 50, 48, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 77, 105, 110, 105, 109, 97, 108, 32, 97, 114, 101, 97, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 114, 101, 115, 111,
  108, 117, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  48, 44, 49, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 89, 45, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 49, 44, 50, 53, 54, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 108, 105, 110,
  101, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40,
  48, 44, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117,
  108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117,
  112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 51, 47, 49, 50, 47, 48, 50, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  112, 111, 108, 121, 103, 111, 110, 105, 122, 101, 32, 58, 10, 45, 112, 111,
  108, 121, 103, 111, 110, 105, 122, 101, 32, 36, 49, 44, 36, 50, 44, 123,
  36, 51, 94, 50, 125, 44, 36, 52, 44, 36, 53, 10, 45, 105, 102, 32,
  36, 57, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 45, 110, 111, 114, 109, 32, 45, 103, 114, 97,
  100, 105, 101, 110, 116, 91, 45, 49, 93, 32, 120, 121, 44, 49, 32, 45,
  110, 101, 113, 91, 45, 50, 44, 45, 49, 93, 32, 48, 32, 45, 111, 114,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 114, 91, 45, 49, 93, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 52, 10, 45, 114, 101,
  112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32,
  48, 44, 48, 44, 49, 44, 49, 44, 49, 44, 49, 44, 36, 54, 44, 36,
  55, 44, 36, 56, 44, 36, 57, 10, 45, 98, 108, 101, 110, 100, 32, 97,
  108, 112, 104, 97, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 112, 111, 108,
  121, 103, 111, 110, 105, 122, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 112, 111, 108,
  121, 103, 111, 110, 105, 122, 101, 32, 36, 42, 34, 44, 36, 45, 49, 10,
  35, 64, 103, 105, 109, 112, 32, 80, 111, 115, 116, 101, 114, 105, 122, 101,
  100, 32, 100, 105, 116, 104, 101, 114, 105, 110, 103, 32, 58, 32, 103, 105,
  109, 112, 95, 112, 100, 105, 116, 104, 101, 114, 101, 100, 44, 32, 103, 105,
  109, 112, 95, 112, 100, 105, 116, 104, 101, 114, 101, 100, 95, 112, 114, 101,
  118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 71, 97, 109, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  44, 48, 46, 48, 49, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 66, 114, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 81,
  117, 97, 110, 116, 105, 122, 101, 32, 99, 111, 108, 111, 114, 115, 32, 61,
  32, 105, 110, 116, 40, 50, 48, 44, 50, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 32, 99,
  111, 108, 111, 114, 115, 32, 61, 102, 108, 111, 97, 116, 40, 49, 44, 48,
  44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 105,
  120, 101, 114, 32, 109, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 32, 34, 67, 111, 108, 111, 114, 32, 68, 111, 112, 105, 110, 103,
  34, 44, 32, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 83, 111, 102,
  116, 32, 76, 105, 103, 104, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32,
  77, 101, 114, 103, 101, 34, 44, 32, 34, 77, 117, 108, 116, 105, 112, 108,
  121, 34, 44, 34, 86, 97, 108, 117, 101, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 105, 110, 116, 101, 110,
  115, 105, 116, 121, 32, 61, 102, 108, 111, 97, 116, 32, 40, 49, 44, 48,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 80, 104, 111, 116, 111,
  67, 111, 109, 105, 88, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32,
  60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 112, 100, 105, 116, 104, 101, 114, 101, 100, 32, 58, 10, 45, 45,
  97, 112, 112, 108, 121, 95, 103, 97, 109, 109, 97, 91, 45, 49, 93, 32,
  36, 49, 32, 45, 45, 32, 49, 50, 56, 32, 45, 42, 32, 36, 50, 32,
  45, 43, 32, 49, 50, 56, 32, 45, 43, 32, 36, 51, 32, 45, 98, 108,
  117, 114, 91, 45, 49, 93, 32, 36, 52, 32, 45, 99, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 32, 45, 100, 105, 116, 104, 101, 114, 101, 100,
  98, 119, 91, 45, 49, 93, 10, 45, 113, 117, 97, 110, 116, 105, 122, 101,
  91, 45, 50, 93, 32, 36, 53, 32, 45, 116, 111, 95, 114, 103, 98, 32,
  45, 98, 108, 117, 114, 95, 120, 121, 91, 45, 50, 93, 32, 36, 54, 44,
  36, 54, 10, 45, 105, 102, 32, 123, 36, 55, 61, 61, 48, 125, 32, 45,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 99, 111, 108,
  111, 114, 100, 111, 112, 105, 110, 103, 32, 36, 56, 44, 48, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 55, 61, 61, 49, 125, 32, 45, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101, 110,
  32, 36, 56, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 55, 61,
  61, 50, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 115, 111, 102, 116, 108, 105, 103, 104, 116, 32, 36, 56, 44, 48,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 55, 61, 61, 51, 125, 32, 45,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97,
  105, 110, 109, 101, 114, 103, 101, 32, 36, 56, 44, 48, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 55, 61, 61, 52, 125, 32, 45, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108, 116, 105, 112, 108,
  121, 32, 36, 56, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 55,
  61, 61, 53, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 118, 97, 108, 117, 101, 32, 36, 56, 44, 49, 32, 45, 101,
  110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 112, 100, 105, 116, 104, 101,
  114, 101, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 103, 105, 109, 112, 95, 112, 100, 105, 116, 104, 101, 114,
  101, 100, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10,
  35, 64, 103, 105, 109, 112, 32, 80, 111, 115, 116, 101, 114, 32, 101, 100,
  103, 101, 115, 32, 58, 32, 103, 105, 109, 112, 95, 112, 111, 115, 116, 101,
  114, 95, 101, 100, 103, 101, 115, 44, 32, 103, 105, 109, 112, 95, 112, 111,
  115, 116, 101, 114, 95, 101, 100, 103, 101, 115, 95, 112, 114, 101, 118, 105,
  101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73,
  109, 97, 103, 101, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101, 32,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 54, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 69, 100, 103, 101, 32, 115, 104, 97, 100, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 51, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101, 32, 116, 104,
  105, 99, 107, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  69, 100, 103, 101, 32, 97, 110, 116, 105, 97, 108, 105, 97, 115, 105, 110,
  103, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 111, 115,
  116, 101, 114, 105, 122, 97, 116, 105, 111, 110, 32, 108, 101, 118, 101, 108,
  32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 49, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 80, 111, 115, 116, 101, 114, 105, 122,
  97, 116, 105, 111, 110, 32, 97, 110, 116, 105, 97, 108, 105, 97, 115, 105,
  110, 103, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 115, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115,
  99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 32, 97,
  110, 100, 32, 68, 97, 118, 105, 100, 32, 82, 101, 118, 111, 121, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 50, 47,
  49, 49, 47, 51, 48, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 112, 111, 115, 116, 101, 114,
  95, 101, 100, 103, 101, 115, 32, 58, 10, 45, 105, 102, 32, 36, 49, 32,
  45, 98, 105, 108, 97, 116, 101, 114, 97, 108, 32, 49, 48, 44, 36, 49,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 112, 111, 115, 116, 101, 114, 95,
  101, 100, 103, 101, 115, 32, 36, 123, 50, 45, 55, 125, 10, 103, 105, 109,
  112, 95, 112, 111, 115, 116, 101, 114, 95, 101, 100, 103, 101, 115, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115,
  112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103,
  105, 109, 112, 95, 112, 111, 115, 116, 101, 114, 95, 101, 100, 103, 101, 115,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32,
  80, 115, 121, 99, 104, 101, 100, 101, 108, 105, 99, 32, 103, 108, 97, 115,
  115, 119, 111, 114, 107, 32, 116, 105, 108, 101, 114, 32, 58, 32, 103, 105,
  109, 112, 95, 112, 115, 121, 103, 108, 97, 115, 115, 44, 32, 103, 105, 109,
  112, 95, 112, 115, 121, 103, 108, 97, 115, 115, 95, 112, 114, 101, 118, 105,
  101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 83, 116, 97, 105, 110, 101, 100, 32, 71,
  108, 97, 115, 115, 32, 99, 111, 110, 116, 114, 111, 108, 115, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 87, 104, 105, 116, 101, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 115, 32, 61, 32, 98, 111, 111, 108,
  40, 102, 97, 108, 115, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 69, 100, 103, 101, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50,
  48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 104, 97, 100, 105, 110, 103, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 49, 44, 48, 44, 48, 46, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 84, 104, 105, 110, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 113, 117, 97, 108, 105, 122,
  101, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 84, 111, 32, 115, 107, 105, 112, 32,
  76, 97, 121, 101, 114, 32, 70, 120, 32, 115, 101, 116, 32, 79, 112, 97,
  99, 105, 116, 121, 32, 116, 111, 32, 48, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  76, 97, 121, 101, 114, 32, 102, 120, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 71, 114, 97, 105, 110, 32, 77, 101, 114, 103, 101, 34, 44,
  34, 72, 97, 114, 100, 32, 76, 105, 103, 104, 116, 34, 44, 34, 83, 111,
  102, 116, 32, 76, 105, 103, 104, 116, 34, 44, 34, 79, 118, 101, 114, 108,
  97, 121, 34, 44, 34, 67, 111, 108, 111, 114, 32, 66, 117, 114, 110, 32,
  34, 44, 34, 77, 117, 108, 116, 105, 112, 108, 121, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 81, 117, 105, 99, 107, 32,
  67, 111, 114, 114, 101, 99, 116, 105, 111, 110, 115, 32, 97, 110, 100, 32,
  83, 112, 101, 99, 105, 97, 108, 32, 70, 120, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 65, 112, 112, 108, 121, 32, 109, 97, 115, 107,
  32, 61, 32, 98, 111, 111, 108, 40, 116, 114, 117, 101, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 32, 67, 111, 110, 116, 114, 97, 115, 116, 32, 77, 97,
  115, 107, 32, 112, 114, 101, 115, 101, 116, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  82, 97, 105, 115, 101, 32, 108, 111, 99, 97, 108, 32, 99, 111, 110, 116,
  114, 97, 115, 116, 32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108, 115,
  101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 76, 111, 99, 97, 108, 32, 78,
  111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110, 32, 112, 114, 101,
  115, 101, 116, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 77, 105, 114, 114, 111, 114, 115, 32, 67, 111, 110, 116, 114, 111,
  108, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 99,
  116, 105, 118, 97, 116, 101, 32, 109, 105, 114, 114, 111, 114, 115, 32, 61,
  32, 98, 111, 111, 108, 40, 116, 114, 117, 101, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116,
  40, 49, 44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 45, 111, 102, 102, 115, 101, 116, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 89, 45, 111, 102, 102, 115, 101, 116, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 114, 114, 97, 121, 32, 109, 111,
  100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 50, 44, 34, 88,
  45, 97, 120, 105, 115, 34, 44, 34, 89, 45, 97, 120, 105, 115, 34, 44,
  34, 88, 89, 45, 97, 120, 101, 115, 34, 44, 34, 50, 88, 89, 45, 97,
  120, 101, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73,
  110, 105, 116, 105, 97, 108, 105, 122, 97, 116, 105, 111, 110, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 79, 114, 105, 103, 105, 110, 97, 108,
  34, 44, 34, 77, 105, 114, 114, 111, 114, 32, 88, 34, 44, 34, 77, 105,
  114, 114, 111, 114, 32, 89, 34, 44, 34, 82, 111, 116, 97, 116, 101, 32,
  57, 48, 32, 100, 101, 103, 46, 34, 44, 34, 82, 111, 116, 97, 116, 101,
  32, 49, 56, 48, 32, 100, 101, 103, 46, 34, 44, 34, 82, 111, 116, 97,
  116, 101, 32, 50, 55, 48, 32, 100, 101, 103, 46, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 69, 120, 112, 97, 110, 100, 32, 115, 105,
  122, 101, 32, 61, 32, 95, 98, 111, 111, 108, 40, 102, 97, 108, 115, 101,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 80, 104, 111, 116, 111, 67, 111, 109, 105, 88, 60, 47,
  105, 62, 46, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48, 51, 47, 51,
  48, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 103, 105, 109, 112, 95, 112, 115, 121, 103, 108, 97, 115, 115, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116,
  121, 32, 45, 108, 91, 48, 93, 10, 45, 105, 102, 32, 123, 36, 49, 61,
  61, 48, 125, 10, 45, 98, 108, 117, 114, 32, 48, 46, 49, 32, 45, 115,
  116, 97, 105, 110, 101, 100, 95, 103, 108, 97, 115, 115, 32, 36, 50, 44,
  36, 51, 44, 36, 52, 32, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 10, 45, 110, 101,
  103, 97, 116, 105, 118, 101, 32, 45, 98, 108, 117, 114, 32, 48, 46, 49,
  32, 45, 115, 116, 97, 105, 110, 101, 100, 95, 103, 108, 97, 115, 115, 32,
  36, 50, 44, 36, 51, 44, 36, 52, 32, 45, 110, 32, 48, 44, 50, 53,
  53, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 36, 53, 32, 45, 101, 113, 117, 97, 108,
  105, 122, 101, 32, 50, 53, 54, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  45, 98, 108, 117, 114, 32, 48, 46, 57, 10, 45, 105, 102, 32, 123, 36,
  54, 61, 61, 48, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 32, 36,
  55, 10, 45, 101, 108, 105, 102, 32, 123, 36, 54, 61, 61, 49, 125, 32,
  45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 104, 97,
  114, 100, 108, 105, 103, 104, 116, 32, 36, 55, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 54, 61, 61, 50, 125, 32, 45, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 115, 111, 102, 116, 108, 105, 103, 104, 116,
  32, 36, 55, 10, 45, 101, 108, 105, 102, 32, 123, 36, 54, 61, 61, 51,
  125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95,
  111, 118, 101, 114, 108, 97, 121, 32, 36, 55, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 54, 61, 61, 52, 125, 32, 45, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 99, 111, 108, 111, 114, 98, 117, 114, 110,
  32, 36, 55, 10, 45, 101, 108, 105, 102, 32, 123, 36, 54, 61, 61, 53,
  125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95,
  109, 117, 108, 116, 105, 112, 108, 121, 32, 36, 55, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 56, 61, 61, 49, 125, 32, 45,
  103, 105, 109, 112, 95, 99, 111, 110, 116, 114, 97, 115, 116, 95, 115, 119,
  109, 32, 50, 44, 48, 44, 49, 44, 48, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 57, 61, 61, 49, 125, 32, 45, 103, 105,
  109, 112, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 108, 111, 99,
  97, 108, 32, 50, 44, 54, 44, 53, 44, 50, 48, 44, 49, 44, 51, 44,
  48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 49, 48,
  10, 45, 105, 102, 32, 123, 36, 49, 53, 61, 61, 49, 125, 32, 45, 109,
  105, 114, 114, 111, 114, 32, 120, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  49, 53, 61, 61, 50, 125, 32, 45, 109, 105, 114, 114, 111, 114, 32, 121,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 53, 61, 61, 51, 125, 32,
  45, 114, 111, 116, 97, 116, 101, 32, 57, 48, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 53, 61, 61, 52, 125, 32, 45, 114, 111, 116, 97, 116,
  101, 32, 49, 56, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 53,
  61, 61, 53, 125, 32, 45, 114, 111, 116, 97, 116, 101, 32, 50, 55, 48,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 97, 114, 114, 97, 121, 95, 109,
  105, 114, 114, 111, 114, 32, 36, 49, 49, 44, 36, 49, 52, 44, 36, 49,
  54, 10, 45, 115, 104, 105, 102, 116, 32, 45, 36, 49, 50, 37, 44, 45,
  36, 49, 51, 37, 44, 48, 44, 48, 44, 50, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 112, 115,
  121, 103, 108, 97, 115, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 32, 45, 103, 105, 109, 112, 95, 112, 115, 121,
  103, 108, 97, 115, 115, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36,
  45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 82, 111, 100, 105, 108, 105,
  117, 115, 32, 58, 32, 103, 105, 109, 112, 95, 114, 111, 100, 105, 108, 105,
  117, 115, 44, 32, 103, 105, 109, 112, 95, 114, 111, 100, 105, 108, 105, 117,
  115, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 51, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 105, 99, 107, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  104, 97, 114, 112, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 51, 48, 48, 44, 48, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 79, 114, 105, 101, 110, 116, 97, 116, 105, 111,
  110, 115, 32, 61, 32, 105, 110, 116, 40, 53, 44, 50, 44, 51, 54, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 102, 102, 115, 101, 116,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 48, 44, 48, 44, 49, 56,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48,
  44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108,
  111, 114, 32, 109, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 49, 44, 34, 68, 97, 114, 107, 101, 114, 34, 44, 34, 76, 105, 103,
  104, 116, 101, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34,
  44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114,
  111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101,
  32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82,
  101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83,
  97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117,
  101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32,
  99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34,
  71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65,
  108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99,
  97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65,
  117, 116, 104, 111, 114, 115, 58, 32, 60, 105, 62, 82, 111, 100, 47, 71,
  105, 109, 112, 67, 104, 97, 116, 60, 47, 105, 62, 32, 97, 110, 100, 32,
  60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112,
  101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 51, 47, 48, 53,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  103, 105, 109, 112, 95, 114, 111, 100, 105, 108, 105, 117, 115, 32, 58, 10,
  45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  34, 45, 114, 111, 100, 105, 108, 105, 117, 115, 32, 36, 123, 49, 45, 53,
  44, 55, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 54, 32, 45,
  115, 109, 111, 111, 116, 104, 32, 49, 48, 44, 48, 44, 49, 44, 49, 44,
  49, 44, 48, 46, 56, 44, 52, 53, 32, 45, 115, 104, 97, 114, 112, 101,
  110, 32, 51, 48, 32, 45, 100, 111, 110, 101, 32, 45, 99, 32, 48, 44,
  50, 53, 53, 34, 44, 36, 56, 44, 48, 10, 103, 105, 109, 112, 95, 114,
  111, 100, 105, 108, 105, 117, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 114, 111, 100,
  105, 108, 105, 117, 115, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64,
  103, 105, 109, 112, 32, 83, 104, 97, 112, 101, 105, 115, 109, 32, 58, 32,
  103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 105, 115, 109, 44, 32, 103,
  105, 109, 112, 95, 115, 104, 97, 112, 101, 105, 115, 109, 95, 112, 114, 101,
  118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 104, 97, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  50, 44, 34, 83, 113, 117, 97, 114, 101, 115, 34, 44, 34, 84, 114, 105,
  97, 110, 103, 108, 101, 115, 34, 44, 34, 67, 105, 114, 99, 108, 101, 115,
  34, 44, 34, 68, 105, 97, 109, 111, 110, 100, 34, 44, 34, 72, 101, 120,
  97, 103, 111, 110, 34, 44, 34, 79, 99, 116, 97, 103, 111, 110, 34, 44,
  34, 83, 116, 97, 114, 115, 34, 44, 34, 67, 117, 115, 116, 111, 109, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 114, 97, 110, 99,
  104, 101, 115, 32, 61, 32, 105, 110, 116, 40, 55, 44, 50, 44, 49, 54,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 105, 99, 107,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 51,
  56, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  65, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 60, 98, 62, 78, 111, 116, 101, 58, 60, 47, 98, 62,
  32, 80, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 60, 105, 62, 66,
  114, 97, 110, 99, 104, 101, 115, 60, 47, 105, 62, 44, 32, 60, 105, 62,
  84, 104, 105, 99, 107, 110, 101, 115, 115, 60, 47, 105, 62, 32, 97, 110,
  100, 32, 60, 105, 62, 65, 110, 103, 108, 101, 60, 47, 105, 62, 32, 97,
  114, 101, 32, 117, 115, 101, 100, 32, 111, 110, 108, 121, 32, 102, 111, 114,
  32, 60, 105, 62, 67, 117, 115, 116, 111, 109, 60, 47, 105, 62, 32, 115,
  104, 97, 112, 101, 115, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 116, 105, 97, 108,
  105, 97, 115, 105, 110, 103, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 115, 32, 61, 32, 105, 110,
  116, 40, 53, 44, 49, 44, 49, 54, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 77, 97, 120, 105, 109, 97, 108, 32, 115, 105, 122, 101, 32,
  61, 32, 105, 110, 116, 40, 51, 50, 44, 49, 44, 50, 53, 54, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 105, 110, 105, 109, 97, 108,
  32, 115, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 56, 44, 49, 44,
  50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 108,
  108, 111, 119, 32, 97, 110, 103, 108, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 51, 44, 34, 48, 32, 100, 101, 103, 46, 34, 44, 34, 49,
  56, 48, 32, 100, 101, 103, 46, 34, 44, 34, 57, 48, 32, 100, 101, 103,
  46, 34, 44, 34, 65, 110, 121, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 112, 97, 99, 105, 110, 103, 32, 61, 32, 105, 110, 116,
  40, 49, 44, 45, 53, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 80, 114, 101, 99, 105, 115, 105, 111, 110, 32, 61, 32, 105, 110,
  116, 40, 53, 44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 69, 100, 103, 101, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 53, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 66, 97, 99, 107, 103, 114, 111, 117, 110,
  100, 32, 61, 32, 99, 111, 108, 111, 114, 40, 48, 44, 48, 44, 48, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 51, 47, 48, 54, 47, 49, 49, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 115, 104, 97, 112, 101, 105, 115, 109, 32, 58, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45,
  116, 111, 95, 114, 103, 98, 10, 45, 45, 103, 114, 97, 100, 105, 101, 110,
  116, 95, 110, 111, 114, 109, 32, 45, 98, 91, 45, 49, 93, 32, 36, 49,
  51, 37, 32, 45, 112, 111, 119, 91, 45, 49, 93, 32, 36, 49, 50, 32,
  45, 113, 117, 97, 110, 116, 105, 122, 101, 91, 45, 49, 93, 32, 36, 54,
  44, 48, 44, 48, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 50, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 54, 10, 45, 45,
  99, 104, 97, 110, 110, 101, 108, 115, 91, 50, 93, 32, 49, 48, 48, 37,
  32, 45, 45, 103, 116, 91, 49, 93, 32, 36, 62, 32, 45, 110, 101, 113,
  91, 45, 50, 93, 32, 48, 32, 45, 111, 114, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 97, 91, 50, 44, 45, 49, 93, 32, 99, 10, 115, 105, 122,
  101, 61, 123, 105, 102, 40, 36, 54, 60, 61, 49, 44, 36, 55, 44, 36,
  55, 43, 40, 36, 56, 45, 36, 55, 41, 42, 36, 62, 47, 40, 36, 54,
  45, 49, 41, 41, 125, 10, 45, 105, 102, 32, 123, 36, 115, 105, 122, 101,
  60, 49, 125, 32, 45, 98, 114, 101, 97, 107, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 36, 53, 32, 123, 50, 42, 36, 115, 105, 122,
  101, 125, 44, 123, 50, 42, 36, 115, 105, 122, 101, 125, 32, 45, 95, 103,
  105, 109, 112, 95, 115, 104, 97, 112, 101, 105, 115, 109, 36, 49, 91, 45,
  49, 93, 32, 36, 123, 50, 45, 52, 125, 32, 45, 114, 50, 100, 121, 91,
  45, 49, 93, 32, 36, 115, 105, 122, 101, 10, 45, 101, 108, 115, 101, 32,
  36, 115, 105, 122, 101, 44, 36, 115, 105, 122, 101, 32, 45, 95, 103, 105,
  109, 112, 95, 115, 104, 97, 112, 101, 105, 115, 109, 36, 49, 91, 45, 49,
  93, 32, 36, 123, 50, 45, 52, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 45, 110, 101, 113, 91, 45, 49, 93, 32, 48, 32, 45, 101, 120, 112,
  97, 110, 100, 95, 120, 121, 91, 45, 50, 44, 45, 49, 93, 32, 49, 44,
  48, 32, 45, 110, 91, 45, 50, 44, 45, 49, 93, 32, 48, 44, 49, 10,
  45, 105, 102, 32, 123, 36, 49, 48, 60, 49, 125, 32, 45, 100, 105, 108,
  97, 116, 101, 91, 45, 49, 93, 32, 51, 32, 45, 101, 110, 100, 105, 102,
  10, 91, 45, 49, 93, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32,
  99, 10, 45, 114, 112, 114, 111, 103, 114, 101, 115, 115, 32, 34, 45, 112,
  97, 99, 107, 95, 115, 112, 114, 105, 116, 101, 115, 91, 45, 50, 44, 45,
  49, 93, 32, 49, 44, 49, 48, 48, 44, 36, 57, 44, 36, 49, 48, 44,
  36, 49, 49, 34, 44, 123, 36, 62, 42, 49, 48, 48, 47, 36, 54, 125,
  44, 123, 40, 36, 62, 43, 49, 41, 42, 49, 48, 48, 47, 36, 54, 125,
  10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48,
  44, 49, 10, 45, 100, 111, 110, 101, 10, 45, 114, 112, 114, 111, 103, 114,
  101, 115, 115, 32, 57, 55, 10, 45, 114, 109, 91, 49, 93, 10, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 32, 45, 45,
  110, 101, 113, 91, 45, 49, 93, 32, 48, 32, 45, 98, 108, 101, 110, 100,
  91, 48, 44, 45, 49, 93, 32, 115, 104, 97, 112, 101, 97, 118, 101, 114,
  97, 103, 101, 48, 32, 45, 42, 91, 49, 93, 32, 50, 53, 53, 32, 45,
  97, 32, 99, 10, 45, 105, 91, 48, 93, 32, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 49, 44, 52, 32, 45, 102, 99, 91, 48, 93, 32, 36,
  49, 52, 44, 36, 49, 53, 44, 36, 49, 54, 44, 36, 49, 55, 10, 45,
  98, 108, 101, 110, 100, 32, 97, 108, 112, 104, 97, 10, 45, 114, 112, 114,
  111, 103, 114, 101, 115, 115, 32, 49, 48, 48, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 115, 104, 97, 112,
  101, 105, 115, 109, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  105, 102, 32, 64, 35, 62, 61, 49, 32, 45, 107, 91, 48, 93, 32, 45,
  101, 108, 115, 101, 32, 50, 53, 54, 44, 50, 53, 54, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 110, 111, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 32, 34, 44, 34, 36, 42, 34, 10, 53,
  48, 37, 44, 53, 48, 37, 32, 45, 95, 103, 105, 109, 112, 95, 115, 104,
  97, 112, 101, 105, 115, 109, 36, 49, 91, 45, 49, 93, 32, 36, 123, 50,
  45, 52, 125, 32, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93, 32, 49,
  44, 49, 44, 48, 32, 45, 103, 101, 91, 45, 49, 93, 32, 53, 48, 37,
  32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 114,
  91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 52, 10, 45, 114, 91, 45, 49, 93, 32, 91, 48, 93, 44, 48, 44,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 111, 114, 10, 95, 103,
  105, 109, 112, 95, 115, 104, 97, 112, 101, 105, 115, 109, 48, 32, 58, 10,
  45, 102, 32, 50, 53, 53, 32, 45, 115, 107, 105, 112, 32, 36, 42, 10,
  95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 105, 115, 109, 49, 32,
  58, 10, 45, 112, 111, 108, 121, 103, 111, 110, 32, 51, 44, 53, 48, 37,
  44, 48, 44, 48, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 49, 44, 49, 32, 45, 115, 107, 105, 112, 32, 36, 42,
  10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 105, 115, 109, 50,
  32, 58, 10, 45, 95, 100, 116, 95, 99, 105, 114, 99, 108, 101, 32, 123,
  119, 125, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45, 115, 107, 105, 112,
  32, 36, 42, 10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 105,
  115, 109, 51, 32, 58, 10, 45, 95, 100, 116, 95, 100, 105, 97, 109, 111,
  110, 100, 32, 123, 119, 125, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45,
  115, 107, 105, 112, 32, 36, 42, 10, 95, 103, 105, 109, 112, 95, 115, 104,
  97, 112, 101, 105, 115, 109, 52, 32, 58, 10, 45, 115, 116, 97, 114, 51,
  100, 32, 51, 44, 49, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 64,
  123, 48, 44, 109, 105, 110, 40, 119, 44, 104, 41, 47, 50, 125, 32, 45,
  111, 98, 106, 101, 99, 116, 51, 100, 91, 48, 93, 32, 91, 45, 49, 93,
  44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 49, 44, 50, 44, 48,
  32, 45, 107, 91, 48, 93, 32, 45, 115, 107, 105, 112, 32, 36, 42, 10,
  95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 105, 115, 109, 53, 32,
  58, 10, 45, 115, 116, 97, 114, 51, 100, 32, 52, 44, 49, 32, 45, 42,
  51, 100, 91, 45, 49, 93, 32, 64, 123, 48, 44, 109, 105, 110, 40, 119,
  44, 104, 41, 47, 50, 125, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100,
  91, 48, 93, 32, 91, 45, 49, 93, 44, 53, 48, 37, 44, 53, 48, 37,
  44, 48, 44, 49, 44, 50, 44, 48, 32, 45, 107, 91, 48, 93, 32, 45,
  115, 107, 105, 112, 32, 36, 42, 10, 95, 103, 105, 109, 112, 95, 115, 104,
  97, 112, 101, 105, 115, 109, 54, 32, 58, 10, 45, 115, 116, 97, 114, 51,
  100, 32, 53, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 64, 123, 48,
  44, 109, 105, 110, 40, 119, 44, 104, 41, 47, 50, 125, 32, 45, 111, 98,
  106, 101, 99, 116, 51, 100, 91, 48, 93, 32, 91, 45, 49, 93, 44, 53,
  48, 37, 44, 53, 48, 37, 44, 48, 44, 49, 44, 50, 44, 48, 32, 45,
  107, 91, 48, 93, 32, 45, 115, 107, 105, 112, 32, 36, 42, 10, 95, 103,
  105, 109, 112, 95, 115, 104, 97, 112, 101, 105, 115, 109, 55, 32, 58, 10,
  45, 115, 116, 97, 114, 51, 100, 32, 36, 49, 44, 36, 50, 32, 45, 42,
  51, 100, 91, 45, 49, 93, 32, 64, 123, 48, 44, 109, 105, 110, 40, 119,
  44, 104, 41, 47, 50, 125, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32,
  48, 44, 48, 44, 49, 44, 36, 51, 32, 45, 111, 98, 106, 101, 99, 116,
  51, 100, 91, 48, 93, 32, 91, 45, 49, 93, 44, 53, 48, 37, 44, 53,
  48, 37, 44, 48, 44, 49, 44, 50, 44, 48, 32, 45, 107, 91, 48, 93,
  10, 35, 64, 103, 105, 109, 112, 32, 83, 105, 109, 112, 108, 101, 32, 110,
  111, 105, 115, 101, 32, 99, 97, 110, 118, 97, 115, 32, 58, 32, 103, 105,
  109, 112, 95, 83, 105, 109, 112, 108, 101, 78, 111, 105, 115, 101, 67, 97,
  110, 118, 97, 115, 44, 32, 103, 105, 109, 112, 95, 83, 105, 109, 112, 108,
  101, 78, 111, 105, 115, 101, 67, 97, 110, 118, 97, 115, 80, 114, 101, 118,
  105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 83, 105, 109,
  112, 101, 32, 110, 111, 105, 115, 101, 32, 98, 97, 115, 101, 100, 32, 120,
  121, 32, 99, 97, 110, 118, 97, 115, 32, 101, 102, 102, 101, 99, 116, 46,
  32, 80, 114, 101, 115, 101, 114, 118, 101, 32, 99, 97, 110, 118, 97, 115,
  32, 97, 110, 100, 32, 98, 117, 109, 112, 109, 97, 112, 32, 105, 109, 97,
  103, 101, 32, 119, 105, 116, 104, 32, 99, 97, 110, 118, 97, 115, 32, 97,
  102, 116, 101, 114, 32, 102, 105, 108, 116, 101, 114, 105, 110, 103, 32, 102,
  111, 114, 32, 98, 101, 115, 116, 32, 114, 101, 115, 117, 108, 116, 115, 46,
  32, 77, 101, 114, 103, 101, 32, 111, 112, 116, 105, 111, 110, 32, 68, 111,
  78, 111, 116, 104, 105, 110, 103, 32, 111, 117, 116, 112, 117, 116, 115, 32,
  111, 110, 108, 121, 32, 111, 114, 105, 103, 105, 110, 97, 108, 32, 105, 109,
  97, 103, 101, 32, 105, 102, 32, 80, 114, 101, 115, 101, 114, 118, 101, 32,
  99, 97, 110, 118, 97, 115, 32, 111, 112, 116, 105, 111, 110, 32, 105, 115,
  32, 110, 111, 116, 32, 115, 101, 108, 101, 99, 116, 101, 100, 46, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 102, 97, 99, 116, 111,
  114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 78, 111, 105, 115, 101, 32, 112, 97, 114, 97, 109, 101, 116, 101,
  114, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109,
  112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  51, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 105, 115, 101, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 50, 44, 34, 71, 97, 117, 115, 115, 105, 97, 110,
  34, 44, 34, 85, 110, 105, 102, 111, 114, 109, 34, 44, 34, 83, 97, 108,
  116, 32, 97, 110, 100, 32, 112, 101, 112, 112, 101, 114, 34, 44, 34, 80,
  111, 105, 115, 115, 111, 110, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 84, 104, 114, 101, 97, 100,
  32, 108, 101, 110, 103, 116, 104, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 72, 111, 114, 105, 115, 111, 110, 116, 97, 108, 32, 108, 101,
  110, 103, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 50,
  44, 49, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 101,
  114, 116, 105, 99, 97, 108, 32, 108, 101, 110, 103, 116, 104, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 53, 44, 50, 44, 49, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 79, 118, 101, 114, 32, 97, 108, 108, 32,
  98, 108, 117, 114, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 49, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  97, 110, 118, 97, 115, 32, 98, 114, 105, 103, 104, 116, 110, 101, 115, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 53, 53, 44, 50, 51, 48,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  97, 110, 118, 97, 115, 32, 100, 97, 114, 107, 110, 101, 115, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 72, 111, 119, 32, 116, 111, 32, 99, 111, 109, 98, 105, 110, 101, 32,
  88, 89, 32, 116, 104, 114, 101, 97, 100, 115, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 77, 101, 114, 103, 105, 110, 103, 32, 111, 112,
  116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 50, 44,
  34, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 77, 117, 108, 116, 105,
  112, 108, 121, 34, 44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 69,
  100, 103, 101, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  73, 110, 118, 101, 114, 116, 32, 99, 97, 110, 118, 97, 115, 32, 99, 111,
  108, 111, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 118, 101, 114, 116, 32, 105,
  109, 97, 103, 101, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32, 98, 111,
  111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 72, 111, 119, 32,
  116, 111, 32, 99, 111, 109, 98, 105, 110, 101, 32, 105, 109, 97, 103, 101,
  32, 43, 32, 99, 97, 110, 118, 97, 115, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 115, 101, 32, 111, 114, 100,
  101, 114, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 77, 101, 114, 103, 105, 110, 103, 32, 111, 112,
  116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 32, 40, 49,
  44, 34, 65, 118, 103, 34, 44, 34, 77, 117, 108, 116, 105, 112, 108, 121,
  34, 44, 34, 83, 99, 114, 34, 44, 34, 68, 97, 114, 107, 101, 110, 34,
  44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44, 34, 68, 105, 102, 34,
  44, 34, 78, 101, 103, 97, 116, 105, 111, 110, 34, 44, 34, 69, 120, 99,
  108, 117, 115, 105, 111, 110, 34, 44, 34, 79, 118, 101, 114, 108, 97, 121,
  34, 44, 34, 72, 97, 114, 100, 108, 105, 103, 104, 116, 34, 44, 34, 83,
  111, 102, 116, 108, 105, 103, 104, 116, 34, 44, 34, 68, 111, 100, 103, 101,
  34, 44, 34, 67, 111, 108, 111, 114, 98, 117, 114, 110, 34, 44, 34, 82,
  101, 102, 108, 101, 99, 116, 34, 44, 34, 70, 114, 101, 101, 122, 101, 34,
  44, 34, 83, 116, 97, 109, 112, 34, 44, 34, 73, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 101, 34, 44, 34, 71, 114, 97, 105, 110, 101, 120, 116,
  34, 44, 34, 71, 114, 97, 105, 110, 109, 101, 114, 103, 101, 34, 44, 34,
  88, 111, 114, 34, 44, 34, 69, 100, 103, 101, 115, 34, 44, 34, 68, 111,
  78, 111, 116, 104, 105, 110, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 80, 114, 101, 115, 101, 114, 118, 101, 32, 99, 97, 110, 118,
  97, 115, 32, 102, 111, 114, 32, 112, 111, 115, 116, 32, 98, 117, 109, 112,
  32, 109, 97, 112, 112, 105, 110, 103, 32, 61, 32, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 97, 110, 118,
  97, 115, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114,
  40, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 65, 114, 116, 111, 32, 72,
  117, 111, 116, 97, 114, 105, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58,
  32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 57, 47, 50, 56, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105,
  110, 107, 40, 34, 70, 105, 108, 116, 101, 114, 32, 69, 120, 112, 108, 97,
  105, 110, 101, 100, 32, 104, 101, 114, 101, 34, 44, 34, 104, 116, 116, 112,
  58, 47, 47, 119, 119, 119, 46, 102, 108, 105, 99, 107, 114, 46, 99, 111,
  109, 47, 112, 104, 111, 116, 111, 115, 47, 110, 97, 103, 103, 111, 98, 111,
  116, 47, 54, 49, 53, 50, 48, 52, 48, 54, 52, 50, 47, 34, 41, 10,
  103, 105, 109, 112, 95, 83, 105, 109, 112, 108, 101, 78, 111, 105, 115, 101,
  67, 97, 110, 118, 97, 115, 32, 58, 10, 67, 97, 110, 118, 97, 115, 83,
  99, 97, 108, 101, 61, 123, 36, 49, 125, 10, 78, 111, 105, 115, 101, 65,
  109, 112, 108, 105, 116, 117, 100, 101, 61, 36, 50, 10, 78, 111, 105, 115,
  101, 84, 121, 112, 101, 61, 36, 51, 10, 84, 104, 114, 101, 97, 100, 72,
  111, 114, 105, 122, 76, 101, 110, 61, 36, 52, 10, 84, 104, 114, 101, 97,
  100, 86, 101, 114, 116, 76, 101, 110, 61, 36, 53, 10, 79, 118, 101, 114,
  65, 108, 108, 66, 108, 117, 114, 114, 61, 36, 54, 10, 72, 105, 103, 104,
  67, 117, 116, 61, 36, 55, 10, 76, 111, 119, 67, 117, 116, 61, 36, 56,
  10, 67, 97, 110, 118, 97, 115, 77, 101, 114, 103, 101, 67, 104, 111, 105,
  99, 101, 61, 36, 57, 10, 73, 110, 118, 101, 114, 116, 67, 97, 110, 118,
  97, 115, 67, 111, 108, 111, 114, 115, 61, 36, 49, 48, 10, 73, 110, 118,
  101, 114, 116, 73, 109, 97, 103, 101, 67, 111, 108, 111, 114, 115, 61, 36,
  49, 49, 10, 82, 101, 118, 101, 114, 115, 101, 67, 104, 111, 105, 99, 101,
  61, 36, 49, 50, 10, 77, 101, 114, 103, 101, 67, 104, 111, 105, 99, 101,
  61, 36, 49, 51, 10, 80, 114, 101, 115, 101, 114, 118, 101, 67, 97, 110,
  118, 97, 115, 61, 36, 49, 52, 10, 45, 116, 111, 95, 114, 103, 98, 91,
  48, 93, 10, 67, 97, 110, 118, 97, 115, 83, 99, 97, 108, 101, 61, 123,
  49, 46, 50, 45, 36, 67, 97, 110, 118, 97, 115, 83, 99, 97, 108, 101,
  125, 10, 40, 50, 53, 53, 94, 50, 53, 53, 94, 50, 53, 53, 41, 10,
  45, 114, 91, 45, 49, 93, 32, 91, 48, 93, 10, 45, 114, 91, 49, 93,
  32, 123, 49, 48, 48, 42, 36, 67, 97, 110, 118, 97, 115, 83, 99, 97,
  108, 101, 125, 37, 44, 123, 49, 48, 48, 42, 36, 67, 97, 110, 118, 97,
  115, 83, 99, 97, 108, 101, 125, 37, 10, 45, 105, 102, 32, 123, 36, 78,
  111, 105, 115, 101, 84, 121, 112, 101, 33, 61, 50, 125, 32, 78, 111, 105,
  115, 101, 65, 109, 112, 108, 105, 116, 117, 100, 101, 61, 123, 40, 36, 78,
  111, 105, 115, 101, 65, 109, 112, 108, 105, 116, 117, 100, 101, 42, 49, 48,
  41, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95,
  110, 111, 105, 115, 101, 91, 49, 93, 32, 36, 78, 111, 105, 115, 101, 65,
  109, 112, 108, 105, 116, 117, 100, 101, 44, 36, 78, 111, 105, 115, 101, 84,
  121, 112, 101, 44, 48, 44, 49, 44, 48, 10, 45, 103, 105, 109, 112, 95,
  100, 105, 116, 104, 101, 114, 101, 100, 98, 119, 91, 49, 93, 32, 49, 44,
  49, 44, 48, 44, 48, 44, 48, 44, 48, 10, 45, 45, 103, 105, 109, 112,
  95, 103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 49,
  93, 32, 48, 44, 36, 84, 104, 114, 101, 97, 100, 72, 111, 114, 105, 122,
  76, 101, 110, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 10, 45, 45,
  103, 105, 109, 112, 95, 103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108,
  117, 114, 91, 49, 93, 32, 48, 44, 48, 44, 36, 84, 104, 114, 101, 97,
  100, 86, 101, 114, 116, 76, 101, 110, 44, 49, 44, 48, 44, 48, 44, 48,
  10, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 91, 50, 93, 32, 48,
  44, 50, 53, 53, 10, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 91,
  51, 93, 32, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36, 67,
  97, 110, 118, 97, 115, 77, 101, 114, 103, 101, 67, 104, 111, 105, 99, 101,
  61, 61, 48, 125, 32, 45, 98, 108, 101, 110, 100, 91, 50, 44, 51, 93,
  32, 97, 118, 101, 114, 97, 103, 101, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 67, 97, 110, 118, 97, 115, 77, 101, 114, 103, 101, 67, 104, 111, 105,
  99, 101, 61, 61, 49, 125, 32, 45, 98, 108, 101, 110, 100, 91, 50, 44,
  51, 93, 32, 109, 117, 108, 116, 105, 112, 108, 121, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 67, 97, 110, 118, 97, 115, 77, 101, 114, 103, 101, 67,
  104, 111, 105, 99, 101, 61, 61, 50, 125, 32, 45, 98, 108, 101, 110, 100,
  91, 50, 44, 51, 93, 32, 100, 97, 114, 107, 101, 110, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 67, 97, 110, 118, 97, 115, 77, 101, 114, 103, 101,
  67, 104, 111, 105, 99, 101, 61, 61, 51, 125, 32, 45, 98, 108, 101, 110,
  100, 95, 101, 100, 103, 101, 115, 91, 50, 44, 51, 93, 32, 48, 46, 57,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 103, 97,
  117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 50, 93, 32, 36,
  79, 118, 101, 114, 65, 108, 108, 66, 108, 117, 114, 114, 44, 48, 44, 48,
  44, 49, 44, 48, 44, 48, 44, 48, 10, 45, 114, 101, 109, 111, 118, 101,
  91, 49, 93, 10, 45, 114, 91, 49, 93, 32, 91, 48, 93, 10, 40, 36,
  49, 53, 94, 36, 49, 54, 94, 36, 49, 55, 41, 10, 45, 114, 91, 50,
  93, 32, 91, 48, 93, 10, 45, 98, 108, 101, 110, 100, 91, 49, 44, 50,
  93, 32, 109, 117, 108, 116, 105, 112, 108, 121, 10, 45, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 32, 123, 36, 76,
  111, 119, 67, 117, 116, 125, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49,
  44, 49, 50, 56, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49,
  50, 56, 44, 45, 49, 44, 49, 50, 56, 44, 123, 36, 72, 105, 103, 104,
  67, 117, 116, 125, 44, 49, 44, 51, 44, 48, 44, 48, 44, 48, 10, 45,
  105, 102, 32, 123, 36, 82, 101, 118, 101, 114, 115, 101, 67, 104, 111, 105,
  99, 101, 61, 61, 49, 125, 32, 45, 114, 101, 118, 101, 114, 115, 101, 91,
  48, 44, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 73, 110, 118, 101, 114, 116, 67, 97, 110, 118, 97, 115, 67, 111,
  108, 111, 114, 115, 61, 61, 49, 125, 32, 45, 110, 101, 103, 97, 116, 105,
  118, 101, 91, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 73, 110, 118, 101, 114, 116, 73, 109, 97, 103, 101, 67, 111,
  108, 111, 114, 115, 61, 61, 49, 125, 32, 45, 110, 101, 103, 97, 116, 105,
  118, 101, 91, 48, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 77, 101, 114, 103, 101, 67, 104, 111, 105, 99, 101, 61, 61,
  48, 125, 32, 45, 45, 98, 108, 101, 110, 100, 91, 49, 44, 48, 93, 32,
  97, 118, 101, 114, 97, 103, 101, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  77, 101, 114, 103, 101, 67, 104, 111, 105, 99, 101, 61, 61, 49, 125, 32,
  45, 45, 98, 108, 101, 110, 100, 91, 49, 44, 48, 93, 32, 109, 117, 108,
  116, 105, 112, 108, 121, 10, 45, 101, 108, 105, 102, 32, 123, 36, 77, 101,
  114, 103, 101, 67, 104, 111, 105, 99, 101, 61, 61, 50, 125, 32, 45, 45,
  98, 108, 101, 110, 100, 91, 49, 44, 48, 93, 32, 115, 99, 114, 101, 101,
  110, 10, 45, 101, 108, 105, 102, 32, 123, 36, 77, 101, 114, 103, 101, 67,
  104, 111, 105, 99, 101, 61, 61, 51, 125, 32, 45, 45, 98, 108, 101, 110,
  100, 91, 49, 44, 48, 93, 32, 100, 97, 114, 107, 101, 110, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 77, 101, 114, 103, 101, 67, 104, 111, 105, 99,
  101, 61, 61, 52, 125, 32, 45, 45, 98, 108, 101, 110, 100, 91, 49, 44,
  48, 93, 32, 108, 105, 103, 104, 116, 101, 110, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 77, 101, 114, 103, 101, 67, 104, 111, 105, 99, 101, 61, 61,
  53, 125, 32, 45, 45, 98, 108, 101, 110, 100, 91, 49, 44, 48, 93, 32,
  100, 105, 102, 102, 101, 114, 101, 110, 99, 101, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 77, 101, 114, 103, 101, 67, 104, 111, 105, 99, 101, 61, 61,
  54, 125, 32, 45, 45, 98, 108, 101, 110, 100, 91, 49, 44, 48, 93, 32,
  110, 101, 103, 97, 116, 105, 111, 110, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 77, 101, 114, 103, 101, 67, 104, 111, 105, 99, 101, 61, 61, 55, 125,
  32, 45, 45, 98, 108, 101, 110, 100, 91, 49, 44, 48, 93, 32, 101, 120,
  99, 108, 117, 115, 105, 111, 110, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  77, 101, 114, 103, 101, 67, 104, 111, 105, 99, 101, 61, 61, 56, 125, 32,
  45, 45, 98, 108, 101, 110, 100, 91, 49, 44, 48, 93, 32, 111, 118, 101,
  114, 108, 97, 121, 10, 45, 101, 108, 105, 102, 32, 123, 36, 77, 101, 114,
  103, 101, 67, 104, 111, 105, 99, 101, 61, 61, 57, 125, 32, 45, 45, 98,
  108, 101, 110, 100, 91, 49, 44, 48, 93, 32, 104, 97, 114, 100, 108, 105,
  103, 104, 116, 10, 45, 101, 108, 105, 102, 32, 123, 36, 77, 101, 114, 103,
  101, 67, 104, 111, 105, 99, 101, 61, 61, 49, 48, 125, 32, 45, 45, 98,
  108, 101, 110, 100, 91, 49, 44, 48, 93, 32, 115, 111, 102, 116, 108, 105,
  103, 104, 116, 10, 45, 101, 108, 105, 102, 32, 123, 36, 77, 101, 114, 103,
  101, 67, 104, 111, 105, 99, 101, 61, 61, 49, 49, 125, 32, 45, 45, 98,
  108, 101, 110, 100, 91, 49, 44, 48, 93, 32, 100, 111, 100, 103, 101, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 77, 101, 114, 103, 101, 67, 104, 111,
  105, 99, 101, 61, 61, 49, 50, 125, 32, 45, 45, 98, 108, 101, 110, 100,
  91, 49, 44, 48, 93, 32, 99, 111, 108, 111, 114, 98, 117, 114, 110, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 77, 101, 114, 103, 101, 67, 104, 111,
  105, 99, 101, 61, 61, 49, 51, 125, 32, 45, 45, 98, 108, 101, 110, 100,
  91, 49, 44, 48, 93, 32, 114, 101, 102, 108, 101, 99, 116, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 77, 101, 114, 103, 101, 67, 104, 111, 105, 99,
  101, 61, 61, 49, 52, 125, 32, 45, 45, 98, 108, 101, 110, 100, 91, 49,
  44, 48, 93, 32, 102, 114, 101, 101, 122, 101, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 77, 101, 114, 103, 101, 67, 104, 111, 105, 99, 101, 61, 61,
  49, 53, 125, 32, 45, 45, 98, 108, 101, 110, 100, 91, 49, 44, 48, 93,
  32, 115, 116, 97, 109, 112, 10, 45, 101, 108, 105, 102, 32, 123, 36, 77,
  101, 114, 103, 101, 67, 104, 111, 105, 99, 101, 61, 61, 49, 54, 125, 32,
  45, 45, 98, 108, 101, 110, 100, 91, 49, 44, 48, 93, 32, 105, 110, 116,
  101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 77, 101, 114, 103, 101, 67, 104, 111, 105, 99, 101, 61, 61,
  49, 55, 125, 32, 45, 45, 98, 108, 101, 110, 100, 91, 49, 44, 48, 93,
  32, 103, 114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 77, 101, 114, 103, 101, 67, 104, 111, 105, 99,
  101, 61, 61, 49, 56, 125, 32, 45, 45, 98, 108, 101, 110, 100, 91, 49,
  44, 48, 93, 32, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 77, 101, 114, 103, 101, 67, 104, 111, 105,
  99, 101, 61, 61, 49, 57, 125, 32, 45, 45, 98, 108, 101, 110, 100, 91,
  49, 44, 48, 93, 32, 120, 111, 114, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 77, 101, 114, 103, 101, 67, 104, 111, 105, 99, 101, 61, 61, 50, 48,
  125, 32, 45, 45, 98, 108, 101, 110, 100, 95, 101, 100, 103, 101, 115, 91,
  49, 44, 48, 93, 32, 48, 46, 56, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 82, 101, 118, 101, 114, 115, 101, 67, 104, 111,
  105, 99, 101, 61, 61, 49, 125, 32, 45, 114, 101, 118, 101, 114, 115, 101,
  91, 48, 44, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 80, 114, 101, 115, 101, 114, 118, 101, 67, 97, 110, 118, 97,
  115, 61, 61, 48, 125, 32, 45, 114, 101, 109, 111, 118, 101, 91, 49, 93,
  32, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 80,
  114, 101, 115, 101, 114, 118, 101, 67, 97, 110, 118, 97, 115, 61, 61, 49,
  34, 32, 38, 38, 32, 34, 36, 77, 101, 114, 103, 101, 67, 104, 111, 105,
  99, 101, 33, 61, 50, 49, 125, 32, 45, 114, 101, 118, 101, 114, 115, 101,
  91, 49, 44, 50, 93, 32, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 77, 101, 114, 103, 101, 67, 104, 111, 105, 99, 101, 33,
  61, 50, 49, 125, 32, 45, 114, 101, 109, 111, 118, 101, 91, 48, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 77, 101, 114,
  103, 101, 67, 104, 111, 105, 99, 101, 33, 61, 50, 49, 34, 32, 38, 38,
  32, 34, 36, 80, 114, 101, 115, 101, 114, 118, 101, 67, 97, 110, 118, 97,
  115, 61, 61, 49, 125, 32, 45, 114, 101, 118, 101, 114, 115, 101, 91, 48,
  44, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95,
  83, 105, 109, 112, 108, 101, 78, 111, 105, 115, 101, 67, 97, 110, 118, 97,
  115, 80, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 103, 105, 109, 112, 95, 83, 105, 109, 112, 108, 101, 78, 111, 105, 115,
  101, 67, 97, 110, 118, 97, 115, 32, 36, 123, 49, 45, 45, 50, 125, 34,
  44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 87, 97, 114, 104,
  111, 108, 32, 58, 32, 119, 97, 114, 104, 111, 108, 44, 32, 119, 97, 114,
  104, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  88, 45, 116, 105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 51, 44,
  49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89,
  45, 116, 105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 51, 44, 49,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 111, 108, 111, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  52, 48, 44, 48, 44, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109,
  112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50,
  57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 87, 97, 116, 101, 114, 99, 111, 108,
  111, 114, 32, 58, 32, 103, 105, 109, 112, 95, 119, 97, 116, 101, 114, 99,
  111, 108, 111, 114, 44, 32, 103, 105, 109, 112, 95, 119, 97, 116, 101, 114,
  99, 111, 108, 111, 114, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 71, 101, 110, 101, 114, 97,
  108, 32, 115, 101, 116, 116, 105, 110, 103, 115, 58, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 105, 110, 116,
  101, 110, 115, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  46, 56, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 76, 105, 103, 104, 116, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 49, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 97, 114, 107, 32, 99, 111, 108,
  111, 114, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 76, 105, 110,
  101, 32, 97, 114, 116, 32, 115, 101, 116, 116, 105, 110, 103, 115, 58, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 101, 32,
  97, 114, 116, 32, 100, 101, 116, 97, 105, 108, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 32, 40, 56, 48, 44, 53, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 101, 32, 97, 114,
  116, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 76, 105, 110, 101, 32, 97, 114, 116, 32, 115,
  116, 114, 101, 110, 103, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 76, 105, 110, 101, 32, 97, 114, 116, 32, 115, 116, 121, 108, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 112, 101, 110, 99, 105,
  108, 34, 44, 34, 105, 110, 107, 34, 44, 34, 99, 111, 109, 105, 99, 32,
  115, 116, 121, 108, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 76, 105, 110, 101, 32, 97, 114, 116, 32, 102, 97, 100, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 67, 111, 108, 111, 114, 32, 98,
  114, 117, 115, 104, 101, 115, 32, 115, 101, 116, 116, 105, 110, 103, 115, 58,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 114, 117, 115,
  104, 32, 115, 116, 121, 108, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 109, 111, 100, 101, 114, 110, 34, 44, 34, 99, 108, 97, 115, 115,
  105, 99, 34, 44, 34, 97, 98, 115, 116, 114, 97, 99, 116, 34, 44, 34,
  108, 105, 110, 101, 34, 44, 34, 115, 109, 111, 111, 116, 104, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 121, 97, 110, 32, 98, 114,
  117, 115, 104, 32, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 44, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 121, 97, 110, 32, 115, 116, 114, 111, 107, 101, 32, 115, 116,
  114, 101, 110, 103, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 45, 53, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 121, 97, 110, 32, 101, 100, 103, 101, 32, 100, 105, 115, 116, 97, 110,
  99, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 121, 97, 110,
  32, 97, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 52, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 77, 97, 103, 101, 110, 116, 97, 32, 98, 114,
  117, 115, 104, 32, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 44, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 77, 97, 103, 101, 110, 116, 97, 32, 115, 116, 114, 111, 107, 101,
  32, 115, 116, 114, 101, 110, 103, 116, 104, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 45, 53, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 77, 97, 103, 101, 110, 116, 97, 32, 101, 100, 103, 101, 32,
  100, 105, 115, 116, 97, 110, 99, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 51, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 77, 97, 103, 101, 110, 116, 97, 32, 97, 98, 115, 116, 114, 97,
  99, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44,
  48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89,
  101, 108, 108, 111, 119, 32, 98, 114, 117, 115, 104, 32, 115, 105, 122, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 44, 53, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 101, 108, 108, 111, 119,
  32, 115, 116, 114, 111, 107, 101, 32, 115, 116, 114, 101, 110, 103, 116, 104,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 53, 44, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 101, 108, 108, 111, 119,
  32, 101, 100, 103, 101, 32, 100, 105, 115, 116, 97, 110, 99, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 52, 44, 48, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 89, 101, 108, 108, 111, 119, 32, 97,
  98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 50, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 80, 97, 112, 101, 114, 32, 97, 110, 100, 32, 97, 109,
  98, 105, 101, 110, 99, 101, 32, 115, 101, 116, 116, 105, 110, 103, 115, 58,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 112, 101,
  114, 32, 99, 111, 108, 111, 114, 32, 98, 108, 97, 99, 107, 32, 61, 32,
  98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 65, 100, 100, 32, 112, 97, 112, 101, 114, 32, 116, 101, 120, 116, 117,
  114, 101, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 73, 110, 118, 101, 114, 116, 32, 99, 111, 108,
  111, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 65, 109, 98, 105, 101, 110, 116, 32, 108,
  105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45,
  53, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 115, 32, 58, 32, 60, 105, 62,
  84, 111, 109, 32, 75, 101, 105, 108, 32, 97, 110, 100, 32, 65, 114, 116,
  111, 32, 72, 117, 111, 116, 97, 114, 105, 32, 60, 47, 105, 62, 32, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48, 50, 47, 49,
  57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 108, 105, 110, 107, 40, 34, 84, 117, 116, 111, 114, 105, 97, 108, 32,
  100, 111, 119, 110, 108, 111, 97, 100, 34, 44, 34, 104, 116, 116, 112, 58,
  47, 47, 119, 119, 119, 46, 115, 108, 105, 100, 101, 115, 104, 97, 114, 101,
  46, 110, 101, 116, 47, 65, 114, 116, 111, 72, 117, 111, 116, 97, 114, 105,
  47, 103, 109, 105, 103, 45, 119, 97, 116, 101, 114, 45, 99, 111, 108, 111,
  114, 45, 102, 105, 108, 116, 101, 114, 45, 116, 117, 116, 111, 114, 105, 97,
  108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 86, 105, 100, 101, 111, 32,
  100, 101, 109, 111, 110, 115, 116, 114, 97, 116, 105, 111, 110, 32, 104, 101,
  114, 101, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 118, 105, 109, 101,
  111, 46, 99, 111, 109, 47, 49, 57, 55, 49, 51, 56, 53, 48, 34, 41,
  10, 103, 105, 109, 112, 95, 119, 97, 116, 101, 114, 99, 111, 108, 111, 114,
  32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99,
  105, 116, 121, 32, 45, 108, 91, 48, 93, 10, 45, 105, 102, 32, 123, 36,
  55, 61, 61, 48, 125, 32, 45, 45, 103, 105, 109, 112, 95, 103, 114, 97,
  100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 32, 36, 53, 44, 48, 46,
  53, 44, 123, 57, 57, 46, 57, 57, 45, 36, 52, 125, 44, 36, 52, 44,
  49, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 55, 61, 61, 49,
  125, 32, 45, 45, 103, 105, 109, 112, 95, 101, 100, 103, 101, 115, 32, 123,
  36, 53, 47, 51, 46, 53, 125, 44, 123, 57, 53, 45, 36, 52, 125, 44,
  48, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 55, 61, 61, 50,
  125, 32, 45, 45, 103, 105, 109, 112, 95, 101, 100, 103, 101, 115, 32, 123,
  36, 53, 47, 51, 46, 53, 125, 44, 123, 57, 53, 45, 36, 52, 125, 44,
  48, 44, 48, 10, 45, 45, 103, 105, 109, 112, 95, 109, 105, 120, 95, 104,
  115, 118, 91, 48, 93, 32, 49, 44, 48, 44, 48, 44, 49, 44, 45, 49,
  44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 10, 45,
  116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95,
  112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 91, 50, 93, 32, 49, 44,
  49, 44, 48, 44, 123, 36, 53, 47, 49, 48, 125, 44, 52, 44, 123, 123,
  36, 52, 45, 53, 48, 125, 42, 50, 125, 44, 49, 48, 48, 44, 50, 53,
  54, 44, 48, 44, 48, 44, 48, 44, 50, 44, 55, 44, 48, 10, 45, 114,
  101, 118, 101, 114, 115, 101, 91, 49, 44, 50, 93, 32, 45, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108, 116, 105, 112,
  108, 121, 91, 49, 44, 50, 93, 32, 123, 48, 46, 53, 43, 123, 36, 54,
  47, 50, 125, 125, 10, 45, 101, 110, 100, 105, 102, 32, 45, 103, 105, 109,
  112, 95, 102, 114, 97, 109, 101, 95, 114, 111, 117, 110, 100, 91, 49, 93,
  32, 53, 44, 36, 56, 44, 49, 53, 44, 48, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 48, 46, 49,
  44, 51, 10, 45, 103, 105, 109, 112, 95, 97, 110, 105, 115, 111, 116, 114,
  111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 91, 48,
  93, 10, 54, 48, 44, 48, 46, 49, 54, 44, 123, 123, 50, 48, 47, 53,
  48, 125, 43, 48, 46, 54, 125, 44, 123, 123, 50, 48, 47, 57, 125, 43,
  48, 46, 54, 125, 44, 50, 46, 51, 53, 44, 48, 46, 56, 44, 51, 48,
  44, 50, 44, 48, 44, 49, 44, 49, 44, 48, 44, 49, 10, 45, 45, 103,
  105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 48,
  93, 32, 45, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 48, 93, 32,
  45, 109, 111, 118, 101, 91, 49, 93, 32, 52, 10, 45, 103, 105, 109, 112,
  95, 103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 50,
  93, 32, 123, 123, 119, 43, 104, 125, 47, 49, 48, 48, 125, 44, 48, 44,
  48, 44, 49, 44, 48, 44, 48, 44, 48, 10, 45, 103, 105, 109, 112, 95,
  99, 111, 109, 112, 111, 115, 101, 95, 100, 111, 100, 103, 101, 91, 49, 44,
  50, 93, 32, 49, 10, 45, 103, 105, 109, 112, 95, 109, 105, 120, 95, 108,
  97, 98, 91, 48, 93, 32, 49, 44, 48, 44, 48, 44, 36, 49, 44, 48,
  44, 48, 44, 36, 49, 44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 10,
  45, 114, 101, 118, 101, 114, 115, 101, 91, 48, 44, 49, 93, 10, 45, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 99, 111, 108, 111,
  114, 98, 117, 114, 110, 91, 48, 44, 49, 93, 32, 36, 50, 10, 45, 45,
  108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 48, 93, 32, 45, 114, 101,
  118, 101, 114, 115, 101, 91, 49, 44, 50, 93, 10, 45, 116, 107, 95, 103,
  105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111, 99,
  101, 115, 115, 105, 110, 103, 91, 49, 93, 32, 49, 44, 49, 44, 48, 44,
  48, 44, 52, 44, 123, 36, 51, 42, 53, 125, 44, 49, 48, 48, 44, 50,
  53, 54, 44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 44, 48, 10, 45,
  103, 105, 109, 112, 95, 103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108,
  117, 114, 91, 49, 93, 32, 36, 51, 44, 48, 44, 48, 44, 49, 44, 48,
  44, 48, 44, 48, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 99, 104,
  97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103,
  91, 49, 93, 32, 49, 44, 49, 44, 48, 44, 48, 44, 52, 44, 48, 44,
  57, 57, 44, 50, 53, 54, 44, 48, 44, 49, 44, 48, 44, 50, 44, 48,
  44, 48, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 114, 101, 112, 108,
  97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 49, 93, 32, 49, 44, 48,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 48, 44, 48, 44, 48, 44, 48, 10, 45, 103, 105, 109, 112, 95, 115,
  112, 114, 101, 97, 100, 91, 49, 93, 32, 123, 36, 51, 42, 50, 125, 44,
  123, 36, 51, 42, 50, 125, 44, 48, 44, 48, 10, 45, 103, 105, 109, 112,
  95, 103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 49,
  93, 32, 123, 123, 119, 43, 104, 125, 47, 49, 48, 48, 48, 125, 44, 48,
  44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 10, 45, 114, 101, 118, 101,
  114, 115, 101, 91, 48, 44, 49, 93, 32, 45, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 109, 117, 108, 116, 105, 112, 108, 121, 91,
  48, 44, 49, 93, 32, 49, 10, 45, 115, 112, 108, 105, 116, 91, 48, 93,
  32, 99, 10, 45, 105, 102, 32, 123, 36, 57, 61, 61, 48, 125, 32, 45,
  45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 48, 93, 32, 45, 45, 110,
  101, 103, 97, 116, 105, 118, 101, 91, 49, 93, 32, 45, 45, 110, 101, 103,
  97, 116, 105, 118, 101, 91, 50, 93, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 57, 61, 61, 49, 125, 32, 45, 45, 102, 105, 108, 108, 95, 99, 111,
  108, 111, 114, 91, 48, 93, 32, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 32, 45, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91,
  48, 93, 32, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45,
  45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 48, 93, 32, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 57, 61, 61, 50, 125, 32, 45, 45, 102, 105, 108, 108, 95,
  99, 111, 108, 111, 114, 91, 48, 93, 32, 50, 53, 53, 44, 50, 53, 53,
  44, 50, 53, 53, 32, 45, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111,
  114, 91, 48, 93, 32, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  10, 45, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 48, 93,
  32, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 57, 61, 61, 51, 125, 32, 45, 45, 103, 105, 109,
  112, 95, 101, 100, 103, 101, 115, 91, 48, 93, 32, 123, 36, 49, 48, 47,
  53, 125, 44, 123, 36, 49, 51, 42, 53, 125, 44, 49, 44, 48, 10, 45,
  45, 103, 105, 109, 112, 95, 101, 100, 103, 101, 115, 91, 49, 93, 32, 123,
  36, 49, 52, 47, 53, 125, 44, 123, 36, 49, 55, 42, 53, 125, 44, 49,
  44, 48, 32, 45, 45, 103, 105, 109, 112, 95, 101, 100, 103, 101, 115, 91,
  50, 93, 32, 123, 36, 49, 56, 47, 53, 125, 44, 123, 36, 50, 49, 42,
  53, 125, 44, 49, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 57,
  61, 61, 52, 125, 32, 45, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91,
  48, 93, 32, 45, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 49, 93,
  32, 45, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 50, 93, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 99,
  104, 97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110,
  103, 91, 48, 93, 32, 49, 44, 123, 123, 36, 49, 49, 47, 53, 125, 43,
  49, 125, 44, 123, 36, 49, 49, 47, 53, 48, 125, 44, 48, 44, 48, 44,
  48, 44, 49, 48, 48, 44, 50, 53, 54, 44, 48, 44, 48, 44, 48, 44,
  50, 44, 48, 44, 48, 10, 45, 105, 102, 32, 123, 36, 57, 33, 61, 50,
  125, 10, 45, 103, 105, 109, 112, 95, 103, 97, 117, 115, 115, 105, 97, 110,
  95, 98, 108, 117, 114, 91, 48, 93, 32, 36, 49, 48, 44, 48, 44, 48,
  44, 49, 44, 48, 44, 48, 44, 48, 10, 45, 101, 108, 115, 101, 32, 45,
  99, 117, 98, 105, 115, 109, 91, 48, 93, 32, 51, 48, 48, 44, 123, 36,
  49, 51, 42, 53, 125, 44, 123, 36, 49, 51, 42, 51, 54, 125, 44, 49,
  44, 123, 36, 49, 48, 47, 53, 48, 125, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 57, 61, 61, 48, 125, 10, 45, 116, 107,
  95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114,
  111, 99, 101, 115, 115, 105, 110, 103, 91, 45, 51, 93, 32, 49, 44, 123,
  123, 36, 49, 49, 47, 53, 125, 43, 49, 125, 44, 123, 36, 49, 49, 47,
  53, 48, 125, 44, 48, 44, 48, 44, 48, 44, 49, 48, 48, 44, 50, 53,
  54, 44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 44, 48, 10, 45, 99,
  117, 98, 105, 115, 109, 91, 45, 51, 93, 32, 51, 48, 48, 44, 123, 36,
  49, 51, 42, 53, 125, 44, 123, 36, 49, 51, 42, 51, 54, 125, 44, 49,
  44, 123, 36, 49, 48, 47, 53, 48, 125, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 57, 61, 61, 52, 125, 10, 45, 116, 107,
  95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114,
  111, 99, 101, 115, 115, 105, 110, 103, 91, 45, 51, 93, 32, 49, 44, 123,
  123, 36, 49, 49, 47, 53, 125, 43, 49, 125, 44, 123, 36, 49, 49, 47,
  53, 48, 125, 44, 48, 44, 48, 44, 48, 44, 49, 48, 48, 44, 50, 53,
  54, 44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 44, 48, 10, 45, 103,
  105, 109, 112, 95, 112, 97, 105, 110, 116, 105, 110, 103, 91, 45, 51, 93,
  32, 36, 49, 51, 44, 49, 46, 53, 44, 50, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 103, 105, 109, 112, 95, 102, 114, 97, 109, 101, 95, 102, 117,
  122, 122, 121, 91, 45, 51, 93, 32, 123, 36, 49, 50, 42, 53, 125, 44,
  123, 36, 49, 50, 42, 53, 125, 44, 123, 36, 49, 51, 42, 50, 48, 125,
  44, 123, 36, 49, 48, 47, 50, 125, 44, 48, 44, 48, 44, 48, 44, 50,
  53, 53, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97, 110,
  110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 91, 49,
  93, 32, 49, 44, 123, 123, 36, 49, 53, 47, 53, 125, 43, 49, 125, 44,
  123, 36, 49, 53, 47, 53, 48, 125, 44, 48, 44, 48, 44, 48, 44, 49,
  48, 48, 44, 50, 53, 54, 44, 48, 44, 48, 44, 48, 44, 50, 44, 48,
  44, 48, 10, 45, 105, 102, 32, 123, 36, 57, 33, 61, 50, 125, 10, 45,
  103, 105, 109, 112, 95, 103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108,
  117, 114, 91, 49, 93, 32, 36, 49, 52, 44, 48, 44, 48, 44, 49, 44,
  48, 44, 48, 44, 48, 10, 45, 101, 108, 115, 101, 32, 45, 99, 117, 98,
  105, 115, 109, 91, 49, 93, 32, 51, 48, 48, 44, 123, 36, 49, 55, 42,
  53, 125, 44, 123, 36, 49, 55, 42, 51, 54, 125, 44, 49, 44, 123, 36,
  49, 52, 47, 53, 48, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 57, 61, 61, 48, 125, 10, 45, 116, 107, 95, 103, 105,
  109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101,
  115, 115, 105, 110, 103, 91, 45, 50, 93, 32, 49, 44, 123, 123, 36, 49,
  53, 47, 53, 125, 43, 49, 125, 44, 123, 36, 49, 53, 47, 53, 48, 125,
  44, 48, 44, 48, 44, 48, 44, 49, 48, 48, 44, 50, 53, 54, 44, 48,
  44, 48, 44, 48, 44, 50, 44, 48, 44, 48, 10, 45, 99, 117, 98, 105,
  115, 109, 91, 45, 50, 93, 32, 51, 48, 48, 44, 123, 36, 49, 55, 42,
  53, 125, 44, 123, 36, 49, 55, 42, 51, 54, 125, 44, 49, 44, 123, 36,
  49, 52, 47, 53, 48, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 57, 61, 61, 52, 125, 10, 45, 116, 107, 95, 103, 105,
  109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101,
  115, 115, 105, 110, 103, 91, 45, 50, 93, 32, 49, 44, 123, 123, 36, 49,
  53, 47, 53, 125, 43, 49, 125, 44, 123, 36, 49, 53, 47, 53, 48, 125,
  44, 48, 44, 48, 44, 48, 44, 49, 48, 48, 44, 50, 53, 54, 44, 48,
  44, 48, 44, 48, 44, 50, 44, 48, 44, 48, 10, 45, 103, 105, 109, 112,
  95, 112, 97, 105, 110, 116, 105, 110, 103, 91, 45, 50, 93, 32, 36, 49,
  55, 44, 49, 46, 53, 44, 50, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  103, 105, 109, 112, 95, 102, 114, 97, 109, 101, 95, 102, 117, 122, 122, 121,
  91, 45, 50, 93, 32, 123, 36, 49, 54, 42, 53, 125, 44, 123, 36, 49,
  54, 42, 53, 125, 44, 123, 36, 49, 55, 42, 50, 48, 125, 44, 123, 36,
  49, 52, 47, 50, 125, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 10,
  45, 116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108,
  95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 91, 50, 93, 32, 49,
  44, 123, 123, 36, 49, 57, 47, 53, 125, 43, 49, 125, 44, 123, 36, 49,
  57, 47, 53, 48, 125, 44, 48, 44, 48, 44, 48, 44, 49, 48, 48, 44,
  50, 53, 54, 44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 44, 48, 10,
  45, 105, 102, 32, 123, 36, 57, 33, 61, 50, 125, 10, 45, 103, 105, 109,
  112, 95, 103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91,
  50, 93, 32, 36, 49, 56, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48,
  44, 48, 10, 45, 101, 108, 115, 101, 32, 45, 99, 117, 98, 105, 115, 109,
  91, 50, 93, 32, 51, 48, 48, 44, 123, 36, 50, 49, 42, 53, 125, 44,
  123, 36, 50, 49, 42, 51, 54, 125, 44, 49, 44, 123, 36, 49, 56, 47,
  53, 48, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 57, 61, 61, 48, 125, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95,
  99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105,
  110, 103, 91, 45, 49, 93, 32, 49, 44, 123, 123, 36, 49, 57, 47, 53,
  125, 43, 49, 125, 44, 123, 36, 49, 57, 47, 53, 48, 125, 44, 48, 44,
  48, 44, 48, 44, 49, 48, 48, 44, 50, 53, 54, 44, 48, 44, 48, 44,
  48, 44, 50, 44, 48, 44, 48, 10, 45, 99, 117, 98, 105, 115, 109, 91,
  45, 49, 93, 32, 51, 48, 48, 44, 123, 36, 50, 49, 42, 53, 125, 44,
  123, 36, 50, 49, 42, 51, 54, 125, 44, 49, 44, 123, 36, 49, 56, 47,
  53, 48, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 57, 61, 61, 52, 125, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95,
  99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105,
  110, 103, 91, 45, 49, 93, 32, 49, 44, 123, 123, 36, 49, 57, 47, 53,
  125, 43, 49, 125, 44, 123, 36, 49, 57, 47, 53, 48, 125, 44, 48, 44,
  48, 44, 48, 44, 49, 48, 48, 44, 50, 53, 54, 44, 48, 44, 48, 44,
  48, 44, 50, 44, 48, 44, 48, 10, 45, 103, 105, 109, 112, 95, 112, 97,
  105, 110, 116, 105, 110, 103, 91, 45, 49, 93, 32, 36, 50, 49, 44, 49,
  46, 53, 44, 50, 32, 32, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105,
  109, 112, 95, 102, 114, 97, 109, 101, 95, 102, 117, 122, 122, 121, 91, 45,
  49, 93, 32, 123, 36, 50, 48, 42, 53, 125, 44, 123, 36, 50, 48, 42,
  53, 125, 44, 123, 36, 50, 49, 42, 50, 48, 125, 44, 123, 36, 49, 56,
  47, 50, 125, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 10, 45, 116,
  111, 95, 103, 114, 97, 121, 91, 45, 49, 93, 32, 45, 116, 111, 95, 103,
  114, 97, 121, 91, 45, 50, 93, 32, 45, 116, 111, 95, 103, 114, 97, 121,
  91, 45, 51, 93, 32, 45, 116, 111, 95, 114, 103, 98, 97, 91, 48, 93,
  32, 45, 116, 111, 95, 114, 103, 98, 97, 91, 49, 93, 32, 45, 116, 111,
  95, 114, 103, 98, 97, 91, 50, 93, 10, 45, 115, 112, 108, 105, 116, 91,
  48, 93, 32, 99, 32, 45, 114, 101, 118, 101, 114, 115, 101, 91, 51, 44,
  45, 51, 93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108,
  116, 105, 112, 108, 121, 91, 51, 44, 45, 51, 93, 32, 45, 97, 112, 112,
  101, 110, 100, 91, 48, 44, 49, 44, 50, 44, 51, 93, 32, 99, 10, 45,
  115, 112, 108, 105, 116, 91, 49, 93, 32, 99, 32, 45, 114, 101, 118, 101,
  114, 115, 101, 91, 52, 44, 45, 50, 93, 32, 45, 99, 111, 109, 112, 111,
  115, 101, 95, 109, 117, 108, 116, 105, 112, 108, 121, 91, 52, 44, 45, 50,
  93, 32, 45, 97, 112, 112, 101, 110, 100, 91, 49, 44, 50, 44, 51, 44,
  52, 93, 32, 99, 10, 45, 115, 112, 108, 105, 116, 91, 50, 93, 32, 99,
  32, 45, 114, 101, 118, 101, 114, 115, 101, 91, 53, 44, 45, 49, 93, 32,
  45, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108, 116, 105, 112, 108,
  121, 91, 53, 44, 45, 49, 93, 32, 45, 97, 112, 112, 101, 110, 100, 91,
  50, 44, 51, 44, 52, 44, 53, 93, 32, 99, 10, 45, 105, 102, 32, 123,
  36, 50, 50, 61, 61, 48, 125, 32, 45, 45, 102, 105, 108, 108, 95, 99,
  111, 108, 111, 114, 91, 48, 93, 32, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 32, 45, 101, 108, 115, 101, 32, 45, 45, 102, 105, 108, 108,
  95, 99, 111, 108, 111, 114, 91, 48, 93, 32, 48, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 114, 101, 118, 101, 114, 115, 101, 91, 48, 44, 45, 49,
  93, 32, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 114, 103, 98, 97,
  91, 48, 44, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 50, 50, 61,
  61, 48, 125, 32, 45, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114,
  91, 49, 93, 32, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32,
  45, 101, 108, 115, 101, 32, 45, 45, 102, 105, 108, 108, 95, 99, 111, 108,
  111, 114, 91, 49, 93, 32, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 101, 118, 101, 114, 115, 101, 91, 49, 44, 45, 49, 93, 32, 45, 99,
  111, 109, 112, 111, 115, 101, 95, 114, 103, 98, 97, 91, 49, 44, 45, 49,
  93, 10, 45, 105, 102, 32, 123, 36, 50, 50, 61, 61, 48, 125, 32, 45,
  45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 50, 93, 32, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 101, 108, 115, 101,
  32, 45, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 50, 93,
  32, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 118, 101, 114,
  115, 101, 91, 50, 44, 45, 49, 93, 32, 45, 99, 111, 109, 112, 111, 115,
  101, 95, 114, 103, 98, 97, 91, 50, 44, 45, 49, 93, 10, 45, 116, 111,
  95, 103, 114, 97, 121, 91, 48, 93, 32, 45, 116, 111, 95, 103, 114, 97,
  121, 91, 49, 93, 32, 45, 116, 111, 95, 103, 114, 97, 121, 91, 50, 93,
  32, 45, 97, 112, 112, 101, 110, 100, 91, 48, 44, 49, 44, 50, 93, 32,
  99, 10, 45, 105, 102, 32, 123, 36, 50, 51, 61, 61, 49, 125, 32, 45,
  103, 105, 109, 112, 95, 112, 97, 112, 101, 114, 32, 48, 44, 48, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 50, 52, 61, 61,
  49, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 48, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 109, 105, 120,
  95, 108, 97, 98, 32, 49, 44, 36, 50, 53, 44, 48, 44, 49, 44, 48,
  44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 10, 45,
  114, 101, 118, 101, 114, 115, 101, 91, 48, 44, 49, 93, 32, 45, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108, 116, 105,
  112, 108, 121, 91, 48, 44, 49, 93, 32, 36, 54, 10, 45, 101, 110, 100,
  108, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 103, 105, 109, 112, 95, 119, 97, 116, 101, 114, 99, 111, 108,
  111, 114, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 119, 97, 116, 101, 114, 99, 111, 108,
  111, 114, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10,
  35, 64, 103, 105, 109, 112, 32, 87, 104, 105, 114, 108, 32, 100, 114, 97,
  119, 105, 110, 103, 32, 58, 32, 100, 114, 97, 119, 95, 119, 104, 105, 114,
  108, 44, 32, 103, 105, 109, 112, 95, 100, 114, 97, 119, 95, 119, 104, 105,
  114, 108, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80,
  114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68,
  117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104,
  117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50,
  47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 103, 105, 109, 112, 95, 100, 114, 97, 119, 95, 119, 104, 105,
  114, 108, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 100, 114, 97, 119, 95, 119, 104, 105, 114, 108, 32, 36, 42,
  34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 87, 105, 108,
  100, 32, 99, 97, 114, 116, 111, 111, 110, 105, 122, 101, 114, 32, 58, 32,
  103, 105, 109, 112, 95, 109, 95, 108, 95, 117, 110, 115, 104, 97, 114, 112,
  50, 32, 44, 32, 103, 105, 109, 112, 95, 109, 95, 108, 95, 117, 110, 115,
  104, 97, 114, 112, 50, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 82, 97, 100, 105, 117, 115, 32, 49, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 50, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 65, 109, 111, 117, 110, 116, 32, 49, 32, 61,
  32, 102, 108, 111, 97, 116, 32, 40, 50, 46, 49, 56, 44, 48, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 100, 105,
  117, 115, 32, 50, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 51,
  44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 65, 109, 111, 117, 110, 116, 32, 50, 32, 61, 32, 102, 108, 111, 97,
  116, 32, 40, 49, 46, 53, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 97, 114, 107, 101, 110, 32, 109, 101, 114,
  103, 101, 32, 111, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111,
  97, 116, 32, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 76, 105, 103, 104, 116, 101, 110, 32, 109, 101, 114, 103,
  101, 32, 111, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97,
  116, 32, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 32, 65,
  100, 100, 105, 116, 105, 111, 110, 97, 108, 32, 80, 97, 105, 110, 116, 101,
  114, 32, 77, 111, 100, 117, 108, 101, 32, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 65, 100, 100, 32, 112, 97, 105, 110, 116, 101, 114, 39, 115, 32, 116,
  111, 117, 99, 104, 32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108, 115,
  101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 105, 110,
  116, 101, 114, 39, 115, 32, 116, 111, 117, 99, 104, 32, 115, 104, 97, 114,
  112, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  53, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  80, 97, 105, 110, 116, 101, 114, 39, 115, 32, 101, 100, 103, 101, 32, 112,
  114, 111, 116, 101, 99, 116, 105, 111, 110, 32, 102, 108, 111, 119, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 56, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 105, 110, 116, 101, 114,
  39, 115, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 102,
  108, 111, 97, 116, 40, 49, 46, 50, 56, 44, 48, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32,
  60, 105, 62, 80, 104, 111, 116, 111, 67, 111, 109, 105, 88, 60, 47, 105,
  62, 46, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  32, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  103, 105, 109, 112, 95, 109, 95, 108, 95, 117, 110, 115, 104, 97, 114, 112,
  50, 32, 58, 10, 45, 45, 117, 110, 115, 104, 97, 114, 112, 32, 36, 49,
  44, 36, 50, 44, 48, 10, 45, 117, 110, 115, 104, 97, 114, 112, 32, 36,
  51, 44, 36, 52, 44, 48, 91, 49, 93, 32, 45, 114, 101, 118, 101, 114,
  115, 101, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 100, 97, 114, 107, 101, 110, 32, 36, 53, 10, 45, 45, 117, 110, 115,
  104, 97, 114, 112, 32, 36, 51, 44, 36, 52, 44, 48, 32, 45, 114, 101,
  118, 101, 114, 115, 101, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 108, 105, 103, 104, 116, 101, 110, 32, 36, 54, 10, 45,
  105, 102, 32, 123, 36, 55, 61, 61, 49, 125, 32, 45, 103, 105, 109, 112,
  95, 97, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111,
  111, 116, 104, 105, 110, 103, 32, 54, 48, 44, 36, 56, 44, 36, 57, 44,
  36, 49, 48, 44, 49, 46, 49, 44, 48, 46, 56, 44, 51, 48, 44, 50,
  44, 48, 44, 49, 44, 49, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10,
  103, 105, 109, 112, 95, 109, 95, 108, 95, 117, 110, 115, 104, 97, 114, 112,
  50, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 109, 95, 108, 95, 117, 110, 115, 104, 97,
  114, 112, 50, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 95, 10, 35, 64, 103, 105, 109, 112,
  32, 60, 98, 62, 66, 108, 97, 99, 107, 32, 38, 97, 109, 112, 59, 32,
  119, 104, 105, 116, 101, 60, 47, 98, 62, 10, 35, 64, 103, 105, 109, 112,
  32, 66, 38, 97, 109, 112, 59, 87, 32, 115, 116, 101, 110, 99, 105, 108,
  32, 58, 32, 103, 105, 109, 112, 95, 115, 116, 101, 110, 99, 105, 108, 98,
  119, 44, 32, 103, 105, 109, 112, 95, 115, 116, 101, 110, 99, 105, 108, 98,
  119, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 51, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44,
  48, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72,
  117, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 51,
  54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 97, 116,
  117, 114, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99,
  97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65,
  117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32,
  84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59,
  60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49,
  48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 115, 116, 101, 110,
  99, 105, 108, 98, 119, 32, 58, 10, 45, 115, 116, 101, 110, 99, 105, 108,
  98, 119, 32, 36, 49, 44, 36, 50, 10, 45, 105, 102, 32, 123, 36, 51,
  124, 124, 36, 52, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111,
  112, 97, 99, 105, 116, 121, 10, 45, 47, 91, 48, 93, 32, 50, 53, 53,
  32, 45, 105, 91, 48, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 49, 44, 49, 44, 36, 52, 32, 45, 105, 91, 48, 93, 32, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 36, 51, 32, 45,
  97, 91, 48, 45, 50, 93, 32, 99, 32, 45, 104, 115, 118, 50, 114, 103,
  98, 91, 48, 93, 10, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109,
  112, 95, 115, 116, 101, 110, 99, 105, 108, 98, 119, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112,
  95, 115, 116, 101, 110, 99, 105, 108, 98, 119, 32, 36, 42, 34, 44, 36,
  45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 66, 108, 97, 99, 107, 32,
  38, 97, 109, 112, 59, 32, 119, 104, 105, 116, 101, 32, 58, 32, 103, 105,
  109, 112, 95, 98, 108, 97, 99, 107, 97, 110, 100, 119, 104, 105, 116, 101,
  44, 32, 103, 105, 109, 112, 95, 98, 108, 97, 99, 107, 97, 110, 100, 119,
  104, 105, 116, 101, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 100, 32, 108, 101, 118,
  101, 108, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 50, 57, 57,
  44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  101, 100, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 71, 114, 101, 101, 110, 32, 108, 101, 118,
  101, 108, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 56, 55,
  44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71,
  114, 101, 101, 110, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 117, 101, 32, 108, 101,
  118, 101, 108, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 49, 49,
  52, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  66, 108, 117, 101, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 71, 97, 109, 109, 97, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 45, 49, 46, 50, 44, 49, 46, 50, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116, 114, 97, 115, 116, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 66, 114, 105, 103, 104, 116, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53,
  53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  72, 117, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 97,
  116, 117, 114, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 97, 105,
  110, 32, 40, 115, 104, 97, 100, 111, 119, 115, 41, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 71, 114, 97, 105, 110, 32, 40, 109, 105, 100,
  116, 111, 110, 101, 115, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 71, 114, 97, 105, 110, 32, 40, 104, 105, 103, 104, 108, 105, 103, 104,
  116, 115, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114,
  97, 105, 110, 32, 116, 111, 110, 101, 32, 102, 97, 100, 105, 110, 103, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 97, 105, 110, 32, 115,
  99, 97, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 97,
  105, 110, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 71, 97, 117, 115, 115, 105, 97, 110, 34, 44, 34, 85, 110, 105,
  102, 111, 114, 109, 34, 44, 34, 83, 97, 108, 116, 32, 97, 110, 100, 32,
  112, 101, 112, 112, 101, 114, 34, 44, 34, 80, 111, 105, 115, 115, 111, 110,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 76, 111, 99, 97, 108, 32, 99, 111, 110,
  116, 114, 97, 115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  97, 100, 105, 117, 115, 32, 61, 32, 105, 110, 116, 40, 49, 54, 44, 49,
  44, 53, 49, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  111, 110, 116, 114, 97, 115, 116, 32, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 44, 48, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 80, 115, 101, 117, 100, 111, 45, 103, 114,
  97, 121, 32, 100, 105, 116, 104, 101, 114, 105, 110, 103, 32, 61, 32, 105,
  110, 116, 40, 48, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 85, 115, 101, 32, 109, 97, 120, 105, 109, 117, 109, 32, 116,
  111, 110, 101, 115, 32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108, 115,
  101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80,
  114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68,
  117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104,
  117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 50,
  47, 50, 48, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 103, 105, 109, 112, 95, 98, 108, 97, 99, 107, 97, 110, 100,
  119, 104, 105, 116, 101, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 10, 45, 108, 91, 45, 49, 93, 32, 45, 115, 112, 108, 105, 116,
  95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 114, 118, 32, 45, 116, 111,
  95, 114, 103, 98, 91, 45, 49, 93, 32, 45, 115, 91, 45, 49, 93, 32,
  99, 10, 45, 42, 91, 45, 51, 93, 32, 36, 49, 32, 45, 98, 91, 45,
  51, 93, 32, 36, 50, 37, 10, 45, 42, 91, 45, 50, 93, 32, 36, 51,
  32, 45, 98, 91, 45, 50, 93, 32, 36, 52, 37, 10, 45, 42, 91, 45,
  49, 93, 32, 36, 53, 32, 45, 98, 91, 45, 49, 93, 32, 36, 54, 37,
  10, 45, 43, 91, 45, 51, 45, 45, 49, 93, 32, 45, 47, 91, 45, 49,
  93, 32, 123, 36, 49, 43, 36, 51, 43, 36, 53, 125, 32, 45, 99, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 97, 112, 112, 108, 121,
  95, 103, 97, 109, 109, 97, 91, 45, 49, 93, 32, 123, 49, 48, 94, 36,
  55, 125, 10, 45, 45, 91, 45, 49, 93, 32, 49, 50, 56, 32, 45, 42,
  91, 45, 49, 93, 32, 36, 56, 32, 45, 43, 91, 45, 49, 93, 32, 49,
  50, 56, 32, 45, 43, 91, 45, 49, 93, 32, 36, 57, 32, 45, 99, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36,
  49, 50, 124, 124, 36, 49, 51, 124, 124, 36, 49, 52, 125, 10, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 32, 91, 45, 49, 93, 120, 50, 10, 45,
  110, 111, 105, 115, 101, 91, 45, 51, 93, 32, 49, 48, 48, 44, 36, 49,
  55, 32, 45, 98, 91, 45, 51, 93, 32, 36, 49, 54, 37, 32, 45, 110,
  91, 45, 51, 93, 32, 45, 36, 49, 50, 44, 36, 49, 50, 10, 45, 110,
  111, 105, 115, 101, 91, 45, 50, 93, 32, 49, 48, 48, 44, 36, 49, 55,
  32, 45, 98, 91, 45, 50, 93, 32, 36, 49, 54, 37, 32, 45, 110, 91,
  45, 50, 93, 32, 45, 36, 49, 51, 44, 36, 49, 51, 10, 45, 110, 111,
  105, 115, 101, 91, 45, 49, 93, 32, 49, 48, 48, 44, 36, 49, 55, 32,
  45, 98, 91, 45, 49, 93, 32, 36, 49, 54, 37, 32, 45, 110, 91, 45,
  49, 93, 32, 45, 36, 49, 52, 44, 36, 49, 52, 10, 45, 45, 116, 111,
  110, 101, 115, 91, 45, 52, 93, 32, 51, 32, 45, 98, 91, 45, 51, 45,
  45, 49, 93, 32, 36, 49, 53, 37, 10, 45, 42, 91, 45, 54, 44, 45,
  51, 93, 32, 45, 42, 91, 45, 52, 44, 45, 50, 93, 32, 45, 42, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 43, 91, 45, 52, 45, 45, 49, 93,
  32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 48, 124, 124, 36,
  49, 49, 125, 10, 45, 47, 91, 45, 49, 93, 32, 50, 53, 53, 10, 45,
  105, 91, 45, 50, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  49, 44, 49, 44, 36, 49, 49, 10, 45, 105, 91, 45, 51, 93, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 36, 49, 48,
  10, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 99, 32, 45, 104, 115,
  118, 50, 114, 103, 98, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 114, 118, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32,
  45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10,
  45, 105, 102, 32, 36, 49, 56, 32, 45, 110, 111, 114, 109, 97, 108, 105,
  122, 101, 95, 108, 111, 99, 97, 108, 32, 36, 49, 56, 44, 36, 49, 57,
  44, 36, 50, 48, 44, 50, 37, 44, 49, 44, 48, 44, 50, 53, 53, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 50, 50, 32, 45,
  110, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 36, 50, 49, 32, 45, 116, 111, 95, 112, 115, 101, 117, 100,
  111, 103, 114, 97, 121, 32, 36, 50, 49, 44, 49, 32, 45, 101, 110, 100,
  105, 102, 10, 103, 105, 109, 112, 95, 98, 108, 97, 99, 107, 97, 110, 100,
  119, 104, 105, 116, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 98, 108, 97, 99, 107,
  97, 110, 100, 119, 104, 105, 116, 101, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 66, 119, 32, 115, 116, 101, 97, 109,
  112, 117, 110, 107, 45, 112, 101, 110, 32, 58, 32, 103, 105, 109, 112, 95,
  115, 116, 101, 97, 109, 112, 101, 110, 44, 32, 103, 105, 109, 112, 95, 115,
  116, 101, 97, 109, 112, 101, 110, 95, 112, 114, 101, 118, 105, 101, 119, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 97, 100, 105, 117, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 57, 53, 44, 48, 44, 52, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117,
  100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 52, 44, 48, 44,
  50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116,
  101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 50,
  44, 49, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 116, 101, 97, 109, 32, 112, 114, 101, 115, 115, 117, 114, 101, 32, 61,
  32, 105, 110, 116, 40, 50, 44, 49, 44, 51, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 76, 117, 98, 114, 105, 99, 97, 116, 105, 111,
  110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 57, 44, 48, 44,
  49, 46, 57, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116, 114, 97, 115,
  116, 32, 102, 120, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 78,
  111, 110, 101, 45, 83, 107, 105, 112, 34, 44, 34, 76, 32, 78, 111, 114,
  109, 97, 108, 105, 122, 97, 116, 105, 111, 110, 34, 44, 34, 77, 97, 115,
  107, 34, 44, 34, 66, 111, 111, 115, 116, 34, 44, 34, 70, 97, 115, 116,
  32, 84, 111, 110, 101, 32, 77, 97, 112, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 69, 113, 117, 97, 108, 105, 122, 101, 32, 61, 32,
  98, 111, 111, 108, 40, 116, 114, 117, 101, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 32, 70, 111, 114,
  32, 97, 32, 109, 111, 114, 101, 32, 34, 112, 97, 105, 110, 116, 101, 100,
  34, 32, 101, 102, 102, 101, 99, 116, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 100, 100, 32, 112, 97, 105, 110, 116, 101, 114, 39,
  115, 32, 116, 111, 117, 99, 104, 32, 61, 32, 98, 111, 111, 108, 40, 102,
  97, 108, 115, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 73, 102, 32, 117,
  110, 99, 104, 101, 99, 107, 101, 100, 32, 116, 104, 101, 32, 51, 32, 115,
  108, 105, 100, 101, 114, 115, 32, 98, 101, 108, 111, 119, 32, 97, 114, 101,
  32, 100, 105, 115, 97, 98, 108, 101, 100, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 80, 97, 105, 110, 116, 101, 114, 39, 115, 32, 116, 111, 117, 99, 104,
  32, 115, 104, 97, 114, 112, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 53, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 80, 97, 105, 110, 116, 101, 114, 39, 115, 32, 101,
  100, 103, 101, 32, 112, 114, 111, 116, 101, 99, 116, 105, 111, 110, 32, 102,
  108, 111, 119, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 53,
  44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80,
  97, 105, 110, 116, 101, 114, 39, 115, 32, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 52, 56,
  44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 80, 104,
  111, 116, 111, 67, 111, 109, 105, 88, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58,
  32, 60, 105, 62, 50, 48, 49, 49, 47, 54, 47, 50, 57, 32, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 115, 116, 101, 97, 109, 112, 101, 110, 32, 58, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32,
  45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45,
  108, 91, 48, 93, 10, 45, 103, 105, 109, 112, 95, 112, 101, 110, 99, 105,
  108, 98, 119, 32, 36, 49, 44, 36, 50, 44, 48, 44, 48, 44, 48, 10,
  45, 103, 105, 109, 112, 95, 107, 117, 119, 97, 104, 97, 114, 97, 32, 36,
  51, 44, 36, 52, 44, 48, 44, 48, 10, 45, 98, 108, 117, 114, 95, 120,
  121, 32, 36, 53, 10, 45, 105, 102, 32, 123, 36, 54, 61, 61, 49, 125,
  32, 45, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101,
  95, 108, 111, 99, 97, 108, 32, 52, 46, 56, 44, 50, 50, 44, 54, 46,
  56, 57, 44, 50, 48, 44, 49, 44, 51, 44, 48, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 54, 61, 61, 50, 125, 32, 45, 103, 105, 109, 112, 95,
  99, 111, 110, 116, 114, 97, 115, 116, 95, 115, 119, 109, 32, 50, 44, 48,
  44, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 54, 61, 61, 51, 125,
  32, 45, 103, 105, 109, 112, 95, 99, 111, 110, 116, 114, 97, 115, 116, 95,
  115, 119, 109, 32, 50, 44, 49, 44, 49, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 54, 61, 61, 52, 125, 32, 45, 103, 105, 109, 112, 95, 109, 97,
  112, 95, 116, 111, 110, 101, 115, 95, 102, 97, 115, 116, 32, 51, 44, 48,
  46, 53, 44, 51, 44, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 55, 61, 61, 49, 125, 32, 45, 101, 113, 117, 97, 108, 105,
  122, 101, 32, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 56, 61, 61, 49, 125, 32, 45, 103, 105, 109, 112, 95,
  97, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111,
  116, 104, 105, 110, 103, 32, 54, 48, 44, 36, 57, 44, 36, 49, 48, 44,
  36, 49, 49, 44, 49, 46, 49, 44, 48, 46, 56, 44, 51, 48, 44, 50,
  44, 48, 44, 49, 44, 49, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 115, 116, 101, 97,
  109, 112, 101, 110, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 115, 116, 101, 97, 109, 112,
  101, 110, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10,
  35, 64, 103, 105, 109, 112, 32, 67, 104, 97, 114, 99, 111, 97, 108, 32,
  58, 32, 103, 105, 109, 112, 95, 99, 104, 97, 114, 99, 111, 97, 108, 44,
  32, 103, 105, 109, 112, 95, 99, 104, 97, 114, 99, 111, 97, 108, 95, 112,
  114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 71, 114, 97, 110, 117, 108, 97, 114, 105, 116, 121, 32, 61,
  32, 105, 110, 116, 40, 54, 53, 44, 48, 44, 56, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 76, 111, 119, 108, 105, 103, 104, 116,
  115, 32, 99, 114, 111, 115, 115, 111, 118, 101, 114, 32, 112, 111, 105, 110,
  116, 32, 61, 32, 105, 110, 116, 40, 55, 48, 44, 48, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 105, 103, 104, 108,
  105, 103, 104, 116, 115, 32, 99, 114, 111, 115, 115, 111, 118, 101, 114, 32,
  112, 111, 105, 110, 116, 32, 61, 32, 105, 110, 116, 40, 49, 55, 48, 44,
  48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  66, 111, 111, 115, 116, 32, 99, 111, 110, 116, 114, 97, 115, 116, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 82, 101, 115, 105, 122, 101, 32, 105, 109, 97, 103, 101, 32, 102,
  111, 114, 32, 111, 112, 116, 105, 109, 117, 109, 32, 101, 102, 102, 101, 99,
  116, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 100, 100, 32, 99, 104, 97, 108, 107, 32, 104,
  105, 103, 104, 108, 105, 103, 104, 116, 115, 32, 61, 32, 98, 111, 111, 108,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 105, 110,
  105, 109, 97, 108, 32, 104, 105, 103, 104, 108, 105, 103, 104, 116, 115, 32,
  61, 32, 105, 110, 116, 40, 53, 48, 44, 48, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 97, 120, 105, 109, 97, 108,
  32, 104, 105, 103, 104, 108, 105, 103, 104, 116, 115, 32, 61, 32, 105, 110,
  116, 40, 55, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 66, 97, 99, 107, 103, 114, 111, 117, 110, 100, 32,
  99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 70, 111, 114, 101, 103, 114, 111, 117, 110, 100, 32, 99,
  111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 48, 44, 48,
  44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 118,
  101, 114, 116, 32, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 47, 102,
  111, 114, 101, 103, 114, 111, 117, 110, 100, 32, 61, 32, 98, 111, 111, 108,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48,
  51, 47, 49, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 73, 110, 115, 112, 105, 114, 101, 100, 32, 102, 114, 111, 109, 32, 116,
  104, 101, 32, 67, 104, 97, 114, 99, 111, 97, 108, 32, 115, 99, 114, 105,
  112, 116, 32, 98, 121, 32, 60, 105, 62, 109, 105, 99, 111, 109, 105, 99,
  111, 110, 60, 47, 105, 62, 32, 58, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107,
  32, 61, 32, 108, 105, 110, 107, 40, 34, 104, 116, 116, 112, 58, 47, 47,
  114, 101, 103, 105, 115, 116, 114, 121, 46, 103, 105, 109, 112, 46, 111, 114,
  103, 47, 110, 111, 100, 101, 47, 50, 53, 48, 55, 56, 34, 41, 10, 103,
  105, 109, 112, 95, 99, 104, 97, 114, 99, 111, 97, 108, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32,
  45, 108, 91, 48, 93, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 109, 97, 120, 10, 119, 61, 123, 119,
  125, 32, 104, 61, 123, 104, 125, 10, 45, 105, 102, 32, 36, 53, 32, 45,
  114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 49, 53, 48, 37, 44,
  49, 53, 48, 37, 44, 49, 44, 49, 44, 54, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 36, 52, 32, 45, 101, 113, 117, 97, 108, 105,
  122, 101, 91, 45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 115, 104, 97, 114,
  112, 101, 110, 32, 123, 36, 49, 42, 51, 125, 32, 45, 99, 117, 116, 32,
  48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 36, 54, 32, 45, 45, 116,
  50, 32, 36, 55, 44, 36, 56, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  116, 50, 91, 48, 93, 32, 36, 50, 44, 36, 51, 10, 45, 105, 102, 32,
  123, 33, 36, 49, 53, 125, 32, 45, 101, 113, 91, 48, 93, 32, 48, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 111, 114, 10, 45, 45, 42, 91, 48,
  93, 32, 36, 49, 48, 32, 45, 45, 42, 91, 48, 93, 32, 36, 49, 49,
  32, 45, 42, 91, 48, 93, 32, 36, 57, 10, 45, 97, 112, 112, 101, 110,
  100, 91, 45, 51, 45, 45, 49, 93, 32, 99, 32, 45, 114, 101, 112, 108,
  97, 99, 101, 95, 99, 111, 108, 111, 114, 32, 48, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 36, 49, 50, 44, 36, 49, 51, 44, 36, 49, 52, 10,
  45, 114, 32, 36, 119, 44, 36, 104, 44, 49, 44, 49, 48, 48, 37, 44,
  50, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 99, 104,
  97, 114, 99, 111, 97, 108, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 99, 104, 97, 114,
  99, 111, 97, 108, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103,
  105, 109, 112, 32, 67, 111, 108, 111, 114, 105, 122, 101, 32, 91, 99, 111,
  109, 105, 99, 115, 93, 32, 58, 32, 103, 105, 109, 112, 95, 99, 111, 108,
  111, 114, 105, 122, 101, 95, 99, 111, 109, 105, 99, 115, 44, 32, 103, 105,
  109, 112, 95, 99, 111, 108, 111, 114, 105, 122, 101, 95, 99, 111, 109, 105,
  99, 115, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 98, 62, 76, 97, 121, 101, 114, 115, 32, 111, 114,
  100, 101, 114, 105, 110, 103, 58, 60, 47, 98, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 73, 110, 112, 117, 116, 32, 108, 97, 121,
  101, 114, 115, 32, 61, 32, 99, 104, 111, 105, 99, 101, 123, 48, 44, 34,
  67, 111, 108, 111, 114, 32, 115, 112, 111, 116, 115, 32, 43, 32, 108, 105,
  110, 101, 97, 114, 116, 34, 44, 34, 76, 105, 110, 101, 97, 114, 116, 32,
  43, 32, 99, 111, 108, 111, 114, 32, 115, 112, 111, 116, 115, 34, 44, 34,
  67, 111, 108, 111, 114, 32, 115, 112, 111, 116, 115, 32, 43, 32, 101, 120,
  116, 114, 97, 112, 111, 108, 97, 116, 101, 100, 32, 99, 111, 108, 111, 114,
  115, 32, 43, 32, 108, 105, 110, 101, 97, 114, 116, 34, 44, 34, 76, 105,
  110, 101, 97, 114, 116, 32, 43, 32, 99, 111, 108, 111, 114, 32, 115, 112,
  111, 116, 115, 32, 43, 32, 101, 120, 116, 114, 97, 112, 111, 108, 97, 116,
  101, 100, 32, 99, 111, 108, 111, 114, 115, 34, 125, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 108, 97, 121, 101,
  114, 115, 32, 61, 32, 95, 99, 104, 111, 105, 99, 101, 123, 49, 44, 34,
  83, 105, 110, 103, 108, 101, 32, 40, 109, 101, 114, 103, 101, 100, 41, 34,
  44, 34, 69, 120, 116, 114, 97, 112, 111, 108, 97, 116, 101, 100, 32, 99,
  111, 108, 111, 114, 115, 32, 43, 32, 108, 105, 110, 101, 97, 114, 116, 34,
  44, 34, 76, 105, 110, 101, 97, 114, 116, 32, 43, 32, 101, 120, 116, 114,
  97, 112, 111, 108, 97, 116, 101, 100, 32, 99, 111, 108, 111, 114, 115, 34,
  44, 34, 67, 111, 108, 111, 114, 32, 115, 112, 111, 116, 115, 32, 43, 32,
  101, 120, 116, 114, 97, 112, 111, 108, 97, 116, 101, 100, 32, 99, 111, 108,
  111, 114, 115, 32, 43, 32, 108, 105, 110, 101, 97, 114, 116, 34, 44, 34,
  76, 105, 110, 101, 97, 114, 116, 32, 43, 32, 99, 111, 108, 111, 114, 32,
  115, 112, 111, 116, 115, 32, 43, 32, 101, 120, 116, 114, 97, 112, 111, 108,
  97, 116, 101, 100, 32, 99, 111, 108, 111, 114, 115, 34, 125, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 48, 53, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 123, 34, 60, 98, 62, 78, 111, 116, 101, 58,
  60, 47, 98, 62, 32, 89, 111, 117, 32, 112, 114, 111, 98, 97, 98, 108,
  121, 32, 110, 101, 101, 100, 32, 116, 111, 32, 115, 101, 108, 101, 99, 116,
  32, 60, 105, 62, 65, 108, 108, 60, 47, 105, 62, 32, 102, 111, 114, 32,
  116, 104, 101, 32, 60, 105, 62, 73, 110, 112, 117, 116, 32, 108, 97, 121,
  101, 114, 115, 60, 47, 105, 62, 32, 111, 112, 116, 105, 111, 110, 32, 111,
  110, 32, 116, 104, 101, 32, 108, 101, 102, 116, 46, 92, 110, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 60, 105, 62, 99, 111, 108, 111, 114, 32,
  115, 112, 111, 116, 115, 60, 47, 105, 62, 32, 61, 32, 121, 111, 117, 114,
  32, 108, 97, 121, 101, 114, 32, 119, 105, 116, 104, 32, 99, 111, 108, 111,
  114, 32, 105, 110, 100, 105, 99, 97, 116, 105, 111, 110, 115, 46, 92, 110,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 105, 62, 108, 105, 110,
  101, 97, 114, 116, 60, 47, 105, 62, 32, 61, 32, 121, 111, 117, 114, 32,
  108, 97, 121, 101, 114, 32, 119, 105, 116, 104, 32, 108, 105, 110, 101, 45,
  97, 114, 116, 32, 40, 98, 38, 97, 109, 112, 59, 119, 32, 111, 114, 32,
  116, 114, 97, 110, 115, 112, 97, 114, 101, 110, 116, 41, 46, 92, 110, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 105, 62, 101, 120, 116, 114,
  97, 112, 111, 108, 97, 116, 101, 100, 32, 99, 111, 108, 111, 114, 115, 60,
  47, 105, 62, 32, 61, 32, 116, 104, 101, 32, 71, 39, 77, 73, 67, 32,
  103, 101, 110, 101, 114, 97, 116, 101, 100, 32, 108, 97, 121, 101, 114, 32,
  119, 105, 116, 104, 32, 102, 108, 97, 116, 32, 99, 111, 108, 111, 114, 115,
  46, 92, 110, 92, 110, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60,
  98, 62, 87, 97, 114, 110, 105, 110, 103, 58, 60, 47, 98, 62, 32, 68,
  111, 32, 110, 111, 116, 32, 114, 101, 108, 121, 32, 116, 111, 111, 32, 109,
  117, 99, 104, 32, 111, 110, 32, 116, 104, 101, 32, 112, 114, 101, 118, 105,
  101, 119, 44, 32, 105, 116, 32, 105, 115, 32, 112, 114, 111, 98, 97, 98,
  108, 121, 32, 110, 111, 116, 32, 97, 99, 99, 117, 114, 97, 116, 101, 32,
  33, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 125, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 115, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32,
  84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59,
  44, 32, 84, 105, 109, 111, 116, 104, 38, 35, 50, 51, 51, 59, 101, 32,
  71, 105, 101, 116, 44, 32, 68, 97, 118, 105, 100, 32, 82, 101, 118, 111,
  121, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 51, 47, 48, 54, 47, 49, 57, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 76, 105, 110, 107, 32, 61, 32, 108, 105, 110, 107, 40, 48, 46, 53,
  44, 34, 77, 111, 114, 101, 32, 105, 110, 102, 111, 115, 32, 111, 110, 32,
  116, 104, 105, 115, 32, 102, 105, 108, 116, 101, 114, 34, 44, 34, 104, 116,
  116, 112, 58, 47, 47, 119, 119, 119, 46, 103, 105, 109, 112, 99, 104, 97,
  116, 46, 99, 111, 109, 47, 118, 105, 101, 119, 116, 111, 112, 105, 99, 46,
  112, 104, 112, 63, 102, 61, 50, 56, 38, 116, 61, 55, 53, 54, 55, 34,
  41, 10, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 105, 122, 101, 95,
  99, 111, 109, 105, 99, 115, 32, 58, 10, 45, 105, 102, 32, 123, 64, 35,
  60, 50, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 60, 50, 125, 32, 115, 101,
  108, 101, 99, 116, 105, 111, 110, 61, 48, 44, 49, 32, 45, 101, 108, 115,
  101, 32, 115, 101, 108, 101, 99, 116, 105, 111, 110, 61, 48, 44, 49, 44,
  50, 32, 45, 101, 110, 100, 105, 102, 10, 45, 108, 91, 36, 115, 101, 108,
  101, 99, 116, 105, 111, 110, 93, 10, 45, 105, 102, 32, 123, 36, 49, 61,
  61, 48, 125, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49,
  125, 32, 45, 114, 118, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61,
  61, 50, 125, 32, 45, 114, 109, 91, 49, 93, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 61, 61, 51, 125, 32, 45, 114, 109, 91, 50, 93, 32,
  45, 114, 118, 10, 45, 101, 110, 100, 105, 102, 10, 45, 45, 116, 111, 95,
  114, 103, 98, 97, 91, 48, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111,
  112, 97, 99, 105, 116, 121, 91, 45, 49, 93, 32, 45, 43, 91, 45, 50,
  93, 32, 49, 32, 45, 110, 101, 113, 91, 45, 49, 93, 32, 48, 32, 45,
  42, 91, 45, 50, 44, 45, 49, 93, 10, 45, 45, 110, 111, 114, 109, 91,
  49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 45,
  104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 49, 93, 32, 50, 44,
  48, 44, 49, 10, 45, 105, 102, 32, 123, 105, 40, 48, 41, 62, 105, 40,
  49, 41, 125, 32, 45, 42, 91, 45, 50, 93, 32, 45, 49, 32, 45, 43,
  91, 45, 50, 93, 32, 49, 32, 45, 101, 110, 100, 105, 102, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 98, 91, 45, 49, 93, 32, 36, 51, 37,
  32, 45, 119, 97, 116, 101, 114, 115, 104, 101, 100, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 45, 91,
  45, 49, 93, 32, 49, 10, 45, 105, 102, 32, 123, 36, 50, 61, 61, 48,
  125, 32, 45, 114, 109, 91, 48, 93, 32, 45, 114, 118, 32, 45, 98, 108,
  101, 110, 100, 91, 48, 44, 49, 93, 32, 109, 117, 108, 116, 105, 112, 108,
  121, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 61, 61, 49, 125, 32,
  45, 114, 109, 91, 48, 93, 32, 45, 114, 118, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 50, 61, 61, 50, 125, 32, 45, 114, 109, 91, 48, 93, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 50, 61, 61, 51, 125, 32, 45, 114,
  118, 91, 49, 44, 50, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50,
  61, 61, 52, 125, 32, 45, 114, 118, 91, 48, 44, 49, 93, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 10, 103, 105, 109, 112, 95,
  99, 111, 108, 111, 114, 105, 122, 101, 95, 99, 111, 109, 105, 99, 115, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  99, 111, 108, 111, 114, 105, 122, 101, 95, 99, 111, 109, 105, 99, 115, 32,
  36, 49, 44, 48, 44, 36, 51, 10, 35, 64, 103, 105, 109, 112, 32, 67,
  111, 108, 111, 114, 105, 122, 101, 32, 91, 112, 104, 111, 116, 111, 103, 114,
  97, 112, 104, 115, 93, 32, 58, 32, 103, 105, 109, 112, 95, 114, 101, 99,
  111, 108, 111, 114, 105, 122, 101, 44, 32, 103, 105, 109, 112, 95, 114, 101,
  99, 111, 108, 111, 114, 105, 122, 101, 95, 112, 114, 101, 118, 105, 101, 119,
  40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 105, 110, 116, 40, 50, 44,
  48, 44, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110,
  105, 115, 111, 116, 114, 111, 112, 121, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 50, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 109, 111, 100, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 77, 101, 114, 103, 101, 32, 98,
  114, 105, 103, 104, 116, 110, 101, 115, 115, 47, 99, 111, 108, 111, 114, 115,
  34, 44, 34, 83, 112, 108, 105, 116, 32, 98, 114, 105, 103, 104, 116, 110,
  101, 115, 115, 47, 99, 111, 108, 111, 114, 115, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 98,
  62, 78, 111, 116, 101, 58, 60, 47, 98, 62, 32, 84, 104, 105, 115, 32,
  102, 105, 108, 116, 101, 114, 32, 110, 101, 101, 100, 115, 32, 116, 119, 111,
  32, 108, 97, 121, 101, 114, 115, 32, 116, 111, 32, 119, 111, 114, 107, 32,
  112, 114, 111, 112, 101, 114, 108, 121, 46, 32, 84, 104, 101, 32, 98, 111,
  116, 116, 111, 109, 32, 108, 97, 121, 101, 114, 32, 109, 117, 115, 116, 32,
  98, 101, 32, 97, 32, 66, 38, 97, 109, 112, 59, 87, 32, 105, 109, 97,
  103, 101, 44, 32, 119, 104, 105, 108, 101, 32, 116, 104, 101, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 116, 111, 112, 32, 108, 97, 121, 101, 114,
  32, 99, 111, 110, 116, 97, 105, 110, 115, 32, 99, 111, 108, 111, 114, 32,
  112, 97, 116, 99, 104, 101, 115, 32, 116, 104, 97, 116, 32, 119, 105, 108,
  108, 32, 98, 101, 32, 101, 120, 116, 114, 97, 112, 111, 108, 97, 116, 101,
  100, 32, 105, 110, 32, 97, 32, 115, 109, 97, 114, 116, 32, 119, 97, 121,
  32, 40, 101, 100, 103, 101, 45, 100, 105, 114, 101, 99, 116, 101, 100, 41,
  32, 116, 111, 32, 102, 105, 108, 108, 32, 116, 104, 101, 32, 101, 110, 116,
  105, 114, 101, 32, 105, 109, 97, 103, 101, 46, 32, 65, 116, 32, 116, 104,
  101, 32, 101, 110, 100, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  121, 111, 117, 32, 103, 101, 116, 32, 97, 32, 99, 111, 109, 112, 108, 101,
  116, 101, 108, 121, 32, 114, 101, 99, 111, 108, 111, 114, 101, 100, 32, 105,
  109, 97, 103, 101, 46, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32,
  60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112,
  101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 49, 47, 49, 54,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  103, 105, 109, 112, 95, 114, 101, 99, 111, 108, 111, 114, 105, 122, 101, 32,
  58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64,
  35, 47, 50, 41, 125, 10, 45, 105, 102, 32, 36, 51, 32, 115, 61, 36,
  62, 44, 123, 36, 62, 43, 49, 125, 32, 45, 101, 108, 115, 101, 32, 115,
  61, 123, 50, 42, 36, 62, 125, 44, 123, 50, 42, 36, 62, 43, 49, 125,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 108, 91, 36, 115, 93, 32, 45,
  114, 118, 91, 48, 44, 49, 93, 10, 45, 99, 104, 97, 110, 110, 101, 108,
  115, 91, 48, 93, 32, 48, 32, 45, 116, 111, 95, 114, 103, 98, 91, 45,
  50, 93, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 32,
  45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 91, 45,
  49, 93, 32, 45, 110, 101, 113, 91, 45, 49, 93, 32, 48, 10, 45, 115,
  114, 103, 98, 50, 114, 103, 98, 91, 45, 51, 44, 45, 50, 93, 32, 45,
  114, 103, 98, 50, 108, 97, 98, 56, 91, 45, 51, 44, 45, 50, 93, 32,
  45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 51, 93, 32, 48, 32,
  45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 50, 93, 32, 49, 44,
  50, 10, 45, 43, 91, 45, 50, 93, 32, 49, 32, 45, 42, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 32, 45, 45, 103, 114, 97, 100, 105, 101, 110,
  116, 95, 110, 111, 114, 109, 91, 45, 51, 93, 32, 45, 42, 91, 45, 49,
  93, 32, 45, 49, 32, 45, 119, 97, 116, 101, 114, 115, 104, 101, 100, 91,
  45, 51, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 45, 91, 45, 50, 93, 32, 49, 10, 45, 45, 100, 105, 102, 102,
  117, 115, 105, 111, 110, 116, 101, 110, 115, 111, 114, 115, 91, 45, 51, 93,
  32, 36, 50, 44, 49, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 101,
  113, 91, 45, 50, 93, 32, 48, 32, 45, 42, 91, 45, 49, 93, 32, 91,
  45, 50, 93, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 115, 109, 111,
  111, 116, 104, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 123, 36, 49,
  42, 56, 48, 125, 44, 48, 46, 56, 44, 54, 48, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32,
  45, 108, 97, 98, 56, 50, 114, 103, 98, 91, 45, 49, 93, 32, 45, 114,
  103, 98, 50, 115, 114, 103, 98, 91, 45, 49, 93, 10, 45, 105, 102, 32,
  36, 51, 32, 45, 114, 103, 98, 50, 104, 115, 118, 91, 45, 49, 93, 32,
  45, 115, 91, 45, 49, 93, 32, 99, 32, 45, 105, 91, 50, 93, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 49, 32, 45,
  105, 91, 51, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 50, 44, 48, 32, 45, 97, 91, 48, 45, 50, 93, 32, 99, 32, 45,
  97, 91, 94, 48, 93, 32, 99, 32, 45, 104, 115, 118, 50, 114, 103, 98,
  32, 45, 114, 118, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  108, 10, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 114, 101, 99,
  111, 108, 111, 114, 105, 122, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 114, 101, 99, 111, 108, 111, 114, 105,
  122, 101, 32, 36, 42, 32, 45, 97, 32, 120, 10, 35, 64, 103, 105, 109,
  112, 32, 67, 111, 108, 111, 114, 105, 122, 101, 32, 91, 119, 105, 116, 104,
  32, 99, 111, 108, 111, 114, 109, 97, 112, 93, 32, 58, 32, 103, 105, 109,
  112, 95, 98, 119, 114, 101, 99, 111, 108, 111, 114, 105, 122, 101, 44, 32,
  103, 105, 109, 112, 95, 98, 119, 114, 101, 99, 111, 108, 111, 114, 105, 122,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 71, 97, 109, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 45, 49, 46, 50, 44, 49, 46, 50, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 110, 116, 114, 97, 115, 116, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 66, 114, 105, 103, 104, 116, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 114, 109, 97, 108, 105, 122, 101, 32, 61, 32, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 71, 114, 97, 100, 105, 101, 110, 116, 32,
  112, 114, 101, 115, 101, 116, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 85, 115, 101, 114, 45, 100, 101, 102, 105, 110, 101, 100, 34, 44, 34,
  66, 108, 97, 99, 107, 32, 116, 111, 32, 119, 104, 105, 116, 101, 34, 44,
  34, 87, 104, 105, 116, 101, 32, 116, 111, 32, 98, 108, 97, 99, 107, 34,
  44, 34, 83, 101, 112, 105, 97, 34, 44, 34, 83, 111, 108, 97, 114, 105,
  122, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110,
  116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 78, 101, 97,
  114, 101, 115, 116, 34, 44, 34, 76, 105, 110, 101, 97, 114, 34, 44, 34,
  67, 117, 98, 105, 99, 34, 44, 34, 76, 97, 110, 99, 122, 111, 115, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 115, 101,
  114, 118, 101, 32, 105, 110, 105, 116, 105, 97, 108, 32, 98, 114, 105, 103,
  104, 116, 110, 101, 115, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 60, 117, 62, 85, 115, 101, 114, 45, 100, 101, 102, 105, 110, 101, 100,
  32, 103, 114, 97, 100, 105, 101, 110, 116, 32, 58, 60, 47, 117, 62, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 117, 109, 98, 101, 114, 32, 111, 102, 32, 116, 111, 110,
  101, 115, 32, 61, 32, 105, 110, 116, 40, 53, 44, 50, 44, 56, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 49, 115, 116, 32, 116, 111, 110,
  101, 32, 61, 32, 99, 111, 108, 111, 114, 40, 48, 44, 48, 44, 48, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 50, 110,
  100, 32, 116, 111, 110, 101, 32, 61, 32, 99, 111, 108, 111, 114, 40, 52,
  51, 44, 50, 53, 44, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 51, 114, 100, 32, 116, 111, 110, 101, 32, 61,
  32, 99, 111, 108, 111, 114, 40, 49, 53, 56, 44, 49, 51, 55, 44, 49,
  56, 57, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 52, 116, 104, 32, 116, 111, 110, 101, 32, 61, 32, 99, 111, 108, 111,
  114, 40, 50, 50, 52, 44, 49, 57, 49, 44, 50, 50, 56, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 53, 116, 104, 32,
  116, 111, 110, 101, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 54, 116, 104, 32, 116, 111, 110, 101, 32,
  61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 55, 116, 104, 32, 116, 111, 110, 101, 32, 61, 32, 99, 111, 108,
  111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 56, 116, 104,
  32, 116, 111, 110, 101, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105,
  99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60,
  105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101,
  114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103,
  105, 109, 112, 95, 98, 119, 114, 101, 99, 111, 108, 111, 114, 105, 122, 101,
  32, 58, 10, 45, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105,
  116, 121, 10, 45, 105, 102, 32, 36, 52, 32, 45, 110, 32, 48, 44, 50,
  53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  53, 61, 61, 48, 125, 10, 40, 36, 123, 57, 45, 45, 50, 125, 41, 32,
  45, 114, 91, 45, 49, 93, 32, 52, 44, 36, 56, 44, 49, 44, 49, 44,
  45, 49, 32, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 49, 93, 32,
  121, 122, 99, 120, 10, 45, 101, 108, 105, 102, 32, 123, 36, 53, 61, 61,
  49, 125, 10, 40, 48, 44, 50, 53, 53, 94, 48, 44, 50, 53, 53, 94,
  48, 44, 50, 53, 53, 94, 50, 53, 53, 44, 50, 53, 53, 41, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 53, 61, 61, 50, 125, 10, 40, 50, 53,
  53, 44, 48, 94, 50, 53, 53, 44, 48, 94, 50, 53, 53, 44, 48, 94,
  50, 53, 53, 44, 50, 53, 53, 41, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 53, 61, 61, 51, 125, 10, 40, 48, 44, 52, 52, 44, 49, 49, 53,
  44, 49, 52, 51, 44, 49, 57, 54, 44, 50, 52, 52, 94, 48, 44, 50,
  48, 44, 56, 52, 44, 49, 49, 57, 44, 49, 56, 52, 44, 50, 51, 53,
  94, 48, 44, 53, 44, 52, 52, 44, 55, 51, 44, 49, 52, 52, 44, 50,
  48, 48, 94, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 41, 10, 45, 101, 108, 115,
  101, 10, 40, 48, 44, 51, 53, 57, 94, 49, 44, 49, 94, 49, 44, 49,
  94, 50, 53, 53, 44, 50, 53, 53, 41, 32, 45, 114, 91, 45, 49, 93,
  32, 50, 53, 54, 44, 49, 44, 49, 44, 52, 44, 51, 32, 45, 115, 104,
  91, 45, 49, 93, 32, 48, 44, 50, 32, 45, 104, 115, 118, 50, 114, 103,
  98, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 54, 61, 61, 48, 125,
  32, 45, 114, 91, 45, 49, 93, 32, 50, 53, 54, 44, 49, 44, 49, 44,
  52, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 54, 61, 61, 49,
  125, 32, 45, 114, 91, 45, 49, 93, 32, 50, 53, 54, 44, 49, 44, 49,
  44, 52, 44, 51, 10, 45, 101, 108, 105, 102, 32, 123, 36, 54, 61, 61,
  50, 125, 32, 45, 114, 91, 45, 49, 93, 32, 50, 53, 54, 44, 49, 44,
  49, 44, 52, 44, 53, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 10, 45, 101, 108, 115, 101, 32, 45, 114, 91, 45, 49, 93, 32,
  50, 53, 54, 44, 49, 44, 49, 44, 52, 44, 54, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 55, 61, 61, 49, 125, 32, 45,
  115, 104, 91, 45, 49, 93, 32, 48, 44, 50, 32, 45, 114, 103, 98, 50,
  104, 115, 118, 91, 45, 49, 93, 32, 45, 115, 104, 91, 45, 49, 93, 32,
  50, 44, 50, 32, 45, 102, 91, 45, 49, 93, 32, 120, 47, 119, 32, 45,
  104, 115, 118, 50, 114, 103, 98, 91, 45, 50, 93, 32, 45, 114, 109, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 108,
  91, 94, 45, 49, 93, 32, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101,
  32, 45, 97, 112, 112, 108, 121, 95, 103, 97, 109, 109, 97, 32, 123, 49,
  48, 94, 36, 49, 125, 32, 45, 45, 32, 49, 50, 56, 32, 45, 42, 32,
  36, 50, 32, 45, 43, 32, 123, 36, 51, 43, 49, 50, 56, 125, 32, 45,
  99, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 108, 32, 45, 109,
  97, 112, 91, 94, 45, 49, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 103, 105, 109, 112, 95, 98, 119, 114, 101, 99, 111,
  108, 111, 114, 105, 122, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 98, 119, 114, 101,
  99, 111, 108, 111, 114, 105, 122, 101, 32, 36, 123, 94, 48, 125, 34, 44,
  36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 68, 105, 116, 104, 101,
  114, 105, 110, 103, 32, 58, 32, 103, 105, 109, 112, 95, 100, 105, 116, 104,
  101, 114, 101, 100, 98, 119, 44, 32, 103, 105, 109, 112, 95, 100, 105, 116,
  104, 101, 114, 101, 100, 98, 119, 95, 112, 114, 101, 118, 105, 101, 119, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 97, 109, 109,
  97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 46, 50,
  44, 49, 46, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  111, 110, 116, 114, 97, 115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  66, 114, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 117, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 51, 54, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 97, 116, 117, 114, 97,
  116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49,
  50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 100, 105, 116, 104, 101, 114, 101,
  100, 98, 119, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111,
  112, 97, 99, 105, 116, 121, 32, 45, 108, 91, 48, 93, 10, 45, 108, 117,
  109, 105, 110, 97, 110, 99, 101, 32, 45, 110, 32, 48, 44, 50, 53, 53,
  32, 45, 97, 112, 112, 108, 121, 95, 103, 97, 109, 109, 97, 32, 123, 49,
  48, 94, 36, 49, 125, 32, 45, 45, 32, 49, 50, 56, 32, 45, 42, 32,
  36, 50, 32, 45, 43, 32, 49, 50, 56, 32, 45, 43, 32, 36, 51, 32,
  45, 98, 32, 36, 52, 32, 45, 99, 32, 48, 44, 50, 53, 53, 32, 45,
  100, 105, 116, 104, 101, 114, 101, 100, 98, 119, 10, 45, 105, 102, 32, 123,
  36, 53, 124, 124, 36, 54, 125, 32, 45, 47, 32, 50, 53, 53, 32, 45,
  105, 91, 48, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 50, 32, 45, 102, 99, 91, 48, 93, 32, 36, 53, 44, 36, 54, 32,
  45, 97, 32, 99, 32, 45, 104, 115, 118, 50, 114, 103, 98, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112,
  95, 100, 105, 116, 104, 101, 114, 101, 100, 98, 119, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112,
  95, 100, 105, 116, 104, 101, 114, 101, 100, 98, 119, 32, 36, 42, 34, 44,
  36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 72, 97, 114, 100, 32,
  115, 107, 101, 116, 99, 104, 32, 58, 32, 103, 105, 109, 112, 95, 104, 97,
  114, 100, 115, 107, 101, 116, 99, 104, 98, 119, 44, 32, 103, 105, 109, 112,
  95, 104, 97, 114, 100, 115, 107, 101, 116, 99, 104, 98, 119, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 51, 48, 48, 44, 48, 44, 52, 48, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 110, 115, 105, 116, 121,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 69, 100, 103, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50,
  48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 70, 97, 115, 116, 32, 97, 112, 112, 114, 111, 120, 105, 109, 97,
  116, 105, 111, 110, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 109, 111,
  100, 101, 108, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 66, 108,
  97, 99, 107, 32, 111, 110, 32, 119, 104, 105, 116, 101, 34, 44, 34, 87,
  104, 105, 116, 101, 32, 111, 110, 32, 98, 108, 97, 99, 107, 34, 44, 34,
  66, 108, 97, 99, 107, 32, 111, 110, 32, 116, 114, 97, 110, 115, 112, 97,
  114, 101, 110, 116, 32, 119, 104, 105, 116, 101, 34, 44, 34, 87, 104, 105,
  116, 101, 32, 111, 110, 32, 116, 114, 97, 110, 115, 112, 97, 114, 101, 110,
  116, 32, 98, 108, 97, 99, 107, 34, 44, 34, 67, 111, 108, 111, 114, 32,
  111, 110, 32, 119, 104, 105, 116, 101, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117,
  108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117,
  112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  104, 97, 114, 100, 115, 107, 101, 116, 99, 104, 98, 119, 32, 58, 10, 45,
  98, 32, 36, 51, 10, 45, 105, 102, 32, 123, 36, 55, 61, 61, 52, 125,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 32, 45, 45, 104, 97, 114, 100, 115, 107, 101, 116, 99, 104, 98,
  119, 32, 36, 49, 44, 36, 50, 44, 36, 52, 44, 36, 53, 44, 36, 54,
  32, 45, 98, 108, 101, 110, 100, 32, 104, 97, 114, 100, 108, 105, 103, 104,
  116, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 114,
  101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 104, 97,
  114, 100, 115, 107, 101, 116, 99, 104, 98, 119, 32, 36, 49, 44, 36, 50,
  44, 36, 52, 44, 36, 53, 44, 36, 54, 10, 45, 105, 102, 32, 123, 36,
  55, 38, 49, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 55, 61, 61, 50,
  125, 32, 45, 114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 52, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 115,
  104, 91, 36, 62, 93, 32, 51, 44, 51, 32, 45, 42, 91, 45, 49, 93,
  32, 45, 50, 32, 45, 43, 91, 45, 49, 93, 32, 123, 50, 42, 50, 53,
  53, 125, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32,
  45, 114, 109, 91, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 55, 61, 61, 51, 125, 32, 45, 114, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 52, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 115, 104, 91, 36, 62, 93, 32,
  51, 44, 51, 32, 45, 42, 91, 45, 49, 93, 32, 50, 32, 45, 99, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49,
  93, 32, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 103,
  105, 109, 112, 95, 104, 97, 114, 100, 115, 107, 101, 116, 99, 104, 98, 119,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 103, 105, 109, 112, 95, 104, 97, 114, 100, 115, 107, 101, 116, 99, 104,
  98, 119, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 72, 111, 117, 103, 104, 32, 115, 107, 101, 116, 99, 104, 32, 58,
  32, 103, 105, 109, 112, 95, 104, 111, 117, 103, 104, 115, 107, 101, 116, 99,
  104, 98, 119, 44, 32, 103, 105, 109, 112, 95, 104, 111, 117, 103, 104, 115,
  107, 101, 116, 99, 104, 98, 119, 95, 112, 114, 101, 118, 105, 101, 119, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  46, 50, 53, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 68, 101, 110, 115, 105, 116, 121, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 48, 44, 48, 44, 55, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 82, 97, 100, 105, 117, 115, 32, 61, 32, 105, 110,
  116, 40, 53, 44, 48, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 56, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 49, 44, 48, 44, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32,
  109, 111, 100, 101, 108, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  66, 108, 97, 99, 107, 32, 111, 110, 32, 119, 104, 105, 116, 101, 34, 44,
  34, 87, 104, 105, 116, 101, 32, 111, 110, 32, 98, 108, 97, 99, 107, 34,
  44, 34, 66, 108, 97, 99, 107, 32, 111, 110, 32, 116, 114, 97, 110, 115,
  112, 97, 114, 101, 110, 116, 32, 119, 104, 105, 116, 101, 34, 44, 34, 87,
  104, 105, 116, 101, 32, 111, 110, 32, 116, 114, 97, 110, 115, 112, 97, 114,
  101, 110, 116, 32, 98, 108, 97, 99, 107, 34, 44, 34, 67, 111, 108, 111,
  114, 32, 111, 110, 32, 119, 104, 105, 116, 101, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97,
  116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 49, 47, 48, 53, 47, 49, 56, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 104, 111, 117, 103, 104, 115, 107, 101, 116, 99, 104, 98, 119, 32,
  58, 10, 45, 98, 32, 36, 49, 32, 45, 110, 32, 48, 44, 50, 53, 53,
  10, 45, 105, 102, 32, 123, 36, 54, 61, 61, 52, 125, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45,
  45, 104, 111, 117, 103, 104, 115, 107, 101, 116, 99, 104, 98, 119, 32, 36,
  123, 50, 45, 53, 125, 32, 45, 98, 108, 101, 110, 100, 32, 104, 97, 114,
  100, 108, 105, 103, 104, 116, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 104, 111, 117, 103, 104, 115, 107, 101, 116, 99, 104, 98, 119,
  32, 36, 123, 50, 45, 53, 125, 10, 45, 105, 102, 32, 123, 36, 54, 38,
  49, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 54, 61, 61, 50, 125, 32,
  45, 114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 52,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 115, 104, 91,
  36, 62, 93, 32, 51, 44, 51, 32, 45, 42, 91, 45, 49, 93, 32, 45,
  50, 32, 45, 43, 91, 45, 49, 93, 32, 123, 50, 42, 50, 53, 53, 125,
  32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 54, 61, 61, 51, 125, 32, 45, 114, 32, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 49, 44, 52, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 115, 104, 91, 36, 62, 93, 32, 51, 44,
  51, 32, 45, 42, 91, 45, 49, 93, 32, 50, 32, 45, 99, 91, 45, 49,
  93, 32, 48, 44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109,
  112, 95, 104, 111, 117, 103, 104, 115, 107, 101, 116, 99, 104, 98, 119, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  103, 105, 109, 112, 95, 104, 111, 117, 103, 104, 115, 107, 101, 116, 99, 104,
  98, 119, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 73, 110, 107, 32, 119, 97, 115, 104, 32, 58, 32, 103, 105, 109,
  112, 95, 105, 110, 107, 95, 119, 97, 115, 104, 44, 32, 103, 105, 109, 112,
  95, 105, 110, 107, 95, 119, 97, 115, 104, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 73, 110, 107, 32, 119, 97, 115, 104, 32, 99, 111, 110, 116,
  114, 111, 108, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 49,
  52, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 50, 51, 44, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 67, 104, 101,
  99, 107, 32, 105, 102, 32, 121, 111, 117, 32, 119, 105, 115, 104, 32, 118,
  105, 115, 117, 97, 108, 32, 99, 111, 110, 116, 114, 111, 108, 32, 111, 110,
  32, 116, 104, 105, 115, 32, 115, 116, 101, 112, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 107, 105, 112, 32, 97, 108, 108, 32, 111,
  116, 104, 101, 114, 32, 115, 116, 101, 112, 115, 32, 61, 32, 98, 111, 111,
  108, 40, 102, 97, 108, 115, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 32, 40, 34,
  85, 78, 99, 104, 101, 99, 107, 32, 116, 111, 32, 114, 101, 97, 99, 116,
  105, 118, 97, 116, 101, 32, 116, 104, 101, 32, 111, 116, 104, 101, 114, 32,
  99, 111, 110, 116, 114, 111, 108, 115, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  109, 111, 111, 116, 104, 101, 114, 32, 115, 104, 97, 114, 112, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44,
  50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111,
  116, 104, 101, 114, 32, 101, 100, 103, 101, 32, 112, 114, 111, 116, 101, 99,
  116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53,
  52, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 109, 111, 111, 116, 104, 101, 114, 32, 115, 111, 102, 116, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 46, 50, 53, 44, 48,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 116, 114, 101, 116, 99, 104,
  32, 99, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 78, 111, 110, 101, 34, 44, 34, 65, 117, 116, 111, 109,
  97, 116, 105, 99, 34, 44, 34, 65, 117, 116, 111, 109, 97, 116, 105, 99,
  32, 38, 32, 67, 111, 110, 116, 114, 97, 115, 116, 32, 77, 97, 115, 107,
  34, 44, 34, 77, 97, 110, 117, 97, 108, 32, 67, 111, 110, 116, 114, 111,
  108, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 32, 40, 34, 84, 111, 32, 97,
  99, 116, 105, 118, 97, 116, 101, 32, 116, 104, 101, 32, 115, 108, 105, 100,
  101, 114, 115, 32, 98, 101, 108, 111, 119, 32, 99, 104, 111, 115, 101, 32,
  39, 77, 97, 110, 117, 97, 108, 32, 67, 111, 110, 116, 114, 111, 108, 115,
  39, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 76, 110, 32, 97, 109, 112, 108, 105,
  116, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50,
  44, 48, 44, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  76, 110, 32, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  54, 44, 48, 44, 54, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 76, 110, 32, 110, 101, 105, 103, 104, 116, 98, 111, 114, 104, 111, 111,
  100, 45, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 53, 44, 48, 44, 52, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 76, 110, 32, 97, 118, 101, 114, 97, 103, 101,
  45, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 50, 48, 44, 48, 44, 52, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 58, 32, 60, 105, 62, 80, 104, 111, 116, 111, 67, 111, 109,
  105, 88, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 49, 47, 52, 47, 53, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 48, 44, 34, 70,
  111, 114, 117, 109, 32, 116, 104, 114, 101, 97, 100, 32, 97, 98, 111, 117,
  116, 32, 116, 104, 101, 32, 102, 105, 108, 116, 101, 114, 32, 100, 105, 115,
  99, 117, 115, 115, 105, 111, 110, 34, 44, 34, 104, 116, 116, 112, 58, 47,
  47, 103, 105, 109, 112, 99, 104, 97, 116, 46, 99, 111, 109, 47, 118, 105,
  101, 119, 116, 111, 112, 105, 99, 46, 112, 104, 112, 63, 102, 61, 49, 48,
  38, 116, 61, 57, 49, 52, 34, 41, 10, 103, 105, 109, 112, 95, 105, 110,
  107, 95, 119, 97, 115, 104, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105,
  116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91, 48, 93, 10,
  45, 103, 105, 109, 112, 95, 112, 101, 110, 99, 105, 108, 98, 119, 91, 45,
  49, 93, 32, 36, 49, 44, 36, 50, 44, 48, 44, 48, 44, 48, 10, 45,
  105, 102, 32, 123, 36, 51, 61, 61, 49, 125, 32, 45, 99, 111, 110, 116,
  105, 110, 117, 101, 10, 45, 101, 108, 105, 102, 32, 123, 36, 51, 61, 61,
  48, 125, 32, 45, 103, 105, 109, 112, 95, 97, 110, 105, 115, 111, 116, 114,
  111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 91, 45,
  49, 93, 32, 54, 48, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 49,
  46, 49, 44, 48, 46, 56, 44, 51, 48, 44, 50, 44, 48, 44, 49, 44,
  49, 44, 48, 44, 49, 44, 49, 54, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 55, 61, 61, 49, 125, 32, 45, 110, 111, 114,
  109, 97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 91, 45, 49, 93,
  32, 50, 44, 54, 44, 53, 44, 50, 52, 44, 49, 44, 48, 44, 50, 53,
  53, 10, 45, 101, 108, 105, 102, 32, 123, 36, 55, 61, 61, 50, 125, 32,
  32, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 108, 111, 99, 97,
  108, 91, 45, 49, 93, 32, 50, 44, 54, 44, 53, 44, 50, 52, 44, 49,
  44, 48, 44, 50, 53, 53, 32, 45, 103, 105, 109, 112, 95, 99, 111, 110,
  116, 114, 97, 115, 116, 95, 115, 119, 109, 32, 50, 44, 48, 44, 48, 46,
  53, 49, 50, 10, 45, 101, 108, 105, 102, 32, 123, 36, 55, 61, 61, 51,
  125, 32, 45, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97, 108, 105, 122,
  101, 95, 108, 111, 99, 97, 108, 91, 45, 49, 93, 32, 36, 56, 44, 36,
  57, 44, 36, 49, 48, 44, 36, 49, 49, 44, 49, 44, 51, 44, 48, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32,
  99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64,
  103, 105, 109, 112, 32, 77, 117, 108, 116, 105, 45, 108, 97, 121, 101, 114,
  32, 101, 116, 99, 104, 32, 58, 32, 103, 105, 109, 112, 95, 103, 99, 100,
  95, 108, 97, 121, 101, 114, 101, 116, 99, 104, 44, 32, 103, 105, 109, 112,
  95, 103, 99, 100, 95, 108, 97, 121, 101, 114, 101, 116, 99, 104, 40, 50,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 117, 62, 69, 116, 99, 104, 32,
  119, 105, 116, 104, 32, 115, 101, 108, 101, 99, 116, 97, 98, 108, 101, 32,
  110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 108, 97, 121, 101, 114, 115,
  60, 47, 117, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 98, 62,
  87, 97, 114, 110, 105, 110, 103, 58, 32, 87, 105, 116, 104, 32, 104, 105,
  103, 104, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 108, 97, 121,
  101, 114, 115, 32, 116, 104, 105, 115, 32, 99, 97, 110, 32, 98, 101, 32,
  86, 69, 82, 89, 32, 115, 108, 111, 119, 33, 60, 47, 98, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 84, 111, 116, 97, 108, 32, 108, 97, 121, 101, 114,
  115, 32, 61, 32, 105, 110, 116, 40, 49, 49, 44, 50, 44, 49, 54, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 87, 104, 105, 116, 101, 32,
  108, 97, 121, 101, 114, 115, 32, 61, 32, 105, 110, 116, 40, 52, 44, 49,
  44, 49, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 116,
  99, 104, 32, 116, 111, 110, 101, 115, 32, 61, 32, 105, 110, 116, 40, 49,
  50, 44, 50, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 84, 111, 110, 101, 32, 98, 108, 117, 114, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 49, 50, 44, 48, 44, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 105, 115, 101, 32, 108, 101, 118, 101,
  108, 32, 61, 32, 105, 110, 116, 40, 49, 48, 48, 44, 53, 44, 50, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 97, 114, 107,
  32, 108, 101, 110, 103, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  56, 46, 53, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 66, 114, 105, 103, 104, 116, 32, 108, 101, 110, 103, 116, 104,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 50, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 116, 97, 114, 116, 32,
  97, 110, 103, 108, 101, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44,
  49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97,
  110, 100, 111, 109, 32, 97, 110, 103, 108, 101, 32, 61, 32, 105, 110, 116,
  40, 48, 44, 48, 44, 52, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 77, 97, 120, 32, 99, 117, 114, 118, 101, 32, 61, 32, 105, 110,
  116, 40, 51, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 71, 97, 109, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 44, 48, 46, 48, 49, 44, 50, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 112, 114, 101, 97, 100, 32, 97, 110, 103, 108, 101,
  115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 70, 97, 115, 116, 32, 114, 101, 115, 105, 122, 101,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 32, 58, 32, 60, 105, 62, 71, 97, 114, 97, 103, 101, 99, 111, 100,
  101, 114, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62,
  50, 48, 49, 50, 47, 49, 50, 47, 50, 49, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 103,
  99, 100, 95, 108, 97, 121, 101, 114, 101, 116, 99, 104, 32, 58, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 54, 125, 44, 36, 123, 50,
  61, 55, 125, 44, 36, 123, 51, 61, 49, 52, 125, 44, 36, 123, 52, 61,
  48, 46, 49, 50, 125, 44, 36, 123, 53, 61, 49, 48, 48, 125, 44, 36,
  123, 54, 61, 53, 125, 44, 36, 123, 55, 61, 52, 46, 54, 53, 125, 44,
  36, 123, 56, 61, 48, 125, 44, 36, 123, 57, 61, 48, 125, 44, 36, 123,
  49, 48, 61, 51, 125, 44, 36, 123, 49, 49, 61, 49, 125, 44, 36, 123,
  49, 50, 61, 49, 125, 44, 36, 123, 49, 51, 61, 48, 125, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 32, 115, 99, 61, 56,
  48, 48, 32, 109, 108, 61, 36, 49, 32, 119, 108, 61, 123, 109, 105, 110,
  40, 36, 50, 44, 36, 109, 108, 45, 49, 41, 125, 10, 110, 119, 108, 61,
  123, 36, 109, 108, 45, 36, 119, 108, 125, 32, 110, 119, 108, 61, 123, 36,
  110, 119, 108, 43, 40, 36, 110, 119, 108, 37, 50, 61, 61, 48, 41, 125,
  10, 45, 105, 102, 32, 123, 33, 36, 49, 51, 125, 32, 110, 119, 61, 36,
  119, 32, 110, 104, 61, 36, 104, 10, 45, 101, 108, 105, 102, 32, 123, 119,
  62, 104, 125, 32, 110, 119, 61, 123, 109, 105, 110, 40, 36, 115, 99, 44,
  119, 41, 125, 32, 110, 104, 61, 123, 36, 110, 119, 47, 119, 42, 104, 125,
  10, 45, 101, 108, 115, 101, 32, 110, 104, 61, 123, 109, 105, 110, 40, 36,
  115, 99, 44, 104, 41, 125, 32, 110, 119, 61, 123, 36, 110, 104, 47, 104,
  42, 119, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 114,
  103, 98, 91, 48, 93, 32, 91, 48, 93, 32, 45, 114, 91, 49, 93, 32,
  36, 110, 119, 44, 36, 110, 104, 10, 45, 110, 111, 114, 109, 91, 49, 93,
  32, 45, 110, 91, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 45, 116,
  111, 110, 101, 115, 91, 49, 93, 32, 36, 109, 108, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 36, 109, 108, 45, 49, 125, 32, 45, 43, 91, 123,
  45, 36, 60, 45, 49, 125, 93, 32, 91, 123, 45, 36, 60, 45, 50, 125,
  93, 32, 45, 100, 111, 110, 101, 10, 45, 98, 91, 45, 36, 109, 108, 45,
  45, 49, 93, 32, 36, 52, 37, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  36, 109, 108, 10, 112, 99, 61, 123, 40, 36, 62, 43, 49, 41, 47, 36,
  109, 108, 125, 32, 109, 115, 107, 61, 123, 50, 43, 36, 62, 125, 32, 123,
  119, 125, 44, 123, 104, 125, 44, 49, 44, 49, 44, 48, 10, 45, 105, 102,
  32, 36, 49, 50, 32, 97, 110, 103, 61, 123, 36, 62, 47, 36, 110, 119,
  108, 125, 32, 45, 101, 108, 115, 101, 32, 97, 110, 103, 61, 36, 112, 99,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 60, 62,
  61, 36, 119, 108, 125, 10, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93,
  32, 123, 40, 49, 45, 36, 112, 99, 41, 42, 36, 53, 125, 44, 50, 10,
  45, 98, 108, 117, 114, 95, 108, 105, 110, 101, 97, 114, 91, 45, 49, 93,
  32, 123, 36, 54, 43, 36, 112, 99, 42, 40, 36, 55, 45, 36, 54, 41,
  125, 37, 44, 48, 44, 123, 36, 97, 110, 103, 42, 51, 54, 48, 43, 63,
  40, 45, 36, 57, 44, 36, 57, 41, 43, 36, 56, 125, 10, 45, 113, 117,
  97, 110, 116, 105, 122, 101, 91, 45, 49, 93, 32, 36, 51, 44, 48, 32,
  45, 100, 101, 102, 111, 114, 109, 91, 45, 49, 93, 32, 123, 63, 42, 36,
  49, 48, 43, 49, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 91,
  45, 49, 93, 32, 36, 110, 119, 44, 36, 110, 104, 32, 45, 110, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 109, 117, 108, 91, 36, 109,
  115, 107, 44, 45, 49, 93, 32, 45, 112, 114, 111, 103, 114, 101, 115, 115,
  32, 123, 36, 112, 99, 42, 49, 48, 48, 125, 10, 45, 100, 111, 110, 101,
  10, 45, 97, 100, 100, 91, 45, 36, 109, 108, 45, 45, 49, 93, 32, 45,
  99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 110, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 110, 101, 103, 97, 116, 105,
  118, 101, 91, 45, 49, 93, 32, 45, 97, 112, 112, 108, 121, 95, 103, 97,
  109, 109, 97, 91, 45, 49, 93, 32, 36, 49, 49, 10, 45, 105, 102, 32,
  36, 49, 51, 32, 45, 114, 91, 45, 49, 93, 32, 36, 119, 44, 36, 104,
  44, 49, 44, 51, 44, 53, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 107, 101, 101, 112,
  91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 35, 64, 103, 105, 109, 112, 32, 80, 101, 110, 99, 105, 108, 32, 58,
  32, 103, 105, 109, 112, 95, 112, 101, 110, 99, 105, 108, 98, 119, 44, 32,
  103, 105, 109, 112, 95, 112, 101, 110, 99, 105, 108, 98, 119, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  46, 51, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 54, 48, 44, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 72, 117, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101,
  119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99,
  97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105,
  62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114,
  108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 51, 47, 48, 53, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 112, 101, 110, 99, 105, 108, 98, 119, 32, 58, 10, 45, 112,
  101, 110, 99, 105, 108, 98, 119, 32, 36, 49, 44, 36, 50, 10, 45, 105,
  102, 32, 123, 36, 51, 124, 124, 36, 52, 125, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112,
  108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 10, 45, 47, 91, 48,
  93, 32, 50, 53, 53, 32, 45, 105, 91, 48, 93, 32, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 36, 52, 32, 45, 105, 91,
  48, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49,
  44, 36, 51, 32, 45, 97, 91, 48, 45, 50, 93, 32, 99, 32, 45, 104,
  115, 118, 50, 114, 103, 98, 91, 48, 93, 10, 45, 97, 32, 99, 32, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 105,
  102, 10, 103, 105, 109, 112, 95, 112, 101, 110, 99, 105, 108, 98, 119, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  103, 105, 109, 112, 95, 112, 101, 110, 99, 105, 108, 98, 119, 32, 36, 42,
  34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 80, 101, 110,
  99, 105, 108, 32, 112, 111, 114, 116, 114, 97, 105, 116, 32, 58, 32, 103,
  105, 109, 112, 95, 112, 101, 110, 99, 105, 108, 95, 112, 111, 114, 116, 114,
  97, 105, 116, 98, 119, 44, 32, 103, 105, 109, 112, 95, 112, 101, 110, 99,
  105, 108, 95, 112, 111, 114, 116, 114, 97, 105, 116, 98, 119, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 116, 114, 111, 107, 101, 32, 108, 101, 110, 103, 116, 104, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 51, 48, 44, 48, 44, 53, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 116, 114, 111, 107,
  101, 32, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 50, 48, 44, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 110, 116, 111, 117, 114, 32, 116, 104, 114, 101,
  115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44,
  48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112,
  97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 49, 52,
  52, 44, 55, 57, 44, 50, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108,
  105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 115, 58, 32, 60, 105, 62, 82, 97, 109,
  111, 110, 32, 77, 105, 114, 97, 110, 100, 97, 60, 47, 105, 62, 32, 97,
  110, 100, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104,
  117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 50, 47, 49, 50,
  47, 49, 49, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 103, 105, 109, 112, 95, 112, 101, 110, 99, 105, 108, 95, 112,
  111, 114, 116, 114, 97, 105, 116, 98, 119, 32, 58, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115,
  112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91,
  48, 93, 10, 45, 45, 98, 32, 50, 37, 10, 45, 45, 98, 108, 101, 110,
  100, 32, 100, 105, 118, 105, 100, 101, 32, 45, 114, 109, 91, 45, 50, 93,
  32, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 45, 49, 93, 10,
  45, 103, 105, 109, 112, 95, 105, 110, 107, 95, 119, 97, 115, 104, 91, 45,
  50, 93, 32, 48, 44, 49, 54, 55, 44, 48, 44, 48, 46, 53, 44, 48,
  46, 53, 52, 44, 50, 46, 50, 53, 44, 48, 44, 50, 44, 54, 44, 53,
  44, 50, 48, 10, 45, 45, 103, 105, 109, 112, 95, 104, 97, 114, 100, 115,
  107, 101, 116, 99, 104, 98, 119, 91, 45, 49, 93, 32, 56, 48, 44, 51,
  50, 44, 49, 46, 56, 57, 44, 48, 46, 50, 49, 44, 51, 49, 46, 52,
  54, 44, 48, 44, 48, 10, 45, 45, 103, 105, 109, 112, 95, 115, 107, 101,
  116, 99, 104, 98, 119, 91, 45, 50, 93, 32, 49, 44, 36, 50, 44, 49,
  56, 48, 44, 36, 49, 44, 36, 51, 44, 48, 46, 48, 51, 44, 48, 44,
  48, 46, 54, 44, 48, 46, 49, 44, 48, 46, 54, 44, 48, 46, 50, 53,
  44, 49, 44, 48, 44, 49, 44, 48, 10, 45, 98, 108, 101, 110, 100, 91,
  48, 44, 49, 93, 32, 100, 97, 114, 107, 101, 110, 10, 45, 98, 108, 101,
  110, 100, 91, 48, 44, 49, 93, 32, 109, 117, 108, 116, 105, 112, 108, 121,
  44, 48, 46, 53, 10, 45, 98, 108, 101, 110, 100, 91, 48, 44, 49, 93,
  32, 108, 105, 103, 104, 116, 101, 110, 44, 36, 52, 10, 45, 110, 111, 114,
  109, 97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 32, 44, 10, 45,
  116, 111, 95, 114, 103, 98, 32, 45, 45, 102, 99, 32, 36, 123, 53, 45,
  55, 125, 32, 45, 98, 108, 101, 110, 100, 32, 115, 111, 102, 116, 108, 105,
  103, 104, 116, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95,
  112, 101, 110, 99, 105, 108, 95, 112, 111, 114, 116, 114, 97, 105, 116, 98,
  119, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 112, 101, 110, 99, 105, 108, 95, 112, 111,
  114, 116, 114, 97, 105, 116, 98, 119, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 83, 107, 101, 116, 99, 104, 32, 58,
  32, 103, 105, 109, 112, 95, 115, 107, 101, 116, 99, 104, 98, 119, 44, 32,
  103, 105, 109, 112, 95, 115, 107, 101, 116, 99, 104, 98, 119, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 117, 109, 98, 101, 114, 32, 111, 102, 32, 111, 114, 105, 101,
  110, 116, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 50,
  44, 49, 44, 49, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 116, 97, 114, 116, 105, 110, 103, 32, 97, 110, 103, 108, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 52, 53, 44, 48, 44, 49, 56, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32,
  114, 97, 110, 103, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 56,
  48, 44, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 116, 114, 111, 107, 101, 32, 108, 101, 110, 103, 116, 104, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 51, 48, 44, 48, 44, 49, 48, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116,
  111, 117, 114, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 51, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 48, 51, 44, 48, 44, 48, 46, 51,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 97, 99, 107, 103,
  114, 111, 117, 110, 100, 32, 105, 110, 116, 101, 110, 115, 105, 116, 121, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 50, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 110, 115, 105, 116, 121, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 54, 44, 48, 44, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 114, 112, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 49, 44,
  48, 44, 49, 46, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  65, 110, 105, 115, 111, 116, 114, 111, 112, 121, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 54, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 50, 53, 44, 48, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 104, 101,
  114, 101, 110, 99, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44,
  48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66,
  111, 111, 115, 116, 32, 115, 116, 114, 111, 107, 101, 32, 61, 32, 98, 111,
  111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  117, 114, 118, 101, 100, 32, 115, 116, 114, 111, 107, 101, 32, 61, 32, 98,
  111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 108, 111, 114, 32, 109, 111, 100, 101, 108, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 66, 108, 97, 99, 107, 32, 111, 110, 32, 119,
  104, 105, 116, 101, 34, 44, 34, 87, 104, 105, 116, 101, 32, 111, 110, 32,
  98, 108, 97, 99, 107, 34, 44, 34, 66, 108, 97, 99, 107, 32, 111, 110,
  32, 116, 114, 97, 110, 115, 112, 97, 114, 101, 110, 116, 32, 119, 104, 105,
  116, 101, 34, 44, 34, 87, 104, 105, 116, 101, 32, 111, 110, 32, 116, 114,
  97, 110, 115, 112, 97, 114, 101, 110, 116, 32, 98, 108, 97, 99, 107, 34,
  44, 34, 67, 111, 108, 111, 114, 32, 111, 110, 32, 119, 104, 105, 116, 101,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80,
  114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68,
  117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104,
  117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50,
  47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 103, 105, 109, 112, 95, 115, 107, 101, 116, 99, 104, 98, 119,
  32, 58, 10, 45, 105, 102, 32, 123, 36, 49, 53, 61, 61, 52, 125, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 32, 45, 45, 115, 107, 101, 116, 99, 104, 98, 119, 32, 36, 123, 49,
  45, 49, 52, 125, 32, 45, 98, 108, 101, 110, 100, 32, 104, 97, 114, 100,
  108, 105, 103, 104, 116, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 115, 107, 101, 116, 99, 104, 98, 119, 32, 36, 123, 49, 45, 49,
  52, 125, 10, 45, 105, 102, 32, 123, 36, 49, 53, 38, 49, 125, 32, 45,
  110, 101, 103, 97, 116, 105, 118, 101, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 49, 53, 61, 61, 50, 125, 32, 45, 114, 32,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 52, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 115, 104, 91, 36, 62, 93,
  32, 51, 44, 51, 32, 45, 42, 91, 45, 49, 93, 32, 45, 50, 32, 45,
  43, 91, 45, 49, 93, 32, 123, 50, 42, 50, 53, 53, 125, 32, 45, 99,
  91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 114, 109, 91, 45,
  49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 53, 61, 61, 51, 125, 32, 45, 114, 32, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 44, 49, 44, 52, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 115, 104, 91, 36, 62, 93, 32, 51, 44, 51, 32,
  45, 42, 91, 45, 49, 93, 32, 50, 32, 45, 99, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 100,
  111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95,
  115, 107, 101, 116, 99, 104, 98, 119, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 115, 107,
  101, 116, 99, 104, 98, 119, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35,
  64, 103, 105, 109, 112, 32, 83, 116, 97, 109, 112, 32, 58, 32, 103, 105,
  109, 112, 95, 115, 116, 97, 109, 112, 44, 32, 103, 105, 109, 112, 95, 115,
  116, 97, 109, 112, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 117, 116, 111, 45, 116, 104,
  114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 98, 111, 111, 108, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115,
  104, 111, 108, 100, 32, 61, 32, 105, 110, 116, 40, 53, 48, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 104, 97, 114, 112, 101, 110, 105, 110, 103, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 51, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 71, 114, 97, 105, 110, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 73, 110, 118, 101, 114, 116, 32, 99, 111, 108,
  111, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108, 115, 101,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117,
  112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  115, 58, 32, 60, 105, 62, 65, 110, 116, 97, 114, 111, 110, 44, 32, 77,
  97, 104, 118, 105, 110, 44, 32, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 50, 48,
  49, 50, 47, 49, 48, 47, 48, 56, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 115, 116, 97, 109, 112, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116,
  121, 10, 45, 110, 111, 114, 109, 32, 45, 110, 111, 105, 115, 101, 32, 36,
  53, 10, 45, 105, 102, 32, 36, 49, 32, 45, 111, 116, 115, 117, 32, 50,
  53, 54, 32, 45, 101, 108, 115, 101, 32, 45, 103, 101, 32, 36, 50, 37,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 98, 32, 36, 51, 44, 48, 32,
  45, 115, 104, 97, 114, 112, 101, 110, 32, 36, 52, 32, 45, 110, 32, 48,
  44, 50, 53, 53, 10, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118,
  101, 32, 49, 44, 48, 44, 48, 44, 49, 48, 49, 44, 51, 51, 44, 49,
  55, 48, 44, 50, 50, 57, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45,
  105, 102, 32, 36, 54, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 97, 32, 99, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 115, 116, 97,
  109, 112, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 115, 116, 97, 109, 112, 32, 36, 42,
  34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 84, 104, 114,
  101, 115, 104, 111, 108, 100, 32, 101, 116, 99, 104, 32, 58, 32, 103, 105,
  109, 112, 95, 103, 99, 100, 95, 101, 116, 99, 104, 44, 32, 103, 105, 109,
  112, 95, 103, 99, 100, 95, 101, 116, 99, 104, 95, 112, 114, 101, 118, 105,
  101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 117, 62, 82,
  101, 112, 108, 97, 99, 101, 32, 116, 111, 110, 101, 115, 32, 119, 105, 116,
  104, 32, 110, 111, 105, 115, 101, 32, 103, 101, 110, 101, 114, 97, 116, 101,
  100, 32, 108, 105, 110, 101, 115, 60, 47, 117, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 92, 110, 60, 105, 62, 73, 110, 112, 117, 116, 32, 73,
  109, 97, 103, 101, 32, 83, 101, 116, 116, 105, 110, 103, 115, 60, 47, 105,
  62, 34, 41, 44, 32, 115, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  84, 104, 114, 101, 115, 104, 111, 108, 100, 32, 108, 111, 119, 32, 61, 32,
  105, 110, 116, 40, 49, 50, 53, 44, 49, 48, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111,
  108, 100, 32, 109, 105, 100, 32, 61, 32, 105, 110, 116, 40, 49, 53, 51,
  44, 49, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32, 104, 105, 103, 104,
  32, 61, 32, 105, 110, 116, 40, 49, 55, 49, 44, 49, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101,
  115, 104, 111, 108, 100, 32, 109, 97, 120, 32, 61, 32, 105, 110, 116, 40,
  49, 56, 53, 44, 49, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 66, 108, 117, 114, 32, 97, 109, 111, 117, 110, 116,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 49, 44, 48, 44, 50,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 92, 110, 60, 105, 62, 79, 117, 116,
  112, 117, 116, 32, 69, 116, 99, 104, 32, 83, 101, 116, 116, 105, 110, 103,
  115, 60, 47, 105, 62, 34, 41, 44, 32, 115, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 72, 111, 114, 105, 122, 111, 110, 116, 97, 108, 32, 97,
  109, 111, 117, 110, 116, 32, 61, 32, 105, 110, 116, 40, 53, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  114, 111, 115, 115, 45, 104, 97, 116, 99, 104, 32, 97, 109, 111, 117, 110,
  116, 32, 61, 32, 105, 110, 116, 40, 56, 48, 44, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 101, 114, 116, 105,
  99, 97, 108, 32, 49, 32, 97, 109, 111, 117, 110, 116, 32, 61, 32, 105,
  110, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 86, 101, 114, 116, 105, 99, 97, 108, 32, 50,
  32, 97, 109, 111, 117, 110, 116, 32, 61, 32, 105, 110, 116, 40, 49, 48,
  44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 32, 108, 101, 110, 103, 116, 104, 32, 61, 32,
  105, 110, 116, 40, 49, 53, 44, 48, 44, 53, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 86, 101, 114, 116, 105, 99, 97, 108, 32, 49,
  32, 108, 101, 110, 103, 116, 104, 32, 61, 32, 105, 110, 116, 40, 49, 50,
  44, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  86, 101, 114, 116, 105, 99, 97, 108, 32, 50, 32, 108, 101, 110, 103, 116,
  104, 32, 61, 32, 105, 110, 116, 40, 50, 48, 44, 48, 44, 53, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 108, 105, 112, 32, 99,
  114, 111, 115, 115, 45, 104, 97, 116, 99, 104, 32, 61, 32, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 114, 118, 101, 32, 97,
  109, 111, 117, 110, 116, 32, 61, 32, 105, 110, 116, 40, 49, 44, 48, 44,
  50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 97, 109,
  109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 51, 44, 48,
  46, 48, 49, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  70, 97, 115, 116, 32, 114, 101, 115, 105, 122, 101, 32, 61, 32, 98, 111,
  111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  111, 108, 111, 114, 32, 105, 109, 97, 103, 101, 32, 61, 32, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 71, 97, 114,
  97, 103, 101, 99, 111, 100, 101, 114, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 50, 47, 48, 57,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  103, 105, 109, 112, 95, 103, 99, 100, 95, 101, 116, 99, 104, 32, 58, 10,
  45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 50, 53, 125, 44, 36,
  123, 50, 61, 49, 53, 51, 125, 44, 36, 123, 51, 61, 49, 55, 49, 125,
  44, 36, 123, 52, 61, 49, 56, 53, 125, 44, 36, 123, 53, 61, 48, 46,
  49, 125, 32, 45, 115, 107, 105, 112, 32, 36, 123, 54, 61, 53, 48, 125,
  44, 36, 123, 55, 61, 56, 48, 125, 44, 36, 123, 56, 61, 53, 48, 125,
  44, 36, 123, 57, 61, 49, 48, 125, 10, 45, 115, 107, 105, 112, 32, 36,
  123, 49, 48, 61, 49, 53, 125, 44, 36, 123, 49, 49, 61, 49, 50, 125,
  44, 36, 123, 49, 50, 61, 50, 48, 125, 44, 36, 123, 49, 51, 61, 48,
  125, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 52, 61, 49, 125, 44,
  36, 123, 49, 53, 61, 48, 46, 51, 125, 44, 36, 123, 49, 54, 61, 49,
  125, 44, 36, 123, 49, 55, 61, 48, 125, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 61, 123, 119,
  125, 32, 104, 61, 123, 104, 125, 32, 115, 99, 61, 56, 48, 48, 32, 109,
  108, 61, 52, 10, 45, 105, 102, 32, 123, 119, 62, 104, 125, 32, 110, 119,
  61, 123, 109, 105, 110, 40, 36, 115, 99, 44, 119, 41, 125, 32, 110, 104,
  61, 123, 36, 110, 119, 47, 119, 42, 104, 125, 32, 45, 101, 108, 115, 101,
  32, 110, 104, 61, 123, 109, 105, 110, 40, 36, 115, 99, 44, 104, 41, 125,
  32, 110, 119, 61, 123, 36, 110, 104, 47, 104, 42, 119, 125, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 32,
  91, 48, 93, 32, 45, 105, 102, 32, 36, 49, 54, 32, 45, 114, 91, 49,
  93, 32, 36, 110, 119, 44, 36, 110, 104, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 98, 91, 49, 93, 32, 36, 53, 37, 32, 45, 110, 111, 114, 109,
  91, 49, 93, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 49, 93,
  32, 45, 110, 91, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 45, 99,
  91, 49, 93, 32, 48, 44, 123, 50, 53, 53, 45, 36, 52, 125, 32, 45,
  45, 99, 91, 49, 93, 32, 123, 50, 53, 53, 45, 36, 51, 125, 44, 49,
  50, 56, 32, 45, 45, 99, 91, 49, 93, 32, 123, 50, 53, 53, 45, 36,
  50, 125, 44, 49, 57, 50, 32, 45, 45, 99, 91, 49, 93, 32, 123, 50,
  53, 53, 45, 36, 49, 125, 44, 50, 53, 53, 32, 45, 110, 91, 45, 51,
  45, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 123, 119, 125, 44, 123,
  104, 125, 44, 49, 44, 49, 44, 48, 32, 45, 110, 111, 105, 115, 101, 91,
  45, 49, 93, 32, 36, 54, 44, 50, 32, 45, 100, 101, 114, 105, 99, 104,
  101, 91, 45, 49, 93, 32, 36, 49, 48, 44, 48, 44, 120, 44, 48, 10,
  123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 49, 44, 48, 32, 45, 110,
  111, 105, 115, 101, 91, 45, 49, 93, 32, 36, 55, 44, 50, 32, 123, 119,
  125, 44, 123, 104, 125, 44, 49, 44, 51, 44, 48, 32, 45, 102, 99, 91,
  45, 49, 93, 32, 48, 44, 45, 49, 44, 48, 32, 45, 115, 109, 111, 111,
  116, 104, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 51, 48, 44, 51,
  48, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 105, 102, 32,
  36, 49, 51, 32, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32,
  120, 32, 45, 101, 110, 100, 105, 102, 10, 123, 119, 125, 44, 123, 104, 125,
  44, 49, 44, 49, 44, 48, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49,
  93, 32, 36, 56, 44, 50, 32, 45, 100, 101, 114, 105, 99, 104, 101, 91,
  45, 49, 93, 32, 36, 49, 49, 44, 48, 44, 121, 44, 48, 10, 123, 119,
  125, 44, 123, 104, 125, 44, 49, 44, 49, 44, 48, 32, 45, 110, 111, 105,
  115, 101, 91, 45, 49, 93, 32, 36, 57, 44, 50, 32, 45, 100, 101, 114,
  105, 99, 104, 101, 91, 45, 49, 93, 32, 36, 49, 50, 44, 48, 44, 121,
  44, 48, 10, 45, 113, 117, 97, 110, 116, 105, 122, 101, 91, 45, 36, 109,
  108, 45, 45, 49, 93, 32, 50, 44, 48, 32, 45, 100, 101, 102, 111, 114,
  109, 91, 45, 36, 109, 108, 45, 45, 49, 93, 32, 36, 49, 52, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 36, 109, 108, 32, 45, 109, 117, 108, 91,
  123, 50, 43, 36, 62, 125, 44, 45, 49, 93, 32, 45, 100, 111, 110, 101,
  10, 45, 97, 100, 100, 91, 45, 36, 109, 108, 45, 45, 49, 93, 32, 45,
  110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 114, 109, 91,
  49, 93, 10, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93,
  32, 45, 97, 112, 112, 108, 121, 95, 103, 97, 109, 109, 97, 91, 45, 49,
  93, 32, 36, 49, 53, 10, 45, 105, 102, 32, 36, 49, 54, 32, 45, 114,
  91, 45, 49, 93, 32, 36, 119, 44, 36, 104, 44, 49, 44, 51, 44, 53,
  32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 49, 55, 32, 45, 98, 108,
  101, 110, 100, 91, 48, 44, 49, 93, 32, 115, 104, 97, 112, 101, 97, 118,
  101, 114, 97, 103, 101, 32, 45, 101, 108, 115, 101, 32, 45, 107, 101, 101,
  112, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 103, 99,
  100, 95, 101, 116, 99, 104, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 103, 99, 100, 95,
  101, 116, 99, 104, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45,
  49, 10, 35, 64, 103, 105, 109, 112, 32, 95, 10, 35, 64, 103, 105, 109,
  112, 32, 60, 98, 62, 67, 111, 108, 111, 114, 115, 60, 47, 98, 62, 10,
  35, 64, 103, 105, 109, 112, 32, 65, 98, 115, 116, 114, 97, 99, 116, 105,
  111, 110, 32, 58, 32, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 95,
  97, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 44, 32, 103, 105, 109,
  112, 95, 99, 111, 108, 111, 114, 95, 97, 98, 115, 116, 114, 97, 99, 116,
  105, 111, 110, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 101, 118, 101,
  108, 115, 32, 61, 32, 105, 110, 116, 40, 49, 48, 44, 50, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116,
  114, 97, 115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 50,
  44, 48, 46, 48, 49, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108,
  105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 49, 47, 49, 48, 47, 49, 57, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 99, 111,
  108, 111, 114, 95, 97, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 32,
  58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105,
  116, 121, 32, 45, 108, 91, 48, 93, 32, 45, 116, 111, 95, 114, 103, 98,
  10, 45, 98, 32, 36, 49, 32, 45, 115, 32, 99, 32, 45, 113, 117, 97,
  110, 116, 105, 122, 101, 32, 36, 50, 44, 49, 44, 48, 32, 45, 97, 114,
  101, 97, 32, 48, 32, 45, 94, 32, 36, 51, 32, 45, 110, 32, 48, 44,
  50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95,
  99, 111, 108, 111, 114, 95, 97, 98, 115, 116, 114, 97, 99, 116, 105, 111,
  110, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 95, 97, 98, 115,
  116, 114, 97, 99, 116, 105, 111, 110, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 66, 111, 111, 115, 116, 45, 102, 97,
  100, 101, 32, 58, 32, 103, 105, 109, 112, 95, 98, 111, 111, 115, 116, 95,
  102, 97, 100, 101, 44, 32, 103, 105, 109, 112, 95, 98, 111, 111, 115, 116,
  95, 102, 97, 100, 101, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 49, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101,
  118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112,
  108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109,
  112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 49, 48, 47, 49,
  50, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 103, 105, 109, 112, 95, 98, 111, 111, 115, 116, 95, 102, 97, 100, 101,
  32, 58, 10, 45, 105, 91, 48, 93, 32, 54, 52, 48, 44, 52, 56, 48,
  44, 49, 44, 51, 32, 45, 114, 97, 110, 100, 91, 48, 93, 32, 48, 44,
  49, 32, 45, 98, 91, 48, 93, 32, 123, 49, 48, 45, 36, 49, 125, 32,
  45, 110, 91, 48, 93, 32, 48, 44, 50, 53, 53, 32, 45, 116, 114, 97,
  110, 115, 102, 101, 114, 95, 99, 111, 108, 111, 114, 115, 32, 45, 114, 109,
  91, 48, 93, 10, 103, 105, 109, 112, 95, 98, 111, 111, 115, 116, 95, 102,
  97, 100, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 103, 105, 109, 112, 95, 98, 111, 111, 115, 116, 95, 102,
  97, 100, 101, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105,
  109, 112, 32, 67, 104, 97, 110, 110, 101, 108, 32, 112, 114, 111, 99, 101,
  115, 115, 105, 110, 103, 32, 58, 32, 103, 105, 109, 112, 95, 99, 104, 97,
  110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 44,
  32, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114,
  111, 99, 101, 115, 115, 105, 110, 103, 95, 112, 114, 101, 118, 105, 101, 119,
  40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 97, 109,
  109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 46,
  50, 44, 49, 46, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 66, 114, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108,
  117, 101, 32, 97, 99, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 78, 111, 110, 101, 34, 44, 34, 67, 117, 116, 34, 44,
  34, 67, 117, 116, 32, 38, 32, 78, 111, 114, 109, 97, 108, 105, 122, 101,
  34, 44, 34, 78, 111, 114, 109, 97, 108, 105, 122, 101, 34, 44, 34, 84,
  104, 114, 101, 115, 104, 111, 108, 100, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 76, 111, 119, 32, 118, 97, 108, 117, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 72, 105, 103, 104, 32, 118, 97, 108,
  117, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 81,
  117, 97, 110, 116, 105, 122, 97, 116, 105, 111, 110, 32, 61, 32, 105, 110,
  116, 40, 50, 53, 54, 44, 49, 44, 50, 53, 54, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 69, 113, 117, 97, 108, 105, 122, 97, 116, 105,
  111, 110, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 101, 103, 97, 116, 105, 111, 110, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 111, 110,
  101, 115, 32, 114, 97, 110, 103, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 65, 108, 108, 32, 116, 111, 110, 101, 115, 34, 44, 34, 83,
  104, 97, 100, 111, 119, 115, 34, 44, 34, 77, 105, 100, 45, 116, 111, 110,
  101, 115, 34, 44, 34, 72, 105, 103, 104, 108, 105, 103, 104, 116, 115, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 111, 110, 101, 115,
  32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 50, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34,
  44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114,
  111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101,
  32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82,
  101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83,
  97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117,
  101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32,
  99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34,
  71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65,
  108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99,
  97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65,
  117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32,
  84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59,
  60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49,
  48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 95, 103, 105, 109, 112, 95, 99, 104, 97,
  110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32,
  58, 10, 45, 97, 112, 112, 108, 121, 95, 103, 97, 109, 109, 97, 91, 45,
  49, 93, 32, 123, 49, 48, 94, 36, 49, 125, 10, 45, 105, 102, 32, 123,
  36, 50, 33, 61, 49, 125, 32, 45, 45, 91, 45, 49, 93, 32, 49, 50,
  56, 32, 45, 42, 91, 45, 49, 93, 32, 36, 50, 32, 45, 43, 91, 45,
  49, 93, 32, 49, 50, 56, 32, 45, 101, 110, 100, 105, 102, 10, 45, 43,
  91, 45, 49, 93, 32, 36, 51, 10, 45, 98, 91, 45, 49, 93, 32, 36,
  52, 37, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10,
  45, 105, 102, 32, 123, 36, 53, 61, 61, 49, 125, 32, 45, 99, 91, 45,
  49, 93, 32, 36, 54, 37, 44, 36, 55, 37, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 53, 61, 61, 50, 125, 32, 45, 99, 91, 45, 49, 93, 32,
  36, 54, 37, 44, 36, 55, 37, 32, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 10, 45, 101, 108, 105, 102, 32, 123, 36, 53, 61, 61,
  51, 125, 32, 45, 110, 91, 45, 49, 93, 32, 36, 54, 37, 44, 36, 55,
  37, 10, 45, 101, 108, 105, 102, 32, 123, 36, 53, 61, 61, 52, 125, 32,
  45, 116, 50, 91, 45, 49, 93, 32, 36, 54, 37, 44, 36, 55, 37, 32,
  45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 56, 33, 61, 50, 53, 54, 125, 32,
  45, 113, 117, 97, 110, 116, 105, 122, 101, 91, 45, 49, 93, 32, 36, 56,
  44, 49, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  36, 57, 32, 45, 101, 113, 117, 97, 108, 105, 122, 101, 91, 45, 49, 93,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 49, 48, 32,
  45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32, 45, 101,
  110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101,
  108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 45, 49, 93,
  32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32,
  45, 114, 118, 32, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10,
  45, 103, 105, 109, 112, 95, 115, 116, 97, 114, 116, 95, 109, 105, 120, 32,
  36, 49, 49, 44, 36, 49, 50, 10, 45, 97, 112, 112, 108, 121, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 34, 45, 95, 103,
  105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111, 99,
  101, 115, 115, 105, 110, 103, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44,
  36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 44, 36,
  57, 44, 36, 49, 48, 34, 44, 36, 49, 51, 44, 48, 10, 45, 103, 105,
  109, 112, 95, 101, 110, 100, 95, 109, 105, 120, 32, 36, 49, 49, 10, 45,
  105, 102, 32, 123, 64, 35, 33, 61, 51, 125, 32, 45, 114, 118, 32, 45,
  97, 32, 99, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 108,
  32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101,
  10, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114,
  111, 99, 101, 115, 115, 105, 110, 103, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 99, 104,
  97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32,
  67, 77, 89, 75, 32, 116, 111, 110, 101, 32, 58, 32, 105, 97, 105, 110,
  95, 99, 109, 121, 107, 95, 116, 111, 110, 101, 44, 32, 105, 97, 105, 110,
  95, 99, 109, 121, 107, 95, 116, 111, 110, 101, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123,
  34, 60, 98, 62, 65, 100, 106, 117, 115, 116, 32, 99, 121, 97, 110, 115,
  60, 47, 98, 62, 32, 102, 111, 114, 32, 112, 105, 120, 101, 108, 115, 32,
  116, 104, 97, 116, 32, 104, 97, 118, 101, 58, 34, 125, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 65, 32, 108, 111, 116, 32, 111, 102, 32, 99,
  121, 97, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50,
  53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 111, 109, 101, 32, 99, 121, 97, 110, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 116, 116, 108, 101, 32, 99,
  121, 97, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50,
  53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 98,
  62, 65, 100, 106, 117, 115, 116, 32, 99, 121, 97, 110, 115, 60, 47, 98,
  62, 32, 102, 111, 114, 32, 112, 105, 120, 101, 108, 115, 32, 116, 104, 97,
  116, 32, 104, 97, 118, 101, 58, 34, 125, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 32, 108, 111, 116, 32, 111, 102, 32, 109, 97, 103, 101,
  110, 116, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50,
  53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 111, 109, 101, 32, 109, 97, 103, 101, 110, 116, 97, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 116, 116, 108,
  101, 32, 109, 97, 103, 101, 110, 116, 97, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 123, 34, 60, 98, 62, 65, 100, 106, 117, 115, 116, 32, 99, 121,
  97, 110, 115, 60, 47, 98, 62, 32, 102, 111, 114, 32, 112, 105, 120, 101,
  108, 115, 32, 116, 104, 97, 116, 32, 104, 97, 118, 101, 58, 34, 125, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 32, 108, 111, 116, 32, 111,
  102, 32, 121, 101, 108, 108, 111, 119, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 111, 109, 101, 32, 121, 101, 108, 108, 111,
  119, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76,
  105, 116, 116, 108, 101, 32, 121, 101, 108, 108, 111, 119, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 123, 34, 60, 98, 62, 65, 100, 106, 117, 115, 116,
  32, 99, 121, 97, 110, 115, 60, 47, 98, 62, 32, 102, 111, 114, 32, 112,
  105, 120, 101, 108, 115, 32, 116, 104, 97, 116, 32, 104, 97, 118, 101, 58,
  34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 32, 108, 111,
  116, 32, 111, 102, 32, 107, 101, 121, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 111, 109, 101, 32, 107, 101, 121, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 116, 116,
  108, 101, 32, 107, 101, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 98, 62, 65,
  100, 106, 117, 115, 116, 32, 77, 97, 103, 101, 110, 116, 97, 115, 60, 47,
  98, 62, 32, 102, 111, 114, 32, 112, 105, 120, 101, 108, 115, 32, 116, 104,
  97, 116, 32, 104, 97, 118, 101, 58, 34, 125, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 32, 108, 111, 116, 32, 111, 102, 32, 99, 121, 97,
  110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  111, 109, 101, 32, 99, 121, 97, 110, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 76, 105, 116, 116, 108, 101, 32, 99, 121, 97,
  110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 98, 62, 65,
  100, 106, 117, 115, 116, 32, 77, 97, 103, 101, 110, 116, 97, 115, 60, 47,
  98, 62, 32, 102, 111, 114, 32, 112, 105, 120, 101, 108, 115, 32, 116, 104,
  97, 116, 32, 104, 97, 118, 101, 58, 34, 125, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 32, 108, 111, 116, 32, 111, 102, 32, 109, 97, 103,
  101, 110, 116, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45,
  50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 111, 109, 101, 32, 109, 97, 103, 101, 110, 116, 97, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 116, 116,
  108, 101, 32, 109, 97, 103, 101, 110, 116, 97, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 123, 34, 60, 98, 62, 65, 100, 106, 117, 115, 116, 32, 77,
  97, 103, 101, 110, 116, 97, 115, 60, 47, 98, 62, 32, 102, 111, 114, 32,
  112, 105, 120, 101, 108, 115, 32, 116, 104, 97, 116, 32, 104, 97, 118, 101,
  58, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 32, 108,
  111, 116, 32, 111, 102, 32, 121, 101, 108, 108, 111, 119, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 111, 109, 101, 32, 121,
  101, 108, 108, 111, 119, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 76, 105, 116, 116, 108, 101, 32, 121, 101, 108, 108, 111, 119,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 98, 62, 65, 100,
  106, 117, 115, 116, 32, 77, 97, 103, 101, 110, 116, 97, 115, 60, 47, 98,
  62, 32, 102, 111, 114, 32, 112, 105, 120, 101, 108, 115, 32, 116, 104, 97,
  116, 32, 104, 97, 118, 101, 58, 34, 125, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 32, 108, 111, 116, 32, 111, 102, 32, 107, 101, 121, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 111, 109,
  101, 32, 107, 101, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 76, 105, 116, 116, 108, 101, 32, 107, 101, 121, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 123, 34, 60, 98, 62, 65, 100, 106, 117, 115, 116, 32, 89, 101, 108,
  108, 111, 119, 115, 60, 47, 98, 62, 32, 102, 111, 114, 32, 112, 105, 120,
  101, 108, 115, 32, 116, 104, 97, 116, 32, 104, 97, 118, 101, 58, 34, 125,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 32, 108, 111, 116, 32,
  111, 102, 32, 99, 121, 97, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 111, 109, 101, 32, 99, 121, 97, 110, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 116, 116,
  108, 101, 32, 99, 121, 97, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  123, 34, 60, 98, 62, 65, 100, 106, 117, 115, 116, 32, 89, 101, 108, 108,
  111, 119, 115, 60, 47, 98, 62, 32, 102, 111, 114, 32, 112, 105, 120, 101,
  108, 115, 32, 116, 104, 97, 116, 32, 104, 97, 118, 101, 58, 34, 125, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 32, 108, 111, 116, 32, 111,
  102, 32, 109, 97, 103, 101, 110, 116, 97, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 111, 109, 101, 32, 109, 97, 103, 101,
  110, 116, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50,
  53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 76, 105, 116, 116, 108, 101, 32, 109, 97, 103, 101, 110, 116, 97, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 98, 62, 65, 100, 106,
  117, 115, 116, 32, 89, 101, 108, 108, 111, 119, 115, 60, 47, 98, 62, 32,
  102, 111, 114, 32, 112, 105, 120, 101, 108, 115, 32, 116, 104, 97, 116, 32,
  104, 97, 118, 101, 58, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 65, 32, 108, 111, 116, 32, 111, 102, 32, 121, 101, 108, 108, 111, 119,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 111,
  109, 101, 32, 121, 101, 108, 108, 111, 119, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 76, 105, 116, 116, 108, 101, 32, 121, 101,
  108, 108, 111, 119, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45,
  50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60,
  98, 62, 65, 100, 106, 117, 115, 116, 32, 89, 101, 108, 108, 111, 119, 115,
  60, 47, 98, 62, 32, 102, 111, 114, 32, 112, 105, 120, 101, 108, 115, 32,
  116, 104, 97, 116, 32, 104, 97, 118, 101, 58, 34, 125, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 65, 32, 108, 111, 116, 32, 111, 102, 32, 107,
  101, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53,
  53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 111, 109, 101, 32, 107, 101, 121, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 76, 105, 116, 116, 108, 101, 32, 107, 101, 121,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 123, 34, 60, 98, 62, 65, 100, 106, 117, 115, 116, 32,
  75, 101, 121, 60, 47, 98, 62, 32, 102, 111, 114, 32, 112, 105, 120, 101,
  108, 115, 32, 116, 104, 97, 116, 32, 104, 97, 118, 101, 58, 34, 125, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 32, 108, 111, 116, 32, 111,
  102, 32, 99, 121, 97, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 111, 109, 101, 32, 99, 121, 97, 110, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 116, 116, 108,
  101, 32, 99, 121, 97, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123,
  34, 60, 98, 62, 65, 100, 106, 117, 115, 116, 32, 75, 101, 121, 60, 47,
  98, 62, 32, 102, 111, 114, 32, 112, 105, 120, 101, 108, 115, 32, 116, 104,
  97, 116, 32, 104, 97, 118, 101, 58, 34, 125, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 32, 108, 111, 116, 32, 111, 102, 32, 109, 97, 103,
  101, 110, 116, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45,
  50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 111, 109, 101, 32, 109, 97, 103, 101, 110, 116, 97, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 116, 116,
  108, 101, 32, 109, 97, 103, 101, 110, 116, 97, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 123, 34, 60, 98, 62, 65, 100, 106, 117, 115, 116, 32, 75,
  101, 121, 60, 47, 98, 62, 32, 102, 111, 114, 32, 112, 105, 120, 101, 108,
  115, 32, 116, 104, 97, 116, 32, 104, 97, 118, 101, 58, 34, 125, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 32, 108, 111, 116, 32, 111, 102,
  32, 121, 101, 108, 108, 111, 119, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 111, 109, 101, 32, 121, 101, 108, 108, 111, 119,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105,
  116, 116, 108, 101, 32, 121, 101, 108, 108, 111, 119, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 123, 34, 60, 98, 62, 65, 100, 106, 117, 115, 116, 32,
  75, 101, 121, 60, 47, 98, 62, 32, 102, 111, 114, 32, 112, 105, 120, 101,
  108, 115, 32, 116, 104, 97, 116, 32, 104, 97, 118, 101, 58, 34, 125, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 32, 108, 111, 116, 32, 111,
  102, 32, 107, 101, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 111, 109, 101, 32, 107, 101, 121, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 116, 116, 108, 101, 32,
  107, 101, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50,
  53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 123, 34, 83, 116, 114, 101, 110, 103, 116,
  104, 32, 111, 102, 32, 101, 102, 102, 101, 99, 116, 32, 102, 111, 114, 32,
  83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 32, 108, 101, 118, 101, 108,
  58, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 110,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 53, 53, 44, 48, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105,
  116, 116, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 53, 53,
  44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 111, 109, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 53,
  53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 77, 117, 99, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50,
  53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 77, 111, 115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79,
  117, 116, 112, 117, 116, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48,
  44, 34, 80, 101, 114, 115, 101, 114, 118, 101, 32, 76, 117, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 67, 108, 105, 112, 32, 67, 77, 89, 75,
  34, 44, 34, 67, 108, 105, 112, 32, 82, 71, 66, 34, 44, 34, 83, 99,
  97, 108, 101, 32, 67, 77, 89, 75, 34, 44, 34, 83, 99, 97, 108, 101,
  32, 82, 71, 66, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65,
  117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 73, 97, 105, 110, 32,
  70, 101, 114, 103, 117, 115, 115, 111, 110, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 105, 97, 105, 110, 95, 99, 109,
  121, 107, 95, 116, 111, 110, 101, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105,
  116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91, 48, 93, 10,
  45, 114, 103, 98, 50, 99, 109, 121, 107, 10, 45, 45, 115, 112, 108, 105,
  116, 32, 99, 10, 45, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118,
  101, 91, 49, 93, 32, 48, 44, 48, 44, 36, 49, 44, 49, 50, 56, 44,
  36, 50, 44, 50, 53, 53, 44, 36, 51, 10, 45, 45, 97, 112, 112, 108,
  121, 95, 99, 117, 114, 118, 101, 91, 50, 93, 32, 48, 44, 48, 44, 36,
  52, 44, 49, 50, 56, 44, 36, 53, 44, 50, 53, 53, 44, 36, 54, 10,
  45, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 51, 93,
  32, 48, 44, 48, 44, 36, 55, 44, 49, 50, 56, 44, 36, 56, 44, 50,
  53, 53, 44, 36, 57, 10, 45, 45, 97, 112, 112, 108, 121, 95, 99, 117,
  114, 118, 101, 91, 52, 93, 32, 48, 44, 48, 44, 36, 49, 48, 44, 49,
  50, 56, 44, 36, 49, 49, 44, 50, 53, 53, 44, 36, 49, 50, 10, 45,
  97, 100, 100, 91, 45, 49, 44, 45, 50, 44, 45, 51, 44, 45, 52, 93,
  10, 45, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 49,
  93, 32, 48, 44, 48, 44, 36, 49, 51, 44, 49, 50, 56, 44, 36, 49,
  52, 44, 50, 53, 53, 44, 36, 49, 53, 10, 45, 45, 97, 112, 112, 108,
  121, 95, 99, 117, 114, 118, 101, 91, 50, 93, 32, 48, 44, 48, 44, 36,
  49, 54, 44, 49, 50, 56, 44, 36, 49, 55, 44, 50, 53, 53, 44, 36,
  49, 56, 10, 45, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101,
  91, 51, 93, 32, 48, 44, 48, 44, 36, 49, 57, 44, 49, 50, 56, 44,
  36, 50, 48, 44, 50, 53, 53, 44, 36, 50, 49, 10, 45, 45, 97, 112,
  112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 52, 93, 32, 48, 44, 48,
  44, 36, 50, 50, 44, 49, 50, 56, 44, 36, 50, 51, 44, 50, 53, 53,
  44, 36, 50, 52, 10, 45, 97, 100, 100, 91, 45, 49, 44, 45, 50, 44,
  45, 51, 44, 45, 52, 93, 10, 45, 45, 97, 112, 112, 108, 121, 95, 99,
  117, 114, 118, 101, 91, 49, 93, 32, 48, 44, 48, 44, 36, 50, 53, 44,
  49, 50, 56, 44, 36, 50, 54, 44, 50, 53, 53, 44, 36, 50, 55, 10,
  45, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 50, 93,
  32, 48, 44, 48, 44, 36, 50, 56, 44, 49, 50, 56, 44, 36, 50, 57,
  44, 50, 53, 53, 44, 36, 51, 48, 10, 45, 45, 97, 112, 112, 108, 121,
  95, 99, 117, 114, 118, 101, 91, 51, 93, 32, 48, 44, 48, 44, 36, 51,
  49, 44, 49, 50, 56, 44, 36, 51, 50, 44, 50, 53, 53, 44, 36, 51,
  51, 10, 45, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 91,
  52, 93, 32, 48, 44, 48, 44, 36, 51, 52, 44, 49, 50, 56, 44, 36,
  51, 53, 44, 50, 53, 53, 44, 36, 51, 54, 10, 45, 97, 100, 100, 91,
  45, 49, 44, 45, 50, 44, 45, 51, 44, 45, 52, 93, 10, 45, 45, 97,
  112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 49, 93, 32, 48, 44,
  48, 44, 36, 51, 55, 44, 49, 50, 56, 44, 36, 51, 56, 44, 50, 53,
  53, 44, 36, 51, 57, 10, 45, 45, 97, 112, 112, 108, 121, 95, 99, 117,
  114, 118, 101, 91, 50, 93, 32, 48, 44, 48, 44, 36, 52, 48, 44, 49,
  50, 56, 44, 36, 52, 49, 44, 50, 53, 53, 44, 36, 52, 50, 10, 45,
  45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 51, 93, 32,
  48, 44, 48, 44, 36, 52, 51, 44, 49, 50, 56, 44, 36, 52, 52, 44,
  50, 53, 53, 44, 36, 52, 53, 10, 45, 45, 97, 112, 112, 108, 121, 95,
  99, 117, 114, 118, 101, 91, 52, 93, 32, 48, 44, 48, 44, 36, 52, 54,
  44, 49, 50, 56, 44, 36, 52, 55, 44, 50, 53, 53, 44, 36, 52, 56,
  10, 45, 97, 100, 100, 91, 45, 49, 44, 45, 50, 44, 45, 51, 44, 45,
  52, 93, 10, 45, 97, 100, 100, 91, 49, 44, 53, 93, 10, 45, 97, 100,
  100, 91, 50, 44, 53, 93, 10, 45, 97, 100, 100, 91, 51, 44, 53, 93,
  10, 45, 97, 100, 100, 91, 52, 44, 53, 93, 10, 45, 97, 91, 45, 49,
  44, 45, 50, 44, 45, 51, 44, 45, 52, 93, 32, 99, 10, 45, 45, 115,
  117, 98, 91, 48, 44, 49, 93, 10, 45, 45, 99, 109, 121, 107, 50, 114,
  103, 98, 91, 48, 93, 32, 45, 114, 103, 98, 50, 104, 115, 118, 91, 45,
  49, 93, 32, 45, 115, 112, 108, 105, 116, 91, 45, 49, 93, 32, 99, 32,
  45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 44, 45, 51, 93, 32, 45,
  109, 117, 108, 91, 45, 49, 93, 32, 50, 53, 53, 10, 45, 97, 112, 112,
  108, 121, 95, 99, 117, 114, 118, 101, 91, 45, 49, 93, 32, 48, 44, 48,
  44, 36, 52, 57, 44, 54, 52, 44, 36, 53, 48, 44, 49, 50, 56, 44,
  36, 53, 49, 44, 49, 57, 50, 44, 36, 53, 50, 44, 50, 53, 53, 44,
  36, 53, 51, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108,
  116, 105, 112, 108, 121, 91, 45, 49, 44, 45, 50, 93, 10, 45, 45, 115,
  117, 98, 91, 48, 44, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 53,
  52, 61, 61, 48, 125, 10, 45, 99, 109, 121, 107, 50, 114, 103, 98, 10,
  45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 48, 93, 10, 45, 45,
  108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 45, 49, 93, 10, 45, 99,
  111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 101, 120, 116, 114,
  97, 99, 116, 91, 45, 49, 44, 45, 50, 93, 10, 45, 99, 111, 109, 112,
  111, 115, 101, 95, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 91, 48,
  44, 45, 49, 93, 10, 45, 107, 101, 101, 112, 91, 48, 93, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 53, 52, 61, 61, 49,
  125, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 45, 99, 32, 48,
  44, 50, 53, 53, 10, 45, 99, 109, 121, 107, 50, 114, 103, 98, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 53, 52, 61, 61,
  50, 125, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 45, 99, 109,
  121, 107, 50, 114, 103, 98, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 53, 52, 61,
  61, 51, 125, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 45, 110,
  32, 48, 44, 50, 53, 53, 10, 45, 99, 109, 121, 107, 50, 114, 103, 98,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 53, 52,
  61, 61, 52, 125, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 45,
  99, 109, 121, 107, 50, 114, 103, 98, 10, 45, 110, 32, 48, 44, 50, 53,
  53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45,
  97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  35, 64, 103, 105, 109, 112, 32, 67, 111, 108, 111, 114, 109, 97, 112, 32,
  58, 32, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 109, 97, 112, 44,
  103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 109, 97, 112, 95, 112, 114,
  101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  111, 108, 111, 114, 109, 97, 112, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  91, 49, 44, 34, 65, 100, 97, 112, 116, 105, 118, 101, 34, 44, 34, 67,
  117, 115, 116, 111, 109, 34, 44, 34, 83, 116, 97, 110, 100, 97, 114, 100,
  32, 40, 50, 53, 54, 41, 34, 44, 34, 72, 83, 86, 32, 40, 50, 53,
  54, 41, 34, 44, 34, 76, 105, 110, 101, 115, 32, 40, 50, 53, 54, 41,
  34, 44, 34, 72, 111, 116, 32, 40, 50, 53, 54, 41, 34, 44, 34, 67,
  111, 111, 108, 32, 40, 50, 53, 54, 41, 34, 44, 34, 74, 101, 116, 32,
  40, 50, 53, 54, 41, 34, 44, 34, 70, 108, 97, 103, 32, 40, 50, 53,
  54, 41, 34, 44, 34, 67, 117, 98, 101, 32, 40, 50, 53, 54, 41, 34,
  93, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 105, 116, 104, 101,
  114, 105, 110, 103, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 60, 105, 62, 70, 111, 114, 32, 97, 100, 97, 112, 116,
  105, 118, 101, 32, 97, 110, 100, 32, 99, 117, 115, 116, 111, 109, 32, 99,
  111, 108, 111, 114, 109, 97, 112, 115, 32, 111, 110, 108, 121, 32, 58, 60,
  47, 105, 62, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 117, 109, 98, 101, 114, 32, 111, 102,
  32, 116, 111, 110, 101, 115, 32, 61, 32, 105, 110, 116, 40, 51, 50, 44,
  50, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 60, 105, 62, 70, 111, 114, 32, 99, 117,
  115, 116, 111, 109, 32, 99, 111, 108, 111, 114, 109, 97, 112, 115, 32, 111,
  110, 108, 121, 32, 58, 60, 47, 105, 62, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 117, 109,
  98, 101, 114, 32, 111, 102, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32,
  105, 110, 116, 40, 56, 44, 50, 44, 56, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 49, 115, 116, 32, 99, 111, 108, 111, 114, 32, 61, 32,
  99, 111, 108, 111, 114, 40, 48, 44, 48, 44, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 50, 110, 100, 32, 99, 111, 108, 111, 114, 32,
  61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 51, 114,
  100, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40,
  50, 53, 53, 44, 48, 44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 52, 116, 104, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111,
  108, 111, 114, 40, 48, 44, 50, 53, 53, 44, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 53, 116, 104, 32, 99, 111, 108, 111, 114, 32,
  61, 32, 99, 111, 108, 111, 114, 40, 48, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 54, 116, 104, 32, 99, 111,
  108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44,
  50, 53, 53, 44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  55, 116, 104, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111,
  114, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 56, 116, 104, 32, 99, 111, 108, 111, 114, 32,
  61, 32, 99, 111, 108, 111, 114, 40, 48, 44, 50, 53, 53, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80,
  114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68,
  117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104,
  117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 49, 50,
  47, 50, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 109, 97, 112,
  32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99,
  105, 116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 10, 45,
  105, 102, 32, 123, 36, 49, 62, 61, 50, 125, 10, 45, 105, 110, 100, 101,
  120, 91, 48, 93, 32, 123, 36, 49, 45, 50, 125, 44, 36, 50, 44, 49,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 10, 40,
  36, 123, 53, 45, 50, 56, 125, 41, 32, 45, 122, 91, 45, 49, 93, 32,
  48, 44, 123, 51, 42, 36, 52, 45, 49, 125, 10, 45, 114, 91, 45, 49,
  93, 32, 51, 44, 123, 119, 47, 51, 125, 44, 49, 44, 49, 44, 45, 49,
  32, 45, 112, 101, 114, 109, 117, 116, 101, 91, 45, 49, 93, 32, 121, 122,
  99, 120, 32, 45, 114, 91, 45, 49, 93, 32, 36, 51, 44, 49, 44, 49,
  44, 51, 44, 51, 10, 45, 105, 110, 100, 101, 120, 91, 48, 93, 32, 91,
  45, 49, 93, 44, 36, 50, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 101, 108, 115, 101, 10, 45, 97, 117, 116, 111, 105, 110, 100, 101,
  120, 91, 48, 93, 32, 36, 51, 44, 36, 50, 44, 123, 105, 102, 40, 36,
  51, 60, 61, 51, 50, 44, 49, 44, 48, 41, 125, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 109, 97,
  112, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 109, 97, 112, 32,
  36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 67,
  111, 108, 111, 114, 32, 98, 97, 108, 97, 110, 99, 101, 32, 58, 32, 103,
  105, 109, 112, 95, 98, 97, 108, 97, 110, 99, 101, 95, 103, 97, 109, 109,
  97, 44, 32, 103, 105, 109, 112, 95, 98, 97, 108, 97, 110, 99, 101, 95,
  103, 97, 109, 109, 97, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 101, 117, 116, 114, 97, 108, 32, 99,
  111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 49, 50, 56,
  44, 49, 50, 56, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 116, 114, 101, 116, 99, 104, 32, 99, 111, 108, 111, 114,
  115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32,
  116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70,
  117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116,
  101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68,
  117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68,
  97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38,
  35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 49, 47, 48, 55, 47, 48, 49, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112,
  95, 98, 97, 108, 97, 110, 99, 101, 95, 103, 97, 109, 109, 97, 32, 58,
  10, 45, 98, 97, 108, 97, 110, 99, 101, 95, 103, 97, 109, 109, 97, 32,
  36, 123, 49, 45, 51, 125, 10, 45, 105, 102, 32, 36, 52, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32,
  45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45,
  108, 91, 48, 93, 32, 45, 115, 32, 99, 32, 45, 110, 32, 48, 44, 50,
  53, 53, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 97,
  32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 98, 97, 108, 97, 110,
  99, 101, 95, 103, 97, 109, 109, 97, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 98, 97,
  108, 97, 110, 99, 101, 95, 103, 97, 109, 109, 97, 32, 36, 42, 34, 44,
  36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 67, 111, 108, 111, 114,
  32, 103, 114, 97, 100, 105, 110, 103, 32, 58, 32, 106, 108, 95, 99, 111,
  108, 111, 114, 103, 114, 97, 100, 105, 110, 103, 44, 32, 106, 108, 95, 99,
  111, 108, 111, 114, 103, 114, 97, 100, 105, 110, 103, 95, 112, 114, 101, 118,
  105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 65, 32, 102, 105, 108, 116,
  101, 114, 32, 102, 111, 114, 32, 98, 97, 115, 105, 99, 32, 112, 104, 111,
  116, 111, 32, 101, 100, 105, 116, 105, 110, 103, 32, 97, 110, 100, 32, 99,
  111, 108, 111, 114, 32, 103, 114, 97, 100, 105, 110, 103, 46, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62,
  78, 111, 116, 101, 58, 60, 47, 98, 62, 32, 83, 45, 99, 117, 114, 118,
  101, 32, 99, 111, 110, 116, 114, 111, 108, 115, 32, 115, 104, 97, 100, 111,
  119, 115, 32, 97, 110, 100, 32, 104, 105, 103, 104, 108, 105, 103, 104, 116,
  115, 32, 105, 110, 32, 111, 110, 101, 32, 115, 108, 105, 100, 101, 114, 46,
  32, 65, 118, 111, 105, 100, 32, 117, 115, 105, 110, 103, 32, 76, 111, 99,
  97, 108, 32, 67, 111, 110, 116, 114, 97, 115, 116, 32, 97, 110, 100, 32,
  84, 111, 110, 101, 32, 77, 97, 112, 112, 105, 110, 103, 32, 116, 111, 103,
  101, 116, 104, 101, 114, 32, 98, 101, 99, 97, 117, 115, 101, 32, 111, 102,
  32, 100, 111, 105, 110, 103, 32, 115, 105, 109, 105, 108, 97, 114, 32, 116,
  104, 105, 110, 103, 115, 32, 115, 111, 32, 98, 111, 116, 104, 32, 111, 118,
  101, 114, 32, 112, 114, 111, 99, 101, 115, 115, 32, 105, 109, 97, 103, 101,
  115, 46, 32, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 32, 99, 104,
  97, 110, 110, 101, 108, 32, 103, 97, 109, 109, 97, 32, 99, 104, 97, 110,
  103, 101, 115, 32, 99, 111, 108, 111, 114, 32, 115, 97, 116, 117, 114, 97,
  116, 105, 111, 110, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 108, 121,
  32, 116, 104, 97, 110, 32, 115, 116, 97, 110, 100, 97, 114, 100, 32, 83,
  97, 116, 117, 114, 97, 116, 105, 111, 110, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 111, 108, 32, 47, 32,
  119, 97, 114, 109, 32, 61, 32, 105, 110, 116, 40, 48, 44, 45, 53, 48,
  44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 97,
  116, 117, 114, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 32, 99, 104, 97, 110,
  110, 101, 108, 32, 103, 97, 109, 109, 97, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 44, 48, 46, 49, 44, 51, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  45, 99, 117, 114, 118, 101, 32, 99, 111, 110, 116, 114, 97, 115, 116, 32,
  61, 32, 105, 110, 116, 40, 48, 44, 45, 51, 48, 44, 51, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 100, 111, 119, 115,
  32, 61, 32, 105, 110, 116, 40, 48, 44, 45, 53, 48, 44, 53, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 105, 103, 104, 108, 105,
  103, 104, 116, 115, 32, 61, 32, 105, 110, 116, 40, 48, 44, 45, 53, 48,
  44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108,
  97, 99, 107, 115, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 53,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 114, 105, 103,
  104, 116, 110, 101, 115, 115, 32, 61, 32, 105, 110, 116, 40, 48, 44, 45,
  53, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32, 105, 110, 116, 40, 48,
  44, 45, 53, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 71, 97, 109, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 44, 48, 46, 49, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 111, 99,
  97, 108, 32, 99, 111, 110, 116, 114, 97, 115, 116, 32, 101, 110, 104, 97,
  110, 99, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 111, 110, 101,
  32, 109, 97, 112, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 84, 111, 110, 101, 32, 109, 97, 112,
  32, 115, 116, 114, 101, 110, 103, 116, 104, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 55, 53, 44, 48, 46, 53, 53, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 111, 108, 111, 114, 32, 103, 114, 97, 100, 105, 110, 103,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 72, 105, 103, 104, 108, 105, 103, 104, 116, 115, 32, 99,
  111, 108, 111, 114, 32, 105, 110, 116, 101, 110, 115, 105, 116, 121, 32, 61,
  32, 105, 110, 116, 40, 55, 48, 44, 48, 44, 49, 51, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 72, 105, 103, 104, 108, 105, 103, 104,
  116, 115, 32, 104, 117, 101, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48,
  44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72,
  105, 103, 104, 108, 105, 103, 104, 116, 115, 32, 98, 114, 105, 103, 104, 116,
  110, 101, 115, 115, 32, 61, 32, 105, 110, 116, 40, 48, 44, 45, 49, 48,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 105, 100, 116, 111,
  110, 101, 115, 32, 99, 111, 108, 111, 114, 32, 105, 110, 116, 101, 110, 115,
  105, 116, 121, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 49, 51,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 105, 100, 116,
  111, 110, 101, 115, 32, 104, 117, 101, 32, 61, 32, 105, 110, 116, 40, 48,
  44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 77, 105, 100, 116, 111, 110, 101, 115, 32, 98, 114, 105, 103, 104, 116,
  110, 101, 115, 115, 32, 61, 32, 105, 110, 116, 40, 48, 44, 45, 49, 48,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 100, 111,
  119, 115, 32, 99, 111, 108, 111, 114, 32, 105, 110, 116, 101, 110, 115, 105,
  116, 121, 32, 61, 32, 105, 110, 116, 40, 55, 48, 44, 48, 44, 49, 51,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 100,
  111, 119, 115, 32, 104, 117, 101, 32, 61, 32, 105, 110, 116, 40, 49, 56,
  48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 104, 97, 100, 111, 119, 115, 32, 98, 114, 105, 103, 104, 116,
  110, 101, 115, 115, 32, 61, 32, 105, 110, 116, 40, 48, 44, 45, 49, 48,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117,
  116, 32, 115, 97, 116, 117, 114, 97, 116, 105, 111, 110, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32,
  116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70,
  117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116,
  101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68,
  117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 74,
  111, 104, 110, 32, 76, 97, 107, 107, 97, 115, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 50, 47, 49,
  50, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 106, 108, 95, 99, 111, 108, 111, 114, 103, 114, 97, 100, 105, 110, 103,
  32, 58, 10, 95, 121, 115, 116, 114, 61, 34, 34, 10, 45, 105, 102, 32,
  123, 36, 49, 62, 48, 125, 10, 95, 109, 121, 109, 105, 110, 61, 123, 36,
  49, 125, 10, 95, 109, 121, 109, 97, 120, 61, 123, 50, 53, 53, 45, 36,
  49, 125, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101,
  108, 115, 32, 34, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101,
  32, 48, 44, 48, 44, 36, 95, 109, 121, 109, 105, 110, 44, 50, 53, 53,
  44, 50, 53, 53, 34, 44, 54, 44, 48, 10, 45, 97, 112, 112, 108, 121,
  95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 97, 112, 112, 108,
  121, 95, 99, 117, 114, 118, 101, 32, 48, 44, 48, 44, 48, 44, 50, 53,
  53, 44, 36, 95, 109, 121, 109, 97, 120, 34, 44, 53, 44, 48, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 60, 48, 125,
  10, 95, 109, 121, 109, 105, 110, 61, 123, 45, 36, 49, 125, 10, 95, 109,
  121, 109, 97, 120, 61, 123, 50, 53, 53, 43, 36, 49, 125, 10, 45, 97,
  112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45,
  97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 32, 48, 44, 48, 44,
  36, 95, 109, 121, 109, 105, 110, 44, 50, 53, 53, 44, 50, 53, 53, 34,
  44, 53, 44, 48, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 32, 34, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114,
  118, 101, 32, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 36, 95, 109,
  121, 109, 97, 120, 34, 44, 54, 44, 48, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 50, 33, 61, 49, 46, 48, 125, 10, 45,
  103, 105, 109, 112, 95, 101, 113, 117, 97, 108, 105, 122, 101, 95, 115, 32,
  36, 50, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 51, 33, 61, 49, 46, 48, 125, 10, 45, 97, 112, 112, 108, 121,
  95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 97, 112, 112, 108,
  121, 95, 103, 97, 109, 109, 97, 32, 36, 51, 34, 44, 49, 50, 44, 48,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 52, 33,
  61, 48, 125, 10, 95, 112, 49, 61, 123, 54, 52, 45, 36, 52, 125, 10,
  95, 112, 50, 61, 123, 49, 57, 50, 43, 36, 52, 125, 10, 95, 121, 115,
  116, 114, 61, 36, 95, 121, 115, 116, 114, 34, 32, 45, 97, 112, 112, 108,
  121, 95, 99, 117, 114, 118, 101, 32, 49, 44, 48, 44, 48, 44, 54, 52,
  44, 36, 95, 112, 49, 44, 49, 57, 50, 44, 36, 95, 112, 50, 44, 50,
  53, 53, 44, 50, 53, 53, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 53, 33, 61, 48, 125, 10, 95, 112, 51, 61, 123,
  54, 52, 45, 36, 53, 125, 10, 95, 121, 115, 116, 114, 61, 36, 95, 121,
  115, 116, 114, 34, 32, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118,
  101, 32, 49, 44, 48, 44, 48, 44, 54, 52, 44, 36, 95, 112, 51, 44,
  49, 50, 56, 44, 49, 50, 56, 44, 49, 57, 50, 44, 49, 57, 50, 44,
  50, 53, 53, 44, 50, 53, 53, 34, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 54, 33, 61, 48, 125, 10, 95, 112, 52, 61,
  123, 49, 57, 50, 43, 36, 54, 125, 10, 95, 121, 115, 116, 114, 61, 36,
  95, 121, 115, 116, 114, 34, 32, 45, 97, 112, 112, 108, 121, 95, 99, 117,
  114, 118, 101, 32, 49, 44, 48, 44, 48, 44, 54, 52, 44, 54, 52, 44,
  49, 50, 56, 44, 49, 50, 56, 44, 49, 57, 50, 44, 36, 95, 112, 52,
  44, 50, 53, 53, 44, 50, 53, 53, 34, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 55, 62, 48, 125, 10, 95, 121, 115, 116,
  114, 61, 36, 95, 121, 115, 116, 114, 34, 32, 45, 97, 112, 112, 108, 121,
  95, 99, 117, 114, 118, 101, 32, 49, 44, 36, 55, 44, 48, 44, 54, 52,
  44, 54, 52, 44, 50, 53, 53, 44, 50, 53, 53, 34, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 56, 62, 48, 125, 10, 95,
  112, 53, 61, 48, 10, 95, 121, 115, 116, 114, 61, 36, 95, 121, 115, 116,
  114, 34, 32, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 32,
  48, 44, 48, 44, 36, 56, 44, 50, 53, 53, 44, 50, 53, 53, 34, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 56, 60, 48,
  125, 10, 95, 112, 53, 61, 123, 50, 53, 53, 43, 36, 56, 125, 10, 95,
  121, 115, 116, 114, 61, 36, 95, 121, 115, 116, 114, 34, 32, 45, 97, 112,
  112, 108, 121, 95, 99, 117, 114, 118, 101, 32, 48, 44, 48, 44, 48, 44,
  50, 53, 53, 44, 36, 95, 112, 53, 34, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 57, 62, 48, 125, 10, 95, 112, 54, 61,
  36, 57, 10, 95, 112, 55, 61, 123, 50, 53, 53, 45, 36, 57, 125, 10,
  95, 121, 115, 116, 114, 61, 36, 95, 121, 115, 116, 114, 34, 32, 45, 97,
  112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 32, 48, 44, 48, 44, 48,
  44, 36, 95, 112, 54, 44, 48, 44, 36, 95, 112, 55, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 34, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 57, 60, 48, 125, 10, 95, 112, 54, 61,
  123, 45, 36, 57, 125, 10, 95, 112, 55, 61, 123, 50, 53, 53, 43, 36,
  57, 125, 10, 95, 121, 115, 116, 114, 61, 36, 95, 121, 115, 116, 114, 34,
  32, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 32, 48, 44,
  48, 44, 36, 95, 112, 54, 44, 50, 53, 53, 44, 36, 95, 112, 55, 34,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 48,
  33, 61, 49, 46, 48, 125, 10, 95, 121, 115, 116, 114, 61, 36, 95, 121,
  115, 116, 114, 34, 32, 45, 97, 112, 112, 108, 121, 95, 103, 97, 109, 109,
  97, 32, 36, 49, 48, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 49, 49, 62, 48, 125, 10, 95, 121, 115, 116, 114, 61,
  36, 95, 121, 115, 116, 114, 34, 32, 45, 117, 110, 115, 104, 97, 114, 112,
  32, 50, 48, 44, 36, 49, 49, 44, 48, 34, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 49, 50, 125, 10, 95, 121, 115, 116,
  114, 61, 36, 95, 121, 115, 116, 114, 34, 32, 45, 109, 97, 112, 95, 116,
  111, 110, 101, 115, 32, 48, 46, 53, 44, 36, 49, 51, 44, 48, 46, 49,
  44, 51, 48, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 95, 121, 115, 116, 114, 39, 33, 61, 39, 34, 34, 125, 10, 45,
  97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 36,
  95, 121, 115, 116, 114, 44, 49, 51, 44, 48, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 49, 52, 125, 10, 45, 105, 102, 32,
  123, 36, 49, 54, 43, 36, 50, 50, 62, 51, 54, 48, 125, 10, 95, 115,
  104, 104, 61, 123, 40, 36, 49, 54, 43, 36, 50, 50, 45, 51, 54, 48,
  41, 47, 51, 54, 48, 125, 10, 45, 101, 108, 115, 101, 10, 95, 115, 104,
  104, 61, 123, 40, 36, 49, 54, 43, 36, 50, 50, 41, 47, 51, 54, 48,
  125, 10, 45, 101, 110, 100, 105, 102, 10, 95, 115, 104, 115, 61, 123, 36,
  50, 49, 47, 49, 48, 48, 125, 10, 95, 115, 104, 108, 101, 118, 61, 123,
  36, 50, 51, 125, 10, 95, 109, 105, 100, 104, 61, 123, 36, 49, 57, 47,
  51, 54, 48, 125, 10, 95, 109, 105, 100, 115, 61, 123, 36, 49, 56, 47,
  49, 48, 48, 125, 10, 95, 109, 105, 100, 108, 101, 118, 61, 123, 36, 50,
  48, 125, 10, 95, 104, 105, 103, 104, 104, 61, 123, 36, 49, 54, 47, 51,
  54, 48, 125, 10, 95, 104, 105, 103, 104, 115, 61, 123, 36, 49, 53, 47,
  49, 48, 48, 125, 10, 95, 104, 105, 103, 104, 108, 101, 118, 61, 123, 36,
  49, 55, 125, 10, 95, 115, 97, 116, 108, 101, 118, 61, 123, 36, 50, 52,
  125, 10, 45, 99, 111, 108, 111, 114, 95, 103, 114, 97, 100, 101, 32, 36,
  95, 115, 104, 104, 44, 36, 95, 115, 104, 115, 44, 36, 95, 115, 104, 108,
  101, 118, 44, 36, 95, 109, 105, 100, 104, 44, 36, 95, 109, 105, 100, 115,
  44, 36, 95, 109, 105, 100, 108, 101, 118, 44, 36, 95, 104, 105, 103, 104,
  104, 44, 36, 95, 104, 105, 103, 104, 115, 44, 36, 95, 104, 105, 103, 104,
  108, 101, 118, 44, 36, 95, 115, 97, 116, 108, 101, 118, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 50, 52, 33, 61, 49, 46,
  48, 125, 10, 45, 103, 105, 109, 112, 95, 101, 113, 117, 97, 108, 105, 122,
  101, 95, 115, 32, 36, 50, 52, 44, 48, 10, 45, 101, 110, 100, 105, 102,
  10, 99, 111, 108, 111, 114, 95, 103, 114, 97, 100, 101, 32, 58, 10, 95,
  115, 104, 97, 100, 111, 119, 110, 114, 103, 98, 61, 64, 123, 45, 106, 108,
  95, 104, 115, 118, 95, 116, 111, 95, 114, 103, 98, 34, 32, 34, 36, 49,
  44, 49, 46, 48, 44, 123, 36, 50, 42, 48, 46, 52, 48, 125, 125, 10,
  95, 109, 105, 100, 116, 111, 110, 101, 115, 114, 103, 98, 61, 64, 123, 45,
  106, 108, 95, 104, 115, 118, 95, 116, 111, 95, 114, 103, 98, 34, 32, 34,
  36, 52, 44, 49, 46, 48, 44, 123, 36, 53, 42, 48, 46, 52, 48, 125,
  125, 10, 95, 104, 105, 103, 104, 108, 105, 103, 104, 116, 115, 114, 103, 98,
  61, 64, 123, 45, 106, 108, 95, 104, 115, 118, 95, 116, 111, 95, 114, 103,
  98, 34, 32, 34, 36, 55, 44, 49, 46, 48, 44, 123, 36, 56, 42, 48,
  46, 52, 48, 125, 125, 10, 95, 99, 114, 115, 104, 61, 64, 123, 45, 97,
  114, 103, 34, 32, 49, 44, 34, 36, 95, 115, 104, 97, 100, 111, 119, 110,
  114, 103, 98, 125, 10, 95, 109, 103, 115, 104, 61, 64, 123, 45, 97, 114,
  103, 34, 32, 50, 44, 34, 36, 95, 115, 104, 97, 100, 111, 119, 110, 114,
  103, 98, 125, 10, 95, 121, 98, 115, 104, 61, 64, 123, 45, 97, 114, 103,
  34, 32, 51, 44, 34, 36, 95, 115, 104, 97, 100, 111, 119, 110, 114, 103,
  98, 125, 10, 95, 115, 104, 108, 101, 118, 61, 36, 51, 10, 95, 99, 114,
  109, 105, 100, 61, 64, 123, 45, 97, 114, 103, 34, 32, 49, 44, 34, 36,
  95, 109, 105, 100, 116, 111, 110, 101, 115, 114, 103, 98, 125, 10, 95, 109,
  103, 109, 105, 100, 61, 64, 123, 45, 97, 114, 103, 34, 32, 50, 44, 34,
  36, 95, 109, 105, 100, 116, 111, 110, 101, 115, 114, 103, 98, 125, 10, 95,
  121, 98, 109, 105, 100, 61, 64, 123, 45, 97, 114, 103, 34, 32, 51, 44,
  34, 36, 95, 109, 105, 100, 116, 111, 110, 101, 115, 114, 103, 98, 125, 10,
  95, 109, 105, 100, 108, 101, 118, 61, 36, 54, 10, 95, 99, 114, 104, 105,
  103, 104, 61, 64, 123, 45, 97, 114, 103, 34, 32, 49, 44, 34, 36, 95,
  104, 105, 103, 104, 108, 105, 103, 104, 116, 115, 114, 103, 98, 125, 10, 95,
  109, 103, 104, 105, 103, 104, 61, 64, 123, 45, 97, 114, 103, 34, 32, 50,
  44, 34, 36, 95, 104, 105, 103, 104, 108, 105, 103, 104, 116, 115, 114, 103,
  98, 125, 10, 95, 121, 98, 104, 105, 103, 104, 61, 64, 123, 45, 97, 114,
  103, 34, 32, 51, 44, 34, 36, 95, 104, 105, 103, 104, 108, 105, 103, 104,
  116, 115, 114, 103, 98, 125, 10, 95, 104, 105, 103, 104, 108, 101, 118, 61,
  36, 57, 10, 95, 115, 97, 116, 108, 101, 118, 61, 36, 49, 48, 10, 95,
  108, 111, 119, 105, 110, 114, 101, 100, 61, 48, 10, 95, 104, 105, 105, 110,
  114, 101, 100, 61, 50, 53, 53, 10, 95, 108, 111, 119, 105, 110, 103, 114,
  101, 101, 110, 61, 48, 10, 95, 104, 105, 105, 110, 103, 114, 101, 101, 110,
  61, 50, 53, 53, 10, 95, 108, 111, 119, 105, 110, 98, 108, 117, 101, 61,
  48, 10, 95, 104, 105, 105, 110, 98, 108, 117, 101, 61, 50, 53, 53, 10,
  95, 103, 97, 109, 109, 97, 114, 101, 100, 61, 48, 46, 10, 95, 103, 97,
  109, 109, 97, 103, 114, 101, 101, 110, 61, 48, 46, 10, 95, 103, 97, 109,
  109, 97, 98, 108, 117, 101, 61, 48, 46, 10, 95, 108, 111, 119, 111, 117,
  116, 114, 101, 100, 61, 48, 10, 95, 104, 105, 111, 117, 116, 114, 101, 100,
  61, 50, 53, 53, 10, 95, 108, 111, 119, 111, 117, 116, 103, 114, 101, 101,
  110, 61, 48, 10, 95, 104, 105, 111, 117, 116, 103, 114, 101, 101, 110, 61,
  50, 53, 53, 10, 95, 108, 111, 119, 111, 117, 116, 98, 108, 117, 101, 61,
  48, 10, 95, 104, 105, 111, 117, 116, 98, 108, 117, 101, 61, 50, 53, 53,
  10, 45, 105, 102, 32, 123, 36, 95, 99, 114, 109, 105, 100, 62, 48, 46,
  125, 10, 95, 103, 97, 109, 109, 97, 114, 101, 100, 61, 123, 36, 95, 103,
  97, 109, 109, 97, 114, 101, 100, 43, 48, 46, 52, 42, 36, 95, 99, 114,
  109, 105, 100, 47, 49, 48, 48, 46, 125, 10, 95, 103, 97, 109, 109, 97,
  103, 114, 101, 101, 110, 61, 123, 36, 95, 103, 97, 109, 109, 97, 103, 114,
  101, 101, 110, 45, 48, 46, 51, 42, 36, 95, 99, 114, 109, 105, 100, 47,
  49, 48, 48, 46, 125, 10, 95, 103, 97, 109, 109, 97, 98, 108, 117, 101,
  61, 123, 36, 95, 103, 97, 109, 109, 97, 98, 108, 117, 101, 45, 48, 46,
  51, 42, 36, 95, 99, 114, 109, 105, 100, 47, 49, 48, 48, 46, 125, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 95, 99, 114,
  109, 105, 100, 60, 48, 46, 125, 10, 95, 103, 97, 109, 109, 97, 114, 101,
  100, 61, 123, 36, 95, 103, 97, 109, 109, 97, 114, 101, 100, 43, 48, 46,
  51, 42, 36, 95, 99, 114, 109, 105, 100, 47, 49, 48, 48, 46, 125, 10,
  95, 103, 97, 109, 109, 97, 103, 114, 101, 101, 110, 61, 123, 36, 95, 103,
  97, 109, 109, 97, 103, 114, 101, 101, 110, 45, 48, 46, 52, 42, 36, 95,
  99, 114, 109, 105, 100, 47, 49, 48, 48, 46, 125, 10, 95, 103, 97, 109,
  109, 97, 98, 108, 117, 101, 61, 123, 36, 95, 103, 97, 109, 109, 97, 98,
  108, 117, 101, 45, 48, 46, 52, 42, 36, 95, 99, 114, 109, 105, 100, 47,
  49, 48, 48, 46, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 95, 109, 103, 109, 105, 100, 62, 48, 46, 125, 10, 95, 103,
  97, 109, 109, 97, 114, 101, 100, 61, 123, 36, 95, 103, 97, 109, 109, 97,
  114, 101, 100, 45, 48, 46, 51, 42, 36, 95, 109, 103, 109, 105, 100, 47,
  49, 48, 48, 46, 125, 10, 95, 103, 97, 109, 109, 97, 103, 114, 101, 101,
  110, 61, 123, 36, 95, 103, 97, 109, 109, 97, 103, 114, 101, 101, 110, 43,
  48, 46, 52, 42, 36, 95, 109, 103, 109, 105, 100, 47, 49, 48, 48, 46,
  125, 10, 95, 103, 97, 109, 109, 97, 98, 108, 117, 101, 61, 123, 36, 95,
  103, 97, 109, 109, 97, 98, 108, 117, 101, 45, 48, 46, 51, 42, 36, 95,
  109, 103, 109, 105, 100, 47, 49, 48, 48, 46, 125, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 95, 109, 103, 109, 105, 100, 60,
  48, 46, 125, 10, 95, 103, 97, 109, 109, 97, 114, 101, 100, 61, 123, 36,
  95, 103, 97, 109, 109, 97, 114, 101, 100, 45, 48, 46, 52, 42, 36, 95,
  109, 103, 109, 105, 100, 47, 49, 48, 48, 46, 125, 10, 95, 103, 97, 109,
  109, 97, 103, 114, 101, 101, 110, 61, 123, 36, 95, 103, 97, 109, 109, 97,
  103, 114, 101, 101, 110, 43, 48, 46, 51, 42, 36, 95, 109, 103, 109, 105,
  100, 47, 49, 48, 48, 46, 125, 10, 95, 103, 97, 109, 109, 97, 98, 108,
  117, 101, 61, 123, 36, 95, 103, 97, 109, 109, 97, 98, 108, 117, 101, 45,
  48, 46, 52, 42, 36, 95, 109, 103, 109, 105, 100, 47, 49, 48, 48, 46,
  125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 95,
  121, 98, 109, 105, 100, 62, 48, 46, 125, 10, 95, 103, 97, 109, 109, 97,
  114, 101, 100, 61, 123, 36, 95, 103, 97, 109, 109, 97, 114, 101, 100, 45,
  48, 46, 51, 42, 36, 95, 121, 98, 109, 105, 100, 47, 49, 48, 48, 46,
  125, 10, 95, 103, 97, 109, 109, 97, 103, 114, 101, 101, 110, 61, 123, 36,
  95, 103, 97, 109, 109, 97, 103, 114, 101, 101, 110, 45, 48, 46, 51, 42,
  36, 95, 121, 98, 109, 105, 100, 47, 49, 48, 48, 46, 125, 10, 95, 103,
  97, 109, 109, 97, 98, 108, 117, 101, 61, 123, 36, 95, 103, 97, 109, 109,
  97, 98, 108, 117, 101, 43, 48, 46, 52, 42, 36, 95, 121, 98, 109, 105,
  100, 47, 49, 48, 48, 46, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 95, 121, 98, 109, 105, 100, 60, 48, 46, 125, 10,
  95, 103, 97, 109, 109, 97, 114, 101, 100, 61, 123, 36, 95, 103, 97, 109,
  109, 97, 114, 101, 100, 45, 48, 46, 52, 42, 36, 95, 121, 98, 109, 105,
  100, 47, 49, 48, 48, 46, 125, 10, 95, 103, 97, 109, 109, 97, 103, 114,
  101, 101, 110, 61, 123, 36, 95, 103, 97, 109, 109, 97, 103, 114, 101, 101,
  110, 45, 48, 46, 52, 42, 36, 95, 121, 98, 109, 105, 100, 47, 49, 48,
  48, 46, 125, 10, 95, 103, 97, 109, 109, 97, 98, 108, 117, 101, 61, 123,
  36, 95, 103, 97, 109, 109, 97, 98, 108, 117, 101, 43, 48, 46, 51, 42,
  36, 95, 121, 98, 109, 105, 100, 47, 49, 48, 48, 46, 125, 10, 45, 101,
  110, 100, 105, 102, 10, 95, 103, 97, 109, 109, 97, 114, 101, 100, 61, 123,
  36, 95, 103, 97, 109, 109, 97, 114, 101, 100, 43, 49, 46, 125, 10, 95,
  103, 97, 109, 109, 97, 103, 114, 101, 101, 110, 61, 123, 36, 95, 103, 97,
  109, 109, 97, 103, 114, 101, 101, 110, 43, 49, 46, 125, 10, 95, 103, 97,
  109, 109, 97, 98, 108, 117, 101, 61, 123, 36, 95, 103, 97, 109, 109, 97,
  98, 108, 117, 101, 43, 49, 46, 125, 10, 45, 105, 102, 32, 123, 36, 95,
  109, 105, 100, 108, 101, 118, 62, 48, 46, 125, 10, 95, 103, 97, 109, 109,
  97, 114, 101, 100, 61, 123, 36, 95, 103, 97, 109, 109, 97, 114, 101, 100,
  43, 48, 46, 52, 42, 36, 95, 109, 105, 100, 108, 101, 118, 47, 49, 48,
  48, 46, 125, 10, 95, 103, 97, 109, 109, 97, 103, 114, 101, 101, 110, 61,
  123, 36, 95, 103, 97, 109, 109, 97, 103, 114, 101, 101, 110, 43, 48, 46,
  52, 42, 36, 95, 109, 105, 100, 108, 101, 118, 47, 49, 48, 48, 46, 125,
  10, 95, 103, 97, 109, 109, 97, 98, 108, 117, 101, 61, 123, 36, 95, 103,
  97, 109, 109, 97, 98, 108, 117, 101, 43, 48, 46, 52, 42, 36, 95, 109,
  105, 100, 108, 101, 118, 47, 49, 48, 48, 46, 125, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 95, 109, 105, 100, 108, 101, 118,
  60, 48, 46, 125, 10, 95, 103, 97, 109, 109, 97, 114, 101, 100, 61, 123,
  36, 95, 103, 97, 109, 109, 97, 114, 101, 100, 43, 48, 46, 51, 42, 36,
  95, 109, 105, 100, 108, 101, 118, 47, 49, 48, 48, 46, 125, 10, 95, 103,
  97, 109, 109, 97, 103, 114, 101, 101, 110, 61, 123, 36, 95, 103, 97, 109,
  109, 97, 103, 114, 101, 101, 110, 43, 48, 46, 51, 42, 36, 95, 109, 105,
  100, 108, 101, 118, 47, 49, 48, 48, 46, 125, 10, 95, 103, 97, 109, 109,
  97, 98, 108, 117, 101, 61, 123, 36, 95, 103, 97, 109, 109, 97, 98, 108,
  117, 101, 43, 48, 46, 51, 42, 36, 95, 109, 105, 100, 108, 101, 118, 47,
  49, 48, 48, 46, 125, 10, 45, 101, 110, 100, 105, 102, 10, 95, 99, 114,
  115, 104, 61, 123, 36, 95, 99, 114, 115, 104, 42, 48, 46, 51, 125, 10,
  95, 109, 103, 115, 104, 61, 123, 36, 95, 109, 103, 115, 104, 42, 48, 46,
  51, 125, 10, 95, 121, 98, 115, 104, 61, 123, 36, 95, 121, 98, 115, 104,
  42, 48, 46, 51, 125, 10, 45, 105, 102, 32, 123, 36, 95, 99, 114, 115,
  104, 62, 48, 125, 10, 95, 108, 111, 119, 105, 110, 103, 114, 101, 101, 110,
  61, 123, 36, 95, 108, 111, 119, 105, 110, 103, 114, 101, 101, 110, 43, 36,
  95, 99, 114, 115, 104, 125, 10, 95, 108, 111, 119, 105, 110, 98, 108, 117,
  101, 61, 123, 36, 95, 108, 111, 119, 105, 110, 98, 108, 117, 101, 43, 36,
  95, 99, 114, 115, 104, 125, 10, 95, 108, 111, 119, 111, 117, 116, 114, 101,
  100, 61, 123, 36, 95, 108, 111, 119, 111, 117, 116, 114, 101, 100, 43, 36,
  95, 99, 114, 115, 104, 125, 10, 45, 101, 108, 115, 101, 10, 95, 108, 111,
  119, 105, 110, 114, 101, 100, 61, 123, 36, 95, 108, 111, 119, 105, 110, 114,
  101, 100, 45, 36, 95, 99, 114, 115, 104, 125, 10, 95, 108, 111, 119, 111,
  117, 116, 103, 114, 101, 101, 110, 61, 123, 36, 95, 108, 111, 119, 111, 117,
  116, 103, 114, 101, 101, 110, 45, 36, 95, 99, 114, 115, 104, 125, 10, 95,
  108, 111, 119, 111, 117, 116, 98, 108, 117, 101, 61, 123, 36, 95, 108, 111,
  119, 111, 117, 116, 98, 108, 117, 101, 45, 36, 95, 99, 114, 115, 104, 125,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 95, 109,
  103, 115, 104, 62, 48, 125, 10, 95, 108, 111, 119, 105, 110, 114, 101, 100,
  61, 123, 36, 95, 108, 111, 119, 105, 110, 114, 101, 100, 43, 36, 95, 109,
  103, 115, 104, 125, 10, 95, 108, 111, 119, 105, 110, 98, 108, 117, 101, 61,
  123, 36, 95, 108, 111, 119, 105, 110, 98, 108, 117, 101, 43, 36, 95, 109,
  103, 115, 104, 125, 10, 95, 108, 111, 119, 111, 117, 116, 103, 114, 101, 101,
  110, 61, 123, 36, 95, 108, 111, 119, 111, 117, 116, 103, 114, 101, 101, 110,
  43, 36, 95, 109, 103, 115, 104, 125, 10, 45, 101, 108, 115, 101, 10, 95,
  108, 111, 119, 105, 110, 103, 114, 101, 101, 110, 61, 123, 36, 95, 108, 111,
  119, 105, 110, 103, 114, 101, 101, 110, 45, 36, 95, 109, 103, 115, 104, 125,
  10, 95, 108, 111, 119, 111, 117, 116, 114, 101, 100, 61, 123, 36, 95, 108,
  111, 119, 111, 117, 116, 114, 101, 100, 45, 36, 95, 109, 103, 115, 104, 125,
  10, 95, 108, 111, 119, 111, 117, 116, 98, 108, 117, 101, 61, 123, 36, 95,
  108, 111, 119, 111, 117, 116, 98, 108, 117, 101, 45, 36, 95, 109, 103, 115,
  104, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  95, 121, 98, 115, 104, 62, 48, 125, 10, 95, 108, 111, 119, 105, 110, 114,
  101, 100, 61, 123, 36, 95, 108, 111, 119, 105, 110, 114, 101, 100, 43, 36,
  95, 121, 98, 115, 104, 125, 10, 95, 108, 111, 119, 105, 110, 103, 114, 101,
  101, 110, 61, 123, 36, 95, 108, 111, 119, 105, 110, 103, 114, 101, 101, 110,
  43, 36, 95, 121, 98, 115, 104, 125, 10, 95, 108, 111, 119, 111, 117, 116,
  98, 108, 117, 101, 61, 123, 36, 95, 108, 111, 119, 111, 117, 116, 98, 108,
  117, 101, 43, 36, 95, 121, 98, 115, 104, 125, 10, 45, 101, 108, 115, 101,
  10, 95, 108, 111, 119, 105, 110, 98, 108, 117, 101, 61, 123, 36, 95, 108,
  111, 119, 105, 110, 98, 108, 117, 101, 45, 36, 95, 121, 98, 115, 104, 125,
  10, 95, 108, 111, 119, 111, 117, 116, 114, 101, 100, 61, 123, 36, 95, 108,
  111, 119, 111, 117, 116, 114, 101, 100, 45, 36, 95, 121, 98, 115, 104, 125,
  10, 95, 108, 111, 119, 111, 117, 116, 103, 114, 101, 101, 110, 61, 123, 36,
  95, 108, 111, 119, 111, 117, 116, 103, 114, 101, 101, 110, 45, 36, 95, 121,
  98, 115, 104, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 95, 115, 104, 108, 101, 118, 62, 48, 125, 10, 95, 108, 111, 119,
  111, 117, 116, 114, 101, 100, 61, 123, 36, 95, 108, 111, 119, 111, 117, 116,
  114, 101, 100, 43, 36, 95, 115, 104, 108, 101, 118, 125, 10, 95, 108, 111,
  119, 111, 117, 116, 103, 114, 101, 101, 110, 61, 123, 36, 95, 108, 111, 119,
  111, 117, 116, 103, 114, 101, 101, 110, 43, 36, 95, 115, 104, 108, 101, 118,
  125, 10, 95, 108, 111, 119, 111, 117, 116, 98, 108, 117, 101, 61, 123, 36,
  95, 108, 111, 119, 111, 117, 116, 98, 108, 117, 101, 43, 36, 95, 115, 104,
  108, 101, 118, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 95, 115, 104, 108, 101, 118, 60, 48, 125, 10, 95, 108, 111, 119,
  105, 110, 114, 101, 100, 61, 123, 36, 95, 108, 111, 119, 105, 110, 114, 101,
  100, 45, 36, 95, 115, 104, 108, 101, 118, 125, 10, 95, 108, 111, 119, 105,
  110, 103, 114, 101, 101, 110, 61, 123, 36, 95, 108, 111, 119, 105, 110, 103,
  114, 101, 101, 110, 45, 36, 95, 115, 104, 108, 101, 118, 125, 10, 95, 108,
  111, 119, 105, 110, 98, 108, 117, 101, 61, 123, 36, 95, 108, 111, 119, 105,
  110, 98, 108, 117, 101, 45, 36, 95, 115, 104, 108, 101, 118, 125, 10, 45,
  101, 110, 100, 105, 102, 10, 95, 99, 114, 104, 105, 103, 104, 61, 123, 36,
  95, 99, 114, 104, 105, 103, 104, 42, 48, 46, 51, 125, 10, 95, 109, 103,
  104, 105, 103, 104, 61, 123, 36, 95, 109, 103, 104, 105, 103, 104, 42, 48,
  46, 51, 125, 10, 95, 121, 98, 104, 105, 103, 104, 61, 123, 36, 95, 121,
  98, 104, 105, 103, 104, 42, 48, 46, 51, 125, 10, 45, 105, 102, 32, 123,
  36, 95, 99, 114, 104, 105, 103, 104, 62, 48, 125, 10, 95, 104, 105, 105,
  110, 114, 101, 100, 61, 123, 36, 95, 104, 105, 105, 110, 114, 101, 100, 45,
  36, 95, 99, 114, 104, 105, 103, 104, 125, 10, 95, 104, 105, 111, 117, 116,
  103, 114, 101, 101, 110, 61, 123, 36, 95, 104, 105, 111, 117, 116, 103, 114,
  101, 101, 110, 45, 36, 95, 99, 114, 104, 105, 103, 104, 125, 10, 95, 104,
  105, 111, 117, 116, 98, 108, 117, 101, 61, 123, 36, 95, 104, 105, 111, 117,
  116, 103, 114, 101, 101, 110, 45, 36, 95, 99, 114, 104, 105, 103, 104, 125,
  10, 45, 101, 108, 115, 101, 10, 95, 104, 105, 105, 110, 103, 114, 101, 101,
  110, 61, 123, 36, 95, 104, 105, 105, 110, 103, 114, 101, 101, 110, 43, 36,
  95, 99, 114, 104, 105, 103, 104, 125, 10, 95, 104, 105, 105, 110, 98, 108,
  117, 101, 61, 123, 36, 95, 104, 105, 105, 110, 98, 108, 117, 101, 43, 36,
  95, 99, 114, 104, 105, 103, 104, 125, 10, 95, 104, 105, 111, 117, 116, 114,
  101, 100, 61, 123, 36, 95, 104, 105, 111, 117, 116, 114, 101, 100, 43, 36,
  95, 99, 114, 104, 105, 103, 104, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 95, 109, 103, 104, 105, 103, 104, 62, 48, 125,
  10, 95, 104, 105, 105, 110, 103, 114, 101, 101, 110, 61, 123, 36, 95, 104,
  105, 105, 110, 103, 114, 101, 101, 110, 45, 36, 95, 109, 103, 104, 105, 103,
  104, 125, 10, 95, 104, 105, 111, 117, 116, 114, 101, 100, 61, 123, 36, 95,
  104, 105, 111, 117, 116, 114, 101, 100, 45, 36, 95, 109, 103, 104, 105, 103,
  104, 125, 10, 95, 104, 105, 111, 117, 116, 98, 108, 117, 101, 61, 123, 36,
  95, 104, 105, 111, 117, 116, 98, 108, 117, 101, 45, 36, 95, 109, 103, 104,
  105, 103, 104, 125, 10, 45, 101, 108, 115, 101, 10, 95, 104, 105, 105, 110,
  114, 101, 100, 61, 123, 36, 95, 104, 105, 105, 110, 114, 101, 100, 43, 36,
  95, 109, 103, 104, 105, 103, 104, 125, 10, 95, 104, 105, 105, 110, 98, 108,
  117, 101, 61, 123, 36, 95, 104, 105, 105, 110, 98, 108, 117, 101, 43, 36,
  95, 109, 103, 104, 105, 103, 104, 125, 10, 95, 104, 105, 111, 117, 116, 103,
  114, 101, 101, 110, 61, 123, 36, 95, 104, 105, 111, 117, 116, 103, 114, 101,
  101, 110, 43, 36, 95, 109, 103, 104, 105, 103, 104, 125, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 95, 121, 98, 104, 105, 103,
  104, 62, 48, 125, 10, 95, 104, 105, 105, 110, 98, 108, 117, 101, 61, 123,
  36, 95, 104, 105, 105, 110, 98, 108, 117, 101, 45, 36, 95, 121, 98, 104,
  105, 103, 104, 125, 10, 95, 104, 105, 111, 117, 116, 114, 101, 100, 61, 123,
  36, 95, 104, 105, 111, 117, 116, 114, 101, 100, 45, 36, 95, 121, 98, 104,
  105, 103, 104, 125, 10, 95, 104, 105, 111, 117, 116, 103, 114, 101, 101, 110,
  61, 123, 36, 95, 104, 105, 111, 117, 116, 103, 114, 101, 101, 110, 45, 36,
  95, 121, 98, 104, 105, 103, 104, 125, 10, 45, 101, 108, 115, 101, 10, 95,
  104, 105, 105, 110, 114, 101, 100, 61, 123, 36, 95, 104, 105, 105, 110, 114,
  101, 100, 43, 36, 95, 121, 98, 104, 105, 103, 104, 125, 10, 95, 104, 105,
  105, 110, 103, 114, 101, 101, 110, 61, 123, 36, 95, 104, 105, 105, 110, 103,
  114, 101, 101, 110, 43, 36, 95, 121, 98, 104, 105, 103, 104, 125, 10, 95,
  104, 105, 111, 117, 116, 98, 108, 117, 101, 61, 123, 36, 95, 104, 105, 111,
  117, 116, 98, 108, 117, 101, 43, 36, 95, 121, 98, 104, 105, 103, 104, 125,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 95, 104,
  105, 103, 104, 108, 101, 118, 62, 48, 125, 10, 95, 104, 105, 105, 110, 114,
  101, 100, 61, 123, 36, 95, 104, 105, 105, 110, 114, 101, 100, 45, 36, 95,
  104, 105, 103, 104, 108, 101, 118, 125, 10, 95, 104, 105, 105, 110, 103, 114,
  101, 101, 110, 61, 123, 36, 95, 104, 105, 105, 110, 103, 114, 101, 101, 110,
  45, 36, 95, 104, 105, 103, 104, 108, 101, 118, 125, 10, 95, 104, 105, 105,
  110, 98, 108, 117, 101, 61, 123, 36, 95, 104, 105, 105, 110, 98, 108, 117,
  101, 45, 36, 95, 104, 105, 103, 104, 108, 101, 118, 125, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 95, 104, 105, 103, 104, 108,
  101, 118, 60, 48, 125, 10, 95, 104, 105, 111, 117, 116, 114, 101, 100, 61,
  123, 36, 95, 104, 105, 111, 117, 116, 114, 101, 100, 43, 36, 95, 104, 105,
  103, 104, 108, 101, 118, 125, 10, 95, 104, 105, 111, 117, 116, 103, 114, 101,
  101, 110, 61, 123, 36, 95, 104, 105, 111, 117, 116, 103, 114, 101, 101, 110,
  43, 36, 95, 104, 105, 103, 104, 108, 101, 118, 125, 10, 95, 104, 105, 111,
  117, 116, 98, 108, 117, 101, 61, 123, 36, 95, 104, 105, 111, 117, 116, 98,
  108, 117, 101, 43, 36, 95, 104, 105, 103, 104, 108, 101, 118, 125, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 108, 101, 118, 101, 108, 115, 32, 36, 95,
  108, 111, 119, 105, 110, 114, 101, 100, 44, 36, 95, 104, 105, 105, 110, 114,
  101, 100, 44, 36, 95, 103, 97, 109, 109, 97, 114, 101, 100, 44, 36, 95,
  108, 111, 119, 111, 117, 116, 114, 101, 100, 44, 36, 95, 104, 105, 111, 117,
  116, 114, 101, 100, 44, 49, 57, 10, 45, 108, 101, 118, 101, 108, 115, 32,
  36, 95, 108, 111, 119, 105, 110, 103, 114, 101, 101, 110, 44, 36, 95, 104,
  105, 105, 110, 103, 114, 101, 101, 110, 44, 36, 95, 103, 97, 109, 109, 97,
  103, 114, 101, 101, 110, 44, 36, 95, 108, 111, 119, 111, 117, 116, 103, 114,
  101, 101, 110, 44, 36, 95, 104, 105, 111, 117, 116, 103, 114, 101, 101, 110,
  44, 50, 48, 10, 45, 108, 101, 118, 101, 108, 115, 32, 36, 95, 108, 111,
  119, 105, 110, 98, 108, 117, 101, 44, 36, 95, 104, 105, 105, 110, 98, 108,
  117, 101, 44, 36, 95, 103, 97, 109, 109, 97, 98, 108, 117, 101, 44, 36,
  95, 108, 111, 119, 111, 117, 116, 98, 108, 117, 101, 44, 36, 95, 104, 105,
  111, 117, 116, 98, 108, 117, 101, 44, 50, 49, 10, 106, 108, 95, 99, 111,
  108, 111, 114, 103, 114, 97, 100, 105, 110, 103, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 106, 108, 95, 99, 111,
  108, 111, 114, 103, 114, 97, 100, 105, 110, 103, 32, 36, 42, 34, 44, 36,
  45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 67, 111, 108, 111, 114, 32,
  116, 101, 109, 112, 101, 114, 97, 116, 117, 114, 101, 32, 58, 32, 103, 105,
  109, 112, 95, 116, 107, 95, 99, 111, 108, 111, 114, 116, 101, 109, 112, 44,
  32, 103, 105, 109, 112, 95, 116, 107, 95, 99, 111, 108, 111, 114, 116, 101,
  109, 112, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 116, 101, 109,
  112, 101, 114, 97, 116, 117, 114, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 45, 50, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 117, 116, 111, 109, 97, 116, 105, 99, 32, 99, 111,
  108, 111, 114, 32, 98, 97, 108, 97, 110, 99, 101, 32, 61, 32, 98, 111,
  111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 118, 105, 101,
  119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 84, 111, 109, 32, 75, 101, 105, 108, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 50, 47, 48,
  53, 47, 48, 52, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 116, 107, 95, 99, 111, 108, 111,
  114, 116, 101, 109, 112, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 105, 102, 32, 123, 36,
  50, 61, 61, 49, 125, 32, 45, 45, 108, 117, 109, 105, 110, 97, 110, 99,
  101, 91, 45, 49, 93, 32, 45, 116, 111, 95, 114, 103, 98, 91, 45, 50,
  93, 10, 45, 115, 91, 45, 50, 93, 32, 99, 32, 32, 97, 118, 98, 61,
  123, 49, 50, 55, 46, 53, 45, 64, 123, 45, 50, 44, 97, 125, 125, 32,
  97, 118, 103, 61, 123, 49, 50, 55, 46, 53, 45, 64, 123, 45, 51, 44,
  97, 125, 125, 32, 97, 118, 114, 61, 123, 49, 50, 55, 46, 53, 45, 64,
  123, 45, 52, 44, 97, 125, 125, 10, 45, 43, 91, 45, 52, 93, 32, 36,
  97, 118, 114, 32, 45, 43, 91, 45, 51, 93, 32, 36, 97, 118, 103, 32,
  45, 43, 91, 45, 50, 93, 32, 36, 97, 118, 98, 32, 45, 97, 91, 45,
  52, 44, 45, 51, 44, 45, 50, 93, 32, 99, 32, 45, 114, 118, 32, 45,
  99, 111, 109, 112, 111, 115, 101, 95, 108, 117, 109, 105, 110, 97, 110, 99,
  101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 109,
  105, 120, 95, 108, 97, 98, 32, 49, 44, 48, 44, 48, 44, 49, 44, 123,
  105, 102, 40, 123, 36, 49, 62, 61, 48, 125, 44, 123, 36, 49, 47, 52,
  125, 44, 123, 36, 49, 42, 48, 46, 55, 53, 125, 41, 125, 44, 48, 44,
  49, 44, 36, 49, 44, 48, 44, 48, 44, 50, 44, 48, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 116, 107,
  95, 99, 111, 108, 111, 114, 116, 101, 109, 112, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95,
  116, 107, 95, 99, 111, 108, 111, 114, 116, 101, 109, 112, 32, 36, 123, 49,
  45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112,
  32, 67, 117, 114, 118, 101, 115, 32, 58, 32, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 44, 32, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 116,
  97, 114, 116, 105, 110, 103, 32, 121, 32, 61, 32, 105, 110, 116, 40, 48,
  44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 111,
  111, 114, 100, 40, 49, 41, 32, 61, 32, 105, 110, 116, 40, 45, 49, 44,
  45, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 89, 45, 99, 111, 111, 114, 100, 40, 49, 41, 32, 61, 32, 105, 110,
  116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 88, 45, 99, 111, 111, 114, 100, 40, 50, 41, 32, 61, 32, 105, 110,
  116, 40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100, 40, 50, 41,
  32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 88, 45, 99, 111, 111, 114, 100, 40, 51, 41,
  32, 61, 32, 105, 110, 116, 40, 45, 49, 44, 45, 49, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111,
  114, 100, 40, 51, 41, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44,
  48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 111, 111,
  114, 100, 40, 52, 41, 32, 61, 32, 105, 110, 116, 40, 45, 49, 44, 45,
  49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  89, 45, 99, 111, 111, 114, 100, 40, 52, 41, 32, 61, 32, 105, 110, 116,
  40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  88, 45, 99, 111, 111, 114, 100, 40, 53, 41, 32, 61, 32, 105, 110, 116,
  40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100, 40, 53, 41, 32,
  61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 69, 110, 100, 105, 110, 103, 32, 121, 32, 61, 32,
  105, 110, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 117, 114, 118, 101, 32, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110,
  110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71,
  66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114,
  111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103,
  104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114,
  97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34,
  75, 101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101,
  110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108, 117,
  101, 32, 114, 97, 110, 103, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 67, 117, 116, 34, 44, 34, 78, 111, 114, 109, 97, 108, 105, 122,
  101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 105, 115,
  112, 108, 97, 121, 32, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117,
  108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60,
  105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101,
  114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103,
  105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 32,
  58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 34, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  99, 117, 114, 118, 101, 32, 36, 123, 49, 45, 49, 51, 125, 34, 44, 36,
  49, 52, 44, 36, 49, 53, 10, 95, 103, 105, 109, 112, 95, 97, 112, 112,
  108, 121, 95, 99, 117, 114, 118, 101, 32, 58, 10, 45, 97, 112, 112, 108,
  121, 95, 99, 117, 114, 118, 101, 32, 36, 49, 51, 44, 48, 44, 36, 49,
  44, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 50, 62, 61, 48,
  125, 32, 45, 117, 32, 36, 50, 44, 36, 51, 44, 32, 45, 101, 108, 115,
  101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102,
  34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 52, 62, 61,
  48, 125, 32, 45, 117, 32, 36, 52, 44, 36, 53, 44, 32, 45, 101, 108,
  115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105,
  102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 54, 62,
  61, 48, 125, 32, 45, 117, 32, 36, 54, 44, 36, 55, 44, 32, 45, 101,
  108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100,
  105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 56,
  62, 61, 48, 125, 32, 45, 117, 32, 36, 56, 44, 36, 57, 44, 32, 45,
  101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110,
  100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36,
  49, 48, 62, 61, 48, 125, 32, 45, 117, 32, 36, 49, 48, 44, 36, 49,
  49, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34,
  32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 50, 53, 53, 44, 36,
  49, 50, 10, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117,
  114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 102,
  117, 110, 99, 116, 105, 111, 110, 49, 100, 32, 36, 49, 51, 44, 48, 44,
  36, 49, 44, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 50, 62,
  61, 48, 125, 32, 45, 117, 32, 36, 50, 44, 36, 51, 44, 32, 45, 101,
  108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100,
  105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 52,
  62, 61, 48, 125, 32, 45, 117, 32, 36, 52, 44, 36, 53, 44, 32, 45,
  101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110,
  100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36,
  54, 62, 61, 48, 125, 32, 45, 117, 32, 36, 54, 44, 36, 55, 44, 32,
  45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101,
  110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123,
  36, 56, 62, 61, 48, 125, 32, 45, 117, 32, 36, 56, 44, 36, 57, 44,
  32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45,
  101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32,
  123, 36, 49, 48, 62, 61, 48, 125, 32, 45, 117, 32, 36, 49, 48, 44,
  36, 49, 49, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34,
  92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 50, 53, 53,
  44, 36, 49, 50, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 10, 45, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 91, 45, 49, 93, 32, 34, 45, 103, 105, 109, 112, 95, 97, 112,
  112, 108, 121, 95, 99, 117, 114, 118, 101, 32, 36, 42, 34, 44, 36, 45,
  49, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 97, 120, 101,
  115, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  48, 44, 49, 51, 44, 49, 44, 50, 53, 53, 32, 45, 45, 100, 105, 108,
  97, 116, 101, 91, 45, 49, 93, 32, 51, 32, 45, 114, 91, 45, 50, 93,
  32, 91, 45, 51, 93, 32, 45, 106, 91, 45, 51, 93, 32, 91, 45, 50,
  93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93,
  44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10,
  45, 103, 114, 105, 100, 91, 45, 49, 93, 32, 49, 48, 37, 44, 49, 48,
  37, 44, 48, 44, 48, 44, 48, 46, 51, 44, 48, 120, 67, 67, 67, 67,
  67, 67, 67, 67, 44, 50, 53, 53, 10, 45, 108, 105, 110, 101, 91, 45,
  49, 93, 32, 48, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48,
  44, 48, 46, 51, 44, 48, 120, 67, 67, 67, 67, 67, 67, 67, 67, 44,
  50, 53, 53, 10, 45, 105, 102, 32, 36, 45, 50, 10, 91, 45, 49, 93,
  44, 91, 45, 49, 93, 32, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45,
  51, 93, 32, 45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 51,
  93, 32, 50, 53, 54, 44, 48, 44, 50, 53, 53, 32, 45, 103, 114, 97,
  112, 104, 91, 45, 49, 93, 32, 91, 45, 51, 93, 44, 51, 44, 48, 44,
  48, 44, 48, 44, 49, 44, 49, 32, 45, 110, 101, 113, 91, 45, 49, 93,
  32, 48, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114,
  109, 91, 45, 51, 93, 10, 45, 45, 120, 111, 114, 91, 45, 50, 44, 45,
  49, 93, 32, 45, 106, 91, 45, 51, 93, 32, 91, 45, 49, 93, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 36, 49, 54, 44, 91, 45, 50, 93, 44,
  50, 53, 53, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45,
  101, 108, 115, 101, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45, 101, 110,
  100, 105, 102, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 103,
  114, 97, 112, 104, 91, 45, 49, 93, 32, 91, 48, 93, 44, 49, 44, 48,
  44, 50, 53, 53, 44, 48, 44, 49, 44, 50, 53, 53, 32, 45, 45, 100,
  105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51, 32, 45, 114, 91, 45,
  50, 93, 32, 91, 45, 51, 93, 32, 45, 106, 91, 45, 51, 93, 32, 91,
  45, 50, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45,
  49, 93, 44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49,
  93, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99,
  117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 48, 44, 36,
  49, 44, 48, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121,
  95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36,
  50, 44, 36, 51, 44, 49, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112,
  112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 36, 52, 44, 36, 53, 44, 50, 32, 45, 95, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 36, 54, 44, 36, 55, 44, 51, 10, 45, 95, 103,
  105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 36, 56, 44, 36, 57, 44, 52, 32,
  45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114,
  118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 49, 48, 44, 36,
  49, 49, 44, 53, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108,
  121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  50, 53, 53, 44, 36, 49, 50, 44, 54, 10, 45, 109, 118, 91, 45, 49,
  93, 32, 49, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 93,
  10, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114,
  118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 105, 102,
  32, 123, 36, 49, 62, 61, 48, 125, 10, 120, 61, 123, 36, 49, 42, 49,
  48, 48, 47, 50, 53, 53, 125, 37, 32, 121, 61, 123, 49, 48, 48, 45,
  36, 50, 42, 49, 48, 48, 47, 50, 53, 53, 125, 37, 10, 45, 101, 108,
  108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 120, 44, 36, 121, 44,
  51, 44, 51, 44, 48, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70,
  70, 70, 44, 48, 44, 48, 44, 48, 32, 45, 101, 108, 108, 105, 112, 115,
  101, 91, 45, 49, 93, 32, 36, 120, 44, 36, 121, 44, 50, 44, 50, 44,
  48, 44, 49, 44, 48, 44, 50, 53, 53, 44, 48, 10, 45, 116, 91, 45,
  49, 93, 32, 36, 51, 44, 36, 120, 44, 123, 36, 121, 42, 104, 45, 50,
  48, 125, 44, 49, 51, 44, 49, 44, 50, 53, 53, 10, 45, 101, 110, 100,
  105, 102, 10, 35, 64, 103, 105, 109, 112, 32, 60, 105, 62, 67, 117, 114,
  118, 101, 115, 32, 91, 76, 97, 98, 93, 60, 47, 105, 62, 10, 35, 64,
  103, 105, 109, 112, 32, 65, 45, 99, 111, 108, 111, 114, 32, 58, 32, 103,
  105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 76, 97, 98, 99, 117, 114,
  118, 101, 44, 32, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 97,
  99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 116, 97, 114, 116, 105, 110, 103, 32,
  121, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 88, 45, 99, 111, 111, 114, 100, 40, 49, 41, 32,
  61, 32, 105, 110, 116, 40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114,
  100, 40, 49, 41, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 111, 111, 114,
  100, 40, 50, 41, 32, 61, 32, 105, 110, 116, 40, 45, 49, 44, 45, 49,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89,
  45, 99, 111, 111, 114, 100, 40, 50, 41, 32, 61, 32, 105, 110, 116, 40,
  49, 50, 56, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88,
  45, 99, 111, 111, 114, 100, 40, 51, 41, 32, 61, 32, 105, 110, 116, 40,
  45, 49, 44, 45, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100, 40, 51, 41, 32, 61,
  32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 88, 45, 99, 111, 111, 114, 100, 40, 52, 41, 32, 61,
  32, 105, 110, 116, 40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100,
  40, 52, 41, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 111, 111, 114, 100,
  40, 53, 41, 32, 61, 32, 105, 110, 116, 40, 45, 49, 44, 45, 49, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45,
  99, 111, 111, 114, 100, 40, 53, 41, 32, 61, 32, 105, 110, 116, 40, 49,
  50, 56, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 110,
  100, 105, 110, 103, 32, 121, 32, 61, 32, 105, 110, 116, 40, 50, 53, 53,
  44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 114, 118,
  101, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 68, 105, 115, 112, 108, 97, 121, 32, 104, 105, 115,
  116, 111, 103, 114, 97, 109, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  66, 45, 99, 111, 108, 111, 114, 32, 58, 32, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 76, 97, 98, 99, 117, 114, 118, 101, 44, 32, 103,
  105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 98, 99, 117, 114, 118, 101,
  95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 116, 97, 114, 116, 105, 110, 103, 32, 121, 32, 61, 32, 105,
  110, 116, 40, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  88, 45, 99, 111, 111, 114, 100, 40, 49, 41, 32, 61, 32, 105, 110, 116,
  40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100, 40, 49, 41, 32,
  61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 88, 45, 99, 111, 111, 114, 100, 40, 50, 41, 32,
  61, 32, 105, 110, 116, 40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114,
  100, 40, 50, 41, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 111, 111, 114,
  100, 40, 51, 41, 32, 61, 32, 105, 110, 116, 40, 45, 49, 44, 45, 49,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89,
  45, 99, 111, 111, 114, 100, 40, 51, 41, 32, 61, 32, 105, 110, 116, 40,
  49, 50, 56, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88,
  45, 99, 111, 111, 114, 100, 40, 52, 41, 32, 61, 32, 105, 110, 116, 40,
  45, 49, 44, 45, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100, 40, 52, 41, 32, 61,
  32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 88, 45, 99, 111, 111, 114, 100, 40, 53, 41, 32, 61,
  32, 105, 110, 116, 40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100,
  40, 53, 41, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 110, 100, 105, 110, 103, 32,
  121, 32, 61, 32, 105, 110, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 117, 114, 118, 101, 32, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  68, 105, 115, 112, 108, 97, 121, 32, 104, 105, 115, 116, 111, 103, 114, 97,
  109, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49,
  50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 76,
  97, 98, 99, 117, 114, 118, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32,
  36, 49, 10, 45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 76,
  97, 98, 99, 117, 114, 118, 101, 95, 99, 111, 110, 102, 105, 103, 102, 105,
  108, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49,
  125, 32, 45, 108, 91, 36, 62, 44, 45, 49, 93, 10, 45, 116, 111, 95,
  99, 111, 108, 111, 114, 109, 111, 100, 101, 91, 48, 93, 32, 123, 109, 97,
  120, 40, 51, 44, 115, 41, 125, 32, 45, 115, 104, 91, 48, 93, 32, 48,
  44, 50, 32, 45, 114, 103, 98, 50, 108, 97, 98, 91, 45, 49, 93, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 48, 93, 32, 48,
  44, 48, 32, 45, 42, 91, 45, 49, 93, 32, 50, 46, 53, 53, 32, 45,
  95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 76, 97, 98, 99,
  117, 114, 118, 101, 91, 45, 49, 93, 32, 64, 123, 45, 50, 44, 48, 45,
  49, 50, 125, 32, 45, 47, 91, 45, 49, 93, 32, 50, 46, 53, 53, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 48, 93, 32, 49,
  44, 49, 32, 45, 43, 91, 45, 49, 93, 32, 56, 54, 32, 45, 42, 91,
  45, 49, 93, 32, 49, 46, 51, 56, 53, 56, 55, 32, 45, 95, 103, 105,
  109, 112, 95, 97, 112, 112, 108, 121, 95, 76, 97, 98, 99, 117, 114, 118,
  101, 91, 45, 49, 93, 32, 64, 123, 45, 50, 44, 49, 51, 45, 50, 53,
  125, 32, 45, 47, 91, 45, 49, 93, 32, 49, 46, 51, 56, 53, 56, 55,
  32, 45, 45, 91, 45, 49, 93, 32, 56, 54, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 115, 104, 91, 48, 93, 32, 50, 44, 50, 32, 45, 43,
  91, 45, 49, 93, 32, 49, 48, 56, 32, 45, 42, 91, 45, 49, 93, 32,
  49, 46, 50, 53, 54, 49, 54, 32, 45, 95, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 76, 97, 98, 99, 117, 114, 118, 101, 91, 45, 49,
  93, 32, 64, 123, 45, 50, 44, 50, 54, 45, 51, 56, 125, 32, 45, 47,
  91, 45, 49, 93, 32, 49, 46, 50, 53, 54, 49, 54, 32, 45, 45, 91,
  45, 49, 93, 32, 49, 48, 56, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 115, 104, 91, 48, 93, 32, 48, 44, 50, 32, 45, 108, 97, 98, 50,
  114, 103, 98, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91,
  45, 49, 93, 10, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  76, 97, 98, 99, 117, 114, 118, 101, 32, 58, 10, 45, 97, 112, 112, 108,
  121, 95, 99, 117, 114, 118, 101, 32, 36, 49, 51, 44, 48, 44, 36, 49,
  44, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 50, 62, 61, 48,
  125, 32, 45, 117, 32, 36, 50, 44, 36, 51, 44, 32, 45, 101, 108, 115,
  101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102,
  34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 52, 62, 61,
  48, 125, 32, 45, 117, 32, 36, 52, 44, 36, 53, 44, 32, 45, 101, 108,
  115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105,
  102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 54, 62,
  61, 48, 125, 32, 45, 117, 32, 36, 54, 44, 36, 55, 44, 32, 45, 101,
  108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100,
  105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 56,
  62, 61, 48, 125, 32, 45, 117, 32, 36, 56, 44, 36, 57, 44, 32, 45,
  101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110,
  100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36,
  49, 48, 62, 61, 48, 125, 32, 45, 117, 32, 36, 49, 48, 44, 36, 49,
  49, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34,
  32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 50, 53, 53, 44, 36,
  49, 50, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 76, 99, 117, 114, 118, 101, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 97, 112,
  112, 108, 121, 95, 76, 97, 98, 99, 117, 114, 118, 101, 95, 99, 111, 110,
  102, 105, 103, 102, 105, 108, 101, 10, 45, 115, 104, 91, 45, 49, 93, 32,
  48, 44, 48, 44, 48, 44, 48, 32, 45, 102, 91, 45, 49, 93, 32, 36,
  123, 49, 45, 45, 51, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 76, 97, 98, 99, 117,
  114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 91, 94, 45, 49, 93,
  32, 64, 45, 49, 44, 48, 44, 36, 123, 45, 50, 44, 45, 49, 125, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 103, 105, 109, 112, 95, 97, 112, 112,
  108, 121, 95, 97, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  76, 97, 98, 99, 117, 114, 118, 101, 95, 99, 111, 110, 102, 105, 103, 102,
  105, 108, 101, 10, 45, 115, 104, 91, 45, 49, 93, 32, 49, 44, 49, 44,
  48, 44, 48, 32, 45, 102, 91, 45, 49, 93, 32, 36, 123, 49, 45, 45,
  51, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 76, 97, 98, 99, 117, 114, 118, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 91, 94, 45, 49, 93, 32, 64, 45, 49,
  44, 49, 44, 36, 123, 45, 50, 44, 45, 49, 125, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 98,
  99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 76, 97, 98, 99,
  117, 114, 118, 101, 95, 99, 111, 110, 102, 105, 103, 102, 105, 108, 101, 10,
  45, 115, 104, 91, 45, 49, 93, 32, 50, 44, 50, 44, 48, 44, 48, 32,
  45, 102, 91, 45, 49, 93, 32, 36, 123, 49, 45, 45, 51, 125, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 97, 112, 112,
  108, 121, 95, 76, 97, 98, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 91, 94, 45, 49, 93, 32, 64, 45, 49, 44, 50, 44, 36,
  123, 45, 50, 44, 45, 49, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 76, 97, 98, 99, 117,
  114, 118, 101, 95, 99, 111, 110, 102, 105, 103, 102, 105, 108, 101, 32, 58,
  10, 102, 105, 108, 101, 110, 97, 109, 101, 61, 64, 123, 45, 112, 97, 116,
  104, 95, 116, 109, 112, 125, 47, 46, 103, 109, 105, 99, 95, 76, 97, 98,
  99, 117, 114, 118, 101, 46, 100, 108, 109, 10, 45, 105, 102, 32, 36, 102,
  105, 108, 101, 110, 97, 109, 101, 32, 36, 102, 105, 108, 101, 110, 97, 109,
  101, 32, 45, 101, 108, 115, 101, 32, 40, 48, 44, 45, 49, 44, 49, 50,
  56, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50, 56, 44,
  45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50, 56, 44, 50, 53,
  53, 44, 49, 41, 32, 45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37,
  44, 51, 32, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 76, 97, 98, 99, 117, 114, 118, 101, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 40, 36, 123, 49, 45, 45, 51, 125,
  41, 32, 45, 114, 91, 45, 49, 93, 32, 49, 51, 44, 51, 44, 49, 44,
  49, 44, 45, 49, 32, 45, 111, 91, 45, 49, 93, 32, 64, 123, 45, 112,
  97, 116, 104, 95, 116, 109, 112, 125, 47, 46, 103, 109, 105, 99, 95, 76,
  97, 98, 99, 117, 114, 118, 101, 46, 100, 108, 109, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 102, 117, 110, 99, 116, 105, 111, 110, 49, 100, 32,
  36, 49, 51, 44, 48, 44, 36, 49, 44, 92, 10, 64, 123, 34, 45, 105,
  102, 32, 123, 36, 50, 62, 61, 48, 125, 32, 45, 117, 32, 36, 50, 44,
  36, 51, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92,
  34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45,
  105, 102, 32, 123, 36, 52, 62, 61, 48, 125, 32, 45, 117, 32, 36, 52,
  44, 36, 53, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34,
  92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34,
  45, 105, 102, 32, 123, 36, 54, 62, 61, 48, 125, 32, 45, 117, 32, 36,
  54, 44, 36, 55, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92,
  34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123,
  34, 45, 105, 102, 32, 123, 36, 56, 62, 61, 48, 125, 32, 45, 117, 32,
  36, 56, 44, 36, 57, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32,
  92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64,
  123, 34, 45, 105, 102, 32, 123, 36, 49, 48, 62, 61, 48, 125, 32, 45,
  117, 32, 36, 49, 48, 44, 36, 49, 49, 44, 32, 45, 101, 108, 115, 101,
  32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34,
  125, 92, 10, 50, 53, 53, 44, 36, 49, 50, 10, 45, 102, 117, 110, 99,
  116, 105, 111, 110, 49, 100, 32, 36, 50, 54, 44, 48, 44, 36, 49, 52,
  44, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 49, 53, 62, 61,
  48, 125, 32, 45, 117, 32, 36, 49, 53, 44, 36, 49, 54, 44, 32, 45,
  101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110,
  100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36,
  49, 55, 62, 61, 48, 125, 32, 45, 117, 32, 36, 49, 55, 44, 36, 49,
  56, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34,
  32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105,
  102, 32, 123, 36, 49, 57, 62, 61, 48, 125, 32, 45, 117, 32, 36, 49,
  57, 44, 36, 50, 48, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32,
  92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64,
  123, 34, 45, 105, 102, 32, 123, 36, 50, 49, 62, 61, 48, 125, 32, 45,
  117, 32, 36, 50, 49, 44, 36, 50, 50, 44, 32, 45, 101, 108, 115, 101,
  32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34,
  125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 50, 51, 62, 61,
  48, 125, 32, 45, 117, 32, 36, 50, 51, 44, 36, 50, 52, 44, 32, 45,
  101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110,
  100, 105, 102, 34, 125, 92, 10, 50, 53, 53, 44, 36, 50, 53, 10, 45,
  102, 117, 110, 99, 116, 105, 111, 110, 49, 100, 32, 36, 51, 57, 44, 48,
  44, 36, 50, 55, 44, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36,
  50, 56, 62, 61, 48, 125, 32, 45, 117, 32, 36, 50, 56, 44, 36, 50,
  57, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34,
  32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105,
  102, 32, 123, 36, 51, 48, 62, 61, 48, 125, 32, 45, 117, 32, 36, 51,
  48, 44, 36, 51, 49, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32,
  92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64,
  123, 34, 45, 105, 102, 32, 123, 36, 51, 50, 62, 61, 48, 125, 32, 45,
  117, 32, 36, 51, 50, 44, 36, 51, 51, 44, 32, 45, 101, 108, 115, 101,
  32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34,
  125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 51, 52, 62, 61,
  48, 125, 32, 45, 117, 32, 36, 51, 52, 44, 36, 51, 53, 44, 32, 45,
  101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110,
  100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36,
  51, 54, 62, 61, 48, 125, 32, 45, 117, 32, 36, 51, 54, 44, 36, 51,
  55, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34,
  32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 50, 53, 53, 44, 36,
  51, 56, 10, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 121, 32, 45,
  109, 118, 91, 45, 49, 93, 32, 48, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 123, 64, 35, 45, 49, 125, 10, 45, 45, 103, 105, 109, 112, 95, 115,
  112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 91, 45, 49, 93,
  32, 34, 45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 76, 97,
  98, 99, 117, 114, 118, 101, 32, 48, 34, 44, 36, 45, 49, 10, 45, 97,
  120, 101, 115, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 48, 44, 49, 51, 44, 49, 44, 50, 53, 53, 10, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 32, 45, 97, 120, 101, 115, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 49, 51, 44,
  49, 44, 50, 53, 53, 32, 45, 45, 100, 105, 108, 97, 116, 101, 91, 45,
  49, 93, 32, 51, 32, 45, 114, 91, 45, 50, 93, 32, 91, 45, 51, 93,
  32, 45, 106, 91, 45, 51, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 44, 50, 53, 53, 32,
  45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 103, 114, 105, 100,
  91, 45, 49, 93, 32, 49, 48, 37, 44, 49, 48, 37, 44, 48, 44, 48,
  44, 48, 46, 51, 44, 48, 120, 67, 67, 67, 67, 67, 67, 67, 67, 44,
  50, 53, 53, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 48, 44,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48, 44, 48, 46, 51, 44,
  48, 120, 67, 67, 67, 67, 67, 67, 67, 67, 44, 50, 53, 53, 10, 45,
  105, 102, 32, 36, 45, 50, 10, 91, 45, 49, 93, 44, 91, 45, 49, 93,
  44, 49, 44, 49, 44, 45, 123, 36, 45, 50, 42, 50, 53, 53, 47, 49,
  48, 48, 125, 32, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 51, 93,
  32, 45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 51, 93, 32,
  50, 53, 54, 44, 48, 44, 50, 53, 53, 32, 45, 103, 114, 97, 112, 104,
  91, 45, 49, 93, 32, 91, 45, 51, 93, 44, 51, 44, 48, 44, 48, 44,
  48, 44, 49, 44, 48, 10, 45, 114, 109, 91, 45, 51, 93, 32, 45, 43,
  91, 45, 49, 93, 32, 123, 36, 45, 50, 42, 50, 53, 53, 47, 49, 48,
  48, 125, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 99, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 108, 115, 101, 32,
  45, 114, 109, 91, 45, 50, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  108, 105, 110, 101, 91, 45, 49, 93, 32, 48, 44, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 44, 48, 44, 48, 46, 51, 44, 48, 120, 67, 67, 67,
  67, 67, 67, 67, 67, 44, 50, 53, 53, 10, 45, 115, 104, 91, 48, 93,
  32, 48, 44, 48, 44, 48, 44, 48, 10, 45, 103, 114, 97, 112, 104, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 50, 53, 53,
  44, 48, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  32, 45, 45, 91, 45, 49, 93, 32, 49, 10, 45, 103, 114, 97, 112, 104,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 50, 53,
  53, 44, 48, 44, 48, 46, 53, 44, 50, 48, 48, 44, 50, 48, 48, 44,
  50, 48, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91,
  48, 93, 32, 49, 44, 49, 44, 48, 44, 48, 10, 45, 103, 114, 97, 112,
  104, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 50,
  53, 53, 44, 48, 44, 49, 44, 50, 53, 53, 44, 49, 50, 56, 44, 49,
  50, 56, 32, 45, 45, 91, 45, 49, 93, 32, 49, 10, 45, 103, 114, 97,
  112, 104, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44,
  50, 53, 53, 44, 48, 44, 48, 46, 53, 44, 50, 48, 48, 44, 48, 44,
  48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 48, 93,
  32, 50, 44, 50, 44, 48, 44, 48, 10, 45, 103, 114, 97, 112, 104, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 50, 53, 53,
  44, 48, 44, 49, 44, 49, 50, 56, 44, 49, 50, 56, 44, 50, 53, 53,
  32, 45, 45, 91, 45, 49, 93, 32, 49, 10, 45, 103, 114, 97, 112, 104,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 50, 53,
  53, 44, 48, 44, 48, 46, 53, 44, 48, 44, 48, 44, 50, 48, 48, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 52, 48,
  61, 61, 48, 125, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108,
  121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  48, 44, 36, 49, 44, 48, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112,
  112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 36, 50, 44, 36, 51, 44, 49, 10, 45, 95, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 36, 52, 44, 36, 53, 44, 50, 32, 45, 95, 103,
  105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 36, 54, 44, 36, 55, 44, 51, 10,
  45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114,
  118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 56, 44, 36, 57,
  44, 52, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 49,
  48, 44, 36, 49, 49, 44, 53, 10, 45, 95, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 50, 53, 53, 44, 36, 49, 50, 44, 54, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 52, 48, 61, 61, 49, 125, 10, 45, 95, 103, 105,
  109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 48, 44, 36, 49, 52, 44, 48, 32, 45,
  95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 49, 53, 44, 36, 49,
  54, 44, 49, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121,
  95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36,
  49, 55, 44, 36, 49, 56, 44, 50, 32, 45, 95, 103, 105, 109, 112, 95,
  97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 36, 49, 57, 44, 36, 50, 48, 44, 51, 10, 45, 95,
  103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 50, 49, 44, 36, 50, 50,
  44, 52, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 50,
  51, 44, 36, 50, 52, 44, 53, 10, 45, 95, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 50, 53, 53, 44, 36, 50, 53, 44, 54, 10, 45, 101, 108,
  115, 101, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 48, 44,
  36, 50, 55, 44, 48, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112,
  108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 36, 50, 56, 44, 36, 50, 57, 44, 49, 10, 45, 95, 103, 105, 109,
  112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 36, 51, 48, 44, 36, 51, 49, 44, 50, 32,
  45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114,
  118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 51, 50, 44, 36,
  51, 51, 44, 51, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108,
  121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  36, 51, 52, 44, 36, 51, 53, 44, 52, 32, 45, 95, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 36, 51, 54, 44, 36, 51, 55, 44, 53, 10, 45,
  95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 50, 53, 53, 44, 36, 51,
  56, 44, 54, 10, 45, 101, 110, 100, 105, 102, 10, 45, 109, 118, 91, 45,
  49, 93, 32, 49, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48,
  93, 10, 35, 64, 103, 105, 109, 112, 32, 76, 105, 103, 104, 116, 110, 101,
  115, 115, 32, 58, 32, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  76, 97, 98, 99, 117, 114, 118, 101, 44, 32, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 76, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 116, 97,
  114, 116, 105, 110, 103, 32, 121, 32, 61, 32, 105, 110, 116, 40, 48, 44,
  48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 111, 111,
  114, 100, 40, 49, 41, 32, 61, 32, 105, 110, 116, 40, 45, 49, 44, 45,
  49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  89, 45, 99, 111, 111, 114, 100, 40, 49, 41, 32, 61, 32, 105, 110, 116,
  40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  88, 45, 99, 111, 111, 114, 100, 40, 50, 41, 32, 61, 32, 105, 110, 116,
  40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100, 40, 50, 41, 32,
  61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 88, 45, 99, 111, 111, 114, 100, 40, 51, 41, 32,
  61, 32, 105, 110, 116, 40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114,
  100, 40, 51, 41, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 111, 111, 114,
  100, 40, 52, 41, 32, 61, 32, 105, 110, 116, 40, 45, 49, 44, 45, 49,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89,
  45, 99, 111, 111, 114, 100, 40, 52, 41, 32, 61, 32, 105, 110, 116, 40,
  49, 50, 56, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88,
  45, 99, 111, 111, 114, 100, 40, 53, 41, 32, 61, 32, 105, 110, 116, 40,
  45, 49, 44, 45, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100, 40, 53, 41, 32, 61,
  32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 69, 110, 100, 105, 110, 103, 32, 121, 32, 61, 32, 105,
  110, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 117, 114, 118, 101, 32, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 105, 115, 112, 108,
  97, 121, 32, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117,
  108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60,
  105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101,
  114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 95, 10, 35, 64, 103, 105, 109, 112, 32, 60,
  105, 62, 67, 117, 114, 118, 101, 115, 32, 91, 82, 71, 66, 93, 60, 47,
  105, 62, 10, 35, 64, 103, 105, 109, 112, 32, 66, 108, 117, 101, 32, 58,
  32, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 82, 71, 66, 99,
  117, 114, 118, 101, 44, 32, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121,
  95, 66, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 116, 97, 114, 116, 105, 110,
  103, 32, 121, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 111, 111, 114, 100, 40, 49,
  41, 32, 61, 32, 105, 110, 116, 40, 45, 49, 44, 45, 49, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 111,
  111, 114, 100, 40, 49, 41, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56,
  44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 111,
  111, 114, 100, 40, 50, 41, 32, 61, 32, 105, 110, 116, 40, 45, 49, 44,
  45, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 89, 45, 99, 111, 111, 114, 100, 40, 50, 41, 32, 61, 32, 105, 110,
  116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 88, 45, 99, 111, 111, 114, 100, 40, 51, 41, 32, 61, 32, 105, 110,
  116, 40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100, 40, 51, 41,
  32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 88, 45, 99, 111, 111, 114, 100, 40, 52, 41,
  32, 61, 32, 105, 110, 116, 40, 45, 49, 44, 45, 49, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111,
  114, 100, 40, 52, 41, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44,
  48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 111, 111,
  114, 100, 40, 53, 41, 32, 61, 32, 105, 110, 116, 40, 45, 49, 44, 45,
  49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  89, 45, 99, 111, 111, 114, 100, 40, 53, 41, 32, 61, 32, 105, 110, 116,
  40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  69, 110, 100, 105, 110, 103, 32, 121, 32, 61, 32, 105, 110, 116, 40, 50,
  53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117,
  114, 118, 101, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 68, 105, 115, 112, 108, 97, 121, 32, 104,
  105, 115, 116, 111, 103, 114, 97, 109, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  97, 112, 112, 108, 121, 95, 82, 71, 66, 99, 117, 114, 118, 101, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 49, 10, 45, 103, 105, 109, 112, 95,
  97, 112, 112, 108, 121, 95, 82, 71, 66, 99, 117, 114, 118, 101, 95, 99,
  111, 110, 102, 105, 103, 102, 105, 108, 101, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 64, 35, 45, 49, 125, 32, 45, 108, 91, 36, 62, 44, 45,
  49, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101,
  91, 48, 93, 32, 123, 109, 97, 120, 40, 51, 44, 115, 41, 125, 10, 45,
  115, 104, 91, 48, 93, 32, 48, 44, 48, 32, 45, 95, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 82, 71, 66, 99, 117, 114, 118, 101, 91,
  45, 49, 93, 32, 64, 123, 45, 50, 44, 48, 45, 49, 50, 125, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 48, 93, 32, 49, 44,
  49, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 82,
  71, 66, 99, 117, 114, 118, 101, 91, 45, 49, 93, 32, 64, 123, 45, 50,
  44, 49, 51, 45, 50, 53, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 115, 104, 91, 48, 93, 32, 50, 44, 50, 32, 45, 95, 103, 105, 109,
  112, 95, 97, 112, 112, 108, 121, 95, 82, 71, 66, 99, 117, 114, 118, 101,
  91, 45, 49, 93, 32, 64, 123, 45, 50, 44, 50, 54, 45, 51, 56, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 45, 114, 109, 91, 45, 49, 93, 10, 95, 103, 105,
  109, 112, 95, 97, 112, 112, 108, 121, 95, 82, 71, 66, 99, 117, 114, 118,
  101, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101,
  32, 36, 49, 51, 44, 48, 44, 36, 49, 44, 92, 10, 64, 123, 34, 45,
  105, 102, 32, 123, 36, 50, 62, 61, 48, 125, 32, 45, 117, 32, 36, 50,
  44, 36, 51, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34,
  92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34,
  45, 105, 102, 32, 123, 36, 52, 62, 61, 48, 125, 32, 45, 117, 32, 36,
  52, 44, 36, 53, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92,
  34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123,
  34, 45, 105, 102, 32, 123, 36, 54, 62, 61, 48, 125, 32, 45, 117, 32,
  36, 54, 44, 36, 55, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32,
  92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64,
  123, 34, 45, 105, 102, 32, 123, 36, 56, 62, 61, 48, 125, 32, 45, 117,
  32, 36, 56, 44, 36, 57, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117,
  32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10,
  64, 123, 34, 45, 105, 102, 32, 123, 36, 49, 48, 62, 61, 48, 125, 32,
  45, 117, 32, 36, 49, 48, 44, 36, 49, 49, 44, 32, 45, 101, 108, 115,
  101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102,
  34, 125, 92, 10, 50, 53, 53, 44, 36, 49, 50, 10, 45, 99, 32, 48,
  44, 50, 53, 53, 10, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  82, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 82, 71, 66,
  99, 117, 114, 118, 101, 95, 99, 111, 110, 102, 105, 103, 102, 105, 108, 101,
  10, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48,
  32, 45, 102, 91, 45, 49, 93, 32, 36, 123, 49, 45, 45, 51, 125, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 97, 112,
  112, 108, 121, 95, 82, 71, 66, 99, 117, 114, 118, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 91, 94, 45, 49, 93, 32, 64, 45, 49, 44, 48, 44,
  36, 123, 45, 50, 44, 45, 49, 125, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 71, 99, 117, 114,
  118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 97, 112, 112, 108, 121, 95, 82, 71, 66, 99, 117, 114, 118,
  101, 95, 99, 111, 110, 102, 105, 103, 102, 105, 108, 101, 10, 45, 115, 104,
  91, 45, 49, 93, 32, 49, 44, 49, 44, 48, 44, 48, 32, 45, 102, 91,
  45, 49, 93, 32, 36, 123, 49, 45, 45, 51, 125, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  82, 71, 66, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119,
  91, 94, 45, 49, 93, 32, 64, 45, 49, 44, 49, 44, 36, 123, 45, 50,
  44, 45, 49, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 103, 105, 109,
  112, 95, 97, 112, 112, 108, 121, 95, 66, 99, 117, 114, 118, 101, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 82, 71, 66, 99, 117, 114, 118, 101, 95, 99, 111,
  110, 102, 105, 103, 102, 105, 108, 101, 10, 45, 115, 104, 91, 45, 49, 93,
  32, 50, 44, 50, 44, 48, 44, 48, 32, 45, 102, 91, 45, 49, 93, 32,
  36, 123, 49, 45, 45, 51, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 82, 71, 66, 99,
  117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 91, 94, 45, 49,
  93, 32, 64, 45, 49, 44, 50, 44, 36, 123, 45, 50, 44, 45, 49, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 103, 105, 109, 112, 95, 97, 112,
  112, 108, 121, 95, 82, 71, 66, 99, 117, 114, 118, 101, 95, 99, 111, 110,
  102, 105, 103, 102, 105, 108, 101, 32, 58, 10, 102, 105, 108, 101, 110, 97,
  109, 101, 61, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109, 112, 125, 47,
  46, 103, 109, 105, 99, 95, 82, 71, 66, 99, 117, 114, 118, 101, 46, 100,
  108, 109, 10, 45, 105, 102, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101,
  32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 32, 45, 101, 108, 115, 101,
  32, 40, 48, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50,
  56, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50, 56, 44,
  45, 49, 44, 49, 50, 56, 44, 50, 53, 53, 44, 49, 41, 32, 45, 114,
  91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 51, 32, 45, 101, 110, 100,
  105, 102, 10, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 82, 71,
  66, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 40, 36, 123, 49, 45, 45, 51, 125, 41, 32, 45, 114, 91, 45, 49,
  93, 32, 49, 51, 44, 51, 44, 49, 44, 49, 44, 45, 49, 32, 45, 111,
  91, 45, 49, 93, 32, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109, 112,
  125, 47, 46, 103, 109, 105, 99, 95, 82, 71, 66, 99, 117, 114, 118, 101,
  46, 100, 108, 109, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 102, 117,
  110, 99, 116, 105, 111, 110, 49, 100, 32, 36, 49, 51, 44, 48, 44, 36,
  49, 44, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 50, 62, 61,
  48, 125, 32, 45, 117, 32, 36, 50, 44, 36, 51, 44, 32, 45, 101, 108,
  115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105,
  102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 52, 62,
  61, 48, 125, 32, 45, 117, 32, 36, 52, 44, 36, 53, 44, 32, 45, 101,
  108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100,
  105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 54,
  62, 61, 48, 125, 32, 45, 117, 32, 36, 54, 44, 36, 55, 44, 32, 45,
  101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110,
  100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36,
  56, 62, 61, 48, 125, 32, 45, 117, 32, 36, 56, 44, 36, 57, 44, 32,
  45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101,
  110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123,
  36, 49, 48, 62, 61, 48, 125, 32, 45, 117, 32, 36, 49, 48, 44, 36,
  49, 49, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92,
  34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 50, 53, 53, 44,
  36, 49, 50, 10, 45, 102, 117, 110, 99, 116, 105, 111, 110, 49, 100, 32,
  36, 50, 54, 44, 48, 44, 36, 49, 52, 44, 92, 10, 64, 123, 34, 45,
  105, 102, 32, 123, 36, 49, 53, 62, 61, 48, 125, 32, 45, 117, 32, 36,
  49, 53, 44, 36, 49, 54, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117,
  32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10,
  64, 123, 34, 45, 105, 102, 32, 123, 36, 49, 55, 62, 61, 48, 125, 32,
  45, 117, 32, 36, 49, 55, 44, 36, 49, 56, 44, 32, 45, 101, 108, 115,
  101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102,
  34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 49, 57, 62,
  61, 48, 125, 32, 45, 117, 32, 36, 49, 57, 44, 36, 50, 48, 44, 32,
  45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101,
  110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123,
  36, 50, 49, 62, 61, 48, 125, 32, 45, 117, 32, 36, 50, 49, 44, 36,
  50, 50, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92,
  34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45,
  105, 102, 32, 123, 36, 50, 51, 62, 61, 48, 125, 32, 45, 117, 32, 36,
  50, 51, 44, 36, 50, 52, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117,
  32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10,
  50, 53, 53, 44, 36, 50, 53, 10, 45, 102, 117, 110, 99, 116, 105, 111,
  110, 49, 100, 32, 36, 51, 57, 44, 48, 44, 36, 50, 55, 44, 92, 10,
  64, 123, 34, 45, 105, 102, 32, 123, 36, 50, 56, 62, 61, 48, 125, 32,
  45, 117, 32, 36, 50, 56, 44, 36, 50, 57, 44, 32, 45, 101, 108, 115,
  101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102,
  34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 51, 48, 62,
  61, 48, 125, 32, 45, 117, 32, 36, 51, 48, 44, 36, 51, 49, 44, 32,
  45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101,
  110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123,
  36, 51, 50, 62, 61, 48, 125, 32, 45, 117, 32, 36, 51, 50, 44, 36,
  51, 51, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92,
  34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45,
  105, 102, 32, 123, 36, 51, 52, 62, 61, 48, 125, 32, 45, 117, 32, 36,
  51, 52, 44, 36, 51, 53, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117,
  32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10,
  64, 123, 34, 45, 105, 102, 32, 123, 36, 51, 54, 62, 61, 48, 125, 32,
  45, 117, 32, 36, 51, 54, 44, 36, 51, 55, 44, 32, 45, 101, 108, 115,
  101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102,
  34, 125, 92, 10, 50, 53, 53, 44, 36, 51, 56, 10, 45, 97, 91, 45,
  51, 45, 45, 49, 93, 32, 121, 32, 45, 109, 118, 91, 45, 49, 93, 32,
  48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125,
  10, 45, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 91, 45, 49, 93, 32, 34, 45, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 82, 71, 66, 99, 117, 114, 118, 101, 32,
  48, 34, 44, 36, 45, 49, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  32, 45, 97, 120, 101, 115, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 48, 44, 49, 51, 44, 49, 44, 50, 53, 53, 32,
  45, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 51, 32, 45,
  114, 91, 45, 50, 93, 32, 91, 45, 51, 93, 32, 45, 106, 91, 45, 51,
  93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49,
  44, 91, 45, 49, 93, 44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 50,
  44, 45, 49, 93, 10, 45, 103, 114, 105, 100, 91, 45, 49, 93, 32, 49,
  48, 37, 44, 49, 48, 37, 44, 48, 44, 48, 44, 48, 46, 51, 44, 48,
  120, 67, 67, 67, 67, 67, 67, 67, 67, 44, 50, 53, 53, 10, 45, 108,
  105, 110, 101, 91, 45, 49, 93, 32, 48, 44, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 48, 44, 48, 46, 51, 44, 48, 120, 67, 67, 67, 67,
  67, 67, 67, 67, 44, 50, 53, 53, 10, 45, 105, 102, 32, 36, 45, 50,
  10, 91, 45, 49, 93, 44, 91, 45, 49, 93, 44, 49, 44, 49, 44, 45,
  123, 36, 45, 50, 42, 50, 53, 53, 47, 49, 48, 48, 125, 32, 45, 116,
  111, 95, 103, 114, 97, 121, 91, 45, 51, 93, 32, 45, 104, 105, 115, 116,
  111, 103, 114, 97, 109, 91, 45, 51, 93, 32, 50, 53, 54, 44, 48, 44,
  50, 53, 53, 32, 45, 103, 114, 97, 112, 104, 91, 45, 49, 93, 32, 91,
  45, 51, 93, 44, 51, 44, 48, 44, 48, 44, 48, 44, 49, 44, 48, 10,
  45, 114, 109, 91, 45, 51, 93, 32, 45, 43, 91, 45, 49, 93, 32, 123,
  36, 45, 50, 42, 50, 53, 53, 47, 49, 48, 48, 125, 32, 45, 43, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 10, 45, 101, 108, 115, 101, 32, 45, 114, 109, 91, 45, 50,
  93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 108, 105, 110, 101, 91, 45,
  49, 93, 32, 48, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48,
  44, 48, 46, 51, 44, 48, 120, 67, 67, 67, 67, 67, 67, 67, 67, 44,
  50, 53, 53, 10, 45, 115, 104, 91, 48, 93, 32, 48, 44, 48, 44, 48,
  44, 48, 10, 45, 103, 114, 97, 112, 104, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 44, 49, 44, 48, 44, 50, 53, 53, 44, 48, 44, 49, 44, 50,
  53, 53, 44, 49, 50, 56, 44, 49, 50, 56, 32, 45, 45, 91, 45, 49,
  93, 32, 49, 10, 45, 103, 114, 97, 112, 104, 91, 45, 50, 93, 32, 91,
  45, 49, 93, 44, 49, 44, 48, 44, 50, 53, 53, 44, 48, 44, 48, 46,
  53, 44, 50, 48, 48, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 115, 104, 91, 48, 93, 32, 49, 44, 49, 44, 48, 44, 48,
  10, 45, 103, 114, 97, 112, 104, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  44, 49, 44, 48, 44, 50, 53, 53, 44, 48, 44, 49, 44, 49, 50, 56,
  44, 50, 53, 53, 44, 49, 50, 56, 32, 45, 45, 91, 45, 49, 93, 32,
  49, 10, 45, 103, 114, 97, 112, 104, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 49, 44, 48, 44, 50, 53, 53, 44, 48, 44, 48, 46, 53, 44,
  48, 44, 50, 48, 48, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 115, 104, 91, 48, 93, 32, 50, 44, 50, 44, 48, 44, 48, 10, 45,
  103, 114, 97, 112, 104, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49,
  44, 48, 44, 50, 53, 53, 44, 48, 44, 49, 44, 49, 50, 56, 44, 49,
  50, 56, 44, 50, 53, 53, 32, 45, 45, 91, 45, 49, 93, 32, 49, 10,
  45, 103, 114, 97, 112, 104, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44,
  49, 44, 48, 44, 50, 53, 53, 44, 48, 44, 48, 46, 53, 44, 48, 44,
  48, 44, 50, 48, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 105,
  102, 32, 123, 36, 52, 48, 61, 61, 48, 125, 10, 45, 95, 103, 105, 109,
  112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 48, 44, 36, 49, 44, 48, 32, 45, 95, 103,
  105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 36, 50, 44, 36, 51, 44, 49, 10,
  45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114,
  118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 52, 44, 36, 53,
  44, 50, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 54,
  44, 36, 55, 44, 51, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112,
  108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 36, 56, 44, 36, 57, 44, 52, 32, 45, 95, 103, 105, 109, 112, 95,
  97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 36, 49, 48, 44, 36, 49, 49, 44, 53, 10, 45, 95,
  103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 50, 53, 53, 44, 36, 49, 50,
  44, 54, 10, 45, 101, 108, 105, 102, 32, 123, 36, 52, 48, 61, 61, 49,
  125, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99,
  117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 48, 44, 36,
  49, 52, 44, 48, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108,
  121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  36, 49, 53, 44, 36, 49, 54, 44, 49, 10, 45, 95, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 36, 49, 55, 44, 36, 49, 56, 44, 50, 32, 45,
  95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 49, 57, 44, 36, 50,
  48, 44, 51, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121,
  95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36,
  50, 49, 44, 36, 50, 50, 44, 52, 32, 45, 95, 103, 105, 109, 112, 95,
  97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 36, 50, 51, 44, 36, 50, 52, 44, 53, 10, 45, 95,
  103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 50, 53, 53, 44, 36, 50, 53,
  44, 54, 10, 45, 101, 108, 115, 101, 10, 45, 95, 103, 105, 109, 112, 95,
  97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 48, 44, 36, 50, 55, 44, 48, 32, 45, 95, 103, 105,
  109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 36, 50, 56, 44, 36, 50, 57, 44, 49,
  10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117,
  114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 51, 48, 44,
  36, 51, 49, 44, 50, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112,
  108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 36, 51, 50, 44, 36, 51, 51, 44, 51, 10, 45, 95, 103, 105, 109,
  112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 36, 51, 52, 44, 36, 51, 53, 44, 52, 32,
  45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114,
  118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 51, 54, 44, 36,
  51, 55, 44, 53, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108,
  121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  50, 53, 53, 44, 36, 51, 56, 44, 54, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 109, 118, 91, 45, 49, 93, 32, 49, 32, 45, 100, 111, 110, 101,
  32, 45, 114, 109, 91, 48, 93, 10, 35, 64, 103, 105, 109, 112, 32, 71,
  114, 101, 101, 110, 32, 58, 32, 103, 105, 109, 112, 95, 97, 112, 112, 108,
  121, 95, 82, 71, 66, 99, 117, 114, 118, 101, 44, 32, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 71, 99, 117, 114, 118, 101, 95, 112, 114,
  101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  116, 97, 114, 116, 105, 110, 103, 32, 121, 32, 61, 32, 105, 110, 116, 40,
  48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99,
  111, 111, 114, 100, 40, 49, 41, 32, 61, 32, 105, 110, 116, 40, 45, 49,
  44, 45, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 89, 45, 99, 111, 111, 114, 100, 40, 49, 41, 32, 61, 32, 105,
  110, 116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 45, 99, 111, 111, 114, 100, 40, 50, 41, 32, 61, 32, 105,
  110, 116, 40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100, 40, 50,
  41, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 111, 111, 114, 100, 40, 51,
  41, 32, 61, 32, 105, 110, 116, 40, 45, 49, 44, 45, 49, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 111,
  111, 114, 100, 40, 51, 41, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56,
  44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 111,
  111, 114, 100, 40, 52, 41, 32, 61, 32, 105, 110, 116, 40, 45, 49, 44,
  45, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 89, 45, 99, 111, 111, 114, 100, 40, 52, 41, 32, 61, 32, 105, 110,
  116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 88, 45, 99, 111, 111, 114, 100, 40, 53, 41, 32, 61, 32, 105, 110,
  116, 40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100, 40, 53, 41,
  32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 69, 110, 100, 105, 110, 103, 32, 121, 32, 61,
  32, 105, 110, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 117, 114, 118, 101, 32, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 105, 115,
  112, 108, 97, 121, 32, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109,
  112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50,
  57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 82, 101, 100, 32, 58, 32, 103, 105,
  109, 112, 95, 97, 112, 112, 108, 121, 95, 82, 71, 66, 99, 117, 114, 118,
  101, 44, 32, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 82, 99,
  117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 116, 97, 114, 116, 105, 110, 103, 32, 121,
  32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 88, 45, 99, 111, 111, 114, 100, 40, 49, 41, 32, 61,
  32, 105, 110, 116, 40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100,
  40, 49, 41, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 111, 111, 114, 100,
  40, 50, 41, 32, 61, 32, 105, 110, 116, 40, 45, 49, 44, 45, 49, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45,
  99, 111, 111, 114, 100, 40, 50, 41, 32, 61, 32, 105, 110, 116, 40, 49,
  50, 56, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45,
  99, 111, 111, 114, 100, 40, 51, 41, 32, 61, 32, 105, 110, 116, 40, 45,
  49, 44, 45, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 89, 45, 99, 111, 111, 114, 100, 40, 51, 41, 32, 61, 32,
  105, 110, 116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 88, 45, 99, 111, 111, 114, 100, 40, 52, 41, 32, 61, 32,
  105, 110, 116, 40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100, 40,
  52, 41, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 111, 111, 114, 100, 40,
  53, 41, 32, 61, 32, 105, 110, 116, 40, 45, 49, 44, 45, 49, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99,
  111, 111, 114, 100, 40, 53, 41, 32, 61, 32, 105, 110, 116, 40, 49, 50,
  56, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 110, 100,
  105, 110, 103, 32, 121, 32, 61, 32, 105, 110, 116, 40, 50, 53, 53, 44,
  48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 114, 118, 101,
  32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 68, 105, 115, 112, 108, 97, 121, 32, 104, 105, 115, 116,
  111, 103, 114, 97, 109, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 95,
  10, 35, 64, 103, 105, 109, 112, 32, 60, 105, 62, 67, 117, 114, 118, 101,
  115, 32, 91, 89, 67, 98, 67, 114, 93, 60, 47, 105, 62, 10, 35, 64,
  103, 105, 109, 112, 32, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105,
  110, 97, 110, 99, 101, 32, 58, 32, 103, 105, 109, 112, 95, 97, 112, 112,
  108, 121, 95, 89, 67, 98, 67, 114, 99, 117, 114, 118, 101, 44, 32, 103,
  105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 67, 98, 99, 117, 114, 118,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 116, 97, 114, 116, 105, 110, 103, 32, 121, 32, 61, 32,
  105, 110, 116, 40, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 88, 45, 99, 111, 111, 114, 100, 40, 49, 41, 32, 61, 32, 105, 110,
  116, 40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100, 40, 49, 41,
  32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 88, 45, 99, 111, 111, 114, 100, 40, 50, 41,
  32, 61, 32, 105, 110, 116, 40, 45, 49, 44, 45, 49, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111,
  114, 100, 40, 50, 41, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44,
  48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 111, 111,
  114, 100, 40, 51, 41, 32, 61, 32, 105, 110, 116, 40, 45, 49, 44, 45,
  49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  89, 45, 99, 111, 111, 114, 100, 40, 51, 41, 32, 61, 32, 105, 110, 116,
  40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  88, 45, 99, 111, 111, 114, 100, 40, 52, 41, 32, 61, 32, 105, 110, 116,
  40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100, 40, 52, 41, 32,
  61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 88, 45, 99, 111, 111, 114, 100, 40, 53, 41, 32,
  61, 32, 105, 110, 116, 40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114,
  100, 40, 53, 41, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 110, 100, 105, 110, 103,
  32, 121, 32, 61, 32, 105, 110, 116, 40, 50, 53, 53, 44, 48, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 114, 118, 101, 32, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 68, 105, 115, 112, 108, 97, 121, 32, 104, 105, 115, 116, 111, 103, 114,
  97, 109, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101,
  118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115,
  99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47,
  49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 76, 117, 109, 105,
  110, 97, 110, 99, 101, 32, 58, 32, 103, 105, 109, 112, 95, 97, 112, 112,
  108, 121, 95, 89, 67, 98, 67, 114, 99, 117, 114, 118, 101, 44, 32, 103,
  105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 89, 99, 117, 114, 118, 101,
  95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 116, 97, 114, 116, 105, 110, 103, 32, 121, 32, 61, 32, 105,
  110, 116, 40, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  88, 45, 99, 111, 111, 114, 100, 40, 49, 41, 32, 61, 32, 105, 110, 116,
  40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100, 40, 49, 41, 32,
  61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 88, 45, 99, 111, 111, 114, 100, 40, 50, 41, 32,
  61, 32, 105, 110, 116, 40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114,
  100, 40, 50, 41, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 111, 111, 114,
  100, 40, 51, 41, 32, 61, 32, 105, 110, 116, 40, 45, 49, 44, 45, 49,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89,
  45, 99, 111, 111, 114, 100, 40, 51, 41, 32, 61, 32, 105, 110, 116, 40,
  49, 50, 56, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88,
  45, 99, 111, 111, 114, 100, 40, 52, 41, 32, 61, 32, 105, 110, 116, 40,
  45, 49, 44, 45, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100, 40, 52, 41, 32, 61,
  32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 88, 45, 99, 111, 111, 114, 100, 40, 53, 41, 32, 61,
  32, 105, 110, 116, 40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100,
  40, 53, 41, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 110, 100, 105, 110, 103, 32,
  121, 32, 61, 32, 105, 110, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 117, 114, 118, 101, 32, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  68, 105, 115, 112, 108, 97, 121, 32, 104, 105, 115, 116, 111, 103, 114, 97,
  109, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49,
  50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 82, 101, 100, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 32, 58, 32, 103, 105, 109,
  112, 95, 97, 112, 112, 108, 121, 95, 89, 67, 98, 67, 114, 99, 117, 114,
  118, 101, 44, 32, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 67,
  114, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 116, 97, 114, 116, 105, 110, 103,
  32, 121, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 88, 45, 99, 111, 111, 114, 100, 40, 49, 41,
  32, 61, 32, 105, 110, 116, 40, 45, 49, 44, 45, 49, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111,
  114, 100, 40, 49, 41, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44,
  48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 111, 111,
  114, 100, 40, 50, 41, 32, 61, 32, 105, 110, 116, 40, 45, 49, 44, 45,
  49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  89, 45, 99, 111, 111, 114, 100, 40, 50, 41, 32, 61, 32, 105, 110, 116,
  40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  88, 45, 99, 111, 111, 114, 100, 40, 51, 41, 32, 61, 32, 105, 110, 116,
  40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100, 40, 51, 41, 32,
  61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 88, 45, 99, 111, 111, 114, 100, 40, 52, 41, 32,
  61, 32, 105, 110, 116, 40, 45, 49, 44, 45, 49, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114,
  100, 40, 52, 41, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 111, 111, 114,
  100, 40, 53, 41, 32, 61, 32, 105, 110, 116, 40, 45, 49, 44, 45, 49,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89,
  45, 99, 111, 111, 114, 100, 40, 53, 41, 32, 61, 32, 105, 110, 116, 40,
  49, 50, 56, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69,
  110, 100, 105, 110, 103, 32, 121, 32, 61, 32, 105, 110, 116, 40, 50, 53,
  53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 114,
  118, 101, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 105, 115, 112, 108, 97, 121, 32, 104, 105,
  115, 116, 111, 103, 114, 97, 109, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118,
  105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50,
  51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62,
  50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 89, 67, 98, 67, 114, 99, 117, 114, 118, 101, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 49, 10, 45, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 89, 67, 98, 67, 114, 99, 117, 114, 118,
  101, 95, 99, 111, 110, 102, 105, 103, 102, 105, 108, 101, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 45, 108, 91, 36,
  62, 44, 45, 49, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109,
  111, 100, 101, 91, 48, 93, 32, 123, 109, 97, 120, 40, 51, 44, 115, 41,
  125, 32, 45, 115, 104, 91, 48, 93, 32, 48, 44, 50, 32, 45, 114, 103,
  98, 50, 121, 99, 98, 99, 114, 91, 45, 49, 93, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 115, 104, 91, 48, 93, 32, 48, 44, 48, 32, 45,
  95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 89, 67, 98, 67,
  114, 99, 117, 114, 118, 101, 91, 45, 49, 93, 32, 64, 123, 45, 50, 44,
  48, 45, 49, 50, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115,
  104, 91, 48, 93, 32, 49, 44, 49, 32, 45, 95, 103, 105, 109, 112, 95,
  97, 112, 112, 108, 121, 95, 89, 67, 98, 67, 114, 99, 117, 114, 118, 101,
  91, 45, 49, 93, 32, 64, 123, 45, 50, 44, 49, 51, 45, 50, 53, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 48, 93, 32,
  50, 44, 50, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121,
  95, 89, 67, 98, 67, 114, 99, 117, 114, 118, 101, 91, 45, 49, 93, 32,
  64, 123, 45, 50, 44, 50, 54, 45, 51, 56, 125, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 115, 104, 91, 48, 93, 32, 48, 44, 50, 32, 45,
  121, 99, 98, 99, 114, 50, 114, 103, 98, 91, 45, 49, 93, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 45, 114, 109, 91, 45, 49, 93, 10, 95, 103, 105, 109, 112, 95,
  97, 112, 112, 108, 121, 95, 89, 67, 98, 67, 114, 99, 117, 114, 118, 101,
  32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 32,
  36, 49, 51, 44, 48, 44, 36, 49, 44, 92, 10, 64, 123, 34, 45, 105,
  102, 32, 123, 36, 50, 62, 61, 48, 125, 32, 45, 117, 32, 36, 50, 44,
  36, 51, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92,
  34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45,
  105, 102, 32, 123, 36, 52, 62, 61, 48, 125, 32, 45, 117, 32, 36, 52,
  44, 36, 53, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34,
  92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34,
  45, 105, 102, 32, 123, 36, 54, 62, 61, 48, 125, 32, 45, 117, 32, 36,
  54, 44, 36, 55, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92,
  34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123,
  34, 45, 105, 102, 32, 123, 36, 56, 62, 61, 48, 125, 32, 45, 117, 32,
  36, 56, 44, 36, 57, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32,
  92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64,
  123, 34, 45, 105, 102, 32, 123, 36, 49, 48, 62, 61, 48, 125, 32, 45,
  117, 32, 36, 49, 48, 44, 36, 49, 49, 44, 32, 45, 101, 108, 115, 101,
  32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34,
  125, 92, 10, 50, 53, 53, 44, 36, 49, 50, 10, 45, 99, 32, 48, 44,
  50, 53, 53, 10, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 89,
  99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 89, 67, 98, 67,
  114, 99, 117, 114, 118, 101, 95, 99, 111, 110, 102, 105, 103, 102, 105, 108,
  101, 10, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44,
  48, 32, 45, 102, 91, 45, 49, 93, 32, 36, 123, 49, 45, 45, 51, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 89, 67, 98, 67, 114, 99, 117, 114, 118, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 91, 94, 45, 49, 93, 32, 64, 45, 49,
  44, 48, 44, 36, 123, 45, 50, 44, 45, 49, 125, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 67,
  98, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 89, 67, 98,
  67, 114, 99, 117, 114, 118, 101, 95, 99, 111, 110, 102, 105, 103, 102, 105,
  108, 101, 10, 45, 115, 104, 91, 45, 49, 93, 32, 49, 44, 49, 44, 48,
  44, 48, 32, 45, 102, 91, 45, 49, 93, 32, 36, 123, 49, 45, 45, 51,
  125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95,
  97, 112, 112, 108, 121, 95, 89, 67, 98, 67, 114, 99, 117, 114, 118, 101,
  95, 112, 114, 101, 118, 105, 101, 119, 91, 94, 45, 49, 93, 32, 64, 45,
  49, 44, 49, 44, 36, 123, 45, 50, 44, 45, 49, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  67, 114, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 89, 67,
  98, 67, 114, 99, 117, 114, 118, 101, 95, 99, 111, 110, 102, 105, 103, 102,
  105, 108, 101, 10, 45, 115, 104, 91, 45, 49, 93, 32, 50, 44, 50, 44,
  48, 44, 48, 32, 45, 102, 91, 45, 49, 93, 32, 36, 123, 49, 45, 45,
  51, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 89, 67, 98, 67, 114, 99, 117, 114, 118,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 91, 94, 45, 49, 93, 32, 64,
  45, 49, 44, 50, 44, 36, 123, 45, 50, 44, 45, 49, 125, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121,
  95, 89, 67, 98, 67, 114, 99, 117, 114, 118, 101, 95, 99, 111, 110, 102,
  105, 103, 102, 105, 108, 101, 32, 58, 10, 102, 105, 108, 101, 110, 97, 109,
  101, 61, 64, 123, 45, 112, 97, 116, 104, 95, 116, 109, 112, 125, 47, 46,
  103, 109, 105, 99, 95, 89, 67, 98, 67, 114, 99, 117, 114, 118, 101, 46,
  100, 108, 109, 10, 45, 105, 102, 32, 36, 102, 105, 108, 101, 110, 97, 109,
  101, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 32, 45, 101, 108, 115,
  101, 32, 40, 48, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49,
  50, 56, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50, 56,
  44, 45, 49, 44, 49, 50, 56, 44, 50, 53, 53, 44, 49, 41, 32, 45,
  114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 51, 32, 45, 101, 110,
  100, 105, 102, 10, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 89,
  67, 98, 67, 114, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 40, 36, 123, 49, 45, 45, 51, 125, 41, 32, 45, 114,
  91, 45, 49, 93, 32, 49, 51, 44, 51, 44, 49, 44, 49, 44, 45, 49,
  32, 45, 111, 91, 45, 49, 93, 32, 64, 123, 45, 112, 97, 116, 104, 95,
  116, 109, 112, 125, 47, 46, 103, 109, 105, 99, 95, 89, 67, 98, 67, 114,
  99, 117, 114, 118, 101, 46, 100, 108, 109, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 102, 117, 110, 99, 116, 105, 111, 110, 49, 100, 32, 36, 49,
  51, 44, 48, 44, 36, 49, 44, 92, 10, 64, 123, 34, 45, 105, 102, 32,
  123, 36, 50, 62, 61, 48, 125, 32, 45, 117, 32, 36, 50, 44, 36, 51,
  44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32,
  45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102,
  32, 123, 36, 52, 62, 61, 48, 125, 32, 45, 117, 32, 36, 52, 44, 36,
  53, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34,
  32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105,
  102, 32, 123, 36, 54, 62, 61, 48, 125, 32, 45, 117, 32, 36, 54, 44,
  36, 55, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92,
  34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45,
  105, 102, 32, 123, 36, 56, 62, 61, 48, 125, 32, 45, 117, 32, 36, 56,
  44, 36, 57, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34,
  92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34,
  45, 105, 102, 32, 123, 36, 49, 48, 62, 61, 48, 125, 32, 45, 117, 32,
  36, 49, 48, 44, 36, 49, 49, 44, 32, 45, 101, 108, 115, 101, 32, 45,
  117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92,
  10, 50, 53, 53, 44, 36, 49, 50, 10, 45, 102, 117, 110, 99, 116, 105,
  111, 110, 49, 100, 32, 36, 50, 54, 44, 48, 44, 36, 49, 52, 44, 92,
  10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 49, 53, 62, 61, 48, 125,
  32, 45, 117, 32, 36, 49, 53, 44, 36, 49, 54, 44, 32, 45, 101, 108,
  115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105,
  102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 49, 55,
  62, 61, 48, 125, 32, 45, 117, 32, 36, 49, 55, 44, 36, 49, 56, 44,
  32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45,
  101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32,
  123, 36, 49, 57, 62, 61, 48, 125, 32, 45, 117, 32, 36, 49, 57, 44,
  36, 50, 48, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34,
  92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34,
  45, 105, 102, 32, 123, 36, 50, 49, 62, 61, 48, 125, 32, 45, 117, 32,
  36, 50, 49, 44, 36, 50, 50, 44, 32, 45, 101, 108, 115, 101, 32, 45,
  117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92,
  10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 50, 51, 62, 61, 48, 125,
  32, 45, 117, 32, 36, 50, 51, 44, 36, 50, 52, 44, 32, 45, 101, 108,
  115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105,
  102, 34, 125, 92, 10, 50, 53, 53, 44, 36, 50, 53, 10, 45, 102, 117,
  110, 99, 116, 105, 111, 110, 49, 100, 32, 36, 51, 57, 44, 48, 44, 36,
  50, 55, 44, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 50, 56,
  62, 61, 48, 125, 32, 45, 117, 32, 36, 50, 56, 44, 36, 50, 57, 44,
  32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45,
  101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32,
  123, 36, 51, 48, 62, 61, 48, 125, 32, 45, 117, 32, 36, 51, 48, 44,
  36, 51, 49, 44, 32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34,
  92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92, 10, 64, 123, 34,
  45, 105, 102, 32, 123, 36, 51, 50, 62, 61, 48, 125, 32, 45, 117, 32,
  36, 51, 50, 44, 36, 51, 51, 44, 32, 45, 101, 108, 115, 101, 32, 45,
  117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105, 102, 34, 125, 92,
  10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 51, 52, 62, 61, 48, 125,
  32, 45, 117, 32, 36, 51, 52, 44, 36, 51, 53, 44, 32, 45, 101, 108,
  115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45, 101, 110, 100, 105,
  102, 34, 125, 92, 10, 64, 123, 34, 45, 105, 102, 32, 123, 36, 51, 54,
  62, 61, 48, 125, 32, 45, 117, 32, 36, 51, 54, 44, 36, 51, 55, 44,
  32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 92, 34, 92, 34, 32, 45,
  101, 110, 100, 105, 102, 34, 125, 92, 10, 50, 53, 53, 44, 36, 51, 56,
  10, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 121, 32, 45, 109, 118,
  91, 45, 49, 93, 32, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  64, 35, 45, 49, 125, 10, 45, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 91, 45, 49, 93, 32, 34,
  45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 89, 67, 98, 67,
  114, 99, 117, 114, 118, 101, 32, 48, 34, 44, 36, 45, 49, 10, 45, 97,
  120, 101, 115, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 48, 44, 49, 51, 44, 49, 44, 50, 53, 53, 10, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 32, 45, 97, 120, 101, 115, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 49, 51, 44,
  49, 44, 50, 53, 53, 32, 45, 45, 100, 105, 108, 97, 116, 101, 91, 45,
  49, 93, 32, 51, 32, 45, 114, 91, 45, 50, 93, 32, 91, 45, 51, 93,
  32, 45, 106, 91, 45, 51, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 44, 50, 53, 53, 32,
  45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 103, 114, 105, 100,
  91, 45, 49, 93, 32, 49, 48, 37, 44, 49, 48, 37, 44, 48, 44, 48,
  44, 48, 46, 51, 44, 48, 120, 67, 67, 67, 67, 67, 67, 67, 67, 44,
  50, 53, 53, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 48, 44,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48, 44, 48, 46, 51, 44,
  48, 120, 67, 67, 67, 67, 67, 67, 67, 67, 44, 50, 53, 53, 10, 45,
  105, 102, 32, 36, 45, 50, 10, 91, 45, 49, 93, 44, 91, 45, 49, 93,
  44, 49, 44, 49, 44, 45, 123, 36, 45, 50, 42, 50, 53, 53, 47, 49,
  48, 48, 125, 32, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 51, 93,
  32, 45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 51, 93, 32,
  50, 53, 54, 44, 48, 44, 50, 53, 53, 32, 45, 103, 114, 97, 112, 104,
  91, 45, 49, 93, 32, 91, 45, 51, 93, 44, 51, 44, 48, 44, 48, 44,
  48, 44, 49, 44, 48, 10, 45, 114, 109, 91, 45, 51, 93, 32, 45, 43,
  91, 45, 49, 93, 32, 123, 36, 45, 50, 42, 50, 53, 53, 47, 49, 48,
  48, 125, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 99, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 108, 115, 101, 32,
  45, 114, 109, 91, 45, 50, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  108, 105, 110, 101, 91, 45, 49, 93, 32, 48, 44, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 44, 48, 44, 48, 46, 51, 44, 48, 120, 67, 67, 67,
  67, 67, 67, 67, 67, 44, 50, 53, 53, 10, 45, 115, 104, 91, 48, 93,
  32, 48, 44, 48, 44, 48, 44, 48, 10, 45, 103, 114, 97, 112, 104, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 50, 53, 53,
  44, 48, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  32, 45, 45, 91, 45, 49, 93, 32, 49, 10, 45, 103, 114, 97, 112, 104,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 50, 53,
  53, 44, 48, 44, 48, 46, 53, 44, 50, 48, 48, 44, 50, 48, 48, 44,
  50, 48, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91,
  48, 93, 32, 49, 44, 49, 44, 48, 44, 48, 10, 45, 103, 114, 97, 112,
  104, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 50,
  53, 53, 44, 48, 44, 49, 44, 49, 50, 56, 44, 49, 50, 56, 44, 50,
  53, 53, 32, 45, 45, 91, 45, 49, 93, 32, 49, 10, 45, 103, 114, 97,
  112, 104, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44,
  50, 53, 53, 44, 48, 44, 48, 46, 53, 44, 48, 44, 48, 44, 50, 48,
  48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 48, 93,
  32, 50, 44, 50, 44, 48, 44, 48, 10, 45, 103, 114, 97, 112, 104, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 50, 53, 53,
  44, 48, 44, 49, 44, 50, 53, 53, 44, 49, 50, 56, 44, 49, 50, 56,
  32, 45, 45, 91, 45, 49, 93, 32, 49, 10, 45, 103, 114, 97, 112, 104,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 44, 48, 44, 50, 53,
  53, 44, 48, 44, 48, 46, 53, 44, 50, 48, 48, 44, 48, 44, 48, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 52, 48,
  61, 61, 48, 125, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108,
  121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  48, 44, 36, 49, 44, 48, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112,
  112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 36, 50, 44, 36, 51, 44, 49, 10, 45, 95, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 36, 52, 44, 36, 53, 44, 50, 32, 45, 95, 103,
  105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 36, 54, 44, 36, 55, 44, 51, 10,
  45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114,
  118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 56, 44, 36, 57,
  44, 52, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 49,
  48, 44, 36, 49, 49, 44, 53, 10, 45, 95, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 50, 53, 53, 44, 36, 49, 50, 44, 54, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 52, 48, 61, 61, 49, 125, 10, 45, 95, 103, 105,
  109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 48, 44, 36, 49, 52, 44, 48, 32, 45,
  95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 49, 53, 44, 36, 49,
  54, 44, 49, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121,
  95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36,
  49, 55, 44, 36, 49, 56, 44, 50, 32, 45, 95, 103, 105, 109, 112, 95,
  97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 36, 49, 57, 44, 36, 50, 48, 44, 51, 10, 45, 95,
  103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 50, 49, 44, 36, 50, 50,
  44, 52, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 50,
  51, 44, 36, 50, 52, 44, 53, 10, 45, 95, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 50, 53, 53, 44, 36, 50, 53, 44, 54, 10, 45, 101, 108,
  115, 101, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 48, 44,
  36, 50, 55, 44, 48, 32, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112,
  108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 36, 50, 56, 44, 36, 50, 57, 44, 49, 10, 45, 95, 103, 105, 109,
  112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 36, 51, 48, 44, 36, 51, 49, 44, 50, 32,
  45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114,
  118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 51, 50, 44, 36,
  51, 51, 44, 51, 10, 45, 95, 103, 105, 109, 112, 95, 97, 112, 112, 108,
  121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  36, 51, 52, 44, 36, 51, 53, 44, 52, 32, 45, 95, 103, 105, 109, 112,
  95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 36, 51, 54, 44, 36, 51, 55, 44, 53, 10, 45,
  95, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 50, 53, 53, 44, 36, 51,
  56, 44, 54, 10, 45, 101, 110, 100, 105, 102, 10, 45, 109, 118, 91, 45,
  49, 93, 32, 49, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48,
  93, 10, 35, 64, 103, 105, 109, 112, 32, 95, 10, 35, 64, 103, 105, 109,
  112, 32, 68, 101, 99, 111, 109, 112, 111, 115, 101, 32, 99, 104, 97, 110,
  110, 101, 108, 115, 32, 58, 32, 103, 105, 109, 112, 95, 100, 101, 99, 111,
  109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 44, 32,
  103, 105, 109, 112, 95, 100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 95, 112, 114, 101, 118, 105, 101, 119, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 98,
  97, 115, 105, 115, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 55, 44,
  34, 82, 71, 66, 34, 44, 34, 72, 83, 86, 34, 44, 34, 72, 83, 76,
  34, 44, 34, 72, 83, 73, 34, 44, 34, 89, 85, 86, 34, 44, 34, 89,
  67, 98, 67, 114, 34, 44, 34, 88, 89, 90, 34, 44, 34, 76, 97, 98,
  34, 44, 34, 76, 99, 104, 34, 44, 34, 67, 77, 89, 34, 44, 34, 67,
  77, 89, 75, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  99, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  68, 101, 99, 111, 109, 112, 111, 115, 101, 34, 44, 34, 82, 101, 99, 111,
  109, 112, 111, 115, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 85, 115, 101, 32, 109, 117, 108, 116, 105, 112, 108, 101, 32, 108, 97,
  121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 99, 108, 117, 100, 101, 32,
  111, 112, 97, 99, 105, 116, 121, 32, 108, 97, 121, 101, 114, 32, 61, 32,
  98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32,
  60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112,
  101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  103, 105, 109, 112, 95, 100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 58, 10, 45, 105, 102, 32, 123, 33,
  36, 50, 125, 10, 45, 105, 102, 32, 36, 52, 32, 45, 116, 111, 95, 114,
  103, 98, 97, 32, 45, 101, 108, 115, 101, 32, 45, 116, 111, 95, 114, 103,
  98, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 45, 49, 93, 10, 45, 115, 112, 108, 105,
  116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 95, 103, 105, 109, 112,
  95, 100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110,
  101, 108, 115, 36, 49, 91, 48, 93, 10, 45, 115, 91, 48, 93, 32, 99,
  32, 45, 105, 102, 32, 123, 33, 36, 51, 125, 32, 45, 97, 32, 120, 32,
  45, 101, 110, 100, 105, 102, 10, 110, 98, 61, 64, 35, 10, 45, 101, 110,
  100, 108, 32, 45, 109, 118, 91, 45, 36, 110, 98, 45, 45, 49, 93, 32,
  48, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 115, 101, 10, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 48, 32, 110, 98, 99, 61, 123, 51,
  43, 40, 36, 49, 61, 61, 49, 48, 41, 125, 32, 110, 98, 61, 123, 36,
  110, 98, 99, 43, 36, 52, 125, 10, 45, 105, 102, 32, 36, 51, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 36,
  110, 98, 41, 125, 32, 45, 108, 91, 48, 45, 123, 36, 110, 98, 45, 49,
  125, 93, 10, 45, 97, 91, 48, 45, 123, 36, 110, 98, 99, 45, 49, 125,
  93, 32, 99, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 99, 111, 109,
  112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 36, 49, 91,
  48, 93, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 109,
  118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 45, 101,
  108, 115, 101, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 115, 32, 120, 44, 36, 110, 98, 32, 45,
  97, 91, 48, 45, 123, 36, 110, 98, 99, 45, 49, 125, 93, 32, 99, 32,
  45, 95, 103, 105, 109, 112, 95, 114, 101, 99, 111, 109, 112, 111, 115, 101,
  95, 99, 104, 97, 110, 110, 101, 108, 115, 36, 49, 91, 48, 93, 32, 45,
  97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 109, 118, 91, 45, 49,
  93, 32, 48, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 100, 101, 99,
  111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101,
  108, 115, 32, 36, 123, 94, 48, 125, 32, 45, 97, 112, 112, 101, 110, 100,
  95, 116, 105, 108, 101, 115, 32, 44, 10, 95, 103, 105, 109, 112, 95, 100,
  101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 48, 32, 58, 10, 95, 103, 105, 109, 112, 95, 100, 101, 99, 111, 109,
  112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 49, 32, 58,
  32, 45, 114, 103, 98, 50, 104, 115, 118, 56, 10, 95, 103, 105, 109, 112,
  95, 100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110,
  101, 108, 115, 50, 32, 58, 32, 45, 114, 103, 98, 50, 104, 115, 108, 56,
  10, 95, 103, 105, 109, 112, 95, 100, 101, 99, 111, 109, 112, 111, 115, 101,
  95, 99, 104, 97, 110, 110, 101, 108, 115, 51, 32, 58, 32, 45, 114, 103,
  98, 50, 104, 115, 105, 56, 10, 95, 103, 105, 109, 112, 95, 100, 101, 99,
  111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 52,
  32, 58, 32, 45, 114, 103, 98, 50, 121, 117, 118, 56, 10, 95, 103, 105,
  109, 112, 95, 100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97,
  110, 110, 101, 108, 115, 53, 32, 58, 32, 45, 114, 103, 98, 50, 121, 99,
  98, 99, 114, 10, 95, 103, 105, 109, 112, 95, 100, 101, 99, 111, 109, 112,
  111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 54, 32, 58, 32,
  45, 114, 103, 98, 50, 120, 121, 122, 56, 10, 95, 103, 105, 109, 112, 95,
  100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101,
  108, 115, 55, 32, 58, 32, 45, 114, 103, 98, 50, 108, 97, 98, 56, 10,
  95, 103, 105, 109, 112, 95, 100, 101, 99, 111, 109, 112, 111, 115, 101, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 56, 32, 58, 32, 45, 114, 103, 98,
  50, 108, 99, 104, 56, 10, 95, 103, 105, 109, 112, 95, 100, 101, 99, 111,
  109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 57, 32,
  58, 32, 45, 114, 103, 98, 50, 99, 109, 121, 10, 95, 103, 105, 109, 112,
  95, 100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110,
  101, 108, 115, 49, 48, 32, 58, 32, 45, 114, 103, 98, 50, 99, 109, 121,
  107, 10, 95, 103, 105, 109, 112, 95, 114, 101, 99, 111, 109, 112, 111, 115,
  101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 48, 32, 58, 10, 95, 103,
  105, 109, 112, 95, 114, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104,
  97, 110, 110, 101, 108, 115, 49, 32, 58, 32, 45, 104, 115, 118, 56, 50,
  114, 103, 98, 10, 95, 103, 105, 109, 112, 95, 114, 101, 99, 111, 109, 112,
  111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 50, 32, 58, 32,
  45, 104, 115, 108, 56, 50, 114, 103, 98, 10, 95, 103, 105, 109, 112, 95,
  114, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101,
  108, 115, 51, 32, 58, 32, 45, 104, 115, 105, 56, 50, 114, 103, 98, 10,
  95, 103, 105, 109, 112, 95, 114, 101, 99, 111, 109, 112, 111, 115, 101, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 52, 32, 58, 32, 45, 121, 117, 118,
  56, 50, 114, 103, 98, 10, 95, 103, 105, 109, 112, 95, 114, 101, 99, 111,
  109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 53, 32,
  58, 32, 45, 121, 99, 98, 99, 114, 50, 114, 103, 98, 10, 95, 103, 105,
  109, 112, 95, 114, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97,
  110, 110, 101, 108, 115, 54, 32, 58, 32, 45, 120, 121, 122, 56, 50, 114,
  103, 98, 10, 95, 103, 105, 109, 112, 95, 114, 101, 99, 111, 109, 112, 111,
  115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 55, 32, 58, 32, 45,
  108, 97, 98, 56, 50, 114, 103, 98, 10, 95, 103, 105, 109, 112, 95, 114,
  101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 56, 32, 58, 32, 45, 108, 99, 104, 56, 50, 114, 103, 98, 10, 95,
  103, 105, 109, 112, 95, 114, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 57, 32, 58, 32, 45, 99, 109, 121, 50,
  114, 103, 98, 10, 95, 103, 105, 109, 112, 95, 114, 101, 99, 111, 109, 112,
  111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 49, 48, 32, 58,
  32, 45, 99, 109, 121, 107, 50, 114, 103, 98, 10, 35, 64, 103, 105, 109,
  112, 32, 68, 101, 116, 101, 99, 116, 32, 115, 107, 105, 110, 32, 58, 32,
  103, 105, 109, 112, 95, 100, 101, 116, 101, 99, 116, 95, 115, 107, 105, 110,
  44, 32, 103, 105, 109, 112, 95, 100, 101, 116, 101, 99, 116, 95, 115, 107,
  105, 110, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 107, 105, 110, 32, 101, 115, 116, 105,
  109, 97, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  49, 44, 34, 77, 97, 110, 117, 97, 108, 34, 44, 34, 65, 117, 116, 111,
  109, 97, 116, 105, 99, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 111, 108, 101,
  114, 97, 110, 99, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 53, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 45, 110, 111, 114, 109,
  97, 108, 105, 122, 101, 32, 105, 109, 97, 103, 101, 32, 61, 32, 98, 111,
  111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98,
  62, 77, 97, 110, 117, 97, 108, 32, 101, 115, 116, 105, 109, 97, 116, 105,
  111, 110, 58, 60, 47, 98, 62, 92, 110, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 85, 115, 101, 32, 116, 104, 101, 32, 115, 108, 105, 100, 101,
  114, 115, 32, 98, 101, 108, 111, 119, 32, 116, 111, 32, 116, 97, 114, 103,
  101, 116, 32, 97, 115, 32, 109, 117, 99, 104, 32, 115, 107, 105, 110, 32,
  112, 105, 120, 101, 108, 115, 32, 97, 115, 32, 121, 111, 117, 32, 99, 97,
  110, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 88, 45, 99, 111, 111, 114, 100, 105, 110, 97,
  116, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45,
  99, 111, 111, 114, 100, 105, 110, 97, 116, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 82, 97, 100, 105, 117, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 53, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 79, 117, 116, 112, 117, 116, 32, 109, 111, 100, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 49, 44, 34, 80, 114, 111, 98, 97, 98, 105,
  108, 105, 116, 121, 32, 109, 97, 112, 34, 44, 34, 79, 112, 97, 113, 117,
  101, 32, 115, 107, 105, 110, 34, 44, 34, 84, 114, 97, 110, 115, 112, 97,
  114, 101, 110, 116, 32, 115, 107, 105, 110, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32,
  116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70,
  117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116,
  101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68,
  117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68,
  97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38,
  35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 48, 51, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112,
  95, 100, 101, 116, 101, 99, 116, 95, 115, 107, 105, 110, 32, 58, 10, 45,
  116, 111, 95, 114, 103, 98, 10, 45, 109, 32, 34, 95, 103, 105, 109, 112,
  95, 100, 101, 116, 101, 99, 116, 95, 115, 107, 105, 110, 32, 58, 10, 45,
  105, 102, 32, 36, 53, 32, 45, 98, 97, 108, 97, 110, 99, 101, 95, 103,
  97, 109, 109, 97, 32, 49, 50, 56, 44, 49, 50, 56, 44, 49, 50, 56,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 49, 32, 45,
  100, 101, 116, 101, 99, 116, 95, 115, 107, 105, 110, 32, 36, 50, 32, 45,
  101, 108, 115, 101, 32, 45, 100, 101, 116, 101, 99, 116, 95, 115, 107, 105,
  110, 32, 36, 50, 44, 36, 54, 37, 44, 36, 55, 37, 44, 36, 56, 37,
  32, 45, 101, 110, 100, 105, 102, 10, 77, 61, 123, 105, 77, 125, 32, 45,
  98, 32, 36, 51, 37, 32, 45, 42, 32, 123, 50, 53, 53, 42, 36, 77,
  47, 105, 77, 125, 32, 45, 42, 32, 36, 52, 32, 45, 99, 32, 48, 44,
  50, 53, 53, 34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 36, 57, 10, 45, 45,
  95, 103, 105, 109, 112, 95, 100, 101, 116, 101, 99, 116, 95, 115, 107, 105,
  110, 32, 45, 97, 32, 99, 10, 45, 105, 102, 32, 123, 36, 57, 62, 49,
  125, 32, 45, 115, 104, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32,
  45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 43, 91, 45, 49, 93,
  32, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 108, 115, 101, 32, 45, 95, 103, 105, 109, 112,
  95, 100, 101, 116, 101, 99, 116, 95, 115, 107, 105, 110, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  45, 117, 110, 99, 111, 109, 109, 97, 110, 100, 32, 95, 103, 105, 109, 112,
  95, 100, 101, 116, 101, 99, 116, 95, 115, 107, 105, 110, 10, 103, 105, 109,
  112, 95, 100, 101, 116, 101, 99, 116, 95, 115, 107, 105, 110, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112,
  108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105,
  109, 112, 95, 100, 101, 116, 101, 99, 116, 95, 115, 107, 105, 110, 32, 36,
  42, 34, 44, 36, 45, 49, 10, 45, 105, 102, 32, 123, 33, 36, 49, 125,
  10, 45, 99, 105, 114, 99, 108, 101, 32, 36, 54, 37, 44, 36, 55, 37,
  44, 36, 56, 37, 44, 48, 46, 51, 44, 48, 44, 50, 53, 53, 44, 48,
  44, 50, 53, 53, 10, 45, 99, 105, 114, 99, 108, 101, 32, 36, 54, 37,
  44, 36, 55, 37, 44, 36, 56, 37, 44, 49, 44, 48, 120, 70, 70, 70,
  70, 70, 70, 70, 70, 44, 48, 44, 50, 53, 53, 44, 48, 44, 50, 53,
  53, 10, 45, 108, 105, 110, 101, 32, 123, 36, 54, 45, 48, 46, 50, 53,
  42, 36, 56, 125, 37, 44, 123, 36, 55, 45, 48, 46, 50, 53, 42, 36,
  56, 125, 37, 44, 123, 36, 54, 43, 48, 46, 50, 53, 42, 36, 56, 125,
  37, 44, 123, 36, 55, 43, 48, 46, 50, 53, 42, 36, 56, 125, 37, 44,
  49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 50, 53, 53, 10,
  45, 108, 105, 110, 101, 32, 123, 36, 54, 43, 48, 46, 50, 53, 42, 36,
  56, 125, 37, 44, 123, 36, 55, 45, 48, 46, 50, 53, 42, 36, 56, 125,
  37, 44, 123, 36, 54, 45, 48, 46, 50, 53, 42, 36, 56, 125, 37, 44,
  123, 36, 55, 43, 48, 46, 50, 53, 42, 36, 56, 125, 37, 44, 49, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 50, 53, 53, 10, 45, 101,
  110, 100, 105, 102, 10, 35, 64, 103, 105, 109, 112, 32, 69, 113, 117, 97,
  108, 105, 122, 101, 32, 72, 83, 86, 32, 58, 32, 103, 105, 109, 112, 95,
  104, 115, 118, 95, 101, 113, 117, 97, 108, 105, 122, 101, 114, 44, 32, 103,
  105, 109, 112, 95, 104, 115, 118, 95, 101, 113, 117, 97, 108, 105, 122, 101,
  114, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 80, 114, 101, 118, 105, 101, 119, 32, 98, 97, 110, 100, 115,
  32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108, 115, 101, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 72, 117, 101, 32, 98, 97, 110, 100, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 56, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 66, 97, 110, 100, 32, 119, 105, 100,
  116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 48, 44, 49, 44,
  51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 117,
  101, 32, 115, 104, 105, 102, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 45, 49, 56, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 32,
  99, 111, 114, 114, 101, 99, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 45, 48, 46, 57, 57, 44, 48, 46, 57, 57, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108, 117, 101, 32,
  99, 111, 114, 114, 101, 99, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 45, 48, 46, 57, 57, 44, 48, 46, 57, 57, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 72, 117, 101, 32, 98, 97, 110, 100, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 56, 48, 44, 48, 44, 51, 54, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 97, 110, 100, 32, 119,
  105, 100, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 48, 44,
  49, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  72, 117, 101, 32, 115, 104, 105, 102, 116, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 45, 49, 56, 48, 44, 49, 56, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 97, 116, 117, 114, 97, 116, 105, 111,
  110, 32, 99, 111, 114, 114, 101, 99, 116, 105, 111, 110, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 45, 48, 46, 57, 57, 44, 48, 46, 57,
  57, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108, 117,
  101, 32, 99, 111, 114, 114, 101, 99, 116, 105, 111, 110, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 45, 48, 46, 57, 57, 44, 48, 46, 57,
  57, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 72, 117, 101, 32, 98, 97, 110, 100, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 56, 48, 44, 48, 44, 51, 54,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 97, 110, 100,
  32, 119, 105, 100, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52,
  48, 44, 49, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 72, 117, 101, 32, 115, 104, 105, 102, 116, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 49, 56, 48, 44, 49, 56, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 97, 116, 117, 114, 97, 116,
  105, 111, 110, 32, 99, 111, 114, 114, 101, 99, 116, 105, 111, 110, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 48, 46, 57, 57, 44, 48,
  46, 57, 57, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97,
  108, 117, 101, 32, 99, 111, 114, 114, 101, 99, 116, 105, 111, 110, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 48, 46, 57, 57, 44, 48,
  46, 57, 57, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 58, 32, 60, 105, 62, 74, 38, 35, 50, 51, 51, 59, 114,
  111, 109, 101, 32, 70, 101, 114, 114, 97, 114, 105, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48, 49, 47,
  49, 52, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 108, 105, 110, 107, 40, 34, 70, 105, 108, 116, 101, 114, 32, 101,
  120, 112, 108, 97, 105, 110, 101, 100, 32, 104, 101, 114, 101, 34, 44, 34,
  104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 102, 108, 105, 99, 107,
  114, 46, 99, 111, 109, 47, 103, 114, 111, 117, 112, 115, 47, 103, 109, 105,
  99, 47, 100, 105, 115, 99, 117, 115, 115, 47, 55, 50, 49, 53, 55, 54,
  50, 53, 55, 57, 56, 53, 51, 51, 52, 56, 50, 34, 41, 10, 103, 105,
  109, 112, 95, 104, 115, 118, 95, 101, 113, 117, 97, 108, 105, 122, 101, 114,
  32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  111, 99, 97, 108, 91, 64, 123, 62, 44, 45, 49, 125, 93, 10, 45, 116,
  111, 95, 114, 103, 98, 32, 45, 114, 103, 98, 50, 104, 115, 118, 32, 45,
  115, 112, 108, 105, 116, 32, 99, 10, 45, 45, 102, 91, 48, 93, 32, 105,
  102, 40, 97, 98, 115, 40, 105, 45, 36, 50, 41, 60, 36, 51, 47, 50,
  124, 97, 98, 115, 40, 105, 45, 36, 50, 45, 51, 54, 48, 41, 60, 36,
  51, 47, 50, 124, 97, 98, 115, 40, 105, 45, 36, 50, 43, 51, 54, 48,
  41, 60, 36, 51, 47, 50, 44, 49, 44, 48, 41, 10, 45, 45, 102, 91,
  48, 93, 32, 105, 102, 40, 97, 98, 115, 40, 105, 45, 36, 55, 41, 60,
  36, 56, 47, 50, 124, 97, 98, 115, 40, 105, 45, 36, 55, 45, 51, 54,
  48, 41, 60, 36, 56, 47, 50, 124, 97, 98, 115, 40, 105, 45, 36, 55,
  43, 51, 54, 48, 41, 60, 36, 56, 47, 50, 44, 49, 44, 48, 41, 10,
  45, 45, 102, 91, 48, 93, 32, 105, 102, 40, 97, 98, 115, 40, 105, 45,
  36, 49, 50, 41, 60, 36, 49, 51, 47, 50, 124, 97, 98, 115, 40, 105,
  45, 36, 49, 50, 45, 51, 54, 48, 41, 60, 36, 49, 51, 47, 50, 124,
  97, 98, 115, 40, 105, 45, 36, 49, 50, 43, 51, 54, 48, 41, 60, 36,
  49, 51, 47, 50, 44, 49, 44, 48, 41, 10, 45, 45, 116, 104, 114, 101,
  115, 104, 111, 108, 100, 91, 49, 44, 50, 93, 32, 48, 46, 48, 49, 32,
  45, 42, 91, 45, 49, 44, 45, 50, 93, 32, 91, 45, 49, 93, 120, 50,
  32, 45, 42, 91, 45, 49, 44, 51, 93, 32, 45, 42, 91, 45, 49, 44,
  52, 93, 32, 45, 42, 91, 45, 49, 44, 53, 93, 10, 45, 45, 42, 91,
  51, 93, 32, 36, 52, 32, 45, 45, 42, 91, 52, 93, 32, 36, 57, 32,
  45, 45, 42, 91, 53, 93, 32, 36, 49, 52, 32, 45, 43, 91, 45, 49,
  44, 45, 50, 44, 45, 51, 93, 10, 45, 43, 91, 45, 49, 44, 48, 93,
  32, 45, 37, 91, 48, 93, 32, 51, 54, 48, 10, 45, 105, 102, 32, 123,
  36, 53, 62, 61, 48, 125, 32, 45, 45, 42, 91, 51, 93, 32, 45, 36,
  53, 32, 45, 101, 108, 115, 101, 32, 45, 45, 42, 91, 51, 93, 32, 123,
  49, 47, 40, 49, 43, 36, 53, 41, 45, 49, 125, 32, 45, 101, 110, 100,
  105, 102, 32, 45, 43, 91, 45, 49, 93, 32, 49, 10, 45, 105, 102, 32,
  123, 36, 49, 48, 62, 61, 48, 125, 32, 45, 45, 42, 91, 52, 93, 32,
  45, 36, 49, 48, 32, 45, 101, 108, 115, 101, 32, 45, 45, 42, 91, 52,
  93, 32, 123, 49, 47, 40, 49, 43, 36, 49, 48, 41, 45, 49, 125, 32,
  45, 101, 110, 100, 105, 102, 32, 45, 43, 91, 45, 49, 93, 32, 49, 10,
  45, 105, 102, 32, 123, 36, 49, 53, 62, 61, 48, 125, 32, 45, 45, 42,
  91, 53, 93, 32, 45, 36, 49, 53, 32, 45, 101, 108, 115, 101, 32, 45,
  45, 42, 91, 53, 93, 32, 123, 49, 47, 40, 49, 43, 36, 49, 53, 41,
  45, 49, 125, 32, 45, 101, 110, 100, 105, 102, 32, 45, 43, 91, 45, 49,
  93, 32, 49, 10, 45, 42, 91, 45, 49, 44, 45, 50, 44, 45, 51, 93,
  32, 45, 94, 91, 49, 44, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36,
  54, 62, 61, 48, 125, 32, 45, 45, 42, 91, 51, 93, 32, 45, 36, 54,
  32, 45, 101, 108, 115, 101, 32, 45, 45, 42, 91, 51, 93, 32, 123, 49,
  47, 40, 49, 43, 36, 54, 41, 45, 49, 125, 32, 45, 101, 110, 100, 105,
  102, 32, 45, 43, 91, 45, 49, 93, 32, 49, 10, 45, 105, 102, 32, 123,
  36, 49, 49, 62, 61, 48, 125, 32, 45, 45, 42, 91, 52, 93, 32, 45,
  36, 49, 49, 32, 45, 101, 108, 115, 101, 32, 45, 45, 42, 91, 52, 93,
  32, 123, 49, 47, 40, 49, 43, 36, 49, 49, 41, 45, 49, 125, 32, 45,
  101, 110, 100, 105, 102, 32, 45, 43, 91, 45, 49, 93, 32, 49, 10, 45,
  105, 102, 32, 123, 36, 49, 54, 62, 61, 48, 125, 32, 45, 45, 42, 91,
  53, 93, 32, 45, 36, 49, 54, 32, 45, 101, 108, 115, 101, 32, 45, 45,
  42, 91, 53, 93, 32, 123, 49, 47, 40, 49, 43, 36, 49, 54, 41, 45,
  49, 125, 32, 45, 101, 110, 100, 105, 102, 32, 45, 43, 91, 45, 49, 93,
  32, 49, 10, 45, 42, 91, 45, 49, 44, 45, 50, 44, 45, 51, 93, 32,
  45, 94, 91, 50, 44, 45, 49, 93, 10, 45, 114, 109, 91, 51, 44, 52,
  44, 53, 93, 32, 45, 97, 112, 112, 101, 110, 100, 91, 48, 44, 49, 44,
  50, 93, 32, 99, 32, 45, 104, 115, 118, 50, 114, 103, 98, 10, 45, 101,
  110, 100, 108, 111, 99, 97, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105,
  109, 112, 95, 104, 115, 118, 95, 101, 113, 117, 97, 108, 105, 122, 101, 114,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 108, 111, 99, 97,
  108, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48,
  125, 32, 45, 103, 105, 109, 112, 95, 104, 115, 118, 95, 101, 113, 117, 97,
  108, 105, 122, 101, 114, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36,
  52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 44, 36, 57,
  44, 36, 49, 48, 44, 36, 49, 49, 44, 36, 49, 50, 44, 36, 49, 51,
  44, 36, 49, 52, 44, 36, 49, 53, 44, 36, 49, 54, 10, 45, 101, 108,
  115, 101, 10, 45, 116, 111, 95, 114, 103, 98, 32, 45, 114, 103, 98, 50,
  104, 115, 118, 32, 45, 115, 112, 108, 105, 116, 32, 99, 10, 40, 48, 44,
  51, 53, 57, 41, 32, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 44, 123, 64, 123, 48, 44, 104, 125, 47, 49, 48,
  125, 44, 49, 44, 49, 44, 51, 32, 91, 45, 49, 93, 32, 45, 102, 91,
  45, 49, 93, 32, 49, 10, 45, 106, 91, 48, 93, 32, 91, 51, 93, 44,
  48, 44, 57, 49, 37, 32, 45, 106, 91, 49, 93, 32, 91, 52, 93, 44,
  48, 44, 57, 49, 37, 32, 45, 106, 91, 50, 93, 32, 91, 52, 93, 44,
  48, 44, 57, 49, 37, 32, 45, 114, 109, 91, 45, 49, 44, 45, 50, 93,
  10, 45, 45, 102, 91, 48, 93, 32, 105, 102, 40, 97, 98, 115, 40, 105,
  45, 36, 50, 41, 60, 36, 51, 47, 50, 124, 97, 98, 115, 40, 105, 45,
  36, 50, 45, 51, 54, 48, 41, 60, 36, 51, 47, 50, 124, 97, 98, 115,
  40, 105, 45, 36, 50, 43, 51, 54, 48, 41, 60, 36, 51, 47, 50, 44,
  49, 44, 48, 41, 10, 45, 45, 102, 91, 48, 93, 32, 105, 102, 40, 97,
  98, 115, 40, 105, 45, 36, 55, 41, 60, 36, 56, 47, 50, 124, 97, 98,
  115, 40, 105, 45, 36, 55, 45, 51, 54, 48, 41, 60, 36, 56, 47, 50,
  124, 97, 98, 115, 40, 105, 45, 36, 55, 43, 51, 54, 48, 41, 60, 36,
  56, 47, 50, 44, 49, 44, 48, 41, 10, 45, 45, 102, 91, 48, 93, 32,
  105, 102, 40, 97, 98, 115, 40, 105, 45, 36, 49, 50, 41, 60, 36, 49,
  51, 47, 50, 124, 97, 98, 115, 40, 105, 45, 36, 49, 50, 45, 51, 54,
  48, 41, 60, 36, 49, 51, 47, 50, 124, 97, 98, 115, 40, 105, 45, 36,
  49, 50, 43, 51, 54, 48, 41, 60, 36, 49, 51, 47, 50, 44, 49, 44,
  48, 41, 10, 45, 111, 114, 91, 45, 51, 45, 45, 49, 93, 32, 45, 43,
  91, 45, 49, 93, 32, 48, 46, 51, 51, 32, 45, 47, 91, 45, 49, 93,
  32, 49, 46, 51, 51, 10, 45, 42, 91, 50, 44, 45, 49, 93, 32, 45,
  97, 112, 112, 101, 110, 100, 32, 99, 32, 45, 104, 115, 118, 50, 114, 103,
  98, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 111, 99,
  97, 108, 10, 35, 64, 103, 105, 109, 112, 32, 72, 83, 76, 32, 97, 100,
  106, 117, 115, 116, 109, 101, 110, 116, 32, 58, 32, 103, 99, 100, 95, 104,
  115, 108, 44, 32, 103, 99, 100, 95, 104, 115, 108, 95, 112, 114, 101, 118,
  105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 92, 110, 60,
  105, 62, 73, 110, 112, 117, 116, 32, 83, 97, 116, 117, 114, 97, 116, 105,
  111, 110, 32, 83, 101, 116, 116, 105, 110, 103, 115, 60, 47, 105, 62, 34,
  41, 44, 32, 115, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111,
  110, 116, 114, 97, 115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76,
  101, 118, 101, 108, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45,
  49, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 117,
  116, 111, 32, 114, 101, 100, 117, 99, 101, 32, 108, 101, 118, 101, 108, 32,
  40, 108, 101, 118, 101, 108, 32, 115, 108, 105, 100, 101, 114, 32, 105, 115,
  32, 100, 105, 115, 97, 98, 108, 101, 100, 41, 32, 61, 32, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 92, 110, 60, 105, 62,
  79, 117, 116, 112, 117, 116, 32, 72, 117, 101, 32, 83, 101, 116, 116, 105,
  110, 103, 115, 60, 47, 105, 62, 34, 41, 44, 32, 115, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 72, 117, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 56, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 65, 109, 111, 117, 110, 116, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 50, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 65, 117, 116, 111, 32, 115, 101, 116, 32,
  104, 117, 101, 32, 105, 110, 118, 101, 114, 115, 101, 32, 40, 104, 117, 101,
  32, 115, 108, 105, 100, 101, 114, 32, 105, 115, 32, 100, 105, 115, 97, 98,
  108, 101, 100, 41, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 92, 110, 60, 105, 62, 79, 117, 116, 112, 117, 116,
  32, 76, 117, 109, 105, 110, 97, 110, 99, 101, 32, 83, 101, 116, 116, 105,
  110, 103, 115, 60, 47, 105, 62, 34, 41, 44, 32, 115, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 71, 97, 109, 109, 97, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32,
  116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70,
  117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58,
  32, 60, 105, 62, 71, 97, 114, 97, 103, 101, 99, 111, 100, 101, 114, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49,
  50, 47, 48, 57, 47, 51, 48, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 103, 99, 100, 95, 104, 115, 108, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 125, 44, 36, 123,
  50, 61, 48, 125, 44, 36, 123, 51, 61, 48, 125, 44, 36, 123, 52, 61,
  49, 56, 48, 125, 44, 36, 123, 53, 61, 48, 46, 50, 125, 44, 36, 123,
  54, 61, 48, 125, 44, 36, 123, 55, 61, 49, 125, 44, 36, 123, 56, 61,
  49, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 45, 49, 93, 10, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 32,
  45, 114, 103, 98, 50, 104, 115, 118, 91, 48, 93, 10, 45, 105, 102, 32,
  36, 54, 10, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48, 93,
  32, 48, 10, 45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 49,
  93, 32, 51, 54, 48, 44, 48, 44, 51, 54, 48, 10, 104, 117, 101, 61,
  123, 40, 120, 77, 43, 49, 56, 48, 41, 37, 51, 54, 48, 125, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 115, 101, 32, 104, 117, 101,
  61, 36, 52, 32, 45, 101, 110, 100, 105, 102, 10, 45, 115, 104, 91, 48,
  93, 32, 49, 44, 49, 10, 45, 105, 102, 32, 36, 51, 32, 115, 97, 116,
  61, 123, 45, 109, 97, 120, 40, 48, 44, 64, 123, 45, 49, 44, 97, 125,
  45, 48, 46, 53, 41, 125, 32, 45, 101, 108, 115, 101, 32, 115, 97, 116,
  61, 36, 50, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 91, 45, 49,
  93, 32, 48, 46, 53, 32, 45, 42, 91, 45, 49, 93, 32, 36, 49, 32,
  45, 43, 91, 45, 49, 93, 32, 36, 115, 97, 116, 10, 45, 43, 91, 45,
  49, 93, 32, 48, 46, 53, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44,
  49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 104, 115, 118, 50, 114,
  103, 98, 91, 48, 93, 10, 45, 45, 108, 117, 109, 105, 110, 97, 110, 99,
  101, 91, 48, 93, 32, 45, 97, 112, 112, 108, 121, 95, 103, 97, 109, 109,
  97, 91, 45, 49, 93, 32, 123, 109, 97, 120, 40, 48, 46, 48, 48, 49,
  44, 36, 55, 41, 125, 10, 45, 105, 102, 32, 123, 36, 56, 33, 61, 49,
  125, 32, 45, 45, 91, 45, 49, 93, 32, 49, 50, 56, 32, 45, 42, 91,
  45, 49, 93, 32, 36, 56, 32, 45, 43, 91, 45, 49, 93, 32, 49, 50,
  56, 32, 45, 101, 110, 100, 105, 102, 10, 45, 99, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 10, 45, 45, 102, 99, 91, 48, 93, 32, 36, 104,
  117, 101, 44, 49, 44, 49, 32, 45, 104, 115, 118, 50, 114, 103, 98, 91,
  45, 49, 93, 10, 45, 110, 91, 45, 49, 93, 32, 123, 49, 45, 36, 53,
  125, 44, 49, 32, 45, 42, 91, 48, 44, 45, 49, 93, 10, 45, 114, 103,
  98, 50, 121, 99, 98, 99, 114, 91, 48, 93, 10, 45, 99, 104, 97, 110,
  110, 101, 108, 115, 91, 48, 93, 32, 49, 44, 50, 32, 45, 114, 118, 91,
  48, 44, 49, 93, 32, 45, 97, 91, 48, 44, 49, 93, 32, 99, 10, 45,
  121, 99, 98, 99, 114, 50, 114, 103, 98, 91, 48, 93, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 99, 100, 95, 104, 115, 108,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 103, 99, 100, 95, 104, 115, 108, 32, 36, 123, 49, 45, 45, 50, 125,
  34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 72, 83, 86,
  32, 115, 101, 108, 101, 99, 116, 32, 58, 32, 103, 99, 100, 95, 104, 115,
  118, 95, 115, 101, 108, 101, 99, 116, 44, 32, 103, 99, 100, 95, 104, 115,
  118, 95, 115, 101, 108, 101, 99, 116, 40, 50, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 105, 62, 67, 111, 108, 111, 114, 32, 83, 101, 108, 101, 99,
  116, 105, 111, 110, 60, 47, 105, 62, 34, 41, 44, 32, 115, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 72, 117, 101, 32, 61, 32, 105, 110, 116,
  40, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108, 117, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 92, 110, 60, 105, 62, 67, 111, 108, 111, 114, 32, 82, 97,
  110, 103, 101, 60, 47, 105, 62, 34, 41, 44, 32, 115, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 72, 117, 101, 32, 114, 97, 110, 103, 101, 32,
  61, 32, 105, 110, 116, 40, 49, 56, 48, 44, 48, 44, 49, 56, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 97, 116, 32, 114, 97,
  110, 103, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44,
  48, 44, 48, 46, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  86, 97, 108, 32, 114, 97, 110, 103, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 53, 44, 48, 44, 48, 46, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 92, 110, 60, 105, 62, 79, 117, 116, 112, 117, 116, 32, 79,
  112, 116, 105, 111, 110, 115, 60, 47, 105, 62, 34, 41, 44, 32, 115, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 111, 119, 32, 97, 108,
  112, 104, 97, 32, 61, 32, 105, 110, 116, 40, 50, 44, 45, 50, 48, 44,
  50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 117,
  114, 32, 97, 108, 112, 104, 97, 32, 61, 32, 105, 110, 116, 40, 50, 44,
  48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 92, 110, 60, 105,
  62, 65, 100, 118, 97, 110, 99, 101, 100, 32, 79, 112, 116, 105, 111, 110,
  115, 60, 47, 105, 62, 34, 41, 44, 32, 115, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 80, 97, 116, 99, 104, 32, 115, 105, 122, 101, 32, 61,
  32, 105, 110, 116, 40, 49, 56, 44, 51, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 70, 105, 108, 108, 32, 104, 111, 108,
  101, 115, 32, 37, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 53,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 105, 110, 32,
  97, 114, 101, 97, 32, 37, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48,
  44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104,
  111, 119, 32, 119, 97, 116, 101, 114, 115, 104, 101, 100, 32, 61, 32, 98,
  111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32,
  60, 105, 62, 71, 97, 114, 97, 103, 101, 99, 111, 100, 101, 114, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51,
  47, 48, 50, 47, 49, 49, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 103, 99, 100, 95, 104, 115, 118, 95, 115, 101,
  108, 101, 99, 116, 32, 58, 10, 45, 115, 107, 105, 112, 32, 36, 123, 49,
  61, 48, 125, 44, 36, 123, 50, 61, 48, 46, 53, 125, 44, 36, 123, 51,
  61, 49, 125, 32, 45, 115, 107, 105, 112, 32, 36, 123, 52, 61, 49, 56,
  48, 125, 44, 36, 123, 53, 61, 48, 46, 53, 125, 44, 36, 123, 54, 61,
  48, 46, 53, 125, 10, 45, 115, 107, 105, 112, 32, 36, 123, 55, 61, 50,
  125, 44, 36, 123, 56, 61, 50, 125, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 57, 61, 49, 56, 125, 44, 36, 123, 49, 48, 61, 48, 125, 44, 36,
  123, 49, 49, 61, 48, 125, 44, 36, 123, 49, 50, 61, 48, 125, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 48, 93, 32, 45, 114, 101,
  109, 111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 91, 48, 93, 10,
  45, 105, 102, 32, 123, 33, 36, 49, 50, 125, 32, 91, 48, 93, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 108, 91, 45, 49, 93, 10, 45, 103, 99,
  100, 95, 115, 104, 114, 105, 110, 107, 10, 45, 45, 114, 103, 98, 50, 104,
  115, 118, 91, 48, 93, 32, 45, 115, 91, 45, 49, 93, 32, 99, 10, 98,
  104, 61, 123, 36, 49, 45, 36, 52, 125, 32, 116, 104, 61, 123, 36, 49,
  43, 36, 52, 125, 10, 45, 45, 103, 101, 91, 49, 93, 32, 123, 51, 54,
  48, 43, 36, 98, 104, 125, 32, 45, 45, 108, 101, 91, 49, 93, 32, 123,
  36, 116, 104, 45, 51, 54, 48, 125, 10, 45, 116, 50, 91, 49, 93, 32,
  123, 109, 97, 120, 40, 36, 98, 104, 44, 48, 41, 125, 44, 123, 109, 105,
  110, 40, 36, 116, 104, 44, 51, 54, 48, 41, 125, 10, 45, 111, 114, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 111, 114, 91, 49, 44, 45, 49, 93,
  10, 45, 116, 50, 91, 50, 93, 32, 123, 36, 50, 45, 36, 53, 125, 44,
  123, 36, 50, 43, 36, 53, 125, 10, 45, 116, 50, 91, 51, 93, 32, 123,
  36, 51, 45, 36, 54, 125, 44, 123, 36, 51, 43, 36, 54, 125, 10, 45,
  97, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 45, 97, 110, 100, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 109, 101, 97, 110, 99, 117, 114, 118,
  97, 116, 117, 114, 101, 95, 102, 108, 111, 119, 91, 48, 93, 32, 51, 32,
  45, 109, 101, 100, 105, 97, 110, 91, 48, 93, 32, 51, 10, 45, 43, 91,
  48, 93, 32, 49, 32, 45, 45, 103, 114, 97, 100, 105, 101, 110, 116, 95,
  110, 111, 114, 109, 91, 48, 93, 32, 45, 45, 98, 91, 45, 49, 93, 32,
  50, 44, 49, 44, 49, 32, 45, 109, 105, 110, 95, 112, 97, 116, 99, 104,
  91, 45, 49, 93, 32, 36, 57, 10, 45, 42, 91, 48, 44, 45, 49, 93,
  32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 10, 45, 45, 42, 91, 48,
  93, 32, 91, 49, 93, 32, 45, 103, 116, 91, 48, 93, 32, 48, 32, 45,
  110, 101, 103, 97, 116, 105, 118, 101, 91, 49, 93, 32, 45, 42, 91, 48,
  44, 49, 93, 32, 45, 42, 91, 48, 93, 32, 48, 46, 53, 32, 45, 109,
  97, 120, 91, 48, 44, 45, 49, 93, 10, 45, 45, 119, 97, 116, 101, 114,
  115, 104, 101, 100, 91, 48, 93, 32, 91, 45, 49, 93, 32, 45, 107, 91,
  45, 49, 93, 32, 45, 45, 91, 45, 49, 93, 32, 49, 10, 45, 103, 99,
  100, 95, 117, 110, 115, 104, 114, 105, 110, 107, 10, 45, 101, 110, 100, 108,
  10, 45, 105, 102, 32, 123, 33, 36, 49, 50, 125, 10, 45, 99, 104, 97,
  110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 32, 45, 103, 101, 91,
  45, 49, 93, 32, 48, 10, 45, 45, 97, 114, 101, 97, 91, 45, 49, 93,
  32, 48, 32, 45, 45, 108, 101, 91, 45, 49, 93, 32, 123, 40, 36, 49,
  48, 37, 42, 109, 97, 120, 40, 119, 44, 104, 41, 41, 94, 50, 125, 10,
  45, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 51, 93, 32, 45,
  42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 105, 110, 112, 97, 105, 110,
  116, 91, 45, 51, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 108, 101, 91, 45, 49, 93, 32, 123, 40, 36, 49, 49,
  37, 42, 109, 97, 120, 40, 119, 44, 104, 41, 41, 94, 50, 125, 32, 45,
  42, 91, 45, 49, 93, 32, 91, 45, 50, 93, 10, 45, 105, 110, 112, 97,
  105, 110, 116, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 10,
  45, 105, 102, 32, 123, 36, 55, 62, 48, 125, 32, 45, 100, 105, 108, 97,
  116, 101, 91, 45, 49, 93, 32, 36, 55, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 55, 60, 48, 125, 32, 45, 101, 114, 111, 100, 101, 91, 45, 49,
  93, 32, 123, 97, 98, 115, 40, 36, 55, 41, 125, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 36, 56, 32, 45, 98, 91, 45, 49, 93,
  32, 36, 56, 44, 49, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109,
  112, 32, 72, 117, 101, 32, 108, 105, 103, 104, 116, 101, 110, 45, 100, 97,
  114, 107, 101, 110, 32, 58, 32, 105, 97, 105, 110, 95, 104, 117, 101, 95,
  108, 105, 103, 104, 116, 95, 100, 97, 114, 107, 44, 32, 105, 97, 105, 110,
  95, 104, 117, 101, 95, 108, 105, 103, 104, 116, 95, 100, 97, 114, 107, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 100, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 50, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 51, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 89, 101, 108, 108, 111, 119, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 53, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 54, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 101, 101, 110, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 56, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 121, 97, 110,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 49, 48,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 49, 49,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108,
  117, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53,
  53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  49, 51, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53,
  53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  49, 52, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53,
  53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  77, 97, 103, 101, 110, 116, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 49, 54, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 49, 55, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 49, 56, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  71, 108, 111, 98, 97, 108, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 72, 83, 76, 32, 61, 32, 98, 111, 111, 108, 32, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 97, 116, 32, 116, 111, 112, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 97, 116, 32, 98,
  111, 116, 116, 111, 109, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48,
  48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 86, 97, 108, 117, 101, 32, 116, 111, 112, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108, 117, 101, 32, 98, 111,
  116, 116, 111, 109, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 38, 119, 32, 61, 32,
  98, 111, 111, 108, 32, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 73, 97, 105,
  110, 32, 70, 101, 114, 103, 117, 115, 115, 111, 110, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 105, 97, 105, 110, 95,
  104, 117, 101, 95, 108, 105, 103, 104, 116, 95, 100, 97, 114, 107, 58, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121,
  32, 45, 108, 91, 48, 93, 10, 45, 45, 108, 91, 48, 93, 10, 45, 116,
  111, 95, 114, 103, 98, 10, 45, 105, 102, 32, 123, 36, 50, 48, 61, 61,
  48, 125, 10, 45, 114, 103, 98, 50, 104, 115, 118, 56, 10, 45, 101, 108,
  115, 101, 10, 45, 114, 103, 98, 50, 104, 115, 108, 56, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 115, 32, 99, 10, 45, 45, 97, 112, 112, 108, 121,
  95, 99, 117, 114, 118, 101, 91, 48, 93, 32, 48, 44, 48, 44, 123, 49,
  50, 56, 43, 36, 49, 125, 44, 49, 54, 44, 123, 49, 50, 56, 43, 36,
  50, 125, 44, 51, 48, 44, 123, 49, 50, 56, 43, 36, 51, 125, 44, 52,
  50, 44, 123, 49, 50, 56, 43, 36, 52, 125, 44, 54, 48, 44, 123, 49,
  50, 56, 43, 36, 53, 125, 44, 55, 53, 44, 123, 49, 50, 56, 43, 36,
  54, 125, 44, 56, 53, 44, 123, 49, 50, 56, 43, 36, 55, 125, 44, 49,
  48, 53, 44, 123, 49, 50, 56, 43, 36, 56, 125, 44, 49, 50, 55, 44,
  123, 49, 50, 56, 43, 36, 57, 125, 44, 49, 51, 53, 44, 123, 49, 50,
  56, 43, 36, 49, 48, 125, 44, 49, 53, 48, 44, 123, 49, 50, 56, 43,
  36, 49, 49, 125, 44, 49, 55, 48, 44, 123, 49, 50, 56, 43, 36, 49,
  50, 125, 44, 49, 56, 48, 44, 123, 49, 50, 56, 43, 36, 49, 51, 125,
  44, 49, 57, 53, 44, 123, 49, 50, 56, 43, 36, 49, 52, 125, 44, 50,
  49, 51, 44, 123, 49, 50, 56, 43, 36, 49, 53, 125, 44, 50, 50, 53,
  44, 123, 49, 50, 56, 43, 36, 49, 54, 125, 44, 50, 52, 48, 44, 123,
  49, 50, 56, 43, 36, 49, 55, 125, 44, 50, 53, 53, 44, 123, 49, 50,
  56, 43, 36, 49, 56, 125, 10, 45, 115, 117, 98, 91, 45, 49, 93, 32,
  49, 50, 56, 10, 45, 97, 100, 100, 91, 45, 49, 93, 32, 36, 49, 57,
  10, 45, 97, 100, 100, 91, 45, 49, 44, 45, 50, 93, 10, 45, 97, 32,
  99, 10, 45, 105, 102, 32, 123, 36, 50, 48, 61, 61, 48, 125, 10, 45,
  104, 115, 118, 56, 50, 114, 103, 98, 10, 45, 101, 108, 115, 101, 10, 45,
  104, 115, 108, 56, 50, 114, 103, 98, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 108, 10, 45, 45, 114, 103, 98, 50, 104, 115, 118, 91,
  48, 93, 10, 45, 115, 91, 45, 49, 93, 32, 99, 10, 45, 107, 101, 101,
  112, 91, 48, 44, 49, 44, 45, 49, 44, 45, 50, 93, 10, 45, 109, 117,
  108, 91, 45, 49, 44, 45, 50, 93, 32, 50, 53, 53, 10, 45, 97, 112,
  112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 45, 50, 93, 32, 48, 44,
  48, 44, 48, 44, 36, 50, 50, 44, 48, 44, 36, 50, 49, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 97, 112, 112, 108, 121,
  95, 99, 117, 114, 118, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48,
  44, 36, 50, 52, 44, 48, 44, 36, 50, 51, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 50, 53, 53, 10, 45, 109, 117, 108, 91, 45, 49, 93, 32,
  91, 45, 50, 93, 10, 45, 100, 105, 118, 91, 45, 49, 93, 32, 50, 53,
  53, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 50, 93, 10, 45, 99,
  91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 97, 91, 49, 44,
  50, 93, 32, 99, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 97, 108,
  112, 104, 97, 91, 48, 44, 49, 93, 10, 45, 105, 102, 32, 123, 36, 50,
  53, 61, 61, 49, 125, 10, 45, 116, 111, 95, 103, 114, 97, 121, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103,
  105, 109, 112, 32, 73, 110, 102, 114, 97, 114, 101, 100, 32, 115, 105, 109,
  117, 108, 97, 116, 105, 111, 110, 32, 58, 32, 103, 105, 109, 112, 95, 116,
  107, 95, 105, 110, 102, 114, 97, 114, 101, 100, 44, 32, 103, 105, 109, 112,
  95, 116, 107, 95, 105, 110, 102, 114, 97, 114, 101, 100, 95, 112, 114, 101,
  118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 70, 105, 108, 116, 101, 114, 32, 100, 101, 110, 115, 105, 116, 121, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 53, 44, 48, 46, 48,
  49, 44, 48, 46, 57, 57, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 87, 111, 111, 100, 32, 101, 102, 102, 101, 99, 116, 32, 115, 97, 116,
  117, 114, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 87, 111, 111, 100, 32, 101, 102, 102, 101, 99, 116, 32, 99, 111,
  108, 111, 114, 32, 61, 32, 105, 110, 116, 40, 45, 49, 48, 48, 44, 45,
  49, 56, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 87, 111, 111, 100, 32, 101, 102, 102, 101, 99, 116, 32, 102, 97,
  108, 108, 111, 102, 102, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  55, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 107, 121, 32, 99, 111, 108, 111, 114, 32, 61, 32, 105, 110, 116,
  40, 48, 44, 45, 49, 56, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 107, 121, 32, 102, 97, 108, 108, 111, 102,
  102, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 102, 114, 97, 114,
  101, 100, 32, 100, 101, 102, 111, 99, 117, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 69, 120, 112, 111, 115, 117, 114, 101, 32, 61, 32, 105, 110,
  116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116, 114, 97, 115, 116, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 97, 116, 117, 114, 97, 116, 105,
  111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 50,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114,
  32, 47, 32, 66, 38, 97, 109, 112, 59, 87, 32, 61, 32, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 100,
  100, 32, 103, 114, 97, 105, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  53, 48, 44, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121,
  112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105,
  62, 84, 111, 109, 32, 75, 101, 105, 108, 60, 47, 105, 62, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 50, 47, 48, 55, 47, 49, 55, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103,
  105, 109, 112, 95, 116, 107, 95, 105, 110, 102, 114, 97, 114, 101, 100, 32,
  58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 45, 103, 105, 109, 112, 95, 104, 115, 118, 95, 101,
  113, 117, 97, 108, 105, 122, 101, 114, 32, 48, 44, 49, 50, 48, 44, 123,
  50, 52, 48, 42, 36, 52, 125, 44, 123, 105, 102, 40, 123, 36, 50, 61,
  61, 48, 125, 44, 48, 44, 36, 51, 41, 125, 44, 123, 105, 102, 40, 123,
  36, 50, 61, 61, 48, 125, 44, 45, 36, 49, 44, 123, 45, 49, 43, 36,
  50, 125, 41, 125, 44, 36, 49, 44, 50, 52, 48, 44, 123, 49, 50, 48,
  42, 36, 54, 125, 44, 36, 53, 44, 48, 44, 45, 36, 49, 44, 48, 44,
  48, 44, 48, 44, 48, 44, 48, 10, 45, 98, 108, 117, 114, 91, 45, 49,
  93, 32, 36, 55, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 97, 108, 112, 104, 97, 32, 36, 49, 44, 48, 10, 45, 116,
  107, 95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112,
  114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 49, 44, 36, 57, 44, 36,
  56, 44, 48, 44, 48, 44, 48, 44, 49, 48, 48, 44, 50, 53, 54, 44,
  48, 44, 48, 44, 48, 44, 50, 44, 48, 44, 48, 10, 45, 103, 105, 109,
  112, 95, 109, 105, 120, 95, 108, 97, 98, 32, 49, 44, 48, 44, 48, 44,
  36, 49, 48, 44, 48, 44, 48, 44, 36, 49, 48, 44, 48, 44, 48, 44,
  48, 44, 50, 44, 48, 10, 45, 105, 102, 32, 123, 36, 49, 49, 61, 61,
  49, 125, 32, 45, 103, 105, 109, 112, 95, 98, 108, 97, 99, 107, 97, 110,
  100, 119, 104, 105, 116, 101, 32, 48, 46, 50, 57, 57, 44, 48, 44, 48,
  46, 53, 56, 55, 44, 48, 44, 48, 46, 49, 49, 52, 44, 48, 44, 49,
  44, 49, 44, 48, 44, 48, 44, 48, 44, 36, 49, 50, 44, 36, 49, 50,
  44, 36, 49, 50, 44, 50, 44, 123, 123, 119, 43, 104, 125, 47, 54, 48,
  48, 48, 48, 125, 44, 48, 44, 48, 44, 49, 54, 44, 52, 44, 48, 44,
  48, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 116, 107, 95, 105,
  110, 102, 114, 97, 114, 101, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 116, 107, 95,
  105, 110, 102, 114, 97, 114, 101, 100, 32, 36, 123, 49, 45, 45, 50, 125,
  34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 77, 101, 116,
  97, 108, 108, 105, 99, 32, 108, 111, 111, 107, 32, 58, 32, 103, 105, 109,
  112, 95, 116, 107, 95, 109, 101, 116, 97, 108, 108, 105, 99, 44, 32, 103,
  105, 109, 112, 95, 116, 107, 95, 109, 101, 116, 97, 108, 108, 105, 99, 95,
  112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 116, 114, 101, 110, 103, 116, 104, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 50, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 101, 116, 97, 108, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 115, 105, 108, 118, 101, 114, 34,
  44, 34, 103, 111, 108, 100, 34, 44, 34, 99, 111, 112, 112, 101, 114, 34,
  44, 34, 98, 114, 111, 110, 122, 101, 34, 44, 34, 98, 108, 117, 101, 32,
  115, 116, 101, 101, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62,
  84, 111, 109, 32, 75, 101, 105, 108, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48, 52, 47, 49, 50, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108,
  105, 110, 107, 40, 34, 70, 105, 108, 116, 101, 114, 32, 101, 120, 112, 108,
  97, 105, 110, 101, 100, 32, 104, 101, 114, 101, 34, 44, 104, 116, 116, 112,
  58, 47, 47, 119, 119, 119, 46, 116, 107, 102, 105, 108, 116, 101, 114, 46,
  98, 112, 108, 97, 99, 101, 100, 46, 110, 101, 116, 47, 84, 75, 70, 105,
  108, 116, 101, 114, 37, 50, 48, 102, 105, 108, 116, 101, 114, 46, 104, 116,
  109, 108, 41, 10, 103, 105, 109, 112, 95, 116, 107, 95, 109, 101, 116, 97,
  108, 108, 105, 99, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 103, 105, 109, 112, 95, 103,
  97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 32, 36, 50, 44,
  48, 44, 48, 44, 49, 44, 49, 44, 48, 44, 48, 10, 45, 108, 117, 109,
  105, 110, 97, 110, 99, 101, 32, 45, 45, 108, 117, 109, 105, 110, 97, 110,
  99, 101, 10, 45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99,
  117, 114, 118, 101, 91, 49, 93, 32, 48, 44, 51, 49, 44, 49, 49, 49,
  44, 54, 52, 44, 49, 55, 44, 49, 49, 48, 44, 49, 55, 54, 44, 49,
  52, 56, 44, 55, 53, 44, 49, 55, 55, 44, 50, 51, 53, 44, 49, 56,
  54, 44, 49, 44, 48, 44, 48, 44, 48, 44, 48, 10, 45, 103, 105, 109,
  112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 49, 93,
  32, 48, 44, 51, 49, 44, 49, 49, 49, 44, 54, 52, 44, 49, 55, 44,
  49, 49, 48, 44, 49, 55, 54, 44, 49, 52, 56, 44, 55, 53, 44, 49,
  55, 55, 44, 50, 51, 53, 44, 49, 56, 54, 44, 49, 44, 48, 44, 48,
  44, 48, 44, 48, 10, 45, 114, 118, 91, 48, 44, 49, 93, 32, 45, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 118, 97, 108, 117,
  101, 91, 48, 44, 49, 93, 32, 36, 49, 44, 48, 10, 45, 105, 102, 32,
  123, 36, 51, 61, 61, 49, 125, 32, 45, 103, 105, 109, 112, 95, 109, 105,
  120, 95, 114, 103, 98, 32, 49, 44, 53, 48, 44, 48, 44, 49, 44, 53,
  48, 44, 48, 44, 49, 44, 45, 53, 48, 44, 48, 44, 48, 44, 50, 44,
  48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 51, 61, 61, 50, 125, 32,
  45, 103, 105, 109, 112, 95, 109, 105, 120, 95, 114, 103, 98, 32, 49, 44,
  55, 53, 44, 48, 44, 49, 44, 53, 44, 48, 44, 49, 44, 45, 50, 53,
  44, 48, 44, 48, 44, 50, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 51, 61, 61, 51, 125, 32, 45, 103, 105, 109, 112, 95, 109, 105, 120,
  95, 114, 103, 98, 32, 49, 44, 55, 48, 44, 48, 44, 49, 44, 52, 48,
  44, 48, 44, 49, 44, 45, 50, 48, 44, 48, 44, 48, 44, 50, 44, 48,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 51, 61, 61, 52, 125, 32, 45,
  103, 105, 109, 112, 95, 109, 105, 120, 95, 114, 103, 98, 32, 49, 44, 45,
  53, 44, 48, 44, 49, 44, 48, 44, 48, 44, 49, 46, 49, 44, 49, 50,
  44, 48, 44, 48, 44, 50, 44, 48, 10, 45, 101, 110, 100, 105, 102, 32,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112,
  95, 116, 107, 95, 109, 101, 116, 97, 108, 108, 105, 99, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109,
  112, 95, 116, 107, 95, 109, 101, 116, 97, 108, 108, 105, 99, 32, 36, 123,
  49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 77, 105, 120, 101, 114, 32, 91, 67, 77, 89, 75, 93, 32, 58,
  32, 103, 105, 109, 112, 95, 109, 105, 120, 95, 99, 109, 121, 107, 44, 32,
  103, 105, 109, 112, 95, 109, 105, 120, 95, 99, 109, 121, 107, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 121, 97, 110, 32, 99, 111, 110, 116, 114, 97, 115, 116, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 121, 97, 110, 32, 98, 114, 105,
  103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 121, 97, 110, 32, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 97,
  103, 101, 110, 116, 97, 32, 99, 111, 110, 116, 114, 97, 115, 116, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 77, 97, 103, 101, 110, 116, 97, 32, 98,
  114, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 77, 97, 103, 101, 110, 116, 97, 32, 115,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 89, 101, 108, 108, 111, 119, 32, 99, 111, 110, 116, 114, 97,
  115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 101, 108, 108, 111,
  119, 32, 98, 114, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 101, 108, 108, 111, 119,
  32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 75, 101, 121, 32, 99, 111, 110, 116, 114, 97, 115,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 75, 101, 121, 32, 98, 114,
  105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 75, 101, 121, 32, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 84, 111, 110, 101, 115, 32, 114, 97, 110, 103, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 32, 116,
  111, 110, 101, 115, 34, 44, 34, 83, 104, 97, 100, 111, 119, 115, 34, 44,
  34, 77, 105, 100, 45, 116, 111, 110, 101, 115, 34, 44, 34, 72, 105, 103,
  104, 108, 105, 103, 104, 116, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 84, 111, 110, 101, 115, 32, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49,
  50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 109, 105, 120, 95, 99, 109, 121,
  107, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 45, 49, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97,
  99, 105, 116, 121, 32, 45, 114, 118, 32, 45, 116, 111, 95, 114, 103, 98,
  91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 115, 116, 97, 114, 116,
  95, 109, 105, 120, 32, 36, 49, 51, 44, 36, 49, 52, 10, 45, 114, 103,
  98, 50, 99, 109, 121, 107, 91, 45, 49, 93, 32, 45, 115, 91, 45, 49,
  93, 32, 99, 10, 45, 42, 91, 45, 52, 93, 32, 36, 49, 32, 45, 43,
  91, 45, 52, 93, 32, 36, 50, 32, 45, 98, 91, 45, 52, 93, 32, 36,
  51, 37, 10, 45, 42, 91, 45, 51, 93, 32, 36, 52, 32, 45, 43, 91,
  45, 51, 93, 32, 36, 53, 32, 45, 98, 91, 45, 51, 93, 32, 36, 54,
  37, 10, 45, 42, 91, 45, 50, 93, 32, 36, 55, 32, 45, 43, 91, 45,
  50, 93, 32, 36, 56, 32, 45, 98, 91, 45, 50, 93, 32, 36, 57, 37,
  10, 45, 42, 91, 45, 49, 93, 32, 36, 49, 48, 32, 45, 43, 91, 45,
  49, 93, 32, 36, 49, 49, 32, 45, 98, 91, 45, 49, 93, 32, 36, 49,
  50, 37, 10, 45, 97, 91, 45, 52, 45, 45, 49, 93, 32, 99, 32, 45,
  99, 109, 121, 107, 50, 114, 103, 98, 91, 45, 49, 93, 10, 45, 103, 105,
  109, 112, 95, 101, 110, 100, 95, 109, 105, 120, 32, 36, 49, 51, 10, 45,
  105, 102, 32, 123, 64, 35, 33, 61, 51, 125, 32, 45, 114, 118, 32, 45,
  97, 32, 99, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 108,
  32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101,
  10, 103, 105, 109, 112, 95, 109, 105, 120, 95, 99, 109, 121, 107, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115,
  112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103,
  105, 109, 112, 95, 109, 105, 120, 95, 99, 109, 121, 107, 32, 36, 42, 34,
  44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 77, 105, 120, 101,
  114, 32, 91, 72, 83, 86, 93, 32, 58, 32, 103, 105, 109, 112, 95, 109,
  105, 120, 95, 104, 115, 118, 44, 32, 103, 105, 109, 112, 95, 109, 105, 120,
  95, 104, 115, 118, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 117, 101, 32, 99, 111, 110,
  116, 114, 97, 115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44,
  48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 117,
  101, 32, 98, 114, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 45, 49, 56, 48, 44, 49, 56, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 117, 101, 32, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 32, 99, 111, 110,
  116, 114, 97, 115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44,
  48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 97,
  116, 117, 114, 97, 116, 105, 111, 110, 32, 98, 114, 105, 103, 104, 116, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 97, 116,
  117, 114, 97, 116, 105, 111, 110, 32, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108, 117,
  101, 32, 99, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 86, 97, 108, 117, 101, 32, 98, 114, 105, 103, 104, 116, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108,
  117, 101, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 111,
  110, 101, 115, 32, 114, 97, 110, 103, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 65, 108, 108, 32, 116, 111, 110, 101, 115, 34, 44, 34,
  83, 104, 97, 100, 111, 119, 115, 34, 44, 34, 77, 105, 100, 45, 116, 111,
  110, 101, 115, 34, 44, 34, 72, 105, 103, 104, 108, 105, 103, 104, 116, 115,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 111, 110, 101,
  115, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 50, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97,
  116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 109, 105, 120, 95, 104, 115, 118, 32, 58, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 45, 49, 93, 32, 45, 115,
  112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 114, 118,
  32, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10, 45, 103, 105,
  109, 112, 95, 115, 116, 97, 114, 116, 95, 109, 105, 120, 32, 36, 49, 48,
  44, 36, 49, 49, 10, 45, 114, 103, 98, 50, 104, 115, 118, 91, 45, 49,
  93, 32, 45, 115, 91, 45, 49, 93, 32, 99, 32, 45, 45, 91, 45, 50,
  44, 45, 49, 93, 32, 48, 46, 53, 10, 45, 42, 91, 45, 51, 93, 32,
  36, 49, 32, 45, 43, 91, 45, 51, 93, 32, 36, 50, 32, 45, 98, 91,
  45, 51, 93, 32, 36, 51, 37, 10, 45, 42, 91, 45, 50, 93, 32, 36,
  52, 32, 45, 43, 91, 45, 50, 93, 32, 36, 53, 32, 45, 98, 91, 45,
  50, 93, 32, 36, 54, 37, 10, 45, 42, 91, 45, 49, 93, 32, 36, 55,
  32, 45, 43, 91, 45, 49, 93, 32, 36, 56, 32, 45, 98, 91, 45, 49,
  93, 32, 36, 57, 37, 10, 45, 37, 91, 45, 51, 93, 32, 51, 54, 48,
  32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 48, 46, 53, 32, 45,
  99, 91, 45, 50, 44, 45, 49, 93, 32, 48, 44, 49, 32, 45, 97, 91,
  45, 51, 45, 45, 49, 93, 32, 99, 32, 45, 104, 115, 118, 50, 114, 103,
  98, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 101, 110, 100, 95,
  109, 105, 120, 32, 36, 49, 48, 10, 45, 105, 102, 32, 123, 64, 35, 33,
  61, 51, 125, 32, 45, 114, 118, 32, 45, 97, 32, 99, 32, 45, 101, 110,
  100, 105, 102, 32, 45, 101, 110, 100, 108, 32, 45, 109, 118, 91, 45, 49,
  93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 109,
  105, 120, 95, 104, 115, 118, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 109, 105, 120, 95,
  104, 115, 118, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105,
  109, 112, 32, 77, 105, 120, 101, 114, 32, 91, 76, 97, 98, 93, 32, 58,
  32, 103, 105, 109, 112, 95, 109, 105, 120, 95, 108, 97, 98, 44, 32, 103,
  105, 109, 112, 95, 109, 105, 120, 95, 108, 97, 98, 95, 112, 114, 101, 118,
  105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  76, 105, 103, 104, 116, 110, 101, 115, 115, 32, 99, 111, 110, 116, 114, 97,
  115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 46, 53,
  44, 49, 46, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76,
  105, 103, 104, 116, 110, 101, 115, 115, 32, 98, 114, 105, 103, 104, 116, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 53,
  48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76,
  105, 103, 104, 116, 110, 101, 115, 115, 32, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 45, 99,
  111, 108, 111, 114, 32, 99, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 65, 45, 99, 111, 108, 111, 114, 32, 98, 114,
  105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 45, 50, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 45, 99, 111, 108, 111, 114, 32, 115, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  66, 45, 99, 111, 108, 111, 114, 32, 99, 111, 110, 116, 114, 97, 115, 116,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 45, 99, 111, 108, 111, 114,
  32, 98, 114, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 50, 48, 44, 50, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 66, 45, 99, 111, 108, 111, 114, 32, 115,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 111, 110, 101, 115, 32,
  114, 97, 110, 103, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  65, 108, 108, 32, 116, 111, 110, 101, 115, 34, 44, 34, 83, 104, 97, 100,
  111, 119, 115, 34, 44, 34, 77, 105, 100, 45, 116, 111, 110, 101, 115, 34,
  44, 34, 72, 105, 103, 104, 108, 105, 103, 104, 116, 115, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 84, 111, 110, 101, 115, 32, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108,
  105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 109, 105,
  120, 95, 108, 97, 98, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116,
  95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 116, 111, 95, 114, 103, 98,
  91, 48, 93, 10, 45, 103, 105, 109, 112, 95, 112, 97, 114, 97, 108, 108,
  101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 91, 48, 93, 32, 34, 45,
  95, 103, 105, 109, 112, 95, 109, 105, 120, 95, 108, 97, 98, 32, 36, 42,
  34, 44, 48, 44, 123, 51, 42, 109, 97, 120, 40, 36, 51, 44, 36, 54,
  44, 36, 57, 41, 125, 10, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108,
  32, 45, 109, 118, 91, 36, 62, 93, 32, 48, 32, 45, 100, 111, 110, 101,
  10, 95, 103, 105, 109, 112, 95, 109, 105, 120, 95, 108, 97, 98, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 116, 97, 114, 116, 95, 109, 105, 120,
  32, 36, 49, 48, 44, 36, 49, 49, 10, 45, 114, 103, 98, 50, 108, 97,
  98, 91, 45, 49, 93, 32, 45, 115, 91, 45, 49, 93, 32, 99, 10, 45,
  42, 91, 45, 51, 93, 32, 36, 49, 32, 45, 43, 91, 45, 51, 93, 32,
  36, 50, 32, 45, 98, 91, 45, 51, 93, 32, 36, 51, 37, 10, 45, 42,
  91, 45, 50, 93, 32, 36, 52, 32, 45, 43, 91, 45, 50, 93, 32, 36,
  53, 32, 45, 98, 91, 45, 50, 93, 32, 36, 54, 37, 10, 45, 42, 91,
  45, 49, 93, 32, 36, 55, 32, 45, 43, 91, 45, 49, 93, 32, 36, 56,
  32, 45, 98, 91, 45, 49, 93, 32, 36, 57, 37, 10, 45, 97, 91, 45,
  51, 45, 45, 49, 93, 32, 99, 32, 45, 108, 97, 98, 50, 114, 103, 98,
  91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 101, 110, 100, 95, 109,
  105, 120, 32, 36, 49, 48, 10, 103, 105, 109, 112, 95, 109, 105, 120, 95,
  108, 97, 98, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 103, 105, 109, 112, 95, 109, 105, 120, 95, 108, 97, 98,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32,
  77, 105, 120, 101, 114, 32, 91, 82, 71, 66, 93, 32, 58, 32, 103, 105,
  109, 112, 95, 109, 105, 120, 95, 114, 103, 98, 44, 32, 103, 105, 109, 112,
  95, 109, 105, 120, 95, 114, 103, 98, 95, 112, 114, 101, 118, 105, 101, 119,
  40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 100,
  32, 99, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 82, 101, 100, 32, 98, 114, 105, 103, 104, 116, 110, 101, 115, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101,
  100, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 71, 114, 101, 101, 110, 32, 99, 111, 110, 116,
  114, 97, 115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48,
  44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 101,
  101, 110, 32, 98, 114, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 101, 101, 110,
  32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 66, 108, 117, 101, 32, 99, 111, 110, 116, 114, 97,
  115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 117, 101, 32,
  98, 114, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 117, 101, 32, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 84, 111, 110, 101, 115, 32, 114, 97,
  110, 103, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108,
  108, 32, 116, 111, 110, 101, 115, 34, 44, 34, 83, 104, 97, 100, 111, 119,
  115, 34, 44, 34, 77, 105, 100, 45, 116, 111, 110, 101, 115, 34, 44, 34,
  72, 105, 103, 104, 108, 105, 103, 104, 116, 115, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 84, 111, 110, 101, 115, 32, 115, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50,
  44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99,
  97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65,
  117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32,
  84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59,
  60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49,
  48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 115, 116, 97, 114,
  116, 95, 109, 105, 120, 32, 58, 10, 45, 105, 102, 32, 123, 36, 49, 61,
  61, 49, 125, 32, 45, 45, 116, 111, 110, 101, 115, 91, 45, 49, 93, 32,
  51, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 98, 91, 45,
  50, 44, 45, 49, 93, 32, 36, 50, 37, 32, 45, 114, 91, 45, 50, 44,
  45, 49, 93, 32, 91, 45, 51, 93, 32, 45, 42, 91, 45, 49, 93, 32,
  91, 45, 51, 93, 32, 45, 109, 118, 91, 45, 51, 93, 32, 64, 35, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 50, 125, 32, 45, 45,
  116, 111, 110, 101, 115, 91, 45, 49, 93, 32, 51, 32, 45, 43, 91, 45,
  51, 44, 45, 49, 93, 32, 45, 98, 91, 45, 50, 44, 45, 49, 93, 32,
  36, 50, 37, 32, 45, 114, 91, 45, 50, 44, 45, 49, 93, 32, 91, 45,
  51, 93, 32, 45, 42, 91, 45, 50, 93, 32, 91, 45, 51, 93, 32, 45,
  109, 118, 91, 45, 51, 93, 32, 64, 35, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 49, 61, 61, 51, 125, 32, 45, 45, 116, 111, 110, 101, 115, 91,
  45, 49, 93, 32, 51, 32, 45, 43, 91, 45, 51, 44, 45, 50, 93, 32,
  45, 98, 91, 45, 50, 44, 45, 49, 93, 32, 36, 50, 37, 32, 45, 114,
  91, 45, 50, 44, 45, 49, 93, 32, 91, 45, 51, 93, 32, 45, 42, 91,
  45, 50, 93, 32, 91, 45, 51, 93, 32, 45, 109, 118, 91, 45, 51, 93,
  32, 64, 35, 10, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95,
  101, 110, 100, 95, 109, 105, 120, 32, 58, 10, 45, 105, 102, 32, 123, 36,
  49, 61, 61, 49, 125, 32, 45, 42, 91, 45, 51, 44, 45, 49, 93, 32,
  45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 49, 61, 61, 50, 125, 32, 45, 42, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 61, 61, 51, 125, 32, 45, 42, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101,
  110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 109, 105, 120, 95, 114, 103,
  98, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 45, 49, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97,
  99, 105, 116, 121, 32, 45, 114, 118, 32, 45, 116, 111, 95, 114, 103, 98,
  91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 115, 116, 97, 114, 116,
  95, 109, 105, 120, 32, 36, 49, 48, 44, 36, 49, 49, 10, 45, 45, 91,
  45, 49, 93, 32, 49, 50, 56, 32, 45, 115, 91, 45, 49, 93, 32, 99,
  10, 45, 42, 91, 45, 51, 93, 32, 36, 49, 32, 45, 43, 91, 45, 51,
  93, 32, 36, 50, 32, 45, 98, 91, 45, 51, 93, 32, 36, 51, 37, 10,
  45, 42, 91, 45, 50, 93, 32, 36, 52, 32, 45, 43, 91, 45, 50, 93,
  32, 36, 53, 32, 45, 98, 91, 45, 50, 93, 32, 36, 54, 37, 10, 45,
  42, 91, 45, 49, 93, 32, 36, 55, 32, 45, 43, 91, 45, 49, 93, 32,
  36, 56, 32, 45, 98, 91, 45, 49, 93, 32, 36, 57, 37, 10, 45, 97,
  91, 45, 51, 45, 45, 49, 93, 32, 99, 32, 45, 43, 91, 45, 49, 93,
  32, 49, 50, 56, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 10, 45, 103, 105, 109, 112, 95, 101, 110, 100, 95, 109, 105, 120, 32,
  36, 49, 48, 10, 45, 105, 102, 32, 123, 64, 35, 33, 61, 51, 125, 32,
  45, 114, 118, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 105, 102, 32,
  45, 101, 110, 100, 108, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32,
  45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 109, 105, 120, 95, 114,
  103, 98, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 109, 105, 120, 95, 114, 103, 98, 32,
  36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 77,
  105, 120, 101, 114, 32, 91, 89, 67, 98, 67, 114, 93, 32, 58, 32, 103,
  105, 109, 112, 95, 109, 105, 120, 95, 121, 99, 98, 99, 114, 44, 32, 103,
  105, 109, 112, 95, 109, 105, 120, 95, 121, 99, 98, 99, 114, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 76, 117, 109, 105, 110, 97, 110, 99, 101, 32, 99, 111, 110, 116,
  114, 97, 115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48,
  44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 117, 109,
  105, 110, 97, 110, 99, 101, 32, 98, 114, 105, 103, 104, 116, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76,
  117, 109, 105, 110, 97, 110, 99, 101, 32, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 117,
  101, 32, 99, 104, 114, 111, 109, 97, 32, 99, 111, 110, 116, 114, 97, 115,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 117, 101, 32, 99,
  104, 114, 111, 109, 97, 32, 98, 114, 105, 103, 104, 116, 110, 101, 115, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108,
  117, 101, 32, 99, 104, 114, 111, 109, 97, 32, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101,
  100, 32, 99, 104, 114, 111, 109, 97, 32, 99, 111, 110, 116, 114, 97, 115,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 100, 32, 99, 104,
  114, 111, 109, 97, 32, 98, 114, 105, 103, 104, 116, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 100,
  32, 99, 104, 114, 111, 109, 97, 32, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 84, 111, 110, 101, 115, 32, 114, 97, 110, 103, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 32, 116, 111, 110,
  101, 115, 34, 44, 34, 83, 104, 97, 100, 111, 119, 115, 34, 44, 34, 77,
  105, 100, 45, 116, 111, 110, 101, 115, 34, 44, 34, 72, 105, 103, 104, 108,
  105, 103, 104, 116, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 84, 111, 110, 101, 115, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 44, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117,
  112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47,
  50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 109, 105, 120, 95, 121, 99, 98, 99, 114,
  32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 45, 49, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99,
  105, 116, 121, 32, 45, 114, 118, 32, 45, 116, 111, 95, 114, 103, 98, 91,
  45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 115, 116, 97, 114, 116, 95,
  109, 105, 120, 32, 36, 49, 48, 44, 36, 49, 49, 10, 45, 114, 103, 98,
  50, 121, 99, 98, 99, 114, 91, 45, 49, 93, 32, 45, 45, 91, 45, 49,
  93, 32, 49, 50, 56, 32, 45, 115, 91, 45, 49, 93, 32, 99, 10, 45,
  42, 91, 45, 51, 93, 32, 36, 49, 32, 45, 43, 91, 45, 51, 93, 32,
  36, 50, 32, 45, 98, 91, 45, 51, 93, 32, 36, 51, 37, 10, 45, 42,
  91, 45, 50, 93, 32, 36, 52, 32, 45, 43, 91, 45, 50, 93, 32, 36,
  53, 32, 45, 98, 91, 45, 50, 93, 32, 36, 54, 37, 10, 45, 42, 91,
  45, 49, 93, 32, 36, 55, 32, 45, 43, 91, 45, 49, 93, 32, 36, 56,
  32, 45, 98, 91, 45, 49, 93, 32, 36, 57, 37, 10, 45, 97, 91, 45,
  51, 45, 45, 49, 93, 32, 99, 32, 45, 43, 91, 45, 49, 93, 32, 49,
  50, 56, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32,
  45, 121, 99, 98, 99, 114, 50, 114, 103, 98, 91, 45, 49, 93, 10, 45,
  103, 105, 109, 112, 95, 101, 110, 100, 95, 109, 105, 120, 32, 36, 49, 48,
  10, 45, 105, 102, 32, 123, 64, 35, 33, 61, 51, 125, 32, 45, 114, 118,
  32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110,
  100, 108, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111,
  110, 101, 10, 103, 105, 109, 112, 95, 109, 105, 120, 95, 121, 99, 98, 99,
  114, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 109, 105, 120, 95, 121, 99, 98, 99, 114,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32,
  82, 71, 66, 32, 116, 111, 110, 101, 32, 58, 32, 105, 97, 105, 110, 95,
  114, 103, 98, 95, 116, 111, 110, 101, 44, 32, 105, 97, 105, 110, 95, 114,
  103, 98, 95, 116, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 98,
  62, 65, 100, 106, 117, 115, 116, 32, 82, 101, 100, 115, 60, 47, 98, 62,
  32, 102, 111, 114, 32, 112, 105, 120, 101, 108, 115, 32, 116, 104, 97, 116,
  32, 104, 97, 118, 101, 58, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 76, 105, 116, 116, 108, 101, 32, 114, 101, 100, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 111, 109, 101, 32, 114,
  101, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53,
  53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  77, 117, 99, 104, 32, 114, 101, 100, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 123, 34, 60, 98, 62, 65, 100, 106, 117, 115, 116, 32, 82, 101, 100,
  115, 60, 47, 98, 62, 32, 102, 111, 114, 32, 112, 105, 120, 101, 108, 115,
  32, 116, 104, 97, 116, 32, 104, 97, 118, 101, 58, 34, 125, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 76, 105, 116, 116, 108, 101, 32, 103, 114,
  101, 101, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50,
  53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 111, 109, 101, 32, 103, 114, 101, 101, 110, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 117, 99, 104, 32, 103, 114,
  101, 101, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50,
  53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 98,
  62, 65, 100, 106, 117, 115, 116, 32, 82, 101, 100, 115, 60, 47, 98, 62,
  32, 102, 111, 114, 32, 112, 105, 120, 101, 108, 115, 32, 116, 104, 97, 116,
  32, 104, 97, 118, 101, 58, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 76, 105, 116, 116, 108, 101, 32, 98, 108, 117, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 111, 109, 101, 32,
  98, 108, 117, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45,
  50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 77, 117, 99, 104, 32, 98, 108, 117, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 120, 120, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 123, 34, 60, 98, 62, 65, 100, 106, 117, 115, 116, 32, 71, 114, 101,
  101, 110, 115, 60, 47, 98, 62, 32, 102, 111, 114, 32, 112, 105, 120, 101,
  108, 115, 32, 116, 104, 97, 116, 32, 104, 97, 118, 101, 58, 34, 125, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 116, 116, 108, 101, 32,
  114, 101, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50,
  53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 111, 109, 101, 32, 114, 101, 100, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 77, 117, 99, 104, 32, 114, 101, 100, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 98, 62, 65, 100, 106,
  117, 115, 116, 32, 71, 114, 101, 101, 110, 115, 60, 47, 98, 62, 32, 102,
  111, 114, 32, 112, 105, 120, 101, 108, 115, 32, 116, 104, 97, 116, 32, 104,
  97, 118, 101, 58, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  76, 105, 116, 116, 108, 101, 32, 103, 114, 101, 101, 110, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 111, 109, 101, 32, 103,
  114, 101, 101, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45,
  50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 77, 117, 99, 104, 32, 103, 114, 101, 101, 110, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 123, 34, 60, 98, 62, 65, 100, 106, 117, 115, 116,
  32, 71, 114, 101, 101, 110, 115, 60, 47, 98, 62, 32, 102, 111, 114, 32,
  112, 105, 120, 101, 108, 115, 32, 116, 104, 97, 116, 32, 104, 97, 118, 101,
  58, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 116,
  116, 108, 101, 32, 98, 108, 117, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 111, 109, 101, 32, 98, 108, 117, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 117, 99,
  104, 32, 98, 108, 117, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 98, 62, 65,
  100, 106, 117, 115, 116, 32, 66, 108, 117, 101, 115, 60, 47, 98, 62, 32,
  102, 111, 114, 32, 112, 105, 120, 101, 108, 115, 32, 116, 104, 97, 116, 32,
  104, 97, 118, 101, 58, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 76, 105, 116, 116, 108, 101, 32, 114, 101, 100, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 111, 109, 101, 32, 114, 101,
  100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77,
  117, 99, 104, 32, 114, 101, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  123, 34, 60, 98, 62, 65, 100, 106, 117, 115, 116, 32, 66, 108, 117, 101,
  115, 60, 47, 98, 62, 32, 102, 111, 114, 32, 112, 105, 120, 101, 108, 115,
  32, 116, 104, 97, 116, 32, 104, 97, 118, 101, 58, 34, 125, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 76, 105, 116, 116, 108, 101, 32, 103, 114,
  101, 101, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50,
  53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 111, 109, 101, 32, 103, 114, 101, 101, 110, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 117, 99, 104, 32, 103, 114,
  101, 101, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50,
  53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 98,
  62, 65, 100, 106, 117, 115, 116, 32, 66, 108, 117, 101, 115, 60, 47, 98,
  62, 32, 102, 111, 114, 32, 112, 105, 120, 101, 108, 115, 32, 116, 104, 97,
  116, 32, 104, 97, 118, 101, 58, 34, 125, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 76, 105, 116, 116, 108, 101, 32, 98, 108, 117, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 111, 109, 101,
  32, 98, 108, 117, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 77, 117, 99, 104, 32, 98, 108, 117, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  123, 34, 83, 116, 114, 101, 110, 103, 116, 104, 32, 111, 102, 32, 101, 102,
  102, 101, 99, 116, 32, 102, 111, 114, 32, 83, 97, 116, 117, 114, 97, 116,
  105, 111, 110, 32, 108, 101, 118, 101, 108, 58, 34, 125, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 110, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 76, 105, 116, 116, 108, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 111, 109, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 117, 99, 104, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 115, 116,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 53, 53, 44, 48, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 80, 101, 114, 115, 101,
  114, 118, 101, 32, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  67, 108, 105, 112, 34, 44, 34, 83, 99, 97, 108, 101, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32,
  60, 105, 62, 73, 97, 105, 110, 32, 70, 101, 114, 103, 117, 115, 115, 111,
  110, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 105, 97, 105, 110, 95, 114, 103, 98, 95, 116, 111, 110, 101, 58, 10,
  45, 116, 111, 95, 114, 103, 98, 10, 45, 45, 115, 112, 108, 105, 116, 32,
  99, 10, 45, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 91,
  49, 93, 32, 48, 44, 48, 44, 36, 49, 44, 49, 50, 56, 44, 36, 50,
  44, 50, 53, 53, 44, 36, 51, 10, 45, 45, 97, 112, 112, 108, 121, 95,
  99, 117, 114, 118, 101, 91, 50, 93, 32, 48, 44, 48, 44, 36, 52, 44,
  49, 50, 56, 44, 36, 53, 44, 50, 53, 53, 44, 36, 54, 10, 45, 45,
  97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 51, 93, 32, 48,
  44, 48, 44, 36, 55, 44, 49, 50, 56, 44, 36, 56, 44, 50, 53, 53,
  44, 36, 57, 10, 45, 97, 100, 100, 91, 45, 49, 44, 45, 50, 44, 45,
  51, 93, 10, 45, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101,
  91, 49, 93, 32, 48, 44, 48, 44, 36, 49, 48, 44, 49, 50, 56, 44,
  36, 49, 49, 44, 50, 53, 53, 44, 36, 49, 50, 10, 45, 45, 97, 112,
  112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 50, 93, 32, 48, 44, 48,
  44, 36, 49, 51, 44, 49, 50, 56, 44, 36, 49, 52, 44, 50, 53, 53,
  44, 36, 49, 53, 10, 45, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114,
  118, 101, 91, 51, 93, 32, 48, 44, 48, 44, 36, 49, 54, 44, 49, 50,
  56, 44, 36, 49, 55, 44, 50, 53, 53, 44, 36, 49, 56, 10, 45, 97,
  100, 100, 91, 45, 49, 44, 45, 50, 44, 45, 51, 93, 10, 45, 45, 97,
  112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 49, 93, 32, 48, 44,
  48, 44, 36, 49, 57, 44, 49, 50, 56, 44, 36, 50, 48, 44, 50, 53,
  53, 44, 36, 50, 49, 10, 45, 45, 97, 112, 112, 108, 121, 95, 99, 117,
  114, 118, 101, 91, 50, 93, 32, 48, 44, 48, 44, 36, 50, 50, 44, 49,
  50, 56, 44, 36, 50, 51, 44, 50, 53, 53, 44, 36, 50, 52, 10, 45,
  45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 51, 93, 32,
  48, 44, 48, 44, 36, 50, 53, 44, 49, 50, 56, 44, 36, 50, 54, 44,
  50, 53, 53, 44, 36, 50, 55, 10, 45, 97, 100, 100, 91, 45, 49, 44,
  45, 50, 44, 45, 51, 93, 10, 45, 97, 100, 100, 91, 49, 44, 52, 93,
  10, 45, 97, 100, 100, 91, 50, 44, 52, 93, 10, 45, 97, 100, 100, 91,
  51, 44, 52, 93, 10, 45, 97, 91, 45, 49, 44, 45, 50, 44, 45, 51,
  93, 32, 99, 10, 45, 45, 115, 117, 98, 91, 48, 44, 49, 93, 10, 45,
  45, 114, 103, 98, 50, 104, 115, 118, 91, 48, 93, 32, 45, 115, 112, 108,
  105, 116, 91, 45, 49, 93, 32, 99, 32, 45, 114, 101, 109, 111, 118, 101,
  91, 45, 49, 44, 45, 51, 93, 32, 45, 109, 117, 108, 91, 45, 49, 93,
  32, 50, 53, 53, 10, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118,
  101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 36, 50, 56, 44, 54, 52,
  44, 36, 50, 57, 44, 49, 50, 56, 44, 36, 51, 48, 44, 49, 57, 50,
  44, 36, 51, 49, 44, 50, 53, 53, 44, 36, 51, 50, 10, 45, 99, 111,
  109, 112, 111, 115, 101, 95, 109, 117, 108, 116, 105, 112, 108, 121, 91, 45,
  49, 44, 45, 50, 93, 10, 45, 45, 115, 117, 98, 91, 48, 44, 45, 49,
  93, 10, 45, 105, 102, 32, 123, 36, 51, 51, 61, 61, 48, 125, 10, 45,
  108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 48, 93, 10, 45, 45, 108,
  117, 109, 105, 110, 97, 110, 99, 101, 91, 45, 49, 93, 10, 45, 99, 111,
  109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 101, 120, 116, 114, 97,
  99, 116, 91, 45, 49, 44, 45, 50, 93, 10, 45, 99, 111, 109, 112, 111,
  115, 101, 95, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 91, 48, 44,
  45, 49, 93, 10, 45, 107, 101, 101, 112, 91, 48, 93, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 51, 51, 61, 61, 49, 125,
  10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 45, 99, 32, 48, 44,
  50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 51, 51, 61, 61, 50, 125, 10, 45, 107, 101, 101, 112, 91, 45, 49,
  93, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105,
  102, 10, 35, 10, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
  35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
  35, 35, 35, 35, 35, 35, 35, 35, 10, 35, 64, 103, 105, 109, 112, 32,
  83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 32, 101, 113, 32, 58, 32,
  83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 95, 69, 81, 44, 32, 83,
  97, 116, 117, 114, 97, 116, 105, 111, 110, 95, 69, 81, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 123, 34, 60, 98, 62, 76, 105, 103, 104, 116, 110, 101, 115, 115, 60,
  47, 98, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66,
  108, 97, 99, 107, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45,
  49, 50, 56, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 101, 97, 114, 32, 98, 108, 97, 99, 107, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 45, 49, 50, 56, 44, 49, 50, 56, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 97, 114, 107, 32, 103,
  114, 101, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49,
  50, 56, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 77, 105, 100, 45, 100, 97, 114, 107, 32, 103, 114, 101, 121, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 50, 56, 44, 49, 50,
  56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 105, 100, 100,
  108, 101, 32, 103, 114, 101, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 45, 49, 50, 56, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 77, 105, 100, 45, 108, 105, 103, 104, 116, 32, 103,
  114, 101, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49,
  50, 56, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 76, 105, 103, 104, 116, 32, 103, 114, 101, 121, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 49, 50, 56, 44, 49, 50, 56, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 105, 103, 104, 108, 105, 103,
  104, 116, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49,
  50, 56, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 87, 104, 105, 116, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 45, 49, 50, 56, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 98, 62, 72,
  117, 101, 60, 47, 98, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 48, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49,
  50, 56, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 52, 53, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49,
  50, 56, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 57, 48, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49,
  50, 56, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 49, 51, 53, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45,
  49, 50, 56, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 49, 56, 48, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  45, 49, 50, 56, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 50, 50, 53, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 45, 49, 50, 56, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 50, 55, 48, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 45, 49, 50, 56, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 51, 49, 53, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 45, 49, 50, 56, 44, 49, 50, 56, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 51, 54, 48, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 45, 49, 50, 56, 44, 49, 50, 56, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 111, 116, 97, 116, 101, 32, 104, 117,
  101, 32, 98, 97, 110, 100, 115, 32, 61, 32, 102, 108, 111, 97, 116, 32,
  40, 48, 44, 45, 52, 53, 44, 52, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 84, 104, 105, 115,
  32, 102, 105, 108, 116, 101, 114, 32, 97, 108, 108, 111, 119, 115, 32, 121,
  111, 117, 32, 116, 111, 32, 97, 100, 106, 117, 115, 116, 32, 116, 104, 101,
  32, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 32, 98, 97, 115, 101,
  100, 32, 111, 110, 32, 116, 104, 101, 32, 76, 105, 103, 104, 116, 110, 101,
  115, 115, 32, 111, 114, 32, 72, 117, 101, 32, 111, 102, 32, 116, 104, 101,
  32, 112, 105, 120, 101, 108, 46, 32, 84, 104, 101, 32, 60, 105, 62, 82,
  111, 116, 97, 116, 101, 32, 72, 117, 101, 32, 66, 97, 110, 100, 115, 60,
  47, 105, 62, 32, 99, 111, 110, 116, 114, 111, 108, 32, 97, 108, 108, 111,
  119, 115, 32, 121, 111, 117, 32, 115, 104, 105, 102, 116, 32, 116, 104, 101,
  32, 104, 117, 101, 32, 116, 104, 97, 116, 32, 101, 97, 99, 104, 32, 98,
  97, 110, 100, 32, 99, 111, 110, 116, 114, 111, 108, 115, 32, 98, 121, 32,
  52, 53, 32, 100, 101, 103, 114, 101, 101, 115, 46, 34, 125, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60,
  105, 62, 73, 97, 105, 110, 32, 70, 101, 114, 103, 117, 115, 115, 111, 110,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 95, 69, 81, 58, 10, 45,
  116, 111, 95, 114, 103, 98, 32, 45, 114, 103, 98, 50, 104, 115, 108, 56,
  10, 45, 115, 112, 108, 105, 116, 91, 45, 49, 93, 32, 99, 10, 45, 45,
  97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 50, 93, 32, 46,
  53, 44, 48, 44, 123, 49, 50, 56, 43, 36, 49, 125, 44, 51, 49, 44,
  123, 49, 50, 56, 43, 36, 50, 125, 44, 54, 51, 44, 123, 49, 50, 56,
  43, 36, 51, 125, 44, 57, 53, 44, 123, 49, 50, 56, 43, 36, 52, 125,
  44, 49, 50, 56, 44, 123, 49, 50, 56, 43, 36, 53, 125, 44, 49, 54,
  48, 44, 123, 49, 50, 56, 43, 36, 54, 125, 44, 49, 57, 50, 44, 123,
  49, 50, 56, 43, 36, 55, 125, 44, 50, 50, 52, 44, 123, 49, 50, 56,
  43, 36, 56, 125, 44, 50, 53, 53, 44, 123, 49, 50, 56, 43, 36, 57,
  125, 10, 45, 45, 43, 91, 48, 93, 32, 123, 40, 40, 40, 36, 49, 57,
  47, 51, 54, 48, 41, 42, 50, 53, 53, 41, 41, 42, 45, 49, 125, 10,
  45, 109, 111, 100, 91, 45, 49, 93, 32, 50, 53, 53, 10, 45, 97, 112,
  112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 45, 49, 93, 32, 46, 53,
  44, 48, 44, 123, 49, 50, 56, 43, 36, 49, 48, 125, 44, 51, 49, 44,
  123, 49, 50, 56, 43, 36, 49, 49, 125, 44, 54, 51, 44, 123, 49, 50,
  56, 43, 36, 49, 50, 125, 44, 57, 53, 44, 123, 49, 50, 56, 43, 36,
  49, 51, 125, 44, 49, 50, 56, 44, 123, 49, 50, 56, 43, 36, 49, 52,
  125, 44, 49, 54, 48, 44, 123, 49, 50, 56, 43, 36, 49, 53, 125, 44,
  49, 57, 50, 44, 123, 49, 50, 56, 43, 36, 49, 54, 125, 44, 50, 50,
  52, 44, 123, 49, 50, 56, 43, 36, 49, 55, 125, 44, 50, 53, 53, 44,
  123, 49, 50, 56, 43, 36, 49, 56, 125, 10, 45, 115, 117, 98, 91, 45,
  49, 44, 45, 50, 93, 32, 49, 50, 56, 10, 45, 97, 100, 100, 91, 45,
  49, 44, 45, 50, 93, 10, 45, 109, 117, 108, 91, 45, 49, 93, 32, 50,
  10, 45, 97, 100, 100, 91, 49, 44, 51, 93, 10, 45, 99, 91, 49, 93,
  32, 48, 44, 50, 53, 53, 10, 45, 97, 112, 112, 101, 110, 100, 32, 99,
  10, 45, 104, 115, 108, 56, 50, 114, 103, 98, 10, 35, 64, 103, 105, 109,
  112, 32, 83, 101, 108, 101, 99, 116, 45, 114, 101, 112, 108, 97, 99, 101,
  32, 99, 111, 108, 111, 114, 32, 58, 32, 103, 105, 109, 112, 95, 115, 101,
  108, 101, 99, 116, 95, 99, 111, 108, 111, 114, 44, 32, 103, 105, 109, 112,
  95, 115, 101, 108, 101, 99, 116, 95, 99, 111, 108, 111, 114, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 105, 109, 105, 108, 97, 114, 105, 116, 121, 32, 115, 112, 97,
  99, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 82,
  71, 66, 91, 65, 93, 34, 44, 34, 82, 71, 66, 34, 44, 34, 89, 67,
  98, 67, 114, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101,
  110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 79, 112, 97, 99, 105,
  116, 121, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 66, 108, 117, 101, 32, 38, 32, 82, 101, 100, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 72, 117, 101, 34, 44,
  34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 84, 111, 108, 101, 114, 97, 110, 99, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 108, 101, 99, 116, 101, 100, 32, 99, 111, 108, 111, 114, 32, 61,
  32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 79, 117, 116, 112, 117, 116, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 48, 44, 34, 83, 101, 108, 101, 99, 116, 101,
  100, 32, 99, 111, 108, 111, 114, 115, 34, 44, 34, 83, 101, 108, 101, 99,
  116, 101, 100, 32, 109, 97, 115, 107, 34, 44, 34, 82, 101, 106, 101, 99,
  116, 101, 100, 32, 99, 111, 108, 111, 114, 115, 34, 44, 34, 82, 101, 106,
  101, 99, 116, 101, 100, 32, 109, 97, 115, 107, 34, 44, 34, 82, 101, 112,
  108, 97, 99, 101, 100, 32, 99, 111, 108, 111, 114, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 101, 112, 108, 97, 99, 101, 109, 101,
  110, 116, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114,
  40, 50, 53, 53, 44, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101,
  119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99,
  97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105,
  62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114,
  108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 95, 103,
  105, 109, 112, 95, 115, 101, 108, 101, 99, 116, 95, 99, 111, 108, 111, 114,
  32, 58, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 32, 45,
  116, 111, 95, 114, 103, 98, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49,
  61, 61, 50, 125, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 114, 103,
  98, 50, 121, 99, 98, 99, 114, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  49, 61, 61, 51, 125, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 52, 125, 32,
  45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 49, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 61, 61, 53, 125, 32, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 50, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61,
  61, 54, 125, 32, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 32, 51, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 61, 61, 55, 125, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45,
  114, 103, 98, 50, 121, 99, 98, 99, 114, 32, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61,
  61, 56, 125, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 114, 103, 98,
  50, 121, 99, 98, 99, 114, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 49, 44, 50, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61,
  57, 125, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 114, 103, 98, 50,
  104, 115, 118, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 48, 125, 32, 45,
  116, 111, 95, 114, 103, 98, 32, 45, 114, 103, 98, 50, 104, 115, 118, 32,
  45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 49, 10, 45, 101, 110, 100,
  105, 102, 10, 103, 105, 109, 112, 95, 115, 101, 108, 101, 99, 116, 95, 99,
  111, 108, 111, 114, 32, 58, 10, 40, 36, 52, 94, 36, 53, 94, 36, 54,
  94, 36, 55, 41, 32, 45, 95, 103, 105, 109, 112, 95, 115, 101, 108, 101,
  99, 116, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 36, 49, 32,
  99, 111, 108, 111, 114, 61, 64, 45, 49, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 32, 45, 116, 111, 95, 114, 103, 98, 97, 10, 45, 45, 95,
  103, 105, 109, 112, 95, 115, 101, 108, 101, 99, 116, 95, 99, 111, 108, 111,
  114, 32, 36, 49, 10, 45, 115, 101, 108, 101, 99, 116, 95, 99, 111, 108,
  111, 114, 91, 49, 93, 32, 36, 50, 37, 44, 36, 99, 111, 108, 111, 114,
  10, 45, 98, 91, 49, 93, 32, 36, 51, 37, 32, 45, 110, 91, 49, 93,
  32, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36, 56, 61, 61,
  48, 125, 32, 45, 115, 104, 91, 48, 93, 32, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 32, 45, 97, 110, 100, 91, 45, 49, 93, 32, 91, 49, 93,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 56, 61, 61, 49, 125, 32, 45,
  114, 109, 91, 48, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 56, 61,
  61, 50, 125, 32, 45, 45, 91, 49, 93, 32, 50, 53, 53, 32, 45, 42,
  91, 49, 93, 32, 45, 49, 32, 45, 115, 104, 91, 48, 93, 32, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 32, 45, 97, 110, 100, 91, 45, 49, 93,
  32, 91, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 56, 61, 61,
  51, 125, 32, 45, 114, 109, 91, 48, 93, 32, 45, 45, 32, 50, 53, 53,
  32, 45, 42, 32, 45, 49, 10, 45, 101, 108, 115, 101, 10, 45, 47, 91,
  49, 93, 32, 50, 53, 53, 32, 45, 45, 42, 91, 48, 44, 49, 93, 32,
  45, 45, 42, 91, 49, 93, 32, 36, 49, 48, 32, 45, 45, 42, 91, 49,
  93, 32, 36, 49, 49, 32, 45, 45, 42, 91, 49, 93, 32, 36, 49, 50,
  32, 45, 42, 91, 49, 93, 32, 36, 57, 32, 45, 97, 91, 49, 44, 45,
  51, 45, 45, 49, 93, 32, 99, 32, 45, 45, 91, 49, 44, 50, 93, 32,
  45, 43, 10, 45, 101, 110, 100, 105, 102, 10, 45, 107, 91, 48, 93, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112,
  95, 115, 101, 108, 101, 99, 116, 95, 99, 111, 108, 111, 114, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112,
  108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105,
  109, 112, 95, 115, 101, 108, 101, 99, 116, 95, 99, 111, 108, 111, 114, 32,
  36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 83,
  101, 112, 105, 97, 32, 58, 32, 103, 105, 109, 112, 95, 115, 101, 112, 105,
  97, 44, 32, 103, 105, 109, 112, 95, 115, 101, 112, 105, 97, 95, 112, 114,
  101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71,
  97, 109, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45,
  49, 46, 50, 44, 49, 46, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 66, 114, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117,
  112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47,
  50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 115, 101, 112, 105, 97, 32, 58, 10, 45,
  115, 101, 112, 105, 97, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  10, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 50, 32, 45, 97, 112,
  112, 108, 121, 95, 103, 97, 109, 109, 97, 91, 45, 49, 93, 32, 123, 49,
  48, 94, 36, 49, 125, 32, 45, 45, 91, 45, 49, 93, 32, 49, 50, 56,
  32, 45, 42, 91, 45, 49, 93, 32, 36, 50, 32, 45, 43, 91, 45, 49,
  93, 32, 123, 49, 50, 56, 43, 36, 51, 125, 32, 45, 99, 91, 45, 49,
  93, 32, 48, 44, 50, 53, 53, 10, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10,
  103, 105, 109, 112, 95, 115, 101, 112, 105, 97, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95,
  115, 101, 112, 105, 97, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64,
  103, 105, 109, 112, 32, 84, 111, 110, 101, 32, 112, 114, 101, 115, 101, 116,
  115, 32, 58, 32, 105, 97, 105, 110, 95, 116, 111, 110, 101, 95, 112, 114,
  101, 115, 101, 116, 115, 44, 32, 105, 97, 105, 110, 95, 116, 111, 110, 101,
  95, 112, 114, 101, 115, 101, 116, 115, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 80, 114, 101, 115, 101, 116, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 87, 104, 105, 116, 101, 114, 32, 87, 104, 105, 116, 101, 115,
  34, 44, 34, 87, 97, 114, 109, 32, 86, 105, 110, 116, 97, 103, 101, 34,
  44, 34, 77, 97, 103, 101, 110, 116, 97, 45, 89, 101, 108, 108, 111, 119,
  34, 44, 34, 86, 101, 108, 118, 101, 116, 105, 97, 34, 44, 34, 83, 101,
  118, 101, 110, 116, 105, 101, 115, 32, 77, 97, 103, 97, 122, 105, 110, 101,
  34, 44, 34, 70, 97, 100, 101, 100, 32, 80, 114, 105, 110, 116, 34, 44,
  34, 69, 120, 112, 105, 114, 101, 100, 32, 54, 57, 34, 44, 34, 77, 111,
  100, 101, 114, 110, 32, 70, 105, 108, 109, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 116, 114, 101, 110, 103, 116, 104, 32, 61, 32,
  102, 108, 111, 97, 116, 32, 40, 49, 48, 48, 44, 45, 50, 48, 48, 44,
  50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99,
  97, 108, 101, 32, 111, 117, 116, 112, 117, 116, 32, 61, 32, 98, 111, 111,
  108, 32, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 73, 97, 105, 110, 32, 70,
  101, 114, 103, 117, 115, 115, 111, 110, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 105, 97, 105, 110, 95, 116, 111, 110,
  101, 95, 112, 114, 101, 115, 101, 116, 115, 58, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112,
  108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91, 48,
  93, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 125, 10, 45, 45,
  105, 97, 105, 110, 95, 114, 103, 98, 95, 116, 111, 110, 101, 32, 48, 48,
  44, 49, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44,
  48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48,
  48, 44, 48, 48, 44, 49, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48,
  44, 48, 48, 44, 48, 48, 44, 50, 48, 44, 48, 48, 44, 48, 48, 44,
  50, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 50,
  53, 53, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 10,
  45, 45, 105, 97, 105, 110, 95, 99, 109, 121, 107, 95, 116, 111, 110, 101,
  32, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44,
  48, 48, 44, 45, 56, 44, 45, 50, 48, 44, 48, 48, 44, 48, 48, 44,
  48, 48, 44, 45, 52, 57, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44,
  48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 45, 50, 53, 44,
  48, 48, 44, 48, 48, 44, 49, 55, 44, 48, 44, 48, 48, 44, 48, 48,
  44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 51, 53, 44,
  45, 50, 53, 44, 49, 55, 44, 56, 44, 50, 54, 44, 51, 49, 44, 48,
  48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 49, 55, 44, 48, 48,
  44, 45, 57, 44, 45, 51, 49, 44, 50, 57, 44, 48, 48, 44, 48, 48,
  44, 45, 57, 44, 49, 56, 56, 44, 50, 53, 53, 44, 49, 56, 49, 44,
  49, 51, 51, 44, 55, 50, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 49, 61, 61, 50, 125, 10, 45, 45, 105, 97,
  105, 110, 95, 99, 109, 121, 107, 95, 116, 111, 110, 101, 32, 48, 48, 44,
  45, 51, 56, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44,
  48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48,
  48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48,
  44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 45, 49, 54,
  52, 44, 56, 56, 44, 50, 53, 53, 44, 48, 48, 44, 48, 48, 44, 48,
  48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48,
  44, 48, 48, 44, 54, 53, 44, 51, 51, 44, 45, 49, 53, 44, 48, 48,
  44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44,
  48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 45,
  50, 53, 44, 49, 50, 56, 44, 57, 50, 44, 54, 50, 44, 52, 53, 44,
  51, 56, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 49, 61, 61, 51, 125, 10, 45, 45, 105, 97, 105, 110, 95, 99,
  109, 121, 107, 95, 116, 111, 110, 101, 32, 45, 50, 53, 44, 53, 48, 44,
  48, 48, 44, 50, 53, 44, 48, 48, 44, 48, 48, 44, 50, 53, 44, 48,
  48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 50,
  53, 44, 50, 53, 44, 48, 48, 44, 45, 53, 48, 44, 48, 48, 44, 48,
  48, 44, 50, 53, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48,
  44, 48, 48, 44, 48, 50, 53, 44, 48, 48, 44, 48, 48, 44, 50, 53,
  44, 48, 48, 44, 48, 48, 44, 45, 53, 48, 44, 48, 48, 44, 48, 48,
  44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44,
  48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48,
  48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 51, 54,
  44, 49, 55, 56, 44, 50, 53, 53, 44, 49, 54, 57, 44, 57, 52, 44,
  50, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49,
  61, 61, 52, 125, 10, 45, 45, 105, 97, 105, 110, 95, 99, 109, 121, 107,
  95, 116, 111, 110, 101, 32, 50, 53, 44, 45, 53, 48, 44, 48, 48, 44,
  45, 50, 53, 44, 48, 48, 44, 48, 48, 44, 45, 50, 53, 44, 48, 48,
  44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 45, 48, 50,
  53, 44, 45, 50, 53, 44, 48, 48, 44, 53, 48, 44, 48, 48, 44, 48,
  48, 44, 45, 50, 53, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48,
  48, 44, 48, 48, 44, 45, 48, 50, 53, 44, 48, 48, 44, 48, 48, 44,
  45, 50, 53, 44, 48, 48, 44, 48, 48, 44, 53, 48, 44, 48, 48, 44,
  48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48,
  48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48,
  44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44,
  49, 55, 44, 49, 50, 48, 44, 50, 52, 48, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 52, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 49, 61, 61, 53, 125, 10, 45, 45, 105, 97, 105, 110, 95, 99,
  109, 121, 107, 95, 116, 111, 110, 101, 32, 48, 48, 48, 44, 48, 48, 44,
  48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48,
  48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 45, 54, 48, 44, 48,
  48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48,
  48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 45, 50, 50, 44, 52,
  48, 44, 49, 54, 49, 44, 48, 48, 48, 44, 48, 48, 44, 48, 48, 44,
  48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 50, 56,
  44, 51, 51, 44, 51, 51, 44, 49, 54, 44, 48, 48, 44, 48, 48, 44,
  48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48,
  48, 44, 48, 48, 44, 55, 55, 44, 45, 56, 44, 45, 56, 48, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 49, 61, 61, 54, 125, 10, 45, 45, 105, 97, 105, 110, 95, 99,
  109, 121, 107, 95, 116, 111, 110, 101, 32, 48, 48, 48, 44, 48, 48, 44,
  48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48,
  48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48,
  48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48,
  44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 55, 44, 45, 50, 48,
  44, 45, 51, 51, 44, 48, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48,
  48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48,
  44, 52, 56, 44, 45, 54, 53, 44, 45, 55, 55, 44, 48, 48, 48, 44,
  48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48,
  48, 44, 48, 48, 44, 48, 48, 44, 52, 53, 44, 52, 53, 44, 48, 48,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 48, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 49, 61, 61, 55, 125, 10, 45, 45, 105, 97,
  105, 110, 95, 99, 109, 121, 107, 95, 116, 111, 110, 101, 32, 48, 48, 48,
  44, 50, 48, 44, 48, 48, 44, 48, 48, 44, 48, 56, 44, 48, 48, 44,
  48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 45, 50, 51, 44,
  48, 48, 44, 48, 48, 48, 44, 45, 49, 51, 44, 48, 48, 44, 48, 44,
  49, 55, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 45,
  49, 44, 50, 57, 44, 48, 48, 44, 48, 48, 48, 44, 48, 48, 44, 48,
  48, 44, 48, 48, 44, 48, 48, 44, 45, 49, 50, 44, 48, 48, 44, 48,
  48, 44, 48, 48, 44, 49, 57, 44, 54, 56, 44, 49, 56, 44, 48, 48,
  48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 48, 48,
  44, 48, 48, 44, 48, 48, 44, 48, 48, 44, 45, 53, 44, 53, 53, 44,
  45, 49, 53, 44, 49, 50, 56, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 48, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 45, 115, 117, 98, 91, 48, 44, 49, 93, 10, 45, 109,
  117, 108, 91, 45, 49, 93, 32, 123, 123, 36, 50, 47, 49, 48, 48, 125,
  42, 45, 49, 125, 10, 45, 43, 91, 48, 44, 45, 49, 93, 10, 45, 107,
  101, 101, 112, 91, 48, 93, 10, 45, 105, 102, 32, 123, 36, 51, 61, 61,
  48, 125, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 101, 108, 115,
  101, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 10, 35, 35, 35, 35, 35,
  35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
  35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
  35, 35, 10, 35, 64, 103, 105, 109, 112, 32, 85, 115, 101, 114, 45, 100,
  101, 102, 105, 110, 101, 100, 32, 58, 32, 103, 105, 109, 112, 95, 99, 117,
  115, 116, 111, 109, 95, 116, 114, 97, 110, 115, 102, 111, 114, 109, 44, 32,
  103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 116, 114, 97, 110,
  115, 102, 111, 114, 109, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  101, 100, 32, 45, 32, 103, 114, 101, 101, 110, 32, 45, 32, 98, 108, 117,
  101, 32, 45, 32, 97, 108, 112, 104, 97, 32, 61, 32, 116, 101, 120, 116,
  123, 34, 105, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  101, 100, 32, 45, 32, 103, 114, 101, 101, 110, 32, 45, 32, 98, 108, 117,
  101, 32, 61, 32, 116, 101, 120, 116, 123, 34, 105, 32, 43, 32, 57, 48,
  42, 40, 120, 47, 119, 41, 42, 99, 111, 115, 40, 105, 47, 49, 48, 41,
  34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 100, 32,
  61, 32, 116, 101, 120, 116, 123, 34, 105, 34, 125, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 71, 114, 101, 101, 110, 32, 61, 32, 116, 101, 120,
  116, 123, 34, 105, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  66, 108, 117, 101, 32, 61, 32, 116, 101, 120, 116, 123, 34, 105, 34, 125,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 108, 112, 104, 97, 32,
  61, 32, 116, 101, 120, 116, 123, 34, 105, 34, 125, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 86, 97, 108, 117, 101, 32, 110, 111, 114, 109, 97,
  108, 105, 122, 97, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 78, 111, 110, 101, 34, 44, 34, 82, 71, 66, 34, 44, 34,
  82, 71, 66, 65, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60,
  105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101,
  114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103,
  105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 116, 114, 97, 110, 115,
  102, 111, 114, 109, 32, 58, 10, 45, 116, 111, 95, 114, 103, 98, 97, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 102, 91, 45, 49,
  93, 32, 34, 36, 49, 34, 10, 45, 115, 91, 45, 49, 93, 32, 99, 32,
  45, 97, 91, 45, 52, 45, 45, 50, 93, 32, 99, 32, 45, 102, 91, 45,
  50, 93, 32, 34, 36, 50, 34, 10, 45, 115, 91, 45, 50, 93, 32, 99,
  32, 45, 102, 91, 45, 52, 93, 32, 34, 36, 51, 34, 32, 45, 102, 91,
  45, 51, 93, 32, 34, 36, 52, 34, 32, 45, 102, 91, 45, 50, 93, 32,
  34, 36, 53, 34, 32, 45, 102, 91, 45, 49, 93, 32, 34, 36, 54, 34,
  10, 45, 105, 102, 32, 123, 36, 55, 61, 61, 48, 125, 32, 45, 97, 91,
  45, 52, 45, 45, 49, 93, 32, 99, 32, 45, 99, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 10, 45, 101, 108, 105, 102, 32, 123, 36, 55, 61,
  61, 49, 125, 32, 45, 97, 91, 45, 52, 45, 45, 50, 93, 32, 99, 32,
  45, 110, 91, 45, 50, 93, 32, 48, 44, 50, 53, 53, 32, 45, 99, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 97, 91, 45, 50, 44,
  45, 49, 93, 32, 99, 10, 45, 101, 108, 115, 101, 32, 45, 97, 91, 45,
  52, 45, 45, 49, 93, 32, 99, 32, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 109, 118, 91,
  45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105,
  109, 112, 32, 86, 105, 110, 116, 97, 103, 101, 32, 115, 116, 121, 108, 101,
  32, 58, 32, 103, 105, 109, 112, 95, 116, 107, 95, 118, 105, 110, 116, 97,
  103, 101, 44, 32, 103, 105, 109, 112, 95, 116, 107, 95, 118, 105, 110, 116,
  97, 103, 101, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 69, 120, 112, 111, 115, 117, 114, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 45, 53, 44, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116, 114, 97,
  115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 56, 53, 44,
  48, 46, 53, 44, 49, 46, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 55, 44, 48, 44, 52, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 100, 111, 119, 115, 32, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 56, 48, 44, 48, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 72, 105, 103, 104, 108, 105, 103, 104, 116, 115, 32, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 48, 48, 44, 49, 50, 56, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 84, 114, 97, 110, 115, 105, 116, 105, 111,
  110, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 53, 44, 48, 44, 53, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 111, 108, 111, 114, 32, 115, 104, 97, 100, 111, 119, 115, 32, 61,
  32, 99, 111, 108, 111, 114, 40, 49, 52, 55, 44, 50, 54, 44, 49, 54,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 116, 114, 101,
  110, 103, 116, 104, 32, 115, 104, 97, 100, 111, 119, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 51, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 109, 105, 100,
  116, 111, 110, 101, 115, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 51,
  53, 44, 50, 50, 48, 44, 49, 55, 54, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 116, 114, 101, 110, 103, 116, 104, 32, 109, 105, 100,
  116, 111, 110, 101, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  52, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 108, 111, 114, 32, 104, 105, 103, 104, 108, 105, 103, 104, 116, 115,
  32, 61, 32, 99, 111, 108, 111, 114, 40, 49, 57, 48, 44, 49, 56, 49,
  44, 49, 48, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  116, 114, 101, 110, 103, 116, 104, 32, 104, 105, 103, 104, 108, 105, 103, 104,
  116, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 50, 44, 48,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108,
  111, 114, 32, 111, 118, 101, 114, 97, 108, 108, 32, 101, 102, 102, 101, 99,
  116, 32, 61, 32, 99, 111, 108, 111, 114, 40, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111,
  114, 32, 101, 102, 102, 101, 99, 116, 32, 109, 111, 100, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 101, 120, 99, 108, 117, 115, 105, 111,
  110, 34, 44, 34, 111, 118, 101, 114, 108, 97, 121, 34, 44, 34, 115, 111,
  102, 116, 32, 32, 76, 105, 103, 104, 116, 34, 44, 34, 109, 117, 108, 116,
  105, 112, 108, 121, 34, 44, 34, 115, 99, 114, 101, 101, 110, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 116, 114, 101, 110, 103, 116,
  104, 32, 101, 102, 102, 101, 99, 116, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 51, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 105,
  103, 110, 101, 116, 116, 101, 32, 115, 105, 122, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 50, 53, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 86, 105, 103, 110, 101, 116, 116, 101, 32,
  115, 116, 114, 101, 110, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62,
  84, 111, 109, 32, 75, 101, 105, 108, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48, 54, 47, 48, 52,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  108, 105, 110, 107, 40, 34, 70, 105, 108, 116, 101, 114, 32, 101, 120, 112,
  108, 97, 105, 110, 101, 100, 32, 32, 104, 101, 114, 101, 34, 44, 104, 116,
  116, 112, 58, 47, 47, 119, 119, 119, 46, 116, 107, 102, 105, 108, 116, 101,
  114, 46, 98, 112, 108, 97, 99, 101, 100, 46, 110, 101, 116, 47, 84, 75,
  70, 105, 108, 116, 101, 114, 37, 50, 48, 102, 105, 108, 116, 101, 114, 46,
  104, 116, 109, 108, 41, 10, 103, 105, 109, 112, 95, 116, 107, 95, 118, 105,
  110, 116, 97, 103, 101, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 116, 111, 95, 114, 103,
  98, 91, 48, 93, 32, 45, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101,
  91, 48, 93, 32, 45, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91,
  48, 93, 32, 45, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 48,
  93, 10, 45, 103, 105, 109, 112, 95, 109, 105, 120, 95, 108, 97, 98, 91,
  48, 93, 32, 36, 50, 44, 123, 36, 49, 42, 49, 48, 125, 44, 48, 44,
  36, 51, 44, 48, 44, 48, 44, 36, 51, 44, 48, 44, 48, 44, 48, 44,
  50, 44, 48, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97,
  110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 91,
  45, 49, 93, 32, 49, 44, 49, 44, 48, 44, 48, 44, 52, 44, 123, 36,
  52, 47, 50, 46, 53, 53, 125, 44, 49, 48, 48, 44, 50, 53, 54, 44,
  48, 44, 49, 44, 48, 44, 50, 44, 48, 44, 48, 10, 45, 116, 107, 95,
  103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111,
  99, 101, 115, 115, 105, 110, 103, 91, 45, 50, 93, 32, 49, 44, 49, 44,
  48, 44, 48, 44, 52, 44, 123, 36, 52, 47, 50, 46, 53, 53, 125, 44,
  123, 36, 53, 47, 50, 46, 53, 53, 125, 44, 50, 53, 54, 44, 48, 44,
  48, 44, 48, 44, 50, 44, 48, 44, 48, 10, 45, 116, 107, 95, 103, 105,
  109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101,
  115, 115, 105, 110, 103, 91, 45, 51, 93, 32, 49, 44, 49, 44, 48, 44,
  48, 44, 52, 44, 48, 44, 123, 36, 53, 47, 50, 46, 53, 53, 125, 44,
  50, 53, 54, 44, 48, 44, 49, 44, 48, 44, 50, 44, 48, 44, 48, 10,
  45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 49, 44, 45, 50, 44, 45,
  51, 93, 32, 45, 103, 105, 109, 112, 95, 103, 97, 117, 115, 115, 105, 97,
  110, 95, 98, 108, 117, 114, 91, 45, 49, 44, 45, 50, 44, 45, 51, 93,
  32, 36, 54, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 10,
  45, 45, 102, 99, 91, 48, 93, 32, 36, 55, 44, 36, 56, 44, 36, 57,
  32, 45, 45, 102, 99, 91, 48, 93, 32, 36, 49, 49, 44, 36, 49, 50,
  44, 36, 49, 51, 32, 45, 45, 102, 99, 91, 48, 93, 32, 36, 49, 53,
  44, 36, 49, 54, 44, 36, 49, 55, 32, 45, 116, 111, 95, 114, 103, 98,
  97, 91, 45, 49, 44, 45, 50, 44, 45, 51, 93, 10, 45, 115, 91, 45,
  49, 93, 32, 99, 32, 45, 114, 118, 91, 45, 49, 44, 45, 57, 93, 32,
  45, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108, 116, 105, 112, 108,
  121, 91, 45, 49, 44, 45, 57, 93, 32, 45, 109, 118, 91, 45, 56, 93,
  32, 57, 32, 45, 97, 91, 45, 52, 44, 45, 51, 44, 45, 50, 44, 45,
  49, 93, 32, 99, 10, 45, 115, 91, 45, 50, 93, 32, 99, 32, 45, 114,
  118, 91, 45, 50, 44, 45, 56, 93, 32, 45, 99, 111, 109, 112, 111, 115,
  101, 95, 109, 117, 108, 116, 105, 112, 108, 121, 91, 45, 50, 44, 45, 56,
  93, 32, 45, 109, 118, 91, 45, 55, 93, 32, 55, 32, 45, 97, 91, 45,
  53, 44, 45, 52, 44, 45, 51, 44, 45, 50, 93, 32, 99, 10, 45, 115,
  91, 45, 51, 93, 32, 99, 32, 45, 114, 118, 91, 45, 51, 44, 45, 55,
  93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108, 116, 105,
  112, 108, 121, 91, 45, 51, 44, 45, 55, 93, 32, 45, 109, 118, 91, 45,
  54, 93, 32, 53, 32, 45, 97, 91, 45, 54, 44, 45, 53, 44, 45, 52,
  44, 45, 51, 93, 32, 99, 10, 45, 45, 102, 99, 91, 48, 93, 32, 36,
  49, 57, 44, 36, 50, 48, 44, 36, 50, 49, 32, 45, 114, 118, 91, 45,
  49, 44, 45, 53, 93, 10, 45, 105, 102, 32, 123, 36, 50, 50, 61, 61,
  48, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 101, 120, 99, 108, 117, 115, 105, 111, 110, 91, 45, 49, 44, 45, 53,
  93, 32, 36, 50, 51, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 50,
  61, 61, 49, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 111, 118, 101, 114, 108, 97, 121, 91, 45, 49, 44, 45, 53,
  93, 32, 36, 50, 51, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 50,
  61, 61, 50, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 115, 111, 102, 116, 108, 105, 103, 104, 116, 91, 45, 49, 44,
  45, 53, 93, 32, 36, 50, 51, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  50, 50, 61, 61, 51, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 109, 117, 108, 116, 105, 112, 108, 121, 91, 45, 49,
  44, 45, 53, 93, 32, 36, 50, 51, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 50, 50, 61, 61, 52, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 115, 99, 114, 101, 101, 110, 91, 45, 49, 44,
  45, 53, 93, 32, 36, 50, 51, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 118, 91, 45, 51, 44, 45, 52, 93, 32, 45, 103, 105, 109, 112, 95,
  99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103, 104, 116, 101, 110, 91,
  45, 51, 44, 45, 52, 93, 32, 36, 49, 48, 10, 45, 114, 118, 91, 45,
  50, 44, 45, 51, 93, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 111, 118, 101, 114, 108, 97, 121, 91, 45, 50, 44, 45,
  51, 93, 32, 36, 49, 52, 10, 45, 114, 118, 91, 45, 49, 44, 45, 50,
  93, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95,
  100, 97, 114, 107, 101, 110, 91, 45, 49, 44, 45, 50, 93, 32, 36, 49,
  56, 10, 45, 105, 102, 32, 123, 36, 50, 53, 33, 61, 48, 125, 10, 45,
  45, 102, 99, 91, 48, 93, 32, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 32, 45, 103, 105, 109, 112, 95, 102, 114, 97, 109, 101, 95, 114,
  111, 117, 110, 100, 91, 45, 49, 93, 32, 50, 44, 36, 50, 52, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 49, 48, 48,
  44, 48, 46, 49, 44, 51, 10, 45, 103, 105, 109, 112, 95, 103, 97, 117,
  115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 45, 49, 93, 32, 123,
  36, 54, 42, 53, 125, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 44,
  48, 10, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 32, 45, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108, 116, 105,
  112, 108, 121, 91, 45, 49, 44, 45, 50, 93, 32, 36, 50, 53, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 103, 105, 109, 112, 95, 116, 107, 95, 118, 105, 110, 116, 97, 103,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 116, 107, 95, 118, 105, 110, 116, 97, 103,
  101, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35,
  64, 103, 105, 109, 112, 32, 90, 111, 110, 101, 32, 115, 121, 115, 116, 101,
  109, 32, 58, 32, 103, 105, 109, 112, 95, 122, 111, 110, 101, 115, 121, 115,
  116, 101, 109, 44, 32, 103, 105, 109, 112, 95, 122, 111, 110, 101, 115, 121,
  115, 116, 101, 109, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 100, 111, 119, 115,
  32, 122, 111, 110, 101, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49, 44,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 105, 103, 104,
  108, 105, 103, 104, 116, 115, 32, 122, 111, 110, 101, 32, 61, 32, 105, 110,
  116, 40, 49, 48, 44, 54, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 71, 97, 109, 109, 97, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 66, 108, 97, 99, 107, 32, 112, 111, 105, 110, 116, 32, 61,
  32, 105, 110, 116, 40, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 87, 104, 105, 116, 101, 32, 112, 111, 105,
  110, 116, 32, 61, 32, 105, 110, 116, 40, 50, 53, 53, 44, 48, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 84, 111, 109, 32,
  75, 101, 105, 108, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 49, 47, 48, 50, 47, 49, 51, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  122, 111, 110, 101, 115, 121, 115, 116, 101, 109, 32, 58, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45,
  116, 111, 95, 114, 103, 98, 32, 45, 114, 103, 98, 50, 108, 97, 98, 32,
  45, 115, 32, 99, 32, 45, 110, 91, 48, 93, 32, 123, 123, 36, 49, 45,
  49, 125, 42, 49, 48, 125, 37, 44, 123, 36, 50, 42, 49, 48, 125, 37,
  10, 45, 97, 32, 99, 32, 45, 108, 97, 98, 50, 114, 103, 98, 32, 45,
  116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95,
  112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 36, 51, 44, 36, 52,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 48, 48, 44, 50, 53, 54,
  44, 48, 44, 48, 44, 48, 44, 50, 44, 55, 44, 48, 10, 45, 103, 105,
  109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 32, 48,
  44, 36, 53, 44, 48, 44, 36, 54, 44, 50, 53, 53, 44, 45, 49, 44,
  49, 50, 56, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50,
  56, 44, 50, 53, 53, 44, 49, 44, 55, 44, 48, 44, 48, 44, 48, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112,
  95, 122, 111, 110, 101, 115, 121, 115, 116, 101, 109, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112,
  95, 122, 111, 110, 101, 115, 121, 115, 116, 101, 109, 32, 36, 123, 49, 45,
  45, 50, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32,
  95, 10, 35, 64, 103, 105, 109, 112, 32, 60, 98, 62, 67, 111, 110, 116,
  111, 117, 114, 115, 60, 47, 98, 62, 10, 35, 64, 103, 105, 109, 112, 32,
  67, 111, 110, 118, 111, 108, 118, 101, 32, 58, 32, 103, 105, 109, 112, 95,
  99, 111, 110, 118, 111, 108, 118, 101, 44, 32, 103, 105, 109, 112, 95, 99,
  111, 110, 118, 111, 108, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 75, 101, 114, 110,
  101, 108, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 67, 117, 115,
  116, 111, 109, 34, 44, 34, 65, 118, 101, 114, 97, 103, 101, 32, 51, 120,
  51, 34, 44, 34, 65, 118, 101, 114, 97, 103, 101, 32, 53, 120, 53, 34,
  44, 34, 65, 118, 101, 114, 97, 103, 101, 32, 55, 120, 55, 34, 44, 34,
  65, 118, 101, 114, 97, 103, 101, 32, 57, 120, 57, 34, 44, 34, 80, 114,
  101, 119, 105, 116, 116, 45, 88, 34, 44, 34, 80, 114, 101, 119, 105, 116,
  116, 45, 89, 34, 44, 34, 83, 111, 98, 101, 108, 45, 88, 34, 44, 34,
  83, 111, 98, 101, 108, 45, 89, 34, 44, 34, 82, 111, 116, 105, 110, 118,
  45, 88, 34, 44, 34, 82, 111, 116, 105, 110, 118, 45, 89, 34, 44, 34,
  76, 97, 112, 108, 97, 99, 105, 97, 110, 34, 44, 34, 82, 111, 98, 101,
  114, 116, 32, 67, 114, 111, 115, 115, 32, 49, 34, 44, 34, 82, 111, 98,
  101, 114, 116, 32, 67, 114, 111, 115, 115, 32, 50, 34, 44, 34, 73, 109,
  112, 117, 108, 115, 101, 115, 32, 53, 120, 53, 34, 44, 34, 73, 109, 112,
  117, 108, 115, 101, 115, 32, 55, 120, 55, 34, 44, 34, 73, 109, 112, 117,
  108, 115, 101, 115, 32, 57, 120, 57, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 66, 111, 117, 110, 100, 97, 114, 121, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 49, 44, 34, 68, 105, 114, 105, 99, 104, 108,
  101, 116, 34, 44, 34, 78, 101, 117, 109, 97, 110, 110, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60,
  98, 62, 78, 111, 116, 101, 58, 60, 47, 98, 62, 32, 73, 102, 32, 112,
  97, 114, 97, 109, 101, 116, 101, 114, 32, 60, 105, 62, 75, 101, 114, 110,
  101, 108, 60, 47, 105, 62, 32, 105, 115, 32, 115, 101, 116, 32, 116, 111,
  32, 60, 105, 62, 67, 117, 115, 116, 111, 109, 60, 47, 105, 62, 44, 32,
  105, 116, 32, 117, 115, 101, 115, 32, 116, 104, 101, 32, 99, 117, 115, 116,
  111, 109, 32, 99, 111, 110, 118, 111, 108, 117, 116, 105, 111, 110, 32, 107,
  101, 114, 110, 101, 108, 32, 100, 101, 102, 105, 110, 101, 100, 32, 98, 101,
  108, 111, 119, 46, 32, 85, 115, 101, 32, 99, 111, 109, 109, 97, 115, 32,
  97, 110, 100, 32, 115, 101, 109, 105, 99, 111, 108, 111, 110, 115, 32, 97,
  115, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 115, 32, 102, 111, 114,
  32, 114, 101, 115, 46, 32, 109, 97, 116, 114, 105, 120, 32, 99, 111, 108,
  117, 109, 110, 115, 32, 97, 110, 100, 32, 114, 111, 119, 115, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 117, 115, 116, 111, 109, 32, 107, 101, 114, 110, 101, 108, 32,
  61, 32, 116, 101, 120, 116, 40, 34, 48, 44, 49, 44, 48, 59, 49, 44,
  45, 52, 44, 49, 59, 48, 44, 49, 44, 48, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62,
  78, 111, 116, 101, 58, 60, 47, 98, 62, 32, 75, 101, 114, 110, 101, 108,
  32, 109, 117, 108, 116, 105, 112, 108, 105, 101, 114, 32, 105, 115, 32, 117,
  115, 101, 102, 117, 108, 32, 111, 110, 108, 121, 32, 119, 104, 101, 110, 32,
  112, 97, 114, 97, 109, 101, 116, 101, 114, 32, 60, 105, 62, 86, 97, 108,
  117, 101, 32, 114, 97, 110, 103, 101, 60, 47, 105, 62, 32, 105, 115, 32,
  115, 101, 116, 32, 116, 111, 32, 60, 105, 62, 67, 117, 116, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 86, 97, 108, 117, 101, 32, 114, 97, 110, 103,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 67, 117,
  116, 34, 44, 34, 78, 111, 114, 109, 97, 108, 105, 122, 101, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 75, 101, 114, 110, 101, 108, 32,
  109, 117, 108, 116, 105, 112, 108, 105, 101, 114, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 44, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44,
  34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101,
  34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32,
  99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101,
  100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97,
  116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101,
  34, 44, 34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71,
  114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108,
  112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97,
  116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84,
  115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51,
  47, 48, 54, 47, 48, 54, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 99, 111, 110, 118, 111,
  108, 118, 101, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 34, 45, 95, 103, 105, 109, 112, 95, 99, 111,
  110, 118, 111, 108, 118, 101, 32, 36, 49, 44, 36, 50, 44, 92, 34, 36,
  51, 92, 34, 44, 36, 123, 52, 45, 45, 51, 125, 34, 44, 36, 45, 50,
  44, 48, 10, 95, 103, 105, 109, 112, 95, 99, 111, 110, 118, 111, 108, 118,
  101, 32, 58, 10, 45, 105, 102, 32, 36, 49, 32, 45, 95, 103, 105, 109,
  112, 95, 99, 111, 110, 118, 111, 108, 118, 101, 36, 49, 91, 93, 32, 45,
  101, 108, 115, 101, 32, 40, 36, 51, 41, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 33, 36, 52, 125, 32, 45, 42, 91, 45, 49,
  93, 32, 36, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 99, 111, 110,
  118, 111, 108, 118, 101, 91, 48, 45, 45, 50, 93, 32, 91, 45, 49, 93,
  44, 36, 50, 10, 45, 105, 102, 32, 36, 52, 32, 45, 110, 32, 48, 44,
  50, 53, 53, 32, 45, 101, 108, 115, 101, 32, 45, 99, 32, 48, 44, 50,
  53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 49,
  93, 10, 95, 103, 105, 109, 112, 95, 99, 111, 110, 118, 111, 108, 118, 101,
  49, 32, 58, 32, 51, 44, 51, 32, 45, 102, 32, 49, 32, 45, 110, 111,
  114, 109, 97, 108, 105, 122, 101, 95, 115, 117, 109, 10, 95, 103, 105, 109,
  112, 95, 99, 111, 110, 118, 111, 108, 118, 101, 50, 32, 58, 32, 53, 44,
  53, 32, 45, 102, 32, 49, 32, 45, 110, 111, 114, 109, 97, 108, 105, 122,
  101, 95, 115, 117, 109, 10, 95, 103, 105, 109, 112, 95, 99, 111, 110, 118,
  111, 108, 118, 101, 51, 32, 58, 32, 55, 44, 55, 32, 45, 102, 32, 49,
  32, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 115, 117, 109, 10,
  95, 103, 105, 109, 112, 95, 99, 111, 110, 118, 111, 108, 118, 101, 52, 32,
  58, 32, 57, 44, 57, 32, 45, 102, 32, 49, 32, 45, 110, 111, 114, 109,
  97, 108, 105, 122, 101, 95, 115, 117, 109, 10, 95, 103, 105, 109, 112, 95,
  99, 111, 110, 118, 111, 108, 118, 101, 53, 32, 58, 32, 40, 49, 44, 48,
  44, 45, 49, 59, 49, 44, 48, 44, 45, 49, 59, 49, 44, 48, 44, 45,
  49, 41, 10, 95, 103, 105, 109, 112, 95, 99, 111, 110, 118, 111, 108, 118,
  101, 54, 32, 58, 32, 40, 49, 44, 49, 44, 49, 59, 48, 44, 48, 44,
  48, 59, 45, 49, 44, 45, 49, 44, 45, 49, 41, 10, 95, 103, 105, 109,
  112, 95, 99, 111, 110, 118, 111, 108, 118, 101, 55, 32, 58, 32, 40, 49,
  44, 48, 44, 45, 49, 59, 50, 44, 48, 44, 45, 50, 59, 49, 44, 48,
  44, 45, 49, 41, 10, 95, 103, 105, 109, 112, 95, 99, 111, 110, 118, 111,
  108, 118, 101, 56, 32, 58, 32, 40, 49, 44, 50, 44, 49, 59, 48, 44,
  48, 44, 48, 59, 45, 49, 44, 45, 50, 44, 45, 49, 41, 10, 95, 103,
  105, 109, 112, 95, 99, 111, 110, 118, 111, 108, 118, 101, 57, 32, 58, 32,
  97, 61, 123, 48, 46, 50, 53, 42, 40, 50, 45, 115, 113, 114, 116, 40,
  50, 41, 41, 125, 32, 98, 61, 123, 48, 46, 53, 42, 40, 115, 113, 114,
  116, 40, 50, 41, 45, 49, 41, 125, 32, 40, 36, 97, 44, 48, 44, 45,
  36, 97, 59, 36, 98, 44, 48, 44, 45, 36, 98, 59, 36, 97, 44, 48,
  44, 45, 36, 97, 41, 10, 95, 103, 105, 109, 112, 95, 99, 111, 110, 118,
  111, 108, 118, 101, 49, 48, 32, 58, 32, 97, 61, 123, 48, 46, 50, 53,
  42, 40, 50, 45, 115, 113, 114, 116, 40, 50, 41, 41, 125, 32, 98, 61,
  123, 48, 46, 53, 42, 40, 115, 113, 114, 116, 40, 50, 41, 45, 49, 41,
  125, 32, 40, 36, 97, 44, 36, 98, 44, 36, 97, 59, 48, 44, 48, 44,
  48, 59, 45, 36, 97, 44, 45, 36, 98, 44, 45, 36, 97, 41, 10, 95,
  103, 105, 109, 112, 95, 99, 111, 110, 118, 111, 108, 118, 101, 49, 49, 32,
  58, 32, 40, 48, 44, 49, 44, 48, 59, 49, 44, 45, 52, 44, 49, 59,
  48, 44, 49, 44, 48, 41, 10, 95, 103, 105, 109, 112, 95, 99, 111, 110,
  118, 111, 108, 118, 101, 49, 50, 32, 58, 32, 40, 49, 44, 48, 59, 48,
  44, 45, 49, 41, 10, 95, 103, 105, 109, 112, 95, 99, 111, 110, 118, 111,
  108, 118, 101, 49, 51, 32, 58, 32, 40, 48, 44, 49, 59, 45, 49, 44,
  48, 41, 10, 95, 103, 105, 109, 112, 95, 99, 111, 110, 118, 111, 108, 118,
  101, 49, 52, 32, 58, 32, 51, 44, 51, 32, 45, 102, 32, 49, 32, 45,
  114, 32, 55, 44, 55, 44, 49, 44, 49, 44, 52, 44, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32,
  45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 115, 117, 109, 10, 95,
  103, 105, 109, 112, 95, 99, 111, 110, 118, 111, 108, 118, 101, 49, 53, 32,
  58, 32, 51, 44, 51, 32, 45, 102, 32, 49, 32, 45, 114, 32, 57, 44,
  57, 44, 49, 44, 49, 44, 52, 44, 48, 44, 48, 46, 53, 44, 48, 46,
  53, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 45, 110, 111, 114,
  109, 97, 108, 105, 122, 101, 95, 115, 117, 109, 10, 95, 103, 105, 109, 112,
  95, 99, 111, 110, 118, 111, 108, 118, 101, 49, 54, 32, 58, 32, 51, 44,
  51, 32, 45, 102, 32, 49, 32, 45, 114, 32, 49, 49, 44, 49, 49, 44,
  49, 44, 49, 44, 52, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32,
  45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 45, 110, 111, 114, 109, 97,
  108, 105, 122, 101, 95, 115, 117, 109, 10, 103, 105, 109, 112, 95, 99, 111,
  110, 118, 111, 108, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 99, 111, 110, 118,
  111, 108, 118, 101, 32, 36, 49, 44, 36, 50, 44, 92, 34, 36, 51, 92,
  34, 44, 36, 123, 52, 45, 45, 49, 125, 34, 44, 36, 45, 49, 10, 35,
  64, 103, 105, 109, 112, 32, 67, 117, 114, 118, 97, 116, 117, 114, 101, 32,
  58, 32, 103, 105, 109, 112, 95, 99, 117, 114, 118, 97, 116, 117, 114, 101,
  44, 32, 103, 105, 109, 112, 95, 99, 117, 114, 118, 97, 116, 117, 114, 101,
  95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 105, 110, 32, 116, 104, 114,
  101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 77, 97, 120, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 48, 48, 44, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 98, 115, 111, 108,
  117, 116, 101, 32, 118, 97, 108, 117, 101, 32, 61, 32, 98, 111, 111, 108,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 101, 103,
  97, 116, 105, 118, 101, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32, 98,
  111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99,
  97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65,
  117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32,
  84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59,
  60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49,
  48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 99, 117, 114, 118,
  97, 116, 117, 114, 101, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116,
  95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91, 48, 93, 10, 45,
  98, 32, 36, 49, 32, 45, 105, 101, 101, 10, 45, 105, 102, 32, 36, 52,
  32, 45, 97, 98, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 99, 32,
  36, 50, 37, 44, 36, 51, 37, 10, 45, 105, 102, 32, 36, 53, 32, 45,
  110, 101, 103, 97, 116, 105, 118, 101, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45,
  97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  103, 105, 109, 112, 95, 99, 117, 114, 118, 97, 116, 117, 114, 101, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115,
  112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103,
  105, 109, 112, 95, 99, 117, 114, 118, 97, 116, 117, 114, 101, 32, 36, 123,
  94, 48, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32,
  68, 105, 102, 102, 101, 114, 101, 110, 99, 101, 32, 111, 102, 32, 103, 97,
  117, 115, 115, 105, 97, 110, 115, 32, 58, 32, 103, 105, 109, 112, 95, 100,
  111, 103, 44, 32, 103, 105, 109, 112, 95, 100, 111, 103, 95, 112, 114, 101,
  118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 49, 115, 116, 32, 118, 97, 114, 105, 97, 110, 99, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 46, 52, 44, 48, 44, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 50, 110, 100, 32, 118, 97, 114, 105,
  97, 110, 99, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 53,
  44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84,
  104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 52, 57, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 101, 103, 97, 116, 105, 118, 101, 32, 99, 111, 108, 111, 114,
  115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32,
  116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70,
  117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116,
  101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68,
  117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68,
  97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38,
  35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112,
  95, 100, 111, 103, 32, 58, 10, 45, 100, 111, 103, 32, 36, 49, 37, 44,
  36, 50, 37, 10, 45, 99, 32, 36, 51, 37, 44, 123, 49, 48, 48, 45,
  36, 51, 125, 37, 10, 45, 105, 102, 32, 36, 52, 32, 45, 110, 101, 103,
  97, 116, 105, 118, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 110, 32,
  48, 44, 50, 53, 53, 10, 103, 105, 109, 112, 95, 100, 111, 103, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115,
  112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103,
  105, 109, 112, 95, 100, 111, 103, 32, 36, 123, 94, 48, 125, 34, 44, 36,
  45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 68, 105, 115, 116, 97, 110,
  99, 101, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32, 58, 32, 103,
  105, 109, 112, 95, 100, 105, 115, 116, 97, 110, 99, 101, 44, 32, 103, 105,
  109, 112, 95, 100, 105, 115, 116, 97, 110, 99, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  86, 97, 108, 117, 101, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44,
  48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  77, 101, 116, 114, 105, 99, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  50, 44, 34, 67, 104, 101, 98, 121, 115, 104, 101, 118, 34, 44, 34, 77,
  97, 110, 104, 97, 116, 116, 97, 110, 34, 44, 34, 69, 117, 99, 108, 105,
  100, 101, 97, 110, 34, 44, 34, 83, 113, 117, 97, 114, 101, 100, 45, 69,
  117, 99, 108, 105, 100, 101, 97, 110, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111,
  110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 50, 44, 34, 67, 117,
  116, 34, 44, 34, 78, 111, 114, 109, 97, 108, 105, 122, 101, 34, 44, 34,
  77, 111, 100, 117, 108, 111, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 77, 111, 100, 117, 108, 111, 32, 118, 97, 108, 117, 101, 32, 61,
  32, 105, 110, 116, 40, 51, 50, 44, 49, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105,
  99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60,
  105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101,
  114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48, 52, 47, 48, 55, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103,
  105, 109, 112, 95, 100, 105, 115, 116, 97, 110, 99, 101, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32,
  45, 108, 91, 48, 93, 10, 45, 100, 105, 115, 116, 97, 110, 99, 101, 32,
  36, 49, 44, 36, 50, 10, 45, 105, 102, 32, 123, 36, 51, 61, 61, 48,
  125, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 51, 61, 61, 49, 125, 32, 45, 110, 32, 48, 44, 50, 53,
  53, 10, 45, 101, 108, 115, 101, 32, 45, 37, 32, 36, 52, 32, 45, 110,
  32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 100, 105, 115, 116, 97, 110,
  99, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 100, 105, 115, 116, 97, 110, 99, 101,
  32, 36, 123, 94, 48, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105,
  109, 112, 32, 69, 100, 103, 101, 115, 32, 58, 32, 103, 105, 109, 112, 95,
  101, 100, 103, 101, 115, 44, 32, 103, 105, 109, 112, 95, 101, 100, 103, 101,
  115, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104,
  111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 53, 44, 48,
  44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 101,
  103, 97, 116, 105, 118, 101, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32,
  98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105,
  99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 101, 100, 103,
  101, 115, 32, 58, 10, 45, 116, 111, 95, 114, 103, 98, 32, 45, 98, 32,
  36, 49, 37, 32, 45, 101, 100, 103, 101, 115, 32, 36, 50, 37, 10, 45,
  105, 102, 32, 36, 51, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10,
  103, 105, 109, 112, 95, 101, 100, 103, 101, 115, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95,
  101, 100, 103, 101, 115, 32, 36, 123, 94, 48, 125, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 69, 100, 103, 101, 115, 32, 111, 102,
  102, 115, 101, 116, 115, 32, 58, 32, 103, 105, 109, 112, 95, 101, 100, 103,
  101, 95, 111, 102, 102, 115, 101, 116, 115, 44, 32, 103, 105, 109, 112, 95,
  101, 100, 103, 101, 95, 111, 102, 102, 115, 101, 116, 115, 95, 112, 114, 101,
  118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 53, 44, 48, 44, 53, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 61,
  32, 105, 110, 116, 40, 52, 44, 48, 44, 51, 50, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 84, 104, 105, 99, 107, 110, 101, 115, 115, 32,
  61, 32, 105, 110, 116, 40, 49, 44, 48, 44, 49, 54, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 101, 103, 97, 116, 105, 118, 101, 32,
  99, 111, 108, 111, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101,
  118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112,
  108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109,
  112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50,
  57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 103, 105, 109, 112, 95, 101, 100, 103, 101, 95, 111, 102, 102, 115, 101,
  116, 115, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10,
  111, 115, 61, 123, 115, 125, 10, 45, 98, 91, 45, 49, 93, 32, 36, 49,
  37, 32, 45, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109,
  91, 45, 49, 93, 32, 45, 103, 101, 91, 45, 49, 93, 32, 36, 50, 37,
  32, 45, 115, 107, 101, 108, 101, 116, 111, 110, 91, 45, 49, 93, 32, 48,
  32, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49,
  32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 49, 32, 45, 37,
  91, 45, 49, 93, 32, 36, 51, 32, 45, 103, 101, 91, 45, 49, 93, 32,
  123, 109, 97, 120, 40, 49, 44, 36, 51, 45, 36, 52, 41, 125, 10, 45,
  105, 102, 32, 123, 33, 36, 53, 125, 32, 45, 110, 101, 103, 97, 116, 105,
  118, 101, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 110,
  91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 116, 111, 95, 99,
  111, 108, 111, 114, 109, 111, 100, 101, 91, 45, 49, 93, 32, 36, 111, 115,
  10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101,
  10, 103, 105, 109, 112, 95, 101, 100, 103, 101, 95, 111, 102, 102, 115, 101,
  116, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 101, 100, 103, 101, 95, 111, 102, 102,
  115, 101, 116, 115, 32, 36, 123, 94, 48, 125, 34, 44, 36, 45, 49, 10,
  35, 64, 103, 105, 109, 112, 32, 71, 114, 97, 100, 105, 101, 110, 116, 32,
  110, 111, 114, 109, 32, 58, 32, 103, 105, 109, 112, 95, 103, 114, 97, 100,
  105, 101, 110, 116, 95, 110, 111, 114, 109, 44, 32, 103, 105, 109, 112, 95,
  103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 76, 105, 110, 101, 97, 114, 105, 116, 121, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 46,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 105, 110, 32,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 77, 97, 120, 32, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 48, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 101,
  103, 97, 116, 105, 118, 101, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32,
  98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105,
  99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 103, 114, 97,
  100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 32, 58, 10, 45, 98, 32,
  36, 49, 32, 45, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114,
  109, 32, 45, 94, 32, 36, 50, 10, 45, 99, 32, 36, 51, 37, 44, 36,
  52, 37, 10, 45, 105, 102, 32, 36, 53, 32, 45, 110, 101, 103, 97, 116,
  105, 118, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 110, 32, 48, 44,
  50, 53, 53, 10, 103, 105, 109, 112, 95, 103, 114, 97, 100, 105, 101, 110,
  116, 95, 110, 111, 114, 109, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 103, 114, 97, 100,
  105, 101, 110, 116, 95, 110, 111, 114, 109, 32, 36, 123, 94, 48, 125, 34,
  44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 71, 114, 97, 100,
  105, 101, 110, 116, 32, 82, 71, 66, 32, 58, 32, 103, 105, 109, 112, 95,
  103, 114, 97, 100, 105, 101, 110, 116, 50, 114, 103, 98, 44, 32, 103, 105,
  109, 112, 95, 103, 114, 97, 100, 105, 101, 110, 116, 50, 114, 103, 98, 95,
  112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 77, 105, 110, 32, 116, 104, 114, 101,
  115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  77, 97, 120, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 48, 48, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 114, 105, 101, 110, 116,
  97, 116, 105, 111, 110, 32, 111, 110, 108, 121, 32, 61, 32, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 101,
  103, 97, 116, 105, 118, 101, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32,
  98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105,
  99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 103, 114, 97,
  100, 105, 101, 110, 116, 50, 114, 103, 98, 32, 58, 10, 45, 98, 32, 36,
  49, 32, 45, 103, 114, 97, 100, 105, 101, 110, 116, 50, 114, 103, 98, 32,
  36, 52, 10, 45, 99, 32, 36, 50, 37, 44, 36, 51, 37, 10, 45, 105,
  102, 32, 36, 53, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10, 103,
  105, 109, 112, 95, 103, 114, 97, 100, 105, 101, 110, 116, 50, 114, 103, 98,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 103, 105, 109, 112, 95, 103, 114, 97, 100, 105, 101, 110, 116, 50, 114,
  103, 98, 32, 36, 123, 94, 48, 125, 34, 44, 36, 45, 49, 10, 35, 64,
  103, 105, 109, 112, 32, 73, 115, 111, 112, 104, 111, 116, 101, 115, 32, 58,
  32, 103, 105, 109, 112, 95, 105, 115, 111, 112, 104, 111, 116, 101, 115, 44,
  32, 103, 105, 109, 112, 95, 105, 115, 111, 112, 104, 111, 116, 101, 115, 95,
  112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 76, 101, 118, 101, 108, 115, 32, 61, 32, 105, 110, 116,
  40, 56, 44, 49, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 70, 105, 108, 108, 105, 110, 103, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 84, 114, 97, 110, 115, 112,
  97, 114, 101, 110, 116, 34, 44, 34, 67, 111, 108, 111, 114, 115, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101,
  118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112,
  108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109,
  112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50,
  57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 103, 105, 109, 112, 95, 105, 115, 111, 112, 104, 111, 116, 101, 115, 32,
  58, 10, 45, 105, 102, 32, 36, 51, 10, 45, 116, 111, 112, 111, 103, 114,
  97, 112, 104, 105, 99, 95, 109, 97, 112, 32, 36, 49, 44, 36, 50, 10,
  45, 101, 108, 115, 101, 10, 45, 98, 32, 36, 50, 32, 45, 105, 115, 111,
  112, 104, 111, 116, 101, 115, 32, 36, 49, 10, 45, 101, 110, 100, 105, 102,
  10, 103, 105, 109, 112, 95, 105, 115, 111, 112, 104, 111, 116, 101, 115, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  103, 105, 109, 112, 95, 105, 115, 111, 112, 104, 111, 116, 101, 115, 32, 36,
  123, 94, 48, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112,
  32, 76, 97, 112, 108, 97, 99, 105, 97, 110, 32, 58, 32, 103, 105, 109,
  112, 95, 108, 97, 112, 108, 97, 99, 105, 97, 110, 44, 32, 103, 105, 109,
  112, 95, 108, 97, 112, 108, 97, 99, 105, 97, 110, 95, 112, 114, 101, 118,
  105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 77, 105, 110, 32, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 97, 120, 32,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 48, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 65, 98, 115, 111, 108, 117, 116, 101, 32, 118,
  97, 108, 117, 101, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 101, 103, 97, 116, 105, 118, 101,
  32, 99, 111, 108, 111, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117,
  112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47,
  50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 108, 97, 112, 108, 97, 99, 105, 97, 110,
  32, 58, 10, 45, 98, 32, 36, 49, 32, 45, 108, 97, 112, 108, 97, 99,
  105, 97, 110, 10, 45, 105, 102, 32, 36, 52, 32, 45, 97, 98, 115, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 99, 32, 36, 50, 37, 44, 36, 51,
  37, 10, 45, 105, 102, 32, 36, 53, 32, 45, 110, 101, 103, 97, 116, 105,
  118, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 110, 32, 48, 44, 50,
  53, 53, 10, 103, 105, 109, 112, 95, 108, 97, 112, 108, 97, 99, 105, 97,
  110, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 108, 97, 112, 108, 97, 99, 105, 97, 110,
  32, 36, 123, 94, 48, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105,
  109, 112, 32, 76, 111, 99, 97, 108, 32, 111, 114, 105, 101, 110, 116, 97,
  116, 105, 111, 110, 32, 58, 32, 103, 105, 109, 112, 95, 108, 111, 99, 97,
  108, 95, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 44, 32, 103,
  105, 109, 112, 95, 108, 111, 99, 97, 108, 95, 111, 114, 105, 101, 110, 116,
  97, 116, 105, 111, 110, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 105, 110,
  32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 77, 97, 120, 32, 116, 104, 114, 101, 115, 104, 111,
  108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  101, 103, 97, 116, 105, 118, 101, 32, 99, 111, 108, 111, 114, 115, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66,
  65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108,
  117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97,
  98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44,
  34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97,
  108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101,
  110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34,
  99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34,
  44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44,
  34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108,
  105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 95, 103, 105, 109, 112, 95, 108,
  111, 99, 97, 108, 95, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110,
  32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99,
  105, 116, 121, 32, 45, 108, 91, 48, 93, 10, 45, 98, 32, 36, 49, 37,
  32, 45, 103, 114, 97, 100, 105, 101, 110, 116, 95, 111, 114, 105, 101, 110,
  116, 97, 116, 105, 111, 110, 32, 50, 32, 45, 99, 111, 109, 112, 108, 101,
  120, 50, 112, 111, 108, 97, 114, 32, 45, 114, 109, 91, 48, 45, 45, 49,
  58, 50, 93, 10, 45, 99, 32, 36, 50, 37, 44, 36, 51, 37, 10, 45,
  105, 102, 32, 36, 52, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10,
  45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 108, 111, 99, 97,
  108, 95, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 32, 58, 10,
  45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  34, 45, 95, 103, 105, 109, 112, 95, 108, 111, 99, 97, 108, 95, 111, 114,
  105, 101, 110, 116, 97, 116, 105, 111, 110, 32, 36, 49, 44, 36, 50, 44,
  36, 51, 44, 36, 52, 34, 44, 36, 53, 44, 49, 10, 103, 105, 109, 112,
  95, 108, 111, 99, 97, 108, 95, 111, 114, 105, 101, 110, 116, 97, 116, 105,
  111, 110, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 108, 111, 99, 97, 108, 95, 111, 114,
  105, 101, 110, 116, 97, 116, 105, 111, 110, 32, 36, 123, 94, 48, 125, 34,
  44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 77, 111, 114, 112,
  104, 111, 108, 111, 103, 105, 99, 97, 108, 32, 102, 105, 108, 116, 101, 114,
  32, 58, 32, 103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111, 44, 32,
  103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111, 95, 112, 114, 101, 118,
  105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  65, 99, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 69, 114, 111, 115, 105, 111, 110, 34, 44, 34, 68, 105, 108, 97, 116,
  105, 111, 110, 34, 44, 34, 79, 112, 101, 110, 105, 110, 103, 34, 44, 34,
  67, 108, 111, 115, 105, 110, 103, 34, 44, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 34, 79, 114, 105, 103, 105, 110, 97, 108, 32, 45, 32, 69,
  114, 111, 115, 105, 111, 110, 34, 44, 34, 68, 105, 108, 97, 116, 105, 111,
  110, 32, 45, 32, 79, 114, 105, 103, 105, 110, 97, 108, 34, 44, 34, 79,
  114, 105, 103, 105, 110, 97, 108, 32, 45, 32, 79, 112, 101, 110, 105, 110,
  103, 34, 44, 34, 67, 108, 111, 115, 105, 110, 103, 32, 45, 32, 79, 114,
  105, 103, 105, 110, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 53, 44, 50,
  44, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110,
  118, 101, 114, 116, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32, 98, 111,
  111, 108, 40, 102, 97, 108, 115, 101, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 104, 97, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 48, 44, 34, 83, 113, 117, 97, 114, 101, 34, 44, 34, 79, 99,
  116, 97, 103, 111, 110, 97, 108, 34, 44, 34, 67, 105, 114, 99, 117, 108,
  97, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104,
  97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34,
  82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34,
  44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100,
  32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76,
  105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116,
  117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34,
  44, 34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114,
  101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112,
  104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99,
  97, 108, 101, 32, 61, 32, 98, 111, 111, 108, 40, 116, 114, 117, 101, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101,
  118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112,
  108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109,
  112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50,
  57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111, 32, 58, 10, 45,
  97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34,
  45, 95, 95, 103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111, 32, 36,
  123, 94, 48, 125, 34, 44, 36, 53, 44, 36, 54, 10, 103, 105, 109, 112,
  95, 109, 111, 114, 112, 104, 111, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 109, 111, 114,
  112, 104, 111, 32, 36, 123, 94, 48, 125, 34, 44, 36, 45, 49, 10, 95,
  95, 103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111, 32, 58, 10, 45,
  105, 102, 32, 123, 36, 52, 61, 61, 49, 125, 32, 115, 117, 102, 61, 34,
  95, 111, 99, 116, 34, 32, 45, 101, 108, 105, 102, 32, 123, 36, 52, 61,
  61, 48, 125, 32, 115, 117, 102, 61, 34, 34, 32, 45, 101, 108, 115, 101,
  32, 115, 117, 102, 61, 34, 95, 99, 105, 114, 99, 34, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 125, 32,
  45, 101, 114, 111, 100, 101, 36, 115, 117, 102, 32, 36, 50, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 32, 45, 100, 105, 108,
  97, 116, 101, 36, 115, 117, 102, 32, 36, 50, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 61, 61, 50, 125, 32, 45, 101, 114, 111, 100, 101, 36,
  115, 117, 102, 32, 36, 50, 32, 45, 100, 105, 108, 97, 116, 101, 36, 115,
  117, 102, 32, 36, 50, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61,
  61, 51, 125, 32, 45, 100, 105, 108, 97, 116, 101, 36, 115, 117, 102, 32,
  36, 50, 32, 45, 101, 114, 111, 100, 101, 36, 115, 117, 102, 32, 36, 50,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 52, 125, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 45, 101, 114, 111, 100,
  101, 36, 115, 117, 102, 32, 36, 50, 32, 45, 45, 91, 45, 50, 44, 45,
  49, 93, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111,
  110, 101, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 53, 125,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 45, 100, 105,
  108, 97, 116, 101, 36, 115, 117, 102, 32, 36, 50, 32, 45, 114, 118, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 45, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 54, 125, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 45, 101, 114, 111, 100,
  101, 36, 115, 117, 102, 32, 36, 50, 32, 45, 100, 105, 108, 97, 116, 101,
  36, 115, 117, 102, 91, 45, 49, 93, 32, 36, 50, 32, 45, 45, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32,
  45, 100, 111, 110, 101, 10, 45, 101, 108, 115, 101, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 45, 100, 105, 108, 97, 116, 101, 36,
  115, 117, 102, 32, 36, 50, 32, 45, 101, 114, 111, 100, 101, 36, 115, 117,
  102, 91, 45, 49, 93, 32, 36, 50, 32, 45, 114, 118, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 45, 91, 45, 50, 44, 45, 49, 93, 32, 45, 109,
  118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 51, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115,
  112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 110, 101,
  103, 97, 116, 105, 118, 101, 91, 48, 93, 32, 45, 97, 32, 99, 32, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 105,
  102, 10, 35, 64, 103, 105, 109, 112, 32, 83, 101, 103, 109, 101, 110, 116,
  97, 116, 105, 111, 110, 32, 58, 32, 103, 105, 109, 112, 95, 115, 101, 103,
  109, 101, 110, 116, 95, 119, 97, 116, 101, 114, 115, 104, 101, 100, 44, 32,
  103, 105, 109, 112, 95, 115, 101, 103, 109, 101, 110, 116, 95, 119, 97, 116,
  101, 114, 115, 104, 101, 100, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101, 32,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 50, 44, 48, 44, 49, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44,
  34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114,
  101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34,
  44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115,
  34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115,
  34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72,
  117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34,
  44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34,
  71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34,
  82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108,
  117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97,
  116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 115, 101, 103, 109, 101, 110, 116, 95, 119, 97, 116, 101, 114, 115,
  104, 101, 100, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 34, 45, 98, 32, 36, 50, 32, 45, 115, 101,
  103, 109, 101, 110, 116, 95, 119, 97, 116, 101, 114, 115, 104, 101, 100, 32,
  36, 49, 34, 44, 36, 51, 44, 48, 10, 103, 105, 109, 112, 95, 115, 101,
  103, 109, 101, 110, 116, 95, 119, 97, 116, 101, 114, 115, 104, 101, 100, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  103, 105, 109, 112, 95, 115, 101, 103, 109, 101, 110, 116, 95, 119, 97, 116,
  101, 114, 115, 104, 101, 100, 32, 36, 123, 94, 48, 125, 34, 44, 36, 45,
  49, 10, 35, 64, 103, 105, 109, 112, 32, 83, 107, 101, 108, 101, 116, 111,
  110, 32, 58, 32, 103, 105, 109, 112, 95, 115, 107, 101, 108, 101, 116, 111,
  110, 44, 32, 103, 105, 109, 112, 95, 115, 107, 101, 108, 101, 116, 111, 110,
  95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 77, 101, 116, 104, 111, 100, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 68, 105, 115, 116, 97, 110, 99, 101, 34, 44,
  34, 84, 104, 105, 110, 110, 105, 110, 103, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 114, 118, 105, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 117, 108, 116,
  105, 112, 108, 101, 32, 99, 104, 97, 110, 110, 101, 108, 115, 32, 61, 32,
  98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105,
  99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 49, 47, 48, 52, 47, 48, 55, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 115, 107, 101,
  108, 101, 116, 111, 110, 32, 58, 10, 45, 114, 101, 109, 111, 118, 101, 95,
  111, 112, 97, 99, 105, 116, 121, 10, 45, 105, 102, 32, 123, 33, 36, 52,
  125, 32, 45, 110, 111, 114, 109, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  98, 32, 36, 50, 37, 10, 45, 105, 102, 32, 36, 49, 32, 45, 116, 104,
  105, 110, 110, 105, 110, 103, 32, 45, 101, 108, 115, 101, 32, 45, 115, 107,
  101, 108, 101, 116, 111, 110, 32, 36, 51, 37, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 42, 32, 50, 53, 53, 10, 103, 105, 109, 112, 95, 115, 107,
  101, 108, 101, 116, 111, 110, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 115, 107, 101, 108,
  101, 116, 111, 110, 32, 36, 123, 94, 48, 125, 34, 44, 36, 45, 49, 10,
  35, 64, 103, 105, 109, 112, 32, 84, 104, 105, 110, 32, 101, 100, 103, 101,
  115, 32, 58, 32, 103, 105, 109, 112, 95, 116, 104, 105, 110, 95, 101, 100,
  103, 101, 115, 44, 32, 103, 105, 109, 112, 95, 116, 104, 105, 110, 95, 101,
  100, 103, 101, 115, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114,
  101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  53, 44, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 101, 103, 97, 116, 105, 118, 101, 32, 99, 111, 108, 111, 114, 115,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117,
  108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117,
  112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  116, 104, 105, 110, 95, 101, 100, 103, 101, 115, 32, 58, 10, 45, 98, 32,
  36, 49, 37, 32, 45, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111,
  114, 109, 32, 45, 103, 101, 32, 36, 50, 37, 32, 45, 116, 104, 105, 110,
  110, 105, 110, 103, 10, 45, 105, 102, 32, 123, 33, 36, 51, 125, 32, 45,
  110, 101, 103, 97, 116, 105, 118, 101, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 110, 32, 48, 44, 50, 53, 53, 10, 103, 105, 109, 112, 95, 116, 104,
  105, 110, 95, 101, 100, 103, 101, 115, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 116, 104,
  105, 110, 95, 101, 100, 103, 101, 115, 32, 36, 123, 94, 48, 125, 34, 44,
  36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 95, 10, 35, 64, 103,
  105, 109, 112, 32, 60, 98, 62, 68, 101, 102, 111, 114, 109, 97, 116, 105,
  111, 110, 115, 60, 47, 98, 62, 10, 35, 64, 103, 105, 109, 112, 32, 67,
  97, 114, 116, 101, 115, 105, 97, 110, 32, 116, 114, 97, 110, 115, 102, 111,
  114, 109, 32, 58, 32, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109,
  95, 100, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 44, 32, 103, 105,
  109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 100, 101, 102, 111, 114, 109,
  97, 116, 105, 111, 110, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 45, 119, 97, 114, 112, 105, 110, 103, 32, 61, 32, 116, 101,
  120, 116, 123, 34, 40, 119, 43, 104, 41, 47, 50, 48, 32, 42, 32, 99,
  111, 115, 40, 121, 42, 50, 48, 47, 104, 41, 34, 125, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 89, 45, 119, 97, 114, 112, 105, 110, 103, 32,
  61, 32, 116, 101, 120, 116, 123, 34, 40, 119, 43, 104, 41, 47, 50, 48,
  32, 42, 32, 115, 105, 110, 40, 120, 42, 50, 48, 47, 119, 41, 34, 125,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 108, 97, 116, 105,
  118, 101, 32, 119, 97, 114, 112, 105, 110, 103, 32, 61, 32, 98, 111, 111,
  108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110,
  116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 49, 44, 34, 78, 101, 97, 114, 101, 115, 116, 32,
  110, 101, 105, 103, 104, 98, 111, 114, 34, 44, 34, 76, 105, 110, 101, 97,
  114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 111, 117,
  110, 100, 97, 114, 121, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49,
  44, 34, 66, 108, 97, 99, 107, 34, 44, 34, 78, 101, 97, 114, 101, 115,
  116, 34, 44, 34, 82, 101, 112, 101, 97, 116, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115,
  99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47,
  49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109,
  95, 100, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 45, 110, 111, 114, 109,
  91, 45, 49, 93, 32, 91, 45, 49, 93, 32, 45, 102, 91, 45, 50, 93,
  32, 34, 36, 49, 34, 32, 45, 102, 91, 45, 49, 93, 32, 34, 36, 50,
  34, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 119,
  97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 51, 44,
  36, 52, 44, 36, 53, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10,
  35, 64, 103, 105, 109, 112, 32, 67, 105, 114, 99, 108, 101, 32, 116, 114,
  97, 110, 115, 102, 111, 114, 109, 32, 58, 32, 103, 105, 109, 112, 95, 99,
  105, 114, 99, 108, 101, 95, 116, 114, 97, 110, 115, 102, 111, 114, 109, 44,
  32, 103, 105, 109, 112, 95, 99, 105, 114, 99, 108, 101, 95, 116, 114, 97,
  110, 115, 102, 111, 114, 109, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 101, 110,
  116, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44,
  48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45,
  99, 101, 110, 116, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 88, 45, 115, 99, 97, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 45, 50, 44, 45, 49, 54, 44, 49, 54, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 89, 45, 115, 99, 97, 108, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 45, 50, 44, 45, 49, 54, 44, 49, 54, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 100, 105, 117, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 50, 44, 48, 44, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 121, 109, 109, 101, 116,
  114, 121, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 78, 111, 110,
  101, 34, 44, 34, 73, 110, 115, 105, 100, 101, 34, 44, 34, 79, 117, 116,
  115, 105, 100, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 78, 101, 97, 114, 101, 115,
  116, 32, 110, 101, 105, 103, 104, 98, 111, 114, 34, 44, 34, 76, 105, 110,
  101, 97, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66,
  111, 117, 110, 100, 97, 114, 121, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 49, 44, 34, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 116, 34,
  44, 34, 78, 101, 97, 114, 101, 115, 116, 34, 44, 34, 82, 101, 112, 101,
  97, 116, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32,
  99, 105, 114, 99, 108, 101, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 51, 47, 48, 49, 47, 48, 56, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 99, 105,
  114, 99, 108, 101, 95, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 32, 45, 116, 111, 95, 114, 103, 98, 97, 10, 114, 61, 123, 36,
  53, 42, 115, 113, 114, 116, 40, 119, 94, 50, 43, 104, 94, 50, 41, 125,
  10, 45, 105, 102, 32, 123, 36, 54, 61, 61, 48, 125, 32, 99, 111, 110,
  100, 61, 34, 105, 40, 88, 44, 89, 44, 122, 44, 99, 44, 36, 55, 44,
  36, 56, 41, 34, 10, 45, 101, 108, 105, 102, 32, 123, 36, 54, 61, 61,
  49, 125, 32, 99, 111, 110, 100, 61, 34, 105, 102, 40, 78, 60, 34, 36,
  114, 34, 44, 105, 40, 88, 44, 89, 44, 122, 44, 99, 44, 36, 55, 44,
  36, 56, 41, 44, 105, 41, 34, 10, 45, 101, 108, 115, 101, 32, 99, 111,
  110, 100, 61, 34, 105, 102, 40, 78, 62, 34, 36, 114, 34, 44, 105, 40,
  88, 44, 89, 44, 122, 44, 99, 44, 36, 55, 44, 36, 56, 41, 44, 105,
  41, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 102, 32, 39, 85, 61,
  120, 45, 119, 42, 36, 49, 59, 86, 61, 121, 45, 104, 42, 36, 50, 59,
  78, 61, 115, 113, 114, 116, 40, 85, 42, 85, 43, 86, 42, 86, 41, 59,
  78, 114, 61, 78, 45, 36, 114, 59, 88, 61, 120, 43, 36, 51, 42, 78,
  114, 42, 85, 47, 78, 59, 89, 61, 121, 43, 36, 52, 42, 78, 114, 42,
  86, 47, 78, 59, 36, 99, 111, 110, 100, 39, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 99, 105, 114, 99,
  108, 101, 95, 116, 114, 97, 110, 115, 102, 111, 114, 109, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 99, 105, 114,
  99, 108, 101, 95, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32, 36, 42,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 120, 48, 61, 123, 36, 49, 42, 119, 125, 10, 121, 48, 61,
  123, 36, 50, 42, 104, 125, 10, 114, 61, 123, 36, 53, 42, 115, 113, 114,
  116, 40, 119, 94, 50, 43, 104, 94, 50, 41, 125, 10, 45, 105, 102, 32,
  36, 57, 10, 45, 99, 105, 114, 99, 108, 101, 32, 36, 120, 48, 44, 36,
  121, 48, 44, 123, 36, 114, 45, 49, 125, 44, 49, 44, 48, 120, 70, 70,
  70, 70, 70, 70, 70, 70, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53,
  10, 45, 99, 105, 114, 99, 108, 101, 32, 36, 120, 48, 44, 36, 121, 48,
  44, 123, 36, 114, 43, 49, 125, 44, 49, 44, 48, 120, 70, 70, 70, 70,
  70, 70, 70, 70, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 10, 45,
  99, 105, 114, 99, 108, 101, 32, 36, 120, 48, 44, 36, 121, 48, 44, 36,
  114, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48,
  44, 50, 53, 53, 44, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64,
  103, 105, 109, 112, 32, 69, 117, 99, 108, 105, 100, 101, 97, 110, 32, 45,
  32, 112, 111, 108, 97, 114, 32, 58, 32, 103, 105, 109, 112, 95, 101, 117,
  99, 108, 105, 100, 101, 97, 110, 50, 112, 111, 108, 97, 114, 44, 32, 103,
  105, 109, 112, 95, 101, 117, 99, 108, 105, 100, 101, 97, 110, 50, 112, 111,
  108, 97, 114, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  88, 45, 99, 101, 110, 116, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 89, 45, 99, 101, 110, 116, 101, 114, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 105, 108, 97, 116, 105, 111, 110, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 46, 49, 44, 49, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 111, 117, 110, 100, 97,
  114, 121, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 66,
  108, 97, 99, 107, 34, 44, 34, 78, 101, 97, 114, 101, 115, 116, 34, 44,
  34, 82, 101, 112, 101, 97, 116, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 73, 110, 118, 101, 114, 115, 101, 32, 116, 114, 97, 110, 115,
  102, 111, 114, 109, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65,
  117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32,
  84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59,
  60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49,
  48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 101, 117, 99, 108,
  105, 100, 101, 97, 110, 50, 112, 111, 108, 97, 114, 32, 58, 10, 45, 105,
  102, 32, 36, 53, 32, 45, 112, 111, 108, 97, 114, 50, 101, 117, 99, 108,
  105, 100, 101, 97, 110, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36,
  52, 32, 45, 101, 108, 115, 101, 32, 45, 101, 117, 99, 108, 105, 100, 101,
  97, 110, 50, 112, 111, 108, 97, 114, 32, 36, 49, 44, 36, 50, 44, 36,
  51, 44, 36, 52, 32, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103, 105,
  109, 112, 32, 70, 105, 115, 104, 45, 101, 121, 101, 32, 58, 32, 102, 105,
  115, 104, 101, 121, 101, 44, 32, 102, 105, 115, 104, 101, 121, 101, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 101, 110,
  116, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89,
  45, 99, 101, 110, 116, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 82, 97, 100, 105, 117, 115, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 55, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 50, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84,
  115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48,
  47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 70, 108, 111,
  119, 101, 114, 32, 58, 32, 103, 105, 109, 112, 95, 102, 108, 111, 119, 101,
  114, 44, 32, 103, 105, 109, 112, 95, 102, 108, 111, 119, 101, 114, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105,
  116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 48, 44,
  45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 80, 101, 116, 97, 108, 115, 32, 61, 32, 105, 110, 116, 40,
  54, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 79, 102, 102, 115, 101, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 65, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 45, 99, 101, 110, 116, 101, 114, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 89, 45, 99, 101, 110, 116, 101, 114, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 66, 111, 117, 110, 100, 97, 114, 121,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 66, 108, 97,
  99, 107, 34, 44, 34, 78, 101, 97, 114, 101, 115, 116, 34, 44, 34, 82,
  101, 112, 101, 97, 116, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32,
  60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112,
  101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  103, 105, 109, 112, 95, 102, 108, 111, 119, 101, 114, 32, 58, 10, 45, 102,
  108, 111, 119, 101, 114, 32, 36, 49, 44, 36, 50, 44, 36, 51, 37, 44,
  36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 10, 35, 64, 103, 105,
  109, 112, 32, 75, 97, 108, 101, 105, 100, 111, 115, 99, 111, 112, 101, 32,
  91, 98, 108, 101, 110, 100, 101, 100, 93, 32, 58, 32, 103, 105, 109, 112,
  95, 114, 111, 116, 111, 105, 100, 111, 115, 99, 111, 112, 101, 44, 32, 103,
  105, 109, 112, 95, 114, 111, 116, 111, 105, 100, 111, 115, 99, 111, 112, 101,
  40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99,
  101, 110, 116, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  89, 45, 99, 101, 110, 116, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 110, 103, 117, 108, 97, 114, 32, 116, 105, 108, 101, 115,
  32, 61, 32, 105, 110, 116, 40, 49, 48, 44, 49, 44, 55, 50, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44,
  48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 111,
  117, 110, 100, 97, 114, 121, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  50, 44, 34, 66, 108, 97, 99, 107, 34, 44, 34, 78, 101, 97, 114, 101,
  115, 116, 34, 44, 34, 82, 101, 112, 101, 97, 116, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84,
  115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48,
  47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 114, 111, 116, 111, 105,
  100, 111, 115, 99, 111, 112, 101, 32, 58, 10, 45, 114, 111, 116, 111, 105,
  100, 111, 115, 99, 111, 112, 101, 32, 123, 36, 49, 42, 49, 48, 48, 125,
  37, 44, 123, 36, 50, 42, 49, 48, 48, 125, 37, 44, 36, 51, 44, 36,
  52, 37, 44, 36, 53, 10, 35, 64, 103, 105, 109, 112, 32, 75, 97, 108,
  101, 105, 100, 111, 115, 99, 111, 112, 101, 32, 91, 112, 111, 108, 97, 114,
  93, 32, 58, 32, 103, 105, 109, 112, 95, 107, 97, 108, 101, 105, 100, 111,
  115, 99, 111, 112, 101, 44, 32, 103, 105, 109, 112, 95, 107, 97, 108, 101,
  105, 100, 111, 115, 99, 111, 112, 101, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 88, 45, 99, 101, 110, 116, 101, 114, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 101, 110, 116, 101, 114,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 111, 102, 102,
  115, 101, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45,
  111, 102, 102, 115, 101, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 82, 97, 100, 105, 117, 115, 32, 99, 117, 116, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 48, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 99, 117,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 111, 117,
  110, 100, 97, 114, 121, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 50,
  44, 34, 66, 108, 97, 99, 107, 34, 44, 34, 78, 101, 97, 114, 101, 115,
  116, 34, 44, 34, 82, 101, 112, 101, 97, 116, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115,
  99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47,
  49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 107, 97, 108, 101, 105, 100,
  111, 115, 99, 111, 112, 101, 32, 58, 10, 45, 115, 104, 105, 102, 116, 32,
  36, 51, 37, 44, 36, 52, 37, 44, 48, 44, 48, 44, 50, 32, 45, 107,
  97, 108, 101, 105, 100, 111, 115, 99, 111, 112, 101, 32, 36, 49, 44, 36,
  50, 44, 36, 53, 44, 36, 54, 44, 36, 55, 10, 35, 64, 103, 105, 109,
  112, 32, 75, 97, 108, 101, 105, 100, 111, 115, 99, 111, 112, 101, 32, 91,
  115, 121, 109, 109, 101, 116, 114, 121, 93, 32, 58, 32, 103, 105, 109, 112,
  95, 115, 121, 109, 109, 101, 116, 114, 105, 122, 111, 115, 99, 111, 112, 101,
  44, 32, 103, 105, 109, 112, 95, 115, 121, 109, 109, 101, 116, 114, 105, 122,
  111, 115, 99, 111, 112, 101, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32,
  105, 110, 116, 40, 52, 44, 49, 44, 51, 50, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 66, 111, 117, 110, 100, 97, 114, 121, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 84, 114, 97, 110, 115, 112,
  97, 114, 101, 110, 116, 34, 44, 34, 78, 101, 97, 114, 101, 115, 116, 34,
  44, 34, 82, 101, 112, 101, 97, 116, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 121, 109, 109, 101, 116, 114, 121, 32, 115, 105, 100,
  101, 115, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 34,
  44, 34, 83, 119, 97, 112, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109,
  112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 49, 47, 48,
  55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 103, 105, 109, 112, 95, 115, 121, 109, 109, 101, 116, 114, 105, 122, 111,
  115, 99, 111, 112, 101, 32, 58, 10, 45, 116, 111, 95, 114, 103, 98, 97,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 10, 97, 110, 103, 61,
  123, 36, 50, 43, 49, 56, 48, 42, 36, 62, 47, 109, 97, 120, 40, 49,
  44, 36, 49, 45, 49, 41, 125, 10, 45, 115, 121, 109, 109, 101, 116, 114,
  105, 122, 101, 32, 53, 48, 37, 44, 53, 48, 37, 44, 36, 97, 110, 103,
  44, 36, 51, 44, 48, 44, 123, 105, 102, 40, 36, 52, 33, 61, 50, 44,
  36, 52, 44, 36, 62, 37, 50, 41, 125, 10, 45, 100, 111, 110, 101, 10,
  35, 64, 103, 105, 109, 112, 32, 80, 101, 114, 115, 112, 101, 99, 116, 105,
  118, 101, 32, 58, 32, 103, 105, 109, 112, 95, 119, 97, 114, 112, 95, 112,
  101, 114, 115, 112, 101, 99, 116, 105, 118, 101, 44, 32, 103, 105, 109, 112,
  95, 119, 97, 114, 112, 95, 112, 101, 114, 115, 112, 101, 99, 116, 105, 118,
  101, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45,
  97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46,
  55, 51, 44, 45, 52, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 89, 45, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 45, 52, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 90, 111, 111, 109, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 44, 48, 46, 49, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 45, 99, 101, 110, 116, 101, 114, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 89, 45, 99, 101, 110, 116, 101, 114, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 111, 102, 102, 115,
  101, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 111,
  102, 102, 115, 101, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  66, 111, 117, 110, 100, 97, 114, 121, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 50, 44, 34, 66, 108, 97, 99, 107, 34, 44, 34, 78, 101, 97,
  114, 101, 115, 116, 34, 44, 34, 82, 101, 112, 101, 97, 116, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 119, 97, 114,
  112, 95, 112, 101, 114, 115, 112, 101, 99, 116, 105, 118, 101, 32, 58, 10,
  45, 115, 104, 105, 102, 116, 32, 36, 54, 37, 44, 36, 55, 37, 44, 48,
  44, 48, 44, 50, 32, 45, 119, 97, 114, 112, 95, 112, 101, 114, 115, 112,
  101, 99, 116, 105, 118, 101, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44,
  36, 52, 44, 36, 53, 44, 36, 56, 10, 35, 64, 103, 105, 109, 112, 32,
  80, 111, 108, 97, 114, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32,
  58, 32, 103, 105, 109, 112, 95, 116, 114, 97, 110, 115, 102, 111, 114, 109,
  95, 112, 111, 108, 97, 114, 44, 32, 103, 105, 109, 112, 95, 116, 114, 97,
  110, 115, 102, 111, 114, 109, 95, 112, 111, 108, 97, 114, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 115, 101, 116, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 67, 117, 115, 116, 111, 109,
  32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 34, 44, 34, 73, 110, 118,
  101, 114, 115, 101, 32, 114, 97, 100, 105, 117, 115, 34, 44, 34, 83, 119,
  97, 112, 32, 114, 97, 100, 105, 117, 115, 47, 97, 110, 103, 108, 101, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 101, 110,
  116, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89,
  45, 99, 101, 110, 116, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 82, 97, 100, 105, 117, 115, 32, 61, 32, 116, 101, 120, 116,
  123, 34, 114, 32, 43, 32, 82, 47, 49, 48, 42, 99, 111, 115, 40, 97,
  42, 53, 41, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  110, 103, 108, 101, 32, 61, 32, 116, 101, 120, 116, 123, 34, 97, 34, 125,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 111, 117, 110, 100, 97,
  114, 121, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 66,
  108, 97, 99, 107, 34, 44, 34, 78, 101, 97, 114, 101, 115, 116, 34, 44,
  34, 82, 101, 112, 101, 97, 116, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47,
  50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 116, 114, 97, 110, 115, 102, 111, 114, 109,
  95, 112, 111, 108, 97, 114, 32, 58, 10, 45, 105, 102, 32, 123, 36, 49,
  61, 61, 48, 125, 10, 45, 116, 114, 97, 110, 115, 102, 111, 114, 109, 95,
  112, 111, 108, 97, 114, 32, 34, 36, 52, 34, 44, 34, 36, 53, 34, 44,
  36, 50, 44, 36, 51, 44, 36, 54, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 61, 61, 49, 125, 10, 45, 116, 114, 97, 110, 115, 102, 111, 114,
  109, 95, 112, 111, 108, 97, 114, 32, 82, 45, 114, 44, 97, 44, 36, 50,
  44, 36, 51, 44, 36, 54, 10, 45, 101, 108, 115, 101, 10, 45, 116, 114,
  97, 110, 115, 102, 111, 114, 109, 95, 112, 111, 108, 97, 114, 32, 97, 42,
  82, 47, 40, 50, 42, 112, 105, 41, 44, 114, 42, 50, 42, 112, 105, 47,
  82, 44, 36, 50, 44, 36, 51, 44, 36, 54, 10, 45, 101, 110, 100, 105,
  102, 10, 35, 64, 103, 105, 109, 112, 32, 82, 97, 105, 110, 100, 114, 111,
  112, 115, 32, 58, 32, 114, 97, 105, 110, 100, 114, 111, 112, 115, 44, 32,
  114, 97, 105, 110, 100, 114, 111, 112, 115, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 56, 48, 44, 48, 44, 51, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 110, 115, 105,
  116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 49, 44, 48,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 87, 97, 118,
  101, 108, 101, 110, 103, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  77, 101, 114, 103, 105, 110, 103, 32, 115, 116, 101, 112, 115, 32, 61, 32,
  105, 110, 116, 40, 48, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 50, 47, 49,
  49, 47, 50, 56, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 82, 97, 110, 100, 111,
  109, 32, 58, 32, 100, 101, 102, 111, 114, 109, 44, 32, 100, 101, 102, 111,
  114, 109, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104,
  117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50,
  47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 82, 101, 102, 108, 101, 99,
  116, 105, 111, 110, 32, 58, 32, 103, 105, 109, 112, 95, 114, 101, 102, 108,
  101, 99, 116, 44, 32, 103, 105, 109, 112, 95, 114, 101, 102, 108, 101, 99,
  116, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 101,
  105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  65, 116, 116, 101, 110, 117, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 44, 48, 46, 49, 44, 52, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 61, 32, 99, 111,
  108, 111, 114, 40, 49, 49, 48, 44, 49, 54, 48, 44, 49, 57, 48, 44,
  54, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 87, 97, 118,
  101, 115, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 87, 97, 118, 101, 115, 32, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 46, 53, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 45, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 45, 49, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 89, 45, 97, 110, 103, 108, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 45, 51, 46, 51, 48, 44, 45, 49, 48, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 111, 99, 97,
  108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 55, 44, 48, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 111, 111, 109,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 53, 44, 49, 44, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118,
  105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50,
  51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62,
  50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 114,
  101, 102, 108, 101, 99, 116, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93,
  32, 45, 45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 123, 49, 48, 48,
  45, 36, 49, 125, 37, 44, 49, 48, 48, 37, 32, 45, 109, 105, 114, 114,
  111, 114, 91, 45, 49, 93, 32, 121, 32, 45, 119, 97, 116, 101, 114, 91,
  45, 49, 93, 32, 36, 55, 44, 36, 56, 10, 45, 115, 91, 45, 49, 93,
  32, 99, 10, 45, 102, 91, 45, 52, 93, 32, 34, 40, 105, 42, 40, 50,
  53, 53, 45, 36, 54, 41, 32, 43, 32, 36, 54, 42, 36, 51, 41, 47,
  50, 53, 53, 34, 10, 45, 102, 91, 45, 51, 93, 32, 34, 40, 105, 42,
  40, 50, 53, 53, 45, 36, 54, 41, 32, 43, 32, 36, 54, 42, 36, 52,
  41, 47, 50, 53, 53, 34, 10, 45, 102, 91, 45, 50, 93, 32, 34, 40,
  105, 42, 40, 50, 53, 53, 45, 36, 54, 41, 32, 43, 32, 36, 54, 42,
  36, 53, 41, 47, 50, 53, 53, 34, 32, 45, 97, 91, 45, 52, 45, 45,
  49, 93, 32, 99, 10, 45, 42, 91, 45, 49, 93, 32, 39, 40, 104, 94,
  36, 50, 45, 121, 94, 36, 50, 41, 47, 104, 94, 36, 50, 39, 32, 45,
  97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 10, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 36, 49, 49, 42,
  36, 49, 50, 42, 40, 120, 47, 119, 45, 48, 46, 53, 41, 10, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 36,
  49, 49, 42, 36, 49, 50, 42, 40, 121, 47, 104, 45, 48, 46, 53, 41,
  10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  49, 44, 34, 36, 49, 48, 42, 40, 120, 47, 119, 45, 48, 46, 53, 41,
  32, 43, 32, 36, 57, 42, 40, 121, 47, 104, 45, 48, 46, 53, 41, 32,
  43, 32, 36, 49, 49, 34, 10, 45, 47, 91, 45, 51, 93, 32, 91, 45,
  49, 93, 32, 45, 43, 91, 45, 51, 93, 32, 48, 46, 53, 32, 45, 42,
  91, 45, 51, 93, 32, 64, 123, 45, 51, 44, 119, 125, 10, 45, 47, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 43, 91, 45, 49, 93, 32, 48, 46,
  53, 32, 45, 42, 91, 45, 49, 93, 32, 123, 104, 125, 10, 45, 97, 91,
  45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 119, 97, 114, 112, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 49, 44, 48, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32,
  45, 100, 111, 110, 101, 10, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32,
  48, 44, 48, 44, 48, 44, 48, 10, 35, 64, 103, 105, 109, 112, 32, 82,
  105, 112, 112, 108, 101, 32, 58, 32, 114, 105, 112, 112, 108, 101, 44, 32,
  114, 105, 112, 112, 108, 101, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 50, 48, 44, 49, 44, 51, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 112, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 50, 44, 34, 66, 108, 111, 99, 34, 44,
  34, 84, 114, 105, 97, 110, 103, 108, 101, 34, 44, 34, 83, 105, 110, 101,
  34, 44, 34, 83, 105, 110, 101, 43, 34, 44, 34, 82, 97, 110, 100, 111,
  109, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103,
  108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 51,
  54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 102, 102,
  115, 101, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  53, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 49, 47, 48, 56, 47, 50, 51, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 83, 112, 104, 101, 114, 101, 32, 58, 32, 103, 105, 109,
  112, 95, 109, 97, 112, 95, 115, 112, 104, 101, 114, 101, 44, 32, 103, 105,
  109, 112, 95, 109, 97, 112, 95, 115, 112, 104, 101, 114, 101, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 87, 105, 100, 116, 104, 32, 61, 32, 95, 105, 110, 116, 40, 53,
  49, 50, 44, 49, 44, 52, 48, 57, 54, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 72, 101, 105, 103, 104, 116, 32, 61, 32, 95, 105, 110,
  116, 40, 53, 49, 50, 44, 49, 44, 52, 48, 57, 54, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 97, 100, 105, 117, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 57, 48, 44, 48, 44, 52, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 105, 108, 97, 116, 105, 111,
  110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 53, 48, 44,
  53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 111, 114,
  100, 101, 114, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 50, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 111, 114, 100, 101, 114, 32,
  119, 105, 100, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48,
  44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 79, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 48, 32, 100, 101, 103, 46, 34, 44, 34,
  57, 48, 32, 100, 101, 103, 46, 34, 44, 34, 49, 56, 48, 32, 100, 101,
  103, 46, 34, 44, 34, 50, 55, 48, 32, 100, 101, 103, 46, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 97, 99, 107, 103, 114, 111,
  117, 110, 100, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 84, 114,
  97, 110, 115, 112, 97, 114, 101, 110, 116, 34, 44, 34, 77, 101, 97, 110,
  32, 99, 111, 108, 111, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 70, 97, 100, 105, 110, 103, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 70, 97, 100, 105, 110, 103, 32, 115, 104, 97, 112, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 51, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 49, 47, 49, 49, 47, 48, 55, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 109, 97,
  112, 95, 115, 112, 104, 101, 114, 101, 32, 58, 10, 45, 114, 111, 116, 97,
  116, 101, 32, 123, 36, 56, 42, 57, 48, 125, 10, 45, 105, 102, 32, 36,
  54, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 115, 104,
  105, 102, 116, 91, 45, 49, 93, 32, 53, 48, 37, 44, 48, 44, 48, 44,
  48, 44, 50, 32, 45, 45, 99, 111, 108, 117, 109, 110, 115, 91, 45, 49,
  93, 32, 123, 40, 49, 45, 36, 55, 47, 49, 48, 48, 41, 42, 119, 47,
  50, 125, 44, 123, 40, 49, 43, 36, 55, 47, 49, 48, 48, 41, 42, 119,
  47, 50, 125, 10, 49, 48, 48, 37, 32, 45, 103, 97, 117, 115, 115, 105,
  97, 110, 91, 45, 49, 93, 32, 123, 48, 46, 49, 42, 119, 125, 44, 123,
  104, 125, 44, 48, 32, 49, 48, 48, 37, 32, 49, 48, 48, 37, 32, 45,
  97, 91, 45, 51, 45, 45, 49, 93, 32, 99, 32, 45, 114, 91, 45, 49,
  93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 51, 10,
  45, 115, 109, 111, 111, 116, 104, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  44, 36, 54, 44, 53, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 123, 40, 49, 45,
  36, 55, 47, 49, 48, 48, 41, 42, 64, 123, 45, 50, 44, 119, 125, 47,
  50, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 115, 104, 105, 102,
  116, 91, 45, 49, 93, 32, 45, 53, 48, 37, 44, 48, 44, 48, 44, 48,
  44, 50, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111,
  110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 115, 104, 105, 102, 116,
  32, 36, 53, 37, 44, 48, 44, 48, 44, 48, 44, 50, 32, 45, 116, 111,
  95, 114, 103, 98, 97, 10, 45, 105, 102, 32, 36, 57, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 10, 45, 45, 114, 111, 119, 115, 91, 36,
  62, 93, 32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 49, 44, 49, 44,
  49, 44, 52, 44, 50, 32, 82, 71, 66, 65, 36, 62, 61, 64, 45, 49,
  10, 45, 114, 91, 45, 49, 93, 32, 91, 36, 62, 93, 44, 91, 36, 62,
  93, 44, 49, 44, 52, 32, 45, 45, 91, 36, 62, 44, 45, 49, 93, 10,
  45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 109, 97,
  112, 95, 115, 112, 104, 101, 114, 101, 32, 36, 49, 44, 36, 50, 44, 36,
  51, 44, 36, 52, 44, 36, 49, 48, 44, 36, 49, 49, 10, 45, 105, 102,
  32, 36, 57, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 40,
  36, 123, 82, 71, 66, 65, 36, 62, 125, 41, 32, 45, 121, 91, 45, 49,
  93, 32, 99, 32, 45, 114, 91, 45, 49, 93, 32, 91, 36, 62, 93, 44,
  91, 36, 62, 93, 44, 49, 44, 52, 32, 45, 43, 91, 36, 62, 44, 45,
  49, 93, 10, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10,
  103, 105, 109, 112, 95, 109, 97, 112, 95, 115, 112, 104, 101, 114, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  109, 97, 112, 95, 115, 112, 104, 101, 114, 101, 32, 123, 119, 125, 44, 123,
  104, 125, 44, 36, 123, 51, 45, 45, 49, 125, 10, 35, 64, 103, 105, 109,
  112, 32, 83, 121, 109, 109, 101, 116, 114, 105, 122, 101, 32, 58, 32, 103,
  105, 109, 112, 95, 115, 121, 109, 109, 101, 116, 114, 105, 122, 101, 44, 32,
  103, 105, 109, 112, 95, 115, 121, 109, 109, 101, 116, 114, 105, 122, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 88, 45, 99, 101, 110, 116, 101, 114, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 101, 110, 116, 101, 114,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 57, 48, 44, 48, 44, 51,
  54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 111, 117,
  110, 100, 97, 114, 121, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49,
  44, 34, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 116, 34, 44, 34,
  78, 101, 97, 114, 101, 115, 116, 34, 44, 34, 82, 101, 112, 101, 97, 116,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 83, 121, 109, 109, 101,
  116, 114, 121, 34, 44, 34, 65, 110, 116, 105, 115, 121, 109, 109, 101, 116,
  114, 121, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 119,
  97, 112, 32, 115, 105, 100, 101, 115, 32, 61, 32, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 51, 47, 48, 49, 47, 48, 55, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  115, 121, 109, 109, 101, 116, 114, 105, 122, 101, 32, 58, 10, 45, 116, 111,
  95, 114, 103, 98, 97, 32, 45, 115, 121, 109, 109, 101, 116, 114, 105, 122,
  101, 32, 36, 49, 37, 44, 36, 50, 37, 44, 36, 51, 44, 36, 52, 44,
  36, 53, 44, 36, 54, 10, 103, 105, 109, 112, 95, 115, 121, 109, 109, 101,
  116, 114, 105, 122, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 121, 109, 109, 101, 116, 114, 105, 122, 101,
  32, 36, 42, 10, 116, 104, 101, 116, 97, 61, 123, 36, 51, 42, 112, 105,
  47, 49, 56, 48, 125, 32, 117, 61, 123, 99, 111, 115, 40, 36, 116, 104,
  101, 116, 97, 41, 125, 32, 118, 61, 123, 115, 105, 110, 40, 36, 116, 104,
  101, 116, 97, 41, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 120, 48, 61, 123, 119, 42, 36, 49,
  37, 125, 10, 121, 48, 61, 123, 104, 42, 36, 50, 37, 125, 10, 120, 49,
  61, 123, 36, 120, 48, 45, 109, 97, 120, 40, 119, 44, 104, 41, 42, 36,
  117, 125, 32, 121, 49, 61, 123, 36, 121, 48, 45, 109, 97, 120, 40, 119,
  44, 104, 41, 42, 36, 118, 125, 10, 120, 50, 61, 123, 36, 120, 48, 43,
  109, 97, 120, 40, 119, 44, 104, 41, 42, 36, 117, 125, 32, 121, 50, 61,
  123, 36, 121, 48, 43, 109, 97, 120, 40, 119, 44, 104, 41, 42, 36, 118,
  125, 10, 45, 108, 105, 110, 101, 32, 36, 120, 49, 44, 36, 121, 49, 44,
  36, 120, 50, 44, 36, 121, 50, 44, 49, 44, 48, 120, 48, 70, 48, 70,
  48, 70, 48, 70, 44, 48, 10, 45, 108, 105, 110, 101, 32, 36, 120, 49,
  44, 36, 121, 49, 44, 36, 120, 50, 44, 36, 121, 50, 44, 49, 44, 48,
  120, 70, 48, 70, 48, 70, 48, 70, 48, 44, 50, 53, 53, 10, 45, 99,
  105, 114, 99, 108, 101, 32, 36, 120, 48, 44, 36, 121, 48, 44, 51, 44,
  49, 44, 48, 44, 50, 53, 53, 44, 48, 44, 50, 53, 53, 10, 45, 99,
  105, 114, 99, 108, 101, 32, 36, 120, 48, 44, 36, 121, 48, 44, 51, 44,
  49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 44, 48,
  44, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 84, 101, 120, 116, 117, 114,
  101, 100, 32, 103, 108, 97, 115, 115, 32, 58, 32, 103, 105, 109, 112, 95,
  116, 101, 120, 116, 117, 114, 101, 100, 95, 103, 108, 97, 115, 115, 44, 32,
  103, 105, 109, 112, 95, 116, 101, 120, 116, 117, 114, 101, 100, 95, 103, 108,
  97, 115, 115, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 97, 109, 112, 108, 105, 116,
  117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 48, 44, 48,
  44, 52, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89,
  45, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 52, 48, 44, 48, 44, 52, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 88, 45, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  69, 100, 103, 101, 32, 97, 116, 116, 101, 110, 117, 97, 116, 105, 111, 110,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101, 32, 105, 110,
  102, 108, 117, 101, 110, 99, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  50, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 105, 115, 101, 32, 115, 99, 97, 108, 101, 32, 61, 32, 105,
  110, 116, 40, 48, 44, 48, 44, 49, 54, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117,
  108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117,
  112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 51, 47, 49, 49, 47, 50, 49, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  116, 101, 120, 116, 117, 114, 101, 100, 95, 103, 108, 97, 115, 115, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49,
  10, 45, 105, 102, 32, 36, 55, 32, 45, 112, 108, 97, 115, 109, 97, 91,
  45, 49, 93, 32, 49, 44, 49, 44, 36, 55, 32, 45, 101, 108, 115, 101,
  32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 103, 91, 45, 49, 93, 32, 120, 121, 10,
  45, 105, 102, 32, 36, 53, 10, 45, 45, 103, 114, 97, 100, 105, 101, 110,
  116, 95, 110, 111, 114, 109, 91, 45, 51, 93, 32, 45, 43, 91, 45, 49,
  93, 32, 49, 32, 45, 98, 91, 45, 49, 93, 32, 36, 54, 32, 45, 112,
  111, 119, 91, 45, 49, 93, 32, 45, 36, 53, 10, 45, 42, 91, 45, 51,
  93, 32, 91, 45, 49, 93, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 98, 108, 117, 114, 95, 120, 121,
  91, 45, 50, 44, 45, 49, 93, 32, 36, 51, 44, 36, 52, 10, 45, 42,
  91, 45, 50, 93, 32, 64, 123, 45, 50, 44, 36, 49, 47, 109, 97, 120,
  40, 97, 98, 115, 40, 105, 109, 41, 44, 97, 98, 115, 40, 105, 77, 41,
  41, 125, 10, 45, 42, 91, 45, 49, 93, 32, 64, 123, 45, 49, 44, 36,
  50, 47, 109, 97, 120, 40, 97, 98, 115, 40, 105, 109, 41, 44, 97, 98,
  115, 40, 105, 77, 41, 41, 125, 10, 45, 97, 91, 45, 50, 44, 45, 49,
  93, 32, 99, 10, 45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 44, 49, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95,
  116, 101, 120, 116, 117, 114, 101, 100, 95, 103, 108, 97, 115, 115, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115,
  112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103,
  105, 109, 112, 95, 116, 101, 120, 116, 117, 114, 101, 100, 95, 103, 108, 97,
  115, 115, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 84, 119, 105, 114, 108, 32, 58, 32, 116, 119, 105, 114, 108, 44,
  32, 116, 119, 105, 114, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 44, 45, 53, 44, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 88, 45, 99, 101, 110, 116, 101, 114, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 101, 110, 116, 101,
  114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 111, 117, 110,
  100, 97, 114, 121, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44,
  34, 66, 108, 97, 99, 107, 34, 44, 34, 78, 101, 97, 114, 101, 115, 116,
  34, 44, 34, 82, 101, 112, 101, 97, 116, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49,
  50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 87, 97, 116, 101, 114,
  32, 58, 32, 119, 97, 116, 101, 114, 44, 32, 119, 97, 116, 101, 114, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108,
  105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 48,
  44, 48, 44, 51, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 46, 53, 44, 48, 44, 52, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115,
  99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47,
  49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 87, 97, 118, 101,
  32, 58, 32, 119, 97, 118, 101, 44, 32, 119, 97, 118, 101, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116,
  117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48,
  44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 114,
  101, 113, 117, 101, 110, 99, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 52, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 45, 99, 101, 110, 116, 101, 114, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 89, 45, 99, 101, 110, 116, 101, 114, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  87, 105, 110, 100, 32, 58, 32, 103, 105, 109, 112, 95, 119, 105, 110, 100,
  44, 32, 103, 105, 109, 112, 95, 119, 105, 110, 100, 95, 112, 114, 101, 118,
  105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 105, 110, 116, 40,
  50, 48, 44, 48, 44, 53, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 116, 116, 101, 110, 117, 97, 116, 105, 111, 110, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111,
  108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111,
  100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 68,
  97, 114, 107, 101, 114, 34, 44, 34, 66, 114, 105, 103, 104, 116, 101, 114,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110,
  110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71,
  66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114,
  111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103,
  104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114,
  97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34,
  75, 101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101,
  110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80,
  114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68,
  117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104,
  117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48, 55,
  47, 49, 51, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 103, 105, 109, 112, 95, 119, 105, 110, 100, 32, 58, 10, 45,
  105, 102, 32, 123, 33, 36, 53, 125, 32, 45, 110, 101, 103, 97, 116, 105,
  118, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 112, 112, 108, 121,
  95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 119, 105, 110, 100,
  32, 36, 123, 49, 45, 52, 125, 34, 44, 36, 45, 50, 10, 45, 105, 102,
  32, 123, 33, 36, 53, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101,
  32, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 119, 105, 110,
  100, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 119, 105, 110, 100, 32, 36, 42, 34, 44,
  36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 90, 111, 111, 109, 32,
  58, 32, 103, 105, 109, 112, 95, 122, 111, 111, 109, 44, 32, 103, 105, 109,
  112, 95, 122, 111, 111, 109, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 70, 97, 99, 116, 111, 114, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 50, 44, 48, 46, 48, 49, 44, 49, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 88, 45, 99, 101, 110, 116, 101, 114, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 101, 110, 116, 101,
  114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 111, 117, 110,
  100, 97, 114, 121, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44,
  34, 66, 108, 97, 99, 107, 34, 44, 34, 78, 101, 97, 114, 101, 115, 116,
  34, 44, 34, 82, 101, 112, 101, 97, 116, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49,
  50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 122, 111, 111, 109, 32, 58, 10,
  45, 105, 102, 32, 123, 36, 49, 60, 49, 125, 32, 45, 116, 111, 95, 114,
  103, 98, 97, 32, 45, 101, 110, 100, 105, 102, 10, 45, 122, 111, 111, 109,
  32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 48, 44, 36, 52, 10, 35,
  64, 103, 105, 109, 112, 32, 95, 10, 35, 64, 103, 105, 109, 112, 32, 60,
  98, 62, 68, 101, 103, 114, 97, 100, 97, 116, 105, 111, 110, 115, 60, 47,
  98, 62, 10, 35, 64, 103, 105, 109, 112, 32, 66, 108, 117, 114, 32, 91,
  97, 110, 103, 117, 108, 97, 114, 93, 32, 58, 32, 103, 105, 109, 112, 95,
  98, 108, 117, 114, 95, 97, 110, 103, 117, 108, 97, 114, 44, 32, 103, 105,
  109, 112, 95, 98, 108, 117, 114, 95, 97, 110, 103, 117, 108, 97, 114, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108,
  105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44,
  48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88,
  45, 99, 101, 110, 116, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 89, 45, 99, 101, 110, 116, 101, 114, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 104, 97, 114, 112, 110, 101, 115, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 53, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108,
  40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108,
  108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44,
  34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117,
  101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105,
  110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110,
  101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105,
  111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121,
  34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44,
  34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108, 117, 101, 32, 114,
  97, 110, 103, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 67,
  117, 116, 34, 44, 34, 78, 111, 114, 109, 97, 108, 105, 122, 101, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 98, 108,
  117, 114, 95, 97, 110, 103, 117, 108, 97, 114, 32, 58, 10, 45, 97, 112,
  112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 98,
  108, 117, 114, 95, 97, 110, 103, 117, 108, 97, 114, 32, 36, 49, 37, 44,
  36, 50, 44, 36, 51, 32, 45, 115, 104, 97, 114, 112, 101, 110, 32, 36,
  52, 34, 44, 36, 53, 44, 36, 54, 10, 35, 64, 103, 105, 109, 112, 32,
  66, 108, 117, 114, 32, 91, 100, 101, 112, 116, 104, 45, 111, 102, 45, 102,
  105, 101, 108, 100, 93, 32, 58, 32, 103, 105, 109, 112, 95, 98, 108, 117,
  114, 95, 100, 111, 102, 44, 32, 103, 105, 109, 112, 95, 98, 108, 117, 114,
  95, 100, 111, 102, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 117, 114, 32, 97, 109,
  112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 105, 110, 116, 40, 51, 50,
  44, 50, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 66, 108, 117, 114, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 49, 44, 34, 73, 110, 110, 101, 114, 32, 98, 108, 117,
  114, 34, 44, 34, 79, 117, 116, 101, 114, 32, 98, 108, 117, 114, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 88, 45, 99, 101, 110, 116, 101, 114, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 101, 110, 116, 101,
  114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 105, 114,
  115, 116, 32, 114, 97, 100, 105, 117, 115, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 51, 48, 44, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 99, 111, 110, 100, 32, 114, 97, 100, 105,
  117, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 48, 44, 48, 44,
  50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110,
  103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 97,
  100, 105, 110, 103, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53,
  44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 111, 119, 32, 103,
  117, 105, 100, 101, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 52, 47, 48, 50, 47, 50, 48, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 98, 108, 117,
  114, 95, 100, 111, 102, 32, 58, 10, 45, 95, 36, 48, 32, 36, 123, 49,
  45, 56, 125, 44, 48, 10, 95, 103, 105, 109, 112, 95, 98, 108, 117, 114,
  95, 100, 111, 102, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 114, 109, 97, 120, 61, 123, 40,
  119, 42, 119, 43, 104, 42, 104, 41, 94, 48, 46, 53, 125, 32, 82, 61,
  123, 36, 53, 42, 36, 114, 109, 97, 120, 47, 49, 48, 48, 125, 32, 114,
  61, 123, 36, 54, 42, 36, 114, 109, 97, 120, 47, 49, 48, 48, 125, 10,
  116, 61, 123, 36, 55, 42, 112, 105, 47, 49, 56, 48, 125, 32, 117, 61,
  123, 99, 111, 115, 40, 36, 116, 41, 125, 32, 118, 61, 123, 115, 105, 110,
  40, 36, 116, 41, 125, 10, 108, 49, 61, 123, 40, 36, 114, 109, 97, 120,
  47, 40, 49, 101, 45, 56, 43, 36, 82, 41, 41, 94, 50, 125, 32, 108,
  50, 61, 123, 40, 36, 114, 109, 97, 120, 47, 40, 49, 101, 45, 56, 43,
  36, 114, 41, 41, 94, 50, 125, 10, 97, 61, 123, 36, 108, 49, 42, 40,
  36, 117, 41, 94, 50, 43, 36, 108, 50, 42, 40, 36, 118, 41, 94, 50,
  125, 32, 98, 61, 123, 36, 117, 42, 36, 118, 42, 40, 36, 108, 49, 45,
  36, 108, 50, 41, 125, 32, 99, 61, 123, 36, 108, 49, 42, 40, 36, 118,
  41, 94, 50, 43, 36, 108, 50, 42, 40, 36, 117, 41, 94, 50, 125, 10,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 39, 88,
  61, 40, 120, 45, 36, 51, 42, 119, 47, 49, 48, 48, 41, 47, 109, 97,
  120, 40, 119, 44, 104, 41, 59, 89, 61, 40, 121, 45, 36, 52, 42, 104,
  47, 49, 48, 48, 41, 47, 109, 97, 120, 40, 119, 44, 104, 41, 59, 102,
  61, 36, 97, 42, 88, 42, 88, 43, 50, 42, 36, 98, 42, 88, 42, 89,
  43, 36, 99, 42, 89, 42, 89, 59, 118, 61, 101, 120, 112, 40, 45, 102,
  47, 50, 46, 53, 41, 39, 10, 100, 61, 123, 109, 105, 110, 40, 49, 45,
  36, 56, 44, 48, 46, 57, 57, 41, 47, 50, 125, 32, 45, 99, 91, 49,
  93, 32, 36, 100, 44, 123, 49, 45, 36, 100, 125, 32, 45, 45, 91, 49,
  93, 32, 36, 100, 32, 45, 42, 91, 49, 93, 32, 123, 40, 36, 49, 45,
  49, 41, 47, 40, 49, 45, 50, 42, 36, 100, 41, 125, 10, 45, 105, 102,
  32, 36, 57, 10, 45, 45, 105, 115, 111, 108, 105, 110, 101, 51, 100, 91,
  49, 93, 32, 123, 36, 49, 45, 49, 46, 53, 125, 32, 45, 99, 111, 108,
  51, 100, 91, 45, 49, 93, 32, 50, 53, 53, 44, 50, 53, 53, 44, 48,
  10, 45, 45, 105, 115, 111, 108, 105, 110, 101, 51, 100, 91, 49, 93, 32,
  123, 36, 49, 47, 50, 125, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49,
  93, 32, 50, 53, 53, 44, 49, 50, 56, 44, 48, 10, 45, 45, 105, 115,
  111, 108, 105, 110, 101, 51, 100, 91, 49, 93, 32, 48, 46, 53, 32, 45,
  99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 50, 53, 53, 44, 48, 44,
  48, 10, 45, 43, 51, 100, 91, 45, 51, 45, 45, 49, 93, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 111, 117, 110, 100, 91, 49, 93, 32, 49,
  10, 91, 48, 93, 44, 91, 48, 93, 44, 49, 44, 91, 48, 93, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 36, 49, 10, 45, 45, 61, 61, 91, 49,
  93, 32, 123, 105, 102, 40, 36, 50, 44, 36, 60, 44, 36, 62, 41, 125,
  10, 45, 106, 91, 45, 50, 93, 32, 91, 48, 93, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 44, 49, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 98, 91, 48, 93, 32, 123, 40, 49, 43, 36,
  62, 41, 47, 54, 48, 125, 37, 10, 45, 114, 112, 114, 111, 103, 114, 101,
  115, 115, 32, 123, 36, 62, 42, 49, 48, 48, 47, 40, 36, 49, 45, 49,
  41, 125, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 48, 44, 49,
  93, 10, 45, 105, 102, 32, 36, 57, 10, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 44, 51, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100,
  91, 45, 49, 93, 32, 91, 48, 93, 44, 48, 44, 48, 44, 48, 44, 49,
  44, 49, 44, 48, 44, 48, 10, 45, 114, 109, 91, 48, 93, 10, 45, 99,
  105, 114, 99, 108, 101, 91, 45, 49, 93, 32, 36, 51, 37, 44, 36, 52,
  37, 44, 51, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53,
  53, 10, 45, 45, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 91, 45, 49, 93, 32, 43, 32, 45, 110, 101, 113, 91,
  45, 49, 93, 32, 48, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49,
  93, 32, 51, 10, 45, 106, 91, 48, 93, 32, 91, 45, 50, 93, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 48, 46, 53, 44, 91, 45, 49, 93, 44,
  49, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  103, 105, 109, 112, 95, 98, 108, 117, 114, 95, 100, 111, 102, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 98,
  108, 117, 114, 95, 100, 111, 102, 32, 36, 42, 10, 35, 64, 103, 105, 109,
  112, 32, 66, 108, 117, 114, 32, 91, 103, 97, 117, 115, 115, 105, 97, 110,
  93, 32, 58, 32, 103, 105, 109, 112, 95, 103, 97, 117, 115, 115, 105, 97,
  110, 95, 98, 108, 117, 114, 44, 32, 103, 105, 109, 112, 95, 103, 97, 117,
  115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 95, 112, 114, 101, 118, 105,
  101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88,
  121, 45, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 51, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 88, 45, 97, 109, 112, 108, 105, 116, 117, 100, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 50, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 97, 109, 112, 108,
  105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66,
  111, 114, 100, 101, 114, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 115,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 66, 108, 97,
  99, 107, 34, 44, 34, 78, 101, 97, 114, 101, 115, 116, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40,
  115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108,
  34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34,
  76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101,
  47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101,
  115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111,
  110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34,
  44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34,
  66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108, 117, 101, 32, 114, 97,
  110, 103, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 67, 117,
  116, 34, 44, 34, 78, 111, 114, 109, 97, 108, 105, 122, 101, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108,
  105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32,
  60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112,
  101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  95, 103, 105, 109, 112, 95, 103, 97, 117, 115, 115, 105, 97, 110, 95, 98,
  108, 117, 114, 32, 58, 10, 45, 98, 32, 36, 49, 44, 36, 52, 10, 45,
  105, 102, 32, 123, 36, 50, 62, 48, 125, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 45, 49, 93, 32, 45, 115, 32, 121,
  32, 45, 98, 32, 36, 50, 44, 36, 52, 32, 45, 97, 32, 121, 32, 45,
  101, 110, 100, 108, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45,
  100, 111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 51, 62, 48, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 45, 49, 93, 32, 45, 115, 32, 120, 32, 45, 98,
  32, 36, 51, 44, 36, 52, 32, 45, 97, 32, 120, 32, 45, 101, 110, 100,
  108, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110,
  101, 32, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 103, 97,
  117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 32, 58, 10, 45, 97,
  112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45,
  95, 103, 105, 109, 112, 95, 103, 97, 117, 115, 115, 105, 97, 110, 95, 98,
  108, 117, 114, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 34,
  44, 36, 53, 44, 36, 54, 10, 103, 105, 109, 112, 95, 103, 97, 117, 115,
  115, 105, 97, 110, 95, 98, 108, 117, 114, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 103,
  97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 32, 36, 42, 34,
  44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 66, 108, 117, 114,
  32, 91, 103, 108, 111, 119, 93, 32, 58, 32, 103, 105, 109, 112, 95, 103,
  108, 111, 119, 44, 32, 103, 105, 109, 112, 95, 103, 108, 111, 119, 95, 112,
  114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 54, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44,
  34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114,
  101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34,
  44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115,
  34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115,
  34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72,
  117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34,
  44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34,
  71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34,
  82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108,
  117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97,
  116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 103, 108, 111, 119, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 103, 108, 111, 119, 32,
  36, 49, 34, 44, 36, 50, 44, 48, 10, 103, 105, 109, 112, 95, 103, 108,
  111, 119, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 103, 108, 111, 119, 32, 36, 42, 34,
  44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 66, 108, 117, 114,
  32, 91, 108, 105, 110, 101, 97, 114, 93, 32, 58, 32, 103, 105, 109, 112,
  95, 98, 108, 117, 114, 95, 108, 105, 110, 101, 97, 114, 44, 32, 103, 105,
  109, 112, 95, 98, 108, 117, 114, 95, 108, 105, 110, 101, 97, 114, 95, 112,
  114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 84, 97, 110, 103, 101, 110, 116, 32, 114, 97, 100, 105, 117,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 114, 116,
  104, 111, 103, 111, 110, 97, 108, 32, 114, 97, 100, 105, 117, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 56, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 114, 112,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 53, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66,
  111, 114, 100, 101, 114, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 115,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 66, 108, 97,
  99, 107, 34, 44, 34, 78, 101, 97, 114, 101, 115, 116, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40,
  115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108,
  34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34,
  76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101,
  47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101,
  115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111,
  110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34,
  44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34,
  66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108, 117, 101, 32, 114, 97,
  110, 103, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 67, 117,
  116, 34, 44, 34, 78, 111, 114, 109, 97, 108, 105, 122, 101, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108,
  105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32,
  60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112,
  101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  103, 105, 109, 112, 95, 98, 108, 117, 114, 95, 108, 105, 110, 101, 97, 114,
  32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101,
  108, 115, 32, 34, 45, 98, 108, 117, 114, 95, 108, 105, 110, 101, 97, 114,
  32, 36, 49, 44, 123, 36, 50, 42, 36, 49, 47, 49, 48, 48, 125, 44,
  36, 51, 44, 36, 53, 32, 45, 115, 104, 97, 114, 112, 101, 110, 32, 36,
  52, 34, 44, 36, 54, 44, 36, 55, 10, 103, 105, 109, 112, 95, 98, 108,
  117, 114, 95, 108, 105, 110, 101, 97, 114, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 98,
  108, 117, 114, 95, 108, 105, 110, 101, 97, 114, 32, 36, 42, 34, 44, 36,
  45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 66, 108, 117, 114, 32, 91,
  114, 97, 100, 105, 97, 108, 93, 32, 58, 32, 103, 105, 109, 112, 95, 98,
  108, 117, 114, 95, 114, 97, 100, 105, 97, 108, 44, 32, 103, 105, 109, 112,
  95, 98, 108, 117, 114, 95, 114, 97, 100, 105, 97, 108, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117,
  100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44, 48, 44, 50,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 101,
  110, 116, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53,
  44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89,
  45, 99, 101, 110, 116, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 104, 97, 114, 112, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 53, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44,
  34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114,
  101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34,
  44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115,
  34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115,
  34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72,
  117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34,
  44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34,
  71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34,
  82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108,
  117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 86, 97, 108, 117, 101, 32, 114, 97, 110, 103,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 67, 117, 116, 34,
  44, 34, 78, 111, 114, 109, 97, 108, 105, 122, 101, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84,
  115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48,
  47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 98, 108, 117, 114, 95,
  114, 97, 100, 105, 97, 108, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 98, 108, 117, 114, 95,
  114, 97, 100, 105, 97, 108, 32, 36, 49, 37, 44, 36, 50, 44, 36, 51,
  32, 45, 115, 104, 97, 114, 112, 101, 110, 32, 36, 52, 34, 44, 36, 53,
  44, 36, 54, 10, 35, 64, 103, 105, 109, 112, 32, 67, 82, 84, 32, 115,
  117, 98, 45, 112, 105, 120, 101, 108, 115, 32, 58, 32, 103, 105, 109, 112,
  95, 103, 99, 100, 95, 99, 114, 116, 44, 32, 103, 105, 109, 112, 95, 103,
  99, 100, 95, 99, 114, 116, 40, 50, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 105, 62, 67, 97, 116, 104, 111, 100, 101, 32, 114, 97, 121, 32, 116,
  117, 98, 101, 32, 115, 117, 98, 45, 112, 105, 120, 101, 108, 32, 114, 101,
  110, 100, 101, 114, 105, 110, 103, 32, 102, 105, 108, 116, 101, 114, 60, 47,
  105, 62, 34, 41, 44, 32, 115, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 72, 111, 114, 105, 122, 111, 110, 116, 97, 108, 32, 98, 108, 117, 114,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 56, 44, 48, 44, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 101, 114, 116, 105,
  99, 97, 108, 32, 98, 108, 117, 114, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 46, 56, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 99, 114, 101, 101, 110, 32, 98, 111, 114, 100, 101, 114,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 69, 113, 117, 97, 108, 105, 122, 101, 32, 61, 32, 98,
  111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32,
  60, 105, 62, 71, 97, 114, 97, 103, 101, 99, 111, 100, 101, 114, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51,
  47, 48, 50, 47, 48, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 103, 99, 100, 95, 99,
  114, 116, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49,
  46, 56, 125, 44, 36, 123, 50, 61, 49, 46, 56, 125, 44, 36, 123, 51,
  61, 48, 125, 44, 36, 123, 52, 61, 48, 125, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 116, 111,
  95, 114, 103, 98, 91, 48, 93, 10, 45, 101, 120, 112, 97, 110, 100, 95,
  120, 121, 32, 49, 50, 44, 48, 32, 50, 52, 44, 49, 52, 44, 49, 44,
  51, 44, 48, 10, 45, 102, 91, 45, 49, 93, 32, 34, 105, 102, 40, 40,
  120, 45, 99, 42, 52, 41, 37, 49, 50, 60, 52, 44, 50, 53, 53, 44,
  48, 41, 34, 10, 45, 102, 91, 45, 49, 93, 32, 34, 105, 102, 40, 120,
  37, 52, 61, 61, 48, 44, 48, 44, 105, 41, 34, 10, 45, 102, 91, 45,
  49, 93, 32, 34, 105, 102, 40, 40, 121, 37, 49, 52, 61, 61, 48, 41,
  38, 38, 40, 120, 37, 50, 52, 60, 49, 50, 41, 44, 48, 44, 105, 41,
  34, 10, 45, 102, 91, 45, 49, 93, 32, 34, 105, 102, 40, 40, 40, 121,
  45, 55, 41, 37, 49, 52, 61, 61, 48, 41, 38, 38, 40, 40, 120, 43,
  49, 50, 41, 37, 50, 52, 60, 49, 50, 41, 44, 48, 44, 105, 41, 34,
  10, 45, 97, 114, 114, 97, 121, 91, 45, 49, 93, 32, 123, 114, 111, 117,
  110, 100, 40, 64, 123, 48, 44, 119, 125, 47, 50, 52, 41, 125, 44, 123,
  114, 111, 117, 110, 100, 40, 64, 123, 48, 44, 104, 125, 47, 49, 52, 41,
  125, 44, 50, 10, 45, 122, 91, 45, 49, 93, 32, 48, 44, 48, 44, 123,
  64, 123, 48, 44, 119, 125, 45, 49, 125, 44, 123, 64, 123, 48, 44, 104,
  125, 45, 49, 125, 10, 45, 115, 32, 99, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 51, 32, 45, 98, 108, 101, 110, 100, 91, 45, 52, 44, 45, 49,
  93, 32, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97, 103, 101, 32, 45,
  100, 111, 110, 101, 32, 45, 97, 32, 99, 10, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 32, 45, 109, 101, 97, 110, 99, 117, 114, 118,
  97, 116, 117, 114, 101, 95, 102, 108, 111, 119, 91, 45, 49, 93, 32, 52,
  10, 45, 105, 102, 32, 36, 51, 10, 123, 119, 125, 44, 123, 104, 125, 44,
  49, 44, 49, 44, 48, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101,
  91, 45, 49, 93, 32, 53, 37, 44, 53, 37, 44, 57, 53, 37, 44, 57,
  53, 37, 44, 49, 44, 49, 10, 45, 98, 91, 45, 49, 93, 32, 49, 48,
  37, 32, 45, 42, 91, 48, 44, 49, 93, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 100, 101, 114, 105, 99, 104, 101, 91, 45, 49, 93, 32, 36, 49,
  44, 48, 44, 120, 32, 45, 100, 101, 114, 105, 99, 104, 101, 91, 45, 49,
  93, 32, 36, 50, 44, 48, 44, 121, 10, 45, 115, 104, 114, 105, 110, 107,
  95, 120, 121, 91, 45, 49, 93, 32, 49, 50, 32, 45, 110, 91, 45, 49,
  93, 32, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 36, 52, 32, 45,
  101, 113, 117, 97, 108, 105, 122, 101, 91, 45, 49, 93, 32, 50, 53, 54,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 68, 111, 102, 32, 109,
  97, 110, 105, 112, 117, 108, 97, 116, 105, 111, 110, 32, 58, 32, 103, 105,
  109, 112, 95, 116, 107, 95, 100, 111, 102, 44, 32, 103, 105, 109, 112, 95,
  116, 107, 95, 100, 111, 102, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 70, 111, 99, 97, 108, 32, 112, 111, 105, 110,
  116, 32, 120, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 53, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  70, 111, 99, 97, 108, 32, 112, 111, 105, 110, 116, 32, 121, 32, 61, 32,
  102, 108, 111, 97, 116, 32, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 111, 102, 32, 49, 32,
  61, 32, 105, 110, 116, 32, 40, 51, 48, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 111, 102, 32, 50, 32,
  61, 32, 105, 110, 116, 32, 40, 54, 48, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 114, 97, 110, 115, 105,
  116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48,
  44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101,
  102, 111, 99, 117, 115, 32, 115, 116, 114, 101, 110, 103, 116, 104, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 53, 44, 48, 44, 50, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 102, 111, 99, 117,
  115, 32, 115, 116, 121, 108, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 50, 44, 34, 109, 101, 100, 105, 97, 110, 34, 44, 34, 103, 97, 117,
  115, 115, 105, 97, 110, 34, 44, 34, 109, 105, 120, 101, 100, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 112, 116, 104, 32, 101,
  115, 116, 105, 109, 97, 116, 105, 111, 110, 32, 109, 111, 100, 101, 108, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 97, 117, 116, 111, 109, 97,
  116, 105, 99, 32, 100, 101, 112, 116, 104, 32, 101, 115, 116, 105, 109, 97,
  116, 105, 111, 110, 34, 44, 34, 100, 97, 121, 108, 105, 103, 104, 116, 32,
  115, 99, 101, 110, 101, 34, 44, 34, 105, 110, 100, 105, 118, 105, 100, 117,
  97, 108, 32, 102, 111, 99, 117, 115, 32, 102, 105, 101, 108, 100, 32, 109,
  97, 115, 107, 34, 44, 34, 105, 110, 100, 105, 118, 105, 100, 117, 97, 108,
  32, 100, 101, 112, 116, 104, 32, 109, 97, 112, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 66, 111, 107, 101, 104, 32, 115, 116, 114, 101,
  110, 103, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 105, 103,
  104, 108, 105, 103, 104, 116, 115, 32, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 48, 44, 48, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 111,
  107, 101, 104, 32, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 52, 48, 44, 50, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 66, 111, 107, 101, 104, 32, 98, 108, 117, 114, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 44, 50, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 112, 101, 114, 116, 117, 114, 101,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  99, 105, 114, 99, 117, 108, 97, 114, 34, 44, 34, 111, 99, 116, 111, 103,
  111, 110, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  82, 101, 109, 111, 118, 101, 32, 98, 108, 117, 114, 114, 105, 110, 103, 32,
  97, 114, 116, 105, 102, 97, 99, 116, 115, 32, 61, 32, 98, 111, 111, 108,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 104, 101, 105, 109, 112, 102,
  108, 117, 103, 32, 101, 102, 102, 101, 99, 116, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 110, 111, 110, 101, 34, 44, 34, 118, 101, 114, 116,
  105, 99, 97, 108, 32, 98, 108, 101, 110, 100, 34, 44, 34, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 32, 98, 108, 101, 110, 100, 34, 44, 34,
  118, 101, 114, 116, 105, 99, 97, 108, 32, 111, 110, 108, 121, 34, 44, 34,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 32, 111, 110, 108, 121, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 105, 108, 116, 32,
  112, 108, 97, 110, 101, 32, 49, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 84, 105, 108, 116, 32, 112, 108, 97, 110, 101, 32, 50, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 48, 49, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 109, 111,
  100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 105, 109, 97,
  103, 101, 34, 44, 34, 108, 97, 121, 101, 114, 115, 32, 105, 110, 32, 102,
  111, 99, 117, 115, 47, 111, 117, 116, 32, 111, 102, 32, 102, 111, 99, 117,
  115, 34, 44, 34, 102, 111, 99, 117, 115, 32, 102, 105, 101, 108, 100, 32,
  109, 97, 115, 107, 32, 111, 110, 108, 121, 34, 44, 34, 100, 101, 112, 116,
  104, 32, 101, 115, 116, 105, 109, 97, 116, 105, 111, 110, 32, 111, 110, 108,
  121, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 109,
  112, 117, 116, 97, 116, 105, 111, 110, 32, 109, 111, 100, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 104, 105, 103, 104, 32, 113,
  117, 97, 108, 105, 116, 121, 34, 44, 34, 110, 111, 114, 109, 97, 108, 34,
  44, 34, 104, 105, 103, 104, 32, 115, 112, 101, 101, 100, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 85, 115, 101, 32, 116, 114, 101, 115,
  104, 111, 108, 100, 32, 109, 97, 115, 107, 32, 109, 111, 100, 101, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  84, 111, 109, 32, 75, 101, 105, 108, 60, 47, 105, 62, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 50, 47, 50, 49, 47, 48, 49, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105,
  110, 107, 40, 34, 70, 105, 108, 116, 101, 114, 32, 101, 120, 112, 108, 97,
  105, 110, 101, 100, 32, 104, 101, 114, 101, 34, 44, 104, 116, 116, 112, 58,
  47, 47, 119, 119, 119, 46, 116, 107, 102, 105, 108, 116, 101, 114, 46, 98,
  112, 108, 97, 99, 101, 100, 46, 110, 101, 116, 47, 84, 75, 70, 105, 108,
  116, 101, 114, 37, 50, 48, 116, 117, 116, 111, 114, 105, 97, 108, 115, 37,
  50, 48, 68, 79, 70, 37, 50, 48, 109, 97, 110, 105, 112, 117, 108, 97,
  116, 105, 111, 110, 46, 104, 116, 109, 108, 41, 10, 103, 105, 109, 112, 95,
  116, 107, 95, 100, 111, 102, 32, 58, 10, 45, 105, 102, 32, 123, 123, 36,
  56, 61, 61, 48, 125, 124, 124, 123, 36, 56, 61, 61, 49, 125, 125, 32,
  45, 105, 102, 32, 123, 123, 64, 35, 125, 33, 61, 49, 125, 32, 45, 101,
  114, 114, 111, 114, 91, 93, 32, 34, 83, 101, 108, 101, 99, 116, 32, 105,
  110, 112, 117, 116, 32, 109, 111, 100, 101, 32, 65, 67, 84, 73, 86, 69,
  46, 32, 84, 104, 105, 115, 32, 111, 112, 116, 105, 111, 110, 32, 105, 115,
  32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 32, 102, 111, 114, 32, 115,
  105, 110, 103, 108, 101, 32, 108, 97, 121, 101, 114, 32, 111, 110, 108, 121,
  46, 34, 10, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 123, 36, 56, 61, 61, 50, 125, 124, 124, 123,
  36, 56, 61, 61, 51, 125, 125, 32, 45, 105, 102, 32, 123, 123, 36, 49,
  53, 61, 61, 51, 125, 124, 124, 123, 36, 49, 53, 61, 61, 52, 125, 124,
  124, 123, 36, 49, 55, 61, 61, 51, 125, 125, 32, 45, 101, 114, 114, 111,
  114, 91, 93, 32, 34, 79, 112, 116, 105, 111, 110, 32, 110, 111, 116, 32,
  97, 118, 97, 105, 108, 97, 98, 108, 101, 32, 102, 111, 114, 32, 105, 110,
  100, 105, 118, 105, 100, 117, 97, 108, 32, 109, 97, 115, 107, 34, 32, 45,
  101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 123, 36, 56, 61, 61, 50, 125, 124, 124, 123, 36, 56, 61, 61,
  51, 125, 125, 32, 45, 105, 102, 32, 123, 123, 64, 35, 125, 33, 61, 50,
  125, 32, 45, 101, 114, 114, 111, 114, 91, 93, 32, 34, 70, 111, 114, 32,
  105, 110, 100, 105, 118, 105, 100, 117, 97, 108, 32, 109, 97, 115, 107, 32,
  115, 101, 108, 101, 99, 116, 32, 105, 110, 112, 117, 116, 32, 109, 111, 100,
  101, 32, 65, 67, 84, 73, 86, 69, 32, 65, 78, 68, 32, 66, 69, 76,
  79, 87, 34, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105,
  102, 10, 116, 114, 61, 123, 36, 53, 125, 32, 100, 102, 115, 61, 123, 36,
  54, 125, 32, 98, 115, 105, 61, 123, 36, 49, 49, 125, 32, 98, 115, 98,
  61, 123, 36, 49, 50, 125, 10, 45, 105, 102, 32, 123, 36, 49, 57, 61,
  61, 49, 125, 32, 115, 99, 100, 111, 61, 53, 48, 32, 115, 99, 117, 112,
  61, 50, 48, 48, 32, 116, 114, 61, 123, 36, 53, 47, 50, 125, 32, 100,
  102, 115, 61, 123, 36, 54, 47, 50, 125, 32, 98, 115, 105, 61, 123, 36,
  49, 49, 47, 50, 125, 32, 98, 115, 98, 61, 123, 36, 49, 50, 47, 50,
  125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49,
  57, 61, 61, 50, 125, 32, 115, 99, 100, 111, 61, 50, 53, 32, 115, 99,
  117, 112, 61, 52, 48, 48, 32, 116, 114, 61, 123, 36, 53, 47, 52, 125,
  32, 100, 102, 115, 61, 123, 36, 54, 47, 52, 125, 32, 98, 115, 105, 61,
  123, 36, 49, 49, 47, 52, 125, 32, 98, 115, 98, 61, 123, 36, 49, 50,
  47, 52, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  123, 36, 56, 61, 61, 48, 125, 124, 124, 123, 36, 56, 61, 61, 49, 125,
  125, 32, 45, 105, 102, 32, 123, 36, 49, 57, 33, 61, 48, 125, 32, 45,
  45, 114, 91, 48, 93, 32, 36, 115, 99, 100, 111, 37, 44, 36, 115, 99,
  100, 111, 37, 32, 45, 101, 108, 115, 101, 32, 45, 45, 103, 105, 109, 112,
  95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 48, 93, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101, 32, 45, 105, 102, 32,
  123, 36, 49, 57, 33, 61, 48, 125, 32, 45, 114, 91, 45, 49, 93, 32,
  36, 115, 99, 100, 111, 37, 44, 36, 115, 99, 100, 111, 37, 32, 45, 101,
  110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 49, 57, 33, 61, 48, 125, 32, 45, 45, 114, 91, 48, 93, 32,
  36, 115, 99, 100, 111, 37, 44, 36, 115, 99, 100, 111, 37, 32, 45, 101,
  108, 115, 101, 32, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111,
  116, 104, 105, 110, 103, 91, 48, 93, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 123, 36, 56, 61, 61, 50, 125, 124, 124, 123, 36,
  56, 61, 61, 51, 125, 125, 32, 45, 114, 118, 91, 45, 49, 44, 45, 50,
  93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 123, 36,
  49, 53, 61, 61, 48, 125, 124, 124, 123, 36, 49, 53, 61, 61, 49, 125,
  124, 124, 123, 36, 49, 53, 61, 61, 50, 125, 125, 10, 45, 105, 102, 32,
  123, 36, 56, 61, 61, 48, 125, 32, 45, 103, 105, 109, 112, 95, 116, 107,
  95, 97, 117, 116, 111, 100, 101, 112, 116, 104, 91, 45, 49, 93, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 56, 61, 61, 49, 125, 32, 45, 103, 105,
  109, 112, 95, 116, 107, 95, 100, 101, 112, 116, 104, 109, 97, 112, 91, 45,
  49, 93, 32, 49, 44, 50, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44,
  48, 10, 45, 101, 108, 105, 102, 32, 123, 123, 36, 56, 61, 61, 50, 125,
  124, 124, 123, 36, 56, 61, 61, 51, 125, 125, 32, 45, 103, 105, 109, 112,
  95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 56, 33, 61, 51, 125, 32,
  45, 105, 102, 32, 123, 36, 56, 33, 61, 50, 125, 10, 45, 105, 102, 32,
  123, 36, 50, 48, 61, 61, 49, 125, 32, 45, 116, 111, 95, 114, 103, 98,
  91, 45, 49, 93, 10, 45, 45, 102, 91, 45, 49, 93, 32, 105, 102, 40,
  105, 62, 61, 123, 123, 50, 53, 53, 45, 36, 51, 125, 43, 123, 36, 52,
  47, 50, 125, 125, 44, 48, 44, 105, 41, 10, 45, 45, 102, 91, 45, 49,
  93, 32, 105, 102, 40, 105, 60, 61, 123, 123, 50, 53, 53, 45, 36, 51,
  125, 45, 123, 36, 52, 47, 50, 125, 125, 44, 48, 44, 105, 41, 32, 45,
  99, 111, 109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101, 110, 91, 45,
  49, 44, 45, 50, 93, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 32, 45, 102, 91, 45, 49, 93, 32, 105, 102, 40, 105, 62, 61,
  49, 44, 50, 53, 53, 44, 105, 41, 32, 45, 114, 109, 91, 45, 50, 93,
  10, 45, 101, 108, 115, 101, 10, 45, 108, 111, 99, 97, 108, 95, 115, 105,
  109, 105, 108, 97, 114, 105, 116, 121, 95, 109, 97, 115, 107, 91, 45, 49,
  93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 52, 44,
  48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 98, 108, 117, 114, 95, 120,
  121, 91, 45, 49, 93, 32, 36, 116, 114, 10, 45, 101, 110, 100, 105, 102,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 123, 36, 49, 53, 61, 61, 49, 125, 124, 124, 123, 36,
  49, 53, 61, 61, 51, 125, 125, 10, 45, 45, 103, 105, 109, 112, 95, 108,
  105, 110, 101, 97, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45,
  49, 93, 32, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 49, 44, 49,
  56, 48, 44, 49, 48, 48, 44, 36, 49, 54, 10, 45, 45, 103, 105, 109,
  112, 95, 108, 105, 110, 101, 97, 114, 95, 103, 114, 97, 100, 105, 101, 110,
  116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  48, 44, 49, 56, 48, 44, 48, 44, 36, 49, 55, 10, 45, 99, 111, 109,
  112, 111, 115, 101, 95, 100, 97, 114, 107, 101, 110, 91, 45, 49, 44, 45,
  50, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 123,
  36, 49, 53, 61, 61, 50, 125, 124, 124, 123, 36, 49, 53, 61, 61, 52,
  125, 125, 10, 45, 45, 103, 105, 109, 112, 95, 108, 105, 110, 101, 97, 114,
  95, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32, 48, 44,
  48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 49, 44, 57, 48, 44, 49, 48, 48,
  44, 36, 49, 54, 10, 45, 45, 103, 105, 109, 112, 95, 108, 105, 110, 101,
  97, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32,
  48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 57, 48, 44, 48,
  44, 36, 49, 55, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 100, 97,
  114, 107, 101, 110, 91, 45, 49, 44, 45, 50, 93, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 123, 36, 49, 53, 61, 61, 49, 125,
  124, 124, 123, 36, 49, 53, 61, 61, 50, 125, 125, 32, 45, 114, 118, 91,
  45, 49, 44, 45, 50, 93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  108, 105, 103, 104, 116, 101, 110, 91, 45, 49, 44, 45, 50, 93, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 123, 36, 49, 53, 61,
  61, 51, 125, 124, 124, 123, 36, 49, 53, 61, 61, 52, 125, 125, 32, 45,
  114, 109, 91, 45, 50, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 123, 36, 49, 56, 61, 61, 48, 125, 124, 124, 123, 36, 49,
  56, 61, 61, 49, 125, 125, 10, 45, 105, 102, 32, 123, 36, 49, 52, 61,
  61, 49, 125, 32, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111,
  116, 104, 105, 110, 103, 91, 45, 49, 44, 45, 50, 93, 10, 45, 98, 108,
  117, 114, 95, 120, 121, 91, 45, 49, 93, 32, 123, 36, 116, 114, 47, 50,
  125, 10, 45, 116, 50, 91, 45, 49, 93, 32, 49, 44, 50, 53, 54, 32,
  45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 116, 107,
  95, 103, 105, 109, 112, 95, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111,
  108, 111, 114, 91, 45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 48, 44,
  48, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 48, 10, 45, 105,
  110, 112, 97, 105, 110, 116, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32,
  45, 114, 109, 91, 45, 49, 44, 49, 93, 32, 45, 114, 118, 91, 45, 49,
  44, 45, 50, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 55, 61, 61, 48, 125, 32, 45, 109, 101, 100, 105, 97, 110, 91,
  45, 50, 93, 32, 36, 100, 102, 115, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 55, 61, 61, 49, 125, 32, 45, 98, 108, 117, 114, 95, 120, 121, 91,
  45, 50, 93, 32, 36, 100, 102, 115, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 55, 61, 61, 50, 125, 32, 45, 109, 101, 100, 105, 97, 110, 91, 45,
  50, 93, 32, 123, 36, 100, 102, 115, 47, 50, 125, 32, 45, 98, 108, 117,
  114, 95, 120, 121, 91, 45, 49, 93, 32, 123, 36, 100, 102, 115, 47, 53,
  125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 57,
  33, 61, 48, 125, 32, 45, 105, 102, 32, 123, 36, 49, 57, 61, 61, 48,
  125, 32, 32, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116,
  104, 105, 110, 103, 91, 48, 93, 32, 45, 101, 108, 115, 101, 32, 45, 45,
  114, 91, 48, 93, 32, 36, 115, 99, 100, 111, 37, 44, 36, 115, 99, 100,
  111, 37, 32, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95,
  109, 111, 114, 112, 104, 111, 91, 45, 49, 93, 32, 49, 44, 36, 98, 115,
  105, 44, 48, 44, 123, 50, 45, 36, 49, 51, 125, 44, 48, 44, 49, 44,
  48, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 114, 101, 112, 108, 97,
  99, 101, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 123, 36, 49,
  48, 42, 49, 46, 55, 54, 53, 125, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 48, 10, 45, 98, 108,
  117, 114, 95, 120, 121, 91, 45, 49, 93, 32, 36, 98, 115, 98, 10, 45,
  114, 118, 91, 45, 49, 44, 45, 51, 93, 32, 45, 103, 105, 109, 112, 95,
  99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103, 104, 116, 101, 110, 91,
  45, 49, 44, 45, 51, 93, 32, 36, 57, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 49, 57, 33, 61, 48, 125, 32, 45, 114,
  91, 49, 44, 50, 93, 32, 36, 115, 99, 117, 112, 37, 44, 36, 115, 99,
  117, 112, 37, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 114,
  103, 98, 97, 91, 48, 93, 32, 45, 115, 91, 48, 93, 32, 99, 32, 45,
  114, 118, 91, 51, 44, 53, 93, 10, 45, 99, 111, 109, 112, 111, 115, 101,
  95, 109, 117, 108, 116, 105, 112, 108, 121, 91, 51, 44, 53, 93, 32, 45,
  116, 111, 95, 103, 114, 97, 121, 91, 51, 93, 10, 45, 97, 91, 48, 44,
  49, 44, 50, 44, 51, 93, 32, 99, 10, 45, 105, 102, 32, 123, 36, 49,
  56, 61, 61, 48, 125, 32, 45, 114, 118, 91, 48, 44, 49, 93, 32, 45,
  99, 111, 109, 112, 111, 115, 101, 95, 114, 103, 98, 97, 91, 48, 44, 49,
  93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 49, 56, 33, 61, 49, 125, 32, 45, 107, 91,
  45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  123, 36, 49, 56, 61, 61, 50, 125, 124, 124, 123, 36, 49, 56, 61, 61,
  51, 125, 125, 32, 45, 105, 102, 32, 123, 36, 49, 57, 33, 61, 48, 125,
  32, 45, 114, 91, 45, 49, 93, 32, 36, 115, 99, 117, 112, 37, 44, 36,
  115, 99, 117, 112, 37, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110,
  100, 105, 102, 10, 103, 105, 109, 112, 95, 116, 107, 95, 100, 111, 102, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 116, 111, 95, 114, 103,
  98, 97, 10, 45, 105, 102, 32, 123, 123, 36, 56, 61, 61, 48, 125, 124,
  124, 123, 36, 56, 61, 61, 49, 125, 125, 32, 45, 105, 102, 32, 123, 123,
  64, 35, 125, 33, 61, 49, 125, 32, 45, 101, 114, 114, 111, 114, 91, 93,
  32, 34, 83, 101, 108, 101, 99, 116, 32, 105, 110, 112, 117, 116, 32, 109,
  111, 100, 101, 32, 65, 67, 84, 73, 86, 69, 46, 32, 84, 104, 105, 115,
  32, 111, 112, 116, 105, 111, 110, 32, 105, 115, 32, 97, 118, 97, 105, 108,
  97, 98, 108, 101, 32, 102, 111, 114, 32, 115, 105, 110, 103, 108, 101, 32,
  108, 97, 121, 101, 114, 32, 111, 110, 108, 121, 46, 34, 10, 45, 101, 110,
  100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  123, 36, 56, 33, 61, 50, 125, 38, 38, 123, 36, 56, 33, 61, 51, 125,
  125, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 116, 107, 95,
  100, 111, 102, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49,
  10, 45, 101, 108, 115, 101, 32, 45, 103, 105, 109, 112, 95, 116, 107, 95,
  100, 111, 102, 32, 36, 123, 49, 45, 45, 49, 125, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 116, 111, 95, 114, 103, 98, 97, 10, 45, 105, 102, 32,
  123, 36, 50, 48, 61, 61, 48, 125, 10, 45, 108, 105, 110, 101, 32, 49,
  48, 48, 37, 44, 36, 50, 37, 44, 123, 36, 49, 43, 53, 125, 37, 44,
  36, 50, 37, 44, 49, 44, 50, 53, 53, 44, 48, 44, 48, 10, 45, 108,
  105, 110, 101, 32, 48, 37, 44, 36, 50, 37, 44, 123, 36, 49, 45, 53,
  125, 37, 44, 36, 50, 37, 44, 49, 44, 50, 53, 53, 44, 48, 44, 48,
  10, 45, 108, 105, 110, 101, 32, 36, 49, 37, 44, 49, 48, 48, 37, 44,
  36, 49, 37, 44, 123, 36, 50, 43, 53, 125, 37, 44, 49, 44, 50, 53,
  53, 44, 48, 44, 48, 10, 45, 108, 105, 110, 101, 32, 36, 49, 37, 44,
  48, 37, 44, 36, 49, 37, 44, 123, 36, 50, 45, 53, 125, 37, 44, 49,
  44, 50, 53, 53, 44, 48, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10,
  35, 64, 103, 105, 109, 112, 32, 76, 111, 109, 111, 32, 58, 32, 103, 105,
  109, 112, 95, 108, 111, 109, 111, 44, 32, 103, 105, 109, 112, 95, 108, 111,
  109, 111, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 86, 105, 103, 110, 101, 116, 116, 101, 32,
  115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99,
  97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65,
  117, 116, 104, 111, 114, 115, 58, 32, 60, 105, 62, 74, 38, 35, 50, 51,
  51, 59, 114, 111, 109, 101, 32, 66, 111, 117, 108, 97, 110, 103, 101, 114,
  44, 32, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101,
  114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 50, 47, 48, 54, 47, 48, 54, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103,
  105, 109, 112, 95, 108, 111, 109, 111, 32, 58, 10, 45, 114, 101, 109, 111,
  118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 103,
  97, 117, 115, 115, 105, 97, 110, 32, 123, 49, 48, 48, 45, 36, 49, 125,
  37, 44, 123, 49, 48, 48, 45, 36, 49, 125, 37, 32, 45, 110, 111, 114,
  109, 97, 108, 105, 122, 101, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45,
  42, 10, 45, 115, 32, 99, 10, 45, 102, 91, 48, 93, 32, 39, 50, 53,
  53, 42, 97, 116, 97, 110, 40, 40, 105, 45, 49, 50, 56, 41, 47, 49,
  50, 56, 41, 39, 10, 45, 102, 91, 49, 93, 32, 39, 50, 53, 53, 42,
  116, 97, 110, 40, 40, 105, 45, 49, 50, 56, 41, 47, 49, 50, 56, 41,
  39, 10, 45, 102, 91, 50, 93, 32, 39, 50, 53, 53, 42, 97, 116, 97,
  110, 40, 40, 105, 45, 49, 50, 56, 41, 47, 50, 53, 53, 41, 39, 10,
  45, 97, 32, 99, 10, 45, 115, 104, 97, 114, 112, 101, 110, 32, 49, 10,
  45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 32, 48, 44, 50, 53, 53,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109,
  112, 95, 108, 111, 109, 111, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 108, 111, 109, 111,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32,
  78, 111, 105, 115, 101, 32, 91, 97, 100, 100, 105, 116, 105, 118, 101, 93,
  32, 58, 32, 103, 105, 109, 112, 95, 110, 111, 105, 115, 101, 44, 32, 103,
  105, 109, 112, 95, 110, 111, 105, 115, 101, 95, 112, 114, 101, 118, 105, 101,
  119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109,
  112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 48, 44, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 105, 115, 101, 32, 116, 121, 112, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 71, 97, 117, 115, 115, 105, 97, 110,
  34, 44, 34, 85, 110, 105, 102, 111, 114, 109, 34, 44, 34, 83, 97, 108,
  116, 32, 97, 110, 100, 32, 112, 101, 112, 112, 101, 114, 34, 44, 34, 80,
  111, 105, 115, 115, 111, 110, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66,
  65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108,
  117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97,
  98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44,
  34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97,
  108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101,
  110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34,
  99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34,
  44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44,
  34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 86, 97, 108, 117, 101, 32, 114, 97, 110, 103, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 67, 117, 116, 34, 44, 34, 78, 111,
  114, 109, 97, 108, 105, 122, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121,
  112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112,
  108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118,
  105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50,
  51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62,
  50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 110,
  111, 105, 115, 101, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104,
  97, 110, 110, 101, 108, 115, 32, 34, 45, 110, 111, 105, 115, 101, 32, 36,
  49, 44, 36, 50, 34, 44, 36, 51, 44, 36, 52, 10, 103, 105, 109, 112,
  95, 110, 111, 105, 115, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 110, 111, 105, 115,
  101, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112,
  32, 78, 111, 105, 115, 101, 32, 91, 115, 112, 114, 101, 97, 100, 93, 32,
  58, 32, 103, 105, 109, 112, 95, 115, 112, 114, 101, 97, 100, 44, 32, 103,
  105, 109, 112, 95, 115, 112, 114, 101, 97, 100, 95, 112, 114, 101, 118, 105,
  101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88,
  45, 118, 97, 114, 105, 97, 116, 105, 111, 110, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 52, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 89, 45, 118, 97, 114, 105, 97, 116, 105, 111, 110,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 44, 48, 44, 50, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110,
  101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66,
  34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66,
  108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104,
  116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97,
  116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75,
  101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110,
  34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117,
  112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47,
  50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 115, 112, 114, 101, 97, 100, 32, 58, 10,
  45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  34, 45, 115, 112, 114, 101, 97, 100, 32, 36, 49, 44, 36, 50, 34, 44,
  36, 51, 44, 48, 10, 103, 105, 109, 112, 95, 115, 112, 114, 101, 97, 100,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 103, 105, 109, 112, 95, 115, 112, 114, 101, 97, 100, 32, 36, 42, 34,
  44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 79, 108, 100, 45,
  109, 111, 118, 105, 101, 32, 115, 116, 114, 105, 112, 101, 115, 32, 58, 32,
  103, 105, 109, 112, 95, 115, 116, 114, 105, 112, 101, 115, 95, 121, 44, 32,
  103, 105, 109, 112, 95, 115, 116, 114, 105, 112, 101, 115, 95, 121, 95, 112,
  114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 70, 114, 101, 113, 117, 101, 110, 99, 121, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40,
  115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108,
  34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34,
  76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101,
  47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101,
  115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111,
  110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34,
  44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34,
  66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105,
  99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60,
  105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101,
  114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103,
  105, 109, 112, 95, 115, 116, 114, 105, 112, 101, 115, 95, 121, 32, 58, 10,
  45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  34, 45, 115, 116, 114, 105, 112, 101, 115, 95, 121, 32, 36, 49, 34, 44,
  36, 50, 44, 48, 10, 103, 105, 109, 112, 95, 115, 116, 114, 105, 112, 101,
  115, 95, 121, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 103, 105, 109, 112, 95, 115, 116, 114, 105, 112, 101, 115,
  95, 121, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 79, 108, 100, 115, 99, 104, 111, 111, 108, 32, 56, 98, 105, 116,
  115, 32, 58, 32, 103, 105, 109, 112, 95, 56, 98, 105, 116, 115, 44, 32,
  103, 105, 109, 112, 95, 56, 98, 105, 116, 115, 95, 112, 114, 101, 118, 105,
  101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  99, 97, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 53, 44,
  49, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  68, 105, 116, 104, 101, 114, 105, 110, 103, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 56, 48, 48, 44, 48, 44, 49, 48, 48, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 76, 101, 118, 101, 108, 115, 32, 61,
  32, 105, 110, 116, 40, 49, 54, 44, 50, 44, 50, 53, 54, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105,
  99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60,
  105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101,
  114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 49, 49, 47, 48, 50, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103,
  105, 109, 112, 95, 56, 98, 105, 116, 115, 32, 58, 10, 45, 114, 101, 109,
  111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 61,
  123, 119, 125, 32, 104, 61, 123, 104, 125, 10, 45, 114, 32, 36, 49, 37,
  44, 36, 49, 37, 44, 49, 44, 49, 48, 48, 37, 44, 50, 10, 45, 45,
  108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 115, 104, 97, 114, 112,
  101, 110, 91, 45, 49, 93, 32, 36, 50, 32, 45, 111, 116, 115, 117, 91,
  45, 49, 93, 32, 50, 53, 54, 32, 45, 98, 108, 101, 110, 100, 91, 45,
  50, 44, 45, 49, 93, 32, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97,
  103, 101, 48, 10, 45, 108, 91, 45, 49, 93, 32, 45, 115, 32, 99, 32,
  45, 113, 117, 97, 110, 116, 105, 122, 101, 32, 36, 51, 44, 49, 44, 49,
  32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 36, 119, 44, 36, 104, 44, 49, 44,
  49, 48, 48, 37, 44, 49, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 103, 105, 109, 112, 95, 56, 98, 105, 116, 115, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112,
  108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105,
  109, 112, 95, 56, 98, 105, 116, 115, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 82, 97, 110, 100, 111, 109, 32, 115,
  104, 97, 100, 101, 32, 115, 116, 114, 105, 112, 101, 115, 32, 58, 32, 103,
  105, 109, 112, 95, 115, 104, 97, 100, 101, 95, 115, 116, 114, 105, 112, 101,
  115, 44, 32, 103, 105, 109, 112, 95, 115, 104, 97, 100, 101, 95, 115, 116,
  114, 105, 112, 101, 115, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 114, 101, 113, 117, 101,
  110, 99, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 48, 44, 49,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79,
  114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 49, 44, 34, 72, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 86, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 97, 114, 107, 110, 101, 115, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 56, 44, 48, 44, 51,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 103, 104, 116,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 51,
  44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44,
  34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101,
  34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32,
  99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101,
  100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97,
  116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101,
  34, 44, 34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71,
  114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108,
  112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97,
  116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84,
  115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48,
  47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 115, 104, 97, 100, 101,
  95, 115, 116, 114, 105, 112, 101, 115, 32, 58, 10, 45, 97, 112, 112, 108,
  121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 115, 104, 97,
  100, 101, 95, 115, 116, 114, 105, 112, 101, 115, 32, 36, 49, 44, 36, 50,
  44, 36, 51, 44, 36, 52, 34, 44, 36, 53, 44, 48, 10, 103, 105, 109,
  112, 95, 115, 104, 97, 100, 101, 95, 115, 116, 114, 105, 112, 101, 115, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  103, 105, 109, 112, 95, 115, 104, 97, 100, 101, 95, 115, 116, 114, 105, 112,
  101, 115, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 84, 105, 108, 116, 32, 115, 104, 105, 102, 116, 32, 58, 32, 106,
  101, 106, 101, 95, 116, 105, 108, 116, 95, 115, 104, 105, 102, 116, 44, 32,
  106, 101, 106, 101, 95, 116, 105, 108, 116, 95, 115, 104, 105, 102, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 84, 105, 108, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48,
  44, 48, 44, 57, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 104, 105, 102, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 45, 49,
  48, 44, 45, 53, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  55, 53, 44, 49, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 109, 111, 117, 110, 116, 32, 61, 32, 105, 110, 116, 40,
  51, 44, 50, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62,
  74, 38, 35, 50, 51, 51, 59, 114, 38, 35, 50, 52, 52, 59, 109, 101,
  32, 66, 111, 117, 108, 97, 110, 103, 101, 114, 60, 47, 105, 62, 46, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 51, 47, 48, 54, 47, 48, 55, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 106, 101, 106, 101,
  95, 116, 105, 108, 116, 95, 115, 104, 105, 102, 116, 58, 10, 116, 104, 101,
  116, 97, 61, 123, 112, 105, 42, 40, 57, 48, 45, 36, 49, 41, 47, 49,
  56, 48, 125, 10, 115, 99, 97, 108, 101, 61, 123, 51, 42, 36, 51, 47,
  109, 105, 110, 40, 119, 44, 104, 41, 42, 49, 48, 48, 125, 10, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 10, 45, 102, 91, 45, 49, 93, 32, 39,
  40, 49, 45, 101, 120, 112, 40, 45, 46, 53, 42, 40, 99, 111, 115, 40,
  36, 116, 104, 101, 116, 97, 41, 42, 40, 120, 45, 119, 47, 50, 41, 43,
  115, 105, 110, 40, 36, 116, 104, 101, 116, 97, 41, 42, 40, 121, 45, 104,
  47, 50, 41, 43, 36, 50, 42, 109, 97, 120, 40, 119, 44, 104, 41, 47,
  49, 48, 48, 41, 94, 50, 47, 40, 36, 115, 99, 97, 108, 101, 42, 36,
  115, 99, 97, 108, 101, 41, 41, 41, 39, 10, 45, 114, 101, 118, 101, 114,
  115, 101, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 52, 32, 45, 45,
  98, 108, 117, 114, 91, 45, 49, 93, 32, 49, 32, 32, 45, 100, 111, 110,
  101, 32, 32, 45, 97, 91, 49, 45, 45, 49, 93, 32, 122, 10, 45, 108,
  91, 48, 93, 32, 45, 116, 111, 110, 101, 115, 32, 123, 36, 52, 43, 49,
  125, 32, 45, 98, 108, 117, 114, 32, 49, 32, 45, 97, 32, 122, 32, 32,
  45, 101, 110, 100, 108, 10, 45, 114, 101, 118, 101, 114, 115, 101, 32, 45,
  42, 32, 32, 45, 115, 32, 122, 32, 45, 43, 10, 106, 101, 106, 101, 95,
  116, 105, 108, 116, 95, 115, 104, 105, 102, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 106, 101, 106, 101, 95, 116,
  105, 108, 116, 95, 115, 104, 105, 102, 116, 32, 36, 49, 44, 36, 50, 44,
  36, 51, 44, 36, 52, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 86, 105, 115, 105, 98, 108, 101, 32, 119, 97, 116, 101, 114, 109,
  97, 114, 107, 32, 58, 32, 103, 105, 109, 112, 95, 119, 97, 116, 101, 114,
  109, 97, 114, 107, 95, 118, 105, 115, 105, 98, 108, 101, 44, 32, 103, 105,
  109, 112, 95, 119, 97, 116, 101, 114, 109, 97, 114, 107, 95, 118, 105, 115,
  105, 98, 108, 101, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 84, 101, 120, 116, 32, 61, 32, 116, 101, 120, 116, 123, 34, 40, 99,
  41, 32, 71, 39, 77, 73, 67, 34, 125, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 52, 44, 48, 46, 49, 44, 48, 46, 57, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 105, 122, 101, 32, 61, 32,
  105, 110, 116, 40, 53, 55, 44, 49, 51, 44, 49, 50, 56, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 50, 53, 44, 48, 44, 51, 54, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44,
  48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105,
  103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 49, 44, 34, 68, 97, 114, 107, 101, 114, 34, 44, 34, 66, 114, 105,
  103, 104, 116, 101, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32,
  60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112,
  101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  103, 105, 109, 112, 95, 119, 97, 116, 101, 114, 109, 97, 114, 107, 95, 118,
  105, 115, 105, 98, 108, 101, 32, 58, 10, 45, 119, 97, 116, 101, 114, 109,
  97, 114, 107, 95, 118, 105, 115, 105, 98, 108, 101, 32, 34, 36, 49, 34,
  44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 54, 44, 36, 53, 10,
  35, 64, 103, 105, 109, 112, 32, 95, 10, 35, 64, 103, 105, 109, 112, 32,
  60, 98, 62, 68, 101, 116, 97, 105, 108, 115, 60, 47, 98, 62, 10, 35,
  64, 103, 105, 109, 112, 32, 68, 101, 116, 97, 105, 108, 115, 32, 101, 113,
  117, 97, 108, 105, 122, 101, 114, 32, 58, 32, 103, 105, 109, 112, 95, 101,
  113, 117, 97, 108, 105, 122, 101, 95, 100, 101, 116, 97, 105, 108, 115, 44,
  32, 103, 105, 109, 112, 95, 101, 113, 117, 97, 108, 105, 122, 101, 95, 100,
  101, 116, 97, 105, 108, 115, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60,
  98, 62, 67, 111, 97, 114, 115, 101, 32, 115, 99, 97, 108, 101, 58, 60,
  47, 98, 62, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 116, 121, 112, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 50, 44, 34, 71, 97, 117, 115, 115, 105,
  97, 110, 34, 44, 34, 66, 105, 108, 97, 116, 101, 114, 97, 108, 34, 44,
  34, 68, 105, 102, 102, 117, 115, 105, 111, 110, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 71, 97, 105, 110, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 45, 50, 44, 50, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 77, 101,
  100, 105, 117, 109, 32, 115, 99, 97, 108, 101, 58, 60, 47, 98, 62, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 50, 44, 34, 71, 97, 117, 115, 115, 105, 97, 110, 34, 44,
  34, 66, 105, 108, 97, 116, 101, 114, 97, 108, 34, 44, 34, 68, 105, 102,
  102, 117, 115, 105, 111, 110, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 71, 97, 105, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 45, 50, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 83, 109, 97, 108, 108, 32,
  115, 99, 97, 108, 101, 58, 60, 47, 98, 62, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104,
  114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 50, 44,
  34, 71, 97, 117, 115, 115, 105, 97, 110, 34, 44, 34, 66, 105, 108, 97,
  116, 101, 114, 97, 108, 34, 44, 34, 68, 105, 102, 102, 117, 115, 105, 111,
  110, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 97, 105,
  110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 44, 50,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 60, 98, 62, 70, 105, 110, 101, 32, 115, 99, 97, 108, 101, 58,
  60, 47, 98, 62, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108,
  100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 116, 121, 112, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 50, 44, 34, 71, 97, 117, 115, 115,
  105, 97, 110, 34, 44, 34, 66, 105, 108, 97, 116, 101, 114, 97, 108, 34,
  44, 34, 68, 105, 102, 102, 117, 115, 105, 111, 110, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 71, 97, 105, 110, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 50, 44, 50, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  80, 97, 114, 97, 108, 108, 101, 108, 32, 112, 114, 111, 99, 101, 115, 115,
  105, 110, 103, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 117,
  116, 111, 34, 44, 34, 79, 110, 101, 32, 116, 104, 114, 101, 97, 100, 34,
  44, 34, 84, 119, 111, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34,
  70, 111, 117, 114, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 69,
  105, 103, 104, 116, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 83,
  105, 120, 116, 101, 101, 110, 32, 116, 104, 114, 101, 97, 100, 115, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 97, 116, 105, 97,
  108, 32, 111, 118, 101, 114, 108, 97, 112, 32, 61, 32, 105, 110, 116, 40,
  51, 50, 44, 48, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 65, 108, 108,
  34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34,
  76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101,
  47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101,
  115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111,
  110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34,
  44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34,
  66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105,
  99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60,
  105, 62, 74, 38, 35, 50, 51, 51, 59, 114, 111, 109, 101, 32, 66, 111,
  117, 108, 97, 110, 103, 101, 114, 60, 47, 105, 62, 32, 97, 110, 100, 32,
  60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112,
  101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 49, 50, 47, 49, 53,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  95, 103, 105, 109, 112, 95, 101, 113, 117, 97, 108, 105, 122, 101, 95, 100,
  101, 116, 97, 105, 108, 115, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 112, 108, 105,
  116, 95, 100, 101, 116, 97, 105, 108, 115, 32, 53, 44, 53, 37, 44, 48,
  46, 53, 37, 10, 45, 95, 95, 103, 105, 109, 112, 95, 101, 113, 117, 97,
  108, 105, 122, 101, 95, 100, 101, 116, 97, 105, 108, 115, 91, 49, 93, 32,
  36, 123, 49, 45, 52, 125, 44, 56, 10, 45, 95, 95, 103, 105, 109, 112,
  95, 101, 113, 117, 97, 108, 105, 122, 101, 95, 100, 101, 116, 97, 105, 108,
  115, 91, 50, 93, 32, 36, 123, 53, 45, 56, 125, 44, 52, 10, 45, 95,
  95, 103, 105, 109, 112, 95, 101, 113, 117, 97, 108, 105, 122, 101, 95, 100,
  101, 116, 97, 105, 108, 115, 91, 51, 93, 32, 36, 123, 57, 45, 49, 50,
  125, 44, 50, 10, 45, 95, 95, 103, 105, 109, 112, 95, 101, 113, 117, 97,
  108, 105, 122, 101, 95, 100, 101, 116, 97, 105, 108, 115, 91, 52, 93, 32,
  36, 123, 49, 51, 45, 49, 54, 125, 44, 49, 10, 45, 43, 32, 45, 99,
  32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 95, 95, 103, 105, 109, 112, 95, 101, 113, 117, 97, 108, 105,
  122, 101, 95, 100, 101, 116, 97, 105, 108, 115, 32, 58, 10, 45, 116, 104,
  114, 101, 115, 104, 111, 108, 100, 32, 36, 49, 44, 49, 10, 45, 105, 102,
  32, 123, 36, 51, 61, 61, 48, 125, 32, 45, 98, 32, 123, 36, 50, 42,
  36, 53, 47, 50, 125, 10, 45, 101, 108, 105, 102, 32, 123, 36, 51, 61,
  61, 49, 125, 10, 45, 105, 102, 32, 123, 36, 50, 62, 48, 125, 10, 109,
  61, 123, 105, 109, 125, 32, 77, 61, 123, 105, 77, 125, 32, 45, 110, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 105, 110, 116, 40, 36, 50, 47, 53, 41, 125, 32, 45, 98,
  105, 108, 97, 116, 101, 114, 97, 108, 32, 49, 53, 44, 123, 53, 42, 36,
  53, 125, 32, 45, 100, 111, 110, 101, 10, 45, 98, 105, 108, 97, 116, 101,
  114, 97, 108, 32, 49, 53, 44, 123, 40, 36, 50, 37, 53, 41, 42, 36,
  53, 125, 10, 45, 42, 91, 45, 49, 93, 32, 123, 40, 36, 77, 45, 36,
  109, 41, 47, 50, 53, 53, 125, 32, 45, 43, 91, 45, 49, 93, 32, 36,
  109, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101, 32, 45,
  115, 109, 111, 111, 116, 104, 32, 123, 36, 50, 42, 53, 48, 125, 44, 48,
  46, 50, 44, 48, 46, 56, 44, 36, 53, 44, 36, 53, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 42, 32, 123, 49, 48, 94, 36, 52, 125, 10, 103,
  105, 109, 112, 95, 101, 113, 117, 97, 108, 105, 122, 101, 95, 100, 101, 116,
  97, 105, 108, 115, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104,
  97, 110, 110, 101, 108, 115, 32, 34, 45, 103, 105, 109, 112, 95, 112, 97,
  114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 32, 92,
  34, 45, 95, 103, 105, 109, 112, 95, 101, 113, 117, 97, 108, 105, 122, 101,
  95, 100, 101, 116, 97, 105, 108, 115, 32, 36, 123, 49, 45, 49, 54, 125,
  92, 34, 44, 36, 49, 55, 44, 36, 49, 56, 34, 44, 36, 49, 57, 44,
  48, 10, 103, 105, 109, 112, 95, 101, 113, 117, 97, 108, 105, 122, 101, 95,
  100, 101, 116, 97, 105, 108, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 101, 113, 117,
  97, 108, 105, 122, 101, 95, 100, 101, 116, 97, 105, 108, 115, 32, 36, 42,
  34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 68, 121, 110,
  97, 109, 105, 99, 32, 114, 97, 110, 103, 101, 32, 105, 110, 99, 114, 101,
  97, 115, 101, 32, 58, 32, 103, 105, 109, 112, 95, 116, 107, 95, 100, 114,
  105, 44, 32, 103, 105, 109, 112, 95, 116, 107, 95, 100, 114, 105, 95, 112,
  114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 97,
  112, 32, 116, 111, 110, 101, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  82, 101, 99, 111, 118, 101, 114, 32, 115, 104, 97, 100, 111, 119, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 99, 111, 118, 101, 114, 32,
  104, 105, 103, 104, 108, 105, 103, 104, 116, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 69, 110, 104, 97, 110, 99, 101, 32, 100, 101, 116, 97, 105,
  108, 115, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 49, 44, 48, 44,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 116, 97,
  105, 108, 32, 115, 116, 114, 101, 110, 103, 116, 104, 32, 61, 32, 102, 108,
  111, 97, 116, 32, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 77, 97, 112, 32, 116, 111, 110, 101, 115,
  32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 69, 110, 104, 97, 110, 99, 101, 32, 100, 101, 116, 97,
  105, 108, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101,
  119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 84, 111, 109, 32, 75, 101, 105, 108, 60, 47, 105,
  62, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48, 52,
  47, 49, 50, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 108, 105, 110, 107, 40, 34, 70, 105, 108, 116, 101, 114, 32,
  101, 120, 112, 108, 97, 105, 110, 101, 100, 32, 104, 101, 114, 101, 34, 44,
  104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 116, 107, 102, 105, 108,
  116, 101, 114, 46, 98, 112, 108, 97, 99, 101, 100, 46, 110, 101, 116, 47,
  84, 75, 70, 105, 108, 116, 101, 114, 37, 50, 48, 102, 105, 108, 116, 101,
  114, 46, 104, 116, 109, 108, 41, 10, 103, 105, 109, 112, 95, 116, 107, 95,
  100, 114, 105, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 36, 54, 61,
  61, 49, 125, 10, 45, 45, 110, 101, 103, 97, 116, 105, 118, 101, 32, 45,
  45, 116, 111, 95, 114, 103, 98, 97, 91, 48, 93, 32, 45, 45, 108, 117,
  109, 105, 110, 97, 110, 99, 101, 91, 48, 93, 32, 45, 45, 116, 111, 95,
  114, 103, 98, 97, 91, 48, 93, 32, 45, 45, 108, 117, 109, 105, 110, 97,
  110, 99, 101, 91, 48, 93, 10, 45, 103, 105, 109, 112, 95, 103, 97, 117,
  115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 49, 93, 32, 123, 123,
  123, 119, 43, 104, 125, 47, 50, 48, 125, 42, 123, 49, 46, 49, 45, 36,
  49, 125, 125, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 32,
  45, 116, 111, 95, 103, 114, 97, 121, 91, 49, 93, 10, 45, 114, 118, 91,
  48, 44, 49, 93, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 115, 111, 102, 116, 108, 105, 103, 104, 116, 91, 48, 44, 49,
  93, 32, 36, 49, 10, 45, 103, 105, 109, 112, 95, 103, 97, 117, 115, 115,
  105, 97, 110, 95, 98, 108, 117, 114, 91, 50, 93, 32, 123, 123, 119, 43,
  104, 125, 47, 50, 48, 48, 125, 44, 48, 44, 48, 44, 49, 44, 49, 44,
  48, 44, 48, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 50, 93,
  32, 45, 116, 111, 95, 103, 114, 97, 121, 91, 50, 93, 10, 45, 115, 91,
  49, 93, 32, 99, 32, 45, 114, 118, 91, 52, 44, 53, 93, 32, 45, 99,
  111, 109, 112, 111, 115, 101, 95, 109, 117, 108, 116, 105, 112, 108, 121, 91,
  52, 44, 53, 93, 32, 45, 97, 91, 49, 44, 50, 44, 51, 44, 52, 93,
  32, 99, 32, 45, 114, 118, 91, 48, 44, 49, 93, 10, 45, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 100, 111, 100, 103, 101, 91,
  48, 44, 49, 93, 32, 36, 50, 10, 45, 103, 105, 109, 112, 95, 103, 97,
  117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 50, 93, 32, 123,
  123, 119, 43, 104, 125, 47, 50, 48, 48, 125, 44, 48, 44, 48, 44, 49,
  44, 49, 44, 48, 44, 48, 32, 45, 116, 111, 95, 103, 114, 97, 121, 91,
  50, 93, 32, 45, 115, 91, 49, 93, 32, 99, 10, 45, 114, 118, 91, 52,
  44, 53, 93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108,
  116, 105, 112, 108, 121, 91, 52, 44, 53, 93, 32, 45, 97, 91, 49, 44,
  50, 44, 51, 44, 52, 93, 32, 99, 32, 45, 114, 118, 91, 48, 44, 49,
  93, 10, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95,
  99, 111, 108, 111, 114, 98, 117, 114, 110, 91, 48, 44, 49, 93, 32, 36,
  51, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 55,
  61, 61, 49, 125, 32, 45, 45, 109, 97, 112, 95, 116, 111, 110, 101, 115,
  91, 48, 93, 32, 48, 46, 53, 48, 44, 48, 46, 55, 48, 44, 36, 52,
  44, 53, 48, 10, 45, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95,
  108, 111, 99, 97, 108, 91, 48, 93, 32, 36, 52, 44, 54, 46, 48, 48,
  44, 53, 46, 48, 48, 44, 49, 46, 48, 48, 10, 45, 114, 118, 91, 48,
  44, 49, 93, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 118, 97, 108, 117, 101, 91, 48, 44, 49, 93, 32, 36, 53, 44,
  48, 10, 45, 114, 118, 91, 48, 44, 49, 93, 32, 45, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 118, 97, 108, 117, 101, 91, 48,
  44, 49, 93, 32, 36, 53, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112,
  95, 116, 107, 95, 100, 114, 105, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 116, 107, 95,
  100, 114, 105, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 70, 114, 101, 97, 107, 121, 32, 100,
  101, 116, 97, 105, 108, 115, 32, 58, 32, 103, 105, 109, 112, 95, 102, 114,
  101, 97, 107, 121, 95, 100, 101, 116, 97, 105, 108, 115, 44, 32, 103, 105,
  109, 112, 95, 102, 114, 101, 97, 107, 121, 95, 100, 101, 116, 97, 105, 108,
  115, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32,
  61, 32, 105, 110, 116, 40, 50, 44, 49, 44, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 73, 116, 101, 114, 97, 116, 105, 111, 110,
  115, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49, 44, 52, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40,
  115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108,
  34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34,
  76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101,
  47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101,
  115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111,
  110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34,
  44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34,
  66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 80, 97, 114, 97, 108, 108, 101, 108, 32, 112, 114, 111, 99,
  101, 115, 115, 105, 110, 103, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 65, 117, 116, 111, 34, 44, 34, 79, 110, 101, 32, 116, 104, 114, 101,
  97, 100, 34, 44, 34, 84, 119, 111, 32, 116, 104, 114, 101, 97, 100, 115,
  34, 44, 34, 70, 111, 117, 114, 32, 116, 104, 114, 101, 97, 100, 115, 34,
  44, 34, 69, 105, 103, 104, 116, 32, 116, 104, 114, 101, 97, 100, 115, 34,
  44, 34, 83, 105, 120, 116, 101, 101, 110, 32, 116, 104, 114, 101, 97, 100,
  115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 97,
  116, 105, 97, 108, 32, 111, 118, 101, 114, 108, 97, 112, 32, 61, 32, 105,
  110, 116, 40, 51, 50, 44, 48, 44, 50, 53, 54, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97,
  116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 115, 58, 32, 60, 105,
  62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114,
  108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 32, 97, 110, 100, 32,
  60, 105, 62, 80, 97, 116, 114, 105, 99, 107, 32, 68, 97, 118, 105, 100,
  60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49,
  51, 47, 48, 50, 47, 50, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  84, 104, 105, 115, 32, 101, 102, 102, 101, 99, 116, 32, 104, 97, 115, 32,
  98, 101, 101, 110, 32, 100, 111, 110, 101, 32, 102, 111, 108, 108, 111, 119,
  105, 110, 103, 58, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  76, 105, 110, 107, 32, 61, 32, 108, 105, 110, 107, 40, 34, 84, 104, 105,
  115, 32, 116, 117, 116, 111, 114, 105, 97, 108, 32, 102, 114, 111, 109, 32,
  80, 97, 116, 114, 105, 99, 107, 32, 68, 97, 118, 105, 100, 34, 44, 34,
  104, 116, 116, 112, 58, 47, 47, 98, 108, 111, 103, 46, 112, 97, 116, 100,
  97, 118, 105, 100, 46, 110, 101, 116, 47, 50, 48, 49, 51, 47, 48, 50,
  47, 99, 97, 108, 118, 105, 110, 45, 104, 111, 108, 108, 121, 119, 111, 111,
  100, 45, 102, 114, 101, 97, 107, 121, 45, 100, 101, 116, 97, 105, 108, 115,
  45, 105, 110, 45, 103, 105, 109, 112, 46, 104, 116, 109, 108, 34, 41, 10,
  95, 103, 105, 109, 112, 95, 102, 114, 101, 97, 107, 121, 95, 100, 101, 116,
  97, 105, 108, 115, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 36, 51, 10, 91, 45, 49, 93, 32, 45, 45, 45, 91, 45, 49, 93,
  32, 50, 53, 53, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 36, 49, 32, 45, 98, 105, 108, 97, 116,
  101, 114, 97, 108, 91, 45, 49, 93, 32, 36, 50, 44, 123, 49, 46, 53,
  42, 36, 50, 125, 32, 45, 100, 111, 110, 101, 10, 45, 98, 108, 101, 110,
  100, 91, 45, 50, 44, 45, 49, 93, 32, 118, 105, 118, 105, 100, 108, 105,
  103, 104, 116, 32, 45, 98, 108, 101, 110, 100, 32, 111, 118, 101, 114, 108,
  97, 121, 10, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 102, 114, 101, 97, 107, 121,
  95, 100, 101, 116, 97, 105, 108, 115, 32, 58, 10, 45, 97, 112, 112, 108,
  121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 103, 105, 109,
  112, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108,
  97, 112, 32, 92, 34, 45, 95, 103, 105, 109, 112, 95, 102, 114, 101, 97,
  107, 121, 95, 100, 101, 116, 97, 105, 108, 115, 32, 36, 123, 49, 45, 51,
  125, 92, 34, 44, 36, 53, 44, 36, 54, 34, 44, 36, 52, 44, 48, 10,
  45, 110, 32, 48, 44, 50, 53, 53, 10, 103, 105, 109, 112, 95, 102, 114,
  101, 97, 107, 121, 95, 100, 101, 116, 97, 105, 108, 115, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109,
  112, 95, 102, 114, 101, 97, 107, 121, 95, 100, 101, 116, 97, 105, 108, 115,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32,
  72, 105, 103, 104, 32, 112, 97, 115, 115, 32, 58, 32, 103, 105, 109, 112,
  95, 104, 105, 103, 104, 112, 97, 115, 115, 44, 32, 103, 105, 109, 112, 95,
  104, 105, 103, 104, 112, 97, 115, 115, 95, 112, 114, 101, 118, 105, 101, 119,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 100,
  105, 117, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111,
  110, 116, 114, 97, 115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50,
  44, 48, 44, 55, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73,
  110, 118, 101, 114, 115, 101, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 101, 121, 115, 99,
  97, 108, 101, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101,
  119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  32, 58, 32, 60, 105, 62, 84, 111, 109, 32, 75, 101, 105, 108, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47,
  48, 49, 47, 48, 53, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 104, 105, 103, 104, 112, 97,
  115, 115, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 116, 111, 95, 114, 103, 98, 32, 45,
  45, 110, 101, 103, 97, 116, 105, 118, 101, 10, 45, 105, 102, 32, 123, 36,
  52, 61, 61, 49, 125, 32, 45, 116, 111, 95, 103, 114, 97, 121, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 103, 97, 117, 115,
  115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 49, 93, 32, 36, 49, 44,
  48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 10, 45, 99, 111, 109,
  112, 111, 115, 101, 95, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105,
  111, 110, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97, 110,
  110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 49,
  44, 36, 50, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 48, 48, 44,
  50, 53, 54, 44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 44, 48, 10,
  45, 105, 102, 32, 123, 36, 50, 62, 61, 52, 125, 32, 45, 116, 107, 95,
  103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111,
  99, 101, 115, 115, 105, 110, 103, 32, 49, 44, 123, 36, 50, 45, 51, 125,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 48, 48, 44, 50, 53, 54,
  44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 44, 48, 32, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 99, 104,
  97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103,
  32, 49, 44, 49, 44, 48, 44, 48, 44, 49, 44, 53, 48, 44, 49, 48,
  48, 44, 50, 53, 54, 44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 44,
  48, 10, 45, 105, 102, 32, 123, 36, 51, 61, 61, 49, 125, 32, 45, 110,
  101, 103, 97, 116, 105, 118, 101, 32, 45, 101, 110, 100, 105, 102, 32, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95,
  104, 105, 103, 104, 112, 97, 115, 115, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 104, 105,
  103, 104, 112, 97, 115, 115, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44,
  36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 76, 111, 99, 97, 108,
  32, 99, 111, 110, 116, 114, 97, 115, 116, 32, 101, 110, 104, 97, 110, 99,
  101, 109, 101, 110, 116, 32, 58, 32, 103, 105, 109, 112, 95, 76, 67, 69,
  44, 32, 103, 105, 109, 112, 95, 76, 67, 69, 95, 112, 114, 101, 118, 105,
  101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 76, 111, 99, 97,
  108, 32, 99, 111, 110, 116, 114, 97, 115, 116, 32, 101, 110, 104, 97, 110,
  99, 101, 109, 101, 110, 116, 32, 105, 115, 32, 60, 105, 62, 85, 110, 115,
  104, 97, 114, 112, 32, 77, 97, 115, 107, 60, 47, 105, 62, 32, 119, 105,
  116, 104, 32, 104, 105, 103, 104, 32, 114, 97, 100, 105, 117, 115, 46, 32,
  65, 112, 112, 108, 121, 32, 116, 111, 32, 102, 105, 108, 116, 101, 114, 32,
  116, 111, 32, 82, 71, 66, 32, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  102, 111, 114, 32, 99, 111, 108, 111, 114, 32, 97, 110, 100, 32, 99, 111,
  110, 116, 114, 97, 115, 116, 32, 101, 110, 104, 97, 110, 99, 101, 109, 101,
  110, 116, 46, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  112, 97, 116, 105, 97, 108, 32, 114, 97, 100, 105, 117, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 56, 48, 44, 51, 48, 44, 50, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 111, 117, 110, 116,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 97, 114, 107, 110,
  101, 115, 115, 32, 108, 101, 118, 101, 108, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 76, 105, 103, 104, 116, 110, 101, 115, 115, 32, 108, 101, 118, 101,
  108, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101,
  108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 51, 44,
  34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71,
  66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114,
  111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103,
  104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114,
  97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34,
  75, 101, 121, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34, 99, 104,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34,
  71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65,
  108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 70, 117, 108, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 92, 110, 92, 110, 60,
  115, 109, 97, 108, 108, 62, 60, 98, 62, 78, 111, 116, 101, 32, 58, 32,
  60, 47, 98, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 114,
  105, 103, 105, 110, 97, 108, 32, 85, 83, 77, 32, 99, 111, 100, 101, 32,
  98, 121, 32, 60, 105, 62, 98, 121, 32, 68, 97, 118, 105, 100, 32, 84,
  115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60,
  47, 105, 62, 46, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 115,
  32, 58, 32, 60, 105, 62, 65, 114, 116, 111, 32, 72, 117, 111, 116, 97,
  114, 105, 44, 32, 80, 104, 111, 116, 111, 67, 111, 109, 105, 88, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51,
  47, 48, 51, 47, 50, 51, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 95, 103, 105, 109, 112, 95, 76, 67, 69, 32,
  58, 10, 83, 112, 97, 116, 105, 97, 108, 82, 97, 100, 105, 117, 115, 61,
  36, 49, 10, 65, 109, 111, 117, 110, 116, 61, 36, 50, 10, 68, 97, 114,
  107, 110, 101, 115, 115, 76, 101, 118, 101, 108, 61, 36, 51, 10, 76, 105,
  103, 104, 116, 110, 101, 115, 115, 76, 101, 118, 101, 108, 61, 36, 52, 10,
  84, 104, 114, 101, 115, 104, 111, 108, 100, 61, 48, 10, 45, 45, 98, 108,
  117, 114, 91, 45, 49, 93, 32, 36, 83, 112, 97, 116, 105, 97, 108, 82,
  97, 100, 105, 117, 115, 10, 45, 45, 91, 45, 49, 93, 32, 91, 45, 50,
  93, 32, 45, 42, 91, 45, 49, 93, 32, 45, 36, 65, 109, 111, 117, 110,
  116, 10, 45, 45, 110, 111, 114, 109, 91, 45, 49, 93, 32, 45, 103, 101,
  91, 45, 49, 93, 32, 36, 84, 104, 114, 101, 115, 104, 111, 108, 100, 37,
  32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 42, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 45, 99, 91, 45, 49, 93, 32, 48,
  44, 49, 48, 48, 37, 32, 45, 99, 91, 45, 50, 93, 32, 45, 49, 48,
  48, 37, 44, 48, 32, 45, 42, 91, 45, 50, 93, 32, 36, 68, 97, 114,
  107, 110, 101, 115, 115, 76, 101, 118, 101, 108, 32, 45, 42, 91, 45, 49,
  93, 32, 36, 76, 105, 103, 104, 116, 110, 101, 115, 115, 76, 101, 118, 101,
  108, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 43, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 10, 103, 105, 109, 112, 95, 76, 67, 69, 32, 58, 10, 45, 97,
  112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45,
  95, 103, 105, 109, 112, 95, 76, 67, 69, 32, 36, 49, 44, 36, 50, 44,
  36, 51, 44, 36, 52, 34, 44, 36, 53, 44, 48, 10, 103, 105, 109, 112,
  95, 76, 67, 69, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 76, 67, 69, 32, 36, 123,
  49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 76, 111, 99, 97, 108, 32, 110, 111, 114, 109, 97, 108, 105, 122,
  97, 116, 105, 111, 110, 32, 58, 32, 103, 105, 109, 112, 95, 110, 111, 114,
  109, 97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 44, 32, 103, 105,
  109, 112, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 108, 111, 99,
  97, 108, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 44, 54, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 100, 105, 117, 115,
  32, 61, 32, 105, 110, 116, 40, 54, 44, 49, 44, 54, 52, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 101, 105, 103, 104, 98, 111, 114,
  104, 111, 111, 100, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 52, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 118, 101, 114, 97, 103, 101,
  32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 50, 48, 44, 48, 44, 52, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 110, 115, 116, 114, 97, 105, 110, 32,
  118, 97, 108, 117, 101, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101,
  108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 51, 44,
  34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71,
  66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114,
  111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103,
  104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114,
  97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34,
  75, 101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101,
  110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80,
  114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68,
  117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104,
  117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50,
  47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97, 108, 105, 122,
  101, 95, 108, 111, 99, 97, 108, 32, 58, 10, 45, 97, 112, 112, 108, 121,
  95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 110, 111, 114, 109,
  97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 32, 36, 49, 44, 36,
  50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 48, 44, 50, 53, 53,
  34, 44, 36, 54, 44, 48, 10, 103, 105, 109, 112, 95, 110, 111, 114, 109,
  97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112,
  95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32,
  76, 111, 99, 97, 108, 32, 118, 97, 114, 105, 97, 110, 99, 101, 32, 110,
  111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110, 32, 58, 32, 106,
  101, 106, 101, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 108, 111,
  99, 97, 108, 95, 118, 97, 114, 105, 97, 110, 99, 101, 44, 32, 106, 101,
  106, 101, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 108, 111, 99,
  97, 108, 95, 118, 97, 114, 105, 97, 110, 99, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112,
  108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53,
  48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 53, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 112, 101, 97, 116,
  32, 61, 32, 105, 110, 116, 32, 40, 49, 44, 49, 44, 52, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40,
  115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 51, 44, 34, 65,
  108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34,
  44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108,
  117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110,
  99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114,
  111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116,
  110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116,
  105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101,
  121, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34, 99, 104, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114,
  101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112,
  104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 74, 38, 35,
  50, 51, 51, 59, 114, 38, 35, 50, 52, 52, 59, 109, 101, 32, 66, 111,
  117, 108, 97, 110, 103, 101, 114, 60, 47, 105, 62, 46, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 51, 47, 49, 48, 47, 51, 48, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 106, 101, 106, 101, 95, 110, 111,
  114, 109, 97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 95, 118, 97,
  114, 105, 97, 110, 99, 101, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 110, 111, 114, 109, 97,
  108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 95, 118, 97, 114, 105, 97,
  110, 99, 101, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 34,
  44, 36, 53, 44, 48, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10, 106,
  101, 106, 101, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 108, 111,
  99, 97, 108, 95, 118, 97, 114, 105, 97, 110, 99, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 106, 101, 106, 101,
  95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108,
  95, 118, 97, 114, 105, 97, 110, 99, 101, 32, 36, 49, 44, 36, 50, 44,
  36, 51, 44, 36, 52, 44, 36, 53, 34, 44, 36, 45, 49, 10, 35, 64,
  103, 105, 109, 112, 32, 77, 97, 107, 101, 32, 117, 112, 32, 58, 32, 109,
  97, 107, 101, 95, 117, 112, 44, 32, 109, 97, 107, 101, 95, 117, 112, 95,
  112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 112, 97, 99, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 53, 44, 49, 44, 52, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 86, 97, 108, 117, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 52, 44, 48, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 70, 97, 115, 116, 32, 61, 32, 98, 111, 111, 108, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 109, 105, 116,
  32, 104, 117, 101, 32, 114, 97, 110, 103, 101, 32, 61, 32, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60,
  105, 62, 73, 97, 105, 110, 32, 70, 101, 114, 103, 117, 115, 115, 111, 110,
  60, 47, 105, 62, 46, 32, 32, 45, 32, 85, 112, 100, 97, 116, 101, 58,
  32, 49, 32, 77, 97, 114, 99, 104, 32, 50, 48, 49, 51, 58, 32, 70,
  105, 120, 101, 100, 32, 114, 101, 115, 105, 122, 105, 110, 103, 32, 105, 115,
  115, 117, 101, 44, 32, 115, 111, 109, 101, 32, 109, 101, 109, 111, 114, 121,
  32, 117, 115, 101, 97, 103, 101, 32, 105, 109, 112, 114, 111, 118, 101, 109,
  101, 110, 116, 115, 44, 32, 97, 110, 100, 32, 97, 100, 100, 101, 100, 32,
  109, 111, 114, 101, 32, 111, 112, 116, 105, 111, 110, 115, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 109, 97, 107, 101, 117, 112, 95, 102,
  117, 108, 108, 58, 10, 45, 116, 111, 95, 114, 103, 98, 10, 45, 115, 117,
  98, 91, 45, 49, 93, 32, 49, 50, 56, 32, 45, 42, 91, 45, 49, 93,
  32, 46, 53, 32, 45, 43, 91, 45, 49, 93, 32, 49, 50, 56, 10, 45,
  115, 112, 108, 105, 116, 32, 99, 10, 45, 110, 97, 109, 101, 91, 48, 93,
  32, 114, 101, 100, 10, 45, 110, 97, 109, 101, 91, 49, 93, 32, 103, 114,
  101, 101, 110, 10, 45, 110, 97, 109, 101, 91, 50, 93, 32, 98, 108, 117,
  101, 10, 45, 115, 117, 98, 91, 103, 114, 101, 101, 110, 93, 32, 91, 114,
  101, 100, 93, 10, 45, 98, 105, 108, 97, 116, 101, 114, 97, 108, 91, 103,
  114, 101, 101, 110, 93, 32, 36, 49, 44, 36, 50, 10, 45, 97, 100, 100,
  91, 103, 114, 101, 101, 110, 93, 32, 91, 114, 101, 100, 93, 10, 45, 115,
  117, 98, 91, 98, 108, 117, 101, 93, 32, 91, 114, 101, 100, 93, 10, 45,
  98, 105, 108, 97, 116, 101, 114, 97, 108, 91, 98, 108, 117, 101, 93, 32,
  36, 49, 44, 36, 50, 10, 45, 97, 100, 100, 91, 98, 108, 117, 101, 93,
  32, 91, 114, 101, 100, 93, 10, 45, 97, 112, 112, 101, 110, 100, 91, 48,
  44, 49, 44, 50, 93, 32, 99, 10, 45, 45, 91, 45, 49, 93, 32, 49,
  50, 56, 32, 45, 42, 91, 45, 49, 93, 32, 50, 32, 45, 43, 91, 45,
  49, 93, 32, 49, 50, 56, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10,
  109, 97, 107, 101, 95, 117, 112, 58, 10, 99, 114, 111, 112, 119, 105, 100,
  116, 104, 61, 123, 119, 125, 10, 99, 114, 111, 112, 104, 101, 105, 103, 104,
  116, 61, 123, 104, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93,
  32, 123, 119, 43, 40, 50, 45, 119, 37, 50, 41, 125, 44, 123, 104, 43,
  40, 50, 45, 104, 37, 50, 41, 125, 44, 49, 44, 123, 115, 125, 44, 48,
  44, 49, 10, 119, 105, 100, 116, 104, 61, 123, 119, 125, 10, 104, 101, 105,
  103, 104, 116, 61, 123, 104, 125, 10, 45, 105, 102, 32, 123, 36, 51, 61,
  61, 49, 125, 10, 45, 45, 114, 101, 115, 105, 122, 101, 32, 53, 48, 37,
  44, 53, 48, 37, 44, 49, 44, 51, 44, 53, 10, 45, 45, 109, 97, 107,
  101, 117, 112, 95, 102, 117, 108, 108, 91, 49, 93, 32, 123, 36, 49, 47,
  50, 125, 44, 36, 50, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 49,
  93, 32, 50, 48, 48, 37, 44, 50, 48, 48, 37, 44, 49, 44, 51, 44,
  53, 10, 45, 45, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105,
  110, 101, 120, 116, 114, 97, 99, 116, 91, 48, 44, 51, 93, 10, 45, 114,
  101, 115, 105, 122, 101, 91, 50, 93, 32, 123, 119, 125, 44, 123, 104, 125,
  44, 49, 44, 51, 44, 53, 10, 45, 45, 99, 111, 109, 112, 111, 115, 101,
  95, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 91, 50, 44, 52, 93,
  10, 45, 107, 101, 101, 112, 91, 48, 44, 45, 49, 93, 10, 45, 101, 108,
  115, 101, 10, 45, 105, 102, 32, 123, 36, 52, 61, 61, 49, 125, 10, 45,
  45, 109, 97, 107, 101, 117, 112, 95, 102, 117, 108, 108, 91, 48, 93, 32,
  36, 49, 44, 36, 50, 10, 45, 101, 108, 115, 101, 10, 45, 109, 97, 107,
  101, 117, 112, 95, 102, 117, 108, 108, 91, 48, 93, 32, 36, 49, 44, 36,
  50, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 52, 61, 61, 49, 125, 10, 45, 45, 114, 103,
  98, 50, 104, 115, 108, 56, 91, 49, 93, 10, 45, 115, 112, 108, 105, 116,
  91, 45, 49, 93, 32, 99, 32, 45, 114, 101, 109, 111, 118, 101, 91, 45,
  49, 44, 45, 50, 93, 10, 45, 43, 91, 45, 49, 93, 32, 49, 50, 56,
  10, 45, 109, 111, 100, 91, 45, 49, 93, 32, 50, 53, 53, 10, 45, 97,
  112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 45, 49, 93, 32, 48,
  44, 48, 44, 48, 44, 49, 51, 48, 44, 48, 44, 49, 51, 54, 44, 50,
  53, 53, 44, 49, 53, 53, 44, 50, 53, 53, 44, 49, 54, 48, 44, 48,
  44, 50, 53, 53, 44, 48, 10, 45, 109, 101, 100, 105, 97, 110, 91, 45,
  49, 93, 32, 51, 10, 45, 45, 101, 100, 103, 101, 115, 91, 49, 93, 32,
  49, 48, 37, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 49, 10, 45,
  109, 117, 108, 91, 45, 49, 44, 45, 50, 93, 10, 45, 97, 91, 49, 44,
  50, 93, 32, 99, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 97, 108,
  112, 104, 97, 91, 48, 44, 49, 93, 10, 45, 101, 108, 115, 101, 10, 45,
  107, 101, 101, 112, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 99, 114, 111, 112, 32, 48, 44, 48, 44, 123, 36, 99, 114, 111, 112,
  119, 105, 100, 116, 104, 45, 49, 125, 44, 123, 36, 99, 114, 111, 112, 104,
  101, 105, 103, 104, 116, 45, 49, 125, 10, 109, 97, 107, 101, 95, 117, 112,
  95, 112, 114, 101, 118, 105, 101, 119, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  109, 97, 107, 101, 95, 117, 112, 32, 36, 123, 49, 45, 45, 50, 125, 34,
  44, 36, 45, 49, 10, 35, 10, 35, 64, 103, 105, 109, 112, 32, 77, 97,
  115, 107, 32, 99, 114, 101, 97, 116, 111, 114, 32, 58, 32, 103, 105, 109,
  112, 95, 116, 107, 95, 109, 97, 115, 107, 44, 32, 103, 105, 109, 112, 95,
  116, 107, 95, 109, 97, 115, 107, 95, 112, 114, 101, 118, 105, 101, 119, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 77, 97, 115, 107, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 76, 117, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111,
  110, 34, 44, 34, 72, 117, 101, 34, 44, 34, 76, 65, 66, 45, 108, 105,
  103, 104, 116, 110, 101, 115, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 111, 108, 111, 114, 32, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34,
  44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34,
  66, 108, 117, 101, 34, 44, 34, 89, 101, 108, 108, 111, 119, 34, 44, 34,
  77, 97, 103, 101, 110, 116, 97, 34, 44, 34, 67, 121, 97, 110, 34, 44,
  34, 76, 65, 66, 45, 65, 34, 44, 34, 76, 65, 66, 45, 66, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 100, 111, 119,
  115, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 72, 105, 103, 104, 108, 105, 103, 104, 116, 115,
  32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 84, 111, 110, 101, 115, 32, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 77, 97, 115, 107, 32, 99, 111, 110, 116, 114, 97, 115, 116, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 101, 103, 97, 116, 105, 118, 101,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 112, 112, 108, 121, 32, 109, 97, 115, 107, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 121, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101,
  119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 84, 111, 109, 32, 75, 101, 105, 108, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48,
  52, 47, 49, 49, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 70, 105, 108, 116, 101, 114,
  32, 101, 120, 112, 108, 97, 105, 110, 101, 100, 32, 104, 101, 114, 101, 34,
  44, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 116, 107, 102, 105,
  108, 116, 101, 114, 46, 98, 112, 108, 97, 99, 101, 100, 46, 110, 101, 116,
  47, 84, 75, 70, 105, 108, 116, 101, 114, 37, 50, 48, 102, 105, 108, 116,
  101, 114, 46, 104, 116, 109, 108, 41, 10, 103, 105, 109, 112, 95, 116, 107,
  95, 109, 97, 115, 107, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 36,
  56, 61, 61, 49, 125, 32, 45, 45, 116, 111, 95, 114, 103, 98, 97, 91,
  45, 49, 93, 32, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 32, 45,
  101, 110, 100, 105, 102, 32, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49,
  93, 10, 45, 105, 102, 32, 123, 36, 50, 61, 61, 49, 125, 32, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 50, 61, 61, 50, 125, 32, 45, 99, 104, 97,
  110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 49, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 50, 61, 61, 51, 125, 32, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 91, 45, 49, 93, 32, 50, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 50, 61, 61, 52, 125, 32, 45, 114, 103, 98, 50, 99, 109, 121,
  32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 50,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 61, 61, 52, 125, 32, 45,
  114, 103, 98, 50, 99, 109, 121, 32, 45, 99, 104, 97, 110, 110, 101, 108,
  115, 91, 45, 49, 93, 32, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  50, 61, 61, 52, 125, 32, 45, 114, 103, 98, 50, 99, 109, 121, 32, 45,
  99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 50, 61, 61, 53, 125, 32, 45, 114, 103,
  98, 50, 108, 97, 98, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91,
  45, 49, 93, 32, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 61,
  61, 54, 125, 32, 45, 114, 103, 98, 50, 108, 97, 98, 32, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 50, 10, 45, 101, 110,
  100, 105, 102, 32, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10,
  45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 125, 32, 45, 108, 117, 109,
  105, 110, 97, 110, 99, 101, 91, 45, 49, 93, 32, 45, 45, 108, 117, 109,
  105, 110, 97, 110, 99, 101, 91, 45, 49, 93, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 61, 61, 49, 125, 32, 45, 114, 103, 98, 50, 104, 115,
  118, 91, 45, 49, 93, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91,
  45, 49, 93, 32, 49, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 32, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116,
  104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 61, 61, 50, 125, 32, 45, 114, 103, 98, 50, 104, 115, 118, 91,
  45, 49, 93, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49,
  93, 32, 48, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  32, 32, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104,
  105, 110, 103, 91, 45, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  49, 61, 61, 51, 125, 32, 45, 114, 103, 98, 50, 108, 97, 98, 91, 45,
  49, 93, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93,
  32, 48, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32,
  32, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105,
  110, 103, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 99,
  91, 45, 49, 93, 32, 36, 51, 44, 50, 53, 53, 32, 45, 110, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 102, 91, 45, 50, 93, 32,
  34, 105, 102, 40, 105, 60, 36, 52, 44, 105, 102, 40, 99, 61, 61, 48,
  44, 105, 44, 105, 41, 44, 48, 41, 34, 10, 45, 103, 105, 109, 112, 95,
  103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 45, 49,
  44, 45, 50, 93, 32, 36, 53, 44, 48, 44, 48, 44, 49, 44, 48, 44,
  48, 44, 48, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 100, 97, 114,
  107, 101, 110, 10, 45, 105, 102, 32, 123, 36, 56, 61, 61, 49, 125, 32,
  45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110,
  101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 91, 45, 49,
  93, 32, 49, 44, 36, 54, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49,
  48, 48, 44, 50, 53, 54, 44, 48, 44, 48, 44, 48, 44, 50, 44, 48,
  44, 48, 10, 45, 105, 102, 32, 123, 36, 55, 61, 61, 49, 125, 32, 45,
  110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 56, 61, 61, 49, 125, 32,
  45, 115, 91, 45, 50, 93, 32, 99, 32, 32, 45, 114, 118, 91, 45, 49,
  44, 45, 50, 93, 10, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 109, 117, 108, 116, 105, 112, 108, 121, 91, 45, 49, 44, 45,
  50, 93, 32, 36, 57, 10, 45, 97, 91, 45, 52, 44, 45, 51, 44, 45,
  50, 44, 45, 49, 93, 32, 99, 10, 45, 101, 110, 100, 105, 102, 32, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95,
  116, 107, 95, 109, 97, 115, 107, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 116, 107, 95,
  109, 97, 115, 107, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45,
  49, 10, 35, 64, 103, 105, 109, 112, 32, 80, 111, 114, 116, 114, 97, 105,
  116, 32, 114, 101, 116, 111, 117, 99, 104, 105, 110, 103, 32, 58, 32, 103,
  105, 109, 112, 95, 116, 107, 95, 112, 111, 114, 116, 114, 97, 105, 116, 44,
  32, 103, 105, 109, 112, 95, 116, 107, 95, 112, 111, 114, 116, 114, 97, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 82, 101, 116, 111, 117, 99, 104, 105, 110, 103, 32, 115, 116, 121, 108,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 83, 116, 97, 110,
  100, 97, 114, 100, 34, 44, 34, 71, 108, 97, 109, 111, 117, 114, 32, 103,
  108, 111, 119, 34, 44, 34, 77, 97, 115, 99, 117, 108, 105, 110, 101, 34,
  44, 34, 72, 105, 103, 104, 32, 107, 101, 121, 34, 44, 34, 76, 111, 119,
  32, 75, 101, 121, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  69, 102, 102, 101, 99, 116, 32, 115, 116, 114, 101, 110, 103, 116, 104, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 98, 62, 82, 101, 116, 111, 117, 99, 104, 105, 110,
  103, 32, 115, 101, 116, 116, 105, 110, 103, 115, 58, 60, 47, 98, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 105, 110, 101, 32,
  100, 101, 116, 97, 105, 108, 115, 32, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 101, 100, 105,
  117, 109, 32, 100, 101, 116, 97, 105, 108, 115, 32, 115, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44,
  48, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  114, 101, 97, 115, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 105, 110, 101, 32,
  100, 101, 116, 97, 105, 108, 115, 32, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44, 48, 44, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 101, 100, 105, 117,
  109, 32, 100, 101, 116, 97, 105, 108, 115, 32, 116, 104, 114, 101, 115, 104,
  111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  114, 101, 97, 115, 32, 108, 105, 103, 104, 116, 32, 97, 100, 106, 117, 115,
  116, 109, 101, 110, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48,
  44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 109, 111, 111, 116, 104, 105, 110, 103, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 71, 97, 117, 115, 115, 105,
  97, 110, 34, 44, 34, 66, 105, 108, 97, 116, 101, 114, 97, 108, 34, 44,
  34, 65, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 34, 44, 34, 77,
  101, 100, 105, 97, 110, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 79, 117, 116, 112, 117, 116, 32, 109, 111, 100, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 82, 101, 116, 111, 117, 99, 104, 101, 100,
  32, 105, 109, 97, 103, 101, 34, 44, 34, 67, 111, 109, 112, 111, 115, 101,
  100, 32, 108, 97, 121, 101, 114, 115, 34, 44, 34, 65, 108, 108, 32, 108,
  97, 121, 101, 114, 115, 32, 97, 110, 100, 32, 109, 97, 115, 107, 115, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 98, 62, 83, 107, 105, 110, 32, 116, 111, 110, 101, 32,
  109, 97, 115, 107, 32, 115, 101, 116, 116, 105, 110, 103, 115, 58, 60, 47,
  98, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 112,
  112, 108, 121, 32, 115, 107, 105, 110, 32, 116, 111, 110, 101, 32, 109, 97,
  115, 107, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 105, 109, 105, 108, 97, 114, 105, 116, 121,
  32, 115, 112, 97, 99, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  50, 44, 34, 82, 71, 66, 91, 65, 93, 34, 44, 34, 82, 71, 66, 34,
  44, 34, 89, 67, 98, 67, 114, 34, 44, 34, 82, 101, 100, 34, 44, 34,
  71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 79,
  112, 97, 99, 105, 116, 121, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 34, 66, 108, 117, 101, 32, 38, 32, 82, 101, 100, 32,
  99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 72,
  117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 111, 108, 101, 114,
  97, 110, 99, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 53, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 50, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 108, 101, 99, 116, 101, 100, 32, 99, 111, 108,
  111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 48, 44, 49,
  56, 48, 44, 49, 53, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 71, 101, 110, 101, 114, 105, 99, 32, 115, 107, 105,
  110, 32, 115, 116, 114, 117, 99, 116, 117, 114, 101, 32, 61, 32, 98, 111,
  111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 98, 62, 69, 110, 104, 97, 110, 99,
  101, 109, 101, 110, 116, 32, 115, 101, 116, 116, 105, 110, 103, 115, 58, 60,
  47, 98, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  112, 112, 108, 121, 32, 97, 100, 106, 117, 115, 116, 109, 101, 110, 116, 115,
  32, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34,
  70, 105, 110, 97, 108, 32, 105, 109, 97, 103, 101, 34, 44, 34, 82, 101,
  116, 111, 117, 99, 104, 101, 100, 32, 97, 114, 101, 97, 115, 32, 111, 110,
  108, 121, 34, 44, 34, 83, 104, 97, 114, 112, 101, 110, 101, 100, 32, 97,
  114, 101, 97, 115, 32, 111, 110, 108, 121, 34, 44, 34, 82, 101, 116, 111,
  117, 99, 104, 101, 100, 32, 97, 110, 100, 32, 115, 104, 97, 114, 112, 101,
  110, 101, 100, 32, 97, 114, 101, 97, 115, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 104, 97, 114, 112, 101, 110, 105, 110, 103, 32,
  114, 97, 100, 105, 117, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 104, 97, 114, 112, 101, 110, 105, 110, 103, 32, 115, 116, 114, 101, 110,
  103, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 53, 44,
  48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100,
  103, 101, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 53, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101, 32, 115, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 108, 111, 114, 32, 116, 101, 109, 112, 101, 114, 97, 116, 117, 114,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 48, 44,
  50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 103,
  104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 45, 53, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 44, 48, 46, 53, 44, 49, 46, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 97, 116, 117, 114, 97, 116, 105, 111,
  110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 80, 114, 101, 118, 105, 101, 119, 32, 115, 101, 108,
  101, 99, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 82, 101, 116, 111, 117, 99, 104, 101, 100, 32, 105, 109, 97, 103, 101,
  32, 102, 105, 110, 97, 108, 34, 44, 34, 82, 101, 116, 111, 117, 99, 104,
  101, 100, 32, 105, 109, 97, 103, 101, 32, 98, 97, 115, 105, 99, 34, 44,
  34, 82, 101, 116, 111, 117, 99, 104, 32, 108, 97, 121, 101, 114, 34, 44,
  34, 83, 104, 97, 114, 112, 101, 110, 105, 110, 103, 32, 108, 97, 121, 101,
  114, 34, 44, 34, 83, 107, 105, 110, 32, 116, 111, 110, 101, 32, 109, 97,
  115, 107, 34, 44, 34, 83, 107, 105, 110, 32, 116, 111, 110, 101, 32, 99,
  111, 108, 111, 114, 115, 34, 44, 34, 69, 100, 103, 101, 32, 109, 97, 115,
  107, 34, 44, 34, 72, 105, 103, 104, 32, 102, 114, 101, 113, 117, 101, 110,
  99, 121, 32, 108, 97, 121, 101, 114, 34, 44, 34, 77, 101, 100, 105, 117,
  109, 32, 102, 114, 101, 113, 117, 101, 110, 99, 121, 32, 108, 97, 121, 101,
  114, 34, 44, 34, 76, 111, 119, 32, 102, 114, 101, 113, 117, 101, 110, 99,
  121, 32, 108, 97, 121, 101, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 84, 111,
  109, 32, 75, 101, 105, 108, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 50, 47, 48, 52, 47, 49, 56, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110,
  107, 40, 34, 70, 105, 108, 116, 101, 114, 32, 101, 120, 112, 108, 97, 105,
  110, 101, 100, 32, 104, 101, 114, 101, 34, 44, 34, 104, 116, 116, 112, 58,
  47, 47, 119, 119, 119, 46, 116, 107, 102, 105, 108, 116, 101, 114, 46, 98,
  112, 108, 97, 99, 101, 100, 46, 110, 101, 116, 47, 84, 75, 70, 105, 108,
  116, 101, 114, 37, 50, 48, 116, 117, 116, 111, 114, 105, 97, 108, 115, 37,
  50, 48, 80, 111, 114, 116, 114, 97, 105, 116, 37, 50, 48, 114, 101, 116,
  111, 117, 99, 104, 105, 110, 103, 46, 104, 116, 109, 108, 34, 41, 10, 103,
  105, 109, 112, 95, 116, 107, 95, 112, 111, 114, 116, 114, 97, 105, 116, 32,
  58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 32, 45, 116, 111, 95, 114, 103, 98, 10, 45, 105, 102, 32,
  123, 110, 97, 114, 103, 40, 36, 95, 112, 114, 101, 118, 105, 101, 119, 102,
  108, 97, 103, 41, 61, 61, 48, 125, 32, 95, 112, 114, 101, 118, 105, 101,
  119, 102, 108, 97, 103, 61, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 123, 36, 49, 61, 61, 51, 125, 124, 124, 123, 36, 49,
  61, 61, 52, 125, 125, 32, 45, 45, 108, 117, 109, 105, 110, 97, 110, 99,
  101, 91, 48, 93, 32, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61,
  50, 125, 32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48, 93,
  32, 50, 32, 45, 103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112,
  91, 45, 49, 93, 32, 48, 44, 36, 50, 49, 44, 51, 48, 44, 36, 50,
  50, 44, 48, 46, 48, 48, 44, 49, 46, 48, 48, 44, 48, 46, 53, 44,
  49, 44, 48, 44, 48, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  45, 103, 105, 109, 112, 95, 101, 100, 103, 101, 115, 91, 48, 93, 32, 36,
  50, 52, 44, 36, 50, 51, 44, 48, 44, 48, 32, 45, 105, 102, 32, 123,
  36, 50, 51, 61, 61, 48, 125, 32, 45, 102, 99, 91, 45, 49, 93, 32,
  48, 32, 45, 101, 110, 100, 105, 102, 32, 45, 45, 103, 105, 109, 112, 95,
  117, 110, 115, 104, 97, 114, 112, 91, 48, 93, 32, 48, 44, 36, 50, 49,
  44, 51, 48, 44, 36, 50, 50, 44, 48, 46, 48, 48, 44, 49, 46, 48,
  48, 44, 48, 46, 53, 44, 49, 44, 48, 44, 55, 44, 48, 10, 45, 105,
  102, 32, 123, 123, 36, 95, 112, 114, 101, 118, 105, 101, 119, 102, 108, 97,
  103, 61, 61, 52, 125, 38, 38, 123, 36, 50, 57, 61, 61, 53, 125, 125,
  32, 45, 45, 116, 107, 95, 103, 105, 109, 112, 95, 115, 101, 108, 101, 99,
  116, 95, 99, 111, 108, 111, 114, 91, 48, 93, 32, 36, 123, 49, 50, 45,
  49, 56, 125, 44, 48, 44, 48, 32, 45, 101, 108, 115, 101, 32, 45, 45,
  116, 107, 95, 103, 105, 109, 112, 95, 115, 101, 108, 101, 99, 116, 95, 99,
  111, 108, 111, 114, 91, 48, 93, 32, 36, 123, 49, 50, 45, 49, 56, 125,
  44, 49, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 102, 114, 101, 113, 91, 48, 93,
  32, 36, 54, 32, 45, 105, 102, 32, 123, 36, 49, 57, 61, 61, 49, 125,
  32, 45, 102, 99, 91, 45, 49, 93, 32, 49, 50, 56, 44, 49, 50, 56,
  44, 49, 50, 56, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32,
  123, 36, 54, 42, 50, 125, 44, 48, 32, 45, 108, 117, 109, 105, 110, 97,
  110, 99, 101, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 102, 114, 101, 113,
  91, 48, 93, 32, 36, 55, 10, 45, 114, 109, 91, 45, 50, 44, 45, 52,
  93, 10, 45, 45, 103, 105, 109, 112, 95, 116, 107, 95, 100, 114, 105, 91,
  48, 93, 32, 123, 36, 56, 47, 49, 48, 48, 125, 44, 123, 36, 56, 47,
  50, 48, 48, 125, 44, 123, 36, 56, 47, 50, 48, 48, 125, 44, 48, 44,
  48, 44, 49, 44, 48, 44, 48, 10, 45, 105, 102, 32, 123, 36, 57, 61,
  61, 48, 125, 32, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 53,
  32, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 32, 45, 98, 108, 117,
  114, 91, 45, 49, 93, 32, 36, 52, 32, 45, 98, 108, 117, 114, 91, 45,
  51, 93, 32, 36, 51, 10, 45, 101, 108, 105, 102, 32, 123, 36, 57, 61,
  61, 49, 125, 32, 45, 98, 105, 108, 97, 116, 101, 114, 97, 108, 91, 45,
  49, 93, 32, 36, 55, 44, 36, 53, 32, 45, 114, 118, 91, 45, 49, 44,
  45, 50, 93, 32, 45, 98, 105, 108, 97, 116, 101, 114, 97, 108, 91, 45,
  49, 93, 32, 36, 54, 44, 36, 52, 32, 45, 98, 105, 108, 97, 116, 101,
  114, 97, 108, 91, 45, 51, 93, 32, 123, 36, 51, 47, 53, 125, 44, 36,
  51, 10, 45, 101, 108, 105, 102, 32, 123, 36, 57, 61, 61, 50, 125, 32,
  45, 115, 109, 111, 111, 116, 104, 91, 45, 49, 93, 32, 36, 53, 32, 45,
  114, 118, 91, 45, 49, 44, 45, 50, 93, 32, 45, 115, 109, 111, 111, 116,
  104, 91, 45, 49, 93, 32, 36, 52, 32, 45, 115, 109, 111, 111, 116, 104,
  91, 45, 51, 93, 32, 36, 51, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  57, 61, 61, 51, 125, 32, 45, 109, 101, 100, 105, 97, 110, 91, 45, 49,
  93, 32, 36, 53, 32, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 32,
  45, 109, 101, 100, 105, 97, 110, 91, 45, 49, 93, 32, 36, 52, 32, 45,
  109, 101, 100, 105, 97, 110, 91, 45, 51, 93, 32, 36, 51, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 123, 123, 36, 95, 112, 114,
  101, 118, 105, 101, 119, 102, 108, 97, 103, 33, 61, 48, 125, 38, 38, 123,
  36, 95, 112, 114, 101, 118, 105, 101, 119, 102, 108, 97, 103, 60, 61, 51,
  125, 125, 124, 124, 123, 123, 36, 49, 48, 60, 61, 49, 125, 38, 38, 123,
  36, 95, 112, 114, 101, 118, 105, 101, 119, 102, 108, 97, 103, 61, 61, 48,
  125, 125, 125, 10, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 102, 114, 101, 113, 91, 45, 49, 44, 45, 50, 93, 32, 45, 114,
  118, 91, 45, 49, 44, 45, 50, 93, 32, 45, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 102, 114, 101, 113, 91, 45, 49, 44, 45,
  50, 93, 10, 45, 105, 102, 32, 123, 36, 49, 49, 61, 61, 49, 125, 32,
  45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 32, 45, 98, 108,
  117, 114, 91, 45, 50, 93, 32, 36, 49, 52, 32, 45, 115, 91, 45, 49,
  93, 32, 99, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49,
  93, 32, 45, 43, 91, 45, 49, 93, 32, 91, 45, 53, 93, 32, 45, 97,
  91, 45, 49, 44, 45, 50, 44, 45, 51, 44, 45, 52, 93, 32, 99, 32,
  45, 101, 110, 100, 105, 102, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45,
  109, 118, 91, 45, 49, 93, 32, 49, 10, 45, 116, 111, 95, 114, 103, 98,
  97, 91, 45, 49, 93, 32, 45, 115, 91, 45, 49, 93, 32, 99, 32, 45,
  110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 44, 45, 53, 93, 32,
  45, 43, 91, 45, 49, 93, 32, 91, 45, 53, 93, 32, 45, 97, 91, 45,
  49, 44, 45, 50, 44, 45, 51, 44, 45, 52, 93, 32, 99, 32, 45, 114,
  109, 91, 45, 50, 93, 32, 45, 105, 102, 32, 123, 36, 50, 51, 61, 61,
  53, 48, 125, 32, 45, 102, 99, 91, 45, 49, 93, 32, 48, 44, 48, 44,
  48, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  123, 123, 36, 95, 112, 114, 101, 118, 105, 101, 119, 102, 108, 97, 103, 61,
  61, 49, 125, 124, 124, 123, 36, 95, 112, 114, 101, 118, 105, 101, 119, 102,
  108, 97, 103, 61, 61, 50, 125, 125, 124, 124, 123, 123, 36, 49, 48, 61,
  61, 48, 125, 38, 38, 123, 36, 95, 112, 114, 101, 118, 105, 101, 119, 102,
  108, 97, 103, 61, 61, 48, 125, 125, 125, 10, 45, 105, 102, 32, 123, 123,
  36, 49, 33, 61, 48, 125, 38, 38, 123, 36, 49, 33, 61, 49, 125, 125,
  32, 45, 109, 118, 91, 45, 50, 93, 32, 48, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 50, 48, 61, 61, 49, 125, 32, 45,
  103, 105, 109, 112, 95, 109, 105, 120, 95, 108, 97, 98, 91, 45, 50, 93,
  32, 36, 50, 55, 44, 36, 50, 54, 44, 48, 44, 36, 50, 56, 44, 123,
  105, 102, 40, 123, 36, 50, 53, 62, 61, 48, 125, 44, 123, 36, 50, 53,
  47, 52, 125, 44, 123, 36, 50, 53, 42, 48, 46, 55, 53, 125, 41, 125,
  44, 48, 44, 36, 50, 56, 44, 36, 50, 53, 44, 48, 44, 48, 44, 50,
  44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 48, 61, 61, 50,
  125, 32, 45, 103, 105, 109, 112, 95, 109, 105, 120, 95, 108, 97, 98, 91,
  45, 49, 93, 32, 36, 50, 55, 44, 36, 50, 54, 44, 48, 44, 36, 50,
  56, 44, 123, 105, 102, 40, 123, 36, 50, 53, 62, 61, 48, 125, 44, 123,
  36, 50, 53, 47, 52, 125, 44, 123, 36, 50, 53, 42, 48, 46, 55, 53,
  125, 41, 125, 44, 48, 44, 36, 50, 56, 44, 36, 50, 53, 44, 48, 44,
  48, 44, 50, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 48,
  61, 61, 51, 125, 32, 45, 103, 105, 109, 112, 95, 109, 105, 120, 95, 108,
  97, 98, 91, 45, 49, 44, 45, 50, 93, 32, 36, 50, 55, 44, 36, 50,
  54, 44, 48, 44, 36, 50, 56, 44, 123, 105, 102, 40, 123, 36, 50, 53,
  62, 61, 48, 125, 44, 123, 36, 50, 53, 47, 52, 125, 44, 123, 36, 50,
  53, 42, 48, 46, 55, 53, 125, 41, 125, 44, 48, 44, 36, 50, 56, 44,
  36, 50, 53, 44, 48, 44, 48, 44, 50, 44, 48, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 97, 108, 112, 104, 97, 91, 45, 50, 44, 45, 51, 93, 32, 123, 105,
  102, 40, 123, 36, 49, 61, 61, 48, 125, 44, 123, 36, 50, 47, 49, 48,
  48, 125, 44, 49, 41, 125, 44, 48, 32, 45, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 97, 108, 112, 104, 97, 91, 45, 49, 44,
  45, 50, 93, 32, 123, 105, 102, 40, 123, 36, 49, 61, 61, 48, 125, 44,
  123, 36, 50, 47, 49, 48, 48, 125, 44, 49, 41, 125, 44, 48, 10, 45,
  105, 102, 32, 123, 36, 50, 51, 61, 61, 53, 48, 125, 32, 45, 103, 105,
  109, 112, 95, 117, 110, 115, 104, 97, 114, 112, 91, 48, 93, 32, 48, 44,
  36, 50, 49, 44, 51, 48, 44, 36, 50, 50, 44, 48, 46, 48, 48, 44,
  49, 46, 48, 48, 44, 48, 46, 53, 44, 49, 44, 48, 44, 48, 44, 48,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 95, 112,
  114, 101, 118, 105, 101, 119, 102, 108, 97, 103, 60, 61, 49, 125, 10, 45,
  105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 32, 45, 103, 105, 109, 112,
  95, 103, 108, 111, 119, 91, 48, 93, 32, 123, 36, 50, 47, 49, 48, 125,
  44, 48, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61,
  50, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 104, 97, 114, 100, 108, 105, 103, 104, 116, 91, 48, 44, 49, 93, 32,
  123, 36, 50, 47, 49, 48, 48, 125, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 61, 61, 51, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 115, 99, 114, 101, 101, 110, 91, 48, 44, 49, 93,
  32, 123, 36, 50, 47, 49, 48, 48, 125, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 49, 61, 61, 52, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 109, 117, 108, 116, 105, 112, 108, 121, 91, 48,
  44, 49, 93, 32, 123, 36, 50, 47, 49, 48, 48, 125, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 50, 48, 61, 61, 48, 125,
  32, 45, 103, 105, 109, 112, 95, 109, 105, 120, 95, 108, 97, 98, 91, 48,
  93, 32, 36, 50, 55, 44, 36, 50, 54, 44, 48, 44, 36, 50, 56, 44,
  123, 105, 102, 40, 123, 36, 50, 53, 62, 61, 48, 125, 44, 123, 36, 50,
  53, 47, 52, 125, 44, 123, 36, 50, 53, 42, 48, 46, 55, 53, 125, 41,
  125, 44, 48, 44, 36, 50, 56, 44, 36, 50, 53, 44, 48, 44, 48, 44,
  50, 44, 48, 32, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  105, 102, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109,
  112, 95, 116, 107, 95, 112, 111, 114, 116, 114, 97, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 95, 112, 114, 101, 118, 105, 101, 119,
  102, 108, 97, 103, 61, 49, 10, 45, 105, 102, 32, 123, 36, 50, 57, 61,
  61, 49, 125, 32, 95, 112, 114, 101, 118, 105, 101, 119, 102, 108, 97, 103,
  61, 50, 32, 45, 101, 108, 105, 102, 32, 123, 123, 36, 50, 57, 61, 61,
  50, 125, 124, 124, 123, 36, 50, 57, 61, 61, 51, 125, 125, 32, 95, 112,
  114, 101, 118, 105, 101, 119, 102, 108, 97, 103, 61, 51, 32, 45, 101, 108,
  105, 102, 32, 123, 36, 50, 57, 62, 61, 52, 125, 32, 95, 112, 114, 101,
  118, 105, 101, 119, 102, 108, 97, 103, 61, 52, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 50, 57, 62, 61, 50, 125, 32, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 116, 107, 95, 112, 111, 114,
  116, 114, 97, 105, 116, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 48,
  10, 45, 101, 108, 115, 101, 32, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109,
  112, 95, 116, 107, 95, 112, 111, 114, 116, 114, 97, 105, 116, 32, 36, 123,
  49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 50, 57, 61, 61, 49, 125, 32, 45,
  107, 91, 48, 93, 32, 45, 101, 108, 105, 102, 32, 123, 36, 50, 57, 61,
  61, 50, 125, 32, 45, 107, 91, 50, 93, 32, 45, 101, 108, 105, 102, 32,
  123, 36, 50, 57, 61, 61, 51, 125, 32, 45, 107, 91, 48, 93, 32, 45,
  101, 108, 105, 102, 32, 123, 36, 50, 57, 61, 61, 52, 125, 32, 45, 107,
  91, 45, 51, 93, 32, 45, 101, 108, 105, 102, 32, 123, 36, 50, 57, 61,
  61, 53, 125, 32, 45, 107, 91, 45, 51, 93, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 50, 57, 61, 61, 54, 125, 32, 45, 107, 91, 45, 53, 93,
  32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 32, 45, 101, 108, 105, 102,
  32, 123, 36, 50, 57, 61, 61, 55, 125, 32, 45, 107, 91, 45, 50, 93,
  32, 45, 101, 108, 105, 102, 32, 123, 36, 50, 57, 61, 61, 56, 125, 32,
  45, 107, 91, 48, 93, 32, 45, 101, 108, 105, 102, 32, 123, 36, 50, 57,
  61, 61, 57, 125, 32, 45, 107, 91, 45, 49, 93, 32, 45, 101, 110, 100,
  105, 102, 10, 95, 112, 114, 101, 118, 105, 101, 119, 102, 108, 97, 103, 61,
  48, 10, 35, 64, 103, 105, 109, 112, 32, 83, 104, 97, 114, 112, 101, 110,
  32, 91, 100, 101, 98, 108, 117, 114, 93, 32, 58, 32, 103, 105, 109, 112,
  95, 100, 101, 98, 108, 117, 114, 44, 32, 103, 105, 109, 112, 95, 100, 101,
  98, 108, 117, 114, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 100, 105, 117, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 44, 50, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101, 114, 97, 116, 105,
  111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 49, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 105, 109,
  101, 32, 115, 116, 101, 112, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50,
  48, 44, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 49, 44, 48, 44, 49, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 101, 103, 117, 108, 97, 114, 105, 122,
  97, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49,
  44, 34, 84, 105, 107, 104, 111, 110, 111, 118, 34, 44, 34, 77, 101, 97,
  110, 32, 99, 117, 114, 118, 97, 116, 117, 114, 101, 34, 44, 34, 84, 111,
  116, 97, 108, 32, 118, 97, 114, 105, 97, 116, 105, 111, 110, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108,
  40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108,
  108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44,
  34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117,
  101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105,
  110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110,
  101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105,
  111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121,
  34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44,
  34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 80, 97, 114, 97, 108, 108, 101, 108, 32, 112, 114, 111,
  99, 101, 115, 115, 105, 110, 103, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 65, 117, 116, 111, 34, 44, 34, 79, 110, 101, 32, 116, 104, 114,
  101, 97, 100, 34, 44, 34, 84, 119, 111, 32, 116, 104, 114, 101, 97, 100,
  115, 34, 44, 34, 70, 111, 117, 114, 32, 116, 104, 114, 101, 97, 100, 115,
  34, 44, 34, 69, 105, 103, 104, 116, 32, 116, 104, 114, 101, 97, 100, 115,
  34, 44, 34, 83, 105, 120, 116, 101, 101, 110, 32, 116, 104, 114, 101, 97,
  100, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112,
  97, 116, 105, 97, 108, 32, 111, 118, 101, 114, 108, 97, 112, 32, 61, 32,
  105, 110, 116, 40, 50, 52, 44, 48, 44, 50, 53, 54, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101,
  119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99,
  97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105,
  62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114,
  108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 100, 101, 98, 108, 117, 114, 32, 58, 10, 45, 97, 112, 112,
  108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 103, 105,
  109, 112, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114,
  108, 97, 112, 32, 92, 34, 45, 100, 101, 98, 108, 117, 114, 32, 36, 123,
  49, 45, 53, 125, 32, 45, 99, 32, 48, 44, 50, 53, 53, 92, 34, 44,
  36, 55, 44, 36, 56, 34, 44, 36, 54, 44, 48, 10, 103, 105, 109, 112,
  95, 100, 101, 98, 108, 117, 114, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 100, 101, 98,
  108, 117, 114, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105,
  109, 112, 32, 83, 104, 97, 114, 112, 101, 110, 32, 91, 103, 111, 108, 100,
  45, 109, 101, 105, 110, 101, 108, 93, 32, 58, 32, 103, 105, 109, 112, 95,
  117, 110, 115, 104, 97, 114, 112, 95, 103, 111, 108, 100, 109, 101, 105, 110,
  101, 108, 44, 32, 103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112,
  95, 103, 111, 108, 100, 109, 101, 105, 110, 101, 108, 95, 112, 114, 101, 118,
  105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 105, 103,
  109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 46, 53,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116,
  101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 53,
  44, 49, 44, 49, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  65, 99, 99, 101, 108, 101, 114, 97, 116, 105, 111, 110, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 44, 49, 44, 51, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 66, 108, 117, 114, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 49, 44, 34, 69, 120, 112, 111, 110, 101, 110, 116, 105, 97,
  108, 34, 44, 34, 71, 97, 117, 115, 115, 105, 97, 110, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 116, 32, 61, 32, 98, 111,
  111, 108, 40, 116, 114, 117, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 114,
  97, 108, 108, 101, 108, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 117, 116, 111, 34,
  44, 34, 79, 110, 101, 32, 116, 104, 114, 101, 97, 100, 34, 44, 34, 84,
  119, 111, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 70, 111, 117,
  114, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 69, 105, 103, 104,
  116, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 83, 105, 120, 116,
  101, 101, 110, 32, 116, 104, 114, 101, 97, 100, 115, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 112, 97, 116, 105, 97, 108, 32, 111,
  118, 101, 114, 108, 97, 112, 32, 61, 32, 105, 110, 116, 40, 50, 52, 44,
  48, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 74,
  38, 35, 50, 51, 51, 59, 114, 38, 35, 50, 52, 52, 59, 109, 101, 32,
  66, 111, 117, 108, 97, 110, 103, 101, 114, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 51, 47, 50, 57,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112, 95, 103, 111, 108,
  100, 109, 101, 105, 110, 101, 108, 58, 10, 45, 103, 105, 109, 112, 95, 112,
  97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 32,
  34, 45, 100, 101, 98, 108, 117, 114, 95, 103, 111, 108, 100, 109, 101, 105,
  110, 101, 108, 32, 36, 42, 32, 45, 105, 102, 32, 36, 53, 32, 45, 99,
  32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 115, 101, 32, 45, 110, 32,
  48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 34, 44, 36, 54,
  44, 36, 55, 10, 103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112,
  95, 103, 111, 108, 100, 109, 101, 105, 110, 101, 108, 95, 112, 114, 101, 118,
  105, 101, 119, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95,
  117, 110, 115, 104, 97, 114, 112, 95, 103, 111, 108, 100, 109, 101, 105, 110,
  101, 108, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 83, 104, 97, 114, 112, 101, 110, 32, 91, 105, 110, 118, 101, 114,
  115, 101, 32, 100, 105, 102, 102, 117, 115, 105, 111, 110, 93, 32, 58, 32,
  103, 105, 109, 112, 95, 115, 104, 97, 114, 112, 101, 110, 95, 105, 110, 118,
  101, 114, 115, 101, 100, 105, 102, 102, 44, 32, 103, 105, 109, 112, 95, 115,
  104, 97, 114, 112, 101, 110, 95, 105, 110, 118, 101, 114, 115, 101, 100, 105,
  102, 102, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 49, 44, 51, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101, 114,
  97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 50, 44, 49,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104,
  97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34,
  82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34,
  44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100,
  32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76,
  105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116,
  117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34,
  44, 34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114,
  101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112,
  104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 114, 97, 108, 108, 101,
  108, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 65, 117, 116, 111, 34, 44, 34, 79, 110,
  101, 32, 116, 104, 114, 101, 97, 100, 34, 44, 34, 84, 119, 111, 32, 116,
  104, 114, 101, 97, 100, 115, 34, 44, 34, 70, 111, 117, 114, 32, 116, 104,
  114, 101, 97, 100, 115, 34, 44, 34, 69, 105, 103, 104, 116, 32, 116, 104,
  114, 101, 97, 100, 115, 34, 44, 34, 83, 105, 120, 116, 101, 101, 110, 32,
  116, 104, 114, 101, 97, 100, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 112, 97, 116, 105, 97, 108, 32, 111, 118, 101, 114, 108,
  97, 112, 32, 61, 32, 105, 110, 116, 40, 50, 52, 44, 48, 44, 50, 53,
  54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80,
  114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68,
  117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104,
  117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50,
  47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 103, 105, 109, 112, 95, 115, 104, 97, 114, 112, 101, 110, 95,
  105, 110, 118, 101, 114, 115, 101, 100, 105, 102, 102, 32, 58, 10, 45, 97,
  112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45,
  103, 105, 109, 112, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118,
  101, 114, 108, 97, 112, 32, 92, 34, 45, 114, 101, 112, 101, 97, 116, 32,
  36, 50, 32, 45, 115, 104, 97, 114, 112, 101, 110, 32, 36, 49, 32, 45,
  99, 32, 48, 44, 50, 53, 53, 32, 45, 100, 111, 110, 101, 92, 34, 44,
  36, 52, 44, 36, 53, 34, 44, 36, 51, 44, 48, 10, 103, 105, 109, 112,
  95, 115, 104, 97, 114, 112, 101, 110, 95, 105, 110, 118, 101, 114, 115, 101,
  100, 105, 102, 102, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 115, 104, 97, 114, 112, 101,
  110, 95, 105, 110, 118, 101, 114, 115, 101, 100, 105, 102, 102, 32, 36, 42,
  34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 83, 104, 97,
  114, 112, 101, 110, 32, 91, 111, 99, 116, 97, 118, 101, 32, 115, 104, 97,
  114, 112, 101, 110, 105, 110, 103, 93, 32, 58, 32, 103, 105, 109, 112, 95,
  117, 110, 115, 104, 97, 114, 112, 95, 111, 99, 116, 97, 118, 101, 44, 32,
  103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112, 95, 111, 99, 116,
  97, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 115, 32, 61,
  32, 105, 110, 116, 40, 52, 44, 49, 44, 49, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 77, 97, 120, 105, 109, 97, 108, 32, 114, 97,
  100, 105, 117, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48,
  44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109,
  111, 117, 110, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44, 48,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104,
  114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66,
  65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108,
  117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97,
  98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44,
  34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97,
  108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101,
  110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34,
  99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34,
  44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44,
  34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 114,
  97, 108, 108, 101, 108, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 117, 116, 111, 34,
  44, 34, 79, 110, 101, 32, 116, 104, 114, 101, 97, 100, 34, 44, 34, 84,
  119, 111, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 70, 111, 117,
  114, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 69, 105, 103, 104,
  116, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 83, 105, 120, 116,
  101, 101, 110, 32, 116, 104, 114, 101, 97, 100, 115, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 112, 97, 116, 105, 97, 108, 32, 111,
  118, 101, 114, 108, 97, 112, 32, 61, 32, 105, 110, 116, 40, 50, 52, 44,
  48, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99,
  97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65,
  117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32,
  84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59,
  60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49,
  48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 117, 110, 115, 104,
  97, 114, 112, 95, 111, 99, 116, 97, 118, 101, 32, 58, 10, 45, 97, 112,
  112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 103,
  105, 109, 112, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101,
  114, 108, 97, 112, 32, 92, 34, 45, 117, 110, 115, 104, 97, 114, 112, 95,
  111, 99, 116, 97, 118, 101, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44,
  36, 52, 92, 34, 44, 36, 54, 44, 36, 55, 34, 44, 36, 53, 44, 48,
  10, 103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112, 95, 111, 99,
  116, 97, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114,
  112, 95, 111, 99, 116, 97, 118, 101, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 83, 104, 97, 114, 112, 101, 110, 32,
  91, 114, 105, 99, 104, 97, 114, 100, 115, 111, 110, 45, 108, 117, 99, 121,
  93, 32, 58, 32, 103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112,
  95, 114, 105, 99, 104, 97, 114, 100, 115, 111, 110, 108, 117, 99, 121, 44,
  32, 103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112, 95, 114, 105,
  99, 104, 97, 114, 100, 115, 111, 110, 108, 117, 99, 121, 95, 112, 114, 101,
  118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 105,
  103, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 46,
  53, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73,
  116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40,
  49, 48, 44, 49, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 66, 108, 117, 114, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 49, 44, 34, 69, 120, 112, 111, 110, 101, 110, 116, 105, 97, 108, 34,
  44, 34, 71, 97, 117, 115, 115, 105, 97, 110, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 117, 116, 32, 61, 32, 98, 111, 111, 108,
  40, 116, 114, 117, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 114, 97, 108,
  108, 101, 108, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 117, 116, 111, 34, 44, 34,
  79, 110, 101, 32, 116, 104, 114, 101, 97, 100, 34, 44, 34, 84, 119, 111,
  32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 70, 111, 117, 114, 32,
  116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 69, 105, 103, 104, 116, 32,
  116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 83, 105, 120, 116, 101, 101,
  110, 32, 116, 104, 114, 101, 97, 100, 115, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 112, 97, 116, 105, 97, 108, 32, 111, 118, 101,
  114, 108, 97, 112, 32, 61, 32, 105, 110, 116, 40, 50, 52, 44, 48, 44,
  50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 74, 38, 35,
  50, 51, 51, 59, 114, 38, 35, 50, 52, 52, 59, 109, 101, 32, 66, 111,
  117, 108, 97, 110, 103, 101, 114, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 51, 47, 50, 57, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 117, 110, 115, 104, 97, 114, 112, 95, 114, 105, 99, 104, 97,
  114, 100, 115, 111, 110, 108, 117, 99, 121, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108,
  97, 112, 32, 34, 45, 100, 101, 98, 108, 117, 114, 95, 114, 105, 99, 104,
  97, 114, 100, 115, 111, 110, 108, 117, 99, 121, 32, 36, 42, 32, 45, 105,
  102, 32, 36, 52, 32, 45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 101,
  108, 115, 101, 32, 45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110,
  100, 105, 102, 34, 44, 36, 53, 44, 36, 54, 10, 103, 105, 109, 112, 95,
  117, 110, 115, 104, 97, 114, 112, 95, 114, 105, 99, 104, 97, 114, 100, 115,
  111, 110, 108, 117, 99, 121, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 117, 110, 115, 104,
  97, 114, 112, 95, 114, 105, 99, 104, 97, 114, 100, 115, 111, 110, 108, 117,
  99, 121, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 83, 104, 97, 114, 112, 101, 110, 32, 91, 115, 104, 111, 99, 107,
  32, 102, 105, 108, 116, 101, 114, 115, 93, 32, 58, 32, 103, 105, 109, 112,
  95, 115, 104, 97, 114, 112, 101, 110, 95, 115, 104, 111, 99, 107, 44, 32,
  103, 105, 109, 112, 95, 115, 104, 97, 114, 112, 101, 110, 95, 115, 104, 111,
  99, 107, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 53, 48, 44, 49, 44, 52,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103,
  101, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 49, 44, 48, 44, 48, 46, 55, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 97, 100, 105, 101, 110, 116,
  32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 56, 44, 48, 44, 49, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 84, 101, 110, 115, 111, 114, 32, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 46, 49, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 61,
  32, 105, 110, 116, 40, 49, 44, 49, 44, 49, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44,
  34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114,
  101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34,
  44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115,
  34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115,
  34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72,
  117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34,
  44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34,
  71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34,
  82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108,
  117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 80, 97, 114, 97, 108, 108, 101, 108, 32, 112, 114, 111, 99, 101, 115,
  115, 105, 110, 103, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65,
  117, 116, 111, 34, 44, 34, 79, 110, 101, 32, 116, 104, 114, 101, 97, 100,
  34, 44, 34, 84, 119, 111, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44,
  34, 70, 111, 117, 114, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34,
  69, 105, 103, 104, 116, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34,
  83, 105, 120, 116, 101, 101, 110, 32, 116, 104, 114, 101, 97, 100, 115, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 97, 116, 105,
  97, 108, 32, 111, 118, 101, 114, 108, 97, 112, 32, 61, 32, 105, 110, 116,
  40, 50, 52, 44, 48, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117,
  108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117,
  112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  115, 104, 97, 114, 112, 101, 110, 95, 115, 104, 111, 99, 107, 32, 58, 10,
  45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  34, 45, 103, 105, 109, 112, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95,
  111, 118, 101, 114, 108, 97, 112, 32, 92, 34, 45, 114, 101, 112, 101, 97,
  116, 32, 36, 53, 32, 45, 115, 104, 97, 114, 112, 101, 110, 32, 36, 49,
  44, 36, 50, 44, 36, 51, 44, 36, 52, 32, 45, 99, 32, 48, 44, 50,
  53, 53, 32, 45, 100, 111, 110, 101, 92, 34, 44, 36, 55, 44, 36, 56,
  34, 44, 36, 54, 44, 48, 10, 103, 105, 109, 112, 95, 115, 104, 97, 114,
  112, 101, 110, 95, 115, 104, 111, 99, 107, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 115,
  104, 97, 114, 112, 101, 110, 95, 115, 104, 111, 99, 107, 32, 36, 42, 34,
  44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 83, 104, 97, 114,
  112, 101, 110, 32, 91, 117, 110, 115, 104, 97, 114, 112, 32, 109, 97, 115,
  107, 93, 32, 58, 32, 103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114,
  112, 44, 32, 103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112, 95,
  112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 104, 97, 114, 112, 101, 110, 105, 110, 103, 32, 116,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34,
  71, 97, 117, 115, 115, 105, 97, 110, 34, 44, 34, 66, 105, 108, 97, 116,
  101, 114, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 112, 97, 116, 105, 97, 108, 32, 114, 97, 100, 105, 117, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 46, 50, 53, 44, 48, 44, 50, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 105, 108, 97, 116,
  101, 114, 97, 108, 32, 114, 97, 100, 105, 117, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 51, 48, 44, 48, 44, 54, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 65, 109, 111, 117, 110, 116, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 51, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 50, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 97, 114, 107, 110, 101, 115,
  115, 32, 108, 101, 118, 101, 108, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  76, 105, 103, 104, 116, 110, 101, 115, 115, 32, 108, 101, 118, 101, 108, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101, 114, 97, 116, 105, 111,
  110, 115, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49, 44, 49, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 101, 103, 97, 116, 105,
  118, 101, 32, 101, 102, 102, 101, 99, 116, 32, 61, 32, 98, 111, 111, 108,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97,
  110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82,
  71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105,
  110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32,
  99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105,
  103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117,
  114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44,
  34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114,
  111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101,
  101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104,
  97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  123, 34, 92, 110, 92, 110, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62,
  78, 111, 116, 101, 58, 32, 60, 47, 98, 62, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 84, 104, 105, 115, 32, 102, 105, 108, 116, 101, 114, 32,
  105, 115, 32, 105, 110, 115, 112, 105, 114, 101, 100, 32, 98, 121, 32, 116,
  104, 101, 32, 111, 114, 105, 103, 105, 110, 97, 108, 32, 60, 105, 62, 85,
  110, 115, 104, 97, 114, 112, 32, 77, 97, 115, 107, 60, 47, 105, 62, 32,
  102, 105, 108, 116, 101, 114, 32, 105, 110, 32, 71, 73, 77, 80, 44, 32,
  119, 105, 116, 104, 32, 97, 100, 100, 105, 116, 105, 111, 110, 97, 108, 32,
  112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 46, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 60, 47, 115, 109, 97, 108, 108, 62, 34, 125, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 95, 103, 105, 109, 112, 95, 117, 110,
  115, 104, 97, 114, 112, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 56, 10, 45, 105,
  102, 32, 123, 36, 49, 61, 61, 48, 125, 32, 45, 45, 98, 91, 45, 49,
  93, 32, 36, 50, 32, 45, 101, 108, 115, 101, 32, 45, 45, 98, 105, 108,
  97, 116, 101, 114, 97, 108, 91, 45, 49, 93, 32, 36, 50, 44, 36, 51,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 91, 45, 49, 93, 32, 91,
  45, 50, 93, 32, 45, 42, 91, 45, 49, 93, 32, 45, 36, 52, 10, 45,
  45, 110, 111, 114, 109, 91, 45, 49, 93, 32, 45, 103, 101, 91, 45, 49,
  93, 32, 36, 53, 37, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50,
  93, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 10, 45, 105, 102, 32,
  36, 57, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 45, 99, 91, 45, 49, 93, 32, 48, 44, 49, 48,
  48, 37, 32, 45, 99, 91, 45, 50, 93, 32, 45, 49, 48, 48, 37, 44,
  48, 32, 45, 42, 91, 45, 50, 93, 32, 36, 54, 32, 45, 42, 91, 45,
  49, 93, 32, 36, 55, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10,
  45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 99, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 10, 45, 100, 111, 110, 101, 32, 45, 109, 118,
  91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109,
  112, 95, 117, 110, 115, 104, 97, 114, 112, 32, 58, 10, 45, 97, 112, 112,
  108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 95, 103,
  105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112, 32, 36, 49, 44, 36,
  50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55,
  44, 36, 56, 44, 36, 57, 34, 44, 36, 49, 48, 44, 48, 10, 103, 105,
  109, 112, 95, 117, 110, 115, 104, 97, 114, 112, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95,
  117, 110, 115, 104, 97, 114, 112, 32, 36, 42, 34, 44, 36, 45, 49, 10,
  35, 64, 103, 105, 109, 112, 32, 83, 104, 97, 114, 112, 101, 110, 32, 91,
  119, 104, 105, 116, 101, 110, 93, 32, 58, 32, 106, 101, 106, 101, 95, 119,
  104, 105, 116, 101, 110, 95, 102, 114, 101, 113, 117, 101, 110, 99, 121, 44,
  32, 106, 101, 106, 101, 95, 119, 104, 105, 116, 101, 110, 95, 102, 114, 101,
  113, 117, 101, 110, 99, 121, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 108, 112, 104, 97, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 116, 32, 61, 32, 98,
  111, 111, 108, 40, 102, 97, 108, 115, 101, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117,
  108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 60,
  98, 62, 78, 111, 116, 101, 58, 60, 47, 98, 62, 84, 104, 105, 115, 32,
  102, 105, 108, 116, 101, 114, 32, 101, 113, 117, 97, 108, 105, 122, 101, 115,
  32, 102, 114, 101, 113, 117, 101, 110, 99, 105, 101, 115, 32, 105, 110, 32,
  116, 104, 101, 32, 105, 109, 97, 103, 101, 46, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 32, 58, 32, 60, 105, 62, 74, 38, 35, 50, 51, 51, 59, 114,
  38, 35, 50, 52, 52, 59, 109, 101, 32, 66, 111, 117, 108, 97, 110, 103,
  101, 114, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 51, 47, 48, 54, 47, 48, 49, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 106, 101, 106, 101, 95, 119, 104,
  105, 116, 101, 110, 95, 102, 114, 101, 113, 117, 101, 110, 99, 121, 32, 58,
  10, 45, 119, 104, 105, 116, 101, 110, 95, 102, 114, 101, 113, 117, 101, 110,
  99, 121, 32, 123, 101, 120, 112, 40, 36, 49, 47, 49, 48, 48, 41, 45,
  49, 125, 10, 45, 105, 102, 32, 36, 50, 32, 45, 99, 32, 48, 44, 50,
  53, 53, 32, 45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 115,
  101, 32, 45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105,
  102, 10, 106, 101, 106, 101, 95, 119, 104, 105, 116, 101, 110, 95, 102, 114,
  101, 113, 117, 101, 110, 99, 121, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 106, 101, 106, 101, 95, 119, 104, 105,
  116, 101, 110, 95, 102, 114, 101, 113, 117, 101, 110, 99, 121, 32, 36, 49,
  44, 36, 50, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32,
  83, 105, 109, 112, 108, 101, 32, 108, 111, 99, 97, 108, 32, 99, 111, 110,
  116, 114, 97, 115, 116, 32, 58, 32, 115, 105, 109, 112, 108, 101, 108, 111,
  99, 97, 108, 99, 111, 110, 116, 114, 97, 115, 116, 44, 115, 105, 109, 112,
  108, 101, 108, 111, 99, 97, 108, 99, 111, 110, 116, 114, 97, 115, 116, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101,
  32, 115, 101, 110, 115, 105, 116, 105, 118, 105, 116, 121, 32, 61, 32, 102,
  108, 111, 97, 116, 32, 40, 49, 54, 44, 48, 44, 50, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101, 114, 97, 116, 105, 111,
  110, 115, 32, 61, 32, 105, 110, 116, 32, 40, 50, 44, 49, 44, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 105, 110, 116, 32,
  101, 102, 102, 101, 99, 116, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40,
  48, 44, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 76, 117, 109, 97, 32, 111, 110, 108, 121, 32, 61, 32, 98, 111, 111,
  108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114,
  101, 45, 103, 97, 109, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 32,
  40, 49, 44, 46, 49, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 80, 111, 115, 116, 45, 103, 97, 109, 109, 97, 32, 61, 32, 102,
  108, 111, 97, 116, 32, 40, 49, 44, 46, 49, 44, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  65, 117, 116, 104, 111, 114, 58, 32, 73, 97, 105, 110, 32, 70, 101, 114,
  103, 117, 115, 115, 111, 110, 32, 45, 32, 117, 112, 100, 97, 116, 101, 32,
  56, 32, 68, 101, 99, 32, 50, 48, 49, 50, 34, 41, 10, 115, 105, 109,
  112, 108, 101, 108, 111, 99, 97, 108, 99, 111, 110, 116, 114, 97, 115, 116,
  58, 10, 115, 116, 114, 49, 61, 36, 49, 10, 115, 116, 114, 50, 61, 123,
  36, 115, 116, 114, 49, 42, 48, 46, 55, 125, 10, 115, 116, 114, 51, 61,
  123, 36, 115, 116, 114, 50, 42, 48, 46, 55, 125, 10, 115, 116, 114, 52,
  61, 123, 36, 115, 116, 114, 51, 42, 48, 46, 55, 125, 10, 115, 116, 114,
  53, 61, 123, 36, 115, 116, 114, 52, 42, 48, 46, 55, 125, 10, 115, 116,
  114, 54, 61, 123, 36, 115, 116, 114, 53, 42, 48, 46, 55, 125, 10, 115,
  116, 114, 55, 61, 123, 36, 115, 116, 114, 54, 42, 48, 46, 55, 125, 10,
  115, 116, 114, 56, 61, 123, 36, 115, 116, 114, 55, 42, 48, 46, 55, 125,
  10, 45, 97, 112, 112, 108, 121, 95, 103, 97, 109, 109, 97, 32, 36, 53,
  10, 45, 99, 111, 110, 116, 116, 101, 115, 116, 52, 32, 36, 52, 44, 36,
  115, 116, 114, 49, 44, 36, 115, 116, 114, 50, 44, 36, 115, 116, 114, 51,
  44, 36, 115, 116, 114, 52, 44, 36, 115, 116, 114, 53, 44, 36, 115, 116,
  114, 54, 44, 36, 115, 116, 114, 55, 44, 36, 115, 116, 114, 56, 44, 36,
  50, 44, 36, 51, 44, 36, 51, 44, 36, 51, 44, 36, 51, 44, 36, 51,
  44, 36, 51, 44, 50, 44, 49, 10, 45, 97, 112, 112, 108, 121, 95, 103,
  97, 109, 109, 97, 32, 36, 54, 10, 45, 110, 32, 48, 44, 50, 53, 53,
  10, 99, 111, 110, 116, 116, 101, 115, 116, 52, 58, 10, 45, 116, 111, 95,
  114, 103, 98, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 10,
  45, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 10, 45, 45, 115, 109,
  111, 111, 116, 104, 98, 97, 115, 101, 52, 91, 45, 49, 93, 32, 36, 50,
  44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44,
  36, 56, 44, 36, 57, 44, 36, 49, 48, 10, 45, 45, 99, 111, 109, 112,
  111, 115, 101, 95, 103, 114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116,
  91, 45, 49, 44, 45, 50, 93, 10, 45, 109, 115, 95, 115, 109, 111, 111,
  116, 104, 91, 45, 49, 93, 32, 36, 49, 49, 44, 36, 49, 50, 44, 36,
  49, 51, 44, 36, 49, 52, 44, 36, 49, 53, 44, 36, 49, 54, 44, 36,
  49, 55, 44, 36, 49, 56, 44, 49, 10, 45, 114, 101, 109, 111, 118, 101,
  91, 49, 44, 50, 93, 10, 45, 115, 117, 98, 91, 45, 49, 93, 32, 49,
  50, 56, 32, 45, 109, 117, 108, 91, 45, 49, 93, 32, 50, 32, 45, 97,
  100, 100, 91, 45, 49, 93, 32, 49, 50, 56, 10, 45, 45, 99, 111, 109,
  112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 10,
  45, 114, 101, 109, 111, 118, 101, 91, 48, 44, 49, 93, 10, 45, 101, 108,
  115, 101, 10, 45, 45, 115, 109, 111, 111, 116, 104, 98, 97, 115, 101, 52,
  32, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44,
  36, 55, 44, 36, 56, 44, 36, 57, 44, 36, 49, 48, 10, 45, 45, 99,
  111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 101, 120, 116, 114,
  97, 99, 116, 10, 45, 109, 115, 95, 115, 109, 111, 111, 116, 104, 91, 45,
  49, 93, 32, 36, 49, 49, 44, 36, 49, 50, 44, 36, 49, 51, 44, 36,
  49, 52, 44, 36, 49, 53, 44, 36, 49, 54, 44, 36, 49, 55, 44, 36,
  49, 56, 44, 49, 10, 45, 114, 101, 109, 111, 118, 101, 91, 49, 93, 10,
  45, 115, 117, 98, 91, 45, 49, 93, 32, 49, 50, 56, 32, 45, 109, 117,
  108, 91, 45, 49, 93, 32, 50, 32, 45, 97, 100, 100, 91, 45, 49, 93,
  32, 49, 50, 56, 10, 45, 45, 99, 111, 109, 112, 111, 115, 101, 95, 103,
  114, 97, 105, 110, 109, 101, 114, 103, 101, 10, 45, 114, 101, 109, 111, 118,
  101, 91, 49, 93, 10, 45, 114, 103, 98, 50, 104, 115, 118, 10, 45, 115,
  112, 108, 105, 116, 32, 99, 10, 45, 114, 101, 109, 111, 118, 101, 91, 49,
  44, 50, 44, 51, 93, 10, 45, 97, 112, 112, 101, 110, 100, 32, 99, 10,
  45, 104, 115, 118, 50, 114, 103, 98, 10, 45, 101, 110, 100, 105, 102, 10,
  115, 109, 111, 111, 116, 104, 98, 97, 115, 101, 52, 58, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 36, 57, 10, 99, 114, 111, 112, 119, 105, 100, 116,
  104, 61, 123, 119, 125, 10, 99, 114, 111, 112, 104, 101, 105, 103, 104, 116,
  61, 123, 104, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32,
  123, 119, 43, 40, 50, 53, 54, 45, 119, 37, 50, 53, 54, 41, 125, 44,
  123, 104, 43, 40, 50, 53, 54, 45, 104, 37, 50, 53, 54, 41, 125, 44,
  49, 44, 123, 115, 125, 44, 48, 44, 49, 10, 119, 105, 100, 116, 104, 61,
  123, 119, 125, 10, 104, 101, 105, 103, 104, 116, 61, 123, 104, 125, 10, 45,
  105, 102, 32, 123, 36, 49, 33, 61, 48, 125, 10, 45, 100, 101, 110, 111,
  105, 115, 101, 91, 48, 93, 32, 49, 48, 44, 36, 49, 44, 51, 44, 53,
  44, 48, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 45, 114, 101,
  115, 105, 122, 101, 91, 48, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47,
  50, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 50, 125, 44, 49,
  44, 123, 115, 125, 44, 50, 44, 49, 10, 45, 45, 114, 101, 115, 105, 122,
  101, 91, 45, 49, 93, 32, 36, 119, 105, 100, 116, 104, 44, 36, 104, 101,
  105, 103, 104, 116, 44, 49, 44, 123, 115, 125, 44, 51, 44, 49, 10, 45,
  98, 108, 117, 114, 91, 45, 49, 93, 32, 46, 53, 10, 45, 99, 111, 109,
  112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 101, 120, 116, 114, 97, 99,
  116, 91, 48, 44, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 50, 33,
  61, 48, 125, 10, 45, 100, 101, 110, 111, 105, 115, 101, 91, 45, 49, 93,
  32, 49, 48, 44, 36, 50, 44, 51, 44, 53, 44, 48, 44, 49, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 45,
  49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 52, 125, 44, 123, 36,
  104, 101, 105, 103, 104, 116, 47, 52, 125, 44, 49, 44, 123, 115, 125, 44,
  50, 44, 49, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93,
  32, 123, 36, 119, 105, 100, 116, 104, 47, 50, 125, 44, 123, 36, 104, 101,
  105, 103, 104, 116, 47, 50, 125, 44, 49, 44, 123, 115, 125, 44, 51, 44,
  49, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 46, 53, 10, 45,
  99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 101, 120, 116,
  114, 97, 99, 116, 91, 49, 44, 45, 49, 93, 10, 45, 105, 102, 32, 123,
  36, 51, 33, 61, 48, 125, 10, 45, 100, 101, 110, 111, 105, 115, 101, 91,
  45, 49, 93, 32, 49, 48, 44, 36, 51, 44, 51, 44, 53, 44, 48, 44,
  49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 45, 114, 101, 115, 105, 122,
  101, 91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 56, 125,
  44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 56, 125, 44, 49, 44, 123,
  115, 125, 44, 50, 44, 49, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91,
  45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 52, 125, 44, 123,
  36, 104, 101, 105, 103, 104, 116, 47, 52, 125, 44, 49, 44, 123, 115, 125,
  44, 51, 44, 49, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 46,
  53, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110,
  101, 120, 116, 114, 97, 99, 116, 91, 50, 44, 45, 49, 93, 10, 45, 105,
  102, 32, 123, 36, 52, 33, 61, 48, 125, 10, 45, 100, 101, 110, 111, 105,
  115, 101, 91, 45, 49, 93, 32, 49, 48, 44, 36, 52, 44, 51, 44, 53,
  44, 48, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 45, 114, 101,
  115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104,
  47, 49, 54, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 49, 54,
  125, 44, 49, 44, 123, 115, 125, 44, 50, 44, 49, 10, 45, 45, 114, 101,
  115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104,
  47, 56, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 56, 125, 44,
  49, 44, 123, 115, 125, 44, 51, 44, 49, 10, 45, 98, 108, 117, 114, 91,
  45, 49, 93, 32, 46, 53, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  103, 114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116, 91, 51, 44, 45,
  49, 93, 10, 45, 105, 102, 32, 123, 36, 53, 33, 61, 48, 125, 10, 45,
  100, 101, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 49, 48, 44, 36,
  53, 44, 51, 44, 53, 44, 48, 44, 49, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36,
  119, 105, 100, 116, 104, 47, 51, 50, 125, 44, 123, 36, 104, 101, 105, 103,
  104, 116, 47, 51, 50, 125, 44, 49, 44, 123, 115, 125, 44, 50, 44, 49,
  10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36,
  119, 105, 100, 116, 104, 47, 49, 54, 125, 44, 123, 36, 104, 101, 105, 103,
  104, 116, 47, 49, 54, 125, 44, 49, 44, 123, 115, 125, 44, 51, 44, 49,
  10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 46, 53, 10, 45, 99,
  111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 101, 120, 116, 114,
  97, 99, 116, 91, 52, 44, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36,
  54, 33, 61, 48, 125, 10, 45, 100, 101, 110, 111, 105, 115, 101, 91, 45,
  49, 93, 32, 49, 48, 44, 36, 54, 44, 51, 44, 53, 44, 48, 44, 49,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 45, 114, 101, 115, 105, 122, 101,
  91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 54, 52, 125,
  44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 54, 52, 125, 44, 49, 44,
  123, 115, 125, 44, 50, 44, 49, 10, 45, 45, 114, 101, 115, 105, 122, 101,
  91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 51, 50, 125,
  44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 51, 50, 125, 44, 49, 44,
  123, 115, 125, 44, 51, 44, 49, 10, 45, 98, 108, 117, 114, 91, 45, 49,
  93, 32, 46, 53, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114,
  97, 105, 110, 101, 120, 116, 114, 97, 99, 116, 91, 53, 44, 45, 49, 93,
  10, 45, 105, 102, 32, 123, 36, 55, 33, 61, 48, 125, 10, 45, 100, 101,
  110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 49, 48, 44, 36, 55, 44,
  51, 44, 53, 44, 48, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 119, 105,
  100, 116, 104, 47, 49, 50, 56, 125, 44, 123, 36, 104, 101, 105, 103, 104,
  116, 47, 49, 50, 56, 125, 44, 49, 44, 123, 115, 125, 44, 50, 44, 49,
  10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36,
  119, 105, 100, 116, 104, 47, 54, 52, 125, 44, 123, 36, 104, 101, 105, 103,
  104, 116, 47, 54, 52, 125, 44, 49, 44, 123, 115, 125, 44, 51, 44, 49,
  10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 46, 53, 10, 45, 99,
  111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 101, 120, 116, 114,
  97, 99, 116, 91, 54, 44, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36,
  56, 33, 61, 48, 125, 10, 45, 100, 101, 110, 111, 105, 115, 101, 91, 45,
  49, 93, 32, 49, 48, 44, 36, 56, 44, 51, 44, 53, 44, 48, 44, 49,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 45, 114, 101, 115, 105, 122, 101,
  91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 50, 53, 54,
  125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 50, 53, 54, 125, 44,
  49, 44, 123, 115, 125, 44, 50, 44, 49, 10, 45, 45, 114, 101, 115, 105,
  122, 101, 91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 49,
  50, 56, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 49, 50, 56,
  125, 44, 49, 44, 123, 115, 125, 44, 51, 44, 49, 10, 45, 98, 108, 117,
  114, 91, 45, 49, 93, 32, 46, 53, 10, 45, 99, 111, 109, 112, 111, 115,
  101, 95, 103, 114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116, 91, 55,
  44, 45, 49, 93, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93,
  32, 123, 36, 119, 105, 100, 116, 104, 47, 49, 50, 56, 125, 44, 123, 36,
  104, 101, 105, 103, 104, 116, 47, 49, 50, 56, 125, 44, 49, 44, 123, 115,
  125, 44, 51, 44, 49, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32,
  46, 53, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105,
  110, 109, 101, 114, 103, 101, 91, 45, 49, 44, 45, 50, 93, 10, 45, 114,
  101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116,
  104, 47, 54, 52, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 54,
  52, 125, 44, 49, 44, 123, 115, 125, 44, 51, 44, 49, 10, 45, 98, 108,
  117, 114, 91, 45, 49, 93, 32, 46, 53, 10, 45, 99, 111, 109, 112, 111,
  115, 101, 95, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 91, 45, 49,
  44, 45, 50, 93, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93,
  32, 123, 36, 119, 105, 100, 116, 104, 47, 51, 50, 125, 44, 123, 36, 104,
  101, 105, 103, 104, 116, 47, 51, 50, 125, 44, 49, 44, 123, 115, 125, 44,
  51, 44, 49, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 46, 53,
  10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 109,
  101, 114, 103, 101, 91, 45, 49, 44, 45, 50, 93, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47,
  49, 54, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 49, 54, 125,
  44, 49, 44, 123, 115, 125, 44, 51, 44, 49, 10, 45, 98, 108, 117, 114,
  91, 45, 49, 93, 32, 46, 53, 10, 45, 99, 111, 109, 112, 111, 115, 101,
  95, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 91, 45, 49, 44, 45,
  50, 93, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123,
  36, 119, 105, 100, 116, 104, 47, 56, 125, 44, 123, 36, 104, 101, 105, 103,
  104, 116, 47, 56, 125, 44, 49, 44, 123, 115, 125, 44, 51, 44, 49, 10,
  45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 46, 53, 10, 45, 99, 111,
  109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101,
  91, 45, 49, 44, 45, 50, 93, 10, 45, 114, 101, 115, 105, 122, 101, 91,
  45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 52, 125, 44, 123,
  36, 104, 101, 105, 103, 104, 116, 47, 52, 125, 44, 49, 44, 123, 115, 125,
  44, 51, 44, 49, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 46,
  53, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110,
  109, 101, 114, 103, 101, 91, 45, 49, 44, 45, 50, 93, 10, 45, 114, 101,
  115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104,
  47, 50, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 50, 125, 44,
  49, 44, 123, 115, 125, 44, 51, 44, 49, 10, 45, 98, 108, 117, 114, 91,
  45, 49, 93, 32, 46, 53, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 91, 45, 49, 44, 45, 50,
  93, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36,
  119, 105, 100, 116, 104, 47, 49, 125, 44, 123, 36, 104, 101, 105, 103, 104,
  116, 47, 49, 125, 44, 49, 44, 123, 115, 125, 44, 51, 44, 49, 10, 45,
  98, 108, 117, 114, 91, 45, 49, 93, 32, 46, 53, 10, 45, 99, 111, 109,
  112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 91,
  45, 49, 44, 45, 50, 93, 10, 45, 99, 114, 111, 112, 32, 48, 44, 48,
  44, 123, 36, 99, 114, 111, 112, 119, 105, 100, 116, 104, 45, 49, 125, 44,
  123, 36, 99, 114, 111, 112, 104, 101, 105, 103, 104, 116, 45, 49, 125, 10,
  45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 83, 112, 108,
  105, 116, 32, 100, 101, 116, 97, 105, 108, 115, 32, 58, 32, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 100, 101, 116, 97, 105, 108, 115, 44,
  32, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 100, 101, 116, 97,
  105, 108, 115, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 99, 116, 105, 111, 110, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 123, 34, 68, 101, 99, 111, 109, 112, 111,
  115, 101, 47, 117, 112, 100, 97, 116, 101, 34, 44, 34, 82, 101, 99, 111,
  109, 112, 111, 115, 101, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 68, 101, 99, 111, 109,
  112, 111, 115, 101, 32, 111, 112, 116, 105, 111, 110, 115, 58, 60, 47, 98,
  62, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 117, 109, 98, 101, 114, 32, 111, 102, 32, 115,
  99, 97, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 51, 44, 50, 44,
  49, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 97, 115,
  101, 32, 115, 99, 97, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  53, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 68, 101, 116, 97, 105, 108, 115, 32, 115, 99, 97, 108, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 50, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 109,
  111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 50, 44, 34,
  82, 111, 119, 34, 44, 34, 67, 111, 108, 117, 109, 110, 34, 44, 34, 84,
  105, 108, 105, 110, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 51, 44, 34, 66, 97, 115, 101, 32, 115, 99, 97, 108, 101, 34,
  44, 34, 68, 101, 116, 97, 105, 108, 115, 32, 115, 99, 97, 108, 101, 115,
  34, 44, 34, 70, 105, 110, 101, 115, 116, 32, 100, 101, 116, 97, 105, 108,
  115, 32, 115, 99, 97, 108, 101, 34, 44, 34, 65, 108, 108, 32, 115, 99,
  97, 108, 101, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 123, 34, 60, 115, 109, 97, 108, 108, 62, 60,
  98, 62, 73, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115, 32, 111,
  102, 32, 117, 115, 101, 58, 60, 47, 98, 62, 92, 110, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 49, 46, 32, 83, 101, 116, 32, 112, 97, 114,
  97, 109, 101, 116, 101, 114, 32, 60, 105, 62, 65, 99, 116, 105, 111, 110,
  60, 47, 105, 62, 32, 116, 111, 32, 60, 105, 62, 68, 101, 99, 111, 109,
  112, 111, 115, 101, 47, 117, 112, 100, 97, 116, 101, 60, 47, 105, 62, 32,
  97, 110, 100, 32, 99, 104, 111, 111, 115, 101, 32, 100, 101, 99, 111, 109,
  112, 111, 115, 101, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 46,
  32, 84, 104, 101, 110, 32, 99, 108, 105, 99, 107, 32, 60, 105, 62, 79,
  75, 60, 47, 105, 62, 46, 92, 110, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 50, 46, 32, 80, 114, 111, 99, 101, 115, 115, 32, 121, 111, 117,
  114, 32, 105, 109, 97, 103, 101, 46, 32, 70, 111, 114, 32, 105, 110, 115,
  116, 97, 110, 99, 101, 44, 32, 114, 101, 109, 111, 118, 101, 32, 100, 101,
  116, 97, 105, 108, 115, 32, 105, 110, 32, 116, 104, 101, 32, 97, 112, 112,
  114, 111, 112, 114, 105, 97, 116, 101, 32, 115, 99, 97, 108, 101, 115, 32,
  117, 115, 105, 110, 103, 32, 116, 104, 101, 32, 110, 101, 117, 116, 114, 97,
  108, 32, 99, 111, 108, 111, 114, 32, 60, 105, 62, 40, 49, 50, 56, 44,
  49, 50, 56, 44, 49, 50, 56, 41, 60, 47, 105, 62, 46, 92, 110, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 51, 46, 32, 85, 115, 101, 32,
  60, 105, 62, 67, 84, 82, 76, 43, 70, 60, 47, 105, 62, 32, 116, 111,
  32, 97, 112, 112, 108, 121, 32, 116, 104, 101, 32, 102, 105, 108, 116, 101,
  114, 32, 97, 103, 97, 105, 110, 32, 40, 117, 112, 100, 97, 116, 101, 32,
  109, 111, 100, 101, 41, 46, 32, 84, 104, 101, 32, 112, 114, 101, 118, 105,
  101, 119, 32, 111, 102, 32, 116, 104, 101, 32, 114, 101, 115, 117, 108, 116,
  105, 110, 103, 32, 114, 101, 99, 111, 109, 112, 111, 115, 101, 100, 32, 105,
  109, 97, 103, 101, 32, 117, 112, 100, 97, 116, 101, 100, 32, 97, 110, 100,
  32, 115, 104, 111, 119, 110, 32, 97, 116, 32, 116, 104, 101, 32, 116, 111,
  112, 32, 108, 101, 102, 116, 32, 111, 102, 32, 121, 111, 117, 114, 32, 99,
  97, 110, 118, 97, 115, 46, 92, 110, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 52, 46, 32, 82, 101, 112, 101, 97, 116, 32, 115, 116, 101, 112,
  115, 32, 50, 46, 32, 97, 110, 100, 32, 51, 46, 32, 97, 115, 32, 109,
  97, 110, 121, 32, 116, 105, 109, 101, 115, 32, 97, 115, 32, 121, 111, 117,
  32, 119, 97, 110, 116, 46, 92, 110, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 53, 46, 32, 87, 104, 101, 110, 32, 121, 111, 117, 32, 97, 114,
  101, 32, 104, 97, 112, 112, 121, 32, 119, 105, 116, 104, 32, 116, 104, 101,
  32, 114, 101, 115, 117, 108, 116, 44, 32, 111, 112, 101, 110, 32, 116, 104,
  101, 32, 71, 39, 77, 73, 67, 32, 112, 108, 117, 103, 45, 105, 110, 32,
  111, 110, 99, 101, 32, 97, 103, 97, 105, 110, 44, 32, 115, 101, 116, 32,
  112, 97, 114, 97, 109, 101, 116, 101, 114, 32, 60, 105, 62, 65, 99, 116,
  105, 111, 110, 60, 47, 105, 62, 32, 116, 111, 32, 60, 105, 62, 82, 101,
  99, 111, 109, 112, 111, 115, 101, 60, 47, 105, 62, 44, 32, 97, 110, 100,
  32, 99, 108, 105, 99, 107, 32, 60, 105, 62, 79, 75, 60, 47, 105, 62,
  46, 92, 110, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 54, 46, 32,
  71, 101, 116, 32, 121, 111, 117, 114, 32, 102, 105, 110, 97, 108, 32, 109,
  111, 100, 105, 102, 105, 101, 100, 32, 105, 109, 97, 103, 101, 32, 97, 108,
  111, 110, 101, 46, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 74, 38, 35, 50, 51, 51, 59, 114, 111, 109, 101, 32,
  66, 111, 117, 108, 97, 110, 103, 101, 114, 60, 47, 105, 62, 32, 97, 110,
  100, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 49, 50, 47,
  49, 52, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 100, 101, 116,
  97, 105, 108, 115, 32, 58, 10, 45, 114, 101, 109, 111, 118, 101, 95, 111,
  112, 97, 99, 105, 116, 121, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61,
  49, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 60, 93, 10, 45, 45, 114, 111, 119, 115, 32, 48, 32, 118, 108,
  105, 115, 116, 61, 64, 123, 45, 49, 44, 116, 125, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 109, 97, 103, 105, 99, 107, 61, 123, 97, 114, 103, 40,
  49, 44, 36, 118, 108, 105, 115, 116, 41, 125, 32, 110, 98, 95, 105, 109,
  103, 115, 61, 123, 49, 43, 97, 114, 103, 40, 50, 44, 36, 118, 108, 105,
  115, 116, 41, 125, 32, 109, 111, 100, 101, 61, 123, 97, 114, 103, 40, 51,
  44, 36, 118, 108, 105, 115, 116, 41, 125, 10, 45, 105, 102, 32, 123, 36,
  109, 97, 103, 105, 99, 107, 33, 61, 55, 49, 55, 55, 55, 51, 54, 55,
  124, 124, 36, 110, 98, 95, 105, 109, 103, 115, 60, 50, 124, 124, 36, 109,
  111, 100, 101, 60, 48, 124, 124, 36, 109, 111, 100, 101, 62, 50, 125, 32,
  45, 101, 114, 114, 111, 114, 32, 34, 34, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 109, 111, 100, 101, 61, 61, 48, 125, 32,
  45, 115, 32, 120, 44, 36, 110, 98, 95, 105, 109, 103, 115, 32, 45, 101,
  108, 105, 102, 32, 123, 36, 109, 111, 100, 101, 61, 61, 49, 125, 32, 45,
  115, 32, 121, 44, 36, 110, 98, 95, 105, 109, 103, 115, 10, 45, 101, 108,
  115, 101, 32, 78, 61, 123, 105, 110, 116, 40, 115, 113, 114, 116, 40, 36,
  110, 98, 95, 105, 109, 103, 115, 41, 41, 125, 32, 77, 61, 123, 114, 111,
  117, 110, 100, 40, 36, 110, 98, 95, 105, 109, 103, 115, 47, 36, 78, 44,
  49, 44, 49, 41, 125, 32, 45, 115, 112, 108, 105, 116, 95, 116, 105, 108,
  101, 115, 32, 36, 77, 44, 36, 78, 32, 45, 107, 91, 48, 45, 123, 36,
  110, 98, 95, 105, 109, 103, 115, 45, 49, 125, 93, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 114, 109, 91, 48, 93, 32, 45, 108, 91, 94, 48, 93,
  32, 45, 45, 32, 49, 50, 56, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 42, 91, 36, 62, 93, 32, 123, 97, 114, 103, 40, 36,
  62, 43, 52, 44, 36, 118, 108, 105, 115, 116, 41, 47, 49, 50, 55, 125,
  32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 108, 32, 45, 43, 32,
  45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 111, 110, 102, 97, 105, 108,
  32, 45, 101, 114, 114, 111, 114, 32, 34, 67, 97, 110, 110, 111, 116, 32,
  114, 101, 99, 111, 109, 112, 111, 115, 101, 32, 105, 109, 97, 103, 101, 44,
  32, 100, 101, 99, 111, 109, 112, 111, 115, 101, 32, 105, 116, 32, 98, 101,
  102, 111, 114, 101, 32, 116, 114, 121, 105, 110, 103, 32, 116, 111, 32, 114,
  101, 99, 111, 109, 112, 111, 115, 101, 32, 105, 116, 32, 33, 34, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 115, 101,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  60, 93, 10, 45, 45, 114, 111, 119, 115, 32, 48, 32, 118, 108, 105, 115,
  116, 61, 64, 123, 45, 49, 44, 116, 125, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 109, 97, 103, 105, 99, 107, 61, 123, 97, 114, 103, 40, 49, 44,
  36, 118, 108, 105, 115, 116, 41, 125, 32, 110, 98, 95, 105, 109, 103, 115,
  61, 123, 49, 43, 97, 114, 103, 40, 50, 44, 36, 118, 108, 105, 115, 116,
  41, 125, 32, 109, 111, 100, 101, 61, 123, 97, 114, 103, 40, 51, 44, 36,
  118, 108, 105, 115, 116, 41, 125, 10, 45, 105, 102, 32, 123, 36, 109, 97,
  103, 105, 99, 107, 33, 61, 55, 49, 55, 55, 55, 51, 54, 55, 124, 124,
  36, 110, 98, 95, 105, 109, 103, 115, 60, 50, 124, 124, 36, 109, 111, 100,
  101, 60, 48, 124, 124, 36, 109, 111, 100, 101, 62, 50, 125, 32, 45, 101,
  114, 114, 111, 114, 32, 34, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  45, 108, 10, 45, 105, 102, 32, 123, 36, 109, 111, 100, 101, 61, 61, 48,
  125, 32, 45, 115, 32, 120, 44, 36, 110, 98, 95, 105, 109, 103, 115, 32,
  45, 101, 108, 105, 102, 32, 123, 36, 109, 111, 100, 101, 61, 61, 49, 125,
  32, 45, 115, 32, 121, 44, 36, 110, 98, 95, 105, 109, 103, 115, 10, 45,
  101, 108, 115, 101, 32, 78, 61, 123, 105, 110, 116, 40, 115, 113, 114, 116,
  40, 36, 110, 98, 95, 105, 109, 103, 115, 41, 41, 125, 32, 77, 61, 123,
  114, 111, 117, 110, 100, 40, 36, 110, 98, 95, 105, 109, 103, 115, 47, 36,
  78, 44, 49, 44, 49, 41, 125, 32, 45, 115, 112, 108, 105, 116, 95, 116,
  105, 108, 101, 115, 32, 36, 77, 44, 36, 78, 32, 45, 107, 91, 48, 45,
  123, 36, 110, 98, 95, 105, 109, 103, 115, 45, 49, 125, 93, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 109, 91, 48, 93, 32, 45, 108, 91, 94,
  48, 93, 32, 45, 45, 32, 49, 50, 56, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 42, 91, 36, 62, 93, 32, 123, 97, 114, 103,
  40, 36, 62, 43, 52, 44, 36, 118, 108, 105, 115, 116, 41, 47, 49, 50,
  55, 125, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 108, 32, 45,
  43, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108,
  10, 45, 106, 91, 48, 93, 32, 91, 49, 93, 32, 45, 114, 109, 91, 49,
  93, 32, 40, 123, 39, 36, 118, 108, 105, 115, 116, 39, 125, 44, 48, 41,
  32, 45, 106, 91, 48, 93, 32, 91, 49, 93, 32, 45, 114, 109, 91, 49,
  93, 10, 45, 111, 110, 102, 97, 105, 108, 10, 45, 45, 115, 112, 108, 105,
  116, 95, 100, 101, 116, 97, 105, 108, 115, 32, 36, 50, 44, 36, 51, 44,
  36, 52, 10, 118, 108, 105, 115, 116, 61, 55, 49, 55, 55, 55, 51, 54,
  55, 44, 36, 50, 44, 36, 53, 10, 45, 108, 91, 50, 45, 45, 49, 93,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 102, 97, 99, 116,
  61, 123, 114, 111, 117, 110, 100, 40, 109, 97, 120, 40, 97, 98, 115, 40,
  105, 109, 41, 44, 97, 98, 115, 40, 105, 77, 41, 41, 44, 48, 46, 48,
  49, 41, 125, 32, 118, 108, 105, 115, 116, 61, 36, 118, 108, 105, 115, 116,
  44, 36, 102, 97, 99, 116, 32, 45, 42, 91, 36, 62, 93, 32, 123, 49,
  50, 55, 47, 36, 102, 97, 99, 116, 125, 10, 45, 100, 111, 110, 101, 32,
  45, 43, 32, 49, 50, 56, 32, 45, 101, 110, 100, 108, 32, 45, 99, 32,
  48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36, 53, 61, 61, 48,
  125, 32, 45, 97, 32, 120, 32, 45, 101, 108, 105, 102, 32, 123, 36, 53,
  61, 61, 49, 125, 32, 45, 97, 32, 121, 32, 45, 101, 108, 115, 101, 32,
  45, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 32, 44, 32,
  45, 101, 110, 100, 105, 102, 10, 40, 123, 39, 36, 118, 108, 105, 115, 116,
  39, 125, 44, 48, 41, 32, 45, 106, 91, 48, 93, 32, 91, 49, 93, 32,
  45, 114, 109, 91, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 115,
  112, 108, 105, 116, 95, 100, 101, 116, 97, 105, 108, 115, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 114, 101, 109, 111, 118, 101, 95, 111,
  112, 97, 99, 105, 116, 121, 10, 45, 105, 102, 32, 36, 49, 32, 45, 103,
  105, 109, 112, 95, 110, 111, 95, 112, 114, 101, 118, 105, 101, 119, 32, 44,
  10, 45, 101, 108, 115, 101, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 115, 112, 108, 105, 116,
  95, 100, 101, 116, 97, 105, 108, 115, 32, 36, 50, 44, 36, 51, 44, 36,
  52, 32, 45, 110, 91, 50, 45, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  10, 45, 105, 102, 32, 123, 36, 54, 61, 61, 48, 125, 32, 45, 107, 91,
  49, 93, 32, 45, 101, 108, 105, 102, 32, 123, 36, 54, 61, 61, 49, 125,
  32, 45, 107, 91, 50, 45, 45, 49, 93, 32, 45, 97, 112, 112, 101, 110,
  100, 95, 116, 105, 108, 101, 115, 32, 44, 32, 45, 101, 108, 105, 102, 32,
  123, 36, 54, 61, 61, 50, 125, 32, 45, 107, 91, 45, 49, 93, 32, 45,
  101, 108, 115, 101, 32, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108,
  101, 115, 32, 44, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 10, 35,
  64, 103, 105, 109, 112, 32, 83, 112, 111, 116, 105, 102, 121, 32, 58, 32,
  106, 101, 106, 101, 95, 115, 112, 111, 116, 105, 102, 121, 44, 106, 101, 106,
  101, 95, 115, 112, 111, 116, 105, 102, 121, 95, 112, 114, 101, 118, 105, 101,
  119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 97, 108, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 46, 55, 53, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101,
  114, 97, 116, 105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 49, 44, 48,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117,
  116, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 51, 44, 34, 65, 108, 108, 34,
  44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76,
  117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47,
  114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115,
  34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105,
  110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115,
  115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34,
  72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110,
  34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44,
  34, 65, 108, 112, 104, 97, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110,
  34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 74, 38, 35, 50, 51, 51,
  59, 114, 38, 35, 50, 52, 52, 59, 109, 101, 32, 66, 111, 117, 108, 97,
  110, 103, 101, 114, 60, 47, 105, 62, 46, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51,
  47, 49, 50, 47, 49, 54, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 106, 101, 106, 101, 95, 115, 112, 111, 116, 105, 102,
  121, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101,
  108, 115, 32, 34, 45, 115, 112, 111, 116, 105, 102, 121, 32, 36, 49, 44,
  36, 50, 32, 45, 105, 102, 32, 36, 51, 32, 45, 99, 32, 48, 44, 50,
  53, 53, 32, 45, 101, 108, 115, 101, 32, 45, 110, 32, 48, 44, 50, 53,
  53, 32, 45, 101, 110, 100, 105, 102, 34, 44, 36, 52, 44, 48, 10, 106,
  101, 106, 101, 95, 115, 112, 111, 116, 105, 102, 121, 95, 112, 114, 101, 118,
  105, 101, 119, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 106, 101, 106, 101, 95,
  115, 112, 111, 116, 105, 102, 121, 32, 36, 49, 44, 36, 50, 44, 36, 51,
  44, 36, 52, 34, 44, 36, 53, 10, 35, 64, 103, 105, 109, 112, 32, 84,
  101, 120, 116, 117, 114, 101, 32, 101, 110, 104, 97, 110, 99, 101, 32, 58,
  32, 105, 97, 105, 110, 95, 116, 101, 120, 116, 117, 114, 101, 95, 101, 110,
  104, 97, 110, 99, 101, 44, 32, 105, 97, 105, 110, 95, 116, 101, 120, 116,
  117, 114, 101, 95, 101, 110, 104, 97, 110, 99, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  82, 97, 100, 105, 117, 115, 32, 61, 32, 105, 110, 116, 32, 40, 50, 44,
  50, 44, 49, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  116, 114, 101, 110, 103, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 32,
  40, 50, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 82, 101, 100, 117, 99, 101, 32, 104, 97, 108, 111, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 32, 40, 51, 48, 44, 48, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 100, 117, 99,
  101, 32, 110, 111, 105, 115, 101, 32, 61, 32, 102, 108, 111, 97, 116, 32,
  40, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 51, 44, 34, 65, 108, 108, 34, 44, 34,
  82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101,
  100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44,
  34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34,
  44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34,
  44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34,
  98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117,
  101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44,
  34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 65,
  108, 112, 104, 97, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44,
  34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 73, 97, 105,
  110, 32, 70, 101, 114, 103, 117, 115, 115, 111, 110, 60, 47, 105, 62, 46,
  32, 85, 112, 100, 97, 116, 101, 58, 32, 52, 32, 77, 97, 114, 99, 104,
  32, 50, 48, 49, 51, 32, 45, 32, 68, 105, 102, 102, 101, 114, 101, 110,
  116, 32, 104, 97, 108, 111, 32, 112, 114, 111, 116, 101, 99, 116, 105, 111,
  110, 32, 109, 101, 116, 104, 111, 100, 44, 32, 97, 100, 100, 101, 100, 32,
  111, 112, 116, 105, 111, 110, 32, 116, 111, 32, 114, 101, 100, 117, 99, 101,
  32, 110, 111, 105, 115, 101, 44, 32, 102, 97, 115, 116, 101, 114, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 105, 97, 105, 110, 95, 116,
  101, 120, 116, 117, 114, 101, 95, 101, 110, 104, 97, 110, 99, 101, 58, 10,
  45, 116, 105, 99, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 32, 34, 10, 45, 105, 102, 32, 123, 36, 49, 37, 50,
  33, 61, 48, 125, 10, 45, 45, 101, 114, 111, 100, 101, 95, 99, 105, 114,
  99, 91, 48, 93, 32, 36, 49, 32, 32, 45, 100, 105, 108, 97, 116, 101,
  95, 99, 105, 114, 99, 91, 45, 49, 93, 32, 36, 49, 10, 45, 45, 100,
  105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 91, 48, 93, 32, 36, 49,
  32, 32, 45, 101, 114, 111, 100, 101, 95, 99, 105, 114, 99, 91, 45, 49,
  93, 32, 36, 49, 10, 45, 101, 108, 115, 101, 10, 45, 45, 101, 114, 111,
  100, 101, 95, 111, 99, 116, 91, 48, 93, 32, 36, 49, 32, 32, 45, 100,
  105, 108, 97, 116, 101, 95, 111, 99, 116, 91, 45, 49, 93, 32, 36, 49,
  10, 45, 45, 100, 105, 108, 97, 116, 101, 95, 111, 99, 116, 91, 48, 93,
  32, 36, 49, 32, 32, 45, 101, 114, 111, 100, 101, 95, 111, 99, 116, 91,
  45, 49, 93, 32, 36, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 115,
  117, 98, 91, 49, 93, 32, 91, 48, 93, 10, 45, 115, 117, 98, 91, 50,
  93, 32, 91, 48, 93, 10, 45, 97, 100, 100, 91, 49, 93, 32, 91, 50,
  93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 50, 93, 10, 45, 109, 117,
  108, 91, 49, 93, 32, 36, 50, 10, 45, 45, 97, 98, 115, 91, 49, 93,
  10, 112, 116, 49, 61, 123, 109, 105, 110, 40, 48, 44, 40, 36, 52, 45,
  49, 48, 41, 41, 125, 10, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114,
  118, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 36, 112, 116,
  49, 44, 48, 44, 123, 36, 52, 43, 49, 125, 44, 49, 44, 50, 53, 53,
  44, 49, 10, 40, 48, 46, 48, 53, 55, 57, 55, 49, 48, 49, 52, 53,
  44, 48, 46, 49, 51, 48, 52, 51, 52, 55, 56, 50, 54, 44, 48, 46,
  48, 53, 55, 57, 55, 49, 48, 49, 52, 53, 59, 48, 46, 49, 51, 48,
  52, 51, 52, 55, 56, 50, 54, 44, 48, 46, 50, 52, 54, 51, 55, 54,
  56, 49, 49, 54, 44, 48, 46, 49, 51, 48, 52, 51, 52, 55, 56, 50,
  54, 59, 48, 46, 48, 53, 55, 57, 55, 49, 48, 49, 52, 53, 44, 48,
  46, 49, 51, 48, 52, 51, 52, 55, 56, 50, 54, 44, 48, 46, 48, 53,
  55, 57, 55, 49, 48, 49, 52, 53, 41, 10, 45, 99, 111, 110, 118, 111,
  108, 118, 101, 91, 45, 50, 93, 32, 91, 45, 49, 93, 10, 45, 114, 101,
  109, 111, 118, 101, 91, 45, 49, 93, 10, 45, 109, 117, 108, 91, 49, 93,
  32, 91, 50, 93, 10, 45, 99, 91, 49, 93, 32, 123, 36, 51, 42, 45,
  49, 125, 44, 36, 51, 10, 45, 115, 117, 98, 91, 48, 93, 32, 91, 49,
  93, 10, 45, 107, 101, 101, 112, 91, 48, 93, 10, 34, 44, 36, 53, 10,
  45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 116, 111, 99, 10, 105, 97,
  105, 110, 95, 116, 101, 120, 116, 117, 114, 101, 95, 101, 110, 104, 97, 110,
  99, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 105, 97, 105, 110, 95, 116, 101, 120, 116, 117, 114, 101, 95,
  101, 110, 104, 97, 110, 99, 101, 32, 36, 123, 49, 45, 45, 50, 125, 34,
  44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 84, 111, 110, 101,
  32, 109, 97, 112, 112, 105, 110, 103, 32, 58, 32, 103, 105, 109, 112, 95,
  109, 97, 112, 95, 116, 111, 110, 101, 115, 44, 32, 103, 105, 109, 112, 95,
  109, 97, 112, 95, 116, 111, 110, 101, 115, 95, 112, 114, 101, 118, 105, 101,
  119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104,
  114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 71, 97, 109, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 55, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 49, 44, 48, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101, 114, 97, 116, 105, 111,
  110, 115, 32, 61, 32, 105, 110, 116, 40, 51, 48, 44, 48, 44, 53, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110,
  110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  51, 44, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34,
  82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34,
  44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100,
  32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76,
  105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116,
  117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34,
  44, 34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105,
  99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 109, 97, 112,
  95, 116, 111, 110, 101, 115, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 109, 97, 112, 95, 116,
  111, 110, 101, 115, 32, 36, 123, 49, 45, 52, 125, 34, 44, 36, 53, 44,
  48, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10, 103, 105, 109, 112, 95,
  109, 97, 112, 95, 116, 111, 110, 101, 115, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 109,
  97, 112, 95, 116, 111, 110, 101, 115, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 84, 111, 110, 101, 32, 109, 97, 112,
  112, 105, 110, 103, 32, 91, 102, 97, 115, 116, 93, 32, 58, 32, 103, 105,
  109, 112, 95, 109, 97, 112, 95, 116, 111, 110, 101, 115, 95, 102, 97, 115,
  116, 44, 32, 103, 105, 109, 112, 95, 109, 97, 112, 95, 116, 111, 110, 101,
  115, 95, 102, 97, 115, 116, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 100, 105, 117,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44, 48, 44, 50, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 111, 119, 101, 114,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110,
  101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 51,
  44, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82,
  71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105,
  110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32,
  99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105,
  103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117,
  114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44,
  34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114,
  111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101,
  101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104,
  97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 115, 58, 32, 60, 105, 62, 80, 97, 117, 108, 32, 78, 97, 115,
  99, 97, 60, 47, 105, 62, 32, 97, 110, 100, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 49, 47, 48, 54, 47, 49, 48, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  109, 97, 112, 95, 116, 111, 110, 101, 115, 95, 102, 97, 115, 116, 32, 58,
  10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 34, 45, 109, 97, 112, 95, 116, 111, 110, 101, 115, 95, 102, 97, 115,
  116, 32, 36, 49, 44, 36, 50, 34, 44, 36, 51, 44, 48, 10, 103, 105,
  109, 112, 95, 109, 97, 112, 95, 116, 111, 110, 101, 115, 95, 102, 97, 115,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 109, 97, 112, 95, 116, 111, 110, 101, 115,
  95, 102, 97, 115, 116, 32, 36, 123, 94, 48, 125, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 89, 97, 103, 32, 101, 102, 102, 101,
  99, 116, 32, 58, 32, 103, 105, 109, 112, 95, 121, 97, 103, 95, 115, 111,
  102, 116, 101, 110, 44, 32, 103, 105, 109, 112, 95, 121, 97, 103, 95, 115,
  111, 102, 116, 101, 110, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 97, 114, 107, 101, 110,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 111, 102, 116, 101,
  110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80,
  114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 48, 44, 34, 70, 117, 108, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 65, 114, 116,
  111, 32, 72, 117, 111, 116, 97, 114, 105, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 57, 47, 50,
  56, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 108, 105, 110, 107, 40, 34, 70, 105, 108, 116, 101, 114, 32, 69, 120,
  112, 108, 97, 105, 110, 101, 100, 32, 104, 101, 114, 101, 34, 44, 34, 104,
  116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 102, 108, 105, 99, 107, 114,
  46, 99, 111, 109, 47, 112, 104, 111, 116, 111, 115, 47, 110, 97, 103, 103,
  111, 98, 111, 116, 47, 54, 50, 54, 48, 50, 53, 55, 57, 50, 51, 47,
  34, 41, 10, 103, 105, 109, 112, 95, 121, 97, 103, 95, 115, 111, 102, 116,
  101, 110, 32, 58, 10, 68, 97, 114, 107, 101, 110, 61, 36, 49, 10, 83,
  111, 102, 116, 101, 110, 61, 36, 50, 10, 45, 45, 103, 105, 109, 112, 95,
  108, 97, 112, 108, 97, 99, 105, 97, 110, 91, 48, 93, 32, 48, 44, 48,
  44, 49, 48, 48, 44, 48, 44, 48, 44, 48, 10, 45, 105, 102, 32, 123,
  36, 83, 111, 102, 116, 101, 110, 62, 48, 125, 10, 45, 103, 105, 109, 112,
  95, 103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 49,
  93, 32, 123, 36, 83, 111, 102, 116, 101, 110, 47, 49, 48, 125, 44, 48,
  44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 45, 103, 105, 109, 112, 95, 109, 105, 120, 95, 108, 97, 98,
  91, 48, 93, 32, 48, 46, 53, 44, 53, 48, 44, 48, 46, 50, 44, 49,
  44, 50, 44, 49, 44, 49, 44, 50, 44, 49, 44, 48, 44, 49, 48, 44,
  48, 10, 45, 105, 102, 32, 123, 36, 68, 97, 114, 107, 101, 110, 62, 48,
  125, 10, 45, 45, 98, 108, 101, 110, 100, 91, 48, 44, 50, 93, 32, 115,
  111, 102, 116, 108, 105, 103, 104, 116, 10, 45, 98, 108, 101, 110, 100, 91,
  48, 44, 51, 93, 32, 109, 117, 108, 116, 105, 112, 108, 121, 44, 123, 36,
  68, 97, 114, 107, 101, 110, 47, 49, 48, 48, 125, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 98, 108, 101, 110, 100, 91, 48, 44, 50, 93, 32, 104,
  97, 114, 100, 108, 105, 103, 104, 116, 10, 45, 105, 102, 32, 123, 36, 83,
  111, 102, 116, 101, 110, 33, 61, 49, 48, 48, 125, 10, 45, 98, 108, 101,
  110, 100, 91, 48, 44, 49, 93, 32, 103, 114, 97, 105, 110, 101, 120, 116,
  114, 97, 99, 116, 10, 45, 101, 108, 105, 102, 32, 123, 36, 83, 111, 102,
  116, 101, 110, 61, 61, 49, 48, 48, 125, 10, 45, 114, 101, 109, 111, 118,
  101, 91, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112,
  95, 121, 97, 103, 95, 115, 111, 102, 116, 101, 110, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112,
  95, 121, 97, 103, 95, 115, 111, 102, 116, 101, 110, 32, 36, 123, 49, 45,
  45, 50, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32,
  95, 10, 35, 64, 103, 105, 109, 112, 32, 60, 98, 62, 70, 105, 108, 109,
  32, 101, 109, 117, 108, 97, 116, 105, 111, 110, 60, 47, 98, 62, 10, 35,
  64, 103, 105, 109, 112, 32, 66, 38, 97, 109, 112, 59, 87, 32, 102, 105,
  108, 109, 115, 32, 58, 32, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97,
  116, 101, 95, 102, 105, 108, 109, 95, 98, 119, 44, 32, 103, 105, 109, 112,
  95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 98, 119,
  95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 80, 114, 101, 115, 101, 116, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 123, 34, 78, 111, 110, 101, 34, 44, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 34, 65, 103, 102, 97, 32, 65, 80, 88, 32,
  49, 48, 48, 34, 44, 34, 65, 103, 102, 97, 32, 65, 80, 88, 32, 50,
  53, 34, 44, 34, 70, 117, 106, 105, 32, 78, 101, 111, 112, 97, 110, 32,
  49, 54, 48, 48, 34, 44, 34, 70, 117, 106, 105, 32, 78, 101, 111, 112,
  97, 110, 32, 65, 99, 114, 111, 115, 32, 49, 48, 48, 34, 44, 34, 73,
  108, 102, 111, 114, 100, 32, 68, 101, 108, 116, 97, 32, 49, 48, 48, 34,
  44, 34, 73, 108, 102, 111, 114, 100, 32, 68, 101, 108, 116, 97, 32, 51,
  50, 48, 48, 34, 44, 34, 73, 108, 102, 111, 114, 100, 32, 68, 101, 108,
  116, 97, 32, 52, 48, 48, 34, 44, 34, 73, 108, 102, 111, 114, 100, 32,
  70, 80, 52, 32, 80, 108, 117, 115, 32, 49, 50, 53, 34, 44, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 34, 73, 108, 102, 111, 114, 100, 32,
  72, 80, 53, 32, 80, 108, 117, 115, 32, 52, 48, 48, 34, 44, 34, 73,
  108, 102, 111, 114, 100, 32, 72, 80, 83, 32, 56, 48, 48, 34, 44, 34,
  73, 108, 102, 111, 114, 100, 32, 80, 97, 110, 32, 70, 32, 80, 108, 117,
  115, 32, 53, 48, 34, 44, 34, 73, 108, 102, 111, 114, 100, 32, 88, 80,
  50, 34, 44, 34, 75, 111, 100, 97, 107, 32, 66, 87, 32, 52, 48, 48,
  32, 67, 78, 34, 44, 34, 75, 111, 100, 97, 107, 32, 72, 73, 69, 32,
  40, 72, 83, 32, 73, 110, 102, 114, 97, 41, 34, 44, 34, 75, 111, 100,
  97, 107, 32, 84, 45, 77, 97, 120, 32, 49, 48, 48, 34, 44, 34, 75,
  111, 100, 97, 107, 32, 84, 45, 77, 97, 120, 32, 51, 50, 48, 48, 34,
  44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 75, 111, 100, 97,
  107, 32, 84, 45, 77, 97, 120, 32, 52, 48, 48, 34, 44, 34, 75, 111,
  100, 97, 107, 32, 84, 114, 105, 45, 88, 32, 52, 48, 48, 34, 44, 34,
  80, 111, 108, 97, 114, 111, 105, 100, 32, 54, 54, 52, 34, 44, 34, 80,
  111, 108, 97, 114, 111, 105, 100, 32, 54, 54, 55, 34, 44, 34, 80, 111,
  108, 97, 114, 111, 105, 100, 32, 54, 55, 50, 34, 44, 34, 82, 111, 108,
  108, 101, 105, 32, 73, 82, 32, 52, 48, 48, 34, 44, 34, 82, 111, 108,
  108, 101, 105, 32, 79, 114, 116, 104, 111, 32, 50, 53, 34, 44, 34, 82,
  111, 108, 108, 101, 105, 32, 82, 101, 116, 114, 111, 32, 49, 48, 48, 32,
  84, 111, 110, 97, 108, 34, 44, 34, 82, 111, 108, 108, 101, 105, 32, 82,
  101, 116, 114, 111, 32, 56, 48, 115, 34, 125, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71,
  97, 109, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45,
  49, 46, 50, 44, 49, 46, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 66, 114, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 117, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 56, 48, 44, 49, 56,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 97, 116, 117,
  114, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80,
  111, 115, 116, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 32, 61, 32,
  98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105,
  99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 115, 58, 32, 60, 105, 62, 80, 97, 116, 114,
  105, 99, 107, 32, 68, 97, 118, 105, 100, 60, 47, 105, 62, 32, 97, 110,
  100, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 56, 47,
  50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102,
  105, 108, 109, 95, 98, 119, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95,
  101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 32, 36, 49, 44,
  64, 123, 45, 97, 114, 103, 92, 32, 36, 49, 44, 64, 123, 45, 95, 36,
  48, 125, 125, 44, 36, 123, 50, 45, 45, 49, 125, 10, 95, 103, 105, 109,
  112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 98,
  119, 32, 58, 10, 45, 117, 32, 97, 103, 102, 97, 95, 97, 112, 120, 95,
  49, 48, 48, 44, 97, 103, 102, 97, 95, 97, 112, 120, 95, 50, 53, 44,
  102, 117, 106, 105, 95, 110, 101, 111, 112, 97, 110, 95, 49, 54, 48, 48,
  44, 102, 117, 106, 105, 95, 110, 101, 111, 112, 97, 110, 95, 97, 99, 114,
  111, 115, 95, 49, 48, 48, 44, 105, 108, 102, 111, 114, 100, 95, 100, 101,
  108, 116, 97, 95, 49, 48, 48, 44, 105, 108, 102, 111, 114, 100, 95, 100,
  101, 108, 116, 97, 95, 51, 50, 48, 48, 44, 105, 108, 102, 111, 114, 100,
  95, 100, 101, 108, 116, 97, 95, 52, 48, 48, 44, 105, 108, 102, 111, 114,
  100, 95, 102, 112, 52, 95, 112, 108, 117, 115, 95, 49, 50, 53, 44, 92,
  10, 105, 108, 102, 111, 114, 100, 95, 104, 112, 53, 95, 112, 108, 117, 115,
  95, 52, 48, 48, 44, 105, 108, 102, 111, 114, 100, 95, 104, 112, 115, 95,
  56, 48, 48, 44, 105, 108, 102, 111, 114, 100, 95, 112, 97, 110, 95, 102,
  95, 112, 108, 117, 115, 95, 53, 48, 44, 105, 108, 102, 111, 114, 100, 95,
  120, 112, 50, 44, 107, 111, 100, 97, 107, 95, 98, 119, 95, 52, 48, 48,
  95, 99, 110, 44, 107, 111, 100, 97, 107, 95, 104, 105, 101, 95, 40, 104,
  115, 95, 105, 110, 102, 114, 97, 41, 44, 107, 111, 100, 97, 107, 95, 116,
  45, 109, 97, 120, 95, 49, 48, 48, 44, 107, 111, 100, 97, 107, 95, 116,
  45, 109, 97, 120, 95, 51, 50, 48, 48, 44, 92, 10, 107, 111, 100, 97,
  107, 95, 116, 45, 109, 97, 120, 95, 52, 48, 48, 44, 107, 111, 100, 97,
  107, 95, 116, 114, 105, 45, 120, 95, 52, 48, 48, 44, 112, 111, 108, 97,
  114, 111, 105, 100, 95, 54, 54, 52, 44, 112, 111, 108, 97, 114, 111, 105,
  100, 95, 54, 54, 55, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 54,
  55, 50, 44, 114, 111, 108, 108, 101, 105, 95, 105, 114, 95, 52, 48, 48,
  44, 114, 111, 108, 108, 101, 105, 95, 111, 114, 116, 104, 111, 95, 50, 53,
  44, 114, 111, 108, 108, 101, 105, 95, 114, 101, 116, 114, 111, 95, 49, 48,
  48, 95, 116, 111, 110, 97, 108, 44, 114, 111, 108, 108, 101, 105, 95, 114,
  101, 116, 114, 111, 95, 56, 48, 115, 10, 103, 105, 109, 112, 95, 101, 109,
  117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 98, 119, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112,
  108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105,
  109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95,
  98, 119, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 71, 114, 97, 105, 110, 32, 58, 32, 103, 105, 109, 112, 95, 103,
  114, 97, 105, 110, 44, 32, 103, 105, 109, 112, 95, 103, 114, 97, 105, 110,
  95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 52, 48, 44, 48, 44, 53, 49, 50, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 111, 110, 101, 32, 115,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 53, 44, 48, 44, 49, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 71, 114, 97, 105, 110, 32, 116, 121, 112, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 71, 97, 117, 115, 115, 105, 97, 110,
  34, 44, 34, 85, 110, 105, 102, 111, 114, 109, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 50, 44, 34, 65, 108, 108,
  34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34,
  76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101,
  47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101,
  115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111,
  110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34,
  44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34,
  66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 83, 104, 97, 100, 111, 119,
  115, 58, 60, 47, 98, 62, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 116, 114, 101, 110, 103,
  116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 56, 44, 48,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 97,
  108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48,
  44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97,
  110, 110, 101, 108, 32, 99, 111, 114, 114, 101, 108, 97, 116, 105, 111, 110,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 77, 105, 100,
  45, 116, 111, 110, 101, 115, 58, 60, 47, 98, 62, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  116, 114, 101, 110, 103, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 99, 97, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104,
  97, 110, 110, 101, 108, 32, 99, 111, 114, 114, 101, 108, 97, 116, 105, 111,
  110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 72, 105,
  103, 104, 108, 105, 103, 104, 116, 115, 58, 60, 47, 98, 62, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 116, 114, 101, 110, 103, 116, 104, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 54, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 50, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 32, 99, 111, 114, 114,
  101, 108, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108,
  105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 51, 47, 49, 49, 47, 50, 49, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 103, 114,
  97, 105, 110, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 45, 97, 112, 112, 108, 121, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 95, 103, 105, 109, 112, 95,
  103, 114, 97, 105, 110, 32, 36, 123, 49, 45, 49, 51, 125, 34, 44, 36,
  52, 44, 48, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  95, 103, 105, 109, 112, 95, 103, 114, 97, 105, 110, 32, 58, 10, 45, 105,
  102, 32, 123, 33, 36, 49, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32,
  45, 101, 110, 100, 105, 102, 10, 115, 61, 123, 115, 125, 32, 45, 45, 108,
  117, 109, 105, 110, 97, 110, 99, 101, 10, 45, 105, 102, 32, 36, 53, 10,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 36, 115, 32, 45,
  110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 49, 44, 36, 51, 32, 45,
  98, 91, 45, 49, 93, 32, 36, 54, 32, 45, 42, 91, 45, 49, 93, 32,
  123, 40, 49, 45, 36, 55, 41, 47, 109, 97, 120, 40, 97, 98, 115, 40,
  105, 109, 41, 44, 97, 98, 115, 40, 105, 77, 41, 41, 125, 10, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 32, 45, 110, 111, 105,
  115, 101, 91, 45, 49, 93, 32, 49, 44, 36, 51, 32, 45, 98, 91, 45,
  49, 93, 32, 36, 54, 32, 45, 42, 91, 45, 49, 93, 32, 123, 36, 55,
  47, 109, 97, 120, 40, 97, 98, 115, 40, 105, 109, 41, 44, 97, 98, 115,
  40, 105, 77, 41, 41, 125, 10, 45, 43, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 45, 116, 50, 91, 49, 93, 32, 48, 44, 56, 53, 32, 45, 98,
  91, 45, 49, 93, 32, 36, 50, 32, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 49, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 42, 91,
  45, 49, 93, 32, 36, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 36, 56, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 36, 115, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 49,
  44, 36, 51, 32, 45, 98, 91, 45, 49, 93, 32, 36, 57, 32, 45, 42,
  91, 45, 49, 93, 32, 123, 40, 49, 45, 36, 49, 48, 41, 47, 109, 97,
  120, 40, 97, 98, 115, 40, 105, 109, 41, 44, 97, 98, 115, 40, 105, 77,
  41, 41, 125, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44,
  49, 32, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 49, 44, 36,
  51, 32, 45, 98, 91, 45, 49, 93, 32, 36, 57, 32, 45, 42, 91, 45,
  49, 93, 32, 123, 36, 49, 48, 47, 109, 97, 120, 40, 97, 98, 115, 40,
  105, 109, 41, 44, 97, 98, 115, 40, 105, 77, 41, 41, 125, 10, 45, 43,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 45, 116, 50, 91, 49, 93, 32,
  56, 54, 44, 49, 54, 57, 32, 45, 98, 91, 45, 49, 93, 32, 36, 50,
  32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 42, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 36, 56, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 49, 49, 10, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 36, 115, 32, 45, 110,
  111, 105, 115, 101, 91, 45, 49, 93, 32, 49, 44, 36, 51, 32, 45, 98,
  91, 45, 49, 93, 32, 36, 49, 50, 32, 45, 42, 91, 45, 49, 93, 32,
  123, 40, 49, 45, 36, 49, 51, 41, 47, 109, 97, 120, 40, 97, 98, 115,
  40, 105, 109, 41, 44, 97, 98, 115, 40, 105, 77, 41, 41, 125, 10, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 32, 45, 110, 111,
  105, 115, 101, 91, 45, 49, 93, 32, 49, 44, 36, 51, 32, 45, 98, 91,
  45, 49, 93, 32, 36, 49, 50, 32, 45, 42, 91, 45, 49, 93, 32, 123,
  36, 49, 51, 47, 109, 97, 120, 40, 97, 98, 115, 40, 105, 109, 41, 44,
  97, 98, 115, 40, 105, 77, 41, 41, 125, 10, 45, 43, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 45, 116, 50, 91, 49, 93, 32, 49, 55, 48, 44,
  50, 53, 54, 32, 45, 98, 91, 45, 49, 93, 32, 36, 50, 32, 45, 110,
  91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 42, 91, 45, 50, 44, 45,
  49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 36, 49, 49, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 109, 91, 49, 93, 32, 45, 43, 91, 45,
  51, 45, 45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 45, 36, 49,
  44, 36, 49, 32, 45, 43, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10,
  103, 105, 109, 112, 95, 103, 114, 97, 105, 110, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95,
  103, 114, 97, 105, 110, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64,
  103, 105, 109, 112, 32, 73, 110, 115, 116, 97, 110, 116, 32, 91, 99, 111,
  110, 115, 117, 109, 101, 114, 93, 32, 58, 32, 103, 105, 109, 112, 95, 101,
  109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 105, 110, 115, 116,
  97, 110, 116, 95, 99, 111, 110, 115, 117, 109, 101, 114, 44, 32, 103, 105,
  109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95,
  105, 110, 115, 116, 97, 110, 116, 95, 99, 111, 110, 115, 117, 109, 101, 114,
  95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 80, 114, 101, 115, 101, 116, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 123, 34, 78, 111, 110, 101, 34, 44, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32,
  80, 88, 45, 49, 48, 48, 85, 86, 43, 32, 67, 111, 108, 100, 32, 45,
  45, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 80, 88, 45,
  49, 48, 48, 85, 86, 43, 32, 67, 111, 108, 100, 32, 45, 34, 44, 34,
  80, 111, 108, 97, 114, 111, 105, 100, 32, 80, 88, 45, 49, 48, 48, 85,
  86, 43, 32, 67, 111, 108, 100, 34, 44, 34, 80, 111, 108, 97, 114, 111,
  105, 100, 32, 80, 88, 45, 49, 48, 48, 85, 86, 43, 32, 67, 111, 108,
  100, 32, 43, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 80,
  88, 45, 49, 48, 48, 85, 86, 43, 32, 67, 111, 108, 100, 32, 43, 43,
  34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 80, 88, 45, 49,
  48, 48, 85, 86, 43, 32, 67, 111, 108, 100, 32, 43, 43, 43, 34, 44,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 80, 111, 108, 97, 114,
  111, 105, 100, 32, 80, 88, 45, 49, 48, 48, 85, 86, 43, 32, 87, 97,
  114, 109, 32, 45, 45, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100,
  32, 80, 88, 45, 49, 48, 48, 85, 86, 43, 32, 87, 97, 114, 109, 32,
  45, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 80, 88, 45,
  49, 48, 48, 85, 86, 43, 32, 87, 97, 114, 109, 34, 44, 34, 80, 111,
  108, 97, 114, 111, 105, 100, 32, 80, 88, 45, 49, 48, 48, 85, 86, 43,
  32, 87, 97, 114, 109, 32, 43, 34, 44, 34, 80, 111, 108, 97, 114, 111,
  105, 100, 32, 80, 88, 45, 49, 48, 48, 85, 86, 43, 32, 87, 97, 114,
  109, 32, 43, 43, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32,
  80, 88, 45, 49, 48, 48, 85, 86, 43, 32, 87, 97, 114, 109, 32, 43,
  43, 43, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 80,
  111, 108, 97, 114, 111, 105, 100, 32, 80, 88, 45, 54, 56, 48, 32, 45,
  45, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 80, 88, 45,
  54, 56, 48, 32, 45, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100,
  32, 80, 88, 45, 54, 56, 48, 34, 44, 34, 80, 111, 108, 97, 114, 111,
  105, 100, 32, 80, 88, 45, 54, 56, 48, 32, 43, 34, 44, 34, 80, 111,
  108, 97, 114, 111, 105, 100, 32, 80, 88, 45, 54, 56, 48, 32, 43, 43,
  34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 80, 111, 108,
  97, 114, 111, 105, 100, 32, 80, 88, 45, 54, 56, 48, 32, 67, 111, 108,
  100, 32, 45, 45, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32,
  80, 88, 45, 54, 56, 48, 32, 67, 111, 108, 100, 32, 45, 34, 44, 34,
  80, 111, 108, 97, 114, 111, 105, 100, 32, 80, 88, 45, 54, 56, 48, 32,
  67, 111, 108, 100, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32,
  80, 88, 45, 54, 56, 48, 32, 67, 111, 108, 100, 32, 43, 34, 44, 34,
  80, 111, 108, 97, 114, 111, 105, 100, 32, 80, 88, 45, 54, 56, 48, 32,
  67, 111, 108, 100, 32, 43, 43, 34, 44, 34, 80, 111, 108, 97, 114, 111,
  105, 100, 32, 80, 88, 45, 54, 56, 48, 32, 67, 111, 108, 100, 32, 43,
  43, 97, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 80,
  111, 108, 97, 114, 111, 105, 100, 32, 80, 88, 45, 54, 56, 48, 32, 87,
  97, 114, 109, 32, 45, 45, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105,
  100, 32, 80, 88, 45, 54, 56, 48, 32, 87, 97, 114, 109, 32, 45, 34,
  44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 80, 88, 45, 54, 56,
  48, 32, 87, 97, 114, 109, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105,
  100, 32, 80, 88, 45, 54, 56, 48, 32, 87, 97, 114, 109, 32, 43, 34,
  44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 80, 88, 45, 54, 56,
  48, 32, 87, 97, 114, 109, 32, 43, 43, 34, 44, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 80,
  88, 45, 55, 48, 32, 45, 45, 34, 44, 34, 80, 111, 108, 97, 114, 111,
  105, 100, 32, 80, 88, 45, 55, 48, 32, 45, 34, 44, 34, 80, 111, 108,
  97, 114, 111, 105, 100, 32, 80, 88, 45, 55, 48, 34, 44, 34, 80, 111,
  108, 97, 114, 111, 105, 100, 32, 80, 88, 45, 55, 48, 32, 43, 34, 44,
  34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 80, 88, 45, 55, 48, 32,
  43, 43, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 80, 88,
  45, 55, 48, 32, 43, 43, 43, 34, 44, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 80, 88, 45,
  55, 48, 32, 67, 111, 108, 100, 32, 45, 45, 34, 44, 34, 80, 111, 108,
  97, 114, 111, 105, 100, 32, 80, 88, 45, 55, 48, 32, 67, 111, 108, 100,
  32, 45, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 80, 88,
  45, 55, 48, 32, 67, 111, 108, 100, 34, 44, 34, 80, 111, 108, 97, 114,
  111, 105, 100, 32, 80, 88, 45, 55, 48, 32, 67, 111, 108, 100, 32, 43,
  34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 80, 88, 45, 55,
  48, 32, 67, 111, 108, 100, 32, 43, 43, 34, 44, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 80,
  88, 45, 55, 48, 32, 87, 97, 114, 109, 32, 45, 45, 34, 44, 34, 80,
  111, 108, 97, 114, 111, 105, 100, 32, 80, 88, 45, 55, 48, 32, 87, 97,
  114, 109, 32, 45, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32,
  80, 88, 45, 55, 48, 32, 87, 97, 114, 109, 34, 44, 34, 80, 111, 108,
  97, 114, 111, 105, 100, 32, 80, 88, 45, 55, 48, 32, 87, 97, 114, 109,
  32, 43, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 80, 88,
  45, 55, 48, 32, 87, 97, 114, 109, 32, 43, 43, 34, 44, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 34, 80, 111, 108, 97, 114, 111, 105, 100,
  32, 84, 105, 109, 101, 32, 90, 101, 114, 111, 32, 40, 69, 120, 112, 105,
  114, 101, 100, 41, 32, 45, 45, 45, 34, 44, 34, 80, 111, 108, 97, 114,
  111, 105, 100, 32, 84, 105, 109, 101, 32, 90, 101, 114, 111, 32, 40, 69,
  120, 112, 105, 114, 101, 100, 41, 32, 45, 45, 34, 44, 34, 80, 111, 108,
  97, 114, 111, 105, 100, 32, 84, 105, 109, 101, 32, 90, 101, 114, 111, 32,
  40, 69, 120, 112, 105, 114, 101, 100, 41, 32, 45, 34, 44, 34, 80, 111,
  108, 97, 114, 111, 105, 100, 32, 84, 105, 109, 101, 32, 90, 101, 114, 111,
  32, 40, 69, 120, 112, 105, 114, 101, 100, 41, 34, 44, 34, 80, 111, 108,
  97, 114, 111, 105, 100, 32, 84, 105, 109, 101, 32, 90, 101, 114, 111, 32,
  40, 69, 120, 112, 105, 114, 101, 100, 41, 32, 43, 34, 44, 34, 80, 111,
  108, 97, 114, 111, 105, 100, 32, 84, 105, 109, 101, 32, 90, 101, 114, 111,
  32, 40, 69, 120, 112, 105, 114, 101, 100, 41, 32, 43, 43, 34, 44, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 80, 111, 108, 97, 114, 111,
  105, 100, 32, 84, 105, 109, 101, 32, 90, 101, 114, 111, 32, 40, 69, 120,
  112, 105, 114, 101, 100, 41, 32, 67, 111, 108, 100, 32, 45, 45, 45, 34,
  44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 84, 105, 109, 101, 32,
  90, 101, 114, 111, 32, 40, 69, 120, 112, 105, 114, 101, 100, 41, 32, 67,
  111, 108, 100, 32, 45, 45, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105,
  100, 32, 84, 105, 109, 101, 32, 90, 101, 114, 111, 32, 40, 69, 120, 112,
  105, 114, 101, 100, 41, 32, 67, 111, 108, 100, 32, 45, 34, 44, 34, 80,
  111, 108, 97, 114, 111, 105, 100, 32, 84, 105, 109, 101, 32, 90, 101, 114,
  111, 32, 40, 69, 120, 112, 105, 114, 101, 100, 41, 32, 67, 111, 108, 100,
  34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 71, 97, 109, 109, 97, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 45, 49, 46, 50, 44, 49, 46, 50, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116, 114, 97,
  115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 114, 105, 103, 104,
  116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 72, 117, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 45, 49, 56, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 50, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 80, 111, 115, 116, 45, 110, 111, 114, 109,
  97, 108, 105, 122, 101, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108,
  105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 115, 58,
  32, 60, 105, 62, 80, 97, 116, 114, 105, 99, 107, 32, 68, 97, 118, 105,
  100, 60, 47, 105, 62, 32, 97, 110, 100, 32, 60, 105, 62, 68, 97, 118,
  105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50,
  51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62,
  50, 48, 49, 51, 47, 48, 56, 47, 50, 57, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 101,
  109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 105, 110, 115, 116,
  97, 110, 116, 95, 99, 111, 110, 115, 117, 109, 101, 114, 32, 58, 10, 45,
  95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105,
  108, 109, 32, 36, 49, 44, 64, 123, 45, 97, 114, 103, 92, 32, 36, 49,
  44, 64, 123, 45, 95, 36, 48, 125, 125, 44, 36, 123, 50, 45, 45, 49,
  125, 10, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95,
  102, 105, 108, 109, 95, 105, 110, 115, 116, 97, 110, 116, 95, 99, 111, 110,
  115, 117, 109, 101, 114, 32, 58, 10, 45, 117, 32, 112, 111, 108, 97, 114,
  111, 105, 100, 95, 112, 120, 45, 49, 48, 48, 117, 118, 43, 95, 99, 111,
  108, 100, 95, 45, 45, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112,
  120, 45, 49, 48, 48, 117, 118, 43, 95, 99, 111, 108, 100, 95, 45, 44,
  112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 49, 48, 48, 117,
  118, 43, 95, 99, 111, 108, 100, 44, 112, 111, 108, 97, 114, 111, 105, 100,
  95, 112, 120, 45, 49, 48, 48, 117, 118, 43, 95, 99, 111, 108, 100, 95,
  43, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 49, 48,
  48, 117, 118, 43, 95, 99, 111, 108, 100, 95, 43, 43, 44, 112, 111, 108,
  97, 114, 111, 105, 100, 95, 112, 120, 45, 49, 48, 48, 117, 118, 43, 95,
  99, 111, 108, 100, 95, 43, 43, 43, 44, 92, 10, 112, 111, 108, 97, 114,
  111, 105, 100, 95, 112, 120, 45, 49, 48, 48, 117, 118, 43, 95, 119, 97,
  114, 109, 95, 45, 45, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112,
  120, 45, 49, 48, 48, 117, 118, 43, 95, 119, 97, 114, 109, 95, 45, 44,
  112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 49, 48, 48, 117,
  118, 43, 95, 119, 97, 114, 109, 44, 112, 111, 108, 97, 114, 111, 105, 100,
  95, 112, 120, 45, 49, 48, 48, 117, 118, 43, 95, 119, 97, 114, 109, 95,
  43, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 49, 48,
  48, 117, 118, 43, 95, 119, 97, 114, 109, 95, 43, 43, 44, 112, 111, 108,
  97, 114, 111, 105, 100, 95, 112, 120, 45, 49, 48, 48, 117, 118, 43, 95,
  119, 97, 114, 109, 95, 43, 43, 43, 44, 92, 10, 112, 111, 108, 97, 114,
  111, 105, 100, 95, 112, 120, 45, 54, 56, 48, 95, 45, 45, 44, 112, 111,
  108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 54, 56, 48, 95, 45, 44,
  112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 54, 56, 48, 44,
  112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 54, 56, 48, 95,
  43, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 54, 56,
  48, 95, 43, 43, 44, 92, 10, 112, 111, 108, 97, 114, 111, 105, 100, 95,
  112, 120, 45, 54, 56, 48, 95, 99, 111, 108, 100, 95, 45, 45, 44, 112,
  111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 54, 56, 48, 95, 99,
  111, 108, 100, 95, 45, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112,
  120, 45, 54, 56, 48, 95, 99, 111, 108, 100, 44, 112, 111, 108, 97, 114,
  111, 105, 100, 95, 112, 120, 45, 54, 56, 48, 95, 99, 111, 108, 100, 95,
  43, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 54, 56,
  48, 95, 99, 111, 108, 100, 95, 43, 43, 44, 112, 111, 108, 97, 114, 111,
  105, 100, 95, 112, 120, 45, 54, 56, 48, 95, 99, 111, 108, 100, 95, 43,
  43, 95, 97, 108, 116, 44, 92, 10, 112, 111, 108, 97, 114, 111, 105, 100,
  95, 112, 120, 45, 54, 56, 48, 95, 119, 97, 114, 109, 95, 45, 45, 44,
  112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 54, 56, 48, 95,
  119, 97, 114, 109, 95, 45, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95,
  112, 120, 45, 54, 56, 48, 95, 119, 97, 114, 109, 44, 112, 111, 108, 97,
  114, 111, 105, 100, 95, 112, 120, 45, 54, 56, 48, 95, 119, 97, 114, 109,
  95, 43, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 54,
  56, 48, 95, 119, 97, 114, 109, 95, 43, 43, 44, 92, 10, 112, 111, 108,
  97, 114, 111, 105, 100, 95, 112, 120, 45, 55, 48, 95, 45, 45, 44, 112,
  111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 55, 48, 95, 45, 44,
  112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 55, 48, 44, 112,
  111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 55, 48, 95, 43, 44,
  112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 55, 48, 95, 43,
  43, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 55, 48,
  95, 43, 43, 43, 44, 92, 10, 112, 111, 108, 97, 114, 111, 105, 100, 95,
  112, 120, 45, 55, 48, 95, 99, 111, 108, 100, 95, 45, 45, 44, 112, 111,
  108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 55, 48, 95, 99, 111, 108,
  100, 95, 45, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45,
  55, 48, 95, 99, 111, 108, 100, 44, 112, 111, 108, 97, 114, 111, 105, 100,
  95, 112, 120, 45, 55, 48, 95, 99, 111, 108, 100, 95, 43, 44, 112, 111,
  108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 55, 48, 95, 99, 111, 108,
  100, 95, 43, 43, 44, 92, 10, 112, 111, 108, 97, 114, 111, 105, 100, 95,
  112, 120, 45, 55, 48, 95, 119, 97, 114, 109, 95, 45, 45, 44, 112, 111,
  108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 55, 48, 95, 119, 97, 114,
  109, 95, 45, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 112, 120, 45,
  55, 48, 95, 119, 97, 114, 109, 44, 112, 111, 108, 97, 114, 111, 105, 100,
  95, 112, 120, 45, 55, 48, 95, 119, 97, 114, 109, 95, 43, 44, 112, 111,
  108, 97, 114, 111, 105, 100, 95, 112, 120, 45, 55, 48, 95, 119, 97, 114,
  109, 95, 43, 43, 44, 92, 10, 112, 111, 108, 97, 114, 111, 105, 100, 95,
  116, 105, 109, 101, 95, 122, 101, 114, 111, 95, 40, 101, 120, 112, 105, 114,
  101, 100, 41, 95, 45, 45, 45, 44, 112, 111, 108, 97, 114, 111, 105, 100,
  95, 116, 105, 109, 101, 95, 122, 101, 114, 111, 95, 40, 101, 120, 112, 105,
  114, 101, 100, 41, 95, 45, 45, 44, 112, 111, 108, 97, 114, 111, 105, 100,
  95, 116, 105, 109, 101, 95, 122, 101, 114, 111, 95, 40, 101, 120, 112, 105,
  114, 101, 100, 41, 95, 45, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95,
  116, 105, 109, 101, 95, 122, 101, 114, 111, 95, 40, 101, 120, 112, 105, 114,
  101, 100, 41, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 116, 105, 109,
  101, 95, 122, 101, 114, 111, 95, 40, 101, 120, 112, 105, 114, 101, 100, 41,
  95, 43, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 116, 105, 109, 101,
  95, 122, 101, 114, 111, 95, 40, 101, 120, 112, 105, 114, 101, 100, 41, 95,
  43, 43, 44, 92, 10, 112, 111, 108, 97, 114, 111, 105, 100, 95, 116, 105,
  109, 101, 95, 122, 101, 114, 111, 95, 40, 101, 120, 112, 105, 114, 101, 100,
  41, 95, 99, 111, 108, 100, 95, 45, 45, 45, 44, 112, 111, 108, 97, 114,
  111, 105, 100, 95, 116, 105, 109, 101, 95, 122, 101, 114, 111, 95, 40, 101,
  120, 112, 105, 114, 101, 100, 41, 95, 99, 111, 108, 100, 95, 45, 45, 44,
  112, 111, 108, 97, 114, 111, 105, 100, 95, 116, 105, 109, 101, 95, 122, 101,
  114, 111, 95, 40, 101, 120, 112, 105, 114, 101, 100, 41, 95, 99, 111, 108,
  100, 95, 45, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 116, 105, 109,
  101, 95, 122, 101, 114, 111, 95, 40, 101, 120, 112, 105, 114, 101, 100, 41,
  95, 99, 111, 108, 100, 10, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97,
  116, 101, 95, 102, 105, 108, 109, 95, 105, 110, 115, 116, 97, 110, 116, 95,
  99, 111, 110, 115, 117, 109, 101, 114, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 101, 109,
  117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 105, 110, 115, 116, 97,
  110, 116, 95, 99, 111, 110, 115, 117, 109, 101, 114, 32, 36, 42, 34, 44,
  36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 73, 110, 115, 116, 97,
  110, 116, 32, 91, 112, 114, 111, 93, 32, 58, 32, 103, 105, 109, 112, 95,
  101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 105, 110, 115,
  116, 97, 110, 116, 95, 112, 114, 111, 44, 32, 103, 105, 109, 112, 95, 101,
  109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 105, 110, 115, 116,
  97, 110, 116, 95, 112, 114, 111, 95, 112, 114, 101, 118, 105, 101, 119, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 115,
  101, 116, 32, 61, 32, 99, 104, 111, 105, 99, 101, 123, 34, 78, 111, 110,
  101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 70, 117,
  106, 105, 32, 70, 80, 45, 49, 48, 48, 99, 32, 45, 45, 34, 44, 34,
  70, 117, 106, 105, 32, 70, 80, 45, 49, 48, 48, 99, 32, 45, 34, 44,
  34, 70, 117, 106, 105, 32, 70, 80, 45, 49, 48, 48, 99, 34, 44, 34,
  70, 117, 106, 105, 32, 70, 80, 45, 49, 48, 48, 99, 32, 43, 34, 44,
  34, 70, 117, 106, 105, 32, 70, 80, 45, 49, 48, 48, 99, 32, 43, 43,
  34, 44, 34, 70, 117, 106, 105, 32, 70, 80, 45, 49, 48, 48, 99, 32,
  43, 43, 97, 34, 44, 34, 70, 117, 106, 105, 32, 70, 80, 45, 49, 48,
  48, 99, 32, 43, 43, 43, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 34, 70, 117, 106, 105, 32, 70, 80, 45, 49, 48, 48, 99, 32,
  67, 111, 111, 108, 32, 45, 45, 34, 44, 34, 70, 117, 106, 105, 32, 70,
  80, 45, 49, 48, 48, 99, 32, 67, 111, 111, 108, 32, 45, 34, 44, 34,
  70, 117, 106, 105, 32, 70, 80, 45, 49, 48, 48, 99, 32, 67, 111, 111,
  108, 34, 44, 34, 70, 117, 106, 105, 32, 70, 80, 45, 49, 48, 48, 99,
  32, 67, 111, 111, 108, 32, 43, 34, 44, 34, 70, 117, 106, 105, 32, 70,
  80, 45, 49, 48, 48, 99, 32, 67, 111, 111, 108, 32, 43, 43, 34, 44,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 70, 117, 106, 105, 32,
  70, 80, 45, 49, 48, 48, 99, 32, 78, 101, 103, 97, 116, 105, 118, 101,
  32, 45, 45, 34, 44, 34, 70, 117, 106, 105, 32, 70, 80, 45, 49, 48,
  48, 99, 32, 78, 101, 103, 97, 116, 105, 118, 101, 32, 45, 34, 44, 34,
  70, 117, 106, 105, 32, 70, 80, 45, 49, 48, 48, 99, 32, 78, 101, 103,
  97, 116, 105, 118, 101, 34, 44, 34, 70, 117, 106, 105, 32, 70, 80, 45,
  49, 48, 48, 99, 32, 78, 101, 103, 97, 116, 105, 118, 101, 32, 43, 34,
  44, 34, 70, 117, 106, 105, 32, 70, 80, 45, 49, 48, 48, 99, 32, 78,
  101, 103, 97, 116, 105, 118, 101, 32, 43, 43, 34, 44, 34, 70, 117, 106,
  105, 32, 70, 80, 45, 49, 48, 48, 99, 32, 78, 101, 103, 97, 116, 105,
  118, 101, 32, 43, 43, 97, 34, 44, 34, 70, 117, 106, 105, 32, 70, 80,
  45, 49, 48, 48, 99, 32, 78, 101, 103, 97, 116, 105, 118, 101, 32, 43,
  43, 43, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 70,
  117, 106, 105, 32, 70, 80, 45, 51, 48, 48, 48, 98, 32, 45, 45, 34,
  44, 34, 70, 117, 106, 105, 32, 70, 80, 45, 51, 48, 48, 48, 98, 32,
  45, 34, 44, 34, 70, 117, 106, 105, 32, 70, 80, 45, 51, 48, 48, 48,
  98, 34, 44, 34, 70, 117, 106, 105, 32, 70, 80, 45, 51, 48, 48, 48,
  98, 32, 43, 34, 44, 34, 70, 117, 106, 105, 32, 70, 80, 45, 51, 48,
  48, 48, 98, 32, 43, 43, 34, 44, 34, 70, 117, 106, 105, 32, 70, 80,
  45, 51, 48, 48, 48, 98, 32, 43, 43, 43, 34, 44, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 34, 70, 117, 106, 105, 32, 70, 80, 45, 51,
  48, 48, 48, 98, 32, 72, 67, 34, 44, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 34, 70, 117, 106, 105, 32, 70, 80, 45, 51, 48, 48, 48,
  98, 32, 78, 101, 103, 97, 116, 105, 118, 101, 32, 45, 45, 34, 44, 34,
  70, 117, 106, 105, 32, 70, 80, 45, 51, 48, 48, 48, 98, 32, 78, 101,
  103, 97, 116, 105, 118, 101, 32, 45, 34, 44, 34, 70, 117, 106, 105, 32,
  70, 80, 45, 51, 48, 48, 48, 98, 32, 78, 101, 103, 97, 116, 105, 118,
  101, 34, 44, 34, 70, 117, 106, 105, 32, 70, 80, 45, 51, 48, 48, 48,
  98, 32, 78, 101, 103, 97, 116, 105, 118, 101, 32, 43, 34, 44, 34, 70,
  117, 106, 105, 32, 70, 80, 45, 51, 48, 48, 48, 98, 32, 78, 101, 103,
  97, 116, 105, 118, 101, 32, 43, 43, 34, 44, 34, 70, 117, 106, 105, 32,
  70, 80, 45, 51, 48, 48, 48, 98, 32, 78, 101, 103, 97, 116, 105, 118,
  101, 32, 43, 43, 43, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 34, 70, 117, 106, 105, 32, 70, 80, 45, 51, 48, 48, 48, 98, 32,
  78, 101, 103, 97, 116, 105, 118, 101, 32, 69, 97, 114, 108, 121, 34, 44,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 80, 111, 108, 97, 114,
  111, 105, 100, 32, 54, 54, 53, 32, 45, 45, 34, 44, 34, 80, 111, 108,
  97, 114, 111, 105, 100, 32, 54, 54, 53, 32, 45, 34, 44, 34, 80, 111,
  108, 97, 114, 111, 105, 100, 32, 54, 54, 53, 34, 44, 34, 80, 111, 108,
  97, 114, 111, 105, 100, 32, 54, 54, 53, 32, 43, 34, 44, 34, 80, 111,
  108, 97, 114, 111, 105, 100, 32, 54, 54, 53, 32, 43, 43, 34, 44, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 80, 111, 108, 97, 114, 111,
  105, 100, 32, 54, 54, 53, 32, 78, 101, 103, 97, 116, 105, 118, 101, 32,
  45, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 54, 54, 53,
  32, 78, 101, 103, 97, 116, 105, 118, 101, 34, 44, 34, 80, 111, 108, 97,
  114, 111, 105, 100, 32, 54, 54, 53, 32, 78, 101, 103, 97, 116, 105, 118,
  101, 32, 43, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34,
  80, 111, 108, 97, 114, 111, 105, 100, 32, 54, 54, 53, 32, 78, 101, 103,
  97, 116, 105, 118, 101, 32, 72, 67, 34, 44, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 54, 54,
  57, 32, 45, 45, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32,
  54, 54, 57, 32, 45, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100,
  32, 54, 54, 57, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32,
  54, 54, 57, 32, 43, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100,
  32, 54, 54, 57, 32, 43, 43, 34, 44, 34, 80, 111, 108, 97, 114, 111,
  105, 100, 32, 54, 54, 57, 32, 43, 43, 43, 34, 44, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32,
  54, 54, 57, 32, 67, 111, 108, 100, 32, 45, 45, 34, 44, 34, 80, 111,
  108, 97, 114, 111, 105, 100, 32, 54, 54, 57, 32, 67, 111, 108, 100, 32,
  45, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 54, 54, 57,
  32, 67, 111, 108, 100, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100,
  32, 54, 54, 57, 32, 67, 111, 108, 100, 32, 43, 34, 44, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 34, 80, 111, 108, 97, 114, 111, 105, 100,
  32, 54, 57, 48, 32, 45, 45, 34, 44, 34, 80, 111, 108, 97, 114, 111,
  105, 100, 32, 54, 57, 48, 32, 45, 34, 44, 34, 80, 111, 108, 97, 114,
  111, 105, 100, 32, 54, 57, 48, 34, 44, 34, 80, 111, 108, 97, 114, 111,
  105, 100, 32, 54, 57, 48, 32, 43, 34, 44, 34, 80, 111, 108, 97, 114,
  111, 105, 100, 32, 54, 57, 48, 32, 43, 43, 34, 44, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32,
  54, 57, 48, 32, 67, 111, 108, 100, 32, 45, 45, 34, 44, 34, 80, 111,
  108, 97, 114, 111, 105, 100, 32, 54, 57, 48, 32, 67, 111, 108, 100, 32,
  45, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 54, 57, 48,
  32, 67, 111, 108, 100, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100,
  32, 54, 57, 48, 32, 67, 111, 108, 100, 32, 43, 34, 44, 34, 80, 111,
  108, 97, 114, 111, 105, 100, 32, 54, 57, 48, 32, 67, 111, 108, 100, 32,
  43, 43, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 80,
  111, 108, 97, 114, 111, 105, 100, 32, 54, 57, 48, 32, 87, 97, 114, 109,
  32, 45, 45, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 54,
  57, 48, 32, 87, 97, 114, 109, 32, 45, 34, 44, 34, 80, 111, 108, 97,
  114, 111, 105, 100, 32, 54, 57, 48, 32, 87, 97, 114, 109, 34, 44, 34,
  80, 111, 108, 97, 114, 111, 105, 100, 32, 54, 57, 48, 32, 87, 97, 114,
  109, 32, 43, 34, 44, 34, 80, 111, 108, 97, 114, 111, 105, 100, 32, 54,
  57, 48, 32, 87, 97, 114, 109, 32, 43, 43, 34, 125, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 71, 97, 109, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 45, 49, 46, 50, 44, 49, 46, 50, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 66, 114, 105, 103, 104, 116, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 117, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 56, 48, 44,
  49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 97,
  116, 117, 114, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 80, 111, 115, 116, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 32,
  61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121,
  112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112,
  108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 115, 58, 32, 60, 105, 62, 80, 97,
  116, 114, 105, 99, 107, 32, 68, 97, 118, 105, 100, 60, 47, 105, 62, 32,
  97, 110, 100, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48,
  56, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101,
  95, 102, 105, 108, 109, 95, 105, 110, 115, 116, 97, 110, 116, 95, 112, 114,
  111, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97,
  116, 101, 95, 102, 105, 108, 109, 32, 36, 49, 44, 64, 123, 45, 97, 114,
  103, 92, 32, 36, 49, 44, 64, 123, 45, 95, 36, 48, 125, 125, 44, 36,
  123, 50, 45, 45, 49, 125, 10, 95, 103, 105, 109, 112, 95, 101, 109, 117,
  108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 105, 110, 115, 116, 97, 110,
  116, 95, 112, 114, 111, 32, 58, 10, 45, 117, 32, 102, 117, 106, 105, 95,
  102, 112, 45, 49, 48, 48, 99, 95, 45, 45, 44, 102, 117, 106, 105, 95,
  102, 112, 45, 49, 48, 48, 99, 95, 45, 44, 102, 117, 106, 105, 95, 102,
  112, 45, 49, 48, 48, 99, 44, 102, 117, 106, 105, 95, 102, 112, 45, 49,
  48, 48, 99, 95, 43, 44, 102, 117, 106, 105, 95, 102, 112, 45, 49, 48,
  48, 99, 95, 43, 43, 44, 102, 117, 106, 105, 95, 102, 112, 45, 49, 48,
  48, 99, 95, 43, 43, 95, 97, 108, 116, 44, 102, 117, 106, 105, 95, 102,
  112, 45, 49, 48, 48, 99, 95, 43, 43, 43, 44, 92, 10, 102, 117, 106,
  105, 95, 102, 112, 45, 49, 48, 48, 99, 95, 99, 111, 111, 108, 95, 45,
  45, 44, 102, 117, 106, 105, 95, 102, 112, 45, 49, 48, 48, 99, 95, 99,
  111, 111, 108, 95, 45, 44, 102, 117, 106, 105, 95, 102, 112, 45, 49, 48,
  48, 99, 95, 99, 111, 111, 108, 44, 102, 117, 106, 105, 95, 102, 112, 45,
  49, 48, 48, 99, 95, 99, 111, 111, 108, 95, 43, 44, 102, 117, 106, 105,
  95, 102, 112, 45, 49, 48, 48, 99, 95, 99, 111, 111, 108, 95, 43, 43,
  44, 92, 10, 102, 117, 106, 105, 95, 102, 112, 45, 49, 48, 48, 99, 95,
  110, 101, 103, 97, 116, 105, 118, 101, 95, 45, 45, 44, 102, 117, 106, 105,
  95, 102, 112, 45, 49, 48, 48, 99, 95, 110, 101, 103, 97, 116, 105, 118,
  101, 95, 45, 44, 102, 117, 106, 105, 95, 102, 112, 45, 49, 48, 48, 99,
  95, 110, 101, 103, 97, 116, 105, 118, 101, 44, 102, 117, 106, 105, 95, 102,
  112, 45, 49, 48, 48, 99, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95,
  43, 44, 102, 117, 106, 105, 95, 102, 112, 45, 49, 48, 48, 99, 95, 110,
  101, 103, 97, 116, 105, 118, 101, 95, 43, 43, 44, 102, 117, 106, 105, 95,
  102, 112, 45, 49, 48, 48, 99, 95, 110, 101, 103, 97, 116, 105, 118, 101,
  95, 43, 43, 95, 97, 108, 116, 44, 102, 117, 106, 105, 95, 102, 112, 45,
  49, 48, 48, 99, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 43, 43,
  43, 44, 92, 10, 102, 117, 106, 105, 95, 102, 112, 45, 51, 48, 48, 48,
  98, 95, 45, 45, 44, 102, 117, 106, 105, 95, 102, 112, 45, 51, 48, 48,
  48, 98, 95, 45, 44, 102, 117, 106, 105, 95, 102, 112, 45, 51, 48, 48,
  48, 98, 44, 102, 117, 106, 105, 95, 102, 112, 45, 51, 48, 48, 48, 98,
  95, 43, 44, 102, 117, 106, 105, 95, 102, 112, 45, 51, 48, 48, 48, 98,
  95, 43, 43, 44, 102, 117, 106, 105, 95, 102, 112, 45, 51, 48, 48, 48,
  98, 95, 43, 43, 43, 44, 102, 117, 106, 105, 95, 102, 112, 45, 51, 48,
  48, 48, 98, 95, 104, 99, 44, 92, 10, 102, 117, 106, 105, 95, 102, 112,
  45, 51, 48, 48, 48, 98, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95,
  45, 45, 44, 102, 117, 106, 105, 95, 102, 112, 45, 51, 48, 48, 48, 98,
  95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 45, 44, 102, 117, 106, 105,
  95, 102, 112, 45, 51, 48, 48, 48, 98, 95, 110, 101, 103, 97, 116, 105,
  118, 101, 44, 102, 117, 106, 105, 95, 102, 112, 45, 51, 48, 48, 48, 98,
  95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 43, 44, 102, 117, 106, 105,
  95, 102, 112, 45, 51, 48, 48, 48, 98, 95, 110, 101, 103, 97, 116, 105,
  118, 101, 95, 43, 43, 44, 102, 117, 106, 105, 95, 102, 112, 45, 51, 48,
  48, 48, 98, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 43, 43, 43,
  44, 102, 117, 106, 105, 95, 102, 112, 45, 51, 48, 48, 48, 98, 95, 110,
  101, 103, 97, 116, 105, 118, 101, 95, 101, 97, 114, 108, 121, 44, 92, 10,
  112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 54, 53, 95, 45, 45, 44,
  112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 54, 53, 95, 45, 44, 112,
  111, 108, 97, 114, 111, 105, 100, 95, 54, 54, 53, 44, 112, 111, 108, 97,
  114, 111, 105, 100, 95, 54, 54, 53, 95, 43, 44, 112, 111, 108, 97, 114,
  111, 105, 100, 95, 54, 54, 53, 95, 43, 43, 44, 92, 10, 112, 111, 108,
  97, 114, 111, 105, 100, 95, 54, 54, 53, 95, 110, 101, 103, 97, 116, 105,
  118, 101, 95, 45, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 54,
  53, 95, 110, 101, 103, 97, 116, 105, 118, 101, 44, 112, 111, 108, 97, 114,
  111, 105, 100, 95, 54, 54, 53, 95, 110, 101, 103, 97, 116, 105, 118, 101,
  95, 43, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 54, 53, 95,
  110, 101, 103, 97, 116, 105, 118, 101, 95, 104, 99, 44, 92, 10, 112, 111,
  108, 97, 114, 111, 105, 100, 95, 54, 54, 57, 95, 45, 45, 44, 112, 111,
  108, 97, 114, 111, 105, 100, 95, 54, 54, 57, 95, 45, 44, 112, 111, 108,
  97, 114, 111, 105, 100, 95, 54, 54, 57, 44, 112, 111, 108, 97, 114, 111,
  105, 100, 95, 54, 54, 57, 95, 43, 44, 112, 111, 108, 97, 114, 111, 105,
  100, 95, 54, 54, 57, 95, 43, 43, 44, 112, 111, 108, 97, 114, 111, 105,
  100, 95, 54, 54, 57, 95, 43, 43, 43, 44, 92, 10, 112, 111, 108, 97,
  114, 111, 105, 100, 95, 54, 54, 57, 95, 99, 111, 108, 100, 95, 45, 45,
  44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 54, 57, 95, 99, 111,
  108, 100, 95, 45, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 54,
  57, 95, 99, 111, 108, 100, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95,
  54, 54, 57, 95, 99, 111, 108, 100, 95, 43, 44, 92, 10, 112, 111, 108,
  97, 114, 111, 105, 100, 95, 54, 57, 48, 95, 45, 45, 44, 112, 111, 108,
  97, 114, 111, 105, 100, 95, 54, 57, 48, 95, 45, 44, 112, 111, 108, 97,
  114, 111, 105, 100, 95, 54, 57, 48, 44, 112, 111, 108, 97, 114, 111, 105,
  100, 95, 54, 57, 48, 95, 43, 44, 112, 111, 108, 97, 114, 111, 105, 100,
  95, 54, 57, 48, 95, 43, 43, 44, 92, 10, 112, 111, 108, 97, 114, 111,
  105, 100, 95, 54, 57, 48, 95, 99, 111, 108, 100, 95, 45, 45, 44, 112,
  111, 108, 97, 114, 111, 105, 100, 95, 54, 57, 48, 95, 99, 111, 108, 100,
  95, 45, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 57, 48, 95,
  99, 111, 108, 100, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 57,
  48, 95, 99, 111, 108, 100, 95, 43, 44, 112, 111, 108, 97, 114, 111, 105,
  100, 95, 54, 57, 48, 95, 99, 111, 108, 100, 95, 43, 43, 44, 92, 10,
  112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 57, 48, 95, 119, 97, 114,
  109, 95, 45, 45, 44, 112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 57,
  48, 95, 119, 97, 114, 109, 95, 45, 44, 112, 111, 108, 97, 114, 111, 105,
  100, 95, 54, 57, 48, 95, 119, 97, 114, 109, 44, 112, 111, 108, 97, 114,
  111, 105, 100, 95, 54, 57, 48, 95, 119, 97, 114, 109, 95, 43, 44, 112,
  111, 108, 97, 114, 111, 105, 100, 95, 54, 57, 48, 95, 119, 97, 114, 109,
  95, 43, 43, 10, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101,
  95, 102, 105, 108, 109, 95, 105, 110, 115, 116, 97, 110, 116, 95, 112, 114,
  111, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102,
  105, 108, 109, 95, 105, 110, 115, 116, 97, 110, 116, 95, 112, 114, 111, 32,
  36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 78,
  101, 103, 97, 116, 105, 118, 101, 32, 91, 99, 111, 108, 111, 114, 93, 32,
  58, 32, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102,
  105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 99, 111, 108,
  111, 114, 44, 32, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101,
  95, 102, 105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 99,
  111, 108, 111, 114, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 115, 101, 116, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 123, 34, 78, 111, 110, 101, 34, 44,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 65, 103, 102, 97, 32,
  85, 108, 116, 114, 97, 32, 67, 111, 108, 111, 114, 32, 49, 48, 48, 34,
  44, 34, 65, 103, 102, 97, 32, 86, 105, 115, 116, 97, 32, 50, 48, 48,
  34, 44, 34, 70, 117, 106, 105, 32, 83, 117, 112, 101, 114, 105, 97, 32,
  50, 48, 48, 34, 44, 34, 70, 117, 106, 105, 32, 83, 117, 112, 101, 114,
  105, 97, 32, 72, 71, 32, 49, 54, 48, 48, 34, 44, 34, 70, 117, 106,
  105, 32, 83, 117, 112, 101, 114, 105, 97, 32, 82, 101, 97, 108, 97, 32,
  49, 48, 48, 34, 44, 34, 70, 117, 106, 105, 32, 83, 117, 112, 101, 114,
  105, 97, 32, 88, 45, 84, 114, 97, 32, 56, 48, 48, 34, 44, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 34, 75, 111, 100, 97, 107, 32, 69,
  108, 105, 116, 101, 32, 49, 48, 48, 32, 88, 80, 82, 79, 34, 44, 34,
  75, 111, 100, 97, 107, 32, 69, 108, 105, 116, 101, 32, 67, 111, 108, 111,
  114, 32, 50, 48, 48, 34, 44, 34, 75, 111, 100, 97, 107, 32, 69, 108,
  105, 116, 101, 32, 67, 111, 108, 111, 114, 32, 52, 48, 48, 34, 44, 34,
  75, 111, 100, 97, 107, 32, 80, 111, 114, 116, 114, 97, 32, 49, 54, 48,
  32, 78, 67, 34, 44, 34, 75, 111, 100, 97, 107, 32, 80, 111, 114, 116,
  114, 97, 32, 49, 54, 48, 32, 86, 67, 34, 44, 34, 76, 111, 109, 111,
  103, 114, 97, 112, 104, 121, 32, 82, 101, 100, 115, 99, 97, 108, 101, 32,
  49, 48, 48, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 97, 109, 109, 97, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 46, 50, 44, 49,
  46, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110,
  116, 114, 97, 115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44,
  48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 114,
  105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 72, 117, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 45, 49, 56, 48, 44, 49, 56, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 97, 116, 117, 114, 97, 116, 105, 111,
  110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 50, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 111, 115, 116, 45, 110,
  111, 114, 109, 97, 108, 105, 122, 101, 32, 61, 32, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80,
  114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68,
  117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 115, 58, 32, 60, 105, 62, 80, 97, 116, 114, 105, 99, 107, 32, 68,
  97, 118, 105, 100, 60, 47, 105, 62, 32, 97, 110, 100, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 51, 47, 48, 56, 47, 50, 57, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 110,
  101, 103, 97, 116, 105, 118, 101, 95, 99, 111, 108, 111, 114, 32, 58, 10,
  45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102,
  105, 108, 109, 32, 36, 49, 44, 64, 123, 45, 97, 114, 103, 92, 32, 36,
  49, 44, 64, 123, 45, 95, 36, 48, 125, 125, 44, 36, 123, 50, 45, 45,
  49, 125, 10, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101,
  95, 102, 105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 99,
  111, 108, 111, 114, 32, 58, 10, 45, 117, 32, 97, 103, 102, 97, 95, 117,
  108, 116, 114, 97, 95, 99, 111, 108, 111, 114, 95, 49, 48, 48, 44, 97,
  103, 102, 97, 95, 118, 105, 115, 116, 97, 95, 50, 48, 48, 44, 102, 117,
  106, 105, 95, 115, 117, 112, 101, 114, 105, 97, 95, 50, 48, 48, 44, 102,
  117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97, 95, 104, 103, 95, 49,
  54, 48, 48, 44, 102, 117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97,
  95, 114, 101, 97, 108, 97, 95, 49, 48, 48, 44, 102, 117, 106, 105, 95,
  115, 117, 112, 101, 114, 105, 97, 95, 120, 45, 116, 114, 97, 95, 56, 48,
  48, 44, 92, 10, 107, 111, 100, 97, 107, 95, 101, 108, 105, 116, 101, 95,
  49, 48, 48, 95, 120, 112, 114, 111, 44, 107, 111, 100, 97, 107, 95, 101,
  108, 105, 116, 101, 95, 99, 111, 108, 111, 114, 95, 50, 48, 48, 44, 107,
  111, 100, 97, 107, 95, 101, 108, 105, 116, 101, 95, 99, 111, 108, 111, 114,
  95, 52, 48, 48, 44, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114,
  97, 95, 49, 54, 48, 95, 110, 99, 44, 107, 111, 100, 97, 107, 95, 112,
  111, 114, 116, 114, 97, 95, 49, 54, 48, 95, 118, 99, 44, 108, 111, 109,
  111, 103, 114, 97, 112, 104, 121, 95, 114, 101, 100, 115, 99, 97, 108, 101,
  95, 49, 48, 48, 10, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116,
  101, 95, 102, 105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95,
  99, 111, 108, 111, 114, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97,
  116, 101, 95, 102, 105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118, 101,
  95, 99, 111, 108, 111, 114, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35,
  64, 103, 105, 109, 112, 32, 78, 101, 103, 97, 116, 105, 118, 101, 32, 91,
  110, 101, 119, 93, 32, 58, 32, 103, 105, 109, 112, 95, 101, 109, 117, 108,
  97, 116, 101, 95, 102, 105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118,
  101, 95, 110, 101, 119, 44, 32, 103, 105, 109, 112, 95, 101, 109, 117, 108,
  97, 116, 101, 95, 102, 105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118,
  101, 95, 110, 101, 119, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 115, 101, 116,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 123, 34, 78, 111, 110, 101, 34,
  44, 34, 70, 117, 106, 105, 32, 49, 54, 48, 67, 34, 44, 34, 70, 117,
  106, 105, 32, 52, 48, 48, 72, 34, 44, 34, 70, 117, 106, 105, 32, 56,
  48, 48, 90, 34, 44, 34, 70, 117, 106, 105, 32, 73, 108, 102, 111, 114,
  100, 32, 72, 80, 53, 34, 44, 34, 75, 111, 100, 97, 107, 32, 80, 111,
  114, 116, 114, 97, 32, 49, 54, 48, 34, 44, 34, 75, 111, 100, 97, 107,
  32, 80, 111, 114, 116, 114, 97, 32, 52, 48, 48, 34, 44, 34, 75, 111,
  100, 97, 107, 32, 80, 111, 114, 116, 114, 97, 32, 56, 48, 48, 34, 44,
  34, 75, 111, 100, 97, 107, 32, 84, 77, 65, 88, 32, 51, 50, 48, 48,
  34, 44, 34, 75, 111, 100, 97, 107, 32, 84, 82, 73, 45, 88, 32, 52,
  48, 48, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 102,
  102, 101, 99, 116, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44,
  34, 76, 111, 119, 34, 44, 34, 83, 116, 97, 110, 100, 97, 114, 100, 34,
  44, 34, 72, 105, 103, 104, 34, 44, 34, 72, 105, 103, 104, 101, 114, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 71, 97, 109, 109, 97, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 49, 46, 50, 44, 49, 46, 50, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116, 114, 97, 115,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 114, 105, 103, 104, 116,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45,
  50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 72, 117, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  45, 49, 56, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 50, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 80, 111, 115, 116, 45, 110, 111, 114, 109, 97,
  108, 105, 122, 101, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105,
  99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 115, 58, 32,
  60, 105, 62, 80, 97, 116, 114, 105, 99, 107, 32, 68, 97, 118, 105, 100,
  60, 47, 105, 62, 32, 97, 110, 100, 32, 60, 105, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 51, 47, 48, 56, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 101, 109,
  117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 110, 101, 103, 97, 116,
  105, 118, 101, 95, 110, 101, 119, 32, 58, 10, 45, 95, 103, 105, 109, 112,
  95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 32, 36, 49,
  44, 64, 123, 45, 97, 114, 103, 92, 32, 123, 109, 97, 120, 40, 49, 44,
  52, 42, 36, 49, 43, 36, 50, 45, 51, 41, 125, 44, 64, 123, 45, 95,
  36, 48, 125, 125, 44, 36, 123, 51, 45, 45, 49, 125, 10, 95, 103, 105,
  109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95,
  110, 101, 103, 97, 116, 105, 118, 101, 95, 110, 101, 119, 32, 58, 10, 45,
  117, 32, 102, 117, 106, 105, 95, 49, 54, 48, 99, 95, 45, 44, 102, 117,
  106, 105, 95, 49, 54, 48, 99, 44, 102, 117, 106, 105, 95, 49, 54, 48,
  99, 95, 43, 44, 102, 117, 106, 105, 95, 49, 54, 48, 99, 95, 43, 43,
  44, 92, 10, 102, 117, 106, 105, 95, 52, 48, 48, 104, 95, 45, 44, 102,
  117, 106, 105, 95, 52, 48, 48, 104, 44, 102, 117, 106, 105, 95, 52, 48,
  48, 104, 95, 43, 44, 102, 117, 106, 105, 95, 52, 48, 48, 104, 95, 43,
  43, 44, 92, 10, 102, 117, 106, 105, 95, 56, 48, 48, 122, 95, 45, 44,
  102, 117, 106, 105, 95, 56, 48, 48, 122, 44, 102, 117, 106, 105, 95, 56,
  48, 48, 122, 95, 43, 44, 102, 117, 106, 105, 95, 56, 48, 48, 122, 95,
  43, 43, 44, 92, 10, 102, 117, 106, 105, 95, 105, 108, 102, 111, 114, 100,
  95, 104, 112, 53, 95, 45, 44, 102, 117, 106, 105, 95, 105, 108, 102, 111,
  114, 100, 95, 104, 112, 53, 44, 102, 117, 106, 105, 95, 105, 108, 102, 111,
  114, 100, 95, 104, 112, 53, 95, 43, 44, 102, 117, 106, 105, 95, 105, 108,
  102, 111, 114, 100, 95, 104, 112, 53, 95, 43, 43, 44, 92, 10, 107, 111,
  100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 49, 54, 48, 95, 45,
  44, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 49, 54,
  48, 44, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 49,
  54, 48, 95, 43, 44, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114,
  97, 95, 49, 54, 48, 95, 43, 43, 44, 92, 10, 107, 111, 100, 97, 107,
  95, 112, 111, 114, 116, 114, 97, 95, 52, 48, 48, 95, 45, 44, 107, 111,
  100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 52, 48, 48, 44, 107,
  111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 52, 48, 48, 95,
  43, 44, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 52,
  48, 48, 95, 43, 43, 44, 92, 10, 107, 111, 100, 97, 107, 95, 112, 111,
  114, 116, 114, 97, 95, 56, 48, 48, 95, 45, 44, 107, 111, 100, 97, 107,
  95, 112, 111, 114, 116, 114, 97, 95, 56, 48, 48, 44, 107, 111, 100, 97,
  107, 95, 112, 111, 114, 116, 114, 97, 95, 56, 48, 48, 95, 43, 44, 107,
  111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 56, 48, 48, 95,
  43, 43, 44, 92, 10, 107, 111, 100, 97, 107, 95, 116, 109, 97, 120, 95,
  51, 50, 48, 48, 95, 45, 44, 107, 111, 100, 97, 107, 95, 116, 109, 97,
  120, 95, 51, 50, 48, 48, 44, 107, 111, 100, 97, 107, 95, 116, 109, 97,
  120, 95, 51, 50, 48, 48, 95, 43, 44, 107, 111, 100, 97, 107, 95, 116,
  109, 97, 120, 95, 51, 50, 48, 48, 95, 43, 43, 44, 92, 10, 107, 111,
  100, 97, 107, 95, 116, 114, 105, 45, 120, 95, 52, 48, 48, 95, 45, 44,
  107, 111, 100, 97, 107, 95, 116, 114, 105, 45, 120, 95, 52, 48, 48, 44,
  107, 111, 100, 97, 107, 95, 116, 114, 105, 45, 120, 95, 52, 48, 48, 95,
  43, 44, 107, 111, 100, 97, 107, 95, 116, 114, 105, 45, 120, 95, 52, 48,
  48, 95, 43, 43, 10, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116,
  101, 95, 102, 105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95,
  110, 101, 119, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101,
  95, 102, 105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 110,
  101, 119, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 78, 101, 103, 97, 116, 105, 118, 101, 32, 91, 111, 108, 100, 93,
  32, 58, 32, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95,
  102, 105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 111, 108,
  100, 44, 32, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95,
  102, 105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 111, 108,
  100, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 80, 114, 101, 115, 101, 116, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 123, 48, 44, 34, 78, 111, 110, 101, 34, 44, 34,
  70, 117, 106, 105, 32, 73, 108, 102, 111, 114, 100, 32, 68, 101, 108, 116,
  97, 32, 51, 50, 48, 48, 34, 44, 34, 70, 117, 106, 105, 32, 78, 101,
  111, 112, 97, 110, 32, 49, 54, 48, 48, 34, 44, 34, 70, 117, 106, 105,
  32, 83, 117, 112, 101, 114, 105, 97, 32, 49, 48, 48, 34, 44, 34, 70,
  117, 106, 105, 32, 83, 117, 112, 101, 114, 105, 97, 32, 52, 48, 48, 34,
  44, 34, 70, 117, 106, 105, 32, 83, 117, 112, 101, 114, 105, 97, 32, 56,
  48, 48, 34, 44, 34, 70, 117, 106, 105, 32, 83, 117, 112, 101, 114, 105,
  97, 32, 49, 54, 48, 48, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 34, 75, 111, 100, 97, 107, 32, 80, 111, 114, 116, 114, 97, 32,
  49, 54, 48, 32, 78, 67, 34, 44, 34, 75, 111, 100, 97, 107, 32, 80,
  111, 114, 116, 114, 97, 32, 49, 54, 48, 32, 86, 67, 34, 44, 34, 75,
  111, 100, 97, 107, 32, 80, 111, 114, 116, 114, 97, 32, 52, 48, 48, 32,
  78, 67, 34, 44, 34, 75, 111, 100, 97, 107, 32, 80, 111, 114, 116, 114,
  97, 32, 52, 48, 48, 32, 85, 67, 34, 44, 34, 75, 111, 100, 97, 107,
  32, 80, 111, 114, 116, 114, 97, 32, 52, 48, 48, 32, 86, 67, 34, 125,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 102, 102, 101, 99, 116,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 76, 111, 119,
  34, 44, 34, 83, 116, 97, 110, 100, 97, 114, 100, 34, 44, 34, 72, 105,
  103, 104, 34, 44, 34, 72, 105, 103, 104, 101, 114, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 71, 97, 109, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 45, 49, 46, 50, 44, 49, 46, 50, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 66, 114, 105, 103, 104, 116, 110, 101, 115, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 117,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 56, 48,
  44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  97, 116, 117, 114, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 80, 111, 115, 116, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117,
  108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117,
  112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 115, 58, 32, 60, 105, 62, 80,
  97, 116, 114, 105, 99, 107, 32, 68, 97, 118, 105, 100, 60, 47, 105, 62,
  32, 97, 110, 100, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115,
  99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47,
  48, 56, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116,
  101, 95, 102, 105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95,
  111, 108, 100, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117,
  108, 97, 116, 101, 95, 102, 105, 108, 109, 32, 36, 49, 44, 64, 123, 45,
  97, 114, 103, 92, 32, 123, 109, 97, 120, 40, 49, 44, 52, 42, 36, 49,
  43, 36, 50, 45, 51, 41, 125, 44, 64, 123, 45, 95, 36, 48, 125, 125,
  44, 36, 123, 51, 45, 45, 49, 125, 10, 95, 103, 105, 109, 112, 95, 101,
  109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 110, 101, 103, 97,
  116, 105, 118, 101, 95, 111, 108, 100, 32, 58, 10, 45, 117, 32, 102, 117,
  106, 105, 95, 105, 108, 102, 111, 114, 100, 95, 100, 101, 108, 116, 97, 95,
  51, 50, 48, 48, 95, 45, 44, 102, 117, 106, 105, 95, 105, 108, 102, 111,
  114, 100, 95, 100, 101, 108, 116, 97, 95, 51, 50, 48, 48, 44, 102, 117,
  106, 105, 95, 105, 108, 102, 111, 114, 100, 95, 100, 101, 108, 116, 97, 95,
  51, 50, 48, 48, 95, 43, 44, 102, 117, 106, 105, 95, 105, 108, 102, 111,
  114, 100, 95, 100, 101, 108, 116, 97, 95, 51, 50, 48, 48, 95, 43, 43,
  44, 92, 10, 102, 117, 106, 105, 95, 110, 101, 111, 112, 97, 110, 95, 49,
  54, 48, 48, 95, 45, 44, 102, 117, 106, 105, 95, 110, 101, 111, 112, 97,
  110, 95, 49, 54, 48, 48, 44, 102, 117, 106, 105, 95, 110, 101, 111, 112,
  97, 110, 95, 49, 54, 48, 48, 95, 43, 44, 102, 117, 106, 105, 95, 110,
  101, 111, 112, 97, 110, 95, 49, 54, 48, 48, 95, 43, 43, 44, 92, 10,
  102, 117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97, 95, 49, 48, 48,
  95, 45, 44, 102, 117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97, 95,
  49, 48, 48, 44, 102, 117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97,
  95, 49, 48, 48, 95, 43, 44, 102, 117, 106, 105, 95, 115, 117, 112, 101,
  114, 105, 97, 95, 49, 48, 48, 95, 43, 43, 44, 92, 10, 102, 117, 106,
  105, 95, 115, 117, 112, 101, 114, 105, 97, 95, 52, 48, 48, 95, 45, 44,
  102, 117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97, 95, 52, 48, 48,
  44, 102, 117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97, 95, 52, 48,
  48, 95, 43, 44, 102, 117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97,
  95, 52, 48, 48, 95, 43, 43, 44, 92, 10, 102, 117, 106, 105, 95, 115,
  117, 112, 101, 114, 105, 97, 95, 56, 48, 48, 95, 45, 44, 102, 117, 106,
  105, 95, 115, 117, 112, 101, 114, 105, 97, 95, 56, 48, 48, 44, 102, 117,
  106, 105, 95, 115, 117, 112, 101, 114, 105, 97, 95, 56, 48, 48, 95, 43,
  44, 102, 117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97, 95, 56, 48,
  48, 95, 43, 43, 44, 92, 10, 102, 117, 106, 105, 95, 115, 117, 112, 101,
  114, 105, 97, 95, 49, 54, 48, 48, 95, 45, 44, 102, 117, 106, 105, 95,
  115, 117, 112, 101, 114, 105, 97, 95, 49, 54, 48, 48, 44, 102, 117, 106,
  105, 95, 115, 117, 112, 101, 114, 105, 97, 95, 49, 54, 48, 48, 95, 43,
  44, 102, 117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97, 95, 49, 54,
  48, 48, 95, 43, 43, 44, 92, 10, 107, 111, 100, 97, 107, 95, 112, 111,
  114, 116, 114, 97, 95, 49, 54, 48, 95, 110, 99, 95, 45, 44, 107, 111,
  100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 49, 54, 48, 95, 110,
  99, 44, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 49,
  54, 48, 95, 110, 99, 95, 43, 44, 107, 111, 100, 97, 107, 95, 112, 111,
  114, 116, 114, 97, 95, 49, 54, 48, 95, 110, 99, 95, 43, 43, 44, 92,
  10, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 49, 54,
  48, 95, 118, 99, 95, 45, 44, 107, 111, 100, 97, 107, 95, 112, 111, 114,
  116, 114, 97, 95, 49, 54, 48, 95, 118, 99, 44, 107, 111, 100, 97, 107,
  95, 112, 111, 114, 116, 114, 97, 95, 49, 54, 48, 95, 118, 99, 95, 43,
  44, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 49, 54,
  48, 95, 118, 99, 95, 43, 43, 44, 92, 10, 107, 111, 100, 97, 107, 95,
  112, 111, 114, 116, 114, 97, 95, 52, 48, 48, 95, 110, 99, 95, 45, 44,
  107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 52, 48, 48,
  95, 110, 99, 44, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97,
  95, 52, 48, 48, 95, 110, 99, 95, 43, 44, 107, 111, 100, 97, 107, 95,
  112, 111, 114, 116, 114, 97, 95, 52, 48, 48, 95, 110, 99, 95, 43, 43,
  44, 92, 10, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95,
  52, 48, 48, 95, 117, 99, 95, 45, 44, 107, 111, 100, 97, 107, 95, 112,
  111, 114, 116, 114, 97, 95, 52, 48, 48, 95, 117, 99, 44, 107, 111, 100,
  97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 52, 48, 48, 95, 117, 99,
  95, 43, 44, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95,
  52, 48, 48, 95, 117, 99, 95, 43, 43, 44, 92, 10, 107, 111, 100, 97,
  107, 95, 112, 111, 114, 116, 114, 97, 95, 52, 48, 48, 95, 118, 99, 95,
  45, 44, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116, 114, 97, 95, 52,
  48, 48, 95, 118, 99, 44, 107, 111, 100, 97, 107, 95, 112, 111, 114, 116,
  114, 97, 95, 52, 48, 48, 95, 118, 99, 95, 43, 44, 107, 111, 100, 97,
  107, 95, 112, 111, 114, 116, 114, 97, 95, 52, 48, 48, 95, 118, 99, 95,
  43, 43, 10, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95,
  102, 105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 111, 108,
  100, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102,
  105, 108, 109, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 111, 108, 100,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32,
  79, 116, 104, 101, 114, 32, 101, 102, 102, 101, 99, 116, 115, 32, 58, 32,
  103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108,
  109, 95, 111, 116, 104, 101, 114, 115, 44, 32, 103, 105, 109, 112, 95, 101,
  109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 111, 116, 104, 101,
  114, 115, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 115, 101, 116, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 123, 34, 78, 111, 110, 101, 34, 44, 34, 54,
  48, 39, 115, 32, 40, 49, 41, 34, 44, 34, 54, 48, 39, 115, 32, 40,
  50, 41, 34, 44, 34, 54, 48, 39, 115, 32, 40, 51, 41, 34, 44, 34,
  72, 111, 110, 103, 32, 75, 111, 110, 103, 34, 44, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 34, 76, 111, 109, 111, 34, 44, 34, 78, 111, 115,
  116, 97, 108, 103, 105, 99, 34, 44, 34, 82, 101, 116, 114, 111, 34, 44,
  34, 83, 117, 116, 114, 111, 32, 70, 88, 34, 44, 34, 86, 105, 110, 116,
  97, 103, 101, 34, 44, 34, 86, 105, 110, 116, 97, 103, 101, 32, 50, 34,
  44, 34, 87, 97, 114, 109, 34, 44, 34, 87, 97, 114, 109, 32, 115, 112,
  114, 105, 110, 103, 34, 44, 34, 87, 97, 114, 109, 32, 121, 101, 108, 108,
  111, 119, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 97, 109, 109, 97, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 46, 50, 44, 49, 46,
  50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116,
  114, 97, 115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48,
  44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 114, 105,
  103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 72, 117, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 45, 49, 56, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 50, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 111, 115, 116, 45, 110, 111,
  114, 109, 97, 108, 105, 122, 101, 32, 61, 32, 98, 111, 111, 108, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117,
  112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  115, 58, 32, 60, 105, 62, 80, 97, 116, 114, 105, 99, 107, 32, 68, 97,
  118, 105, 100, 60, 47, 105, 62, 32, 97, 110, 100, 32, 60, 105, 62, 68,
  97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38,
  35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 51, 47, 48, 56, 47, 50, 57, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112,
  95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 111, 116,
  104, 101, 114, 115, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 101, 109,
  117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 32, 36, 49, 44, 64, 123,
  45, 97, 114, 103, 92, 32, 36, 49, 44, 64, 123, 45, 95, 36, 48, 125,
  125, 44, 36, 123, 50, 45, 45, 49, 125, 10, 95, 103, 105, 109, 112, 95,
  101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 111, 116, 104,
  101, 114, 115, 32, 58, 10, 45, 117, 32, 54, 48, 115, 44, 54, 48, 115,
  95, 50, 44, 54, 48, 115, 95, 51, 44, 104, 107, 102, 105, 108, 109, 44,
  108, 111, 109, 111, 44, 110, 111, 115, 116, 97, 108, 103, 105, 99, 44, 114,
  101, 116, 114, 111, 44, 115, 117, 116, 114, 111, 102, 120, 44, 118, 105, 110,
  116, 97, 103, 101, 44, 118, 105, 110, 116, 97, 103, 101, 95, 50, 44, 119,
  97, 114, 109, 44, 119, 97, 114, 109, 95, 115, 112, 114, 105, 110, 103, 44,
  119, 97, 114, 109, 95, 121, 101, 108, 108, 111, 119, 10, 103, 105, 109, 112,
  95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 111, 116,
  104, 101, 114, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116,
  101, 95, 102, 105, 108, 109, 95, 111, 116, 104, 101, 114, 115, 32, 36, 42,
  34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 83, 108, 105,
  100, 101, 32, 91, 99, 111, 108, 111, 114, 93, 32, 58, 32, 103, 105, 109,
  112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99,
  111, 108, 111, 114, 115, 108, 105, 100, 101, 44, 32, 103, 105, 109, 112, 95,
  101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108,
  111, 114, 115, 108, 105, 100, 101, 95, 112, 114, 101, 118, 105, 101, 119, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 115,
  101, 116, 32, 61, 32, 99, 104, 111, 105, 99, 101, 123, 34, 78, 111, 110,
  101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 65, 103,
  102, 97, 32, 80, 114, 101, 99, 105, 115, 97, 32, 49, 48, 48, 34, 44,
  34, 70, 117, 106, 105, 32, 65, 115, 116, 105, 97, 32, 49, 48, 48, 70,
  34, 44, 34, 70, 117, 106, 105, 32, 70, 80, 32, 49, 48, 48, 67, 34,
  44, 34, 70, 117, 106, 105, 32, 80, 114, 111, 118, 105, 97, 32, 49, 48,
  48, 70, 34, 44, 34, 70, 117, 106, 105, 32, 80, 114, 111, 118, 105, 97,
  32, 52, 48, 48, 70, 34, 44, 34, 70, 117, 106, 105, 32, 80, 114, 111,
  118, 105, 97, 32, 52, 48, 48, 88, 34, 44, 34, 70, 117, 106, 105, 32,
  83, 101, 110, 115, 105, 97, 32, 49, 48, 48, 34, 44, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 34, 70, 117, 106, 105, 32, 83, 117, 112, 101,
  114, 105, 97, 32, 50, 48, 48, 32, 88, 80, 82, 79, 34, 44, 34, 70,
  117, 106, 105, 32, 86, 101, 108, 118, 105, 97, 32, 53, 48, 34, 44, 34,
  71, 101, 110, 101, 114, 105, 99, 32, 70, 117, 106, 105, 32, 65, 115, 116,
  105, 97, 32, 49, 48, 48, 34, 44, 34, 71, 101, 110, 101, 114, 105, 99,
  32, 70, 117, 106, 105, 32, 80, 114, 111, 118, 105, 97, 32, 49, 48, 48,
  34, 44, 34, 71, 101, 110, 101, 114, 105, 99, 32, 70, 117, 106, 105, 32,
  86, 101, 108, 118, 105, 97, 32, 49, 48, 48, 34, 44, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 34, 71, 101, 110, 101, 114, 105, 99, 32, 75,
  111, 100, 97, 99, 104, 114, 111, 109, 101, 32, 54, 52, 34, 44, 34, 71,
  101, 110, 101, 114, 105, 99, 32, 75, 111, 100, 97, 107, 32, 69, 107, 116,
  97, 99, 104, 114, 111, 109, 101, 32, 49, 48, 48, 32, 86, 83, 34, 44,
  34, 75, 111, 100, 97, 107, 32, 69, 45, 49, 48, 48, 32, 71, 88, 32,
  69, 107, 116, 97, 99, 104, 114, 111, 109, 101, 32, 49, 48, 48, 34, 44,
  34, 75, 111, 100, 97, 107, 32, 69, 107, 116, 97, 99, 104, 114, 111, 109,
  101, 32, 49, 48, 48, 32, 86, 83, 34, 44, 34, 75, 111, 100, 97, 107,
  32, 69, 108, 105, 116, 101, 32, 67, 104, 114, 111, 109, 101, 32, 50, 48,
  48, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 75, 111,
  100, 97, 107, 32, 69, 108, 105, 116, 101, 32, 67, 104, 114, 111, 109, 101,
  32, 52, 48, 48, 34, 44, 34, 75, 111, 100, 97, 107, 32, 69, 108, 105,
  116, 101, 32, 69, 120, 116, 114, 97, 67, 111, 108, 111, 114, 32, 49, 48,
  48, 34, 44, 34, 75, 111, 100, 97, 107, 32, 75, 111, 100, 97, 99, 104,
  114, 111, 109, 101, 32, 50, 48, 48, 34, 44, 34, 75, 111, 100, 97, 107,
  32, 75, 111, 100, 97, 99, 104, 114, 111, 109, 101, 32, 50, 53, 34, 44,
  34, 75, 111, 100, 97, 107, 32, 75, 111, 100, 97, 99, 104, 114, 111, 109,
  101, 32, 54, 52, 34, 44, 34, 76, 111, 109, 111, 103, 114, 97, 112, 104,
  121, 32, 88, 45, 80, 114, 111, 32, 83, 108, 105, 100, 101, 32, 50, 48,
  48, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 80, 111,
  108, 97, 114, 111, 105, 100, 32, 54, 54, 57, 34, 44, 34, 80, 111, 108,
  97, 114, 111, 105, 100, 32, 54, 57, 48, 34, 44, 34, 80, 111, 108, 97,
  114, 111, 105, 100, 32, 80, 111, 108, 97, 99, 104, 114, 111, 109, 101, 34,
  125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 71, 97, 109, 109, 97, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 49, 46, 50, 44, 49, 46, 50, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116, 114, 97, 115,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 114, 105, 103, 104, 116,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45,
  50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 72, 117, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  45, 49, 56, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 50, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 80, 111, 115, 116, 45, 110, 111, 114, 109, 97,
  108, 105, 122, 101, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105,
  99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 115, 58, 32,
  60, 105, 62, 80, 97, 116, 114, 105, 99, 107, 32, 68, 97, 118, 105, 100,
  60, 47, 105, 62, 32, 97, 110, 100, 32, 60, 105, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 51, 47, 48, 56, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 101, 109,
  117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 111, 114,
  115, 108, 105, 100, 101, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 101,
  109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 32, 36, 49, 44, 64,
  123, 45, 97, 114, 103, 92, 32, 36, 49, 44, 64, 123, 45, 95, 36, 48,
  125, 125, 44, 36, 123, 50, 45, 45, 49, 125, 10, 95, 103, 105, 109, 112,
  95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111,
  108, 111, 114, 115, 108, 105, 100, 101, 32, 58, 10, 45, 117, 32, 97, 103,
  102, 97, 95, 112, 114, 101, 99, 105, 115, 97, 95, 49, 48, 48, 44, 102,
  117, 106, 105, 95, 97, 115, 116, 105, 97, 95, 49, 48, 48, 102, 44, 102,
  117, 106, 105, 95, 102, 112, 95, 49, 48, 48, 99, 44, 102, 117, 106, 105,
  95, 112, 114, 111, 118, 105, 97, 95, 49, 48, 48, 102, 44, 102, 117, 106,
  105, 95, 112, 114, 111, 118, 105, 97, 95, 52, 48, 48, 102, 44, 102, 117,
  106, 105, 95, 112, 114, 111, 118, 105, 97, 95, 52, 48, 48, 120, 44, 102,
  117, 106, 105, 95, 115, 101, 110, 115, 105, 97, 95, 49, 48, 48, 44, 92,
  10, 102, 117, 106, 105, 95, 115, 117, 112, 101, 114, 105, 97, 95, 50, 48,
  48, 95, 120, 112, 114, 111, 44, 102, 117, 106, 105, 95, 118, 101, 108, 118,
  105, 97, 95, 53, 48, 44, 103, 101, 110, 101, 114, 105, 99, 95, 102, 117,
  106, 105, 95, 97, 115, 116, 105, 97, 95, 49, 48, 48, 44, 103, 101, 110,
  101, 114, 105, 99, 95, 102, 117, 106, 105, 95, 112, 114, 111, 118, 105, 97,
  95, 49, 48, 48, 44, 103, 101, 110, 101, 114, 105, 99, 95, 102, 117, 106,
  105, 95, 118, 101, 108, 118, 105, 97, 95, 49, 48, 48, 44, 92, 10, 103,
  101, 110, 101, 114, 105, 99, 95, 107, 111, 100, 97, 99, 104, 114, 111, 109,
  101, 95, 54, 52, 44, 103, 101, 110, 101, 114, 105, 99, 95, 107, 111, 100,
  97, 107, 95, 101, 107, 116, 97, 99, 104, 114, 111, 109, 101, 95, 49, 48,
  48, 95, 118, 115, 44, 107, 111, 100, 97, 107, 95, 101, 45, 49, 48, 48,
  95, 103, 120, 95, 101, 107, 116, 97, 99, 104, 114, 111, 109, 101, 95, 49,
  48, 48, 44, 107, 111, 100, 97, 107, 95, 101, 107, 116, 97, 99, 104, 114,
  111, 109, 101, 95, 49, 48, 48, 95, 118, 115, 44, 107, 111, 100, 97, 107,
  95, 101, 108, 105, 116, 101, 95, 99, 104, 114, 111, 109, 101, 95, 50, 48,
  48, 44, 92, 10, 107, 111, 100, 97, 107, 95, 101, 108, 105, 116, 101, 95,
  99, 104, 114, 111, 109, 101, 95, 52, 48, 48, 44, 107, 111, 100, 97, 107,
  95, 101, 108, 105, 116, 101, 95, 101, 120, 116, 114, 97, 99, 111, 108, 111,
  114, 95, 49, 48, 48, 44, 107, 111, 100, 97, 107, 95, 107, 111, 100, 97,
  99, 104, 114, 111, 109, 101, 95, 50, 48, 48, 44, 107, 111, 100, 97, 107,
  95, 107, 111, 100, 97, 99, 104, 114, 111, 109, 101, 95, 50, 53, 44, 107,
  111, 100, 97, 107, 95, 107, 111, 100, 97, 99, 104, 114, 111, 109, 101, 95,
  54, 52, 44, 108, 111, 109, 111, 103, 114, 97, 112, 104, 121, 95, 120, 45,
  112, 114, 111, 95, 115, 108, 105, 100, 101, 95, 50, 48, 48, 44, 92, 10,
  112, 111, 108, 97, 114, 111, 105, 100, 95, 54, 54, 57, 44, 112, 111, 108,
  97, 114, 111, 105, 100, 95, 54, 57, 48, 44, 112, 111, 108, 97, 114, 111,
  105, 100, 95, 112, 111, 108, 97, 99, 104, 114, 111, 109, 101, 10, 103, 105,
  109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95,
  99, 111, 108, 111, 114, 115, 108, 105, 100, 101, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95,
  101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108,
  111, 114, 115, 108, 105, 100, 101, 32, 36, 42, 34, 44, 36, 45, 49, 10,
  95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105,
  108, 109, 32, 58, 10, 45, 105, 102, 32, 36, 49, 10, 100, 105, 114, 61,
  64, 123, 45, 112, 97, 116, 104, 95, 117, 115, 101, 114, 125, 10, 45, 105,
  102, 32, 123, 33, 64, 123, 45, 105, 115, 95, 119, 105, 110, 100, 111, 119,
  115, 125, 125, 10, 100, 105, 114, 61, 36, 100, 105, 114, 47, 46, 103, 109,
  105, 99, 95, 102, 105, 108, 109, 95, 112, 114, 101, 115, 101, 116, 115, 10,
  45, 105, 102, 32, 36, 100, 105, 114, 32, 45, 101, 108, 115, 101, 32, 45,
  101, 120, 101, 99, 32, 34, 109, 107, 100, 105, 114, 32, 34, 36, 100, 105,
  114, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 110, 97, 114, 103, 40, 36, 95, 102, 111, 114, 99,
  101, 95, 114, 101, 100, 111, 119, 110, 108, 111, 97, 100, 41, 125, 10, 45,
  105, 32, 104, 116, 116, 112, 58, 47, 47, 103, 109, 105, 99, 46, 115, 111,
  117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 100, 97,
  116, 97, 95, 102, 105, 108, 109, 95, 112, 114, 101, 115, 101, 116, 115, 47,
  36, 50, 46, 99, 105, 109, 103, 122, 32, 45, 111, 91, 45, 49, 93, 32,
  36, 100, 105, 114, 47, 103, 109, 105, 99, 95, 36, 50, 46, 99, 105, 109,
  103, 122, 10, 45, 101, 108, 115, 101, 10, 45, 105, 102, 32, 36, 100, 105,
  114, 47, 103, 109, 105, 99, 95, 36, 50, 46, 99, 105, 109, 103, 122, 32,
  45, 105, 32, 36, 100, 105, 114, 47, 103, 109, 105, 99, 95, 36, 50, 46,
  99, 105, 109, 103, 122, 10, 45, 101, 108, 115, 101, 32, 45, 105, 32, 104,
  116, 116, 112, 58, 47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99,
  101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 100, 97, 116, 97, 95,
  102, 105, 108, 109, 95, 112, 114, 101, 115, 101, 116, 115, 47, 36, 50, 46,
  99, 105, 109, 103, 122, 32, 45, 111, 91, 45, 49, 93, 32, 36, 100, 105,
  114, 47, 103, 109, 105, 99, 95, 36, 50, 46, 99, 105, 109, 103, 122, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 109,
  97, 112, 95, 99, 108, 117, 116, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 10,
  45, 97, 112, 112, 108, 121, 95, 103, 97, 109, 109, 97, 91, 48, 93, 32,
  123, 49, 48, 94, 36, 51, 125, 10, 45, 45, 91, 48, 93, 32, 49, 50,
  56, 32, 45, 42, 91, 48, 93, 32, 36, 52, 32, 45, 43, 91, 48, 93,
  32, 49, 50, 56, 32, 45, 43, 91, 48, 93, 32, 36, 53, 32, 45, 99,
  91, 48, 93, 32, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36,
  54, 124, 124, 36, 55, 33, 61, 49, 124, 124, 36, 56, 125, 10, 45, 114,
  103, 98, 50, 104, 115, 118, 91, 48, 93, 10, 45, 115, 104, 91, 48, 93,
  32, 48, 44, 48, 32, 45, 43, 91, 45, 49, 93, 32, 36, 54, 32, 45,
  37, 91, 45, 49, 93, 32, 51, 54, 48, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 115, 104, 91, 48, 93, 32, 49, 44, 49, 32, 45, 42, 91,
  45, 49, 93, 32, 36, 55, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  104, 115, 118, 50, 114, 103, 98, 91, 48, 93, 10, 45, 105, 102, 32, 36,
  56, 32, 45, 110, 91, 48, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 97, 32, 99,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103,
  105, 109, 112, 32, 60, 105, 62, 91, 99, 111, 108, 108, 97, 103, 101, 115,
  93, 60, 47, 105, 62, 10, 35, 64, 103, 105, 109, 112, 32, 66, 38, 97,
  109, 112, 59, 87, 32, 102, 105, 108, 109, 115, 32, 45, 32, 99, 111, 108,
  108, 97, 103, 101, 32, 58, 32, 103, 105, 109, 112, 95, 101, 109, 117, 108,
  97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 108, 97, 103, 101,
  95, 98, 119, 44, 32, 103, 105, 109, 112, 95, 110, 111, 95, 112, 114, 101,
  118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 109,
  97, 103, 101, 32, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 53, 54, 44, 49, 54, 44, 49, 48, 50, 52, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 117, 109, 110, 115, 32, 102,
  111, 114, 32, 99, 111, 108, 108, 97, 103, 101, 32, 61, 32, 105, 110, 116,
  40, 52, 44, 49, 44, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 115, 109, 97, 108, 108, 62,
  60, 98, 62, 78, 111, 116, 101, 58, 60, 47, 98, 62, 32, 84, 104, 105,
  115, 32, 102, 105, 108, 116, 101, 114, 32, 119, 105, 108, 108, 32, 99, 114,
  101, 97, 116, 101, 32, 97, 32, 99, 111, 108, 108, 97, 103, 101, 32, 111,
  102, 32, 97, 108, 108, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 32,
  60, 105, 62, 66, 38, 97, 109, 112, 59, 87, 60, 47, 105, 62, 32, 102,
  105, 108, 109, 32, 101, 109, 117, 108, 97, 116, 105, 111, 110, 32, 112, 114,
  101, 115, 101, 116, 115, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 116,
  111, 32, 115, 104, 111, 119, 32, 121, 111, 117, 32, 104, 111, 119, 32, 116,
  104, 111, 115, 101, 32, 112, 114, 101, 115, 101, 116, 115, 32, 109, 111, 100,
  105, 102, 121, 32, 116, 104, 101, 32, 108, 111, 111, 107, 32, 111, 102, 32,
  121, 111, 117, 114, 32, 105, 109, 97, 103, 101, 46, 32, 73, 116, 32, 119,
  105, 108, 108, 32, 97, 108, 115, 111, 32, 100, 111, 119, 110, 108, 111, 97,
  100, 32, 97, 108, 108, 32, 99, 111, 114, 114, 101, 115, 112, 111, 110, 100,
  105, 110, 103, 32, 99, 111, 108, 111, 114, 32, 112, 114, 111, 102, 105, 108,
  101, 115, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 40, 116, 104, 105,
  115, 32, 109, 97, 121, 32, 116, 97, 107, 101, 32, 115, 111, 109, 101, 32,
  116, 105, 109, 101, 32, 97, 116, 32, 116, 104, 101, 32, 102, 105, 114, 115,
  116, 32, 114, 117, 110, 41, 46, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 60, 47, 115, 109, 97, 108, 108, 62, 34, 125, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 49,
  48, 47, 50, 56, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101,
  95, 102, 105, 108, 109, 95, 99, 111, 108, 108, 97, 103, 101, 95, 98, 119,
  32, 58, 10, 45, 107, 91, 48, 93, 32, 45, 105, 102, 32, 123, 109, 97,
  120, 40, 119, 44, 104, 41, 62, 36, 49, 125, 32, 45, 105, 102, 32, 123,
  119, 62, 104, 125, 32, 45, 114, 50, 100, 120, 32, 36, 49, 32, 45, 101,
  108, 115, 101, 32, 45, 114, 50, 100, 121, 32, 36, 49, 32, 45, 101, 110,
  100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 95, 110, 98, 99, 61,
  36, 50, 32, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116,
  101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 108, 97, 103, 101, 32, 64,
  123, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95,
  102, 105, 108, 109, 95, 98, 119, 125, 10, 35, 64, 103, 105, 109, 112, 32,
  73, 110, 115, 116, 97, 110, 116, 32, 45, 32, 99, 111, 108, 108, 97, 103,
  101, 32, 91, 99, 111, 110, 115, 117, 109, 101, 114, 93, 32, 58, 32, 103,
  105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109,
  95, 99, 111, 108, 108, 97, 103, 101, 95, 105, 110, 115, 116, 97, 110, 116,
  95, 99, 111, 110, 115, 117, 109, 101, 114, 44, 32, 103, 105, 109, 112, 95,
  110, 111, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 73, 109, 97, 103, 101, 32, 115, 105, 122, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 50, 53, 54, 44, 49, 54, 44, 49, 48,
  50, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108,
  117, 109, 110, 115, 32, 102, 111, 114, 32, 99, 111, 108, 108, 97, 103, 101,
  32, 61, 32, 105, 110, 116, 40, 52, 44, 49, 44, 56, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 123, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 78, 111,
  116, 101, 58, 60, 47, 98, 62, 32, 84, 104, 105, 115, 32, 102, 105, 108,
  116, 101, 114, 32, 119, 105, 108, 108, 32, 99, 114, 101, 97, 116, 101, 32,
  97, 32, 99, 111, 108, 108, 97, 103, 101, 32, 111, 102, 32, 97, 108, 108,
  32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 32, 60, 105, 62, 73, 110,
  115, 116, 97, 110, 116, 32, 91, 99, 111, 110, 115, 117, 109, 101, 114, 93,
  60, 47, 105, 62, 32, 102, 105, 108, 109, 32, 101, 109, 117, 108, 97, 116,
  105, 111, 110, 32, 112, 114, 101, 115, 101, 116, 115, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 116, 111, 32, 115, 104, 111, 119, 32, 121, 111, 117,
  32, 104, 111, 119, 32, 116, 104, 111, 115, 101, 32, 112, 114, 101, 115, 101,
  116, 115, 32, 109, 111, 100, 105, 102, 121, 32, 116, 104, 101, 32, 108, 111,
  111, 107, 32, 111, 102, 32, 121, 111, 117, 114, 32, 105, 109, 97, 103, 101,
  46, 32, 73, 116, 32, 119, 105, 108, 108, 32, 97, 108, 115, 111, 32, 100,
  111, 119, 110, 108, 111, 97, 100, 32, 97, 108, 108, 32, 99, 111, 114, 114,
  101, 115, 112, 111, 110, 100, 105, 110, 103, 32, 99, 111, 108, 111, 114, 32,
  112, 114, 111, 102, 105, 108, 101, 115, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 40, 116, 104, 105, 115, 32, 109, 97, 121, 32, 116, 97, 107, 101,
  32, 115, 111, 109, 101, 32, 116, 105, 109, 101, 32, 97, 116, 32, 116, 104,
  101, 32, 102, 105, 114, 115, 116, 32, 114, 117, 110, 41, 46, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118,
  105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50,
  51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62,
  50, 48, 49, 51, 47, 49, 48, 47, 50, 56, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 101,
  109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 108,
  97, 103, 101, 95, 105, 110, 115, 116, 97, 110, 116, 95, 99, 111, 110, 115,
  117, 109, 101, 114, 32, 58, 10, 45, 107, 91, 48, 93, 32, 45, 105, 102,
  32, 123, 109, 97, 120, 40, 119, 44, 104, 41, 62, 36, 49, 125, 32, 45,
  105, 102, 32, 123, 119, 62, 104, 125, 32, 45, 114, 50, 100, 120, 32, 36,
  49, 32, 45, 101, 108, 115, 101, 32, 45, 114, 50, 100, 121, 32, 36, 49,
  32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 95,
  110, 98, 99, 61, 36, 50, 32, 45, 95, 103, 105, 109, 112, 95, 101, 109,
  117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 108, 97,
  103, 101, 32, 64, 123, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108,
  97, 116, 101, 95, 102, 105, 108, 109, 95, 105, 110, 115, 116, 97, 110, 116,
  95, 99, 111, 110, 115, 117, 109, 101, 114, 125, 10, 35, 64, 103, 105, 109,
  112, 32, 73, 110, 115, 116, 97, 110, 116, 32, 45, 32, 99, 111, 108, 108,
  97, 103, 101, 32, 91, 112, 114, 111, 93, 32, 58, 32, 103, 105, 109, 112,
  95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111,
  108, 108, 97, 103, 101, 95, 105, 110, 115, 116, 97, 110, 116, 95, 112, 114,
  111, 44, 32, 103, 105, 109, 112, 95, 110, 111, 95, 112, 114, 101, 118, 105,
  101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 109, 97, 103,
  101, 32, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50,
  53, 54, 44, 49, 54, 44, 49, 48, 50, 52, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 111, 108, 117, 109, 110, 115, 32, 102, 111, 114,
  32, 99, 111, 108, 108, 97, 103, 101, 32, 61, 32, 105, 110, 116, 40, 52,
  44, 49, 44, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 115, 109, 97,
  108, 108, 62, 60, 98, 62, 78, 111, 116, 101, 58, 60, 47, 98, 62, 32,
  84, 104, 105, 115, 32, 102, 105, 108, 116, 101, 114, 32, 119, 105, 108, 108,
  32, 99, 114, 101, 97, 116, 101, 32, 97, 32, 99, 111, 108, 108, 97, 103,
  101, 32, 111, 102, 32, 97, 108, 108, 32, 97, 118, 97, 105, 108, 97, 98,
  108, 101, 32, 60, 105, 62, 73, 110, 115, 116, 97, 110, 116, 32, 91, 112,
  114, 111, 93, 60, 47, 105, 62, 32, 102, 105, 108, 109, 32, 101, 109, 117,
  108, 97, 116, 105, 111, 110, 32, 112, 114, 101, 115, 101, 116, 115, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 116, 111, 32, 115, 104, 111, 119, 32,
  121, 111, 117, 32, 104, 111, 119, 32, 116, 104, 111, 115, 101, 32, 112, 114,
  101, 115, 101, 116, 115, 32, 109, 111, 100, 105, 102, 121, 32, 116, 104, 101,
  32, 108, 111, 111, 107, 32, 111, 102, 32, 121, 111, 117, 114, 32, 105, 109,
  97, 103, 101, 46, 32, 73, 116, 32, 119, 105, 108, 108, 32, 97, 108, 115,
  111, 32, 100, 111, 119, 110, 108, 111, 97, 100, 32, 97, 108, 108, 32, 99,
  111, 114, 114, 101, 115, 112, 111, 110, 100, 105, 110, 103, 32, 99, 111, 108,
  111, 114, 32, 112, 114, 111, 102, 105, 108, 101, 115, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 40, 116, 104, 105, 115, 32, 109, 97, 121, 32, 116,
  97, 107, 101, 32, 115, 111, 109, 101, 32, 116, 105, 109, 101, 32, 97, 116,
  32, 116, 104, 101, 32, 102, 105, 114, 115, 116, 32, 114, 117, 110, 41, 46,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 51, 47, 49, 48, 47, 50, 56, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99,
  111, 108, 108, 97, 103, 101, 95, 105, 110, 115, 116, 97, 110, 116, 95, 112,
  114, 111, 32, 58, 10, 45, 107, 91, 48, 93, 32, 45, 105, 102, 32, 123,
  109, 97, 120, 40, 119, 44, 104, 41, 62, 36, 49, 125, 32, 45, 105, 102,
  32, 123, 119, 62, 104, 125, 32, 45, 114, 50, 100, 120, 32, 36, 49, 32,
  45, 101, 108, 115, 101, 32, 45, 114, 50, 100, 121, 32, 36, 49, 32, 45,
  101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 95, 110, 98,
  99, 61, 36, 50, 32, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108,
  97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 108, 97, 103, 101,
  32, 64, 123, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116,
  101, 95, 102, 105, 108, 109, 95, 105, 110, 115, 116, 97, 110, 116, 95, 112,
  114, 111, 125, 10, 35, 64, 103, 105, 109, 112, 32, 78, 101, 103, 97, 116,
  105, 118, 101, 32, 45, 32, 99, 111, 108, 108, 97, 103, 101, 32, 91, 99,
  111, 108, 111, 114, 93, 32, 58, 32, 103, 105, 109, 112, 95, 101, 109, 117,
  108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 108, 97, 103,
  101, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 99, 111, 108, 111, 114,
  44, 32, 103, 105, 109, 112, 95, 110, 111, 95, 112, 114, 101, 118, 105, 101,
  119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 109, 97, 103, 101,
  32, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 53,
  54, 44, 49, 54, 44, 49, 48, 50, 52, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 108, 117, 109, 110, 115, 32, 102, 111, 114, 32,
  99, 111, 108, 108, 97, 103, 101, 32, 61, 32, 105, 110, 116, 40, 52, 44,
  49, 44, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 115, 109, 97, 108,
  108, 62, 60, 98, 62, 78, 111, 116, 101, 58, 60, 47, 98, 62, 32, 84,
  104, 105, 115, 32, 102, 105, 108, 116, 101, 114, 32, 119, 105, 108, 108, 32,
  99, 114, 101, 97, 116, 101, 32, 97, 32, 99, 111, 108, 108, 97, 103, 101,
  32, 111, 102, 32, 97, 108, 108, 32, 97, 118, 97, 105, 108, 97, 98, 108,
  101, 32, 60, 105, 62, 78, 101, 103, 97, 116, 105, 118, 101, 32, 91, 99,
  111, 108, 111, 114, 93, 60, 47, 105, 62, 32, 102, 105, 108, 109, 32, 101,
  109, 117, 108, 97, 116, 105, 111, 110, 32, 112, 114, 101, 115, 101, 116, 115,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 116, 111, 32, 115, 104, 111,
  119, 32, 121, 111, 117, 32, 104, 111, 119, 32, 116, 104, 111, 115, 101, 32,
  112, 114, 101, 115, 101, 116, 115, 32, 109, 111, 100, 105, 102, 121, 32, 116,
  104, 101, 32, 108, 111, 111, 107, 32, 111, 102, 32, 121, 111, 117, 114, 32,
  105, 109, 97, 103, 101, 46, 32, 73, 116, 32, 119, 105, 108, 108, 32, 97,
  108, 115, 111, 32, 100, 111, 119, 110, 108, 111, 97, 100, 32, 97, 108, 108,
  32, 99, 111, 114, 114, 101, 115, 112, 111, 110, 100, 105, 110, 103, 32, 99,
  111, 108, 111, 114, 32, 112, 114, 111, 102, 105, 108, 101, 115, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 40, 116, 104, 105, 115, 32, 109, 97, 121,
  32, 116, 97, 107, 101, 32, 115, 111, 109, 101, 32, 116, 105, 109, 101, 32,
  97, 116, 32, 116, 104, 101, 32, 102, 105, 114, 115, 116, 32, 114, 117, 110,
  41, 46, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60,
  105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101,
  114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 49, 48, 47, 50, 56, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103,
  105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109,
  95, 99, 111, 108, 108, 97, 103, 101, 95, 110, 101, 103, 97, 116, 105, 118,
  101, 95, 99, 111, 108, 111, 114, 32, 58, 10, 45, 107, 91, 48, 93, 32,
  45, 105, 102, 32, 123, 109, 97, 120, 40, 119, 44, 104, 41, 62, 36, 49,
  125, 32, 45, 105, 102, 32, 123, 119, 62, 104, 125, 32, 45, 114, 50, 100,
  120, 32, 36, 49, 32, 45, 101, 108, 115, 101, 32, 45, 114, 50, 100, 121,
  32, 36, 49, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105,
  102, 10, 95, 110, 98, 99, 61, 36, 50, 32, 45, 95, 103, 105, 109, 112,
  95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111,
  108, 108, 97, 103, 101, 32, 64, 123, 45, 95, 103, 105, 109, 112, 95, 101,
  109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 110, 101, 103, 97,
  116, 105, 118, 101, 95, 99, 111, 108, 111, 114, 125, 10, 35, 64, 103, 105,
  109, 112, 32, 78, 101, 103, 97, 116, 105, 118, 101, 32, 45, 32, 99, 111,
  108, 108, 97, 103, 101, 32, 91, 110, 101, 119, 93, 32, 58, 32, 103, 105,
  109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95,
  99, 111, 108, 108, 97, 103, 101, 95, 110, 101, 103, 97, 116, 105, 118, 101,
  95, 110, 101, 119, 44, 32, 103, 105, 109, 112, 95, 110, 111, 95, 112, 114,
  101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73,
  109, 97, 103, 101, 32, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 50, 53, 54, 44, 49, 54, 44, 49, 48, 50, 52, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 117, 109, 110, 115, 32,
  102, 111, 114, 32, 99, 111, 108, 108, 97, 103, 101, 32, 61, 32, 105, 110,
  116, 40, 52, 44, 49, 44, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60,
  115, 109, 97, 108, 108, 62, 60, 98, 62, 78, 111, 116, 101, 58, 60, 47,
  98, 62, 32, 84, 104, 105, 115, 32, 102, 105, 108, 116, 101, 114, 32, 119,
  105, 108, 108, 32, 99, 114, 101, 97, 116, 101, 32, 97, 32, 99, 111, 108,
  108, 97, 103, 101, 32, 111, 102, 32, 97, 108, 108, 32, 97, 118, 97, 105,
  108, 97, 98, 108, 101, 32, 60, 105, 62, 78, 101, 103, 97, 116, 105, 118,
  101, 32, 91, 110, 101, 119, 93, 60, 47, 105, 62, 32, 102, 105, 108, 109,
  32, 101, 109, 117, 108, 97, 116, 105, 111, 110, 32, 112, 114, 101, 115, 101,
  116, 115, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 116, 111, 32, 115,
  104, 111, 119, 32, 121, 111, 117, 32, 104, 111, 119, 32, 116, 104, 111, 115,
  101, 32, 112, 114, 101, 115, 101, 116, 115, 32, 109, 111, 100, 105, 102, 121,
  32, 116, 104, 101, 32, 108, 111, 111, 107, 32, 111, 102, 32, 121, 111, 117,
  114, 32, 105, 109, 97, 103, 101, 46, 32, 73, 116, 32, 119, 105, 108, 108,
  32, 97, 108, 115, 111, 32, 100, 111, 119, 110, 108, 111, 97, 100, 32, 97,
  108, 108, 32, 99, 111, 114, 114, 101, 115, 112, 111, 110, 100, 105, 110, 103,
  32, 99, 111, 108, 111, 114, 32, 112, 114, 111, 102, 105, 108, 101, 115, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 40, 116, 104, 105, 115, 32, 109,
  97, 121, 32, 116, 97, 107, 101, 32, 115, 111, 109, 101, 32, 116, 105, 109,
  101, 32, 97, 116, 32, 116, 104, 101, 32, 102, 105, 114, 115, 116, 32, 114,
  117, 110, 41, 46, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109,
  112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 49, 48, 47, 50,
  56, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105,
  108, 109, 95, 99, 111, 108, 108, 97, 103, 101, 95, 110, 101, 103, 97, 116,
  105, 118, 101, 95, 110, 101, 119, 32, 58, 10, 45, 107, 91, 48, 93, 32,
  45, 105, 102, 32, 123, 109, 97, 120, 40, 119, 44, 104, 41, 62, 36, 49,
  125, 32, 45, 105, 102, 32, 123, 119, 62, 104, 125, 32, 45, 114, 50, 100,
  120, 32, 36, 49, 32, 45, 101, 108, 115, 101, 32, 45, 114, 50, 100, 121,
  32, 36, 49, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105,
  102, 10, 95, 110, 98, 99, 61, 36, 50, 32, 45, 95, 103, 105, 109, 112,
  95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111,
  108, 108, 97, 103, 101, 32, 64, 123, 45, 95, 103, 105, 109, 112, 95, 101,
  109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 110, 101, 103, 97,
  116, 105, 118, 101, 95, 110, 101, 119, 125, 10, 35, 64, 103, 105, 109, 112,
  32, 78, 101, 103, 97, 116, 105, 118, 101, 32, 45, 32, 99, 111, 108, 108,
  97, 103, 101, 32, 91, 111, 108, 100, 93, 32, 58, 32, 103, 105, 109, 112,
  95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111,
  108, 108, 97, 103, 101, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 111,
  108, 100, 44, 32, 103, 105, 109, 112, 95, 110, 111, 95, 112, 114, 101, 118,
  105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 109, 97,
  103, 101, 32, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  50, 53, 54, 44, 49, 54, 44, 49, 48, 50, 52, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 108, 117, 109, 110, 115, 32, 102, 111,
  114, 32, 99, 111, 108, 108, 97, 103, 101, 32, 61, 32, 105, 110, 116, 40,
  52, 44, 49, 44, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 115, 109,
  97, 108, 108, 62, 60, 98, 62, 78, 111, 116, 101, 58, 60, 47, 98, 62,
  32, 84, 104, 105, 115, 32, 102, 105, 108, 116, 101, 114, 32, 119, 105, 108,
  108, 32, 99, 114, 101, 97, 116, 101, 32, 97, 32, 99, 111, 108, 108, 97,
  103, 101, 32, 111, 102, 32, 97, 108, 108, 32, 97, 118, 97, 105, 108, 97,
  98, 108, 101, 32, 60, 105, 62, 78, 101, 103, 97, 116, 105, 118, 101, 32,
  91, 111, 108, 100, 93, 60, 47, 105, 62, 32, 102, 105, 108, 109, 32, 101,
  109, 117, 108, 97, 116, 105, 111, 110, 32, 112, 114, 101, 115, 101, 116, 115,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 116, 111, 32, 115, 104, 111,
  119, 32, 121, 111, 117, 32, 104, 111, 119, 32, 116, 104, 111, 115, 101, 32,
  112, 114, 101, 115, 101, 116, 115, 32, 109, 111, 100, 105, 102, 121, 32, 116,
  104, 101, 32, 108, 111, 111, 107, 32, 111, 102, 32, 121, 111, 117, 114, 32,
  105, 109, 97, 103, 101, 46, 32, 73, 116, 32, 119, 105, 108, 108, 32, 97,
  108, 115, 111, 32, 100, 111, 119, 110, 108, 111, 97, 100, 32, 97, 108, 108,
  32, 99, 111, 114, 114, 101, 115, 112, 111, 110, 100, 105, 110, 103, 32, 99,
  111, 108, 111, 114, 32, 112, 114, 111, 102, 105, 108, 101, 115, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 40, 116, 104, 105, 115, 32, 109, 97, 121,
  32, 116, 97, 107, 101, 32, 115, 111, 109, 101, 32, 116, 105, 109, 101, 32,
  97, 116, 32, 116, 104, 101, 32, 102, 105, 114, 115, 116, 32, 114, 117, 110,
  41, 46, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60,
  105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101,
  114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 49, 48, 47, 50, 56, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103,
  105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109,
  95, 99, 111, 108, 108, 97, 103, 101, 95, 110, 101, 103, 97, 116, 105, 118,
  101, 95, 111, 108, 100, 32, 58, 10, 45, 107, 91, 48, 93, 32, 45, 105,
  102, 32, 123, 109, 97, 120, 40, 119, 44, 104, 41, 62, 36, 49, 125, 32,
  45, 105, 102, 32, 123, 119, 62, 104, 125, 32, 45, 114, 50, 100, 120, 32,
  36, 49, 32, 45, 101, 108, 115, 101, 32, 45, 114, 50, 100, 121, 32, 36,
  49, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10,
  95, 110, 98, 99, 61, 36, 50, 32, 45, 95, 103, 105, 109, 112, 95, 101,
  109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 108,
  97, 103, 101, 32, 64, 123, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117,
  108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 110, 101, 103, 97, 116, 105,
  118, 101, 95, 111, 108, 100, 125, 10, 35, 64, 103, 105, 109, 112, 32, 79,
  116, 104, 101, 114, 32, 101, 102, 102, 101, 99, 116, 115, 32, 45, 32, 99,
  111, 108, 108, 97, 103, 101, 32, 58, 32, 103, 105, 109, 112, 95, 101, 109,
  117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 108, 97,
  103, 101, 95, 111, 116, 104, 101, 114, 115, 44, 32, 103, 105, 109, 112, 95,
  110, 111, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 73, 109, 97, 103, 101, 32, 115, 105, 122, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 50, 53, 54, 44, 49, 54, 44, 49, 48,
  50, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108,
  117, 109, 110, 115, 32, 102, 111, 114, 32, 99, 111, 108, 108, 97, 103, 101,
  32, 61, 32, 105, 110, 116, 40, 52, 44, 49, 44, 56, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 123, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 78, 111,
  116, 101, 58, 60, 47, 98, 62, 32, 84, 104, 105, 115, 32, 102, 105, 108,
  116, 101, 114, 32, 119, 105, 108, 108, 32, 99, 114, 101, 97, 116, 101, 32,
  97, 32, 99, 111, 108, 108, 97, 103, 101, 32, 111, 102, 32, 97, 108, 108,
  32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 32, 60, 105, 62, 79, 116,
  104, 101, 114, 115, 60, 47, 105, 62, 32, 102, 105, 108, 109, 32, 101, 109,
  117, 108, 97, 116, 105, 111, 110, 32, 112, 114, 101, 115, 101, 116, 115, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 116, 111, 32, 115, 104, 111, 119,
  32, 121, 111, 117, 32, 104, 111, 119, 32, 116, 104, 111, 115, 101, 32, 112,
  114, 101, 115, 101, 116, 115, 32, 109, 111, 100, 105, 102, 121, 32, 116, 104,
  101, 32, 108, 111, 111, 107, 32, 111, 102, 32, 121, 111, 117, 114, 32, 105,
  109, 97, 103, 101, 46, 32, 73, 116, 32, 119, 105, 108, 108, 32, 97, 108,
  115, 111, 32, 100, 111, 119, 110, 108, 111, 97, 100, 32, 97, 108, 108, 32,
  99, 111, 114, 114, 101, 115, 112, 111, 110, 100, 105, 110, 103, 32, 99, 111,
  108, 111, 114, 32, 112, 114, 111, 102, 105, 108, 101, 115, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 40, 116, 104, 105, 115, 32, 109, 97, 121, 32,
  116, 97, 107, 101, 32, 115, 111, 109, 101, 32, 116, 105, 109, 101, 32, 97,
  116, 32, 116, 104, 101, 32, 102, 105, 114, 115, 116, 32, 114, 117, 110, 41,
  46, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105,
  62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114,
  108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 51, 47, 49, 48, 47, 50, 56, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95,
  99, 111, 108, 108, 97, 103, 101, 95, 111, 116, 104, 101, 114, 115, 32, 58,
  10, 45, 107, 91, 48, 93, 32, 45, 105, 102, 32, 123, 109, 97, 120, 40,
  119, 44, 104, 41, 62, 36, 49, 125, 32, 45, 105, 102, 32, 123, 119, 62,
  104, 125, 32, 45, 114, 50, 100, 120, 32, 36, 49, 32, 45, 101, 108, 115,
  101, 32, 45, 114, 50, 100, 121, 32, 36, 49, 32, 45, 101, 110, 100, 105,
  102, 32, 45, 101, 110, 100, 105, 102, 10, 95, 110, 98, 99, 61, 36, 50,
  32, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95,
  102, 105, 108, 109, 95, 99, 111, 108, 108, 97, 103, 101, 32, 64, 123, 45,
  95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105,
  108, 109, 95, 111, 116, 104, 101, 114, 115, 125, 10, 35, 64, 103, 105, 109,
  112, 32, 83, 108, 105, 100, 101, 32, 45, 32, 99, 111, 108, 108, 97, 103,
  101, 32, 91, 99, 111, 108, 111, 114, 93, 32, 58, 32, 103, 105, 109, 112,
  95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111,
  108, 108, 97, 103, 101, 95, 99, 111, 108, 111, 114, 115, 108, 105, 100, 101,
  44, 32, 103, 105, 109, 112, 95, 110, 111, 95, 112, 114, 101, 118, 105, 101,
  119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 109, 97, 103, 101,
  32, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 53,
  54, 44, 49, 54, 44, 49, 48, 50, 52, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 108, 117, 109, 110, 115, 32, 102, 111, 114, 32,
  99, 111, 108, 108, 97, 103, 101, 32, 61, 32, 105, 110, 116, 40, 52, 44,
  49, 44, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 115, 109, 97, 108,
  108, 62, 60, 98, 62, 78, 111, 116, 101, 58, 60, 47, 98, 62, 32, 84,
  104, 105, 115, 32, 102, 105, 108, 116, 101, 114, 32, 119, 105, 108, 108, 32,
  99, 114, 101, 97, 116, 101, 32, 97, 32, 99, 111, 108, 108, 97, 103, 101,
  32, 111, 102, 32, 97, 108, 108, 32, 97, 118, 97, 105, 108, 97, 98, 108,
  101, 32, 60, 105, 62, 83, 108, 105, 100, 101, 32, 91, 99, 111, 108, 111,
  114, 93, 60, 47, 105, 62, 32, 102, 105, 108, 109, 32, 101, 109, 117, 108,
  97, 116, 105, 111, 110, 32, 112, 114, 101, 115, 101, 116, 115, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 116, 111, 32, 115, 104, 111, 119, 32, 121,
  111, 117, 32, 104, 111, 119, 32, 116, 104, 111, 115, 101, 32, 112, 114, 101,
  115, 101, 116, 115, 32, 109, 111, 100, 105, 102, 121, 32, 116, 104, 101, 32,
  108, 111, 111, 107, 32, 111, 102, 32, 121, 111, 117, 114, 32, 105, 109, 97,
  103, 101, 46, 32, 73, 116, 32, 119, 105, 108, 108, 32, 97, 108, 115, 111,
  32, 100, 111, 119, 110, 108, 111, 97, 100, 32, 97, 108, 108, 32, 99, 111,
  114, 114, 101, 115, 112, 111, 110, 100, 105, 110, 103, 32, 99, 111, 108, 111,
  114, 32, 112, 114, 111, 102, 105, 108, 101, 115, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 40, 116, 104, 105, 115, 32, 109, 97, 121, 32, 116, 97,
  107, 101, 32, 115, 111, 109, 101, 32, 116, 105, 109, 101, 32, 97, 116, 32,
  116, 104, 101, 32, 102, 105, 114, 115, 116, 32, 114, 117, 110, 41, 46, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68,
  97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38,
  35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 51, 47, 49, 48, 47, 50, 56, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112,
  95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 99, 111,
  108, 108, 97, 103, 101, 95, 99, 111, 108, 111, 114, 115, 108, 105, 100, 101,
  32, 58, 10, 45, 107, 91, 48, 93, 32, 45, 105, 102, 32, 123, 109, 97,
  120, 40, 119, 44, 104, 41, 62, 36, 49, 125, 32, 45, 105, 102, 32, 123,
  119, 62, 104, 125, 32, 45, 114, 50, 100, 120, 32, 36, 49, 32, 45, 101,
  108, 115, 101, 32, 45, 114, 50, 100, 121, 32, 36, 49, 32, 45, 101, 110,
  100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 95, 110, 98, 99, 61,
  36, 50, 32, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116,
  101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 108, 97, 103, 101, 32, 64,
  123, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95,
  102, 105, 108, 109, 95, 99, 111, 108, 111, 114, 115, 108, 105, 100, 101, 125,
  10, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102,
  105, 108, 109, 95, 99, 111, 108, 108, 97, 103, 101, 32, 58, 10, 36, 61,
  97, 114, 103, 32, 45, 112, 114, 111, 103, 114, 101, 115, 115, 32, 48, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 36, 35, 10, 112, 114, 101, 115, 101,
  116, 61, 36, 123, 97, 114, 103, 123, 36, 62, 43, 49, 125, 125, 10, 45,
  45, 108, 91, 48, 93, 10, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117,
  108, 97, 116, 101, 95, 102, 105, 108, 109, 91, 48, 93, 32, 49, 44, 36,
  112, 114, 101, 115, 101, 116, 44, 48, 44, 49, 44, 48, 44, 48, 44, 49,
  44, 48, 10, 40, 123, 39, 36, 112, 114, 101, 115, 101, 116, 39, 125, 41,
  32, 45, 114, 101, 112, 108, 97, 99, 101, 91, 45, 49, 93, 32, 123, 39,
  95, 39, 125, 44, 51, 50, 32, 45, 102, 91, 45, 49, 93, 32, 105, 102,
  40, 120, 61, 61, 48, 38, 38, 105, 62, 61, 123, 39, 97, 39, 125, 38,
  38, 105, 60, 61, 123, 39, 122, 39, 125, 44, 105, 43, 123, 39, 65, 39,
  125, 45, 123, 39, 97, 39, 125, 44, 105, 41, 32, 116, 105, 116, 108, 101,
  61, 64, 123, 45, 49, 44, 116, 125, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 116, 101, 120, 116, 95, 111, 117, 116, 108, 105, 110, 101, 91, 45,
  49, 93, 32, 36, 116, 105, 116, 108, 101, 44, 50, 44, 50, 44, 49, 51,
  44, 50, 44, 49, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 10, 45,
  112, 114, 111, 103, 114, 101, 115, 115, 32, 123, 40, 49, 43, 36, 62, 41,
  42, 49, 48, 48, 47, 36, 35, 125, 10, 45, 100, 111, 110, 101, 10, 45,
  116, 101, 120, 116, 95, 111, 117, 116, 108, 105, 110, 101, 91, 48, 93, 32,
  34, 79, 114, 105, 103, 105, 110, 97, 108, 32, 105, 109, 97, 103, 101, 34,
  44, 50, 44, 50, 44, 49, 51, 44, 50, 44, 49, 44, 50, 53, 53, 10,
  45, 102, 114, 97, 109, 101, 32, 49, 44, 49, 44, 48, 32, 45, 102, 114,
  97, 109, 101, 32, 53, 44, 53, 44, 50, 53, 53, 32, 45, 45, 32, 50,
  53, 53, 32, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115,
  32, 123, 109, 105, 110, 40, 36, 95, 110, 98, 99, 44, 64, 35, 41, 125,
  32, 45, 43, 32, 50, 53, 53, 10, 35, 64, 103, 105, 109, 112, 32, 95,
  10, 35, 64, 103, 105, 109, 112, 32, 91, 100, 111, 119, 110, 108, 111, 97,
  100, 32, 97, 108, 108, 32, 112, 114, 101, 115, 101, 116, 115, 93, 32, 58,
  32, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105,
  108, 109, 95, 100, 111, 119, 110, 108, 111, 97, 100, 44, 32, 103, 105, 109,
  112, 95, 110, 111, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 123, 34, 84, 104, 105, 115, 32, 102, 105, 108, 116, 101,
  114, 32, 119, 105, 108, 108, 32, 100, 111, 119, 110, 108, 111, 97, 100, 32,
  116, 104, 101, 32, 99, 111, 108, 111, 114, 32, 112, 114, 111, 102, 105, 108,
  101, 115, 32, 102, 111, 114, 32, 97, 108, 108, 32, 102, 105, 108, 109, 32,
  101, 109, 117, 108, 97, 116, 105, 111, 110, 32, 112, 114, 101, 115, 101, 116,
  115, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 32, 105, 110, 32, 60,
  105, 62, 71, 39, 77, 73, 67, 60, 47, 105, 62, 44, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 97, 110, 100, 32, 119, 105, 108, 108, 32, 115,
  116, 111, 114, 101, 32, 116, 104, 101, 109, 32, 97, 115, 32, 112, 101, 114,
  115, 105, 115, 116, 101, 110, 116, 32, 100, 97, 116, 97, 32, 102, 105, 108,
  101, 115, 32, 111, 110, 32, 121, 111, 117, 114, 32, 104, 97, 114, 100, 32,
  100, 114, 105, 118, 101, 46, 32, 65, 102, 116, 101, 114, 32, 116, 104, 105,
  115, 32, 111, 112, 101, 114, 97, 116, 105, 111, 110, 44, 32, 121, 111, 117,
  32, 119, 111, 110, 39, 116, 32, 110, 101, 101, 100, 32, 97, 32, 112, 101,
  114, 109, 97, 110, 101, 110, 116, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 105, 110, 116, 101, 114, 110, 101, 116, 32, 99, 111, 110, 110, 101, 99,
  116, 105, 111, 110, 32, 97, 110, 121, 109, 111, 114, 101, 44, 32, 105, 110,
  32, 111, 114, 100, 101, 114, 32, 116, 111, 32, 117, 115, 101, 32, 116, 104,
  101, 32, 102, 105, 108, 109, 32, 101, 109, 117, 108, 97, 116, 105, 111, 110,
  32, 102, 105, 108, 116, 101, 114, 115, 46, 34, 125, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 98, 62, 60, 115, 112, 97,
  110, 32, 99, 111, 108, 111, 114, 61, 34, 114, 101, 100, 34, 62, 87, 97,
  114, 110, 105, 110, 103, 58, 60, 47, 115, 112, 97, 110, 62, 60, 47, 98,
  62, 32, 65, 98, 111, 117, 116, 32, 60, 98, 62, 56, 48, 32, 77, 98,
  60, 47, 98, 62, 32, 111, 102, 32, 100, 97, 116, 97, 32, 119, 105, 108,
  108, 32, 98, 101, 32, 100, 111, 119, 110, 108, 111, 97, 100, 101, 100, 32,
  98, 121, 32, 116, 104, 105, 115, 32, 102, 105, 108, 116, 101, 114, 46, 32,
  84, 104, 105, 115, 32, 99, 97, 110, 32, 116, 97, 107, 101, 32, 97, 32,
  108, 111, 110, 103, 32, 116, 105, 109, 101, 32, 33, 34, 125, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 70, 111, 114, 99, 101, 32, 114, 101, 45, 100, 111, 119, 110, 108,
  111, 97, 100, 32, 61, 32, 95, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65,
  117, 116, 104, 111, 114, 115, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 51, 47, 49, 48, 47, 50, 56, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 101, 109, 117,
  108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 100, 111, 119, 110, 108, 111,
  97, 100, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108,
  97, 116, 101, 95, 102, 105, 108, 109, 95, 100, 111, 119, 110, 108, 111, 97,
  100, 32, 64, 123, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97,
  116, 101, 95, 102, 105, 108, 109, 95, 98, 119, 125, 44, 92, 10, 64, 123,
  45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102,
  105, 108, 109, 95, 105, 110, 115, 116, 97, 110, 116, 95, 99, 111, 110, 115,
  117, 109, 101, 114, 125, 44, 92, 10, 64, 123, 45, 95, 103, 105, 109, 112,
  95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 105, 110,
  115, 116, 97, 110, 116, 95, 112, 114, 111, 125, 44, 92, 10, 64, 123, 45,
  95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105,
  108, 109, 95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 99, 111, 108, 111,
  114, 125, 44, 92, 10, 64, 123, 45, 95, 103, 105, 109, 112, 95, 101, 109,
  117, 108, 97, 116, 101, 95, 102, 105, 108, 109, 95, 110, 101, 103, 97, 116,
  105, 118, 101, 95, 110, 101, 119, 125, 44, 92, 10, 64, 123, 45, 95, 103,
  105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109,
  95, 110, 101, 103, 97, 116, 105, 118, 101, 95, 111, 108, 100, 125, 44, 92,
  10, 64, 123, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116,
  101, 95, 102, 105, 108, 109, 95, 111, 116, 104, 101, 114, 115, 125, 44, 92,
  10, 64, 123, 45, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116,
  101, 95, 102, 105, 108, 109, 95, 99, 111, 108, 111, 114, 115, 108, 105, 100,
  101, 125, 10, 45, 108, 91, 93, 32, 49, 32, 45, 112, 114, 111, 103, 114,
  101, 115, 115, 32, 48, 10, 45, 105, 102, 32, 36, 49, 32, 95, 102, 111,
  114, 99, 101, 95, 114, 101, 100, 111, 119, 110, 108, 111, 97, 100, 61, 49,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  36, 95, 110, 98, 95, 112, 114, 101, 115, 101, 116, 115, 32, 45, 95, 103,
  105, 109, 112, 95, 101, 109, 117, 108, 97, 116, 101, 95, 102, 105, 108, 109,
  32, 49, 44, 36, 123, 95, 112, 114, 101, 115, 101, 116, 123, 49, 43, 36,
  62, 125, 125, 44, 49, 44, 49, 44, 48, 44, 48, 44, 49, 44, 48, 32,
  45, 112, 114, 111, 103, 114, 101, 115, 115, 32, 123, 40, 36, 62, 43, 49,
  41, 42, 49, 48, 48, 47, 36, 95, 110, 98, 95, 112, 114, 101, 115, 101,
  116, 115, 125, 32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 32, 45, 101,
  110, 100, 108, 10, 95, 103, 105, 109, 112, 95, 101, 109, 117, 108, 97, 116,
  101, 95, 102, 105, 108, 109, 95, 100, 111, 119, 110, 108, 111, 97, 100, 32,
  58, 10, 95, 110, 98, 95, 112, 114, 101, 115, 101, 116, 115, 61, 36, 35,
  10, 36, 61, 95, 112, 114, 101, 115, 101, 116, 10, 35, 64, 103, 105, 109,
  112, 32, 95, 10, 35, 64, 103, 105, 109, 112, 32, 60, 98, 62, 70, 114,
  97, 109, 101, 115, 60, 47, 98, 62, 10, 35, 64, 103, 105, 109, 112, 32,
  68, 114, 111, 115, 116, 101, 32, 58, 32, 103, 105, 109, 112, 95, 100, 114,
  111, 115, 116, 101, 44, 32, 103, 105, 109, 112, 95, 100, 114, 111, 115, 116,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 112, 97, 110, 32, 99, 111, 108, 111, 114, 61, 92,
  34, 114, 101, 100, 92, 34, 62, 85, 112, 112, 101, 114, 45, 108, 101, 102,
  116, 32, 99, 111, 111, 114, 100, 105, 110, 97, 116, 101, 115, 32, 58, 60,
  47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 48, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  89, 48, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  112, 97, 110, 32, 99, 111, 108, 111, 114, 61, 92, 34, 109, 97, 103, 101,
  110, 116, 97, 92, 34, 62, 85, 112, 112, 101, 114, 45, 114, 105, 103, 104,
  116, 32, 99, 111, 111, 114, 100, 105, 110, 97, 116, 101, 115, 32, 58, 60,
  47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 49, 32, 61, 32, 102, 108, 111, 97, 116, 40, 56, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  89, 49, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  112, 97, 110, 32, 99, 111, 108, 111, 114, 61, 92, 34, 98, 108, 117, 101,
  92, 34, 62, 76, 111, 119, 101, 114, 45, 114, 105, 103, 104, 116, 32, 99,
  111, 111, 114, 100, 105, 110, 97, 116, 101, 115, 32, 58, 60, 47, 115, 112,
  97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88,
  50, 32, 61, 32, 102, 108, 111, 97, 116, 40, 56, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 50, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 56, 48, 44, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110,
  32, 99, 111, 108, 111, 114, 61, 92, 34, 99, 121, 97, 110, 92, 34, 62,
  76, 111, 119, 101, 114, 45, 108, 101, 102, 116, 32, 99, 111, 111, 114, 100,
  105, 110, 97, 116, 101, 115, 32, 58, 60, 47, 115, 112, 97, 110, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 51, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 50, 48, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 51, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 56, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105,
  110, 116, 40, 49, 44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 88, 45, 115, 104, 105, 102, 116, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 115, 104, 105, 102, 116,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 48, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110,
  103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 111,
  111, 109, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 46, 49,
  44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 105, 114,
  114, 111, 114, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 78, 111,
  110, 101, 34, 44, 34, 120, 45, 97, 120, 105, 115, 34, 44, 34, 121, 45,
  97, 120, 105, 115, 34, 44, 34, 120, 121, 45, 97, 120, 101, 115, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 111, 117, 110, 100, 97,
  114, 121, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 66,
  108, 97, 99, 107, 34, 44, 34, 78, 101, 97, 114, 101, 115, 116, 34, 44,
  34, 82, 101, 112, 101, 97, 116, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 68, 114, 97, 119, 105, 110, 103, 32, 109, 111, 100, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 123, 34, 82, 101, 112, 108, 97, 99,
  101, 34, 44, 34, 82, 101, 112, 108, 97, 99, 101, 32, 40, 115, 104, 97,
  114, 112, 101, 115, 116, 41, 34, 44, 34, 66, 101, 104, 105, 110, 100, 34,
  44, 34, 66, 101, 108, 111, 119, 34, 125, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 86, 105, 101, 119, 32, 111, 117, 116, 108, 105, 110, 101, 115,
  32, 111, 110, 108, 121, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 50, 47, 48, 54, 47, 49, 49, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 100, 114, 111,
  115, 116, 101, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  10, 45, 105, 102, 32, 123, 36, 49, 54, 61, 61, 49, 125, 32, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 39, 120, 39, 32,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 39, 121,
  39, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 57, 10,
  120, 48, 61, 123, 114, 111, 117, 110, 100, 40, 36, 49, 42, 119, 47, 49,
  48, 48, 41, 125, 32, 121, 48, 61, 123, 114, 111, 117, 110, 100, 40, 36,
  50, 42, 104, 47, 49, 48, 48, 41, 125, 32, 120, 49, 61, 123, 114, 111,
  117, 110, 100, 40, 36, 51, 42, 119, 47, 49, 48, 48, 41, 125, 32, 121,
  49, 61, 123, 114, 111, 117, 110, 100, 40, 36, 52, 42, 104, 47, 49, 48,
  48, 41, 125, 10, 120, 50, 61, 123, 114, 111, 117, 110, 100, 40, 36, 53,
  42, 119, 47, 49, 48, 48, 41, 125, 32, 121, 50, 61, 123, 114, 111, 117,
  110, 100, 40, 36, 54, 42, 104, 47, 49, 48, 48, 41, 125, 32, 120, 51,
  61, 123, 114, 111, 117, 110, 100, 40, 36, 55, 42, 119, 47, 49, 48, 48,
  41, 125, 32, 121, 51, 61, 123, 114, 111, 117, 110, 100, 40, 36, 56, 42,
  104, 47, 49, 48, 48, 41, 125, 10, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 44, 49, 44, 50, 44, 45, 51, 50, 55, 54, 55, 32, 45, 112, 111,
  108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 52, 44, 36, 120, 48, 44,
  36, 121, 48, 44, 36, 120, 49, 44, 36, 121, 49, 44, 36, 120, 50, 44,
  36, 121, 50, 44, 36, 120, 51, 44, 36, 121, 51, 44, 49, 44, 45, 54,
  53, 53, 51, 53, 10, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 48,
  32, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102, 40, 105, 61, 61, 45,
  54, 53, 53, 51, 53, 44, 120, 48, 51, 61, 36, 120, 48, 43, 40, 121,
  45, 36, 121, 48, 41, 47, 40, 36, 121, 51, 45, 36, 121, 48, 41, 42,
  40, 36, 120, 51, 45, 36, 120, 48, 41, 59, 120, 49, 50, 61, 36, 120,
  49, 43, 40, 121, 45, 36, 121, 49, 41, 47, 40, 36, 121, 50, 45, 36,
  121, 49, 41, 42, 40, 36, 120, 50, 45, 36, 120, 49, 41, 59, 40, 120,
  45, 120, 48, 51, 41, 47, 40, 120, 49, 50, 45, 120, 48, 51, 41, 42,
  40, 119, 45, 49, 41, 44, 105, 41, 39, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 115, 104, 91, 45, 49, 93, 32, 49, 44, 49, 32, 45, 102,
  91, 45, 49, 93, 32, 39, 105, 102, 40, 105, 61, 61, 45, 54, 53, 53,
  51, 53, 44, 121, 48, 49, 61, 36, 121, 48, 43, 40, 120, 45, 36, 120,
  48, 41, 47, 40, 36, 120, 49, 45, 36, 120, 48, 41, 42, 40, 36, 121,
  49, 45, 36, 121, 48, 41, 59, 121, 51, 50, 61, 36, 121, 51, 43, 40,
  120, 45, 36, 120, 51, 41, 47, 40, 36, 120, 50, 45, 36, 120, 51, 41,
  42, 40, 36, 121, 50, 45, 36, 121, 51, 41, 59, 40, 121, 45, 121, 48,
  49, 41, 47, 40, 121, 51, 50, 45, 121, 48, 49, 41, 42, 40, 104, 45,
  49, 41, 44, 105, 41, 39, 32, 45, 114, 109, 91, 45, 49, 93, 10, 120,
  115, 104, 105, 102, 116, 61, 123, 119, 42, 36, 49, 48, 47, 49, 48, 48,
  125, 32, 121, 115, 104, 105, 102, 116, 61, 123, 104, 42, 36, 49, 49, 47,
  49, 48, 48, 125, 32, 97, 108, 112, 104, 97, 61, 123, 45, 36, 49, 50,
  42, 112, 105, 47, 49, 56, 48, 125, 32, 99, 97, 61, 123, 99, 111, 115,
  40, 36, 97, 108, 112, 104, 97, 41, 47, 36, 49, 51, 125, 32, 115, 97,
  61, 123, 115, 105, 110, 40, 36, 97, 108, 112, 104, 97, 41, 47, 36, 49,
  51, 125, 32, 119, 50, 61, 123, 119, 47, 50, 125, 32, 104, 50, 61, 123,
  104, 47, 50, 125, 10, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102, 40,
  105, 61, 61, 45, 51, 50, 55, 54, 55, 44, 105, 44, 88, 61, 105, 40,
  120, 44, 121, 44, 48, 44, 48, 41, 45, 36, 119, 50, 59, 89, 61, 105,
  40, 120, 44, 121, 44, 48, 44, 49, 41, 45, 36, 104, 50, 59, 105, 102,
  40, 99, 61, 61, 48, 44, 36, 119, 50, 45, 36, 120, 115, 104, 105, 102,
  116, 43, 88, 42, 36, 99, 97, 45, 89, 42, 36, 115, 97, 44, 36, 104,
  50, 45, 36, 121, 115, 104, 105, 102, 116, 43, 88, 42, 36, 115, 97, 43,
  89, 42, 36, 99, 97, 41, 41, 39, 10, 45, 105, 102, 32, 123, 36, 49,
  52, 61, 61, 48, 125, 32, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44,
  48, 32, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102, 40, 105, 61, 61,
  45, 51, 50, 55, 54, 55, 44, 120, 44, 105, 41, 39, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 115, 104, 91, 45, 49, 93, 32, 49, 44, 49,
  32, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102, 40, 105, 61, 61, 45,
  51, 50, 55, 54, 55, 44, 121, 44, 105, 41, 39, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 52, 61, 61,
  49, 125, 32, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 48, 32, 45,
  102, 91, 45, 49, 93, 32, 39, 105, 102, 40, 105, 61, 61, 45, 51, 50,
  55, 54, 55, 44, 120, 44, 119, 45, 49, 45, 105, 41, 39, 32, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 115, 104, 91, 45, 49, 93, 32, 49, 44,
  49, 32, 45, 102, 91, 45, 49, 93, 32, 39, 105, 102, 40, 105, 61, 61,
  45, 51, 50, 55, 54, 55, 44, 121, 44, 105, 41, 39, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 52, 61,
  61, 50, 125, 32, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 48, 32,
  45, 102, 91, 45, 49, 93, 32, 39, 105, 102, 40, 105, 61, 61, 45, 51,
  50, 55, 54, 55, 44, 120, 44, 105, 41, 39, 32, 45, 114, 109, 91, 45,
  49, 93, 32, 45, 115, 104, 91, 45, 49, 93, 32, 49, 44, 49, 32, 45,
  102, 91, 45, 49, 93, 32, 39, 105, 102, 40, 105, 61, 61, 45, 51, 50,
  55, 54, 55, 44, 121, 44, 104, 45, 49, 45, 105, 41, 39, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 101, 108, 115, 101, 32, 45, 115, 104, 91,
  45, 49, 93, 32, 48, 44, 48, 32, 45, 102, 91, 45, 49, 93, 32, 39,
  105, 102, 40, 105, 61, 61, 45, 51, 50, 55, 54, 55, 44, 120, 44, 119,
  45, 49, 45, 105, 41, 39, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  115, 104, 91, 45, 49, 93, 32, 49, 44, 49, 32, 45, 102, 91, 45, 49,
  93, 32, 39, 105, 102, 40, 105, 61, 61, 45, 51, 50, 55, 54, 55, 44,
  121, 44, 104, 45, 49, 45, 105, 41, 39, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49,
  54, 60, 50, 125, 32, 45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91,
  45, 49, 93, 44, 48, 44, 123, 36, 49, 54, 61, 61, 48, 125, 44, 36,
  49, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 115, 101,
  10, 45, 45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  44, 48, 44, 49, 44, 36, 49, 53, 32, 45, 114, 109, 91, 45, 50, 93,
  10, 45, 105, 102, 32, 123, 36, 49, 54, 61, 61, 51, 125, 32, 45, 114,
  118, 91, 45, 50, 44, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 98, 108, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 97, 108,
  112, 104, 97, 10, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101,
  10, 45, 105, 102, 32, 123, 36, 49, 54, 61, 61, 49, 125, 32, 45, 119,
  97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 49,
  44, 49, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110,
  101, 10, 103, 105, 109, 112, 95, 100, 114, 111, 115, 116, 101, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 105, 102, 32, 123, 33, 36, 49,
  55, 125, 32, 45, 103, 105, 109, 112, 95, 100, 114, 111, 115, 116, 101, 32,
  36, 42, 32, 45, 101, 108, 115, 101, 32, 45, 112, 111, 108, 121, 103, 111,
  110, 32, 52, 44, 36, 49, 37, 44, 36, 50, 37, 44, 36, 51, 37, 44,
  36, 52, 37, 44, 36, 53, 37, 44, 36, 54, 37, 44, 36, 55, 37, 44,
  36, 56, 37, 44, 48, 46, 51, 44, 48, 44, 48, 44, 48, 44, 50, 53,
  53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 112, 111, 108, 121, 103, 111,
  110, 32, 52, 44, 36, 49, 37, 44, 36, 50, 37, 44, 36, 51, 37, 44,
  36, 52, 37, 44, 36, 53, 37, 44, 36, 54, 37, 44, 36, 55, 37, 44,
  36, 56, 37, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70,
  44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 10, 45, 101, 108, 108, 105,
  112, 115, 101, 32, 36, 49, 37, 44, 36, 50, 37, 44, 51, 44, 51, 44,
  48, 44, 49, 44, 50, 53, 53, 44, 48, 44, 48, 44, 50, 53, 53, 32,
  45, 101, 108, 108, 105, 112, 115, 101, 32, 36, 49, 37, 44, 36, 50, 37,
  44, 51, 44, 51, 44, 48, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70,
  70, 70, 70, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 10, 45, 101,
  108, 108, 105, 112, 115, 101, 32, 36, 51, 37, 44, 36, 52, 37, 44, 51,
  44, 51, 44, 48, 44, 49, 44, 50, 53, 53, 44, 48, 44, 50, 53, 53,
  44, 50, 53, 53, 32, 45, 101, 108, 108, 105, 112, 115, 101, 32, 36, 51,
  37, 44, 36, 52, 37, 44, 51, 44, 51, 44, 48, 44, 49, 44, 48, 120,
  70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 44, 48, 44, 48, 44, 50,
  53, 53, 10, 45, 101, 108, 108, 105, 112, 115, 101, 32, 36, 53, 37, 44,
  36, 54, 37, 44, 51, 44, 51, 44, 48, 44, 49, 44, 48, 44, 48, 44,
  50, 53, 53, 44, 50, 53, 53, 32, 45, 101, 108, 108, 105, 112, 115, 101,
  32, 36, 53, 37, 44, 36, 54, 37, 44, 51, 44, 51, 44, 48, 44, 49,
  44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 44, 48, 44,
  48, 44, 50, 53, 53, 10, 45, 101, 108, 108, 105, 112, 115, 101, 32, 36,
  55, 37, 44, 36, 56, 37, 44, 51, 44, 51, 44, 48, 44, 49, 44, 48,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 101, 108,
  108, 105, 112, 115, 101, 32, 36, 55, 37, 44, 36, 56, 37, 44, 51, 44,
  51, 44, 48, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70,
  44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 10, 35, 64, 103, 105, 109,
  112, 32, 70, 114, 97, 109, 101, 32, 91, 98, 108, 117, 114, 93, 32, 58,
  32, 103, 105, 109, 112, 95, 102, 114, 97, 109, 101, 95, 98, 108, 117, 114,
  44, 32, 103, 105, 109, 112, 95, 102, 114, 97, 109, 101, 95, 98, 108, 117,
  114, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 105,
  122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 48, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 114,
  111, 112, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 117,
  114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 111, 117, 110, 100,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 112, 112,
  108, 121, 32, 99, 111, 108, 111, 114, 32, 98, 97, 108, 97, 110, 99, 101,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 66, 97, 108, 97, 110, 99, 101, 32, 99, 111, 108, 111,
  114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 49, 50, 56, 44, 49, 50,
  56, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 78, 111, 110, 101, 34, 44, 34, 83,
  116, 114, 101, 116, 99, 104, 34, 44, 34, 69, 113, 117, 97, 108, 105, 122,
  101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 108, 105, 110, 101, 32,
  115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48,
  44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117,
  116, 108, 105, 110, 101, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111,
  108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 115, 104, 97, 100,
  111, 119, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 45, 49, 48,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45,
  115, 104, 97, 100, 111, 119, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50,
  44, 45, 49, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 104, 97, 100, 111, 119, 32, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 100,
  111, 119, 32, 99, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115,
  99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47,
  48, 49, 47, 49, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 102, 114, 97, 109, 101, 95,
  98, 108, 117, 114, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 116, 111, 95, 114, 103, 98,
  10, 45, 45, 114, 32, 123, 49, 48, 48, 43, 36, 49, 125, 37, 44, 123,
  49, 48, 48, 43, 36, 49, 125, 37, 44, 49, 44, 49, 48, 48, 37, 44,
  51, 32, 45, 98, 91, 49, 93, 32, 36, 51, 37, 10, 45, 105, 102, 32,
  36, 53, 32, 45, 98, 97, 108, 97, 110, 99, 101, 95, 103, 97, 109, 109,
  97, 91, 49, 93, 32, 36, 123, 54, 45, 56, 125, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 57, 61, 61, 49, 125, 32, 45,
  110, 91, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 105, 102,
  32, 123, 36, 57, 61, 61, 50, 125, 32, 45, 110, 91, 49, 93, 32, 48,
  44, 50, 53, 53, 32, 45, 101, 113, 117, 97, 108, 105, 122, 101, 91, 49,
  93, 32, 50, 53, 54, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 118,
  10, 45, 122, 91, 49, 93, 32, 123, 36, 50, 47, 50, 125, 37, 44, 123,
  36, 50, 47, 50, 125, 37, 44, 123, 49, 48, 48, 45, 36, 50, 47, 50,
  125, 37, 44, 123, 49, 48, 48, 45, 36, 50, 47, 50, 125, 37, 10, 45,
  116, 111, 95, 114, 103, 98, 97, 91, 49, 93, 10, 45, 105, 102, 32, 36,
  52, 32, 114, 61, 123, 49, 43, 49, 47, 36, 52, 125, 32, 45, 115, 104,
  91, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 102,
  91, 45, 49, 93, 32, 39, 49, 45, 40, 97, 98, 115, 40, 120, 47, 119,
  45, 48, 46, 53, 41, 94, 36, 114, 43, 97, 98, 115, 40, 121, 47, 104,
  45, 48, 46, 53, 41, 94, 36, 114, 41, 94, 40, 49, 47, 36, 114, 41,
  39, 10, 118, 61, 123, 109, 105, 110, 40, 105, 40, 119, 47, 50, 44, 48,
  41, 44, 105, 40, 119, 45, 49, 44, 104, 47, 50, 41, 44, 105, 40, 119,
  47, 50, 44, 104, 45, 49, 41, 44, 105, 40, 48, 44, 104, 47, 50, 41,
  41, 125, 10, 45, 99, 91, 45, 49, 93, 32, 36, 118, 44, 123, 36, 118,
  43, 48, 46, 53, 47, 109, 97, 120, 40, 119, 44, 104, 41, 125, 32, 45,
  110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 115, 61, 123, 36, 49,
  48, 37, 42, 109, 97, 120, 40, 119, 44, 104, 41, 125, 10, 45, 114, 91,
  49, 93, 32, 123, 119, 43, 36, 115, 125, 44, 123, 104, 43, 36, 115, 125,
  44, 49, 44, 52, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53,
  10, 45, 105, 91, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 49, 44, 51, 32, 45, 102, 99, 91, 49, 93, 32, 36, 123, 49, 49,
  45, 49, 51, 125, 32, 45, 98, 108, 101, 110, 100, 91, 49, 44, 50, 93,
  32, 97, 108, 112, 104, 97, 32, 45, 116, 111, 95, 97, 91, 45, 49, 93,
  10, 45, 105, 102, 32, 36, 52, 32, 45, 115, 104, 91, 49, 93, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 102, 91, 45, 49, 93, 32,
  39, 49, 45, 40, 97, 98, 115, 40, 120, 47, 119, 45, 48, 46, 53, 41,
  94, 36, 114, 43, 97, 98, 115, 40, 121, 47, 104, 45, 48, 46, 53, 41,
  94, 36, 114, 41, 94, 40, 49, 47, 36, 114, 41, 39, 10, 118, 61, 123,
  109, 105, 110, 40, 105, 40, 119, 47, 50, 44, 48, 41, 44, 105, 40, 119,
  45, 49, 44, 104, 47, 50, 41, 44, 105, 40, 119, 47, 50, 44, 104, 45,
  49, 41, 44, 105, 40, 48, 44, 104, 47, 50, 41, 41, 125, 10, 45, 99,
  91, 45, 49, 93, 32, 36, 118, 44, 123, 36, 118, 43, 48, 46, 53, 47,
  109, 97, 120, 40, 119, 44, 104, 41, 125, 32, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 114, 91, 49, 93, 32, 91, 48, 93, 44,
  91, 48, 93, 44, 49, 44, 52, 44, 48, 44, 48, 44, 48, 46, 53, 44,
  48, 46, 53, 10, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 49,
  93, 32, 49, 48, 48, 37, 32, 45, 98, 91, 45, 49, 93, 32, 36, 49,
  54, 37, 44, 48, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 123, 109,
  97, 120, 40, 49, 44, 49, 48, 48, 45, 36, 49, 55, 41, 125, 37, 32,
  45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 115, 104,
  105, 102, 116, 91, 45, 49, 93, 32, 36, 49, 52, 37, 44, 36, 49, 53,
  37, 44, 48, 44, 48, 44, 48, 32, 45, 47, 91, 45, 49, 93, 32, 45,
  50, 53, 53, 32, 45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 42, 91,
  48, 44, 45, 49, 93, 10, 45, 98, 108, 101, 110, 100, 32, 97, 108, 112,
  104, 97, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35,
  64, 103, 105, 109, 112, 32, 70, 114, 97, 109, 101, 32, 91, 99, 117, 98,
  101, 93, 32, 58, 32, 102, 114, 97, 109, 101, 95, 99, 117, 98, 101, 44,
  32, 102, 114, 97, 109, 101, 95, 99, 117, 98, 101, 40, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 112, 116, 104, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 51, 44, 48, 44, 51, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 88, 45, 99, 101, 110, 116, 101, 114, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 44, 50, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 101, 110, 116, 101,
  114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 44, 50,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 101, 102, 116, 32,
  115, 105, 100, 101, 32, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 78, 111, 114, 109, 97,
  108, 34, 44, 34, 77, 105, 114, 114, 111, 114, 45, 88, 34, 44, 34, 77,
  105, 114, 114, 111, 114, 45, 89, 34, 44, 34, 77, 105, 114, 114, 111, 114,
  45, 88, 89, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  105, 103, 104, 116, 32, 115, 105, 100, 101, 32, 111, 114, 105, 101, 110, 116,
  97, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  78, 111, 114, 109, 97, 108, 34, 44, 34, 77, 105, 114, 114, 111, 114, 45,
  88, 34, 44, 34, 77, 105, 114, 114, 111, 114, 45, 89, 34, 44, 34, 77,
  105, 114, 114, 111, 114, 45, 88, 89, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 85, 112, 112, 101, 114, 32, 115, 105, 100, 101, 32, 111,
  114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 78, 111, 114, 109, 97, 108, 34, 44, 34, 77, 105,
  114, 114, 111, 114, 45, 88, 34, 44, 34, 77, 105, 114, 114, 111, 114, 45,
  89, 34, 44, 34, 77, 105, 114, 114, 111, 114, 45, 88, 89, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 111, 119, 101, 114, 32, 115,
  105, 100, 101, 114, 32, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 78, 111, 114, 109, 97,
  108, 34, 44, 34, 77, 105, 114, 114, 111, 114, 45, 88, 34, 44, 34, 77,
  105, 114, 114, 111, 114, 45, 89, 34, 44, 34, 77, 105, 114, 114, 111, 114,
  45, 88, 89, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105,
  62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114,
  108, 38, 35, 50, 51, 51, 59, 44, 32, 65, 110, 103, 101, 108, 111, 32,
  76, 97, 109, 97, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 50, 47, 48, 49, 47, 50, 57, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 70, 114, 97, 109, 101, 32, 91, 102, 117, 122, 122, 121, 93, 32,
  58, 32, 103, 105, 109, 112, 95, 102, 114, 97, 109, 101, 95, 102, 117, 122,
  122, 121, 44, 32, 103, 105, 109, 112, 95, 102, 114, 97, 109, 101, 95, 102,
  117, 122, 122, 121, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 87, 105, 100, 116, 104, 32, 61, 32, 105, 110, 116, 40, 49, 48, 44,
  48, 44, 57, 57, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72,
  101, 105, 103, 104, 116, 32, 61, 32, 105, 110, 116, 40, 49, 48, 44, 48,
  44, 57, 57, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 117,
  122, 122, 121, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 48, 44, 48, 44, 52, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108,
  111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68,
  97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38,
  35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112,
  95, 102, 114, 97, 109, 101, 95, 102, 117, 122, 122, 121, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 40, 123, 119, 42, 36, 49,
  47, 50, 48, 48, 125, 44, 123, 104, 42, 36, 50, 47, 50, 48, 48, 125,
  41, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 49, 10, 45,
  102, 114, 97, 109, 101, 95, 102, 117, 122, 122, 121, 91, 45, 50, 93, 32,
  64, 45, 49, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44,
  36, 55, 44, 36, 56, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 109,
  118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 35, 64,
  103, 105, 109, 112, 32, 70, 114, 97, 109, 101, 32, 91, 112, 97, 105, 110,
  116, 105, 110, 103, 93, 32, 58, 32, 103, 105, 109, 112, 95, 102, 114, 97,
  109, 101, 95, 112, 97, 105, 110, 116, 105, 110, 103, 44, 32, 103, 105, 109,
  112, 95, 102, 114, 97, 109, 101, 95, 112, 97, 105, 110, 116, 105, 110, 103,
  95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 52, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 54, 44, 48, 44, 51,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111,
  114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 50, 53, 44, 50, 48,
  48, 44, 49, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 105, 103, 110, 101,
  116, 116, 101, 32, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 44, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 86, 105, 103, 110, 101, 116, 116, 101, 32, 99, 111, 110, 116, 114,
  97, 115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 48, 48, 44,
  48, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 102, 101,
  99, 116, 115, 32, 99, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 53, 49, 50, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 102, 101, 99, 116, 115, 32,
  100, 101, 110, 115, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 68, 101, 102, 101, 99, 116, 115, 32, 115, 105, 122, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 102, 101, 99, 116, 115,
  32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 50, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 114, 105, 97, 108, 32, 110, 117, 109, 98, 101, 114, 32,
  61, 32, 105, 110, 116, 40, 49, 50, 51, 52, 53, 54, 44, 48, 44, 49,
  48, 48, 48, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 70, 114, 97, 109, 101, 32, 97, 115, 32, 97, 32, 110, 101, 119, 32,
  108, 97, 121, 101, 114, 32, 61, 32, 95, 98, 111, 111, 108, 40, 102, 97,
  108, 115, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 50, 47, 48, 54, 47, 48, 55, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 102, 114, 97, 109, 101, 95, 112, 97, 105, 110, 116, 105, 110, 103,
  32, 58, 10, 45, 105, 102, 32, 36, 49, 52, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  49, 44, 52, 32, 45, 102, 114, 97, 109, 101, 95, 112, 97, 105, 110, 116,
  105, 110, 103, 91, 45, 49, 93, 32, 36, 49, 37, 44, 36, 50, 44, 36,
  51, 37, 44, 36, 123, 52, 45, 54, 125, 44, 36, 55, 37, 44, 36, 123,
  56, 45, 49, 51, 125, 10, 45, 114, 118, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 116, 111, 95, 97, 91, 45, 49, 93, 32, 45, 114, 91, 45, 49,
  93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 52, 44,
  48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 109, 118, 91,
  45, 50, 44, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 45,
  101, 108, 115, 101, 32, 45, 102, 114, 97, 109, 101, 95, 112, 97, 105, 110,
  116, 105, 110, 103, 32, 36, 49, 37, 44, 36, 50, 44, 36, 51, 37, 44,
  36, 123, 52, 45, 54, 125, 44, 36, 55, 37, 44, 36, 123, 56, 45, 49,
  51, 125, 10, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 102,
  114, 97, 109, 101, 95, 112, 97, 105, 110, 116, 105, 110, 103, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 102, 114, 97, 109, 101, 95, 112,
  97, 105, 110, 116, 105, 110, 103, 32, 36, 49, 37, 44, 36, 50, 44, 36,
  51, 37, 44, 36, 123, 52, 45, 54, 125, 44, 36, 55, 37, 44, 36, 123,
  56, 45, 49, 51, 125, 10, 35, 64, 103, 105, 109, 112, 32, 70, 114, 97,
  109, 101, 32, 91, 112, 97, 116, 116, 101, 114, 110, 93, 32, 58, 32, 103,
  105, 109, 112, 95, 102, 114, 97, 109, 101, 95, 112, 97, 116, 116, 101, 114,
  110, 44, 32, 103, 105, 109, 112, 95, 102, 114, 97, 109, 101, 95, 112, 97,
  116, 116, 101, 114, 110, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 105, 108, 101, 115, 32,
  61, 32, 105, 110, 116, 40, 49, 48, 44, 51, 44, 51, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 116, 116, 101, 114, 110, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 84, 111, 112, 32,
  108, 97, 121, 101, 114, 34, 44, 34, 83, 101, 108, 102, 32, 105, 109, 97,
  103, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116,
  101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 49,
  44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 110, 115, 116, 114, 97, 105, 110, 32, 105, 109, 97, 103, 101, 32,
  115, 105, 122, 101, 32, 61, 32, 95, 98, 111, 111, 108, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 102, 114, 97,
  109, 101, 95, 112, 97, 116, 116, 101, 114, 110, 32, 58, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 36, 51, 32, 45, 102, 114, 97, 109, 101, 95, 112,
  97, 116, 116, 101, 114, 110, 32, 36, 49, 44, 36, 50, 44, 36, 52, 32,
  45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 102, 114, 97, 109, 101,
  95, 112, 97, 116, 116, 101, 114, 110, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 102, 114, 97, 109, 101, 95, 112,
  97, 116, 116, 101, 114, 110, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44,
  49, 10, 35, 64, 103, 105, 109, 112, 32, 70, 114, 97, 109, 101, 32, 91,
  114, 101, 103, 117, 108, 97, 114, 93, 32, 58, 32, 103, 105, 109, 112, 95,
  102, 114, 97, 109, 101, 44, 32, 103, 105, 109, 112, 95, 102, 114, 97, 109,
  101, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 98, 62, 67, 114,
  111, 112, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 58, 60,
  47, 98, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88,
  45, 115, 116, 97, 114, 116, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88,
  45, 101, 110, 100, 32, 61, 32, 105, 110, 116, 40, 49, 48, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89,
  45, 115, 116, 97, 114, 116, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89,
  45, 101, 110, 100, 32, 61, 32, 105, 110, 116, 40, 49, 48, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  98, 62, 70, 114, 97, 109, 101, 32, 112, 97, 114, 97, 109, 101, 116, 101,
  114, 115, 32, 58, 60, 47, 98, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 87, 105, 100, 116, 104, 32, 61, 32, 105, 110, 116, 40,
  49, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 72, 101, 105, 103, 104, 116, 32, 61, 32, 105, 110, 116, 40,
  49, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114,
  40, 48, 44, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 79, 117, 116, 108, 105, 110, 101, 32, 115, 105, 122,
  101, 32, 61, 32, 105, 110, 116, 40, 49, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 108, 105, 110,
  101, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 102, 114,
  97, 109, 101, 32, 58, 10, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 122, 91, 45, 49, 93,
  32, 36, 49, 37, 44, 36, 51, 37, 44, 36, 50, 37, 44, 36, 52, 37,
  10, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93, 32, 36, 49, 49, 44,
  36, 49, 49, 44, 36, 123, 49, 50, 45, 49, 53, 125, 10, 45, 102, 114,
  97, 109, 101, 91, 45, 49, 93, 32, 36, 53, 37, 44, 36, 54, 37, 44,
  36, 123, 55, 45, 49, 48, 125, 10, 45, 109, 118, 91, 45, 49, 93, 32,
  48, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 70,
  114, 97, 109, 101, 32, 91, 114, 111, 117, 110, 100, 93, 32, 58, 32, 103,
  105, 109, 112, 95, 102, 114, 97, 109, 101, 95, 114, 111, 117, 110, 100, 44,
  32, 103, 105, 109, 112, 95, 102, 114, 97, 109, 101, 95, 114, 111, 117, 110,
  100, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104,
  97, 114, 112, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  54, 44, 48, 46, 49, 44, 52, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  50, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 49, 44, 48, 44, 49, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 100, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 61, 32, 99,
  111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66,
  108, 117, 114, 32, 102, 114, 97, 109, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 66, 108, 117, 114, 32, 115, 104, 97, 100, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 49, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 117, 114, 32, 97, 109,
  112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  51, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32,
  60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112,
  101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  103, 105, 109, 112, 95, 102, 114, 97, 109, 101, 95, 114, 111, 117, 110, 100,
  32, 58, 10, 45, 102, 114, 97, 109, 101, 95, 114, 111, 117, 110, 100, 32,
  36, 123, 49, 45, 56, 125, 10, 45, 105, 102, 32, 36, 57, 32, 45, 102,
  114, 97, 109, 101, 95, 98, 108, 117, 114, 32, 36, 49, 44, 123, 109, 105,
  110, 40, 57, 57, 44, 36, 49, 43, 36, 57, 41, 125, 44, 36, 51, 44,
  36, 49, 48, 44, 36, 49, 49, 37, 32, 45, 101, 110, 100, 105, 102, 10,
  35, 64, 103, 105, 109, 112, 32, 79, 108, 100, 32, 112, 104, 111, 116, 111,
  103, 114, 97, 112, 104, 32, 58, 32, 103, 105, 109, 112, 95, 111, 108, 100,
  95, 112, 104, 111, 116, 111, 44, 32, 103, 105, 109, 112, 95, 111, 108, 100,
  95, 112, 104, 111, 116, 111, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 86, 105, 103, 110, 101, 116, 116, 101, 32, 115, 116, 114, 101,
  110, 103, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 48,
  44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 86, 105, 103, 110, 101, 116, 116, 101, 32, 109, 105, 110, 32, 114, 97,
  100, 105, 117, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  86, 105, 103, 110, 101, 116, 116, 101, 32, 109, 97, 120, 32, 114, 97, 100,
  105, 117, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 56, 53, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105,
  62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114,
  108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 111, 108, 100, 95, 112, 104, 111, 116, 111, 32, 58, 10, 45,
  118, 105, 103, 110, 101, 116, 116, 101, 32, 36, 123, 49, 45, 51, 125, 32,
  45, 111, 108, 100, 95, 112, 104, 111, 116, 111, 10, 35, 64, 103, 105, 109,
  112, 32, 80, 111, 108, 97, 114, 111, 105, 100, 32, 58, 32, 103, 105, 109,
  112, 95, 112, 111, 108, 97, 114, 111, 105, 100, 44, 32, 103, 105, 109, 112,
  95, 112, 111, 108, 97, 114, 111, 105, 100, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 70, 114, 97, 109, 101, 32, 115, 105, 122, 101,
  32, 61, 32, 105, 110, 116, 40, 49, 48, 44, 48, 44, 52, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 111, 116, 116, 111, 109,
  32, 115, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 50, 48, 44, 48,
  44, 52, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88,
  45, 115, 104, 97, 100, 111, 119, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 45, 50, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 89, 45, 115, 104, 97, 100, 111, 119, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 50, 48, 44, 50, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44, 48, 44, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 45, 49, 56, 48, 44,
  49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 105,
  103, 110, 101, 116, 116, 101, 32, 115, 116, 114, 101, 110, 103, 116, 104, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 105, 103, 110, 101,
  116, 116, 101, 32, 109, 105, 110, 32, 114, 97, 100, 105, 117, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 55, 48, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 105, 103, 110, 101, 116,
  116, 101, 32, 109, 97, 120, 32, 114, 97, 100, 105, 117, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 57, 53, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 112, 111, 108,
  97, 114, 111, 105, 100, 32, 58, 10, 45, 118, 105, 103, 110, 101, 116, 116,
  101, 32, 36, 123, 55, 45, 57, 125, 32, 45, 112, 111, 108, 97, 114, 111,
  105, 100, 32, 36, 49, 44, 36, 50, 32, 45, 100, 114, 111, 112, 95, 115,
  104, 97, 100, 111, 119, 32, 36, 51, 37, 44, 36, 52, 37, 44, 36, 53,
  37, 32, 45, 114, 111, 116, 97, 116, 101, 32, 36, 54, 44, 49, 44, 48,
  10, 35, 64, 103, 105, 109, 112, 32, 84, 117, 110, 110, 101, 108, 32, 58,
  32, 103, 105, 109, 112, 95, 116, 117, 110, 110, 101, 108, 44, 32, 103, 105,
  109, 112, 95, 116, 117, 110, 110, 101, 108, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 101, 112, 116, 104, 32, 61, 32, 105, 110,
  116, 40, 52, 44, 49, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 70, 97, 99, 116, 111, 114, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 56, 48, 44, 49, 44, 57, 57, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 88, 45, 99, 101, 110, 116, 101, 114, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 101, 110, 116, 101, 114,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105,
  116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 50, 44, 48,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103,
  108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 57, 48,
  44, 57, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 50, 47, 49, 49, 47, 50, 50, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 116, 117, 110, 110, 101, 108, 32, 58, 10, 45, 116, 117, 110, 110,
  101, 108, 32, 36, 49, 44, 36, 50, 37, 44, 36, 123, 51, 45, 54, 125,
  10, 35, 64, 103, 105, 109, 112, 32, 86, 105, 103, 110, 101, 116, 116, 101,
  32, 58, 32, 103, 105, 109, 112, 95, 118, 105, 103, 110, 101, 116, 116, 101,
  44, 32, 103, 105, 109, 112, 95, 118, 105, 103, 110, 101, 116, 116, 101, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 116, 114, 101, 110, 103, 116,
  104, 32, 61, 32, 102, 108, 111, 97, 116, 40, 55, 48, 44, 48, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 105, 110,
  32, 114, 97, 100, 105, 117, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  55, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 77, 97, 120, 32, 114, 97, 100, 105, 117, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 57, 53, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 61,
  32, 99, 111, 108, 111, 114, 40, 48, 44, 48, 44, 48, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118,
  105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50,
  51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62,
  50, 48, 49, 50, 47, 49, 48, 47, 50, 52, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 118,
  105, 103, 110, 101, 116, 116, 101, 32, 58, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 115, 112,
  108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 61, 91, 45,
  49, 93, 32, 48, 32, 45, 118, 105, 103, 110, 101, 116, 116, 101, 91, 45,
  49, 93, 32, 36, 123, 49, 45, 51, 125, 32, 45, 97, 32, 99, 32, 45,
  45, 102, 99, 32, 36, 123, 52, 45, 55, 125, 32, 45, 98, 108, 101, 110,
  100, 32, 97, 108, 112, 104, 97, 44, 49, 44, 49, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 95,
  10, 35, 64, 103, 105, 109, 112, 32, 60, 98, 62, 76, 97, 121, 101, 114,
  115, 60, 47, 98, 62, 10, 35, 64, 103, 105, 109, 112, 32, 65, 108, 105,
  103, 110, 32, 108, 97, 121, 101, 114, 115, 32, 58, 32, 103, 105, 109, 112,
  95, 97, 108, 105, 103, 110, 95, 108, 97, 121, 101, 114, 115, 44, 32, 103,
  105, 109, 112, 95, 97, 108, 105, 103, 110, 95, 108, 97, 121, 101, 114, 115,
  95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 65, 108, 105, 103, 110, 109, 101, 110, 116, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 82, 105, 103,
  105, 100, 34, 44, 34, 78, 111, 110, 45, 114, 105, 103, 105, 100, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55,
  44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  99, 97, 108, 101, 115, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48,
  44, 34, 65, 117, 116, 111, 34, 44, 34, 49, 34, 44, 34, 50, 34, 44,
  34, 51, 34, 44, 34, 52, 34, 44, 34, 53, 34, 44, 34, 54, 34, 44,
  34, 55, 34, 44, 34, 56, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121, 101, 114, 115, 32,
  61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47,
  50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 97, 108, 105, 103, 110, 95, 108, 97, 121,
  101, 114, 115, 32, 58, 10, 45, 105, 102, 32, 36, 123, 52, 61, 48, 125,
  32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108,
  97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101,
  109, 111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 10, 45, 105, 102,
  32, 36, 49, 32, 45, 114, 101, 103, 105, 115, 116, 101, 114, 95, 110, 111,
  110, 114, 105, 103, 105, 100, 32, 36, 50, 44, 48, 46, 49, 44, 36, 51,
  10, 45, 101, 108, 115, 101, 32, 40, 36, 50, 41, 32, 45, 42, 91, 45,
  49, 93, 32, 51, 32, 45, 114, 101, 103, 105, 115, 116, 101, 114, 95, 114,
  105, 103, 105, 100, 91, 94, 45, 49, 93, 32, 64, 45, 49, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109,
  112, 95, 97, 108, 105, 103, 110, 95, 108, 97, 121, 101, 114, 115, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 97,
  108, 105, 103, 110, 95, 108, 97, 121, 101, 114, 115, 32, 36, 49, 44, 36,
  50, 44, 48, 32, 45, 98, 108, 101, 110, 100, 95, 101, 100, 103, 101, 115,
  32, 48, 46, 49, 10, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114,
  116, 95, 108, 97, 121, 101, 114, 115, 32, 58, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45,
  114, 118, 91, 123, 50, 42, 36, 62, 125, 44, 123, 50, 42, 36, 62, 43,
  49, 125, 93, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112,
  32, 66, 108, 101, 110, 100, 32, 91, 97, 118, 101, 114, 97, 103, 101, 32,
  97, 108, 108, 93, 32, 58, 32, 103, 105, 109, 112, 95, 98, 108, 101, 110,
  100, 95, 97, 118, 101, 114, 97, 103, 101, 95, 97, 108, 108, 44, 32, 103,
  105, 109, 112, 95, 98, 108, 101, 110, 100, 95, 97, 118, 101, 114, 97, 103,
  101, 95, 97, 108, 108, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 115, 109, 97,
  108, 108, 62, 60, 98, 62, 78, 111, 116, 101, 58, 60, 47, 98, 62, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 105, 115, 32, 102, 105,
  108, 116, 101, 114, 32, 116, 97, 107, 101, 115, 32, 109, 117, 108, 116, 105,
  112, 108, 101, 32, 108, 97, 121, 101, 114, 115, 32, 97, 115, 32, 105, 110,
  112, 117, 116, 32, 97, 110, 100, 32, 97, 118, 101, 114, 97, 103, 101, 32,
  116, 104, 101, 109, 46, 32, 83, 101, 116, 32, 116, 104, 101, 32, 60, 105,
  62, 73, 110, 112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 60, 47, 105,
  62, 32, 111, 112, 116, 105, 111, 110, 32, 116, 111, 32, 104, 97, 110, 100,
  108, 101, 32, 109, 117, 108, 116, 105, 112, 108, 101, 32, 105, 110, 112, 117,
  116, 32, 108, 97, 121, 101, 114, 115, 46, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 60, 47, 115, 109, 97, 108, 108, 62, 34, 125, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84,
  115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51,
  47, 48, 56, 47, 49, 49, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100,
  95, 97, 118, 101, 114, 97, 103, 101, 95, 97, 108, 108, 32, 58, 10, 45,
  105, 102, 32, 64, 35, 10, 78, 61, 64, 35, 32, 45, 43, 32, 45, 47,
  32, 36, 78, 10, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103, 105, 109,
  112, 32, 66, 108, 101, 110, 100, 32, 91, 101, 100, 103, 101, 115, 93, 32,
  58, 32, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 95, 101, 100, 103,
  101, 115, 44, 32, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 95, 101,
  100, 103, 101, 115, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 56, 44, 48, 44, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121,
  101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 123, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98,
  62, 78, 111, 116, 101, 58, 60, 47, 98, 62, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 84, 104, 105, 115, 32, 102, 105, 108, 116, 101, 114, 32,
  110, 101, 101, 100, 115, 32, 116, 119, 111, 32, 108, 97, 121, 101, 114, 115,
  32, 116, 111, 32, 119, 111, 114, 107, 32, 112, 114, 111, 112, 101, 114, 108,
  121, 46, 32, 83, 101, 116, 32, 116, 104, 101, 32, 60, 105, 62, 73, 110,
  112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 60, 47, 105, 62, 32, 111,
  112, 116, 105, 111, 110, 32, 116, 111, 32, 104, 97, 110, 100, 108, 101, 32,
  109, 117, 108, 116, 105, 112, 108, 101, 32, 105, 110, 112, 117, 116, 32, 108,
  97, 121, 101, 114, 115, 46, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 125, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104,
  117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 49,
  47, 50, 49, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 95, 101, 100,
  103, 101, 115, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105,
  110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44,
  123, 36, 62, 43, 49, 125, 93, 32, 45, 105, 102, 32, 36, 51, 32, 45,
  114, 118, 32, 45, 101, 110, 100, 105, 102, 32, 45, 45, 98, 108, 101, 110,
  100, 95, 101, 100, 103, 101, 115, 91, 45, 50, 44, 45, 49, 93, 32, 36,
  50, 32, 45, 114, 109, 91, 45, 51, 93, 32, 45, 98, 108, 101, 110, 100,
  91, 45, 50, 44, 45, 49, 93, 32, 97, 108, 112, 104, 97, 44, 36, 49,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103,
  105, 109, 112, 32, 66, 108, 101, 110, 100, 32, 91, 102, 97, 100, 101, 93,
  32, 58, 32, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 95, 102, 97,
  100, 101, 44, 32, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 95, 102,
  97, 100, 101, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  80, 114, 101, 115, 101, 116, 32, 61, 32, 99, 104, 111, 105, 99, 101, 123,
  49, 44, 34, 67, 117, 115, 116, 111, 109, 34, 44, 34, 76, 105, 110, 101,
  97, 114, 34, 44, 34, 67, 105, 114, 99, 117, 108, 97, 114, 34, 44, 34,
  87, 97, 118, 101, 34, 44, 34, 75, 101, 102, 116, 97, 108, 101, 115, 34,
  125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 102, 102, 115, 101,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 105, 110, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97,
  114, 112, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53,
  44, 49, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 104, 97, 114, 112, 101, 115, 116, 32, 61, 32, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101,
  114, 116, 32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108,
  111, 114, 32, 115, 112, 97, 99, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 82, 71, 66, 34, 44, 34, 72, 83, 86, 34, 44, 34, 76,
  97, 98, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 92, 110, 60, 115, 109, 97,
  108, 108, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 101,
  32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 98, 101, 108, 111,
  119, 32, 97, 114, 101, 32, 117, 115, 101, 100, 32, 105, 110, 32, 109, 111,
  115, 116, 32, 112, 114, 101, 115, 101, 116, 115, 46, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 60, 47, 115, 109, 97, 108, 108, 62, 125, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 49, 115, 116, 32, 112, 97, 114, 97,
  109, 101, 116, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  45, 49, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 50,
  110, 100, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 45, 49, 44, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 51, 114, 100, 32, 112, 97, 114, 97, 109, 101,
  116, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 123, 92, 110, 60, 115, 109, 97, 108,
  108, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 101, 32,
  102, 111, 114, 109, 117, 108, 97, 32, 98, 101, 108, 111, 119, 32, 105, 115,
  32, 117, 115, 101, 100, 32, 102, 111, 114, 32, 116, 104, 101, 32, 60, 105,
  62, 67, 117, 115, 116, 111, 109, 60, 47, 105, 62, 32, 112, 114, 101, 115,
  101, 116, 46, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 47, 115,
  109, 97, 108, 108, 62, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  70, 111, 114, 109, 117, 108, 97, 32, 61, 32, 116, 101, 120, 116, 123, 34,
  99, 111, 115, 40, 52, 42, 112, 105, 42, 120, 47, 119, 41, 32, 42, 32,
  115, 105, 110, 40, 52, 42, 112, 105, 42, 121, 47, 104, 41, 34, 125, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 123, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62,
  78, 111, 116, 101, 58, 60, 47, 98, 62, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 84, 104, 105, 115, 32, 102, 105, 108, 116, 101, 114, 32, 110,
  101, 101, 100, 115, 32, 116, 119, 111, 32, 108, 97, 121, 101, 114, 115, 32,
  116, 111, 32, 119, 111, 114, 107, 32, 112, 114, 111, 112, 101, 114, 108, 121,
  46, 32, 83, 101, 116, 32, 116, 104, 101, 32, 60, 105, 62, 73, 110, 112,
  117, 116, 32, 108, 97, 121, 101, 114, 115, 60, 47, 105, 62, 32, 111, 112,
  116, 105, 111, 110, 32, 116, 111, 32, 104, 97, 110, 100, 108, 101, 32, 109,
  117, 108, 116, 105, 112, 108, 101, 32, 105, 110, 112, 117, 116, 32, 108, 97,
  121, 101, 114, 115, 46, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 49, 47,
  50, 49, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 95, 102, 97, 100,
  101, 32, 58, 10, 45, 105, 102, 32, 123, 64, 35, 61, 61, 49, 125, 32,
  45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 52, 10, 45,
  105, 102, 32, 123, 36, 55, 61, 61, 49, 125, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 115, 104, 91, 36, 62, 93, 32, 48, 44,
  50, 32, 45, 114, 103, 98, 50, 104, 115, 118, 91, 45, 49, 93, 32, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 55, 61, 61, 50, 125, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 115, 104, 91, 36, 62, 93, 32, 48, 44,
  50, 32, 45, 115, 114, 103, 98, 50, 114, 103, 98, 91, 45, 49, 93, 32,
  45, 114, 103, 98, 50, 108, 97, 98, 91, 45, 49, 93, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 125, 32, 91, 48,
  93, 44, 91, 48, 93, 44, 49, 44, 49, 44, 34, 36, 49, 49, 34, 10,
  45, 101, 108, 115, 101, 32, 45, 95, 103, 105, 109, 112, 95, 98, 108, 101,
  110, 100, 95, 102, 97, 100, 101, 36, 49, 32, 36, 56, 44, 36, 57, 44,
  36, 49, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 48, 93, 44, 91,
  48, 93, 44, 49, 44, 49, 44, 51, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 110, 91, 45, 49, 93, 32, 123, 45, 40, 64, 35, 45, 50, 41, 42,
  36, 51, 125, 44, 123, 40, 64, 35, 45, 50, 41, 42, 40, 49, 43, 36,
  51, 41, 125, 10, 45, 45, 91, 45, 49, 93, 32, 123, 36, 50, 42, 40,
  49, 43, 36, 51, 41, 42, 40, 64, 35, 45, 50, 41, 125, 10, 45, 99,
  91, 45, 49, 93, 32, 48, 44, 123, 64, 35, 45, 50, 125, 10, 45, 105,
  102, 32, 36, 54, 32, 45, 114, 118, 91, 94, 45, 49, 93, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 53, 32, 45, 114, 111, 117,
  110, 100, 91, 45, 49, 93, 32, 49, 10, 45, 101, 108, 115, 101, 32, 45,
  114, 111, 117, 110, 100, 105, 102, 121, 91, 45, 49, 93, 32, 36, 52, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 98, 108, 101, 110, 100, 95, 102, 97,
  100, 101, 10, 45, 105, 102, 32, 123, 36, 55, 61, 61, 49, 125, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 115, 104, 91, 36, 62,
  93, 32, 48, 44, 50, 32, 45, 104, 115, 118, 50, 114, 103, 98, 91, 45,
  49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 100, 111, 110, 101,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 55, 61, 61, 50, 125, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 115, 104, 91, 36, 62,
  93, 32, 48, 44, 50, 32, 45, 108, 97, 98, 50, 114, 103, 98, 91, 45,
  49, 93, 32, 45, 114, 103, 98, 50, 115, 114, 103, 98, 91, 45, 49, 93,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10, 95,
  103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 95, 102, 97, 100, 101, 49,
  32, 58, 32, 91, 48, 93, 44, 91, 48, 93, 44, 49, 44, 49, 44, 34,
  97, 61, 36, 49, 42, 112, 105, 47, 50, 59, 32, 120, 42, 99, 111, 115,
  40, 97, 41, 32, 43, 32, 121, 42, 115, 105, 110, 40, 97, 41, 34, 10,
  95, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 95, 102, 97, 100, 101,
  50, 32, 58, 32, 91, 48, 93, 44, 91, 48, 93, 44, 49, 44, 49, 44,
  48, 32, 45, 61, 91, 45, 49, 93, 32, 49, 44, 123, 40, 36, 49, 43,
  49, 41, 42, 53, 48, 125, 37, 44, 123, 40, 36, 50, 43, 49, 41, 42,
  53, 48, 125, 37, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45,
  49, 93, 32, 49, 10, 95, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100,
  95, 102, 97, 100, 101, 51, 32, 58, 32, 91, 48, 93, 44, 91, 48, 93,
  44, 49, 44, 49, 44, 48, 32, 45, 61, 91, 45, 49, 93, 32, 49, 44,
  123, 40, 36, 49, 43, 49, 41, 42, 53, 48, 125, 37, 44, 123, 40, 36,
  50, 43, 49, 41, 42, 53, 48, 125, 37, 32, 45, 100, 105, 115, 116, 97,
  110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 42, 91, 45, 49, 93,
  32, 123, 48, 46, 48, 49, 43, 36, 51, 47, 50, 125, 32, 45, 99, 111,
  115, 91, 45, 49, 93, 10, 95, 103, 105, 109, 112, 95, 98, 108, 101, 110,
  100, 95, 102, 97, 100, 101, 52, 32, 58, 32, 91, 48, 93, 44, 91, 48,
  93, 44, 49, 44, 49, 44, 34, 40, 40, 120, 45, 119, 42, 40, 36, 49,
  43, 48, 46, 53, 41, 41, 42, 40, 121, 45, 104, 42, 40, 36, 50, 43,
  48, 46, 53, 41, 41, 41, 37, 40, 48, 46, 50, 42, 119, 42, 104, 42,
  40, 49, 46, 48, 48, 49, 43, 36, 51, 41, 41, 34, 10, 35, 64, 103,
  105, 109, 112, 32, 66, 108, 101, 110, 100, 32, 91, 109, 101, 100, 105, 97,
  110, 93, 32, 58, 32, 98, 108, 101, 110, 100, 95, 109, 101, 100, 105, 97,
  110, 44, 32, 98, 108, 101, 110, 100, 95, 109, 101, 100, 105, 97, 110, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 115, 109, 97,
  108, 108, 62, 60, 98, 62, 78, 111, 116, 101, 58, 60, 47, 98, 62, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 105, 115, 32, 102, 105,
  108, 116, 101, 114, 32, 110, 101, 101, 100, 115, 32, 97, 116, 32, 108, 101,
  97, 115, 116, 32, 116, 119, 111, 32, 108, 97, 121, 101, 114, 115, 32, 116,
  111, 32, 119, 111, 114, 107, 32, 112, 114, 111, 112, 101, 114, 108, 121, 46,
  32, 83, 101, 116, 32, 116, 104, 101, 32, 60, 105, 62, 73, 110, 112, 117,
  116, 32, 108, 97, 121, 101, 114, 115, 60, 47, 105, 62, 32, 111, 112, 116,
  105, 111, 110, 32, 116, 111, 32, 104, 97, 110, 100, 108, 101, 32, 109, 117,
  108, 116, 105, 112, 108, 101, 32, 105, 110, 112, 117, 116, 32, 108, 97, 121,
  101, 114, 115, 46, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109,
  112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 53, 47, 48,
  55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 66, 108, 101, 110, 100, 32, 91, 115,
  116, 97, 110, 100, 97, 114, 100, 93, 32, 58, 32, 103, 105, 109, 112, 95,
  98, 108, 101, 110, 100, 44, 32, 103, 105, 109, 112, 95, 98, 108, 101, 110,
  100, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 100, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 100, 100, 34, 44, 34,
  65, 108, 112, 104, 97, 34, 44, 34, 65, 110, 100, 34, 44, 34, 65, 118,
  101, 114, 97, 103, 101, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 66,
  117, 114, 110, 34, 44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 68,
  105, 102, 102, 101, 114, 101, 110, 99, 101, 34, 44, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 34, 68, 105, 118, 105, 100, 101, 34, 44, 34, 68,
  111, 100, 103, 101, 34, 44, 34, 69, 120, 99, 108, 117, 115, 105, 111, 110,
  34, 44, 34, 70, 114, 101, 101, 122, 101, 34, 44, 34, 71, 114, 97, 105,
  110, 32, 101, 120, 116, 114, 97, 99, 116, 34, 44, 34, 71, 114, 97, 105,
  110, 32, 109, 101, 114, 103, 101, 34, 44, 34, 71, 114, 101, 101, 110, 34,
  44, 34, 72, 97, 114, 100, 32, 108, 105, 103, 104, 116, 34, 44, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 34, 72, 97, 114, 100, 32, 109, 105,
  120, 34, 44, 34, 72, 117, 101, 34, 44, 34, 73, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 105, 111, 110, 34, 44, 34, 76, 105, 103, 104, 116, 101,
  110, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34,
  76, 105, 110, 101, 97, 114, 32, 98, 117, 114, 110, 34, 44, 34, 76, 105,
  110, 101, 97, 114, 32, 108, 105, 103, 104, 116, 34, 44, 34, 76, 117, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 34, 77, 117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 78, 101,
  103, 97, 116, 105, 111, 110, 34, 44, 34, 79, 114, 34, 44, 34, 79, 118,
  101, 114, 108, 97, 121, 34, 44, 34, 80, 105, 110, 32, 108, 105, 103, 104,
  116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 82, 101, 102, 108, 101, 99,
  116, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 83, 104, 97, 112, 101,
  32, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 83, 104, 97, 112, 101,
  32, 65, 118, 101, 114, 97, 103, 101, 48, 34, 44, 34, 83, 111, 102, 116,
  32, 98, 117, 114, 110, 34, 44, 34, 83, 111, 102, 116, 32, 100, 111, 100,
  103, 101, 34, 44, 34, 83, 111, 102, 116, 32, 108, 105, 103, 104, 116, 34,
  44, 34, 83, 99, 114, 101, 101, 110, 34, 44, 34, 83, 116, 97, 109, 112,
  34, 44, 34, 83, 117, 98, 116, 114, 97, 99, 116, 34, 44, 34, 86, 97,
  108, 117, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34,
  86, 105, 118, 105, 100, 32, 108, 105, 103, 104, 116, 34, 44, 34, 88, 111,
  114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97,
  99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118,
  101, 114, 116, 32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 115,
  109, 97, 108, 108, 62, 60, 98, 62, 78, 111, 116, 101, 58, 60, 47, 98,
  62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 105, 115, 32,
  102, 105, 108, 116, 101, 114, 32, 110, 101, 101, 100, 115, 32, 116, 119, 111,
  32, 108, 97, 121, 101, 114, 115, 32, 116, 111, 32, 119, 111, 114, 107, 32,
  112, 114, 111, 112, 101, 114, 108, 121, 46, 32, 83, 101, 116, 32, 116, 104,
  101, 32, 60, 105, 62, 73, 110, 112, 117, 116, 32, 108, 97, 121, 101, 114,
  115, 60, 47, 105, 62, 32, 111, 112, 116, 105, 111, 110, 32, 116, 111, 32,
  104, 97, 110, 100, 108, 101, 32, 109, 117, 108, 116, 105, 112, 108, 101, 32,
  105, 110, 112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 46, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32,
  61, 32, 108, 105, 110, 107, 40, 34, 82, 101, 102, 101, 114, 101, 110, 99,
  101, 32, 112, 97, 103, 101, 32, 102, 111, 114, 32, 71, 39, 77, 73, 67,
  32, 98, 108, 101, 110, 100, 105, 110, 103, 32, 109, 111, 100, 101, 115, 34,
  44, 34, 104, 116, 116, 112, 115, 58, 47, 47, 115, 111, 117, 114, 99, 101,
  102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 112, 47, 103, 109, 105, 99,
  47, 119, 105, 107, 105, 47, 66, 108, 101, 110, 100, 105, 110, 103, 37, 50,
  48, 109, 111, 100, 101, 115, 47, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 49, 47,
  50, 49, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 32, 58, 10, 109,
  111, 100, 101, 61, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 36, 49,
  44, 97, 100, 100, 44, 97, 108, 112, 104, 97, 44, 97, 110, 100, 44, 97,
  118, 101, 114, 97, 103, 101, 44, 98, 108, 117, 101, 44, 98, 117, 114, 110,
  44, 100, 97, 114, 107, 101, 110, 44, 100, 105, 102, 102, 101, 114, 101, 110,
  99, 101, 44, 92, 10, 100, 105, 118, 105, 100, 101, 44, 100, 111, 100, 103,
  101, 44, 101, 120, 99, 108, 117, 115, 105, 111, 110, 44, 102, 114, 101, 101,
  122, 101, 44, 103, 114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116, 44,
  103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 44, 103, 114, 101, 101, 110,
  44, 104, 97, 114, 100, 108, 105, 103, 104, 116, 44, 92, 10, 104, 97, 114,
  100, 109, 105, 120, 44, 104, 117, 101, 44, 105, 110, 116, 101, 114, 112, 111,
  108, 97, 116, 105, 111, 110, 44, 108, 105, 103, 104, 116, 101, 110, 44, 108,
  105, 103, 104, 116, 110, 101, 115, 115, 44, 108, 105, 110, 101, 97, 114, 98,
  117, 114, 110, 44, 108, 105, 110, 101, 97, 114, 108, 105, 103, 104, 116, 44,
  108, 117, 109, 105, 110, 97, 110, 99, 101, 44, 92, 10, 109, 117, 108, 116,
  105, 112, 108, 121, 44, 110, 101, 103, 97, 116, 105, 111, 110, 44, 111, 114,
  44, 111, 118, 101, 114, 108, 97, 121, 44, 112, 105, 110, 108, 105, 103, 104,
  116, 44, 114, 101, 100, 44, 114, 101, 102, 108, 101, 99, 116, 44, 115, 97,
  116, 117, 114, 97, 116, 105, 111, 110, 44, 92, 10, 115, 104, 97, 112, 101,
  97, 118, 101, 114, 97, 103, 101, 44, 115, 104, 97, 112, 101, 97, 118, 101,
  114, 97, 103, 101, 48, 44, 115, 111, 102, 116, 98, 117, 114, 110, 44, 115,
  111, 102, 116, 100, 111, 100, 103, 101, 44, 115, 111, 102, 116, 108, 105, 103,
  104, 116, 44, 115, 99, 114, 101, 101, 110, 44, 115, 116, 97, 109, 112, 44,
  115, 117, 98, 116, 114, 97, 99, 116, 44, 118, 97, 108, 117, 101, 44, 92,
  10, 118, 105, 118, 105, 100, 108, 105, 103, 104, 116, 44, 120, 111, 114, 125,
  10, 45, 98, 108, 101, 110, 100, 32, 36, 109, 111, 100, 101, 44, 36, 50,
  44, 123, 49, 45, 36, 51, 125, 10, 35, 64, 103, 105, 109, 112, 32, 70,
  97, 100, 101, 32, 108, 97, 121, 101, 114, 115, 32, 58, 32, 103, 105, 109,
  112, 95, 102, 97, 100, 101, 95, 108, 97, 121, 101, 114, 115, 44, 32, 103,
  105, 109, 112, 95, 102, 97, 100, 101, 95, 108, 97, 121, 101, 114, 115, 95,
  112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 73, 110, 116, 101, 114, 45, 102, 114, 97, 109, 101, 115, 32, 61, 32,
  95, 105, 110, 116, 40, 49, 48, 44, 50, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 123, 34, 60, 115, 109, 97, 108, 108, 62, 60,
  98, 62, 78, 111, 116, 101, 58, 60, 47, 98, 62, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 84, 104, 105, 115, 32, 102, 105, 108, 116, 101, 114,
  32, 110, 101, 101, 100, 115, 32, 97, 116, 32, 108, 101, 97, 115, 116, 32,
  116, 119, 111, 32, 108, 97, 121, 101, 114, 115, 32, 116, 111, 32, 119, 111,
  114, 107, 32, 112, 114, 111, 112, 101, 114, 108, 121, 46, 32, 83, 101, 116,
  32, 116, 104, 101, 32, 60, 105, 62, 73, 110, 112, 117, 116, 32, 108, 97,
  121, 101, 114, 115, 60, 47, 105, 62, 32, 111, 112, 116, 105, 111, 110, 32,
  116, 111, 32, 104, 97, 110, 100, 108, 101, 32, 109, 117, 108, 116, 105, 112,
  108, 101, 32, 105, 110, 112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 46,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 50, 47, 48, 56, 47, 48, 52, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 102, 97, 100, 101, 95, 108, 97, 121, 101, 114, 115, 32, 58, 10,
  45, 105, 102, 32, 123, 64, 35, 60, 50, 125, 32, 45, 114, 101, 116, 117,
  114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 32, 122, 32, 45,
  114, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 123, 40, 100, 45,
  49, 41, 42, 36, 49, 43, 49, 125, 44, 49, 48, 48, 37, 44, 51, 32,
  45, 115, 32, 122, 10, 103, 105, 109, 112, 95, 102, 97, 100, 101, 95, 108,
  97, 121, 101, 114, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 105, 102, 32, 123, 64, 35, 60, 50, 125, 32, 45, 114, 101, 116, 117,
  114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 107, 91, 48, 44, 49,
  93, 32, 45, 43, 32, 45, 47, 32, 50, 10, 35, 64, 103, 105, 109, 112,
  32, 70, 97, 115, 116, 32, 109, 101, 100, 105, 97, 110, 32, 115, 116, 97,
  99, 107, 32, 58, 32, 105, 97, 105, 110, 95, 102, 97, 115, 116, 95, 109,
  101, 100, 105, 97, 110, 95, 115, 116, 97, 99, 107, 44, 32, 105, 97, 105,
  110, 95, 102, 97, 115, 116, 95, 109, 101, 100, 105, 97, 110, 95, 115, 116,
  97, 99, 107, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 84, 104, 105, 115, 32, 102,
  105, 108, 116, 101, 114, 32, 103, 105, 118, 101, 115, 32, 116, 104, 101, 32,
  109, 101, 100, 105, 97, 110, 32, 118, 97, 108, 117, 101, 32, 111, 102, 32,
  51, 44, 52, 44, 32, 111, 114, 32, 53, 32, 105, 109, 97, 103, 101, 115,
  32, 97, 116, 32, 101, 97, 99, 104, 32, 112, 105, 120, 101, 108, 32, 108,
  111, 99, 97, 116, 105, 111, 110, 32, 97, 110, 100, 32, 116, 104, 101, 114,
  101, 102, 111, 114, 101, 32, 60, 98, 62, 114, 101, 113, 117, 105, 114, 101,
  115, 32, 51, 44, 52, 44, 32, 111, 114, 32, 53, 32, 105, 110, 112, 117,
  116, 32, 105, 109, 97, 103, 101, 115, 60, 47, 98, 62, 46, 34, 125, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58,
  32, 60, 105, 62, 73, 97, 105, 110, 32, 70, 101, 114, 103, 117, 115, 115,
  111, 110, 60, 47, 105, 62, 46, 32, 85, 112, 100, 97, 116, 101, 32, 56,
  32, 77, 97, 114, 99, 104, 32, 50, 48, 49, 51, 32, 45, 32, 67, 111,
  109, 98, 105, 110, 101, 100, 32, 60, 105, 62, 109, 101, 100, 105, 97, 110,
  95, 51, 95, 115, 116, 97, 99, 107, 60, 47, 105, 62, 32, 97, 110, 100,
  32, 60, 105, 62, 109, 101, 100, 105, 97, 110, 95, 53, 95, 115, 116, 97,
  99, 107, 60, 47, 105, 62, 32, 105, 110, 116, 111, 32, 116, 104, 105, 115,
  32, 102, 105, 108, 116, 101, 114, 44, 32, 97, 100, 100, 101, 100, 32, 60,
  105, 62, 109, 101, 100, 105, 97, 110, 95, 52, 95, 115, 116, 97, 99, 107,
  60, 47, 105, 62, 32, 97, 110, 100, 32, 97, 100, 100, 101, 100, 32, 97,
  117, 116, 111, 45, 115, 101, 108, 101, 99, 116, 32, 98, 97, 115, 101, 100,
  32, 111, 110, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 105, 110,
  112, 117, 116, 32, 105, 109, 97, 103, 101, 115, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 32, 34, 41, 10, 105, 97, 105, 110, 95, 102, 97, 115, 116,
  95, 109, 101, 100, 105, 97, 110, 95, 115, 116, 97, 99, 107, 58, 10, 108,
  97, 121, 101, 114, 115, 61, 123, 64, 35, 125, 10, 45, 105, 102, 32, 123,
  36, 108, 97, 121, 101, 114, 115, 61, 61, 51, 125, 10, 45, 105, 97, 105,
  110, 95, 109, 101, 100, 105, 97, 110, 95, 51, 95, 115, 116, 97, 99, 107,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 108, 97, 121, 101, 114, 115, 61,
  61, 52, 125, 10, 45, 105, 97, 105, 110, 95, 109, 101, 100, 105, 97, 110,
  95, 52, 95, 115, 116, 97, 99, 107, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 108, 97, 121, 101, 114, 115, 61, 61, 53, 125, 10, 45, 105, 97, 105,
  110, 95, 109, 101, 100, 105, 97, 110, 95, 53, 95, 115, 116, 97, 99, 107,
  10, 45, 101, 108, 115, 101, 10, 45, 101, 110, 100, 105, 102, 10, 105, 97,
  105, 110, 95, 109, 101, 100, 105, 97, 110, 95, 51, 95, 115, 116, 97, 99,
  107, 58, 10, 45, 45, 109, 97, 120, 91, 48, 44, 49, 93, 10, 45, 45,
  109, 105, 110, 91, 48, 44, 49, 93, 10, 45, 107, 101, 101, 112, 91, 50,
  44, 51, 44, 52, 93, 10, 45, 45, 109, 97, 120, 91, 48, 44, 50, 93,
  10, 45, 45, 109, 105, 110, 91, 49, 44, 51, 93, 10, 45, 107, 101, 101,
  112, 91, 45, 49, 93, 10, 105, 97, 105, 110, 95, 109, 101, 100, 105, 97,
  110, 95, 52, 95, 115, 116, 97, 99, 107, 58, 10, 45, 45, 109, 105, 110,
  91, 48, 44, 49, 93, 10, 45, 45, 109, 97, 120, 91, 48, 44, 49, 93,
  10, 45, 114, 101, 109, 111, 118, 101, 91, 48, 44, 49, 93, 10, 45, 45,
  109, 105, 110, 91, 48, 44, 51, 93, 10, 45, 45, 109, 97, 120, 91, 48,
  44, 51, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 48, 44, 51, 93,
  10, 45, 45, 109, 105, 110, 91, 48, 44, 51, 93, 10, 45, 45, 109, 97,
  120, 91, 48, 44, 51, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 48,
  44, 51, 93, 10, 45, 45, 109, 105, 110, 91, 48, 44, 51, 93, 10, 45,
  45, 109, 97, 120, 91, 48, 44, 51, 93, 10, 45, 114, 101, 109, 111, 118,
  101, 91, 48, 44, 51, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 51,
  93, 10, 45, 45, 109, 97, 120, 91, 48, 44, 49, 93, 10, 45, 45, 109,
  105, 110, 91, 48, 44, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91,
  48, 44, 49, 93, 10, 45, 45, 109, 97, 120, 91, 48, 44, 50, 93, 10,
  45, 45, 109, 105, 110, 91, 48, 44, 50, 93, 10, 45, 114, 101, 109, 111,
  118, 101, 91, 48, 44, 50, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91,
  50, 93, 10, 45, 97, 100, 100, 10, 45, 109, 117, 108, 32, 48, 46, 53,
  10, 105, 97, 105, 110, 95, 109, 101, 100, 105, 97, 110, 95, 53, 95, 115,
  116, 97, 99, 107, 58, 10, 45, 45, 109, 105, 110, 91, 48, 44, 49, 93,
  10, 45, 45, 109, 97, 120, 91, 48, 44, 49, 93, 10, 45, 114, 101, 109,
  111, 118, 101, 91, 48, 44, 49, 93, 10, 45, 45, 109, 105, 110, 91, 48,
  44, 52, 93, 10, 45, 45, 109, 97, 120, 91, 48, 44, 52, 93, 10, 45,
  114, 101, 109, 111, 118, 101, 91, 48, 44, 52, 93, 10, 45, 45, 109, 105,
  110, 91, 48, 44, 52, 93, 10, 45, 45, 109, 97, 120, 91, 48, 44, 52,
  93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 48, 44, 52, 93, 10, 45,
  45, 109, 105, 110, 91, 48, 44, 52, 93, 10, 45, 45, 109, 97, 120, 91,
  48, 44, 52, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 48, 44, 52,
  93, 10, 45, 45, 109, 105, 110, 91, 48, 44, 49, 93, 10, 45, 45, 109,
  97, 120, 91, 48, 44, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91,
  48, 44, 49, 93, 10, 45, 45, 109, 105, 110, 91, 48, 44, 52, 93, 10,
  45, 45, 109, 97, 120, 91, 48, 44, 52, 93, 10, 45, 114, 101, 109, 111,
  118, 101, 91, 48, 44, 52, 93, 10, 45, 45, 109, 105, 110, 91, 48, 44,
  52, 93, 10, 45, 45, 109, 97, 120, 91, 48, 44, 52, 93, 10, 45, 114,
  101, 109, 111, 118, 101, 91, 48, 44, 52, 93, 10, 45, 45, 109, 105, 110,
  91, 49, 44, 50, 93, 10, 45, 45, 109, 97, 120, 91, 49, 44, 50, 93,
  10, 45, 114, 101, 109, 111, 118, 101, 91, 49, 44, 50, 93, 10, 45, 45,
  109, 97, 120, 91, 49, 44, 52, 93, 10, 45, 107, 101, 101, 112, 91, 45,
  49, 93, 10, 35, 64, 103, 105, 109, 112, 32, 76, 97, 121, 101, 114, 115,
  32, 116, 111, 32, 116, 105, 108, 101, 115, 32, 58, 32, 97, 112, 112, 101,
  110, 100, 95, 116, 105, 108, 101, 115, 44, 32, 103, 105, 109, 112, 95, 97,
  112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 95, 112, 114, 101, 118,
  105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  88, 45, 116, 105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 48, 44,
  48, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  89, 45, 116, 105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 48, 44,
  48, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 70, 111, 114, 32, 98, 111, 116, 104, 32, 112, 97, 114,
  97, 109, 101, 116, 101, 114, 115, 44, 32, 60, 105, 62, 48, 60, 47, 105,
  62, 32, 109, 101, 97, 110, 115, 32, 60, 105, 62, 97, 117, 116, 111, 109,
  97, 116, 105, 99, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68,
  97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38,
  35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112,
  95, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 102, 114, 97, 109, 101, 32, 49,
  44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 32, 45, 97, 112,
  112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 32, 36, 49, 44, 36, 50,
  10, 35, 64, 103, 105, 109, 112, 32, 77, 111, 114, 112, 104, 32, 108, 97,
  121, 101, 114, 115, 32, 58, 32, 103, 105, 109, 112, 95, 109, 111, 114, 112,
  104, 44, 32, 103, 105, 109, 112, 95, 110, 111, 95, 112, 114, 101, 118, 105,
  101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 116, 101,
  114, 45, 102, 114, 97, 109, 101, 115, 32, 61, 32, 95, 105, 110, 116, 40,
  49, 48, 44, 50, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32,
  95, 102, 108, 111, 97, 116, 40, 48, 46, 50, 44, 48, 44, 50, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 99, 105, 115, 105,
  111, 110, 32, 61, 32, 95, 102, 108, 111, 97, 116, 40, 48, 46, 49, 44,
  48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101,
  118, 101, 114, 116, 32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111,
  111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105,
  62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114,
  108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 109, 111, 114, 112, 104, 32, 58, 10, 45, 105, 102, 32, 36,
  123, 52, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118,
  101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 116, 111, 95, 114, 103, 98, 32, 45, 109, 111, 114, 112, 104,
  32, 36, 49, 44, 36, 50, 44, 36, 51, 10, 35, 64, 103, 105, 109, 112,
  32, 83, 112, 108, 105, 116, 32, 116, 111, 110, 101, 115, 32, 58, 32, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 116, 111, 110, 101, 115, 44,
  32, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 116, 111, 110, 101,
  115, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 117, 109, 98, 101, 114, 32, 111, 102, 32,
  116, 111, 110, 101, 115, 32, 61, 32, 105, 110, 116, 40, 51, 44, 50, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68,
  97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38,
  35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 116, 111, 110, 101, 115, 32, 58, 10, 45,
  114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 60, 93,
  10, 45, 45, 116, 111, 110, 101, 115, 32, 36, 49, 32, 45, 114, 91, 94,
  48, 93, 32, 91, 48, 93, 32, 45, 42, 91, 94, 48, 93, 32, 91, 48,
  93, 32, 45, 114, 109, 91, 48, 93, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  116, 111, 110, 101, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 116, 111, 110, 101,
  115, 32, 36, 49, 32, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108,
  101, 115, 32, 44, 10, 35, 64, 103, 105, 109, 112, 32, 84, 105, 108, 101,
  115, 32, 116, 111, 32, 108, 97, 121, 101, 114, 115, 32, 58, 32, 115, 112,
  108, 105, 116, 95, 116, 105, 108, 101, 115, 44, 32, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 116, 105, 108, 101, 115, 40, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 116, 105, 108, 101, 115, 32,
  61, 32, 105, 110, 116, 40, 51, 44, 49, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 116, 105, 108, 101, 115, 32,
  61, 32, 105, 110, 116, 40, 51, 44, 49, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 72, 111, 109, 111, 103, 101, 110, 101,
  111, 117, 115, 32, 116, 105, 108, 101, 115, 32, 61, 32, 95, 98, 111, 111,
  108, 40, 102, 97, 108, 115, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109,
  112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50,
  57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 116, 105, 108, 101,
  115, 32, 58, 10, 45, 115, 112, 108, 105, 116, 95, 116, 105, 108, 101, 115,
  32, 36, 49, 44, 36, 50, 44, 36, 51, 32, 45, 107, 91, 53, 48, 37,
  93, 10, 35, 64, 103, 105, 109, 112, 32, 84, 114, 97, 110, 115, 102, 101,
  114, 32, 99, 111, 108, 111, 114, 115, 32, 58, 32, 103, 105, 109, 112, 95,
  116, 114, 97, 110, 115, 102, 101, 114, 95, 99, 111, 108, 111, 114, 115, 44,
  32, 103, 105, 109, 112, 95, 116, 114, 97, 110, 115, 102, 101, 114, 95, 99,
  111, 108, 111, 114, 115, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84,
  114, 97, 110, 115, 102, 101, 114, 32, 98, 114, 105, 103, 104, 110, 101, 115,
  115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121, 101,
  114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 123, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 78, 111, 116,
  101, 58, 32, 60, 47, 98, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 84, 104, 101, 32, 116, 111, 112, 32, 108, 97, 121, 101, 114, 32, 99,
  111, 110, 116, 97, 105, 110, 115, 32, 116, 104, 101, 32, 116, 97, 114, 103,
  101, 116, 32, 99, 111, 108, 111, 114, 115, 46, 92, 110, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 84, 104, 105, 115, 32, 102, 105, 108, 116, 101,
  114, 32, 110, 101, 101, 100, 115, 32, 97, 116, 32, 108, 101, 97, 115, 116,
  32, 116, 119, 111, 32, 108, 97, 121, 101, 114, 115, 32, 116, 111, 32, 119,
  111, 114, 107, 32, 112, 114, 111, 112, 101, 114, 108, 121, 46, 32, 83, 101,
  116, 32, 116, 104, 101, 32, 60, 105, 62, 73, 110, 112, 117, 116, 32, 108,
  97, 121, 101, 114, 115, 60, 47, 105, 62, 32, 111, 112, 116, 105, 111, 110,
  32, 116, 111, 32, 104, 97, 110, 100, 108, 101, 32, 109, 117, 108, 116, 105,
  112, 108, 101, 32, 105, 110, 112, 117, 116, 32, 108, 97, 121, 101, 114, 115,
  46, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105,
  62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114,
  108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 116, 114, 97, 110, 115, 102, 101, 114, 95, 99, 111, 108, 111,
  114, 115, 32, 58, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125, 32,
  45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97,
  121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 114, 97,
  110, 115, 102, 101, 114, 95, 99, 111, 108, 111, 114, 115, 32, 36, 49, 10,
  35, 64, 103, 105, 109, 112, 32, 84, 114, 97, 110, 115, 112, 97, 114, 101,
  110, 116, 32, 100, 105, 102, 102, 101, 114, 101, 110, 99, 101, 32, 58, 32,
  103, 105, 109, 112, 95, 116, 114, 97, 110, 115, 112, 97, 114, 101, 110, 116,
  95, 100, 105, 102, 102, 44, 32, 103, 105, 109, 112, 95, 116, 114, 97, 110,
  115, 112, 97, 114, 101, 110, 116, 95, 100, 105, 102, 102, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111,
  108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 79, 112, 97, 113, 117, 101, 32, 112, 105, 120, 101, 108, 115, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 70, 114, 111, 109, 32,
  49, 115, 116, 32, 108, 97, 121, 101, 114, 34, 44, 34, 70, 114, 111, 109,
  32, 50, 110, 100, 32, 108, 97, 121, 101, 114, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110,
  116, 32, 112, 105, 120, 101, 108, 115, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 49, 44, 34, 70, 114, 111, 109, 32, 115, 97, 109, 101, 32, 118,
  97, 108, 117, 101, 115, 34, 44, 34, 70, 114, 111, 109, 32, 100, 105, 102,
  102, 101, 114, 101, 110, 116, 32, 118, 97, 108, 117, 101, 115, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32,
  108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 116, 114,
  97, 110, 115, 112, 97, 114, 101, 110, 116, 95, 100, 105, 102, 102, 32, 58,
  10, 45, 105, 102, 32, 36, 123, 53, 61, 48, 125, 32, 45, 95, 103, 105,
  109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 10, 45, 105, 102, 32,
  36, 51, 10, 45, 45, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45,
  110, 111, 114, 109, 91, 45, 50, 93, 32, 45, 98, 91, 45, 50, 93, 32,
  36, 50, 37, 32, 45, 103, 101, 91, 45, 50, 93, 32, 36, 49, 37, 32,
  45, 114, 118, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 108, 115, 101,
  10, 45, 45, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 110, 111,
  114, 109, 91, 45, 49, 93, 32, 45, 98, 91, 45, 49, 93, 32, 36, 50,
  37, 32, 45, 103, 101, 91, 45, 49, 93, 32, 36, 49, 37, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 33, 36, 52, 125, 32, 45,
  110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 50, 93,
  32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 10, 45, 109, 118, 91, 45,
  49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109,
  112, 32, 95, 10, 35, 64, 103, 105, 109, 112, 32, 60, 98, 62, 76, 105,
  103, 104, 116, 115, 32, 38, 97, 109, 112, 59, 32, 115, 104, 97, 100, 111,
  119, 115, 60, 47, 98, 62, 10, 35, 64, 103, 105, 109, 112, 32, 66, 117,
  114, 110, 32, 58, 32, 103, 105, 109, 112, 95, 98, 117, 114, 110, 44, 32,
  103, 105, 109, 112, 95, 98, 117, 114, 110, 95, 112, 114, 101, 118, 105, 101,
  119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109,
  112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 99, 97, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  51, 48, 44, 49, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44,
  34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114,
  101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34,
  44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115,
  34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115,
  34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72,
  117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34,
  44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34,
  71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34,
  82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108,
  117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97,
  116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 50, 47, 49, 49, 47, 50, 52, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 95, 103, 105,
  109, 112, 95, 98, 117, 114, 110, 32, 58, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 61, 123, 119,
  125, 32, 104, 61, 123, 104, 125, 10, 45, 45, 110, 111, 114, 109, 10, 45,
  103, 105, 109, 112, 95, 102, 111, 117, 114, 105, 101, 114, 91, 45, 49, 93,
  32, 48, 10, 45, 45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 48, 44,
  123, 36, 104, 45, 49, 125, 32, 45, 114, 91, 45, 49, 93, 32, 36, 50,
  37, 44, 36, 50, 37, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 98, 91, 45, 49, 93, 32,
  36, 51, 37, 10, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44,
  123, 40, 36, 119, 45, 119, 41, 47, 50, 125, 44, 123, 40, 36, 104, 45,
  104, 41, 47, 50, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 103,
  105, 109, 112, 95, 102, 111, 117, 114, 105, 101, 114, 91, 45, 49, 93, 32,
  49, 10, 45, 98, 108, 101, 110, 100, 32, 111, 118, 101, 114, 108, 97, 121,
  44, 36, 49, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  103, 105, 109, 112, 95, 98, 117, 114, 110, 32, 58, 10, 45, 97, 112, 112,
  108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 95, 103,
  105, 109, 112, 95, 98, 117, 114, 110, 32, 36, 123, 49, 45, 51, 125, 34,
  44, 36, 52, 44, 49, 10, 103, 105, 109, 112, 95, 98, 117, 114, 110, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  103, 105, 109, 112, 95, 98, 117, 114, 110, 32, 36, 123, 94, 48, 125, 34,
  44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 67, 111, 110, 116,
  114, 97, 115, 116, 32, 115, 119, 105, 115, 115, 32, 109, 97, 115, 107, 32,
  58, 32, 103, 105, 109, 112, 95, 99, 111, 110, 116, 114, 97, 115, 116, 95,
  115, 119, 109, 32, 44, 32, 103, 105, 109, 112, 95, 99, 111, 110, 116, 114,
  97, 115, 116, 95, 115, 119, 109, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66,
  108, 117, 114, 32, 116, 104, 101, 32, 109, 97, 115, 107, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 50, 44, 48, 46, 53, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 32, 40,
  34, 67, 111, 110, 116, 114, 97, 115, 116, 32, 77, 97, 115, 107, 32, 110,
  101, 101, 100, 32, 116, 104, 101, 32, 110, 101, 103, 97, 116, 105, 118, 101,
  32, 111, 102, 32, 116, 104, 101, 32, 109, 97, 115, 107, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 107, 105, 112, 32, 116, 111, 32,
  117, 115, 101, 32, 116, 104, 101, 32, 109, 97, 115, 107, 32, 116, 111, 32,
  98, 111, 111, 115, 116, 32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108,
  115, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 32, 40, 34, 85, 110, 99, 104, 101,
  99, 107, 32, 102, 111, 114, 32, 67, 111, 110, 116, 114, 97, 115, 116, 32,
  77, 97, 115, 107, 44, 67, 104, 101, 99, 107, 32, 102, 111, 114, 32, 67,
  111, 110, 116, 114, 97, 115, 116, 32, 66, 111, 111, 115, 116, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 77, 101, 114, 103, 101, 32, 116, 104, 101, 32, 77, 97, 115, 107, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 116, 101, 110,
  115, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 80,
  104, 111, 116, 111, 67, 111, 109, 105, 88, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 49, 47, 49, 32, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108,
  105, 110, 107, 40, 34, 70, 105, 108, 116, 101, 114, 32, 101, 120, 112, 108,
  97, 105, 110, 101, 100, 32, 104, 101, 114, 101, 34, 44, 34, 104, 116, 116,
  112, 58, 47, 47, 119, 119, 119, 46, 103, 105, 109, 112, 99, 104, 97, 116,
  46, 99, 111, 109, 47, 118, 105, 101, 119, 116, 111, 112, 105, 99, 46, 112,
  104, 112, 63, 102, 61, 57, 38, 116, 61, 56, 54, 52, 34, 41, 10, 103,
  105, 109, 112, 95, 99, 111, 110, 116, 114, 97, 115, 116, 95, 115, 119, 109,
  32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99,
  105, 116, 121, 32, 45, 108, 91, 48, 93, 10, 45, 45, 108, 117, 109, 105,
  110, 97, 110, 99, 101, 32, 45, 116, 111, 95, 114, 103, 98, 10, 45, 98,
  108, 117, 114, 95, 120, 121, 91, 49, 93, 32, 36, 49, 44, 36, 49, 10,
  45, 105, 102, 32, 123, 36, 50, 61, 61, 48, 125, 32, 45, 110, 101, 103,
  97, 116, 105, 118, 101, 91, 49, 93, 32, 45, 101, 108, 105, 102, 32, 123,
  36, 50, 61, 61, 49, 125, 32, 45, 103, 105, 109, 112, 95, 100, 111, 95,
  110, 111, 116, 104, 105, 110, 103, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 118, 32, 45, 98, 108, 101, 110, 100, 32, 104, 97, 114, 100, 108, 105,
  103, 104, 116, 44, 36, 51, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32,
  99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64,
  103, 105, 109, 112, 32, 68, 111, 100, 103, 101, 32, 97, 110, 100, 32, 98,
  117, 114, 110, 32, 58, 32, 103, 105, 109, 112, 95, 100, 111, 100, 103, 101,
  98, 117, 114, 110, 44, 32, 103, 105, 109, 112, 95, 100, 111, 100, 103, 101,
  98, 117, 114, 110, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 97, 117, 116, 111, 109, 97, 116, 105, 99, 32,
  100, 111, 100, 103, 105, 110, 103, 32, 97, 110, 100, 32, 98, 117, 114, 110,
  105, 110, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 105, 103, 104, 108, 105,
  103, 104, 116, 115, 32, 115, 101, 108, 101, 99, 116, 105, 111, 110, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 53, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 105, 103, 104, 108, 105,
  103, 104, 116, 115, 32, 97, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 53, 44, 48, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 111, 100, 103,
  101, 32, 115, 116, 114, 101, 110, 103, 116, 104, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 50, 53, 44, 48, 44, 50, 53, 54, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 111, 100, 103, 101, 32, 98, 108, 117, 114,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 50, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 100, 111,
  119, 115, 32, 115, 101, 108, 101, 99, 116, 105, 111, 110, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 52, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 100, 111, 119, 115, 32,
  97, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 46, 53, 44, 48, 44, 49, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 66, 117, 114, 110, 32, 115, 116, 114, 101,
  110, 103, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 53, 44,
  48, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  66, 117, 114, 110, 32, 98, 108, 117, 114, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 48, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 65, 100, 118, 97,
  110, 118, 101, 100, 58, 32, 111, 117, 116, 112, 117, 116, 32, 100, 111, 100,
  103, 101, 32, 97, 110, 100, 32, 98, 117, 114, 110, 32, 108, 97, 121, 101,
  114, 32, 115, 101, 112, 97, 114, 97, 116, 101, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 75, 101, 101, 112, 32, 108, 97, 121, 101, 114,
  115, 32, 115, 101, 112, 101, 114, 97, 116, 101, 32, 61, 32, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 75, 101,
  101, 112, 32, 111, 114, 105, 103, 105, 110, 97, 108, 32, 108, 97, 121, 101,
  114, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 66, 108, 117, 114, 32, 100, 111, 100, 103, 101, 32,
  97, 110, 100, 32, 98, 117, 114, 110, 32, 108, 97, 121, 101, 114, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 50, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 84, 111, 109, 32, 75, 101, 105, 108, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49,
  47, 48, 50, 47, 49, 53, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 100, 111, 100, 103, 101,
  98, 117, 114, 110, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 45, 108, 117, 109, 105, 110,
  97, 110, 99, 101, 32, 45, 105, 102, 32, 123, 36, 57, 61, 61, 49, 125,
  32, 45, 45, 102, 99, 91, 48, 93, 32, 49, 50, 56, 44, 49, 50, 56,
  44, 49, 50, 56, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108,
  95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 91, 49, 93, 32, 49,
  44, 49, 44, 48, 44, 36, 50, 44, 52, 44, 48, 44, 123, 49, 48, 48,
  45, 36, 49, 125, 44, 50, 53, 54, 44, 48, 44, 49, 44, 48, 44, 50,
  44, 48, 44, 48, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 99, 104,
  97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103,
  91, 49, 93, 32, 49, 44, 49, 44, 123, 45, 123, 50, 53, 54, 45, 36,
  51, 125, 125, 44, 48, 44, 48, 44, 48, 44, 49, 48, 48, 44, 50, 53,
  54, 44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 44, 48, 10, 45, 103,
  105, 109, 112, 95, 103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117,
  114, 91, 49, 93, 32, 36, 52, 44, 48, 44, 48, 44, 49, 44, 48, 44,
  48, 44, 48, 32, 45, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91,
  48, 93, 10, 45, 105, 102, 32, 123, 36, 57, 61, 61, 48, 125, 32, 45,
  99, 111, 109, 112, 111, 115, 101, 95, 100, 111, 100, 103, 101, 91, 48, 44,
  49, 93, 32, 45, 101, 108, 115, 101, 32, 45, 114, 118, 91, 49, 44, 50,
  93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 100, 111, 100, 103, 101,
  91, 49, 44, 50, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 107,
  95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114,
  111, 99, 101, 115, 115, 105, 110, 103, 91, 45, 49, 93, 32, 49, 44, 49,
  44, 48, 44, 36, 54, 44, 52, 44, 36, 53, 44, 49, 48, 48, 44, 50,
  53, 54, 44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 44, 48, 10, 45,
  116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95,
  112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 91, 45, 49, 93, 32, 49,
  44, 49, 44, 123, 50, 53, 54, 45, 36, 55, 125, 44, 48, 44, 48, 44,
  48, 44, 49, 48, 48, 44, 50, 53, 54, 44, 48, 44, 48, 44, 48, 44,
  50, 44, 48, 44, 48, 10, 45, 103, 105, 109, 112, 95, 103, 97, 117, 115,
  115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 56,
  44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 10, 45, 105, 102,
  32, 123, 36, 57, 61, 61, 48, 125, 32, 45, 99, 111, 109, 112, 111, 115,
  101, 95, 99, 111, 108, 111, 114, 98, 117, 114, 110, 91, 48, 44, 49, 93,
  32, 45, 101, 108, 115, 101, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  99, 111, 108, 111, 114, 98, 117, 114, 110, 91, 45, 49, 44, 45, 50, 93,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 57, 61,
  61, 49, 125, 32, 45, 103, 105, 109, 112, 95, 103, 97, 117, 115, 115, 105,
  97, 110, 95, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 49, 49, 44,
  48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 48, 61, 61, 48, 125, 32,
  45, 105, 102, 32, 123, 36, 57, 61, 61, 49, 125, 32, 45, 114, 109, 91,
  48, 93, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109,
  112, 95, 100, 111, 100, 103, 101, 98, 117, 114, 110, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112,
  95, 100, 111, 100, 103, 101, 98, 117, 114, 110, 32, 36, 123, 49, 45, 45,
  50, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 68,
  114, 111, 112, 32, 115, 104, 97, 100, 111, 119, 32, 58, 32, 103, 105, 109,
  112, 95, 100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119, 44, 32, 103,
  105, 109, 112, 95, 100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 115, 104,
  97, 100, 111, 119, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44, 45,
  50, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  89, 45, 115, 104, 97, 100, 111, 119, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 51, 44, 45, 50, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 46, 56, 44, 48, 44, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 114, 118, 97, 116, 117,
  114, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 114, 110, 101,
  114, 32, 98, 114, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 50, 47, 49,
  49, 47, 49, 52, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 100, 114, 111, 112, 95, 115, 104,
  97, 100, 111, 119, 32, 58, 10, 45, 42, 32, 45, 49, 32, 45, 43, 32,
  50, 53, 53, 32, 45, 118, 105, 103, 110, 101, 116, 116, 101, 32, 123, 50,
  53, 53, 42, 36, 53, 125, 44, 56, 48, 44, 57, 53, 32, 45, 42, 32,
  45, 49, 32, 45, 43, 32, 50, 53, 53, 10, 45, 100, 114, 111, 112, 95,
  115, 104, 97, 100, 111, 119, 32, 36, 49, 37, 44, 36, 50, 37, 44, 36,
  51, 37, 44, 36, 52, 32, 45, 114, 111, 116, 97, 116, 101, 32, 36, 54,
  44, 49, 44, 48, 10, 35, 64, 103, 105, 109, 112, 32, 68, 114, 111, 112,
  32, 115, 104, 97, 100, 111, 119, 32, 51, 100, 32, 58, 32, 103, 105, 109,
  112, 95, 100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119, 51, 100, 44,
  32, 103, 105, 109, 112, 95, 100, 114, 111, 112, 95, 115, 104, 97, 100, 111,
  119, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 97, 110, 103, 108, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 57, 48, 44, 57, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 97, 110, 103,
  108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 57, 48,
  44, 57, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 45,
  97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  45, 57, 48, 44, 57, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 90, 111, 111, 109, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 88, 45, 111, 102, 102, 115, 101, 116, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 44, 45, 53, 48, 44, 53, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 89, 45, 111, 102, 102, 115, 101, 116, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 45, 53, 48, 44, 53, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 101, 114, 115, 112,
  101, 99, 116, 105, 118, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50,
  44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 53, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108,
  111, 114, 40, 48, 44, 48, 44, 48, 44, 50, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 118, 105, 101, 119, 32, 111,
  110, 108, 121, 32, 115, 104, 97, 100, 111, 119, 32, 61, 32, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 51, 47, 48, 55, 47, 48, 50, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119, 51, 100, 32,
  58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 60, 93, 10, 45, 45, 95, 103, 105, 109, 112, 95, 100, 114, 111, 112,
  95, 115, 104, 97, 100, 111, 119, 51, 100, 32, 36, 42, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 100, 114,
  111, 112, 95, 115, 104, 97, 100, 111, 119, 51, 100, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 60, 93, 10, 45, 105, 102, 32, 36, 49, 51, 32,
  45, 95, 103, 105, 109, 112, 95, 100, 114, 111, 112, 95, 115, 104, 97, 100,
  111, 119, 51, 100, 32, 36, 42, 10, 45, 101, 108, 115, 101, 32, 45, 45,
  95, 103, 105, 109, 112, 95, 100, 114, 111, 112, 95, 115, 104, 97, 100, 111,
  119, 51, 100, 32, 36, 42, 32, 45, 114, 118, 32, 45, 98, 108, 101, 110,
  100, 32, 97, 108, 112, 104, 97, 44, 49, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 95, 103, 105,
  109, 112, 95, 100, 114, 111, 112, 95, 115, 104, 97, 100, 111, 119, 51, 100,
  32, 58, 10, 45, 112, 111, 105, 110, 116, 51, 100, 32, 48, 44, 48, 44,
  49, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 49, 44, 48, 44, 48,
  44, 36, 49, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48, 44, 49,
  44, 48, 44, 36, 50, 32, 45, 114, 51, 100, 91, 45, 49, 93, 32, 48,
  44, 48, 44, 49, 44, 36, 51, 10, 117, 61, 123, 105, 40, 48, 44, 56,
  41, 125, 32, 118, 61, 123, 105, 40, 48, 44, 57, 41, 125, 32, 119, 61,
  123, 105, 40, 48, 44, 49, 48, 41, 125, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 116, 111, 95, 97, 32, 45, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 49, 48, 48, 37, 32, 45, 105, 102, 32, 123, 105, 109, 61, 61,
  105, 77, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 45, 102, 32, 39, 88, 61, 120, 47, 119, 45, 48, 46,
  53, 59, 89, 61, 121, 47, 104, 45, 48, 46, 53, 59, 65, 61, 40, 36,
  55, 45, 36, 52, 42, 36, 55, 47, 49, 48, 48, 41, 42, 36, 119, 47,
  40, 88, 42, 36, 117, 43, 89, 42, 36, 118, 43, 36, 55, 42, 36, 119,
  41, 59, 105, 102, 40, 65, 60, 48, 44, 49, 101, 56, 44, 65, 41, 39,
  10, 45, 45, 42, 91, 45, 49, 93, 32, 39, 121, 47, 104, 45, 48, 46,
  53, 39, 32, 45, 42, 91, 45, 50, 93, 32, 39, 120, 47, 119, 45, 48,
  46, 53, 39, 32, 45, 43, 91, 45, 50, 93, 32, 123, 48, 46, 53, 45,
  36, 53, 47, 49, 48, 48, 125, 32, 45, 43, 91, 45, 49, 93, 32, 123,
  48, 46, 53, 45, 36, 54, 47, 49, 48, 48, 125, 32, 45, 42, 91, 45,
  50, 93, 32, 123, 119, 125, 32, 45, 42, 91, 45, 49, 93, 32, 123, 104,
  125, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 119,
  97, 114, 112, 91, 48, 93, 32, 91, 45, 49, 93, 44, 48, 44, 49, 44,
  48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 98, 32, 36, 56, 37,
  32, 45, 110, 32, 48, 44, 36, 49, 50, 32, 45, 105, 91, 45, 50, 93,
  32, 40, 36, 57, 94, 36, 49, 48, 94, 36, 49, 49, 41, 32, 45, 114,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 91, 45, 49, 93, 44, 49,
  44, 51, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 35,
  64, 103, 105, 109, 112, 32, 69, 113, 117, 97, 108, 105, 122, 101, 32, 115,
  104, 97, 100, 111, 119, 32, 58, 32, 103, 105, 109, 112, 95, 101, 113, 117,
  97, 108, 105, 122, 101, 95, 115, 104, 97, 100, 111, 119, 44, 32, 103, 105,
  109, 112, 95, 101, 113, 117, 97, 108, 105, 122, 101, 95, 115, 104, 97, 100,
  111, 119, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108,
  105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 115, 58,
  32, 60, 105, 62, 70, 114, 97, 110, 99, 111, 105, 115, 32, 71, 114, 97,
  115, 115, 97, 114, 100, 60, 47, 105, 62, 32, 97, 110, 100, 32, 60, 105,
  62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114,
  108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 50, 47, 49, 49, 47, 50, 52, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 101, 113, 117, 97, 108, 105, 122, 101, 95, 115, 104, 97, 100,
  111, 119, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 32, 45, 45, 110, 101, 103, 97, 116, 105, 118,
  101, 32, 45, 98, 108, 101, 110, 100, 32, 115, 111, 102, 116, 108, 105, 103,
  104, 116, 44, 36, 49, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 103, 105, 109, 112, 95, 101, 113, 117, 97, 108, 105, 122, 101, 95,
  115, 104, 97, 100, 111, 119, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 101, 113, 117, 97,
  108, 105, 122, 101, 95, 115, 104, 97, 100, 111, 119, 32, 36, 49, 34, 44,
  36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 76, 105, 103, 104, 116,
  32, 103, 108, 111, 119, 32, 58, 32, 103, 105, 109, 112, 95, 108, 105, 103,
  104, 116, 103, 108, 111, 119, 44, 32, 103, 105, 109, 112, 95, 108, 105, 103,
  104, 116, 103, 108, 111, 119, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 110, 115, 105,
  116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 48, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109,
  112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 53, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  56, 44, 34, 66, 117, 114, 110, 34, 44, 34, 68, 111, 100, 103, 101, 34,
  44, 34, 70, 114, 101, 101, 122, 101, 34, 44, 34, 71, 114, 97, 105, 110,
  32, 109, 101, 114, 103, 101, 34, 44, 34, 72, 97, 114, 100, 32, 108, 105,
  103, 104, 116, 34, 44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116,
  105, 111, 110, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 34, 76, 105,
  103, 104, 116, 101, 110, 34, 44, 34, 77, 117, 108, 116, 105, 112, 108, 121,
  34, 44, 34, 79, 118, 101, 114, 108, 97, 121, 34, 44, 34, 82, 101, 102,
  108, 101, 99, 116, 34, 44, 34, 83, 111, 102, 116, 32, 108, 105, 103, 104,
  116, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34, 86, 97, 108, 117,
  101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97,
  99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 56,
  44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44,
  34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114,
  101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34,
  44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115,
  34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115,
  34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72,
  117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34,
  44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34,
  71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34,
  82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108,
  117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97,
  116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 49, 47, 48, 50, 47, 50, 49, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 95, 103, 105,
  109, 112, 95, 108, 105, 103, 104, 116, 103, 108, 111, 119, 32, 58, 10, 109,
  111, 100, 101, 61, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43, 36, 51,
  44, 98, 117, 114, 110, 44, 100, 111, 100, 103, 101, 44, 102, 114, 101, 101,
  122, 101, 44, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 44, 104, 97,
  114, 100, 108, 105, 103, 104, 116, 44, 105, 110, 116, 101, 114, 112, 111, 108,
  97, 116, 105, 111, 110, 44, 108, 105, 103, 104, 116, 101, 110, 44, 109, 117,
  108, 116, 105, 112, 108, 121, 44, 111, 118, 101, 114, 108, 97, 121, 44, 114,
  101, 102, 108, 101, 99, 116, 44, 115, 111, 102, 116, 108, 105, 103, 104, 116,
  44, 115, 116, 97, 109, 112, 44, 118, 97, 108, 117, 101, 125, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 45, 103, 114, 97, 100, 105,
  101, 110, 116, 95, 110, 111, 114, 109, 91, 45, 49, 93, 32, 45, 103, 101,
  91, 45, 49, 93, 32, 123, 49, 48, 48, 45, 36, 49, 125, 37, 32, 45,
  100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45,
  94, 91, 45, 49, 93, 32, 36, 50, 32, 45, 42, 91, 45, 49, 93, 32,
  45, 49, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32,
  45, 98, 108, 101, 110, 100, 32, 36, 109, 111, 100, 101, 44, 36, 52, 10,
  45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10,
  103, 105, 109, 112, 95, 108, 105, 103, 104, 116, 103, 108, 111, 119, 32, 58,
  10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 34, 45, 95, 103, 105, 109, 112, 95, 108, 105, 103, 104, 116, 103, 108,
  111, 119, 32, 36, 123, 49, 45, 52, 125, 34, 44, 36, 53, 44, 48, 10,
  103, 105, 109, 112, 95, 108, 105, 103, 104, 116, 103, 108, 111, 119, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115,
  112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103,
  105, 109, 112, 95, 108, 105, 103, 104, 116, 103, 108, 111, 119, 32, 36, 42,
  34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 76, 105, 103,
  104, 116, 32, 112, 97, 116, 99, 104, 32, 58, 32, 103, 105, 109, 112, 95,
  108, 105, 103, 104, 116, 95, 112, 97, 116, 99, 104, 44, 32, 103, 105, 109,
  112, 95, 108, 105, 103, 104, 116, 95, 112, 97, 116, 99, 104, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 110, 115, 105, 116,
  121, 32, 61, 32, 105, 110, 116, 40, 53, 44, 50, 44, 51, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 97, 114, 107, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 103, 104,
  116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 46,
  53, 44, 49, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34,
  44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114,
  111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101,
  32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82,
  101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83,
  97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117,
  101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32,
  99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34,
  71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65,
  108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60,
  105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101,
  114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103,
  105, 109, 112, 95, 108, 105, 103, 104, 116, 95, 112, 97, 116, 99, 104, 32,
  58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105,
  116, 121, 32, 45, 108, 91, 48, 93, 10, 45, 97, 112, 112, 108, 121, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 108, 105, 103, 104, 116,
  95, 112, 97, 116, 99, 104, 32, 36, 49, 44, 36, 50, 44, 36, 51, 34,
  44, 36, 52, 44, 48, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103,
  105, 109, 112, 32, 76, 105, 103, 104, 116, 32, 114, 97, 121, 115, 32, 58,
  32, 103, 105, 109, 112, 95, 108, 105, 103, 104, 116, 114, 97, 121, 115, 44,
  32, 103, 105, 109, 112, 95, 108, 105, 103, 104, 116, 114, 97, 121, 115, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 110, 115,
  105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 56, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88,
  45, 99, 101, 110, 116, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 89, 45, 99, 101, 110, 116, 101, 114, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 76, 101, 110, 103, 116, 104, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 116, 116, 101, 110, 117, 97, 116, 105, 111, 110, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 114, 97, 110, 115, 112,
  97, 114, 101, 110, 99, 121, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 49, 47, 48, 49, 47, 48, 51, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 108, 105,
  103, 104, 116, 114, 97, 121, 115, 32, 58, 10, 45, 108, 105, 103, 104, 116,
  114, 97, 121, 115, 32, 36, 123, 49, 45, 53, 125, 10, 45, 105, 102, 32,
  36, 54, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 114,
  91, 36, 62, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 123, 64, 123, 36, 62, 44, 115, 125, 43, 40, 64, 123, 36, 62, 44,
  115, 125, 37, 50, 41, 125, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110,
  100, 105, 102, 10, 35, 64, 103, 105, 109, 112, 32, 82, 101, 108, 105, 101,
  102, 32, 108, 105, 103, 104, 116, 32, 58, 32, 103, 105, 109, 112, 95, 108,
  105, 103, 104, 116, 95, 114, 101, 108, 105, 101, 102, 44, 32, 103, 105, 109,
  112, 95, 108, 105, 103, 104, 116, 95, 114, 101, 108, 105, 101, 102, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 98, 105, 101,
  110, 116, 32, 108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 51, 44, 48, 44, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 112, 101, 99, 117, 108, 97, 114, 32,
  108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 50, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 112, 101, 99, 117, 108, 97, 114, 32, 115, 105, 122,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 50, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 97, 114, 107,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 103,
  104, 116, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 88, 45, 108, 105, 103, 104, 116, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 108, 105, 103, 104, 116, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 45, 108, 105, 103, 104,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 50, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 45, 115, 99, 97,
  108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48,
  44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97,
  99, 105, 116, 121, 32, 97, 115, 32, 98, 117, 109, 112, 109, 97, 112, 32,
  61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 73, 109, 97, 103, 101, 32, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68,
  97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38,
  35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112,
  95, 108, 105, 103, 104, 116, 95, 114, 101, 108, 105, 101, 102, 32, 58, 10,
  45, 98, 32, 36, 49, 49, 37, 32, 45, 108, 105, 103, 104, 116, 95, 114,
  101, 108, 105, 101, 102, 32, 36, 123, 49, 45, 49, 48, 125, 10, 35, 64,
  103, 105, 109, 112, 32, 83, 104, 97, 100, 111, 119, 32, 112, 97, 116, 99,
  104, 32, 58, 32, 103, 105, 109, 112, 95, 115, 104, 97, 100, 111, 119, 95,
  112, 97, 116, 99, 104, 44, 32, 103, 105, 109, 112, 95, 115, 104, 97, 100,
  111, 119, 95, 112, 97, 116, 99, 104, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 55, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115,
  41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34,
  44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76,
  117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47,
  114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115,
  34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105,
  110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115,
  115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34,
  72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110,
  34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44,
  34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66,
  108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84,
  115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48,
  47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 115, 104, 97, 100, 111,
  119, 95, 112, 97, 116, 99, 104, 32, 58, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108,
  105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91, 48, 93,
  10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 34, 45, 115, 104, 97, 100, 111, 119, 95, 112, 97, 116, 99, 104, 32,
  36, 49, 34, 44, 36, 50, 44, 48, 10, 45, 101, 110, 100, 108, 32, 45,
  97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  35, 64, 103, 105, 109, 112, 32, 95, 10, 35, 64, 103, 105, 109, 112, 32,
  60, 98, 62, 80, 97, 116, 116, 101, 114, 110, 115, 60, 47, 98, 62, 10,
  35, 64, 103, 105, 109, 112, 32, 66, 97, 121, 101, 114, 32, 102, 105, 108,
  116, 101, 114, 32, 58, 32, 114, 103, 98, 50, 98, 97, 121, 101, 114, 44,
  32, 114, 103, 98, 50, 98, 97, 121, 101, 114, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 116, 97, 114, 116, 105, 110, 103, 32,
  112, 97, 116, 116, 101, 114, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 48, 44, 34, 82, 101, 100, 45, 71, 114, 101, 101, 110, 34, 44, 34,
  66, 108, 117, 101, 45, 71, 114, 101, 101, 110, 34, 44, 34, 71, 114, 101,
  101, 110, 45, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 45, 66,
  108, 117, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 75,
  101, 101, 112, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32, 98, 111, 111,
  108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 66, 111, 120, 32, 102, 105, 116, 116, 105, 110, 103, 32,
  58, 32, 103, 105, 109, 112, 95, 98, 111, 120, 102, 105, 116, 116, 105, 110,
  103, 44, 32, 103, 105, 109, 112, 95, 98, 111, 120, 102, 105, 116, 116, 105,
  110, 103, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 77, 105, 110, 105, 109, 97, 108, 32, 115,
  105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 51, 44, 49, 44, 51, 50,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 97, 120, 105, 109,
  97, 108, 32, 115, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 48, 44,
  48, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 60, 98, 62, 78, 111, 116, 101, 58, 60, 47, 98, 62, 32,
  83, 101, 116, 32, 60, 105, 62, 77, 97, 120, 105, 109, 97, 108, 32, 115,
  105, 122, 101, 60, 47, 105, 62, 32, 116, 111, 32, 60, 105, 62, 48, 60,
  47, 105, 62, 32, 116, 111, 32, 97, 108, 108, 111, 119, 32, 97, 110, 121,
  32, 115, 105, 122, 101, 32, 102, 111, 114, 32, 116, 104, 101, 32, 115, 113,
  117, 97, 114, 101, 115, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 105, 116, 105, 97,
  108, 32, 100, 101, 110, 115, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 121,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 78, 111,
  116, 101, 58, 60, 47, 98, 62, 32, 84, 104, 105, 115, 32, 102, 105, 108,
  116, 101, 114, 32, 104, 97, 115, 32, 98, 101, 101, 110, 32, 104, 105, 103,
  104, 108, 121, 32, 105, 110, 115, 112, 105, 114, 101, 100, 32, 98, 121, 32,
  116, 104, 101, 32, 119, 111, 114, 107, 32, 111, 102, 32, 74, 97, 114, 101,
  100, 32, 84, 97, 114, 98, 101, 108, 108, 44, 32, 100, 101, 115, 99, 114,
  105, 98, 101, 100, 32, 111, 110, 32, 116, 104, 101, 32, 112, 97, 103, 101,
  58, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 76, 105, 110, 107, 32, 61, 32, 108, 105, 110, 107,
  40, 34, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 99, 111, 109,
  112, 108, 101, 120, 105, 102, 105, 99, 97, 116, 105, 111, 110, 46, 110, 101,
  116, 47, 103, 97, 108, 108, 101, 114, 121, 47, 109, 97, 99, 104, 105, 110,
  101, 115, 47, 98, 111, 120, 70, 105, 116, 116, 105, 110, 103, 73, 109, 103,
  47, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68,
  97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38,
  35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 51, 47, 48, 54, 47, 48, 54, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112,
  95, 98, 111, 120, 102, 105, 116, 116, 105, 110, 103, 32, 58, 10, 45, 98,
  111, 120, 102, 105, 116, 116, 105, 110, 103, 32, 36, 123, 49, 45, 51, 125,
  44, 51, 10, 45, 105, 102, 32, 36, 52, 32, 45, 116, 111, 95, 114, 103,
  98, 97, 32, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111,
  114, 32, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44,
  48, 44, 48, 44, 48, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 103,
  105, 109, 112, 95, 98, 111, 120, 102, 105, 116, 116, 105, 110, 103, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 98, 111, 120, 102, 105, 116,
  116, 105, 110, 103, 32, 36, 123, 49, 45, 51, 125, 44, 49, 10, 45, 105,
  102, 32, 36, 52, 32, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 114,
  101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 32, 48, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48,
  44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103, 105, 109, 112,
  32, 67, 97, 110, 118, 97, 115, 32, 58, 32, 103, 105, 109, 112, 95, 99,
  97, 110, 118, 97, 115, 44, 32, 103, 105, 109, 112, 95, 99, 97, 110, 118,
  97, 115, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 123, 34, 60, 98, 62, 70, 105, 114, 115, 116, 32, 100, 105, 114,
  101, 99, 116, 105, 111, 110, 32, 58, 60, 47, 98, 62, 34, 125, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 55, 48, 44, 48, 44, 51,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103,
  108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 53, 44, 48, 44,
  49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104,
  97, 114, 112, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  52, 48, 48, 44, 48, 44, 50, 48, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  123, 34, 92, 110, 60, 98, 62, 83, 101, 99, 111, 110, 100, 32, 100, 105,
  114, 101, 99, 116, 105, 111, 110, 32, 58, 32, 60, 47, 98, 62, 34, 125,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 99, 116, 105, 118, 97,
  116, 101, 32, 115, 101, 99, 111, 110, 100, 32, 100, 105, 114, 101, 99, 116,
  105, 111, 110, 32, 61, 32, 98, 111, 111, 108, 40, 116, 114, 117, 101, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116,
  117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 55, 48, 44, 48,
  44, 51, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 51, 53,
  44, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 104, 97, 114, 112, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 52, 48, 48, 44, 48, 44, 50, 48, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105,
  99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60,
  105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101,
  114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103,
  105, 109, 112, 95, 99, 97, 110, 118, 97, 115, 32, 58, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 45, 49, 93, 10, 45,
  105, 102, 32, 36, 52, 10, 40, 123, 99, 111, 115, 40, 36, 50, 42, 112,
  105, 47, 49, 56, 48, 41, 125, 94, 123, 115, 105, 110, 40, 36, 50, 42,
  112, 105, 47, 49, 56, 48, 41, 125, 41, 32, 45, 118, 101, 99, 116, 111,
  114, 50, 116, 101, 110, 115, 111, 114, 91, 45, 49, 93, 32, 45, 114, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 32, 45, 45,
  115, 109, 111, 111, 116, 104, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44,
  36, 49, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45, 115, 104, 97, 114,
  112, 101, 110, 91, 45, 49, 93, 32, 36, 51, 32, 45, 99, 91, 45, 49,
  93, 32, 48, 44, 50, 53, 53, 10, 40, 123, 99, 111, 115, 40, 36, 54,
  42, 112, 105, 47, 49, 56, 48, 41, 125, 94, 123, 115, 105, 110, 40, 36,
  54, 42, 112, 105, 47, 49, 56, 48, 41, 125, 41, 32, 45, 118, 101, 99,
  116, 111, 114, 50, 116, 101, 110, 115, 111, 114, 91, 45, 49, 93, 32, 45,
  114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 32,
  45, 115, 109, 111, 111, 116, 104, 91, 45, 51, 93, 32, 91, 45, 49, 93,
  44, 36, 53, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 115, 104, 97,
  114, 112, 101, 110, 91, 45, 50, 93, 32, 36, 55, 32, 45, 99, 91, 45,
  50, 93, 32, 48, 44, 50, 53, 53, 32, 45, 43, 91, 45, 50, 44, 45,
  49, 93, 32, 45, 47, 91, 45, 49, 93, 32, 50, 10, 45, 101, 108, 115,
  101, 10, 40, 123, 99, 111, 115, 40, 36, 50, 42, 112, 105, 47, 49, 56,
  48, 41, 125, 94, 123, 115, 105, 110, 40, 36, 50, 42, 112, 105, 47, 49,
  56, 48, 41, 125, 41, 32, 45, 118, 101, 99, 116, 111, 114, 50, 116, 101,
  110, 115, 111, 114, 91, 45, 49, 93, 32, 45, 114, 91, 45, 49, 93, 32,
  91, 45, 50, 93, 44, 91, 45, 50, 93, 32, 45, 115, 109, 111, 111, 116,
  104, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 49, 32, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 115, 104, 97, 114, 112, 101, 110, 91, 45,
  49, 93, 32, 36, 51, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32,
  45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10,
  103, 105, 109, 112, 95, 99, 97, 110, 118, 97, 115, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112,
  95, 99, 97, 110, 118, 97, 115, 32, 36, 42, 34, 44, 36, 45, 49, 10,
  35, 64, 103, 105, 109, 112, 32, 67, 97, 110, 118, 97, 115, 32, 116, 101,
  120, 116, 117, 114, 101, 32, 58, 32, 116, 101, 120, 116, 117, 114, 105, 122,
  101, 95, 99, 97, 110, 118, 97, 115, 44, 32, 116, 101, 120, 116, 117, 114,
  105, 122, 101, 95, 99, 97, 110, 118, 97, 115, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 48, 44, 50, 53,
  54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 105, 98, 114,
  111, 117, 115, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  51, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 69, 109, 98, 111, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 54, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109,
  112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50,
  57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 67, 108, 111, 117, 100, 115, 32, 58,
  32, 106, 101, 106, 101, 95, 99, 108, 111, 117, 100, 115, 44, 32, 106, 101,
  106, 101, 95, 99, 108, 111, 117, 100, 115, 95, 112, 114, 101, 118, 105, 101,
  119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 110, 115, 105,
  116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32,
  58, 32, 60, 105, 62, 74, 38, 35, 50, 51, 51, 59, 114, 38, 35, 50,
  52, 52, 59, 109, 101, 32, 66, 111, 117, 108, 97, 110, 103, 101, 114, 60,
  47, 105, 62, 46, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 53, 47, 50,
  57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 106, 101, 106, 101, 95, 99, 108, 111, 117, 100, 115, 32, 58, 10, 45,
  45, 99, 108, 111, 117, 100, 115, 32, 36, 49, 37, 44, 49, 44, 36, 50,
  32, 45, 98, 108, 101, 110, 100, 32, 97, 108, 112, 104, 97, 10, 106, 101,
  106, 101, 95, 99, 108, 111, 117, 100, 115, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 106, 101, 106, 101, 95, 99, 108, 111, 117, 100, 115,
  32, 36, 49, 44, 36, 50, 10, 35, 64, 103, 105, 109, 112, 32, 67, 114,
  97, 99, 107, 115, 32, 58, 32, 103, 105, 109, 112, 95, 99, 114, 97, 99,
  107, 115, 44, 32, 103, 105, 109, 112, 95, 99, 114, 97, 99, 107, 115, 95,
  112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 68, 101, 110, 115, 105, 116, 121, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 44, 48, 46, 49, 44, 49, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 45, 56, 48, 44, 45, 50, 53,
  53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  82, 101, 108, 105, 101, 102, 32, 61, 32, 98, 111, 111, 108, 40, 116, 114,
  117, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97,
  110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82,
  71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105,
  110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32,
  99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105,
  103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117,
  114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44,
  34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114,
  111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101,
  101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104,
  97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49,
  50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 99, 114, 97, 99, 107, 115, 32,
  58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 34, 45, 99, 114, 97, 99, 107, 115, 32, 36, 49, 44, 36, 50,
  44, 36, 51, 34, 44, 36, 52, 44, 48, 10, 103, 105, 109, 112, 95, 99,
  114, 97, 99, 107, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 99, 114, 97, 99, 107,
  115, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112,
  32, 72, 97, 108, 102, 116, 111, 110, 101, 32, 58, 32, 103, 105, 109, 112,
  95, 104, 97, 108, 102, 116, 111, 110, 101, 44, 32, 103, 105, 109, 112, 95,
  104, 97, 108, 102, 116, 111, 110, 101, 95, 112, 114, 101, 118, 105, 101, 119,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 98, 62, 60, 115, 109,
  97, 108, 108, 62, 73, 109, 97, 103, 101, 32, 112, 97, 114, 97, 109, 101,
  116, 101, 114, 115, 32, 58, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47,
  98, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 97,
  109, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49,
  46, 50, 44, 49, 46, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 66, 114, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 98,
  62, 60, 115, 109, 97, 108, 108, 62, 72, 97, 108, 102, 116, 111, 110, 101,
  32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 58, 60, 47, 115,
  109, 97, 108, 108, 62, 60, 47, 98, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 117, 109, 98, 101, 114, 32, 111, 102, 32, 116,
  111, 110, 101, 115, 32, 61, 32, 105, 110, 116, 40, 53, 44, 50, 44, 51,
  50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 105, 122, 101,
  32, 102, 111, 114, 32, 100, 97, 114, 107, 32, 116, 111, 110, 101, 115, 32,
  61, 32, 105, 110, 116, 40, 56, 44, 50, 44, 50, 53, 54, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 105, 122, 101, 32, 102, 111, 114,
  32, 98, 114, 105, 103, 104, 116, 32, 116, 111, 110, 101, 115, 32, 61, 32,
  105, 110, 116, 40, 56, 44, 50, 44, 50, 53, 54, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 104, 97, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 123, 53, 44, 34, 83, 113, 117, 97, 114, 101, 34, 44,
  34, 68, 105, 97, 109, 111, 110, 100, 34, 44, 34, 67, 105, 114, 99, 108,
  101, 34, 44, 34, 83, 113, 117, 97, 114, 101, 32, 40, 105, 110, 118, 46,
  41, 34, 44, 34, 68, 105, 97, 109, 111, 110, 100, 32, 40, 105, 110, 118,
  46, 41, 34, 44, 34, 67, 105, 114, 99, 108, 101, 32, 40, 105, 110, 118,
  46, 41, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 49, 44, 48, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117,
  108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117,
  112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 50, 47, 48, 55, 47, 50, 51, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  104, 97, 108, 102, 116, 111, 110, 101, 32, 58, 10, 45, 97, 112, 112, 108,
  121, 95, 103, 97, 109, 109, 97, 32, 123, 49, 48, 94, 36, 49, 125, 32,
  45, 45, 32, 49, 50, 56, 32, 45, 42, 32, 36, 50, 32, 45, 43, 32,
  49, 50, 56, 32, 45, 43, 32, 36, 51, 32, 45, 98, 32, 36, 52, 32,
  45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105,
  116, 95, 111, 112, 97, 99, 105, 116, 121, 10, 45, 104, 97, 108, 102, 116,
  111, 110, 101, 91, 48, 93, 32, 36, 123, 53, 45, 57, 125, 10, 45, 97,
  32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103,
  105, 109, 112, 95, 104, 97, 108, 102, 116, 111, 110, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109,
  112, 95, 104, 97, 108, 102, 116, 111, 110, 101, 32, 36, 42, 34, 44, 36,
  45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 72, 97, 108, 102, 116, 111,
  110, 101, 32, 115, 104, 97, 112, 101, 115, 32, 58, 32, 105, 97, 105, 110,
  95, 104, 97, 108, 102, 116, 111, 110, 101, 95, 115, 104, 97, 112, 101, 115,
  44, 32, 105, 97, 105, 110, 95, 104, 97, 108, 102, 116, 111, 110, 101, 95,
  115, 104, 97, 112, 101, 115, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 99, 97, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 48, 48, 44, 49, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 101, 103, 97, 116, 105, 118, 101, 32, 61,
  98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 104, 97, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 67, 105, 114, 99, 108, 101, 34, 44, 34, 83, 116, 97, 114, 34, 44,
  34, 84, 114, 105, 97, 110, 103, 108, 101, 34, 44, 34, 72, 101, 97, 114,
  116, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 118, 101,
  114, 115, 97, 109, 112, 108, 101, 32, 61, 32, 98, 111, 111, 108, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 111, 116, 97, 116,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 56,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 119, 105, 114,
  108, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 50, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 79, 118, 101, 114, 115, 97, 109, 112, 108, 101, 32, 103, 105, 118,
  101, 115, 32, 115, 109, 111, 111, 116, 104, 101, 114, 32, 114, 101, 115, 117,
  108, 116, 115, 32, 98, 117, 116, 32, 116, 97, 107, 101, 115, 32, 109, 117,
  99, 104, 32, 108, 111, 110, 103, 101, 114, 46, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 84, 119, 105, 114, 108, 32, 100, 105, 115, 116, 111, 114, 116,
  115, 32, 116, 104, 101, 32, 104, 97, 102, 108, 116, 111, 110, 101, 32, 103,
  114, 105, 100, 46, 32, 84, 104, 101, 32, 112, 114, 101, 118, 105, 101, 119,
  32, 105, 115, 32, 110, 111, 116, 32, 97, 99, 99, 117, 114, 97, 116, 101,
  46, 32, 70, 111, 114, 32, 98, 101, 115, 116, 32, 114, 101, 115, 117, 108,
  116, 115, 32, 117, 115, 101, 32, 119, 105, 116, 104, 32, 111, 118, 101, 114,
  115, 97, 109, 112, 108, 101, 46, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 73, 97,
  105, 110, 32, 70, 101, 114, 103, 117, 115, 115, 111, 110, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 105, 97, 105, 110,
  95, 104, 97, 108, 102, 116, 111, 110, 101, 95, 115, 104, 97, 112, 101, 115,
  58, 10, 45, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105, 116,
  121, 10, 115, 99, 97, 108, 101, 61, 36, 49, 10, 45, 108, 117, 109, 105,
  110, 97, 110, 99, 101, 10, 45, 105, 102, 32, 123, 36, 52, 61, 61, 49,
  125, 10, 45, 114, 101, 115, 105, 122, 101, 32, 52, 48, 48, 37, 44, 52,
  48, 48, 37, 44, 49, 44, 49, 44, 51, 10, 115, 99, 97, 108, 101, 61,
  123, 36, 115, 99, 97, 108, 101, 42, 52, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 51, 61, 61, 48, 125, 10, 115, 120,
  49, 61, 51, 53, 51, 10, 115, 120, 50, 61, 53, 49, 53, 10, 115, 120,
  51, 61, 54, 55, 55, 10, 115, 120, 52, 61, 49, 48, 48, 48, 10, 115,
  120, 53, 61, 49, 51, 50, 51, 10, 115, 120, 54, 61, 49, 52, 56, 53,
  10, 115, 120, 55, 61, 49, 54, 52, 55, 10, 115, 120, 56, 61, 49, 52,
  56, 53, 10, 115, 120, 57, 61, 49, 51, 50, 51, 10, 115, 120, 49, 48,
  61, 49, 48, 48, 48, 10, 115, 120, 49, 49, 61, 54, 55, 55, 10, 115,
  120, 49, 50, 61, 53, 49, 53, 10, 115, 121, 49, 61, 49, 48, 48, 48,
  10, 115, 121, 50, 61, 49, 50, 56, 48, 10, 115, 121, 51, 61, 49, 53,
  54, 48, 10, 115, 121, 52, 61, 49, 53, 54, 48, 10, 115, 121, 53, 61,
  49, 53, 54, 48, 10, 115, 121, 54, 61, 49, 50, 56, 48, 10, 115, 121,
  55, 61, 49, 48, 48, 48, 10, 115, 121, 56, 61, 55, 50, 48, 10, 115,
  121, 57, 61, 52, 52, 48, 10, 115, 121, 49, 48, 61, 52, 52, 48, 10,
  115, 121, 49, 49, 61, 52, 52, 48, 10, 115, 121, 49, 50, 61, 55, 50,
  48, 10, 108, 101, 118, 101, 108, 61, 49, 57, 10, 45, 108, 117, 109, 105,
  110, 97, 110, 99, 101, 10, 45, 45, 108, 10, 45, 114, 109, 10, 50, 48,
  48, 48, 44, 50, 48, 48, 48, 44, 49, 44, 49, 44, 48, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 49, 57, 10, 45, 112, 111, 108, 121, 103, 111,
  110, 32, 49, 50, 44, 36, 115, 120, 49, 44, 36, 115, 121, 49, 44, 36,
  115, 120, 50, 44, 36, 115, 121, 50, 44, 36, 115, 120, 51, 44, 36, 115,
  121, 51, 44, 36, 115, 120, 52, 44, 36, 115, 121, 52, 44, 36, 115, 120,
  53, 44, 36, 115, 121, 53, 44, 36, 115, 120, 54, 44, 36, 115, 121, 54,
  44, 36, 115, 120, 55, 44, 36, 115, 121, 55, 44, 36, 115, 120, 56, 44,
  36, 115, 121, 56, 44, 36, 115, 120, 57, 44, 36, 115, 121, 57, 44, 36,
  115, 120, 49, 48, 44, 36, 115, 121, 49, 48, 44, 36, 115, 120, 49, 49,
  44, 36, 115, 121, 49, 49, 44, 36, 115, 120, 49, 50, 44, 36, 115, 121,
  49, 50, 44, 49, 44, 36, 108, 101, 118, 101, 108, 10, 115, 121, 51, 61,
  123, 36, 115, 121, 51, 45, 40, 55, 56, 47, 49, 54, 41, 125, 10, 115,
  121, 53, 61, 123, 36, 115, 121, 53, 45, 40, 55, 56, 47, 49, 54, 41,
  125, 10, 115, 121, 57, 61, 123, 36, 115, 121, 57, 43, 40, 55, 56, 47,
  49, 54, 41, 125, 10, 115, 121, 49, 49, 61, 123, 36, 115, 121, 49, 49,
  43, 40, 55, 56, 47, 49, 54, 41, 125, 10, 115, 120, 49, 61, 123, 36,
  115, 120, 49, 43, 40, 57, 48, 47, 49, 54, 41, 125, 10, 115, 120, 51,
  61, 123, 36, 115, 120, 51, 43, 40, 52, 53, 47, 49, 54, 41, 125, 10,
  115, 120, 53, 61, 123, 36, 115, 120, 53, 45, 40, 52, 53, 47, 49, 54,
  41, 125, 10, 115, 120, 55, 61, 123, 36, 115, 120, 55, 45, 40, 57, 48,
  47, 49, 54, 41, 125, 10, 115, 120, 57, 61, 123, 36, 115, 120, 57, 45,
  40, 52, 53, 47, 49, 54, 41, 125, 10, 115, 120, 49, 49, 61, 123, 36,
  115, 120, 49, 49, 43, 40, 52, 53, 47, 49, 54, 41, 125, 10, 108, 101,
  118, 101, 108, 61, 123, 36, 108, 101, 118, 101, 108, 43, 49, 48, 125, 10,
  45, 100, 111, 110, 101, 10, 114, 97, 100, 105, 117, 115, 61, 123, 53, 54,
  48, 125, 10, 108, 101, 118, 101, 108, 61, 50, 48, 57, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 53, 55, 10, 45, 99, 105, 114, 99, 108, 101, 32,
  53, 48, 37, 44, 53, 48, 37, 44, 36, 114, 97, 100, 105, 117, 115, 44,
  49, 44, 36, 108, 101, 118, 101, 108, 10, 114, 97, 100, 105, 117, 115, 61,
  123, 36, 114, 97, 100, 105, 117, 115, 45, 49, 48, 125, 10, 108, 101, 118,
  101, 108, 61, 123, 36, 108, 101, 118, 101, 108, 43, 49, 48, 125, 10, 45,
  100, 111, 110, 101, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 45,
  115, 104, 105, 102, 116, 91, 48, 93, 32, 57, 55, 50, 44, 53, 54, 48,
  44, 48, 44, 48, 10, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93, 32,
  57, 55, 50, 44, 45, 53, 54, 48, 44, 48, 44, 48, 10, 45, 45, 115,
  104, 105, 102, 116, 91, 48, 93, 32, 45, 57, 55, 50, 44, 53, 54, 48,
  44, 48, 44, 48, 10, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93, 32,
  45, 57, 55, 50, 44, 45, 53, 54, 48, 44, 48, 44, 48, 10, 45, 97,
  100, 100, 10, 45, 99, 114, 111, 112, 32, 50, 57, 44, 52, 52, 48, 44,
  49, 57, 55, 50, 44, 49, 53, 54, 48, 10, 45, 101, 110, 100, 108, 10,
  45, 114, 101, 115, 105, 122, 101, 91, 49, 93, 32, 49, 57, 52, 44, 49,
  49, 50, 44, 49, 44, 49, 44, 50, 10, 45, 101, 113, 117, 97, 108, 105,
  122, 101, 91, 49, 93, 32, 54, 53, 53, 53, 53, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 49, 93, 32, 36, 115, 99, 97, 108, 101, 37, 44, 36,
  115, 99, 97, 108, 101, 37, 44, 49, 44, 49, 44, 51, 10, 45, 105, 102,
  32, 123, 36, 50, 61, 61, 49, 125, 10, 45, 110, 101, 103, 97, 116, 105,
  118, 101, 91, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 51, 61, 61, 49, 125, 10,
  115, 120, 49, 61, 53, 48, 10, 115, 120, 50, 61, 49, 57, 52, 10, 115,
  120, 51, 61, 50, 56, 49, 10, 115, 120, 52, 61, 53, 49, 49, 10, 115,
  120, 53, 61, 55, 52, 50, 10, 115, 120, 54, 61, 56, 50, 57, 10, 115,
  120, 55, 61, 57, 55, 50, 10, 115, 120, 56, 61, 56, 50, 57, 10, 115,
  120, 57, 61, 55, 52, 50, 10, 115, 120, 49, 48, 61, 53, 49, 49, 10,
  115, 120, 49, 49, 61, 50, 56, 49, 10, 115, 120, 49, 50, 61, 49, 57,
  50, 10, 115, 121, 49, 61, 52, 53, 48, 10, 115, 121, 50, 61, 54, 51,
  51, 10, 115, 121, 51, 61, 56, 52, 57, 10, 115, 121, 52, 61, 56, 49,
  55, 10, 115, 121, 53, 61, 56, 52, 57, 10, 115, 121, 54, 61, 54, 51,
  51, 10, 115, 121, 55, 61, 52, 53, 48, 10, 115, 121, 56, 61, 50, 54,
  55, 10, 115, 121, 57, 61, 53, 48, 10, 115, 121, 49, 48, 61, 56, 51,
  10, 115, 121, 49, 49, 61, 53, 48, 10, 115, 121, 49, 50, 61, 50, 54,
  55, 10, 108, 101, 118, 101, 108, 61, 49, 48, 10, 45, 108, 117, 109, 105,
  110, 97, 110, 99, 101, 10, 45, 45, 108, 10, 45, 114, 109, 10, 50, 48,
  48, 48, 44, 50, 48, 48, 48, 44, 49, 44, 49, 44, 48, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 49, 50, 56, 10, 45, 112, 111, 108, 121, 103,
  111, 110, 32, 49, 50, 44, 36, 115, 120, 49, 44, 36, 115, 121, 49, 44,
  36, 115, 120, 50, 44, 36, 115, 121, 50, 44, 36, 115, 120, 51, 44, 36,
  115, 121, 51, 44, 36, 115, 120, 52, 44, 36, 115, 121, 52, 44, 36, 115,
  120, 53, 44, 36, 115, 121, 53, 44, 36, 115, 120, 54, 44, 36, 115, 121,
  54, 44, 36, 115, 120, 55, 44, 36, 115, 121, 55, 44, 36, 115, 120, 56,
  44, 36, 115, 121, 56, 44, 36, 115, 120, 57, 44, 36, 115, 121, 57, 44,
  36, 115, 120, 49, 48, 44, 36, 115, 121, 49, 48, 44, 36, 115, 120, 49,
  49, 44, 36, 115, 121, 49, 49, 44, 36, 115, 120, 49, 50, 44, 36, 115,
  121, 49, 50, 44, 49, 44, 36, 108, 101, 118, 101, 108, 10, 115, 120, 50,
  61, 123, 36, 115, 120, 50, 43, 40, 52, 48, 47, 49, 54, 41, 125, 10,
  115, 120, 54, 61, 123, 36, 115, 120, 54, 45, 40, 52, 48, 47, 49, 54,
  41, 125, 10, 115, 120, 56, 61, 123, 36, 115, 120, 56, 45, 40, 52, 48,
  47, 49, 54, 41, 125, 10, 115, 120, 49, 50, 61, 123, 36, 115, 120, 49,
  50, 43, 40, 52, 48, 47, 49, 54, 41, 125, 10, 115, 121, 50, 61, 123,
  36, 115, 121, 50, 45, 40, 50, 51, 47, 49, 54, 41, 125, 10, 115, 121,
  52, 61, 123, 36, 115, 121, 52, 45, 40, 52, 55, 47, 49, 54, 41, 125,
  10, 115, 121, 54, 61, 123, 36, 115, 121, 54, 45, 40, 50, 51, 47, 49,
  54, 41, 125, 10, 115, 121, 56, 61, 123, 36, 115, 121, 56, 43, 40, 50,
  51, 47, 49, 54, 41, 125, 10, 115, 121, 49, 48, 61, 123, 36, 115, 121,
  49, 48, 43, 40, 52, 55, 47, 49, 54, 41, 125, 10, 115, 121, 49, 50,
  61, 123, 36, 115, 121, 49, 50, 43, 40, 50, 51, 47, 49, 54, 41, 125,
  10, 108, 101, 118, 101, 108, 61, 123, 36, 108, 101, 118, 101, 108, 43, 49,
  50, 125, 10, 45, 100, 111, 110, 101, 10, 45, 110, 32, 48, 44, 50, 53,
  53, 10, 45, 114, 101, 115, 105, 122, 101, 32, 50, 48, 48, 44, 50, 48,
  48, 44, 49, 44, 49, 44, 51, 10, 45, 45, 115, 104, 105, 102, 116, 91,
  48, 93, 32, 45, 54, 57, 44, 45, 52, 48, 44, 48, 44, 48, 10, 45,
  45, 115, 104, 105, 102, 116, 91, 48, 93, 32, 45, 54, 57, 44, 52, 48,
  44, 48, 44, 48, 10, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93, 32,
  54, 57, 44, 45, 52, 48, 44, 48, 44, 48, 10, 45, 45, 115, 104, 105,
  102, 116, 91, 48, 93, 32, 54, 57, 44, 52, 48, 44, 48, 44, 48, 10,
  45, 97, 100, 100, 10, 45, 99, 114, 111, 112, 32, 53, 44, 53, 44, 49,
  52, 50, 44, 56, 52, 10, 45, 101, 110, 100, 108, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 49, 93, 32, 49, 57, 52, 44, 49, 49, 50, 44, 49,
  44, 49, 44, 50, 10, 45, 101, 113, 117, 97, 108, 105, 122, 101, 91, 49,
  93, 32, 54, 53, 53, 53, 53, 10, 45, 114, 101, 115, 105, 122, 101, 91,
  49, 93, 32, 36, 115, 99, 97, 108, 101, 37, 44, 36, 115, 99, 97, 108,
  101, 37, 44, 49, 44, 49, 44, 51, 10, 45, 105, 102, 32, 123, 36, 50,
  61, 61, 49, 125, 10, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 49,
  93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 51, 61, 61, 50, 125, 10, 115, 120, 49, 61,
  49, 54, 49, 10, 115, 120, 50, 61, 49, 48, 48, 48, 10, 115, 120, 51,
  61, 49, 56, 51, 57, 10, 115, 121, 49, 61, 50, 55, 51, 10, 115, 121,
  50, 61, 49, 55, 50, 55, 10, 115, 121, 51, 61, 50, 55, 51, 10, 108,
  101, 118, 101, 108, 61, 49, 48, 10, 45, 108, 117, 109, 105, 110, 97, 110,
  99, 101, 10, 45, 45, 108, 10, 45, 114, 109, 10, 50, 48, 48, 48, 44,
  50, 48, 48, 48, 44, 49, 44, 49, 44, 48, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 51, 55, 53, 10, 45, 112, 111, 108, 121, 103, 111, 110, 32,
  51, 44, 36, 115, 120, 49, 44, 36, 115, 121, 49, 44, 36, 115, 120, 50,
  44, 36, 115, 121, 50, 44, 36, 115, 120, 51, 44, 36, 115, 121, 51, 44,
  49, 44, 36, 108, 101, 118, 101, 108, 10, 115, 120, 49, 61, 123, 36, 115,
  120, 49, 43, 50, 46, 50, 49, 125, 10, 115, 120, 51, 61, 123, 36, 115,
  120, 51, 45, 50, 46, 50, 49, 125, 10, 115, 121, 49, 61, 123, 36, 115,
  121, 49, 43, 49, 46, 50, 56, 125, 10, 115, 121, 50, 61, 123, 36, 115,
  121, 50, 45, 50, 46, 53, 54, 125, 10, 115, 121, 51, 61, 123, 36, 115,
  121, 51, 43, 49, 46, 50, 56, 125, 10, 108, 101, 118, 101, 108, 61, 123,
  36, 108, 101, 118, 101, 108, 43, 49, 125, 10, 45, 100, 111, 110, 101, 10,
  45, 45, 114, 111, 116, 97, 116, 101, 91, 48, 93, 32, 49, 56, 48, 10,
  45, 45, 115, 104, 105, 102, 116, 91, 49, 93, 32, 123, 56, 52, 48, 43,
  50, 125, 10, 45, 115, 104, 105, 102, 116, 91, 49, 93, 32, 45, 56, 52,
  48, 10, 45, 97, 100, 100, 10, 45, 99, 114, 111, 112, 32, 49, 54, 48,
  44, 123, 50, 49, 54, 43, 53, 54, 125, 44, 49, 56, 52, 50, 44, 49,
  55, 50, 55, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110,
  100, 108, 10, 45, 101, 113, 117, 97, 108, 105, 122, 101, 91, 49, 93, 32,
  50, 53, 54, 10, 45, 114, 101, 115, 105, 122, 101, 91, 49, 93, 32, 49,
  54, 56, 44, 49, 52, 53, 44, 49, 44, 49, 44, 50, 10, 45, 114, 101,
  115, 105, 122, 101, 91, 49, 93, 32, 36, 115, 99, 97, 108, 101, 37, 44,
  36, 115, 99, 97, 108, 101, 37, 44, 49, 44, 49, 44, 51, 10, 45, 105,
  102, 32, 123, 36, 50, 61, 61, 49, 125, 10, 45, 110, 101, 103, 97, 116,
  105, 118, 101, 91, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 51, 61, 61, 51, 125,
  10, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 10, 45, 45, 108, 10,
  45, 114, 109, 10, 45, 108, 10, 49, 57, 48, 44, 49, 57, 48, 44, 49,
  44, 49, 44, 48, 10, 45, 99, 105, 114, 99, 108, 101, 32, 53, 48, 44,
  53, 48, 44, 53, 48, 44, 49, 44, 49, 48, 10, 45, 99, 105, 114, 99,
  108, 101, 32, 49, 52, 48, 44, 53, 48, 44, 53, 48, 44, 49, 44, 49,
  48, 10, 45, 112, 111, 108, 121, 103, 111, 110, 32, 53, 44, 49, 48, 44,
  56, 48, 44, 53, 48, 44, 53, 48, 44, 49, 52, 48, 44, 53, 48, 44,
  49, 56, 48, 44, 56, 48, 44, 57, 53, 44, 49, 57, 48, 44, 49, 44,
  49, 48, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 64,
  123, 48, 44, 119, 43, 50, 125, 44, 64, 123, 48, 44, 104, 43, 50, 125,
  44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53,
  10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 57, 53, 37,
  44, 57, 53, 37, 44, 49, 44, 49, 44, 50, 10, 45, 114, 101, 115, 105,
  122, 101, 91, 45, 49, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123,
  48, 44, 104, 125, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53,
  44, 48, 46, 53, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93,
  32, 57, 48, 37, 44, 57, 48, 37, 44, 49, 44, 49, 44, 50, 10, 45,
  114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 48, 44, 119,
  125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 49, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45, 114, 101, 115, 105, 122,
  101, 91, 48, 93, 32, 56, 53, 37, 44, 56, 53, 37, 44, 49, 44, 49,
  44, 50, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 64,
  123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 49,
  44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45, 114,
  101, 115, 105, 122, 101, 91, 48, 93, 32, 55, 53, 37, 44, 55, 53, 37,
  44, 49, 44, 49, 44, 50, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45,
  49, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125,
  44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53,
  10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 54, 53, 37,
  44, 54, 53, 37, 44, 49, 44, 49, 44, 50, 10, 45, 114, 101, 115, 105,
  122, 101, 91, 45, 49, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123,
  48, 44, 104, 125, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53,
  44, 48, 46, 53, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93,
  32, 53, 53, 37, 44, 53, 53, 37, 44, 49, 44, 49, 44, 50, 10, 45,
  114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 48, 44, 119,
  125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 49, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45, 114, 101, 115, 105, 122,
  101, 91, 48, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 49, 44, 49,
  44, 50, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 64,
  123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 49,
  44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45, 114,
  101, 115, 105, 122, 101, 91, 48, 93, 32, 52, 53, 37, 44, 52, 53, 37,
  44, 49, 44, 49, 44, 50, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45,
  49, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125,
  44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53,
  10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 52, 48, 37,
  44, 52, 48, 37, 44, 49, 44, 49, 44, 50, 10, 45, 114, 101, 115, 105,
  122, 101, 91, 45, 49, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123,
  48, 44, 104, 125, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53,
  44, 48, 46, 53, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93,
  32, 51, 53, 37, 44, 51, 53, 37, 44, 49, 44, 49, 44, 50, 10, 45,
  114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 48, 44, 119,
  125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 49, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45, 114, 101, 115, 105, 122,
  101, 91, 48, 93, 32, 51, 48, 37, 44, 51, 48, 37, 44, 49, 44, 49,
  44, 50, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 64,
  123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 49,
  44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45, 114,
  101, 115, 105, 122, 101, 91, 48, 93, 32, 50, 53, 37, 44, 50, 53, 37,
  44, 49, 44, 49, 44, 50, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45,
  49, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125,
  44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53,
  10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 50, 48, 37,
  44, 50, 48, 37, 44, 49, 44, 49, 44, 50, 10, 45, 114, 101, 115, 105,
  122, 101, 91, 45, 49, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123,
  48, 44, 104, 125, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53,
  44, 48, 46, 53, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93,
  32, 49, 53, 37, 44, 49, 53, 37, 44, 49, 44, 49, 44, 50, 10, 45,
  114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 48, 44, 119,
  125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 49, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45, 114, 101, 115, 105, 122,
  101, 91, 48, 93, 32, 49, 48, 37, 44, 49, 48, 37, 44, 49, 44, 49,
  44, 50, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 64,
  123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 49,
  44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45, 114,
  101, 115, 105, 122, 101, 91, 48, 93, 32, 53, 37, 44, 53, 37, 44, 49,
  44, 49, 44, 50, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93,
  32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125, 44, 49,
  44, 49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45,
  97, 100, 100, 10, 45, 101, 110, 100, 108, 10, 91, 48, 93, 10, 45, 97,
  112, 112, 101, 110, 100, 32, 121, 10, 45, 114, 101, 115, 105, 122, 101, 32,
  50, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 48, 44,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45, 115, 104, 105, 102,
  116, 91, 48, 93, 32, 49, 54, 48, 44, 49, 48, 48, 44, 48, 44, 48,
  10, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93, 32, 45, 49, 54, 48,
  44, 49, 48, 48, 44, 48, 44, 48, 10, 45, 97, 100, 100, 10, 45, 99,
  114, 111, 112, 32, 51, 48, 44, 49, 57, 48, 44, 51, 53, 48, 44, 49,
  48, 48, 37, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110,
  100, 108, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 36,
  115, 99, 97, 108, 101, 44, 36, 115, 99, 97, 108, 101, 44, 49, 44, 49,
  44, 50, 10, 45, 105, 102, 32, 123, 36, 50, 61, 61, 49, 125, 10, 45,
  110, 101, 103, 97, 116, 105, 118, 101, 91, 49, 93, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 119, 105, 100, 116, 104, 61,
  64, 123, 45, 49, 44, 119, 125, 10, 104, 101, 105, 103, 104, 116, 61, 64,
  123, 45, 49, 44, 104, 125, 10, 119, 95, 116, 105, 108, 101, 115, 61, 123,
  114, 111, 117, 110, 100, 40, 64, 123, 48, 44, 119, 125, 47, 36, 119, 105,
  100, 116, 104, 41, 125, 10, 104, 95, 116, 105, 108, 101, 115, 61, 123, 114,
  111, 117, 110, 100, 40, 64, 123, 48, 44, 104, 125, 47, 36, 104, 101, 105,
  103, 104, 116, 41, 125, 10, 116, 111, 116, 97, 108, 95, 116, 105, 108, 101,
  115, 61, 36, 104, 95, 116, 105, 108, 101, 115, 42, 36, 119, 95, 116, 105,
  108, 101, 115, 10, 91, 45, 49, 93, 120, 123, 36, 116, 111, 116, 97, 108,
  95, 116, 105, 108, 101, 115, 45, 49, 125, 10, 45, 97, 112, 112, 101, 110,
  100, 95, 116, 105, 108, 101, 115, 91, 49, 45, 45, 49, 93, 32, 36, 119,
  95, 116, 105, 108, 101, 115, 44, 36, 104, 95, 116, 105, 108, 101, 115, 10,
  45, 101, 113, 117, 97, 108, 105, 122, 101, 91, 45, 49, 93, 32, 50, 53,
  54, 10, 45, 114, 111, 116, 97, 116, 101, 91, 45, 49, 93, 32, 36, 53,
  44, 49, 44, 50, 44, 53, 48, 37, 44, 53, 48, 37, 44, 49, 10, 45,
  116, 119, 105, 114, 108, 91, 45, 49, 93, 32, 36, 54, 44, 46, 53, 44,
  46, 53, 44, 50, 10, 45, 98, 108, 101, 110, 100, 32, 97, 108, 112, 104,
  97, 44, 48, 46, 53, 44, 49, 10, 45, 103, 116, 32, 49, 50, 56, 10,
  45, 109, 117, 108, 32, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36, 52,
  61, 61, 49, 125, 10, 45, 114, 101, 115, 105, 122, 101, 32, 50, 53, 37,
  44, 50, 53, 37, 44, 49, 44, 49, 44, 51, 10, 45, 101, 110, 100, 105,
  102, 10, 35, 64, 103, 105, 109, 112, 32, 72, 101, 97, 114, 116, 115, 32,
  58, 32, 103, 105, 109, 112, 95, 104, 101, 97, 114, 116, 115, 44, 32, 103,
  105, 109, 112, 95, 104, 101, 97, 114, 116, 115, 95, 112, 114, 101, 118, 105,
  101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68,
  101, 110, 115, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66,
  65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108,
  117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97,
  98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44,
  34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97,
  108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101,
  110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34,
  99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34,
  44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44,
  34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108,
  105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 104, 101,
  97, 114, 116, 115, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104,
  97, 110, 110, 101, 108, 115, 32, 34, 45, 104, 101, 97, 114, 116, 115, 32,
  36, 49, 34, 44, 36, 50, 44, 48, 10, 103, 105, 109, 112, 95, 104, 101,
  97, 114, 116, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 104, 101, 97, 114, 116, 115,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32,
  76, 97, 118, 97, 32, 58, 32, 103, 105, 109, 112, 95, 108, 97, 118, 97,
  44, 32, 103, 105, 109, 112, 95, 108, 97, 118, 97, 95, 112, 114, 101, 118,
  105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  80, 101, 114, 116, 117, 114, 98, 97, 116, 105, 111, 110, 32, 61, 32, 105,
  110, 116, 40, 56, 44, 48, 44, 49, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 51, 44, 48, 44, 50, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 114, 112, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 50, 47, 49,
  49, 47, 50, 54, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 108, 97, 118, 97, 32, 58, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121,
  32, 45, 108, 91, 48, 93, 32, 45, 110, 111, 114, 109, 10, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 32, 45, 112, 108, 97, 115, 109, 97, 91, 45,
  49, 93, 32, 49, 44, 49, 44, 123, 49, 54, 45, 36, 49, 125, 32, 45,
  115, 109, 111, 111, 116, 104, 91, 45, 49, 93, 32, 36, 50, 44, 48, 44,
  49, 44, 36, 51, 44, 36, 51, 44, 48, 46, 56, 44, 57, 48, 32, 45,
  42, 10, 45, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109,
  32, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 101, 113, 117, 97, 108,
  105, 122, 101, 32, 45, 109, 97, 112, 32, 51, 10, 45, 115, 104, 97, 114,
  112, 101, 110, 32, 36, 52, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32,
  99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105,
  109, 112, 95, 108, 97, 118, 97, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 108, 97, 118,
  97, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112,
  32, 77, 97, 114, 98, 108, 101, 32, 58, 32, 103, 105, 109, 112, 95, 109,
  97, 114, 98, 108, 101, 44, 32, 103, 105, 109, 112, 95, 109, 97, 114, 98,
  108, 101, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 109, 97, 103,
  101, 32, 119, 101, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 46, 53, 44, 48, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 80, 97, 116, 116, 101, 114, 110, 32, 119, 101, 105, 103, 104,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 51, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 116, 116, 101,
  114, 110, 32, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 114, 112, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 46, 52, 44, 48, 44, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 105, 115, 111,
  116, 114, 111, 112, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 46, 54,
  44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  108, 112, 104, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 46, 54, 44,
  48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  105, 103, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 49,
  44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 117, 116, 32, 108, 111, 119, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 117, 116, 32, 104, 105, 103, 104, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 48, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 58, 32, 60, 105, 62, 80, 114, 101, 98, 101, 110, 32,
  83, 111, 101, 98, 101, 114, 103, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 109, 97, 114, 98, 108, 101, 32, 58, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115,
  112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91,
  48, 93, 10, 45, 109, 97, 114, 98, 108, 101, 32, 36, 49, 47, 49, 48,
  44, 36, 50, 47, 49, 48, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44,
  36, 54, 44, 36, 55, 44, 36, 56, 44, 36, 57, 37, 44, 36, 49, 48,
  37, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32,
  77, 97, 122, 101, 32, 58, 32, 103, 105, 109, 112, 95, 109, 97, 122, 101,
  44, 32, 103, 105, 109, 112, 95, 109, 97, 122, 101, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 101, 108, 108, 32, 115, 105, 122, 101, 32, 61,
  32, 105, 110, 116, 40, 50, 52, 44, 49, 44, 50, 53, 54, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 105, 99, 107, 110, 101, 115,
  115, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 97, 115, 107, 105, 110, 103,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 78, 111, 110, 101, 34,
  44, 34, 82, 101, 110, 100, 101, 114, 32, 111, 110, 32, 100, 97, 114, 107,
  32, 97, 114, 101, 97, 115, 34, 44, 34, 82, 101, 110, 100, 101, 114, 32,
  111, 110, 32, 119, 104, 105, 116, 101, 32, 97, 114, 101, 97, 115, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 115, 101, 114,
  118, 101, 32, 105, 109, 97, 103, 101, 32, 100, 105, 109, 101, 110, 115, 105,
  111, 110, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 77, 97, 122, 101, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 68, 97, 114, 107, 32, 119,
  97, 108, 108, 115, 34, 44, 34, 87, 104, 105, 116, 101, 32, 119, 97, 108,
  108, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 49, 47, 48, 57, 47, 48, 50, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 109, 97, 122, 101, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 10,
  45, 114, 91, 45, 49, 93, 32, 123, 49, 48, 48, 47, 36, 49, 125, 37,
  44, 123, 49, 48, 48, 47, 36, 49, 125, 37, 44, 49, 44, 49, 48, 48,
  37, 44, 50, 10, 45, 105, 102, 32, 123, 36, 51, 61, 61, 48, 125, 32,
  45, 102, 91, 45, 49, 93, 32, 49, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 51, 61, 61, 49, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101,
  91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 109, 97, 122,
  101, 95, 109, 97, 115, 107, 91, 45, 49, 93, 32, 36, 49, 32, 45, 100,
  105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 36, 50, 32, 45, 42, 91,
  45, 49, 93, 32, 50, 53, 53, 10, 45, 105, 102, 32, 123, 33, 36, 53,
  125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 52, 32, 45, 114,
  91, 45, 49, 93, 32, 36, 119, 44, 36, 104, 44, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 32, 45, 101, 110, 100, 105, 102, 10, 45, 109, 118, 91,
  45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105,
  109, 112, 32, 77, 105, 110, 101, 114, 97, 108, 32, 109, 111, 115, 97, 105,
  99, 32, 58, 32, 100, 116, 95, 109, 105, 110, 101, 114, 97, 108, 95, 109,
  111, 115, 97, 105, 99, 44, 100, 116, 95, 109, 105, 110, 101, 114, 97, 108,
  95, 109, 111, 115, 97, 105, 99, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 68, 101, 110, 115, 105, 116, 121, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 114, 101, 97, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 44, 48, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 104, 97, 100, 101, 32, 115, 116, 114, 101,
  110, 103, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 48,
  44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 104, 97, 100, 101, 32, 97, 110, 103, 108, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84,
  115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51,
  47, 48, 50, 47, 48, 49, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 100, 116, 95, 109, 105, 110, 101, 114, 97, 108,
  95, 109, 111, 115, 97, 105, 99, 32, 58, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 116, 111, 95,
  114, 103, 98, 10, 45, 45, 98, 32, 36, 51, 32, 45, 115, 101, 103, 109,
  101, 110, 116, 95, 119, 97, 116, 101, 114, 115, 104, 101, 100, 91, 45, 49,
  93, 32, 36, 49, 32, 45, 45, 110, 111, 114, 109, 91, 45, 49, 93, 10,
  45, 97, 114, 101, 97, 91, 45, 49, 93, 32, 48, 32, 45, 45, 108, 101,
  91, 45, 49, 93, 32, 123, 36, 50, 94, 50, 125, 32, 45, 105, 110, 112,
  97, 105, 110, 116, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 108, 97, 98, 101, 108, 91, 45, 49, 93,
  10, 45, 45, 102, 91, 48, 93, 32, 39, 105, 102, 40, 99, 61, 61, 48,
  44, 120, 44, 121, 41, 39, 32, 45, 45, 98, 108, 101, 110, 100, 91, 45,
  50, 44, 45, 49, 93, 32, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97,
  103, 101, 44, 49, 44, 49, 10, 45, 45, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 114, 109, 91, 48, 44, 50, 93, 32, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 91, 45, 49, 93, 32, 48, 44, 49, 10, 97, 108, 112, 104,
  97, 61, 123, 36, 53, 42, 112, 105, 47, 49, 56, 48, 125, 32, 45, 115,
  104, 91, 45, 49, 93, 32, 48, 44, 48, 32, 45, 42, 91, 45, 49, 93,
  32, 123, 99, 111, 115, 40, 36, 97, 108, 112, 104, 97, 41, 125, 32, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 115, 104, 91, 45, 49, 93, 32, 49,
  44, 49, 32, 45, 42, 91, 45, 49, 93, 32, 123, 115, 105, 110, 40, 36,
  97, 108, 112, 104, 97, 41, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 91, 45, 49, 93, 32, 43, 10, 45, 110, 111, 114, 109, 97, 108, 105,
  122, 101, 95, 108, 111, 99, 97, 108, 91, 45, 49, 93, 32, 49, 48, 48,
  48, 32, 45, 110, 91, 45, 49, 93, 32, 45, 36, 52, 44, 36, 52, 10,
  45, 43, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 77,
  111, 115, 97, 105, 99, 32, 58, 32, 103, 105, 109, 112, 95, 109, 111, 115,
  97, 105, 99, 44, 32, 103, 105, 109, 112, 95, 109, 111, 115, 97, 105, 99,
  95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 68, 101, 110, 115, 105, 116, 121, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 44, 48, 46, 49, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 75, 101, 101, 112, 32, 101, 100, 103,
  101, 115, 32, 61, 32, 98, 111, 111, 108, 40, 116, 114, 117, 101, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108,
  40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108,
  108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44,
  34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117,
  101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105,
  110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110,
  101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105,
  111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121,
  34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44,
  34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108,
  105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32,
  60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112,
  101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  103, 105, 109, 112, 95, 109, 111, 115, 97, 105, 99, 32, 58, 10, 45, 97,
  112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45,
  109, 111, 115, 97, 105, 99, 32, 36, 49, 44, 36, 50, 34, 44, 36, 51,
  44, 48, 10, 103, 105, 109, 112, 95, 109, 111, 115, 97, 105, 99, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115,
  112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103,
  105, 109, 112, 95, 109, 111, 115, 97, 105, 99, 32, 36, 42, 34, 44, 36,
  45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 79, 112, 32, 97, 114, 116,
  32, 58, 32, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 44, 103,
  105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 95, 112, 114, 101, 118, 105,
  101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  104, 97, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 123, 49, 44,
  34, 67, 117, 115, 116, 111, 109, 32, 108, 97, 121, 101, 114, 115, 34, 44,
  34, 67, 105, 114, 99, 108, 101, 115, 34, 44, 34, 83, 113, 117, 97, 114,
  101, 115, 34, 44, 34, 68, 105, 97, 109, 111, 110, 100, 115, 34, 44, 34,
  84, 114, 105, 97, 110, 103, 108, 101, 115, 34, 44, 34, 72, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 32, 115, 116, 114, 105, 112, 101, 115, 34, 44,
  34, 86, 101, 114, 116, 105, 99, 97, 108, 32, 115, 116, 114, 105, 112, 101,
  115, 34, 44, 34, 66, 97, 108, 108, 115, 34, 44, 34, 72, 101, 97, 114,
  116, 115, 34, 44, 34, 83, 116, 97, 114, 115, 34, 44, 34, 65, 114, 114,
  111, 119, 115, 34, 44, 34, 84, 114, 117, 99, 104, 101, 116, 34, 44, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 67, 105, 114, 99, 108, 101,
  115, 32, 40, 111, 117, 116, 108, 105, 110, 101, 41, 34, 44, 34, 83, 113,
  117, 97, 114, 101, 115, 32, 40, 111, 117, 116, 108, 105, 110, 101, 41, 34,
  44, 34, 68, 105, 97, 109, 111, 110, 100, 115, 32, 40, 111, 117, 116, 108,
  105, 110, 101, 41, 34, 44, 34, 84, 114, 105, 97, 110, 103, 108, 101, 115,
  32, 40, 111, 117, 116, 108, 105, 110, 101, 41, 34, 44, 34, 72, 101, 97,
  114, 116, 115, 32, 40, 111, 117, 116, 108, 105, 110, 101, 41, 34, 44, 34,
  83, 116, 97, 114, 115, 32, 40, 111, 117, 116, 108, 105, 110, 101, 41, 34,
  44, 34, 65, 114, 114, 111, 119, 115, 32, 40, 111, 117, 116, 108, 105, 110,
  101, 41, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 117,
  109, 98, 101, 114, 32, 111, 102, 32, 115, 99, 97, 108, 101, 115, 32, 61,
  32, 105, 110, 116, 40, 49, 54, 44, 50, 44, 50, 52, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 101, 115, 111, 108, 117, 116, 105, 111,
  110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 49, 44, 53,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 111, 111, 109,
  32, 102, 97, 99, 116, 111, 114, 32, 61, 32, 95, 105, 110, 116, 40, 50,
  44, 49, 44, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77,
  105, 110, 105, 109, 97, 108, 32, 115, 105, 122, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 53, 44, 48, 44, 49, 53, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 77, 97, 120, 105, 109, 97, 108, 32, 115, 105,
  122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 57, 48, 44, 48, 44,
  49, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 116,
  101, 110, 99, 105, 108, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 48, 44, 34, 66, 108, 97, 99, 107, 32, 38, 32, 119,
  104, 105, 116, 101, 34, 44, 34, 82, 71, 66, 34, 44, 34, 67, 111, 108,
  111, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 108,
  108, 111, 119, 32, 97, 110, 103, 108, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 48, 32, 100, 101, 103, 46, 34, 44, 34, 57, 48, 32,
  100, 101, 103, 46, 34, 44, 34, 49, 56, 48, 32, 100, 101, 103, 46, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 101, 103, 97, 116,
  105, 118, 101, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 65, 110, 116, 105, 97, 108, 105, 97, 115,
  105, 110, 103, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60,
  115, 109, 97, 108, 108, 62, 60, 98, 62, 78, 111, 116, 101, 58, 60, 47,
  98, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 102, 32, 121,
  111, 117, 32, 115, 101, 116, 32, 116, 104, 101, 32, 112, 97, 114, 97, 109,
  101, 116, 101, 114, 32, 60, 105, 62, 83, 104, 97, 112, 101, 60, 47, 105,
  62, 32, 116, 111, 32, 60, 105, 62, 67, 117, 115, 116, 111, 109, 32, 108,
  97, 121, 101, 114, 115, 60, 47, 105, 62, 44, 32, 116, 104, 101, 32, 100,
  105, 102, 102, 101, 114, 101, 110, 116, 32, 115, 104, 97, 112, 101, 115, 32,
  117, 115, 101, 100, 32, 116, 111, 32, 109, 97, 112, 32, 116, 104, 101, 32,
  112, 105, 120, 101, 108, 32, 105, 110, 116, 101, 110, 115, 105, 116, 105, 101,
  115, 32, 119, 105, 108, 108, 32, 98, 101, 32, 100, 101, 102, 105, 110, 101,
  100, 32, 97, 115, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 116, 104,
  101, 32, 60, 105, 62, 78, 117, 109, 98, 101, 114, 32, 111, 102, 32, 115,
  99, 97, 108, 101, 115, 60, 47, 105, 62, 32, 116, 111, 112, 32, 108, 97,
  121, 101, 114, 115, 32, 111, 102, 32, 121, 111, 117, 114, 32, 105, 109, 97,
  103, 101, 46, 32, 68, 111, 110, 39, 116, 32, 102, 111, 114, 103, 101, 116,
  32, 116, 111, 32, 115, 101, 116, 32, 97, 108, 115, 111, 32, 60, 105, 62,
  73, 110, 112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 60, 47, 105, 62,
  32, 116, 111, 32, 60, 105, 62, 65, 108, 108, 60, 47, 105, 62, 32, 116,
  111, 32, 98, 101, 32, 115, 117, 114, 101, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 116, 104, 101, 115, 101, 32, 108, 97, 121, 101, 114, 115, 32,
  97, 114, 101, 32, 112, 97, 115, 115, 101, 100, 32, 116, 111, 32, 116, 104,
  101, 32, 102, 105, 108, 116, 101, 114, 46, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 60, 47, 115, 109, 97, 108, 108, 62, 34, 125, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101,
  119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99,
  97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105,
  62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114,
  108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 51, 47, 49, 50, 47, 49, 54, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 115, 104, 97, 112, 101, 115, 32, 58, 10, 45, 105, 102, 32,
  36, 49, 10, 45, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105,
  116, 121, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 33, 36, 55, 125, 32, 45,
  95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 32, 36, 42, 32,
  45, 42, 32, 50, 53, 53, 10, 45, 101, 108, 105, 102, 32, 123, 36, 55,
  61, 61, 49, 125, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99,
  105, 116, 121, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 32, 45,
  115, 91, 48, 93, 32, 99, 32, 45, 114, 101, 112, 101, 97, 116, 32, 51,
  32, 45, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 91, 36,
  62, 93, 32, 36, 42, 32, 45, 100, 111, 110, 101, 32, 45, 42, 91, 48,
  45, 50, 93, 32, 50, 53, 53, 32, 45, 97, 91, 48, 45, 50, 93, 32,
  99, 32, 45, 97, 32, 99, 10, 45, 101, 108, 115, 101, 32, 45, 45, 95,
  103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 32, 36, 42, 32, 45,
  114, 91, 48, 93, 32, 36, 51, 37, 44, 36, 51, 37, 32, 45, 114, 91,
  48, 93, 32, 91, 49, 93, 44, 91, 49, 93, 32, 45, 42, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 45, 101, 108, 115, 101, 10, 45, 105, 102, 32, 123, 64, 35, 60, 61,
  36, 50, 125, 32, 45, 101, 114, 114, 111, 114, 91, 93, 32, 34, 83, 111,
  109, 101, 32, 108, 97, 121, 101, 114, 115, 32, 97, 114, 101, 32, 109, 105,
  115, 115, 105, 110, 103, 32, 105, 110, 32, 39, 67, 117, 115, 116, 111, 109,
  32, 108, 97, 121, 101, 114, 115, 39, 32, 109, 111, 100, 101, 32, 40, 34,
  123, 36, 50, 43, 49, 125, 34, 32, 101, 120, 112, 101, 99, 116, 101, 100,
  32, 97, 116, 32, 108, 101, 97, 115, 116, 44, 32, 34, 64, 35, 34, 32,
  112, 114, 111, 118, 105, 100, 101, 100, 41, 46, 34, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101,
  91, 48, 45, 123, 36, 50, 45, 49, 125, 93, 32, 64, 123, 45, 109, 97,
  120, 95, 115, 91, 48, 45, 123, 36, 50, 45, 49, 125, 93, 125, 32, 45,
  114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 91, 36,
  50, 45, 45, 49, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64,
  35, 45, 36, 50, 125, 32, 45, 108, 91, 48, 45, 123, 36, 50, 45, 49,
  125, 44, 123, 36, 50, 43, 36, 62, 125, 93, 10, 45, 110, 111, 114, 109,
  91, 45, 49, 93, 32, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125,
  32, 45, 114, 91, 45, 49, 93, 32, 36, 51, 37, 44, 36, 51, 37, 44,
  49, 44, 49, 44, 50, 10, 115, 61, 123, 36, 52, 42, 109, 97, 120, 40,
  114, 111, 117, 110, 100, 40, 36, 119, 47, 119, 41, 44, 114, 111, 117, 110,
  100, 40, 36, 104, 47, 104, 41, 41, 125, 10, 114, 48, 61, 123, 36, 115,
  42, 36, 53, 37, 125, 32, 114, 49, 61, 123, 36, 115, 42, 36, 54, 37,
  125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 50, 32, 114, 61, 123,
  114, 111, 117, 110, 100, 40, 36, 114, 48, 43, 36, 62, 42, 40, 36, 114,
  49, 45, 36, 114, 48, 41, 47, 40, 36, 50, 45, 49, 41, 41, 125, 32,
  45, 105, 102, 32, 36, 114, 32, 45, 45, 114, 91, 36, 62, 93, 32, 36,
  114, 44, 36, 114, 44, 49, 44, 49, 48, 48, 37, 44, 51, 32, 45, 101,
  108, 115, 101, 32, 49, 44, 49, 32, 45, 101, 110, 100, 105, 102, 32, 45,
  100, 111, 110, 101, 10, 45, 114, 91, 45, 36, 50, 45, 45, 49, 93, 32,
  36, 115, 44, 36, 115, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 109, 97, 112, 95, 115, 112,
  114, 105, 116, 101, 115, 91, 36, 50, 45, 45, 49, 93, 32, 36, 50, 44,
  36, 56, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  114, 109, 91, 48, 45, 123, 36, 50, 45, 49, 125, 93, 10, 45, 101, 110,
  100, 105, 102, 10, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 105, 102, 32, 36, 49,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 10, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115,
  32, 36, 123, 49, 45, 51, 125, 44, 49, 44, 36, 123, 53, 45, 45, 50,
  125, 34, 44, 36, 45, 49, 10, 45, 114, 32, 36, 119, 44, 36, 104, 44,
  49, 44, 49, 48, 48, 37, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48,
  46, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45,
  101, 108, 115, 101, 10, 45, 105, 102, 32, 123, 64, 35, 62, 36, 50, 125,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 36, 50, 125,
  32, 45, 108, 91, 48, 45, 123, 36, 50, 45, 49, 125, 44, 123, 36, 50,
  43, 36, 62, 125, 93, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104,
  125, 10, 45, 45, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 32,
  36, 123, 49, 45, 51, 125, 44, 49, 44, 36, 123, 53, 45, 45, 50, 125,
  32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 114, 91, 45, 49, 93, 32,
  36, 119, 44, 36, 104, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 45, 123, 36, 50, 45, 49,
  125, 93, 10, 45, 101, 108, 115, 101, 32, 45, 95, 103, 105, 109, 112, 95,
  110, 111, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 77, 105, 115, 115,
  105, 110, 103, 92, 110, 108, 97, 121, 101, 114, 115, 32, 33, 34, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 95, 103, 105,
  109, 112, 95, 115, 104, 97, 112, 101, 115, 32, 58, 10, 45, 110, 111, 114,
  109, 32, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 32, 45, 114,
  32, 36, 51, 37, 44, 36, 51, 37, 44, 49, 44, 49, 44, 50, 10, 115,
  61, 123, 40, 49, 43, 36, 49, 48, 41, 42, 36, 52, 42, 109, 97, 120,
  40, 114, 111, 117, 110, 100, 40, 36, 119, 47, 119, 41, 44, 114, 111, 117,
  110, 100, 40, 36, 104, 47, 104, 41, 41, 125, 10, 114, 48, 61, 123, 36,
  115, 42, 36, 53, 37, 125, 32, 114, 49, 61, 123, 36, 115, 42, 36, 54,
  37, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 50, 32, 114, 61,
  123, 114, 111, 117, 110, 100, 40, 36, 114, 48, 43, 36, 62, 42, 40, 36,
  114, 49, 45, 36, 114, 48, 41, 47, 40, 36, 50, 45, 49, 41, 41, 125,
  32, 45, 105, 102, 32, 36, 114, 32, 45, 95, 103, 105, 109, 112, 95, 115,
  104, 97, 112, 101, 115, 123, 36, 49, 45, 49, 125, 91, 93, 32, 36, 114,
  44, 36, 115, 32, 45, 101, 108, 115, 101, 32, 49, 44, 49, 32, 45, 101,
  110, 100, 105, 102, 32, 45, 100, 111, 110, 101, 10, 45, 114, 91, 45, 36,
  50, 45, 45, 49, 93, 32, 36, 115, 44, 36, 115, 44, 49, 44, 49, 44,
  48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 105, 102, 32,
  36, 57, 32, 45, 114, 118, 91, 45, 36, 50, 45, 45, 49, 93, 32, 45,
  42, 91, 45, 36, 50, 45, 45, 49, 93, 32, 45, 49, 32, 45, 43, 91,
  45, 36, 50, 45, 45, 49, 93, 32, 49, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 109, 97, 112, 95, 115, 112, 114, 105, 116, 101, 115, 32, 36, 50,
  44, 36, 56, 10, 45, 105, 102, 32, 36, 49, 48, 32, 45, 114, 32, 53,
  48, 37, 44, 53, 48, 37, 44, 49, 44, 49, 44, 50, 32, 45, 101, 110,
  100, 105, 102, 10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115,
  48, 32, 58, 10, 45, 95, 100, 116, 95, 99, 105, 114, 99, 108, 101, 91,
  93, 32, 36, 49, 10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101,
  115, 49, 32, 58, 10, 36, 49, 44, 36, 49, 44, 49, 44, 49, 44, 49,
  10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 50, 32, 58,
  10, 36, 49, 44, 36, 49, 44, 49, 44, 49, 32, 45, 61, 32, 49, 44,
  53, 48, 37, 44, 53, 48, 37, 32, 45, 100, 105, 115, 116, 97, 110, 99,
  101, 32, 49, 44, 49, 32, 45, 108, 116, 32, 123, 36, 49, 47, 50, 125,
  10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 51, 32, 58,
  10, 36, 50, 44, 36, 50, 44, 49, 44, 49, 44, 39, 120, 43, 121, 60,
  61, 50, 42, 36, 49, 45, 49, 39, 10, 95, 103, 105, 109, 112, 95, 115,
  104, 97, 112, 101, 115, 52, 32, 58, 10, 36, 50, 44, 36, 49, 44, 49,
  44, 49, 44, 49, 10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101,
  115, 53, 32, 58, 10, 36, 49, 44, 36, 50, 44, 49, 44, 49, 44, 49,
  10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 54, 32, 58,
  10, 45, 98, 97, 108, 108, 32, 36, 49, 44, 50, 48, 48, 32, 45, 110,
  32, 48, 44, 49, 10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101,
  115, 55, 32, 58, 10, 45, 104, 101, 97, 114, 116, 32, 54, 53, 32, 45,
  114, 32, 36, 49, 44, 36, 49, 44, 49, 44, 49, 44, 50, 32, 45, 103,
  101, 32, 53, 48, 37, 10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112,
  101, 115, 56, 32, 58, 10, 45, 115, 116, 97, 114, 32, 36, 49, 44, 36,
  49, 10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 57, 32,
  58, 10, 45, 97, 114, 114, 111, 119, 51, 100, 32, 48, 44, 48, 44, 48,
  44, 49, 44, 48, 44, 48, 44, 49, 53, 37, 44, 52, 48, 37, 44, 51,
  48, 37, 32, 45, 99, 111, 108, 51, 100, 32, 49, 32, 45, 42, 51, 100,
  32, 36, 49, 32, 45, 99, 51, 100, 10, 36, 50, 44, 36, 50, 32, 45,
  111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50,
  93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 49, 44, 50, 44,
  48, 44, 48, 10, 45, 114, 109, 91, 45, 50, 93, 32, 45, 45, 109, 105,
  114, 114, 111, 114, 32, 121, 32, 45, 109, 97, 120, 10, 95, 103, 105, 109,
  112, 95, 115, 104, 97, 112, 101, 115, 49, 48, 32, 58, 10, 83, 61, 123,
  36, 50, 43, 49, 45, 40, 36, 50, 37, 50, 41, 125, 10, 36, 83, 44,
  36, 83, 44, 49, 44, 49, 44, 34, 88, 61, 120, 47, 40, 119, 45, 49,
  41, 59, 89, 61, 121, 47, 40, 104, 45, 49, 41, 59, 114, 61, 97, 98,
  115, 40, 48, 46, 53, 45, 115, 113, 114, 116, 40, 88, 94, 50, 43, 89,
  94, 50, 41, 41, 59, 97, 61, 97, 116, 97, 110, 50, 40, 121, 44, 120,
  41, 59, 114, 60, 48, 46, 49, 45, 48, 46, 49, 55, 42, 40, 48, 46,
  53, 45, 36, 49, 47, 36, 50, 41, 42, 115, 105, 110, 40, 50, 42, 97,
  41, 34, 10, 45, 45, 109, 105, 114, 114, 111, 114, 32, 120, 121, 32, 45,
  109, 97, 120, 10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115,
  49, 49, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112,
  101, 115, 48, 32, 36, 42, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120,
  121, 32, 49, 44, 48, 32, 45, 45, 101, 114, 111, 100, 101, 32, 51, 32,
  45, 45, 10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 49,
  50, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101,
  115, 49, 32, 36, 42, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121,
  32, 49, 44, 48, 32, 45, 45, 101, 114, 111, 100, 101, 32, 51, 32, 45,
  45, 10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 49, 51,
  32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115,
  50, 32, 36, 42, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 32,
  49, 44, 48, 32, 45, 45, 101, 114, 111, 100, 101, 32, 51, 32, 45, 45,
  10, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 49, 52, 32,
  58, 10, 45, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 51,
  32, 36, 42, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 32, 49,
  44, 48, 32, 45, 45, 101, 114, 111, 100, 101, 32, 51, 32, 45, 45, 10,
  95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 49, 53, 32, 58,
  10, 45, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 55, 32,
  36, 42, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 32, 49, 44,
  48, 32, 45, 45, 101, 114, 111, 100, 101, 32, 51, 32, 45, 45, 10, 95,
  103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 49, 54, 32, 58, 10,
  45, 95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 56, 32, 36,
  42, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 32, 49, 44, 48,
  32, 45, 45, 101, 114, 111, 100, 101, 32, 51, 32, 45, 45, 10, 95, 103,
  105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 49, 55, 32, 58, 10, 45,
  95, 103, 105, 109, 112, 95, 115, 104, 97, 112, 101, 115, 57, 32, 36, 42,
  32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 32, 49, 44, 48, 32,
  45, 45, 101, 114, 111, 100, 101, 32, 51, 32, 45, 45, 10, 35, 64, 103,
  105, 109, 112, 32, 80, 97, 99, 107, 32, 115, 112, 114, 105, 116, 101, 115,
  32, 58, 32, 103, 105, 109, 112, 95, 112, 97, 99, 107, 95, 115, 112, 114,
  105, 116, 101, 115, 44, 32, 103, 105, 109, 112, 95, 110, 111, 95, 112, 114,
  101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  117, 109, 98, 101, 114, 32, 111, 102, 32, 115, 99, 97, 108, 101, 115, 32,
  61, 32, 105, 110, 116, 40, 53, 44, 49, 44, 49, 54, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 77, 105, 110, 105, 109, 97, 108, 32, 115,
  99, 97, 108, 101, 32, 91, 37, 93, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 53, 44, 49, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 108, 108, 111, 119, 32, 97, 110, 103, 108, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 51, 44, 34, 48, 32, 100, 101,
  103, 46, 34, 44, 34, 49, 56, 48, 32, 100, 101, 103, 46, 34, 44, 34,
  57, 48, 32, 100, 101, 103, 46, 34, 44, 34, 65, 110, 121, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 97, 99, 105, 110, 103,
  32, 61, 32, 105, 110, 116, 40, 49, 44, 45, 49, 54, 44, 49, 54, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 99, 105, 115,
  105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 55, 44, 49, 44, 51, 50,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 77, 97, 115, 107, 105, 110, 103, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 78, 111, 32, 109, 97, 115, 107, 105,
  110, 103, 34, 44, 34, 77, 97, 115, 107, 32, 97, 115, 32, 98, 111, 116,
  116, 111, 109, 32, 108, 97, 121, 101, 114, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 87, 105, 100, 116, 104, 32, 61, 32, 105, 110, 116,
  40, 53, 49, 50, 44, 51, 50, 44, 50, 48, 52, 56, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 72, 101, 105, 103, 104, 116, 32, 61, 32,
  105, 110, 116, 40, 53, 49, 50, 44, 51, 50, 44, 50, 48, 52, 56, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98,
  62, 78, 111, 116, 101, 115, 58, 60, 47, 98, 62, 92, 110, 32, 45, 32,
  80, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 60, 105, 62, 87, 105,
  100, 116, 104, 60, 47, 105, 62, 32, 97, 110, 100, 32, 60, 105, 62, 72,
  101, 105, 103, 104, 116, 60, 47, 105, 62, 32, 97, 114, 101, 32, 99, 111,
  110, 115, 105, 100, 101, 114, 101, 100, 32, 111, 110, 108, 121, 32, 119, 104,
  101, 110, 32, 60, 105, 62, 78, 111, 32, 109, 97, 115, 107, 105, 110, 103,
  60, 47, 105, 62, 32, 109, 111, 100, 101, 32, 105, 115, 32, 115, 101, 108,
  101, 99, 116, 101, 100, 46, 92, 110, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 45, 32, 83, 101, 116, 32, 100, 105, 102, 102, 101, 114, 101, 110,
  116, 32, 115, 112, 114, 105, 116, 101, 115, 32, 111, 110, 32, 100, 105, 102,
  102, 101, 114, 101, 110, 116, 32, 108, 97, 121, 101, 114, 115, 32, 116, 111,
  32, 112, 97, 99, 107, 32, 109, 117, 108, 116, 105, 112, 108, 101, 32, 115,
  112, 114, 105, 116, 101, 115, 32, 97, 116, 32, 116, 104, 101, 32, 115, 97,
  109, 101, 32, 116, 105, 109, 101, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 51, 47, 48, 54, 47, 50, 52, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  112, 97, 99, 107, 95, 115, 112, 114, 105, 116, 101, 115, 32, 58, 10, 45,
  105, 102, 32, 36, 54, 10, 45, 105, 102, 32, 123, 64, 35, 60, 50, 125,
  32, 45, 101, 114, 114, 111, 114, 91, 93, 32, 34, 77, 97, 115, 107, 105,
  110, 103, 32, 114, 101, 113, 117, 105, 114, 101, 115, 32, 97, 116, 32, 108,
  101, 97, 115, 116, 32, 116, 119, 111, 32, 105, 110, 112, 117, 116, 32, 108,
  97, 121, 101, 114, 115, 32, 33, 32, 40, 112, 108, 101, 97, 115, 101, 32,
  99, 104, 101, 99, 107, 32, 116, 104, 97, 116, 32, 39, 73, 110, 112, 117,
  116, 32, 76, 97, 121, 101, 114, 115, 39, 32, 105, 115, 32, 99, 111, 114,
  114, 101, 99, 116, 108, 121, 32, 115, 101, 116, 41, 46, 34, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35,
  45, 49, 125, 32, 45, 108, 91, 36, 62, 93, 32, 45, 116, 111, 95, 114,
  103, 98, 97, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105,
  116, 121, 32, 45, 45, 110, 101, 113, 91, 49, 93, 32, 48, 32, 45, 42,
  91, 48, 93, 32, 91, 45, 49, 93, 32, 45, 97, 32, 99, 32, 45, 97,
  117, 116, 111, 99, 114, 111, 112, 32, 48, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 45, 114, 101, 109, 111, 118, 101, 95, 101, 109,
  112, 116, 121, 91, 48, 45, 45, 50, 93, 32, 45, 45, 99, 104, 97, 110,
  110, 101, 108, 115, 91, 45, 49, 93, 32, 49, 48, 48, 37, 32, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 45, 52, 44, 48,
  32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 10, 45, 112, 97, 99, 107,
  95, 115, 112, 114, 105, 116, 101, 115, 91, 48, 45, 45, 50, 93, 32, 36,
  123, 49, 45, 53, 125, 10, 45, 101, 108, 115, 101, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 116,
  111, 95, 114, 103, 98, 97, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112,
  97, 99, 105, 116, 121, 32, 45, 45, 110, 101, 113, 91, 49, 93, 32, 48,
  32, 45, 42, 91, 48, 93, 32, 91, 45, 49, 93, 32, 45, 97, 32, 99,
  32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 48, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 114, 101, 109, 111, 118, 101,
  95, 101, 109, 112, 116, 121, 32, 45, 105, 91, 48, 93, 32, 36, 55, 44,
  36, 56, 44, 49, 44, 53, 32, 45, 112, 97, 99, 107, 95, 115, 112, 114,
  105, 116, 101, 115, 32, 36, 123, 49, 45, 53, 125, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48, 93, 32,
  48, 44, 64, 123, 48, 44, 115, 45, 50, 125, 10, 35, 64, 103, 105, 109,
  112, 32, 80, 97, 112, 101, 114, 32, 116, 101, 120, 116, 117, 114, 101, 32,
  58, 32, 103, 105, 109, 112, 95, 112, 97, 112, 101, 114, 44, 32, 103, 105,
  109, 112, 95, 112, 97, 112, 101, 114, 95, 112, 114, 101, 118, 105, 101, 119,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97,
  110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82,
  71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105,
  110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32,
  99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105,
  103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117,
  114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44,
  34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114,
  111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101,
  101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104,
  97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49,
  50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 112, 97, 112, 101, 114, 32, 58,
  10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 34, 45, 116, 101, 120, 116, 117, 114, 105, 122, 101, 95, 112, 97, 112,
  101, 114, 34, 44, 36, 49, 44, 48, 10, 103, 105, 109, 112, 95, 112, 97,
  112, 101, 114, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 103, 105, 109, 112, 95, 112, 97, 112, 101, 114, 32, 36,
  42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 80, 101,
  114, 105, 111, 100, 105, 99, 32, 100, 111, 116, 115, 32, 58, 32, 106, 101,
  106, 101, 95, 112, 101, 114, 105, 111, 100, 105, 99, 95, 100, 111, 116, 115,
  44, 32, 106, 101, 106, 101, 95, 112, 101, 114, 105, 111, 100, 105, 99, 95,
  100, 111, 116, 115, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 117, 109, 98, 101, 114, 32, 61, 32, 105,
  110, 116, 40, 54, 44, 50, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 52, 44, 49, 44, 49, 50, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 82, 101, 112, 101, 97, 116, 32, 61, 32, 105, 110, 116, 40,
  49, 44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 77, 97, 112, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 78, 111,
  110, 101, 44, 100, 101, 102, 97, 117, 108, 116, 44, 72, 83, 86, 44, 108,
  105, 110, 101, 115, 44, 104, 111, 116, 44, 99, 111, 111, 108, 44, 106, 101,
  116, 44, 102, 108, 97, 103, 44, 99, 117, 98, 101, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 32, 58, 32, 60, 105, 62, 74, 38, 35, 50, 51, 51, 59,
  114, 38, 35, 50, 52, 52, 59, 109, 101, 32, 66, 111, 117, 108, 97, 110,
  103, 101, 114, 60, 47, 105, 62, 46, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47,
  48, 53, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 106, 101, 106, 101, 95, 112, 101, 114, 105, 111, 100,
  105, 99, 95, 100, 111, 116, 115, 58, 10, 116, 87, 61, 123, 109, 97, 120,
  40, 119, 44, 104, 41, 47, 36, 52, 125, 10, 36, 116, 87, 44, 36, 116,
  87, 10, 45, 112, 101, 114, 105, 111, 100, 105, 99, 95, 100, 111, 116, 115,
  91, 45, 49, 93, 32, 36, 42, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 36, 52, 42, 36, 52, 45, 49, 125, 10, 45, 105, 32, 91, 45, 49,
  93, 10, 45, 100, 111, 110, 101, 10, 45, 97, 112, 112, 101, 110, 100, 95,
  116, 105, 108, 101, 115, 91, 49, 45, 45, 49, 93, 32, 36, 52, 44, 36,
  52, 32, 45, 107, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 53,
  62, 48, 125, 32, 45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 109, 97,
  112, 32, 123, 36, 53, 45, 49, 125, 32, 45, 101, 110, 100, 105, 102, 10,
  106, 101, 106, 101, 95, 112, 101, 114, 105, 111, 100, 105, 99, 95, 100, 111,
  116, 115, 95, 112, 114, 101, 118, 105, 101, 119, 58, 10, 45, 106, 101, 106,
  101, 95, 112, 101, 114, 105, 111, 100, 105, 99, 95, 100, 111, 116, 115, 32,
  36, 42, 10, 35, 64, 103, 105, 109, 112, 32, 80, 108, 97, 105, 100, 32,
  58, 32, 103, 105, 109, 112, 95, 112, 108, 97, 105, 100, 95, 116, 101, 120,
  116, 117, 114, 101, 44, 103, 105, 109, 112, 95, 112, 108, 97, 105, 100, 95,
  116, 101, 120, 116, 117, 114, 101, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 76, 105, 110, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 117, 109, 98, 101, 114, 32, 111, 102, 32, 97, 110,
  103, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 50, 44, 49, 44, 56,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 116, 97, 114, 116,
  105, 110, 103, 32, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 114, 97, 110, 103, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 57, 48, 44, 48, 44, 51, 54, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44,
  48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104,
  97, 114, 112, 101, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 48,
  48, 44, 48, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48, 53, 47,
  49, 54, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 112, 108, 97, 105, 100, 95, 116, 101, 120,
  116, 117, 114, 101, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 61, 123, 119, 125, 32, 104,
  61, 123, 104, 125, 32, 115, 61, 123, 115, 125, 10, 45, 114, 111, 119, 115,
  32, 36, 49, 37, 10, 45, 98, 32, 36, 53, 37, 32, 45, 115, 104, 97,
  114, 112, 101, 110, 32, 36, 54, 10, 45, 114, 101, 115, 105, 122, 101, 32,
  36, 119, 44, 36, 104, 44, 49, 44, 36, 115, 44, 50, 10, 45, 45, 114,
  111, 116, 97, 116, 101, 91, 48, 93, 32, 36, 51, 44, 49, 44, 50, 44,
  53, 48, 37, 44, 53, 48, 37, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 36, 50, 45, 49, 125, 32, 45, 45, 114, 111, 116, 97, 116, 101, 91,
  48, 93, 32, 123, 36, 51, 43, 36, 52, 42, 40, 36, 62, 43, 49, 41,
  47, 40, 36, 50, 45, 49, 41, 125, 44, 49, 44, 50, 44, 53, 48, 37,
  44, 53, 48, 37, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 93, 10, 45, 47, 32, 36,
  50, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64,
  103, 105, 109, 112, 32, 80, 108, 97, 115, 109, 97, 32, 58, 32, 103, 105,
  109, 112, 95, 112, 108, 97, 115, 109, 97, 44, 32, 103, 105, 109, 112, 95,
  112, 108, 97, 115, 109, 97, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 108, 112, 104, 97, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 53, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 66, 101, 116, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 99, 97, 108, 101, 32, 61, 32, 105, 110, 116, 40, 56, 44,
  50, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  97, 110, 100, 111, 109, 105, 122, 101, 32, 61, 32, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 114, 97, 110,
  115, 112, 97, 114, 101, 110, 99, 121, 32, 61, 32, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111,
  114, 32, 98, 97, 108, 97, 110, 99, 101, 32, 61, 32, 99, 111, 108, 111,
  114, 40, 49, 50, 56, 44, 49, 50, 56, 44, 49, 50, 56, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65,
  117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32,
  84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59,
  60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49,
  49, 47, 48, 51, 47, 50, 48, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 112, 108, 97, 115,
  109, 97, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 52, 61, 48,
  125, 44, 36, 123, 53, 61, 48, 125, 10, 45, 105, 102, 32, 36, 53, 32,
  45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 101, 108, 115, 101, 32, 45,
  116, 111, 95, 114, 103, 98, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 36, 52, 32, 45, 114, 97, 110, 100, 32, 48, 44, 50, 53, 53,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 112, 108, 97, 115, 109, 97, 32,
  36, 49, 44, 36, 50, 44, 36, 51, 32, 45, 110, 32, 48, 44, 50, 53,
  53, 10, 45, 98, 97, 108, 97, 110, 99, 101, 95, 103, 97, 109, 109, 97,
  32, 36, 123, 54, 45, 56, 125, 10, 35, 64, 103, 105, 109, 112, 32, 80,
  111, 108, 107, 97, 32, 100, 111, 116, 115, 32, 58, 32, 103, 105, 109, 112,
  95, 112, 111, 108, 107, 97, 95, 100, 111, 116, 115, 44, 32, 103, 105, 109,
  112, 95, 112, 111, 108, 107, 97, 95, 100, 111, 116, 115, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 105, 122, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 56, 48, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 110, 115, 105, 116, 121,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 48, 46, 49, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 105,
  114, 115, 116, 32, 111, 102, 102, 115, 101, 116, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 99, 111, 110, 100, 32, 111, 102, 102,
  115, 101, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  108, 105, 97, 115, 105, 110, 103, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 53, 44, 48, 46, 49, 44, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 104, 97, 100, 105, 110, 103, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 49, 44, 48, 46, 49, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 61, 32,
  99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 48, 44, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  112, 111, 108, 107, 97, 95, 100, 111, 116, 115, 32, 58, 10, 45, 116, 111,
  95, 114, 103, 98, 97, 32, 45, 112, 111, 108, 107, 97, 95, 100, 111, 116,
  115, 32, 123, 36, 49, 42, 36, 50, 47, 49, 48, 48, 125, 44, 36, 123,
  50, 45, 45, 49, 125, 10, 35, 64, 103, 105, 109, 112, 32, 82, 97, 110,
  100, 111, 109, 32, 99, 111, 108, 111, 114, 32, 101, 108, 108, 105, 112, 115,
  101, 115, 32, 58, 32, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 95,
  101, 108, 108, 105, 112, 115, 101, 115, 44, 32, 103, 105, 109, 112, 95, 99,
  111, 108, 111, 114, 95, 101, 108, 108, 105, 112, 115, 101, 115, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 110, 115, 105, 116,
  121, 32, 61, 32, 105, 110, 116, 40, 52, 48, 48, 44, 48, 44, 51, 48,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 100,
  105, 117, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 56, 44, 48, 44,
  51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97,
  99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 49,
  44, 48, 46, 48, 49, 44, 48, 46, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104,
  117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50,
  47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 95, 101, 108,
  108, 105, 112, 115, 101, 115, 32, 58, 10, 45, 99, 111, 108, 111, 114, 95,
  101, 108, 108, 105, 112, 115, 101, 115, 32, 36, 49, 44, 36, 50, 44, 36,
  51, 10, 35, 64, 103, 105, 109, 112, 32, 82, 97, 121, 115, 32, 58, 32,
  106, 101, 106, 101, 95, 114, 97, 121, 115, 44, 32, 106, 101, 106, 101, 95,
  114, 97, 121, 115, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 88, 32, 99, 101, 110, 116, 101, 114, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 32, 99, 101, 110, 116,
  101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 114,
  101, 113, 117, 101, 110, 99, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 80, 114, 111, 112, 111, 114, 116, 105, 111, 110, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 49, 32,
  61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 48, 44, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32,
  50, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53,
  53, 44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 74, 38, 35,
  50, 51, 51, 59, 114, 38, 35, 50, 52, 52, 59, 109, 101, 32, 66, 111,
  117, 108, 97, 110, 103, 101, 114, 60, 47, 105, 62, 46, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 51, 47, 49, 48, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 106, 101, 106, 101, 95, 114, 97,
  121, 115, 32, 58, 10, 45, 115, 32, 99, 10, 45, 108, 91, 48, 93, 32,
  45, 114, 97, 121, 115, 32, 123, 119, 42, 36, 49, 47, 49, 48, 48, 125,
  44, 123, 104, 42, 36, 50, 47, 49, 48, 48, 125, 44, 36, 51, 44, 36,
  52, 32, 45, 110, 32, 48, 44, 49, 32, 45, 103, 116, 32, 36, 53, 32,
  45, 110, 32, 36, 54, 44, 36, 57, 32, 45, 101, 110, 100, 108, 10, 45,
  108, 91, 49, 93, 32, 45, 114, 97, 121, 115, 32, 123, 119, 42, 36, 49,
  47, 49, 48, 48, 125, 44, 123, 104, 42, 36, 50, 47, 49, 48, 48, 125,
  44, 36, 51, 44, 36, 52, 32, 45, 110, 32, 48, 44, 49, 32, 45, 103,
  116, 32, 36, 53, 32, 45, 110, 32, 36, 55, 44, 36, 49, 48, 32, 45,
  101, 110, 100, 108, 10, 45, 108, 91, 50, 93, 32, 45, 114, 97, 121, 115,
  32, 123, 119, 42, 36, 49, 47, 49, 48, 48, 125, 44, 123, 104, 42, 36,
  50, 47, 49, 48, 48, 125, 44, 36, 51, 44, 36, 52, 32, 45, 110, 32,
  48, 44, 49, 32, 45, 103, 116, 32, 36, 53, 32, 45, 110, 32, 36, 56,
  44, 36, 49, 49, 32, 45, 101, 110, 100, 108, 10, 45, 97, 32, 99, 10,
  106, 101, 106, 101, 95, 114, 97, 121, 115, 95, 112, 114, 101, 118, 105, 101,
  119, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 106, 101, 106, 101, 95, 114, 97,
  121, 115, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36,
  53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 44, 36, 57, 44, 36, 49,
  48, 44, 36, 49, 49, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 82, 111, 114, 115, 99, 104, 97, 99, 104, 32, 58, 32, 103, 105,
  109, 112, 95, 114, 111, 114, 115, 99, 104, 97, 99, 104, 44, 32, 103, 105,
  109, 112, 95, 114, 111, 114, 115, 99, 104, 97, 99, 104, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 51, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 77, 105, 114, 114, 111, 114, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 49, 44, 34, 78, 111, 110, 101, 34, 44, 34, 120,
  45, 97, 120, 105, 115, 34, 44, 34, 121, 45, 97, 120, 105, 115, 34, 44,
  34, 120, 121, 45, 97, 120, 101, 115, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 116, 101, 110, 99, 105, 108, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 50, 44, 34, 66, 108, 97,
  99, 107, 32, 38, 32, 87, 104, 105, 116, 101, 34, 44, 34, 82, 71, 66,
  34, 44, 34, 67, 111, 108, 111, 114, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104,
  117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48, 51,
  47, 49, 50, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 103, 105, 109, 112, 95, 114, 111, 114, 115, 99, 104, 97, 99,
  104, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 36, 51, 61, 61, 48,
  125, 32, 45, 110, 111, 114, 109, 32, 45, 114, 111, 114, 115, 99, 104, 97,
  99, 104, 32, 36, 49, 37, 44, 36, 50, 32, 45, 42, 32, 50, 53, 53,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 51, 61, 61, 49, 125, 32, 45,
  116, 111, 95, 114, 103, 98, 32, 45, 114, 111, 114, 115, 99, 104, 97, 99,
  104, 32, 36, 49, 37, 44, 36, 50, 32, 45, 42, 32, 50, 53, 53, 10,
  45, 101, 108, 115, 101, 32, 45, 45, 110, 111, 114, 109, 32, 45, 114, 111,
  114, 115, 99, 104, 97, 99, 104, 91, 45, 49, 93, 32, 36, 49, 37, 44,
  36, 50, 32, 45, 98, 108, 101, 110, 100, 32, 115, 104, 97, 112, 101, 97,
  118, 101, 114, 97, 103, 101, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109,
  112, 32, 83, 101, 97, 109, 108, 101, 115, 115, 32, 100, 101, 99, 111, 32,
  58, 32, 103, 105, 109, 112, 95, 109, 97, 100, 95, 114, 111, 114, 115, 99,
  104, 97, 114, 99, 104, 112, 44, 103, 105, 109, 112, 95, 109, 97, 100, 95,
  114, 111, 114, 115, 99, 104, 97, 114, 99, 104, 112, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 51, 44, 48, 44, 49, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 77, 105, 120, 101, 114, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 32, 40, 34, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 71,
  114, 97, 105, 110, 32, 69, 120, 116, 114, 97, 99, 116, 34, 44, 34, 86,
  105, 118, 105, 100, 32, 69, 100, 103, 101, 115, 34, 44, 34, 68, 105, 102,
  102, 101, 114, 101, 110, 99, 101, 34, 44, 32, 34, 69, 120, 99, 108, 117,
  115, 105, 111, 110, 34, 44, 34, 32, 78, 101, 103, 97, 116, 105, 111, 110,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 114, 112, 101,
  110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 48, 48, 44, 48, 44,
  49, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 109, 105, 120, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 32, 40, 32, 34, 86, 105, 118, 105,
  100, 32, 69, 100, 103, 101, 115, 34, 44, 32, 34, 65, 118, 101, 114, 97,
  103, 101, 34, 44, 32, 34, 68, 105, 102, 102, 101, 114, 101, 110, 99, 101,
  34, 44, 34, 78, 101, 103, 97, 116, 105, 111, 110, 34, 44, 34, 68, 97,
  114, 107, 32, 69, 100, 103, 101, 115, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 80, 104, 111, 116, 111, 99, 111, 109, 105, 120, 32, 112,
  114, 101, 115, 101, 116, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 32,
  34, 78, 101, 97, 116, 32, 77, 101, 114, 103, 101, 34, 44, 34, 76, 105,
  103, 104, 116, 121, 32, 83, 109, 111, 111, 116, 104, 34, 44, 34, 68, 114,
  101, 97, 109, 34, 44, 34, 77, 111, 111, 100, 121, 34, 32, 34, 83, 111,
  102, 116, 34, 44, 34, 78, 97, 105, 102, 34, 44, 34, 68, 97, 114, 107,
  32, 66, 111, 111, 115, 116, 34, 44, 34, 87, 104, 105, 116, 101, 110, 105,
  110, 103, 34, 44, 34, 32, 78, 111, 110, 101, 45, 32, 83, 107, 105, 112,
  34, 32, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 99, 116,
  105, 118, 97, 116, 101, 32, 109, 105, 114, 114, 111, 114, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 32, 40, 34, 78, 111, 45, 83, 107, 105, 112, 34,
  44, 32, 88, 89, 32, 77, 105, 114, 114, 111, 114, 34, 44, 34, 32, 50,
  88, 89, 32, 77, 105, 114, 114, 111, 114, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 87, 65, 82,
  78, 73, 78, 71, 44, 34, 69, 120, 112, 97, 110, 100, 105, 110, 103, 32,
  77, 105, 114, 114, 111, 114, 115, 34, 32, 109, 117, 108, 116, 105, 112, 108,
  121, 32, 105, 109, 97, 103, 101, 32, 115, 105, 122, 101, 32, 111, 102, 32,
  120, 52, 32, 111, 114, 32, 105, 102, 32, 34, 50, 88, 89, 32, 77, 105,
  114, 114, 111, 114, 115, 34, 32, 120, 57, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  69, 120, 112, 97, 110, 100, 105, 110, 103, 32, 109, 105, 114, 114, 111, 114,
  115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 80, 104, 111, 116, 111, 67, 111, 109, 105,
  120, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50,
  48, 49, 49, 47, 49, 49, 47, 49, 51, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 109, 97,
  100, 95, 114, 111, 114, 115, 99, 104, 97, 114, 99, 104, 112, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 114, 111, 114, 115, 99, 104, 97, 99, 104, 32,
  36, 49, 44, 49, 44, 49, 10, 45, 45, 109, 105, 114, 114, 111, 114, 32,
  121, 10, 45, 105, 102, 32, 123, 36, 50, 61, 61, 48, 125, 32, 45, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 97, 118, 101, 114,
  97, 103, 101, 32, 49, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  50, 61, 61, 49, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 103, 114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116,
  32, 49, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 61, 61,
  49, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 118, 105, 118, 105, 100, 101, 100, 103, 101, 115, 32, 49, 44, 49, 44,
  48, 46, 53, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 103,
  105, 109, 112, 95, 112, 108, 97, 105, 100, 95, 116, 101, 120, 116, 117, 114,
  101, 32, 36, 51, 44, 50, 44, 48, 44, 57, 48, 44, 36, 52, 44, 36,
  53, 10, 45, 105, 102, 32, 123, 36, 54, 61, 61, 48, 125, 32, 45, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 118, 105, 118, 105,
  100, 101, 100, 103, 101, 115, 32, 49, 44, 49, 44, 48, 46, 53, 44, 49,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 54, 61, 61, 49, 125, 32, 45,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 97, 118, 101,
  114, 97, 103, 101, 32, 49, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 54, 61, 61, 50, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 100, 105, 102, 102, 101, 114, 101, 110, 99, 101, 32,
  49, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 54, 61, 61, 51,
  125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95,
  110, 101, 103, 97, 116, 105, 111, 110, 32, 49, 44, 48, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 54, 61, 61, 52, 125, 32, 45, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 110, 101, 103, 97, 116, 105, 111,
  110, 32, 49, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 54, 61,
  61, 53, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 100, 97, 114, 107, 101, 100, 103, 101, 115, 32, 49, 44, 49, 44,
  48, 46, 56, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 55, 61, 61, 48, 125, 32, 45, 103, 105, 109, 112, 95, 103,
  114, 97, 112, 104, 105, 99, 95, 110, 111, 118, 101, 108, 102, 120, 108, 32,
  48, 44, 50, 44, 54, 44, 53, 44, 50, 48, 44, 48, 44, 48, 46, 54,
  50, 44, 49, 52, 44, 48, 44, 49, 44, 48, 46, 53, 44, 48, 46, 55,
  56, 44, 49, 46, 57, 50, 44, 48, 44, 48, 44, 49, 50, 44, 49, 44,
  49, 44, 49, 44, 48, 46, 53, 44, 48, 46, 56, 44, 49, 46, 50, 56,
  44, 49, 46, 50, 53, 44, 50, 44, 48, 44, 48, 46, 49, 53, 44, 49,
  52, 44, 48, 44, 49, 44, 48, 46, 53, 44, 48, 46, 52, 53, 44, 50,
  44, 48, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49, 44, 48, 46, 53,
  44, 48, 46, 52, 53, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  55, 61, 61, 49, 125, 45, 103, 105, 109, 112, 95, 103, 114, 97, 112, 104,
  105, 99, 95, 110, 111, 118, 101, 108, 102, 120, 108, 32, 48, 44, 55, 46,
  50, 44, 49, 52, 46, 54, 53, 44, 53, 44, 50, 48, 44, 48, 44, 49,
  46, 48, 54, 44, 51, 54, 46, 49, 52, 44, 48, 44, 49, 44, 48, 46,
  53, 44, 48, 46, 56, 53, 44, 49, 46, 57, 51, 44, 48, 44, 48, 44,
  56, 44, 49, 44, 49, 44, 49, 44, 48, 46, 53, 44, 48, 46, 57, 53,
  44, 50, 46, 56, 57, 44, 49, 46, 50, 53, 44, 50, 44, 48, 44, 48,
  46, 49, 53, 44, 49, 52, 44, 48, 44, 49, 44, 48, 46, 53, 44, 48,
  46, 52, 53, 44, 50, 44, 48, 44, 49, 44, 48, 44, 49, 44, 49, 44,
  49, 44, 48, 46, 53, 44, 48, 46, 52, 53, 44, 49, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 55, 61, 61, 50, 125, 32, 45, 103, 105, 109, 112,
  95, 103, 114, 97, 112, 104, 105, 99, 95, 110, 111, 118, 101, 108, 102, 120,
  108, 32, 48, 44, 55, 46, 50, 50, 56, 57, 50, 44, 49, 52, 46, 54,
  53, 48, 54, 44, 53, 44, 50, 48, 44, 48, 44, 49, 46, 54, 44, 51,
  54, 46, 49, 44, 48, 44, 49, 44, 48, 46, 53, 44, 48, 46, 54, 44,
  51, 46, 54, 44, 48, 44, 48, 44, 49, 49, 44, 49, 44, 49, 44, 49,
  44, 48, 46, 53, 44, 48, 46, 56, 44, 50, 46, 49, 54, 44, 49, 46,
  50, 53, 44, 50, 44, 48, 44, 48, 46, 49, 53, 44, 49, 52, 44, 48,
  44, 49, 44, 48, 46, 53, 44, 48, 46, 52, 53, 44, 50, 44, 48, 44,
  49, 44, 55, 44, 49, 44, 49, 44, 49, 44, 48, 46, 53, 44, 48, 46,
  52, 53, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 55, 61, 61,
  51, 125, 32, 32, 45, 103, 105, 109, 112, 95, 103, 114, 97, 112, 104, 105,
  99, 95, 110, 111, 118, 101, 108, 102, 120, 108, 32, 48, 44, 55, 46, 50,
  50, 56, 57, 50, 44, 49, 52, 46, 54, 53, 48, 54, 44, 53, 44, 50,
  48, 44, 48, 44, 49, 46, 53, 57, 48, 51, 54, 44, 51, 54, 46, 49,
  52, 52, 54, 44, 48, 44, 49, 44, 48, 46, 53, 44, 48, 46, 53, 57,
  48, 51, 54, 49, 44, 51, 46, 54, 49, 52, 52, 54, 44, 48, 44, 49,
  44, 49, 55, 44, 49, 44, 49, 44, 49, 44, 48, 46, 53, 44, 48, 46,
  55, 57, 53, 49, 56, 49, 44, 50, 46, 49, 54, 56, 54, 55, 44, 49,
  46, 50, 53, 44, 50, 44, 48, 44, 48, 46, 49, 53, 44, 49, 52, 44,
  48, 44, 49, 44, 48, 46, 53, 44, 48, 46, 52, 53, 44, 50, 44, 48,
  44, 49, 44, 55, 44, 49, 44, 49, 44, 49, 44, 48, 46, 53, 44, 48,
  46, 52, 53, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 55, 61,
  61, 52, 125, 32, 45, 103, 105, 109, 112, 95, 103, 114, 97, 112, 104, 105,
  99, 95, 110, 111, 118, 101, 108, 102, 120, 108, 32, 48, 44, 55, 46, 50,
  50, 56, 57, 50, 44, 49, 52, 46, 54, 53, 48, 54, 44, 53, 44, 50,
  48, 44, 48, 44, 49, 46, 53, 57, 48, 51, 54, 44, 51, 54, 46, 49,
  52, 52, 54, 44, 48, 44, 49, 44, 48, 46, 53, 44, 48, 46, 56, 53,
  53, 52, 50, 50, 44, 49, 46, 57, 50, 55, 55, 49, 44, 48, 44, 48,
  44, 56, 44, 49, 44, 49, 44, 49, 44, 48, 46, 53, 44, 48, 46, 51,
  55, 51, 52, 57, 52, 44, 50, 46, 56, 57, 49, 53, 55, 44, 49, 46,
  50, 53, 44, 50, 44, 48, 44, 48, 46, 49, 53, 44, 49, 52, 44, 48,
  44, 49, 44, 48, 46, 53, 44, 48, 46, 52, 53, 44, 50, 44, 48, 44,
  49, 44, 48, 44, 49, 44, 49, 44, 49, 44, 48, 46, 53, 44, 48, 46,
  52, 53, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 55, 61, 61,
  53, 125, 32, 45, 103, 105, 109, 112, 95, 103, 114, 97, 112, 104, 105, 99,
  95, 110, 111, 118, 101, 108, 102, 120, 108, 32, 49, 44, 55, 46, 50, 50,
  56, 57, 50, 44, 49, 52, 46, 54, 53, 48, 54, 44, 53, 44, 50, 48,
  44, 48, 44, 49, 46, 48, 54, 48, 50, 52, 44, 49, 52, 44, 48, 44,
  49, 44, 48, 46, 53, 44, 48, 46, 56, 53, 53, 52, 50, 50, 44, 49,
  46, 51, 50, 53, 51, 44, 48, 44, 48, 44, 49, 50, 44, 49, 44, 49,
  44, 49, 44, 48, 46, 53, 44, 48, 46, 56, 44, 49, 46, 50, 56, 44,
  49, 46, 50, 53, 44, 50, 44, 48, 44, 48, 46, 49, 53, 44, 49, 52,
  44, 48, 44, 49, 44, 48, 46, 53, 44, 48, 46, 52, 53, 44, 50, 44,
  48, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49, 44, 48, 46, 53, 44,
  48, 46, 52, 53, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 55,
  61, 61, 54, 125, 32, 45, 103, 105, 109, 112, 95, 103, 114, 97, 112, 104,
  105, 99, 95, 110, 111, 118, 101, 108, 102, 120, 108, 32, 49, 44, 55, 46,
  50, 50, 56, 57, 50, 44, 49, 52, 46, 54, 53, 48, 54, 44, 53, 44,
  50, 48, 44, 48, 44, 49, 46, 48, 54, 48, 50, 52, 44, 51, 54, 46,
  49, 52, 52, 54, 44, 48, 44, 49, 44, 48, 46, 53, 44, 48, 46, 56,
  53, 53, 52, 50, 50, 44, 49, 46, 57, 50, 55, 55, 49, 44, 48, 44,
  48, 44, 55, 44, 49, 44, 49, 44, 49, 44, 48, 46, 53, 44, 48, 46,
  57, 53, 49, 56, 48, 55, 44, 49, 46, 57, 50, 55, 55, 49, 44, 49,
  46, 50, 53, 44, 50, 44, 48, 44, 48, 46, 49, 53, 44, 49, 52, 44,
  48, 44, 49, 44, 48, 46, 53, 44, 48, 46, 52, 53, 44, 50, 44, 48,
  44, 49, 44, 48, 44, 49, 44, 49, 44, 49, 44, 48, 46, 53, 44, 48,
  46, 52, 53, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 55, 61,
  61, 55, 125, 32, 45, 103, 105, 109, 112, 95, 103, 114, 97, 112, 104, 105,
  99, 95, 110, 111, 118, 101, 108, 102, 120, 108, 32, 49, 44, 55, 46, 50,
  50, 56, 57, 50, 44, 49, 52, 46, 54, 53, 48, 54, 44, 53, 44, 50,
  48, 44, 48, 44, 49, 46, 53, 57, 48, 51, 54, 44, 51, 54, 46, 49,
  52, 52, 54, 44, 48, 44, 49, 44, 48, 46, 53, 44, 48, 46, 53, 57,
  48, 51, 54, 49, 44, 51, 46, 54, 49, 52, 52, 54, 44, 48, 44, 49,
  44, 49, 56, 44, 49, 44, 49, 44, 49, 44, 48, 46, 53, 44, 48, 46,
  55, 57, 53, 49, 56, 49, 44, 50, 46, 49, 54, 56, 54, 55, 44, 49,
  46, 50, 53, 44, 50, 44, 48, 44, 48, 46, 49, 53, 44, 49, 52, 44,
  48, 44, 49, 44, 48, 46, 53, 44, 48, 46, 52, 53, 44, 50, 44, 48,
  44, 49, 44, 48, 44, 49, 44, 49, 44, 49, 44, 48, 46, 53, 44, 48,
  46, 52, 53, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 56, 61, 61, 49, 125, 32, 45, 103, 105, 109, 112, 95, 97,
  114, 114, 97, 121, 95, 109, 105, 114, 114, 111, 114, 32, 49, 44, 48, 44,
  48, 44, 50, 44, 48, 44, 36, 57, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 56, 61, 61, 50, 125, 32, 45, 103, 105, 109, 112, 95, 97, 114, 114,
  97, 121, 95, 109, 105, 114, 114, 111, 114, 32, 49, 44, 48, 44, 48, 44,
  51, 44, 48, 44, 36, 57, 32, 45, 101, 110, 100, 105, 102, 10, 35, 64,
  103, 105, 109, 112, 32, 83, 101, 97, 109, 108, 101, 115, 115, 32, 116, 117,
  114, 98, 117, 108, 101, 110, 99, 101, 32, 58, 32, 103, 105, 109, 112, 95,
  115, 101, 97, 109, 108, 101, 115, 115, 95, 116, 117, 114, 98, 117, 108, 101,
  110, 99, 101, 44, 32, 103, 105, 109, 112, 95, 115, 101, 97, 109, 108, 101,
  115, 115, 95, 116, 117, 114, 98, 117, 108, 101, 110, 99, 101, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116,
  117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 53, 44, 48,
  44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 48, 44, 48, 44, 52, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 79, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 56, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 118, 105, 97, 116, 105,
  111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116, 114,
  97, 115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44, 48, 44,
  52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111,
  114, 32, 114, 101, 110, 100, 101, 114, 105, 110, 103, 32, 61, 32, 98, 111,
  111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105,
  62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114,
  108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 52, 47, 48, 50, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 115, 101, 97, 109, 108, 101, 115, 115, 95, 116, 117, 114, 98,
  117, 108, 101, 110, 99, 101, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 104, 61, 123, 119,
  125, 44, 123, 104, 125, 32, 45, 114, 109, 10, 36, 119, 104, 44, 49, 44,
  123, 105, 102, 40, 36, 54, 44, 51, 44, 49, 41, 125, 32, 45, 114, 97,
  110, 100, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 36, 119, 104,
  32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 123, 36, 51, 42, 112,
  105, 47, 49, 56, 48, 45, 36, 52, 42, 49, 48, 42, 112, 105, 125, 44,
  123, 36, 51, 42, 112, 105, 47, 49, 56, 48, 43, 36, 52, 42, 49, 48,
  42, 112, 105, 125, 32, 45, 45, 115, 105, 110, 91, 45, 49, 93, 32, 45,
  99, 111, 115, 91, 45, 50, 93, 32, 45, 97, 91, 45, 50, 44, 45, 49,
  93, 32, 99, 10, 45, 114, 91, 45, 50, 44, 45, 49, 93, 32, 49, 51,
  48, 37, 44, 49, 51, 48, 37, 44, 49, 44, 49, 48, 48, 37, 44, 48,
  44, 50, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 98, 91, 45, 49,
  93, 32, 36, 50, 32, 45, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111,
  110, 91, 45, 49, 93, 10, 45, 118, 101, 99, 116, 111, 114, 50, 116, 101,
  110, 115, 111, 114, 91, 45, 49, 93, 10, 45, 115, 109, 111, 111, 116, 104,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 49, 44, 48, 46, 53,
  44, 50, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 114, 91, 45,
  49, 93, 32, 36, 119, 104, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 105, 102, 32, 123, 36,
  53, 33, 61, 49, 125, 32, 105, 97, 61, 123, 105, 97, 125, 32, 45, 45,
  32, 36, 105, 97, 32, 45, 42, 32, 36, 53, 32, 45, 43, 32, 36, 105,
  97, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 110,
  32, 48, 44, 50, 53, 53, 10, 35, 64, 103, 105, 109, 112, 32, 83, 112,
  111, 110, 103, 101, 32, 58, 32, 103, 105, 109, 112, 95, 115, 112, 111, 110,
  103, 101, 44, 32, 103, 105, 109, 112, 95, 115, 112, 111, 110, 103, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 49,
  51, 44, 51, 44, 50, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65,
  34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117,
  101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34,
  44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34,
  83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108,
  117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101, 110,
  32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 99,
  104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44,
  34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34,
  65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105,
  99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 115, 112, 111,
  110, 103, 101, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 34, 45, 115, 112, 111, 110, 103, 101, 32, 36,
  49, 34, 44, 36, 50, 44, 48, 10, 103, 105, 109, 112, 95, 115, 112, 111,
  110, 103, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 103, 105, 109, 112, 95, 115, 112, 111, 110, 103, 101, 32,
  36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 83,
  116, 97, 105, 110, 101, 100, 32, 103, 108, 97, 115, 115, 32, 58, 32, 103,
  105, 109, 112, 95, 115, 116, 97, 105, 110, 101, 100, 95, 103, 108, 97, 115,
  115, 44, 32, 103, 105, 109, 112, 95, 115, 116, 97, 105, 110, 101, 100, 95,
  103, 108, 97, 115, 115, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 100, 105,
  110, 103, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 49, 44, 48,
  44, 48, 46, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84,
  104, 105, 110, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 115, 32, 61,
  32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 113, 117,
  97, 108, 105, 122, 101, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 51, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 71, 97, 109, 109, 97, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 46, 50, 44, 49, 46, 50,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116, 114,
  97, 115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44,
  52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 114, 105, 103,
  104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 45, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117,
  108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117,
  112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 49, 47, 48, 51, 47, 49, 56, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  115, 116, 97, 105, 110, 101, 100, 95, 103, 108, 97, 115, 115, 32, 58, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121,
  32, 45, 108, 91, 48, 93, 10, 45, 115, 116, 97, 105, 110, 101, 100, 95,
  103, 108, 97, 115, 115, 32, 36, 49, 44, 36, 50, 44, 36, 51, 10, 45,
  110, 32, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 36, 52, 32, 45,
  101, 113, 117, 97, 108, 105, 122, 101, 91, 45, 49, 93, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 114, 103, 98, 50, 108, 97, 98, 91, 45, 49, 93,
  32, 45, 115, 104, 91, 45, 49, 93, 32, 49, 44, 50, 32, 45, 42, 91,
  45, 49, 93, 32, 36, 53, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  108, 97, 98, 50, 114, 103, 98, 91, 45, 49, 93, 10, 45, 97, 112, 112,
  108, 121, 95, 103, 97, 109, 109, 97, 91, 45, 49, 93, 32, 123, 49, 48,
  94, 36, 54, 125, 32, 45, 45, 91, 45, 49, 93, 32, 49, 50, 56, 32,
  45, 42, 91, 45, 49, 93, 32, 36, 55, 32, 45, 43, 91, 45, 49, 93,
  32, 123, 49, 50, 56, 43, 36, 56, 125, 10, 45, 99, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 97, 112,
  112, 101, 110, 100, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 103, 105, 109, 112, 95, 115, 116, 97, 105, 110, 101, 100, 95,
  103, 108, 97, 115, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 115, 116, 97, 105, 110,
  101, 100, 95, 103, 108, 97, 115, 115, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 83, 116, 97, 114, 115, 32, 58, 32,
  103, 105, 109, 112, 95, 115, 116, 97, 114, 115, 44, 32, 103, 105, 109, 112,
  95, 115, 116, 97, 114, 115, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 68, 101, 110, 115, 105, 116, 121, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 48, 44, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 101, 112, 116, 104, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 51,
  50, 44, 56, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 66, 114, 97, 110, 99, 104, 101, 115, 32, 61, 32, 105, 110, 116,
  40, 53, 44, 50, 44, 49, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 84, 104, 105, 99, 107, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 51, 56, 44, 48, 46, 49, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108,
  111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 48, 48, 44, 50,
  48, 48, 44, 50, 48, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 50, 47, 49,
  48, 47, 48, 49, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 115, 116, 97, 114, 115, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116,
  121, 32, 45, 114, 118, 10, 45, 115, 116, 97, 114, 115, 32, 36, 49, 37,
  44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 37,
  44, 36, 123, 55, 45, 57, 125, 44, 123, 36, 49, 48, 47, 50, 53, 53,
  125, 10, 45, 114, 118, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 83, 116,
  101, 110, 99, 105, 108, 32, 58, 32, 103, 105, 109, 112, 95, 115, 116, 101,
  110, 99, 105, 108, 44, 32, 103, 105, 109, 112, 95, 115, 116, 101, 110, 99,
  105, 108, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 97, 100, 105, 117, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 51, 44, 48, 44, 49, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 51, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101, 114, 97,
  116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 56, 44, 49, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 108,
  105, 97, 115, 105, 110, 103, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  116, 101, 110, 99, 105, 108, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 50, 44, 34, 66, 108, 97, 99, 107, 32, 38, 32,
  87, 104, 105, 116, 101, 34, 44, 34, 82, 71, 66, 34, 44, 34, 67, 111,
  108, 111, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84,
  114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 121, 32, 61, 32, 98, 111,
  111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97,
  116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84,
  115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48,
  47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 115, 116, 101, 110, 99,
  105, 108, 32, 58, 10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 123, 36,
  53, 61, 61, 48, 125, 32, 45, 110, 111, 114, 109, 32, 45, 115, 116, 101,
  110, 99, 105, 108, 32, 36, 49, 44, 36, 50, 44, 36, 51, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 53, 61, 61, 49, 125, 32, 45, 115, 116, 101,
  110, 99, 105, 108, 32, 36, 49, 44, 36, 50, 44, 36, 51, 10, 45, 101,
  108, 115, 101, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45,
  45, 110, 111, 114, 109, 91, 45, 49, 93, 32, 45, 115, 116, 101, 110, 99,
  105, 108, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 32,
  45, 103, 101, 91, 45, 49, 93, 32, 53, 48, 37, 32, 45, 98, 108, 101,
  110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 115, 104, 97, 112, 101, 97,
  118, 101, 114, 97, 103, 101, 48, 10, 45, 109, 118, 91, 45, 49, 93, 32,
  48, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 36, 54, 32, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45,
  114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 32, 48, 44,
  48, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 48, 44, 48, 44,
  48, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36,
  52, 32, 45, 115, 109, 111, 111, 116, 104, 32, 123, 51, 48, 42, 36, 52,
  125, 44, 48, 44, 49, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 103,
  105, 109, 112, 95, 115, 116, 101, 110, 99, 105, 108, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112,
  95, 115, 116, 101, 110, 99, 105, 108, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 83, 116, 114, 105, 112, 32, 58, 32,
  106, 101, 106, 101, 95, 115, 116, 114, 105, 112, 44, 32, 106, 101, 106, 101,
  95, 115, 116, 114, 105, 112, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 52, 53, 44, 48, 44, 57, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 70, 114, 101, 113, 117, 101, 110, 99,
  121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 104, 97,
  115, 101, 32, 61, 32, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109,
  112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 74,
  38, 35, 50, 51, 51, 59, 114, 38, 35, 50, 52, 52, 59, 109, 101, 32,
  66, 111, 117, 108, 97, 110, 103, 101, 114, 60, 47, 105, 62, 46, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 51, 47, 48, 54, 47, 48, 55, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 106, 101, 106, 101, 95,
  115, 116, 114, 105, 112, 32, 58, 10, 116, 104, 101, 116, 97, 61, 123, 112,
  105, 42, 36, 49, 47, 49, 56, 48, 125, 10, 45, 102, 32, 39, 48, 46,
  53, 42, 105, 42, 40, 49, 43, 36, 52, 42, 115, 105, 110, 40, 50, 42,
  112, 105, 42, 36, 50, 42, 40, 99, 111, 115, 40, 36, 116, 104, 101, 116,
  97, 41, 42, 120, 47, 119, 43, 115, 105, 110, 40, 36, 116, 104, 101, 116,
  97, 41, 42, 121, 47, 104, 41, 43, 50, 42, 112, 105, 42, 36, 51, 47,
  49, 56, 48, 41, 41, 39, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10,
  106, 101, 106, 101, 95, 115, 116, 114, 105, 112, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 106, 101, 106, 101, 95,
  115, 116, 114, 105, 112, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64,
  103, 105, 109, 112, 32, 83, 121, 109, 109, 101, 116, 114, 121, 32, 109, 97,
  115, 116, 101, 114, 32, 58, 32, 103, 105, 109, 112, 95, 118, 105, 114, 97,
  108, 44, 103, 105, 109, 112, 95, 118, 105, 114, 97, 108, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 51, 44, 48, 44, 49, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 77, 105, 120, 101, 114, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 32, 40, 34, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34,
  71, 114, 97, 105, 110, 32, 69, 120, 116, 114, 97, 99, 116, 34, 44, 34,
  86, 105, 118, 105, 100, 32, 69, 100, 103, 101, 115, 34, 44, 34, 68, 105,
  102, 102, 101, 114, 101, 110, 99, 101, 34, 44, 32, 34, 69, 120, 99, 108,
  117, 115, 105, 111, 110, 34, 44, 34, 32, 78, 101, 103, 97, 116, 105, 111,
  110, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 109,
  105, 120, 32, 61, 32, 99, 104, 111, 105, 99, 101, 32, 40, 32, 34, 86,
  105, 118, 105, 100, 32, 69, 100, 103, 101, 115, 34, 44, 32, 34, 65, 118,
  101, 114, 97, 103, 101, 34, 44, 32, 34, 68, 105, 102, 102, 101, 114, 101,
  110, 99, 101, 34, 44, 34, 78, 101, 103, 97, 116, 105, 111, 110, 34, 44,
  34, 68, 97, 114, 107, 32, 69, 100, 103, 101, 115, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 80, 104, 111, 116, 111, 99, 111, 109, 105,
  120, 32, 112, 114, 101, 115, 101, 116, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 32, 34, 78, 101, 97, 116, 32, 77, 101, 114, 103, 101, 34, 44,
  34, 76, 105, 103, 104, 116, 121, 32, 83, 109, 111, 111, 116, 104, 34, 44,
  34, 68, 114, 101, 97, 109, 34, 44, 34, 77, 111, 111, 100, 121, 34, 44,
  34, 83, 111, 102, 116, 34, 44, 34, 78, 97, 105, 102, 34, 44, 34, 68,
  97, 114, 107, 32, 66, 111, 111, 115, 116, 34, 44, 34, 87, 104, 105, 116,
  101, 110, 105, 110, 103, 34, 44, 34, 32, 78, 111, 110, 101, 45, 32, 83,
  107, 105, 112, 34, 32, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  65, 99, 116, 105, 118, 97, 116, 101, 32, 109, 105, 114, 114, 111, 114, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 32, 40, 34, 78, 111, 45, 83, 107,
  105, 112, 34, 44, 32, 88, 89, 32, 77, 105, 114, 114, 111, 114, 34, 44,
  34, 32, 50, 88, 89, 32, 77, 105, 114, 114, 111, 114, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  87, 65, 82, 78, 73, 78, 71, 44, 34, 69, 120, 112, 97, 110, 100, 105,
  110, 103, 32, 77, 105, 114, 114, 111, 114, 115, 34, 32, 109, 117, 108, 116,
  105, 112, 108, 121, 32, 105, 109, 97, 103, 101, 32, 115, 105, 122, 101, 32,
  111, 102, 32, 120, 52, 32, 111, 114, 32, 105, 102, 32, 34, 50, 88, 89,
  32, 77, 105, 114, 114, 111, 114, 115, 34, 32, 120, 57, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 69, 120, 112, 97, 110, 100, 105, 110, 103, 32, 109, 105, 114,
  114, 111, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65,
  117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 80, 104, 111, 116, 111, 67,
  111, 109, 105, 120, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60,
  105, 62, 50, 48, 49, 49, 47, 49, 49, 47, 49, 51, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112,
  95, 118, 105, 114, 97, 108, 32, 58, 10, 45, 103, 105, 109, 112, 95, 114,
  111, 114, 115, 99, 104, 97, 99, 104, 32, 36, 49, 44, 49, 44, 49, 10,
  45, 45, 109, 105, 114, 114, 111, 114, 32, 121, 10, 45, 105, 102, 32, 123,
  36, 50, 61, 61, 48, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 97, 118, 101, 114, 97, 103, 101, 32, 49, 44, 48,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 61, 61, 49, 125, 32, 45,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97,
  105, 110, 101, 120, 116, 114, 97, 99, 116, 32, 49, 44, 48, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 50, 61, 61, 49, 125, 32, 45, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 118, 105, 118, 105, 100, 101,
  100, 103, 101, 115, 32, 49, 44, 49, 44, 48, 46, 53, 44, 49, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 45, 103, 105, 109, 112, 95, 97, 114, 114,
  97, 121, 95, 109, 105, 114, 114, 111, 114, 32, 49, 44, 48, 44, 48, 44,
  50, 44, 48, 44, 48, 10, 45, 105, 102, 32, 123, 36, 51, 61, 61, 48,
  125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95,
  118, 105, 118, 105, 100, 101, 100, 103, 101, 115, 32, 49, 44, 49, 44, 48,
  46, 53, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 51, 61, 61,
  49, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 97, 118, 101, 114, 97, 103, 101, 32, 49, 44, 48, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 51, 61, 61, 50, 125, 32, 45, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 100, 105, 102, 102, 101, 114, 101,
  110, 99, 101, 32, 49, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  51, 61, 61, 51, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 110, 101, 103, 97, 116, 105, 111, 110, 32, 49, 44, 48,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 51, 61, 61, 52, 125, 32, 45,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 110, 101, 103,
  97, 116, 105, 111, 110, 32, 49, 44, 48, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 51, 61, 61, 53, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101, 100, 103, 101, 115, 32,
  49, 44, 49, 44, 48, 46, 56, 44, 49, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 52, 61, 61, 48, 125, 32, 45, 103, 105,
  109, 112, 95, 103, 114, 97, 112, 104, 105, 99, 95, 110, 111, 118, 101, 108,
  102, 120, 108, 32, 48, 44, 50, 44, 54, 44, 53, 44, 50, 48, 44, 48,
  44, 48, 46, 54, 50, 44, 49, 52, 44, 48, 44, 49, 44, 48, 46, 53,
  44, 48, 46, 55, 56, 44, 49, 46, 57, 50, 44, 48, 44, 48, 44, 49,
  50, 44, 49, 44, 49, 44, 49, 44, 48, 46, 53, 44, 48, 46, 56, 44,
  49, 46, 50, 56, 44, 49, 46, 50, 53, 44, 50, 44, 48, 44, 48, 46,
  49, 53, 44, 49, 52, 44, 48, 44, 49, 44, 48, 46, 53, 44, 48, 46,
  52, 53, 44, 50, 44, 48, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49,
  44, 48, 46, 53, 44, 48, 46, 52, 53, 44, 49, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 52, 61, 61, 49, 125, 45, 103, 105, 109, 112, 95, 103,
  114, 97, 112, 104, 105, 99, 95, 110, 111, 118, 101, 108, 102, 120, 108, 32,
  48, 44, 55, 46, 50, 44, 49, 52, 46, 54, 53, 44, 53, 44, 50, 48,
  44, 48, 44, 49, 46, 48, 54, 44, 51, 54, 46, 49, 52, 44, 48, 44,
  49, 44, 48, 46, 53, 44, 48, 46, 56, 53, 44, 49, 46, 57, 51, 44,
  48, 44, 48, 44, 56, 44, 49, 44, 49, 44, 49, 44, 48, 46, 53, 44,
  48, 46, 57, 53, 44, 50, 46, 56, 57, 44, 49, 46, 50, 53, 44, 50,
  44, 48, 44, 48, 46, 49, 53, 44, 49, 52, 44, 48, 44, 49, 44, 48,
  46, 53, 44, 48, 46, 52, 53, 44, 50, 44, 48, 44, 49, 44, 48, 44,
  49, 44, 49, 44, 49, 44, 48, 46, 53, 44, 48, 46, 52, 53, 44, 49,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 52, 61, 61, 50, 125, 32, 45,
  103, 105, 109, 112, 95, 103, 114, 97, 112, 104, 105, 99, 95, 110, 111, 118,
  101, 108, 102, 120, 108, 32, 48, 44, 55, 46, 50, 50, 56, 57, 50, 44,
  49, 52, 46, 54, 53, 48, 54, 44, 53, 44, 50, 48, 44, 48, 44, 49,
  46, 54, 44, 51, 54, 46, 49, 44, 48, 44, 49, 44, 48, 46, 53, 44,
  48, 46, 54, 44, 51, 46, 54, 44, 48, 44, 48, 44, 49, 49, 44, 49,
  44, 49, 44, 49, 44, 48, 46, 53, 44, 48, 46, 56, 44, 50, 46, 49,
  54, 44, 49, 46, 50, 53, 44, 50, 44, 48, 44, 48, 46, 49, 53, 44,
  49, 52, 44, 48, 44, 49, 44, 48, 46, 53, 44, 48, 46, 52, 53, 44,
  50, 44, 48, 44, 49, 44, 55, 44, 49, 44, 49, 44, 49, 44, 48, 46,
  53, 44, 48, 46, 52, 53, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 52, 61, 61, 51, 125, 32, 32, 45, 103, 105, 109, 112, 95, 103, 114,
  97, 112, 104, 105, 99, 95, 110, 111, 118, 101, 108, 102, 120, 108, 32, 48,
  44, 55, 46, 50, 50, 56, 57, 50, 44, 49, 52, 46, 54, 53, 48, 54,
  44, 53, 44, 50, 48, 44, 48, 44, 49, 46, 53, 57, 48, 51, 54, 44,
  51, 54, 46, 49, 52, 52, 54, 44, 48, 44, 49, 44, 48, 46, 53, 44,
  48, 46, 53, 57, 48, 51, 54, 49, 44, 51, 46, 54, 49, 52, 52, 54,
  44, 48, 44, 49, 44, 49, 55, 44, 49, 44, 49, 44, 49, 44, 48, 46,
  53, 44, 48, 46, 55, 57, 53, 49, 56, 49, 44, 50, 46, 49, 54, 56,
  54, 55, 44, 49, 46, 50, 53, 44, 50, 44, 48, 44, 48, 46, 49, 53,
  44, 49, 52, 44, 48, 44, 49, 44, 48, 46, 53, 44, 48, 46, 52, 53,
  44, 50, 44, 48, 44, 49, 44, 55, 44, 49, 44, 49, 44, 49, 44, 48,
  46, 53, 44, 48, 46, 52, 53, 44, 49, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 52, 61, 61, 52, 125, 32, 45, 103, 105, 109, 112, 95, 103, 114,
  97, 112, 104, 105, 99, 95, 110, 111, 118, 101, 108, 102, 120, 108, 32, 48,
  44, 55, 46, 50, 50, 56, 57, 50, 44, 49, 52, 46, 54, 53, 48, 54,
  44, 53, 44, 50, 48, 44, 48, 44, 49, 46, 53, 57, 48, 51, 54, 44,
  51, 54, 46, 49, 52, 52, 54, 44, 48, 44, 49, 44, 48, 46, 53, 44,
  48, 46, 56, 53, 53, 52, 50, 50, 44, 49, 46, 57, 50, 55, 55, 49,
  44, 48, 44, 48, 44, 56, 44, 49, 44, 49, 44, 49, 44, 48, 46, 53,
  44, 48, 46, 51, 55, 51, 52, 57, 52, 44, 50, 46, 56, 57, 49, 53,
  55, 44, 49, 46, 50, 53, 44, 50, 44, 48, 44, 48, 46, 49, 53, 44,
  49, 52, 44, 48, 44, 49, 44, 48, 46, 53, 44, 48, 46, 52, 53, 44,
  50, 44, 48, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49, 44, 48, 46,
  53, 44, 48, 46, 52, 53, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 52, 61, 61, 53, 125, 32, 45, 103, 105, 109, 112, 95, 103, 114, 97,
  112, 104, 105, 99, 95, 110, 111, 118, 101, 108, 102, 120, 108, 32, 49, 44,
  55, 46, 50, 50, 56, 57, 50, 44, 49, 52, 46, 54, 53, 48, 54, 44,
  53, 44, 50, 48, 44, 48, 44, 49, 46, 48, 54, 48, 50, 52, 44, 49,
  52, 44, 48, 44, 49, 44, 48, 46, 53, 44, 48, 46, 56, 53, 53, 52,
  50, 50, 44, 49, 46, 51, 50, 53, 51, 44, 48, 44, 48, 44, 49, 50,
  44, 49, 44, 49, 44, 49, 44, 48, 46, 53, 44, 48, 46, 56, 44, 49,
  46, 50, 56, 44, 49, 46, 50, 53, 44, 50, 44, 48, 44, 48, 46, 49,
  53, 44, 49, 52, 44, 48, 44, 49, 44, 48, 46, 53, 44, 48, 46, 52,
  53, 44, 50, 44, 48, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49, 44,
  48, 46, 53, 44, 48, 46, 52, 53, 44, 49, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 52, 61, 61, 54, 125, 32, 45, 103, 105, 109, 112, 95, 103,
  114, 97, 112, 104, 105, 99, 95, 110, 111, 118, 101, 108, 102, 120, 108, 32,
  49, 44, 55, 46, 50, 50, 56, 57, 50, 44, 49, 52, 46, 54, 53, 48,
  54, 44, 53, 44, 50, 48, 44, 48, 44, 49, 46, 48, 54, 48, 50, 52,
  44, 51, 54, 46, 49, 52, 52, 54, 44, 48, 44, 49, 44, 48, 46, 53,
  44, 48, 46, 56, 53, 53, 52, 50, 50, 44, 49, 46, 57, 50, 55, 55,
  49, 44, 48, 44, 48, 44, 55, 44, 49, 44, 49, 44, 49, 44, 48, 46,
  53, 44, 48, 46, 57, 53, 49, 56, 48, 55, 44, 49, 46, 57, 50, 55,
  55, 49, 44, 49, 46, 50, 53, 44, 50, 44, 48, 44, 48, 46, 49, 53,
  44, 49, 52, 44, 48, 44, 49, 44, 48, 46, 53, 44, 48, 46, 52, 53,
  44, 50, 44, 48, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49, 44, 48,
  46, 53, 44, 48, 46, 52, 53, 44, 49, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 52, 61, 61, 55, 125, 32, 45, 103, 105, 109, 112, 95, 103, 114,
  97, 112, 104, 105, 99, 95, 110, 111, 118, 101, 108, 102, 120, 108, 32, 49,
  44, 55, 46, 50, 50, 56, 57, 50, 44, 49, 52, 46, 54, 53, 48, 54,
  44, 53, 44, 50, 48, 44, 48, 44, 49, 46, 53, 57, 48, 51, 54, 44,
  51, 54, 46, 49, 52, 52, 54, 44, 48, 44, 49, 44, 48, 46, 53, 44,
  48, 46, 53, 57, 48, 51, 54, 49, 44, 51, 46, 54, 49, 52, 52, 54,
  44, 48, 44, 49, 44, 49, 56, 44, 49, 44, 49, 44, 49, 44, 48, 46,
  53, 44, 48, 46, 55, 57, 53, 49, 56, 49, 44, 50, 46, 49, 54, 56,
  54, 55, 44, 49, 46, 50, 53, 44, 50, 44, 48, 44, 48, 46, 49, 53,
  44, 49, 52, 44, 48, 44, 49, 44, 48, 46, 53, 44, 48, 46, 52, 53,
  44, 50, 44, 48, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49, 44, 48,
  46, 53, 44, 48, 46, 52, 53, 44, 49, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 53, 61, 61, 49, 125, 32, 45, 103, 105,
  109, 112, 95, 97, 114, 114, 97, 121, 95, 109, 105, 114, 114, 111, 114, 32,
  49, 44, 48, 44, 48, 44, 50, 44, 48, 44, 36, 54, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 53, 61, 61, 50, 125, 32, 45, 103, 105, 109, 112,
  95, 97, 114, 114, 97, 121, 95, 109, 105, 114, 114, 111, 114, 32, 49, 44,
  48, 44, 48, 44, 51, 44, 48, 44, 36, 54, 32, 45, 101, 110, 100, 105,
  102, 10, 35, 64, 103, 105, 109, 112, 32, 84, 101, 116, 114, 105, 115, 32,
  58, 32, 103, 105, 109, 112, 95, 116, 101, 116, 114, 105, 115, 44, 32, 103,
  105, 109, 112, 95, 116, 101, 116, 114, 105, 115, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 61, 32, 105,
  110, 116, 40, 49, 48, 44, 49, 44, 50, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49,
  50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 116, 101, 116, 114, 105, 115, 32,
  58, 10, 45, 116, 101, 116, 114, 105, 115, 32, 36, 49, 10, 35, 64, 103,
  105, 109, 112, 32, 84, 114, 117, 99, 104, 101, 116, 32, 58, 32, 103, 105,
  109, 112, 95, 116, 114, 117, 99, 104, 101, 116, 44, 32, 103, 105, 109, 112,
  95, 116, 114, 117, 99, 104, 101, 116, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 61, 32, 105, 110, 116,
  40, 51, 50, 44, 49, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 82, 97, 100, 105, 117, 115, 32, 61, 32, 105, 110, 116,
  40, 53, 44, 49, 44, 54, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 84, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 49, 44, 34, 83, 116, 114, 97, 105, 103, 104, 116, 34,
  44, 34, 67, 117, 114, 118, 101, 100, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 108, 111, 114, 105, 122, 101, 32, 114, 97, 110,
  100, 111, 109, 108, 121, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 114, 97, 110, 115, 112, 97,
  114, 101, 110, 99, 121, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 49, 47, 49, 48, 47, 50, 54, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 116, 114, 117,
  99, 104, 101, 116, 32, 58, 10, 45, 105, 102, 32, 36, 54, 32, 45, 116,
  111, 95, 97, 32, 45, 101, 108, 115, 101, 32, 45, 114, 101, 109, 111, 118,
  101, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 116, 114, 117, 99, 104, 101, 116, 32, 36, 49, 44, 36, 50, 44,
  36, 52, 10, 45, 105, 102, 32, 36, 53, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45,
  49, 93, 32, 48, 32, 45, 108, 97, 98, 101, 108, 91, 45, 49, 93, 32,
  48, 44, 49, 32, 123, 105, 77, 43, 49, 125, 44, 49, 44, 49, 44, 51,
  32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  32, 45, 109, 97, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48,
  32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 98,
  32, 36, 51, 32, 45, 110, 32, 48, 44, 50, 53, 53, 10, 35, 64, 103,
  105, 109, 112, 32, 84, 117, 114, 98, 117, 108, 101, 110, 99, 101, 32, 58,
  32, 103, 105, 109, 112, 95, 116, 117, 114, 98, 117, 108, 101, 110, 99, 101,
  44, 32, 103, 105, 109, 112, 95, 116, 117, 114, 98, 117, 108, 101, 110, 99,
  101, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 100, 105, 117,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 50, 56, 44, 49, 44,
  49, 48, 50, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79,
  99, 116, 97, 118, 101, 115, 32, 61, 32, 105, 110, 116, 40, 54, 44, 49,
  44, 49, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 97,
  109, 112, 105, 110, 103, 32, 112, 101, 114, 32, 111, 99, 116, 97, 118, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 44, 49, 44, 49, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 105, 102, 102, 101, 114,
  101, 110, 99, 101, 32, 109, 105, 120, 105, 110, 103, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 49, 48, 44, 49, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 77, 111, 100, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 84, 117, 114, 98, 117, 108, 101, 110, 99, 101,
  34, 44, 34, 84, 117, 114, 98, 117, 108, 101, 110, 99, 101, 32, 50, 34,
  44, 34, 70, 114, 97, 99, 116, 97, 108, 32, 78, 111, 105, 115, 101, 34,
  44, 34, 70, 114, 97, 99, 116, 117, 114, 101, 100, 32, 67, 108, 111, 117,
  100, 115, 34, 44, 34, 83, 116, 97, 114, 100, 117, 115, 116, 34, 44, 34,
  80, 101, 97, 32, 83, 111, 117, 112, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 58, 32, 60, 105, 62, 80, 114, 101, 98, 101, 110, 32, 83, 111, 101,
  98, 101, 114, 103, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  116, 117, 114, 98, 117, 108, 101, 110, 99, 101, 32, 58, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45,
  115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108,
  91, 48, 93, 10, 45, 116, 117, 114, 98, 117, 108, 101, 110, 99, 101, 32,
  36, 123, 94, 48, 125, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103,
  105, 109, 112, 32, 87, 101, 97, 118, 101, 32, 58, 32, 119, 101, 97, 118,
  101, 44, 32, 119, 101, 97, 118, 101, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 68, 101, 110, 115, 105, 116, 121, 32, 61, 32, 105,
  110, 116, 40, 54, 44, 49, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 84, 104, 105, 99, 107, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 54, 53, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 100, 111, 119, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 100, 105, 110,
  103, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44,
  51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 105, 98, 101,
  114, 115, 32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 70, 105, 98, 101, 114, 115, 32, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 65, 110, 103, 108, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 48, 32, 100, 101, 103, 46, 34, 44, 34, 50, 50, 46, 53, 32,
  100, 101, 103, 46, 34, 44, 34, 52, 53, 32, 100, 101, 103, 46, 34, 44,
  34, 54, 55, 46, 53, 32, 100, 101, 103, 46, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 88, 45, 99, 117, 114, 118, 97, 116, 117, 114,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 117, 114,
  118, 97, 116, 117, 114, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 45, 49, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60,
  105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101,
  114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 49, 47, 49, 56, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 87, 104, 105, 114, 108, 115, 32, 58, 32, 103,
  105, 109, 112, 95, 119, 104, 105, 114, 108, 115, 44, 32, 103, 105, 109, 112,
  95, 119, 104, 105, 114, 108, 115, 95, 112, 114, 101, 118, 105, 101, 119, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 110, 115,
  105, 116, 121, 32, 61, 32, 105, 110, 116, 40, 55, 44, 51, 44, 50, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44,
  48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68,
  97, 114, 107, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 50, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 76, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 46, 56, 44, 49, 44, 51, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44,
  34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114,
  101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34,
  44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115,
  34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115,
  34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72,
  117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34,
  44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34,
  71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34,
  82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108,
  117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97,
  116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 119, 104, 105, 114, 108, 115, 32, 58, 10, 45, 97, 112, 112, 108,
  121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 119, 104, 105,
  114, 108, 115, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 34,
  44, 36, 53, 44, 48, 10, 103, 105, 109, 112, 95, 119, 104, 105, 114, 108,
  115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 119, 104, 105, 114, 108, 115, 32, 36, 42,
  34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 95, 10, 35,
  64, 103, 105, 109, 112, 32, 60, 98, 62, 82, 101, 110, 100, 101, 114, 105,
  110, 103, 60, 47, 98, 62, 10, 35, 64, 103, 105, 109, 112, 32, 51, 100,
  32, 98, 108, 111, 99, 107, 115, 32, 58, 32, 103, 105, 109, 112, 95, 98,
  108, 111, 99, 107, 115, 51, 100, 44, 32, 103, 105, 109, 112, 95, 98, 108,
  111, 99, 107, 115, 51, 100, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 32, 61, 32,
  105, 110, 116, 40, 51, 50, 44, 49, 44, 49, 50, 56, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 52, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 108, 101, 118, 97,
  116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 45,
  49, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 53,
  44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 48, 44,
  48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  84, 105, 108, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 54, 48, 44,
  48, 44, 57, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70,
  111, 118, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 53, 44, 49, 44,
  57, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99,
  101, 110, 116, 101, 114, 105, 110, 103, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 89, 45, 99, 101, 110, 116, 101, 114, 105, 110, 103, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 88, 45, 108, 105, 103, 104, 116, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 108, 105, 103,
  104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 45, 53, 48, 44, 45,
  49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 90, 45, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 45, 49, 48, 48, 44, 45, 49, 48, 48, 44, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 101, 99, 117, 108, 97, 114,
  32, 108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 112, 101, 99, 117, 108, 97, 114, 32, 115, 104,
  105, 110, 105, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 55, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 85, 115, 101, 32, 108, 105, 103, 104, 116, 32, 61, 32, 98, 111,
  111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  110, 116, 105, 97, 108, 105, 97, 115, 105, 110, 103, 32, 61, 32, 98, 111,
  111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79,
  117, 116, 108, 105, 110, 101, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99,
  111, 108, 111, 114, 40, 48, 44, 48, 44, 48, 44, 49, 50, 56, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 52, 47, 48, 50, 47, 49, 48, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 98, 108, 111,
  99, 107, 115, 51, 100, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 87, 61, 123, 119, 125, 32,
  72, 61, 123, 104, 125, 32, 77, 61, 123, 109, 97, 120, 40, 119, 44, 104,
  41, 125, 10, 45, 105, 102, 32, 123, 119, 62, 104, 125, 32, 45, 114, 50,
  100, 120, 32, 36, 49, 32, 45, 101, 108, 115, 101, 32, 45, 114, 50, 100,
  121, 32, 36, 49, 32, 45, 101, 110, 100, 105, 102, 10, 119, 61, 123, 119,
  125, 32, 104, 61, 123, 104, 125, 32, 109, 61, 123, 109, 97, 120, 40, 119,
  44, 104, 41, 125, 10, 45, 105, 102, 32, 123, 36, 51, 62, 48, 125, 32,
  45, 109, 105, 114, 114, 111, 114, 32, 121, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 109, 97, 103, 101, 98, 108, 111, 99, 107, 115, 51, 100, 32,
  36, 51, 44, 36, 50, 37, 10, 45, 45, 51, 100, 91, 45, 49, 93, 32,
  123, 36, 119, 47, 50, 125, 44, 123, 36, 104, 47, 50, 125, 32, 102, 61,
  123, 36, 52, 42, 36, 77, 47, 40, 36, 109, 42, 40, 50, 45, 36, 49,
  54, 41, 41, 125, 32, 45, 42, 51, 100, 32, 36, 102, 44, 36, 102, 44,
  123, 36, 102, 42, 97, 98, 115, 40, 36, 51, 42, 36, 49, 47, 49, 48,
  48, 41, 125, 10, 45, 105, 102, 32, 123, 36, 51, 62, 48, 125, 32, 45,
  114, 51, 100, 32, 49, 44, 48, 44, 48, 44, 49, 56, 48, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 51, 100, 32, 48, 44, 48, 44, 49, 44,
  36, 53, 32, 45, 114, 51, 100, 32, 49, 44, 48, 44, 48, 44, 36, 54,
  10, 45, 105, 102, 32, 36, 49, 54, 32, 123, 50, 42, 36, 77, 125, 44,
  123, 50, 42, 36, 77, 125, 44, 49, 44, 52, 44, 45, 49, 32, 45, 101,
  108, 115, 101, 32, 36, 77, 44, 36, 77, 44, 49, 44, 52, 44, 45, 49,
  32, 45, 101, 110, 100, 105, 102, 10, 102, 51, 100, 61, 123, 48, 46, 53,
  42, 119, 47, 116, 97, 110, 40, 36, 55, 42, 112, 105, 47, 51, 54, 48,
  41, 125, 32, 45, 102, 51, 100, 32, 36, 102, 51, 100, 10, 45, 108, 51,
  100, 32, 123, 36, 49, 48, 42, 36, 102, 51, 100, 125, 44, 123, 36, 49,
  49, 42, 36, 102, 51, 100, 125, 44, 123, 36, 49, 50, 42, 36, 102, 51,
  100, 125, 32, 45, 115, 108, 51, 100, 32, 36, 49, 51, 32, 45, 115, 115,
  51, 100, 32, 36, 49, 52, 10, 45, 111, 98, 106, 101, 99, 116, 51, 100,
  91, 45, 49, 93, 32, 91, 48, 93, 44, 36, 56, 37, 44, 36, 57, 37,
  44, 48, 44, 49, 44, 123, 105, 102, 40, 36, 49, 53, 44, 51, 44, 50,
  41, 125, 44, 48, 44, 49, 10, 45, 115, 104, 91, 45, 49, 93, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 43, 91, 45, 49, 93, 32,
  49, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 105, 102, 32, 36, 50, 48, 10, 91, 45, 49,
  93, 44, 91, 45, 49, 93, 44, 49, 44, 51, 44, 45, 49, 10, 45, 111,
  98, 106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 48, 93, 44,
  36, 56, 37, 44, 36, 57, 37, 44, 48, 44, 49, 44, 51, 44, 48, 44,
  49, 32, 45, 114, 109, 91, 48, 93, 10, 45, 103, 114, 97, 100, 105, 101,
  110, 116, 91, 45, 49, 93, 32, 120, 121, 44, 49, 32, 45, 43, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 110, 111, 114, 109, 91, 45, 49, 93, 32,
  45, 110, 101, 113, 91, 45, 49, 93, 32, 48, 10, 45, 45, 114, 91, 45,
  49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 51,
  10, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 48, 32, 45, 42, 91,
  45, 49, 93, 32, 36, 49, 55, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 115, 104, 91, 45, 49, 93, 32, 49, 44, 49, 32, 45, 42, 91, 45,
  49, 93, 32, 36, 49, 56, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  115, 104, 91, 45, 49, 93, 32, 50, 44, 50, 32, 45, 42, 91, 45, 49,
  93, 32, 36, 49, 57, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 106,
  91, 48, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 123, 36, 50, 48, 47, 50, 53, 53, 125, 44, 91, 45, 50, 93, 32,
  45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 108, 115, 101,
  32, 45, 114, 109, 91, 48, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 32, 48, 44,
  48, 44, 45, 49, 44, 45, 49, 44, 45, 49, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 48, 10, 45, 105, 102, 32, 36, 49, 54, 32, 45, 114, 32,
  53, 48, 37, 44, 53, 48, 37, 44, 49, 44, 52, 44, 50, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112,
  32, 51, 100, 32, 99, 111, 108, 111, 114, 101, 100, 32, 111, 98, 106, 101,
  99, 116, 32, 58, 32, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 101,
  100, 111, 98, 106, 101, 99, 116, 51, 100, 44, 32, 103, 105, 109, 112, 95,
  99, 111, 108, 111, 114, 101, 100, 111, 98, 106, 101, 99, 116, 51, 100, 95,
  112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 84, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 123, 49, 44, 34, 80, 108, 97, 110, 101, 34, 44, 34, 66, 111, 120,
  34, 44, 34, 80, 121, 114, 97, 109, 105, 100, 34, 44, 34, 69, 108, 108,
  105, 112, 115, 111, 105, 100, 34, 44, 34, 84, 111, 114, 117, 115, 34, 44,
  34, 71, 121, 114, 111, 105, 100, 34, 44, 34, 87, 101, 105, 114, 100, 34,
  44, 34, 67, 117, 112, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 49,
  50, 56, 44, 49, 50, 56, 44, 49, 50, 56, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 105, 122, 101, 45, 49, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 53, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 105, 122, 101, 45, 50, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 51, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 105, 122, 101, 45, 51, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 51, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 88, 45, 97, 110, 103, 108, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 53, 55, 44, 48, 44, 51, 54, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 97, 110, 103, 108,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 49, 44, 48, 44, 51,
  54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 45, 97,
  110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 49, 44,
  48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  70, 111, 118, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 53, 44, 49,
  44, 57, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45,
  108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 89, 45, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 90, 45, 108, 105, 103, 104, 116, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 45, 49, 48, 48, 44, 45, 49, 48,
  48, 44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112,
  101, 99, 117, 108, 97, 114, 32, 108, 105, 103, 104, 116, 110, 101, 115, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 101, 99, 117,
  108, 97, 114, 32, 115, 104, 105, 110, 105, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 55, 44, 48, 44, 51, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 110, 100, 101, 114, 105, 110,
  103, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 52, 44, 34, 68, 111,
  116, 115, 34, 44, 34, 87, 105, 114, 101, 102, 114, 97, 109, 101, 34, 44,
  34, 70, 108, 97, 116, 34, 44, 34, 70, 108, 97, 116, 32, 115, 104, 97,
  100, 101, 100, 34, 44, 34, 71, 111, 117, 114, 97, 117, 100, 34, 44, 34,
  80, 104, 111, 110, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32,
  60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112,
  101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48, 53, 47, 49, 54,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  95, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 101, 100, 111, 98, 106,
  101, 99, 116, 51, 100, 32, 58, 10, 45, 116, 111, 95, 114, 103, 98, 32,
  45, 95, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 101, 100, 111, 98,
  106, 101, 99, 116, 51, 100, 36, 49, 36, 50, 32, 36, 123, 54, 45, 56,
  125, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 36, 123, 51,
  45, 53, 125, 10, 45, 100, 98, 51, 100, 32, 48, 10, 103, 105, 109, 112,
  95, 99, 111, 108, 111, 114, 101, 100, 111, 98, 106, 101, 99, 116, 51, 100,
  32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 101,
  100, 111, 98, 106, 101, 99, 116, 51, 100, 32, 34, 95, 34, 44, 36, 123,
  49, 45, 52, 44, 54, 45, 56, 125, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 123, 64, 35, 45, 49, 125, 10, 45, 45, 103, 105, 109, 112, 95, 114,
  101, 110, 100, 101, 114, 51, 100, 91, 45, 49, 93, 32, 64, 123, 36, 62,
  44, 119, 125, 44, 64, 123, 36, 62, 44, 104, 125, 44, 36, 54, 44, 36,
  123, 57, 45, 45, 49, 125, 10, 45, 115, 104, 91, 45, 49, 93, 32, 51,
  44, 51, 32, 45, 42, 91, 45, 49, 93, 32, 123, 36, 53, 47, 50, 53,
  53, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 98, 108, 101, 110,
  100, 91, 36, 62, 44, 45, 49, 93, 32, 97, 108, 112, 104, 97, 10, 45,
  100, 111, 110, 101, 10, 45, 114, 109, 91, 45, 49, 93, 10, 103, 105, 109,
  112, 95, 99, 111, 108, 111, 114, 101, 100, 111, 98, 106, 101, 99, 116, 51,
  100, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 95, 103, 105,
  109, 112, 95, 99, 111, 108, 111, 114, 101, 100, 111, 98, 106, 101, 99, 116,
  51, 100, 32, 34, 95, 112, 114, 101, 118, 105, 101, 119, 95, 34, 44, 36,
  123, 49, 45, 52, 44, 54, 45, 56, 125, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 64, 35, 45, 49, 125, 10, 45, 45, 103, 105, 109, 112, 95,
  114, 101, 110, 100, 101, 114, 51, 100, 91, 45, 49, 93, 32, 64, 123, 36,
  62, 44, 119, 125, 44, 64, 123, 36, 62, 44, 104, 125, 44, 36, 54, 44,
  36, 123, 57, 45, 45, 49, 125, 10, 45, 115, 104, 91, 45, 49, 93, 32,
  51, 44, 51, 32, 45, 42, 91, 45, 49, 93, 32, 123, 36, 53, 47, 50,
  53, 53, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 98, 108, 101,
  110, 100, 91, 36, 62, 44, 45, 49, 93, 32, 97, 108, 112, 104, 97, 10,
  45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 45, 49, 93, 10, 95, 103,
  105, 109, 112, 95, 99, 111, 108, 111, 114, 101, 100, 111, 98, 106, 101, 99,
  116, 51, 100, 95, 48, 32, 58, 32, 45, 112, 108, 97, 110, 101, 51, 100,
  32, 49, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 36, 49, 44, 36,
  50, 44, 49, 10, 95, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 101,
  100, 111, 98, 106, 101, 99, 116, 51, 100, 95, 49, 32, 58, 32, 45, 98,
  111, 120, 51, 100, 32, 49, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32,
  36, 49, 44, 36, 50, 44, 36, 51, 10, 95, 103, 105, 109, 112, 95, 99,
  111, 108, 111, 114, 101, 100, 111, 98, 106, 101, 99, 116, 51, 100, 95, 50,
  32, 58, 32, 45, 112, 121, 114, 97, 109, 105, 100, 51, 100, 32, 49, 44,
  49, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50,
  44, 36, 51, 10, 95, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 101,
  100, 111, 98, 106, 101, 99, 116, 51, 100, 95, 51, 32, 58, 32, 45, 115,
  112, 104, 101, 114, 101, 51, 100, 32, 49, 32, 45, 42, 51, 100, 91, 45,
  49, 93, 32, 49, 44, 123, 50, 42, 36, 50, 125, 44, 123, 50, 42, 36,
  51, 125, 10, 95, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 101, 100,
  111, 98, 106, 101, 99, 116, 51, 100, 95, 52, 32, 58, 32, 45, 116, 111,
  114, 117, 115, 51, 100, 32, 36, 49, 44, 123, 36, 50, 47, 50, 125, 32,
  45, 42, 51, 100, 91, 45, 49, 93, 32, 36, 51, 44, 48, 46, 53, 44,
  48, 46, 53, 10, 95, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 101,
  100, 111, 98, 106, 101, 99, 116, 51, 100, 95, 53, 32, 58, 32, 45, 103,
  121, 114, 111, 105, 100, 51, 100, 32, 50, 52, 32, 45, 42, 51, 100, 91,
  45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 10, 95, 103, 105,
  109, 112, 95, 99, 111, 108, 111, 114, 101, 100, 111, 98, 106, 101, 99, 116,
  51, 100, 95, 54, 32, 58, 32, 45, 119, 101, 105, 114, 100, 51, 100, 32,
  51, 50, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 36, 49, 44, 36,
  50, 44, 36, 51, 10, 95, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114,
  101, 100, 111, 98, 106, 101, 99, 116, 51, 100, 95, 55, 32, 58, 32, 45,
  99, 117, 112, 51, 100, 32, 49, 50, 56, 32, 45, 42, 51, 100, 91, 45,
  49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 10, 95, 103, 105, 109,
  112, 95, 99, 111, 108, 111, 114, 101, 100, 111, 98, 106, 101, 99, 116, 51,
  100, 95, 112, 114, 101, 118, 105, 101, 119, 95, 48, 32, 58, 32, 45, 112,
  108, 97, 110, 101, 51, 100, 32, 49, 32, 45, 42, 51, 100, 91, 45, 49,
  93, 32, 36, 49, 44, 36, 50, 44, 49, 10, 95, 103, 105, 109, 112, 95,
  99, 111, 108, 111, 114, 101, 100, 111, 98, 106, 101, 99, 116, 51, 100, 95,
  112, 114, 101, 118, 105, 101, 119, 95, 49, 32, 58, 32, 45, 98, 111, 120,
  51, 100, 32, 49, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 36, 49,
  44, 36, 50, 44, 36, 51, 10, 95, 103, 105, 109, 112, 95, 99, 111, 108,
  111, 114, 101, 100, 111, 98, 106, 101, 99, 116, 51, 100, 95, 112, 114, 101,
  118, 105, 101, 119, 95, 50, 32, 58, 32, 45, 112, 121, 114, 97, 109, 105,
  100, 51, 100, 32, 49, 44, 49, 32, 45, 42, 51, 100, 91, 45, 49, 93,
  32, 36, 49, 44, 36, 50, 44, 36, 51, 10, 95, 103, 105, 109, 112, 95,
  99, 111, 108, 111, 114, 101, 100, 111, 98, 106, 101, 99, 116, 51, 100, 95,
  112, 114, 101, 118, 105, 101, 119, 95, 51, 32, 58, 32, 45, 115, 112, 104,
  101, 114, 101, 51, 100, 32, 49, 32, 45, 42, 51, 100, 91, 45, 49, 93,
  32, 49, 44, 123, 50, 42, 36, 50, 125, 44, 123, 50, 42, 36, 51, 125,
  10, 95, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114, 101, 100, 111, 98,
  106, 101, 99, 116, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 95, 52,
  32, 58, 32, 45, 116, 111, 114, 117, 115, 51, 100, 32, 36, 49, 44, 123,
  36, 50, 47, 50, 125, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 36,
  51, 44, 48, 46, 53, 44, 48, 46, 53, 10, 95, 103, 105, 109, 112, 95,
  99, 111, 108, 111, 114, 101, 100, 111, 98, 106, 101, 99, 116, 51, 100, 95,
  112, 114, 101, 118, 105, 101, 119, 95, 53, 32, 58, 32, 45, 103, 121, 114,
  111, 105, 100, 51, 100, 32, 56, 32, 45, 42, 51, 100, 91, 45, 49, 93,
  32, 36, 49, 44, 36, 50, 44, 36, 51, 10, 95, 103, 105, 109, 112, 95,
  99, 111, 108, 111, 114, 101, 100, 111, 98, 106, 101, 99, 116, 51, 100, 95,
  112, 114, 101, 118, 105, 101, 119, 95, 54, 32, 58, 32, 45, 119, 101, 105,
  114, 100, 51, 100, 32, 49, 50, 32, 45, 42, 51, 100, 91, 45, 49, 93,
  32, 36, 49, 44, 36, 50, 44, 36, 51, 10, 95, 103, 105, 109, 112, 95,
  99, 111, 108, 111, 114, 101, 100, 111, 98, 106, 101, 99, 116, 51, 100, 95,
  112, 114, 101, 118, 105, 101, 119, 95, 55, 32, 58, 32, 45, 99, 117, 112,
  51, 100, 32, 54, 52, 32, 45, 42, 51, 100, 91, 45, 49, 93, 32, 36,
  49, 44, 36, 50, 44, 36, 51, 10, 35, 64, 103, 105, 109, 112, 32, 51,
  100, 32, 101, 108, 101, 118, 97, 116, 105, 111, 110, 32, 58, 32, 103, 105,
  109, 112, 95, 101, 108, 101, 118, 97, 116, 105, 111, 110, 51, 100, 44, 32,
  103, 105, 109, 112, 95, 101, 108, 101, 118, 97, 116, 105, 111, 110, 51, 100,
  95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 70, 97, 99, 116, 111, 114, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 48, 48, 44, 45, 49, 48, 48, 48, 44, 49, 48,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 87, 105, 100, 116,
  104, 32, 61, 32, 95, 105, 110, 116, 40, 49, 48, 50, 52, 44, 56, 44,
  52, 48, 57, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72,
  101, 105, 103, 104, 116, 32, 61, 32, 95, 105, 110, 116, 40, 49, 48, 50,
  52, 44, 56, 44, 52, 48, 57, 54, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 56, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 45, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 50, 53, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 89, 45, 97, 110, 103, 108, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 90, 45, 97, 110, 103, 108, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 50, 49, 44, 48, 44, 51, 54, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 111, 118, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 52, 53, 44, 49, 44, 57, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 108, 105, 103, 104, 116, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 48, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 108,
  105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45,
  49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 90, 45, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 45, 49, 48, 48, 44, 45, 49, 48, 48, 44, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 101, 99, 117, 108, 97, 114,
  32, 108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 112, 101, 99, 117, 108, 97, 114, 32, 115, 104,
  105, 110, 105, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 55, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 82, 101, 110, 100, 101, 114, 105, 110, 103, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 50, 44, 34, 68, 111, 116, 115, 34, 44, 34, 87,
  105, 114, 101, 102, 114, 97, 109, 101, 34, 44, 34, 70, 108, 97, 116, 34,
  44, 34, 70, 108, 97, 116, 32, 115, 104, 97, 100, 101, 100, 34, 44, 34,
  71, 111, 117, 114, 97, 117, 100, 34, 44, 34, 80, 104, 111, 110, 103, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 115, 109, 97, 108,
  108, 62, 60, 98, 62, 78, 111, 116, 101, 58, 60, 47, 98, 62, 32, 65,
  100, 100, 32, 97, 32, 116, 111, 112, 32, 108, 97, 121, 101, 114, 32, 116,
  111, 32, 100, 101, 102, 105, 110, 101, 32, 111, 98, 106, 101, 99, 116, 32,
  116, 101, 120, 116, 117, 114, 101, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 95, 103, 105, 109, 112,
  95, 101, 108, 101, 118, 97, 116, 105, 111, 110, 51, 100, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 47, 50, 125, 32, 45, 108,
  91, 36, 62, 44, 123, 109, 105, 110, 40, 36, 62, 43, 49, 44, 64, 35,
  45, 49, 41, 125, 93, 10, 45, 105, 102, 32, 123, 64, 35, 61, 61, 49,
  125, 32, 45, 45, 110, 111, 114, 109, 32, 45, 101, 108, 115, 101, 32, 45,
  114, 91, 49, 93, 32, 91, 48, 93, 44, 51, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 110, 91, 49, 93, 32, 48, 44, 36, 49, 32, 45, 98, 91,
  49, 93, 32, 36, 50, 10, 45, 101, 108, 101, 118, 97, 116, 105, 111, 110,
  51, 100, 91, 48, 93, 32, 91, 49, 93, 32, 45, 114, 109, 91, 49, 93,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 100, 98,
  51, 100, 10, 103, 105, 109, 112, 95, 101, 108, 101, 118, 97, 116, 105, 111,
  110, 51, 100, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 101, 108, 101,
  118, 97, 116, 105, 111, 110, 51, 100, 32, 36, 123, 49, 45, 50, 125, 32,
  45, 103, 105, 109, 112, 95, 114, 101, 110, 100, 101, 114, 51, 100, 32, 36,
  123, 51, 45, 45, 49, 125, 10, 103, 105, 109, 112, 95, 101, 108, 101, 118,
  97, 116, 105, 111, 110, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 101, 108, 101, 118, 97, 116, 105, 111,
  110, 51, 100, 32, 36, 123, 49, 45, 50, 125, 44, 123, 119, 125, 44, 123,
  104, 125, 44, 36, 123, 53, 45, 45, 49, 125, 10, 35, 64, 103, 105, 109,
  112, 32, 51, 100, 32, 101, 120, 116, 114, 117, 115, 105, 111, 110, 32, 58,
  32, 103, 105, 109, 112, 95, 101, 120, 116, 114, 117, 100, 101, 51, 100, 44,
  32, 103, 105, 109, 112, 95, 101, 120, 116, 114, 117, 100, 101, 51, 100, 95,
  112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 68, 101, 112, 116, 104, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 48, 44, 49, 44, 49, 48, 50, 52, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110,
  32, 61, 32, 105, 110, 116, 40, 53, 49, 50, 44, 49, 44, 49, 48, 50,
  52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  46, 54, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 87, 105, 100, 116,
  104, 32, 61, 32, 95, 105, 110, 116, 40, 49, 48, 50, 52, 44, 49, 44,
  52, 48, 57, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72,
  101, 105, 103, 104, 116, 32, 61, 32, 95, 105, 110, 116, 40, 49, 48, 50,
  52, 44, 49, 44, 52, 48, 57, 54, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 53, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 45, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 53, 55, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 89, 45, 97, 110, 103, 108, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 52, 49, 44, 48, 44, 51, 54, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 90, 45, 97, 110, 103, 108, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 50, 49, 44, 48, 44, 51, 54, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 111, 118, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 52, 53, 44, 49, 44, 57, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 108, 105, 103, 104, 116,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 48, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45,
  108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 90, 45, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 45, 49, 48, 48, 44, 45, 49, 48, 48, 44, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 101, 99, 117, 108, 97,
  114, 32, 108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 112, 101, 99, 117, 108, 97, 114, 32, 115,
  104, 105, 110, 105, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 55, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 82, 101, 110, 100, 101, 114, 105, 110, 103, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 52, 44, 34, 68, 111, 116, 115, 34, 44, 34,
  87, 105, 114, 101, 102, 114, 97, 109, 101, 34, 44, 34, 70, 108, 97, 116,
  34, 44, 34, 70, 108, 97, 116, 32, 115, 104, 97, 100, 101, 100, 34, 44,
  34, 71, 111, 117, 114, 97, 117, 100, 34, 44, 34, 80, 104, 111, 110, 103,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 115, 109, 97,
  108, 108, 62, 60, 98, 62, 78, 111, 116, 101, 58, 60, 47, 98, 62, 32,
  65, 100, 100, 32, 97, 32, 116, 111, 112, 32, 108, 97, 121, 101, 114, 32,
  116, 111, 32, 100, 101, 102, 105, 110, 101, 32, 111, 98, 106, 101, 99, 116,
  32, 116, 101, 120, 116, 117, 114, 101, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68,
  97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38,
  35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 95, 103, 105, 109,
  112, 95, 101, 120, 116, 114, 117, 100, 101, 51, 100, 32, 58, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 123, 64, 35, 47, 50, 125, 32, 45, 108, 91,
  36, 62, 44, 123, 109, 105, 110, 40, 36, 62, 43, 49, 44, 64, 35, 45,
  49, 41, 125, 93, 10, 45, 101, 120, 116, 114, 117, 100, 101, 51, 100, 91,
  45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 37, 10, 45, 105,
  102, 32, 123, 64, 35, 61, 61, 50, 125, 32, 45, 116, 51, 100, 91, 45,
  49, 93, 32, 91, 45, 50, 93, 32, 45, 114, 109, 91, 45, 50, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 45, 100, 98, 51, 100, 32, 48, 10, 103, 105, 109, 112, 95,
  101, 120, 116, 114, 117, 100, 101, 51, 100, 32, 58, 10, 45, 95, 103, 105,
  109, 112, 95, 101, 120, 116, 114, 117, 100, 101, 51, 100, 32, 36, 123, 49,
  45, 51, 125, 32, 45, 103, 105, 109, 112, 95, 114, 101, 110, 100, 101, 114,
  51, 100, 32, 36, 123, 52, 45, 45, 49, 125, 10, 103, 105, 109, 112, 95,
  101, 120, 116, 114, 117, 100, 101, 51, 100, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 101, 120, 116, 114, 117, 100,
  101, 51, 100, 32, 36, 123, 49, 45, 51, 125, 44, 123, 119, 125, 44, 123,
  104, 125, 44, 36, 123, 54, 45, 45, 49, 125, 10, 35, 64, 103, 105, 109,
  112, 32, 51, 100, 32, 105, 109, 97, 103, 101, 32, 111, 98, 106, 101, 99,
  116, 32, 58, 32, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98,
  106, 101, 99, 116, 51, 100, 44, 32, 103, 105, 109, 112, 95, 105, 109, 97,
  103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 95, 112, 114, 101, 118, 105,
  101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 123, 49, 44, 34,
  80, 108, 97, 110, 101, 34, 44, 34, 67, 117, 98, 101, 34, 44, 34, 80,
  121, 114, 97, 109, 105, 100, 34, 44, 34, 83, 112, 104, 101, 114, 101, 34,
  44, 34, 84, 111, 114, 117, 115, 34, 44, 34, 71, 121, 114, 111, 105, 100,
  34, 44, 34, 87, 101, 105, 114, 100, 34, 44, 34, 67, 117, 112, 34, 44,
  34, 82, 117, 98, 105, 107, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 87, 105, 100,
  116, 104, 32, 61, 32, 95, 105, 110, 116, 40, 49, 48, 50, 52, 44, 49,
  44, 52, 48, 57, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  72, 101, 105, 103, 104, 116, 32, 61, 32, 95, 105, 110, 116, 40, 49, 48,
  50, 52, 44, 49, 44, 52, 48, 57, 54, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 53, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 88, 45, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 53, 55, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 89, 45, 97, 110, 103, 108, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 52, 49, 44, 48, 44, 51, 54, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 45, 97, 110, 103, 108, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 49, 44, 48, 44, 51, 54,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 111, 118, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 52, 53, 44, 49, 44, 57, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 108, 105, 103, 104,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 48, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89,
  45, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 90, 45, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 45, 49, 48, 48, 44, 45, 49, 48, 48, 44, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 101, 99, 117, 108,
  97, 114, 32, 108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 112, 101, 99, 117, 108, 97, 114, 32,
  115, 104, 105, 110, 105, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 55, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 82, 101, 110, 100, 101, 114, 105, 110, 103, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 52, 44, 34, 68, 111, 116, 115, 34, 44,
  34, 87, 105, 114, 101, 102, 114, 97, 109, 101, 34, 44, 34, 70, 108, 97,
  116, 34, 44, 34, 70, 108, 97, 116, 32, 115, 104, 97, 100, 101, 100, 34,
  44, 34, 71, 111, 117, 114, 97, 117, 100, 34, 44, 34, 80, 104, 111, 110,
  103, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68,
  97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38,
  35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 95, 103, 105, 109,
  112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 32,
  58, 10, 45, 116, 111, 95, 114, 103, 98, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 95, 103, 105,
  109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100,
  36, 49, 36, 50, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 45, 100, 98, 51, 100, 32, 48, 10, 103, 105, 109, 112, 95, 105, 109,
  97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 32, 58, 10, 45, 95,
  103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116,
  51, 100, 32, 34, 95, 34, 44, 36, 49, 32, 45, 103, 105, 109, 112, 95,
  114, 101, 110, 100, 101, 114, 51, 100, 32, 36, 123, 50, 45, 45, 49, 125,
  10, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99,
  116, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 119, 61,
  123, 119, 125, 32, 104, 61, 123, 104, 125, 32, 45, 95, 103, 105, 109, 112,
  95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 32, 34,
  95, 112, 114, 101, 118, 105, 101, 119, 95, 34, 44, 36, 49, 32, 45, 103,
  105, 109, 112, 95, 114, 101, 110, 100, 101, 114, 51, 100, 32, 36, 119, 44,
  36, 104, 44, 36, 123, 52, 45, 45, 49, 125, 10, 95, 103, 105, 109, 112,
  95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 95, 48,
  32, 58, 32, 45, 105, 109, 97, 103, 101, 112, 108, 97, 110, 101, 51, 100,
  10, 95, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101,
  99, 116, 51, 100, 95, 49, 32, 58, 32, 45, 105, 109, 97, 103, 101, 99,
  117, 98, 101, 51, 100, 10, 95, 103, 105, 109, 112, 95, 105, 109, 97, 103,
  101, 111, 98, 106, 101, 99, 116, 51, 100, 95, 50, 32, 58, 32, 45, 105,
  109, 97, 103, 101, 112, 121, 114, 97, 109, 105, 100, 51, 100, 10, 95, 103,
  105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51,
  100, 95, 51, 32, 58, 32, 45, 105, 109, 97, 103, 101, 115, 112, 104, 101,
  114, 101, 51, 100, 32, 54, 52, 44, 51, 50, 10, 95, 103, 105, 109, 112,
  95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 95, 52,
  32, 58, 32, 45, 116, 111, 114, 117, 115, 51, 100, 32, 49, 48, 48, 44,
  51, 48, 32, 45, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  32, 45, 114, 109, 91, 45, 50, 93, 10, 95, 103, 105, 109, 112, 95, 105,
  109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 95, 53, 32, 58,
  32, 45, 103, 121, 114, 111, 105, 100, 51, 100, 32, 50, 52, 32, 45, 116,
  51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 114, 109, 91,
  45, 50, 93, 10, 95, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111,
  98, 106, 101, 99, 116, 51, 100, 95, 54, 32, 58, 32, 45, 119, 101, 105,
  114, 100, 51, 100, 32, 51, 50, 32, 45, 116, 51, 100, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 32, 45, 114, 109, 91, 45, 50, 93, 10, 95, 103,
  105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51,
  100, 95, 55, 32, 58, 32, 45, 99, 117, 112, 51, 100, 32, 49, 50, 56,
  32, 45, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45,
  114, 109, 91, 45, 50, 93, 10, 95, 103, 105, 109, 112, 95, 105, 109, 97,
  103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 95, 56, 32, 58, 32, 45,
  105, 109, 97, 103, 101, 114, 117, 98, 105, 107, 51, 100, 32, 53, 44, 53,
  10, 95, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101,
  99, 116, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 95, 48, 32, 58,
  32, 45, 105, 109, 97, 103, 101, 112, 108, 97, 110, 101, 51, 100, 10, 95,
  103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116,
  51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 95, 49, 32, 58, 32, 45,
  105, 109, 97, 103, 101, 99, 117, 98, 101, 51, 100, 10, 95, 103, 105, 109,
  112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 95,
  112, 114, 101, 118, 105, 101, 119, 95, 50, 32, 58, 32, 45, 105, 109, 97,
  103, 101, 112, 121, 114, 97, 109, 105, 100, 51, 100, 10, 95, 103, 105, 109,
  112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 95,
  112, 114, 101, 118, 105, 101, 119, 95, 51, 32, 58, 32, 45, 105, 109, 97,
  103, 101, 115, 112, 104, 101, 114, 101, 51, 100, 32, 49, 54, 44, 56, 10,
  95, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99,
  116, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 95, 52, 32, 58, 32,
  45, 116, 111, 114, 117, 115, 51, 100, 32, 49, 48, 48, 44, 51, 48, 32,
  45, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 114,
  109, 91, 45, 50, 93, 10, 95, 103, 105, 109, 112, 95, 105, 109, 97, 103,
  101, 111, 98, 106, 101, 99, 116, 51, 100, 95, 112, 114, 101, 118, 105, 101,
  119, 95, 53, 32, 58, 32, 45, 103, 121, 114, 111, 105, 100, 51, 100, 32,
  56, 32, 45, 99, 51, 100, 91, 45, 49, 93, 32, 45, 110, 51, 100, 91,
  45, 49, 93, 32, 45, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50,
  93, 32, 45, 114, 109, 91, 45, 50, 93, 10, 95, 103, 105, 109, 112, 95,
  105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 95, 112, 114,
  101, 118, 105, 101, 119, 95, 54, 32, 58, 32, 45, 119, 101, 105, 114, 100,
  51, 100, 32, 49, 50, 32, 45, 116, 51, 100, 91, 45, 49, 93, 32, 91,
  45, 50, 93, 32, 45, 114, 109, 91, 45, 50, 93, 10, 95, 103, 105, 109,
  112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 95,
  112, 114, 101, 118, 105, 101, 119, 95, 55, 32, 58, 32, 45, 99, 117, 112,
  51, 100, 32, 54, 52, 32, 45, 116, 51, 100, 91, 45, 49, 93, 32, 91,
  45, 50, 93, 32, 45, 114, 109, 91, 45, 50, 93, 10, 95, 103, 105, 109,
  112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 95,
  112, 114, 101, 118, 105, 101, 119, 95, 56, 32, 58, 32, 45, 105, 109, 97,
  103, 101, 114, 117, 98, 105, 107, 51, 100, 32, 51, 44, 51, 44, 53, 44,
  53, 10, 35, 64, 103, 105, 109, 112, 32, 51, 100, 32, 108, 97, 116, 104,
  105, 110, 103, 32, 58, 32, 103, 105, 109, 112, 95, 108, 97, 116, 104, 105,
  110, 103, 51, 100, 44, 32, 103, 105, 109, 112, 95, 108, 97, 116, 104, 105,
  110, 103, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 115, 111, 108, 117, 116,
  105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 55, 54, 44, 49, 44, 49,
  48, 50, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 54, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 77, 97, 120, 32, 97, 110, 103, 108, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 51, 54, 49, 44, 48, 44, 51, 54, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 87, 105, 100, 116, 104, 32, 61, 32, 95, 105, 110, 116,
  40, 49, 48, 50, 52, 44, 49, 44, 52, 48, 57, 54, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 72, 101, 105, 103, 104, 116, 32, 61, 32,
  95, 105, 110, 116, 40, 49, 48, 50, 52, 44, 49, 44, 52, 48, 57, 54,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 105, 122, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 51, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 97, 110, 103, 108,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 55, 44, 48, 44, 51,
  54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 97,
  110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 49, 44,
  48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  90, 45, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  50, 49, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 70, 111, 118, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52,
  53, 44, 49, 44, 57, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 88, 45, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 89, 45, 108, 105, 103, 104, 116, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 45, 108, 105, 103,
  104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 45, 49, 48, 48, 44,
  45, 49, 48, 48, 44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 112, 101, 99, 117, 108, 97, 114, 32, 108, 105, 103, 104, 116, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44,
  48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112,
  101, 99, 117, 108, 97, 114, 32, 115, 104, 105, 110, 105, 110, 101, 115, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 44, 48, 44, 51,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 110, 100, 101,
  114, 105, 110, 103, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 52, 44,
  34, 68, 111, 116, 115, 34, 44, 34, 87, 105, 114, 101, 102, 114, 97, 109,
  101, 34, 44, 34, 70, 108, 97, 116, 34, 44, 34, 70, 108, 97, 116, 32,
  115, 104, 97, 100, 101, 100, 34, 44, 34, 71, 111, 117, 114, 97, 117, 100,
  34, 44, 34, 80, 104, 111, 110, 103, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 123, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 78, 111,
  116, 101, 58, 60, 47, 98, 62, 32, 65, 100, 100, 32, 97, 32, 116, 111,
  112, 32, 108, 97, 121, 101, 114, 32, 116, 111, 32, 100, 101, 102, 105, 110,
  101, 32, 111, 98, 106, 101, 99, 116, 32, 116, 101, 120, 116, 117, 114, 101,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 125, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49,
  50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 95, 103, 105, 109, 112, 95, 108, 97, 116, 104, 105, 110,
  103, 51, 100, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64,
  35, 47, 50, 125, 32, 45, 108, 91, 36, 62, 44, 123, 109, 105, 110, 40,
  36, 62, 43, 49, 44, 64, 35, 45, 49, 41, 125, 93, 10, 45, 108, 97,
  116, 104, 101, 51, 100, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 37,
  44, 36, 51, 10, 45, 105, 102, 32, 123, 64, 35, 61, 61, 50, 125, 32,
  45, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 114,
  109, 91, 45, 50, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 100, 98, 51, 100, 32, 48,
  10, 103, 105, 109, 112, 95, 108, 97, 116, 104, 105, 110, 103, 51, 100, 32,
  58, 10, 45, 95, 103, 105, 109, 112, 95, 108, 97, 116, 104, 105, 110, 103,
  51, 100, 32, 36, 123, 49, 45, 51, 125, 32, 45, 103, 105, 109, 112, 95,
  114, 101, 110, 100, 101, 114, 51, 100, 32, 36, 123, 52, 45, 45, 49, 125,
  10, 103, 105, 109, 112, 95, 108, 97, 116, 104, 105, 110, 103, 51, 100, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  108, 97, 116, 104, 105, 110, 103, 51, 100, 32, 36, 123, 49, 45, 51, 125,
  44, 123, 119, 125, 44, 123, 104, 125, 44, 36, 123, 54, 45, 45, 49, 125,
  10, 35, 64, 103, 105, 109, 112, 32, 51, 100, 32, 114, 97, 110, 100, 111,
  109, 32, 111, 98, 106, 101, 99, 116, 115, 32, 58, 32, 103, 105, 109, 112,
  95, 114, 97, 110, 100, 111, 109, 51, 100, 44, 32, 103, 105, 109, 112, 95,
  114, 97, 110, 100, 111, 109, 51, 100, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 84, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 67, 117, 98, 101, 34, 44, 34, 67, 111, 110, 101, 34,
  44, 34, 67, 121, 108, 105, 110, 100, 101, 114, 34, 44, 34, 83, 112, 104,
  101, 114, 101, 34, 44, 34, 84, 111, 114, 117, 115, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 68, 101, 110, 115, 105, 116, 121, 32, 61,
  32, 105, 110, 116, 40, 53, 48, 44, 49, 44, 51, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 51, 44, 49, 44, 50, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 90, 45, 114, 97, 110, 103, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 48, 48, 44, 48, 44, 51, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 111, 118, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 52, 53, 44, 49, 44, 57, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 108, 105, 103, 104, 116, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 48, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 108,
  105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45,
  49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 90, 45, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 45, 49, 48, 48, 44, 45, 49, 48, 48, 44, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 101, 99, 117, 108, 97, 114,
  32, 108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 112, 101, 99, 117, 108, 97, 114, 32, 115, 104,
  105, 110, 105, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 55, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 82, 101, 110, 100, 101, 114, 105, 110, 103, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 51, 44, 34, 68, 111, 116, 115, 34, 44, 34, 87,
  105, 114, 101, 102, 114, 97, 109, 101, 34, 44, 34, 70, 108, 97, 116, 34,
  44, 34, 70, 108, 97, 116, 32, 115, 104, 97, 100, 101, 100, 34, 44, 34,
  71, 111, 117, 114, 97, 117, 100, 34, 44, 34, 80, 104, 111, 110, 103, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105,
  116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118,
  105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50,
  51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62,
  50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 114,
  97, 110, 100, 111, 109, 51, 100, 32, 58, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 102, 51, 100, 61,
  123, 48, 46, 53, 42, 109, 97, 120, 40, 119, 44, 104, 41, 47, 116, 97,
  110, 40, 36, 53, 42, 112, 105, 47, 51, 54, 48, 41, 125, 32, 45, 102,
  51, 100, 32, 36, 102, 51, 100, 32, 45, 108, 51, 100, 32, 123, 36, 54,
  42, 36, 102, 51, 100, 125, 44, 123, 36, 55, 42, 36, 102, 51, 100, 125,
  44, 123, 36, 56, 42, 36, 102, 51, 100, 125, 32, 45, 115, 108, 51, 100,
  32, 36, 57, 32, 45, 115, 115, 51, 100, 32, 36, 49, 48, 10, 45, 116,
  111, 95, 114, 103, 98, 32, 40, 123, 119, 125, 44, 123, 104, 125, 44, 123,
  100, 125, 44, 123, 115, 125, 41, 32, 45, 47, 91, 45, 49, 93, 32, 50,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 50, 10, 40, 64, 123, 49,
  44, 48, 125, 41, 32, 45, 43, 91, 45, 49, 93, 32, 64, 123, 49, 44,
  49, 125, 32, 45, 42, 91, 45, 49, 93, 32, 36, 51, 32, 45, 47, 91,
  45, 49, 93, 32, 49, 48, 48, 32, 45, 95, 103, 105, 109, 112, 95, 114,
  97, 110, 100, 111, 109, 51, 100, 36, 49, 32, 64, 45, 49, 32, 45, 114,
  109, 91, 45, 50, 93, 10, 45, 114, 51, 100, 91, 45, 49, 93, 32, 49,
  44, 49, 44, 48, 44, 123, 63, 40, 48, 44, 51, 54, 48, 41, 125, 10,
  40, 123, 63, 40, 45, 49, 44, 49, 41, 125, 41, 32, 45, 42, 91, 45,
  49, 93, 32, 64, 123, 49, 44, 48, 125, 32, 40, 123, 63, 40, 45, 49,
  44, 49, 41, 125, 41, 32, 45, 42, 91, 45, 49, 93, 32, 64, 123, 49,
  44, 49, 125, 10, 45, 43, 51, 100, 91, 45, 51, 93, 32, 64, 45, 50,
  44, 64, 45, 49, 44, 123, 63, 40, 45, 36, 52, 44, 36, 52, 41, 125,
  32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 99, 111, 108,
  51, 100, 91, 45, 49, 93, 32, 123, 63, 40, 50, 53, 53, 41, 125, 44,
  123, 63, 40, 50, 53, 53, 41, 125, 44, 123, 63, 40, 50, 53, 53, 41,
  125, 32, 45, 100, 111, 110, 101, 32, 45, 43, 51, 100, 91, 50, 45, 45,
  49, 93, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 48, 93, 32,
  91, 45, 49, 93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 36,
  49, 50, 44, 36, 49, 49, 44, 48, 44, 49, 10, 45, 107, 91, 48, 93,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 95, 103, 105,
  109, 112, 95, 114, 97, 110, 100, 111, 109, 51, 100, 48, 32, 58, 32, 45,
  98, 111, 120, 51, 100, 32, 36, 49, 10, 95, 103, 105, 109, 112, 95, 114,
  97, 110, 100, 111, 109, 51, 100, 49, 32, 58, 32, 40, 36, 49, 41, 32,
  45, 47, 91, 45, 49, 93, 32, 50, 32, 45, 99, 111, 110, 101, 51, 100,
  32, 64, 45, 49, 44, 36, 49, 32, 45, 114, 109, 91, 45, 50, 93, 10,
  95, 103, 105, 109, 112, 95, 114, 97, 110, 100, 111, 109, 51, 100, 50, 32,
  58, 32, 40, 36, 49, 41, 32, 45, 47, 91, 45, 49, 93, 32, 50, 32,
  45, 99, 121, 108, 105, 110, 100, 101, 114, 51, 100, 32, 64, 45, 49, 44,
  36, 49, 32, 45, 114, 109, 91, 45, 50, 93, 10, 95, 103, 105, 109, 112,
  95, 114, 97, 110, 100, 111, 109, 51, 100, 51, 32, 58, 32, 45, 115, 112,
  104, 101, 114, 101, 51, 100, 32, 36, 49, 44, 50, 10, 95, 103, 105, 109,
  112, 95, 114, 97, 110, 100, 111, 109, 51, 100, 52, 32, 58, 32, 40, 36,
  49, 41, 32, 45, 47, 91, 45, 49, 93, 32, 51, 32, 45, 116, 111, 114,
  117, 115, 51, 100, 32, 36, 49, 44, 64, 45, 49, 32, 45, 114, 109, 91,
  45, 50, 93, 10, 35, 64, 103, 105, 109, 112, 32, 66, 97, 108, 108, 32,
  58, 32, 103, 105, 109, 112, 95, 98, 97, 108, 108, 44, 32, 103, 105, 109,
  112, 95, 98, 97, 108, 108, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 100, 105, 117,
  115, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 49, 44, 49, 48,
  50, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 101,
  99, 117, 108, 97, 114, 32, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 56, 44, 48, 44, 56, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 112, 101, 99, 117, 108, 97, 114, 32, 115,
  105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44,
  56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 100,
  111, 119, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 53, 44, 48,
  44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108,
  111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 48,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105,
  62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114,
  108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 51, 47, 49, 49, 47, 50, 55, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 98, 97, 108, 108, 32, 58, 10, 45, 98, 97, 108, 108, 32,
  36, 49, 44, 36, 123, 53, 45, 55, 125, 44, 36, 123, 50, 45, 52, 125,
  32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 10, 103, 105, 109, 112, 95,
  98, 97, 108, 108, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 98, 97, 108, 108, 32, 36, 42, 10, 45, 105, 102,
  32, 123, 64, 35, 62, 49, 125, 32, 45, 98, 108, 101, 110, 100, 91, 45,
  50, 44, 45, 49, 93, 32, 97, 108, 112, 104, 97, 44, 49, 44, 49, 32,
  45, 101, 110, 100, 105, 102, 10, 35, 64, 103, 105, 109, 112, 32, 67, 117,
  112, 105, 100, 32, 58, 32, 103, 105, 109, 112, 95, 99, 117, 112, 105, 100,
  44, 32, 103, 105, 109, 112, 95, 99, 117, 112, 105, 100, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32,
  61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 48, 44, 48, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 51, 47, 49, 49, 47, 49, 51, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 99, 117, 112, 105, 100, 32, 58, 10, 45, 105, 102, 32, 123, 64,
  35, 62, 48, 125, 32, 115, 105, 122, 61, 123, 109, 105, 110, 40, 64, 123,
  45, 109, 105, 110, 95, 119, 125, 44, 64, 123, 45, 109, 105, 110, 95, 104,
  125, 41, 125, 32, 45, 101, 108, 115, 101, 32, 115, 105, 122, 61, 53, 49,
  50, 32, 45, 101, 110, 100, 105, 102, 10, 45, 99, 117, 112, 105, 100, 32,
  36, 115, 105, 122, 32, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49,
  93, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114,
  91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 50,
  53, 53, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 48, 10, 45, 114,
  101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93,
  32, 48, 44, 48, 44, 49, 44, 49, 44, 49, 44, 50, 53, 53, 44, 36,
  50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 10, 45, 102, 114, 97, 109,
  101, 91, 45, 49, 93, 32, 123, 50, 46, 53, 42, 36, 49, 125, 37, 44,
  123, 50, 46, 53, 42, 36, 49, 125, 37, 44, 36, 50, 44, 36, 51, 44,
  36, 52, 44, 48, 32, 45, 98, 91, 45, 49, 93, 32, 36, 49, 37, 10,
  45, 98, 108, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 97, 108,
  112, 104, 97, 10, 35, 64, 103, 105, 109, 112, 32, 69, 113, 117, 97, 116,
  105, 111, 110, 32, 112, 108, 111, 116, 32, 91, 112, 97, 114, 97, 109, 101,
  116, 114, 105, 99, 93, 32, 58, 32, 103, 105, 109, 112, 95, 101, 113, 117,
  97, 116, 105, 111, 110, 95, 112, 97, 114, 97, 109, 101, 116, 114, 105, 99,
  44, 32, 103, 105, 109, 112, 95, 101, 113, 117, 97, 116, 105, 111, 110, 95,
  112, 97, 114, 97, 109, 101, 116, 114, 105, 99, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 88, 40, 116, 41, 32, 61, 32, 116, 101, 120, 116, 123,
  34, 115, 105, 110, 40, 116, 41, 42, 40, 101, 120, 112, 40, 99, 111, 115,
  40, 116, 41, 41, 45, 50, 42, 99, 111, 115, 40, 52, 42, 116, 41, 45,
  115, 105, 110, 40, 116, 47, 49, 50, 41, 94, 53, 41, 34, 125, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 89, 40, 116, 41, 32, 61, 32, 116,
  101, 120, 116, 123, 34, 99, 111, 115, 40, 116, 41, 42, 40, 101, 120, 112,
  40, 99, 111, 115, 40, 116, 41, 41, 45, 50, 42, 99, 111, 115, 40, 52,
  42, 116, 41, 45, 115, 105, 110, 40, 116, 47, 49, 50, 41, 94, 53, 41,
  34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 105, 110, 45,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 48, 48,
  48, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 77, 97, 120, 45, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  48, 48, 44, 45, 49, 48, 48, 48, 44, 49, 48, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 115, 111, 108, 117, 116, 105,
  111, 110, 32, 61, 32, 105, 110, 116, 40, 52, 48, 57, 54, 44, 50, 44,
  51, 50, 55, 54, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  79, 117, 116, 108, 105, 110, 101, 32, 111, 112, 97, 99, 105, 116, 121, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 111, 116, 32, 115, 105, 122, 101,
  32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 49, 54, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 116, 97, 114, 116, 32, 99, 111,
  108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 54, 52, 44, 48,
  44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 110, 100,
  32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 49,
  50, 56, 44, 48, 44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 111, 108, 111, 114, 101, 100, 32, 111, 117, 116, 108, 105, 110, 101,
  32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 110, 116, 105, 97, 108, 105, 97, 115, 105, 110, 103,
  32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 68, 101, 99, 111, 114, 97, 116, 105, 111, 110, 32, 61,
  32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109,
  112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 49, 49, 47, 49,
  51, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 103, 105, 109, 112, 95, 101, 113, 117, 97, 116, 105, 111, 110, 95, 112,
  97, 114, 97, 109, 101, 116, 114, 105, 99, 32, 58, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 61,
  123, 119, 125, 32, 104, 61, 123, 104, 125, 32, 45, 114, 109, 10, 36, 53,
  44, 49, 44, 49, 44, 50, 44, 39, 34, 116, 61, 36, 51, 43, 120, 42,
  40, 36, 52, 45, 36, 51, 41, 47, 40, 36, 53, 45, 49, 41, 59, 105,
  102, 40, 99, 61, 61, 48, 44, 36, 49, 44, 36, 50, 41, 34, 39, 10,
  45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 44,
  50, 10, 40, 36, 56, 44, 36, 49, 49, 94, 36, 57, 44, 36, 49, 50,
  94, 36, 49, 48, 44, 36, 49, 51, 41, 32, 45, 114, 91, 45, 49, 93,
  32, 64, 123, 45, 50, 44, 119, 125, 44, 49, 44, 49, 44, 51, 44, 51,
  32, 45, 97, 32, 99, 10, 45, 100, 105, 115, 112, 108, 97, 121, 95, 112,
  97, 114, 97, 109, 101, 116, 114, 105, 99, 32, 36, 119, 44, 36, 104, 44,
  123, 36, 54, 43, 36, 49, 52, 42, 49, 46, 48, 48, 49, 125, 44, 36,
  55, 44, 36, 49, 53, 44, 36, 49, 54, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 69, 113, 117,
  97, 116, 105, 111, 110, 32, 112, 108, 111, 116, 32, 91, 121, 61, 102, 40,
  120, 41, 93, 32, 58, 32, 103, 105, 109, 112, 95, 101, 113, 117, 97, 116,
  105, 111, 110, 95, 112, 108, 111, 116, 44, 32, 103, 105, 109, 112, 95, 101,
  113, 117, 97, 116, 105, 111, 110, 95, 112, 108, 111, 116, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 70, 40, 120, 41, 32, 61, 32, 116, 101, 120,
  116, 123, 34, 88, 42, 99, 43, 49, 48, 42, 99, 111, 115, 40, 88, 43,
  99, 43, 63, 41, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  88, 45, 109, 105, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 45, 49,
  48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 88, 45, 109, 97, 120, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 115, 111, 108, 117, 116,
  105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 49, 48, 48, 44, 50, 44,
  49, 48, 50, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  104, 97, 110, 110, 101, 108, 115, 32, 61, 32, 105, 110, 116, 40, 51, 44,
  49, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80,
  108, 111, 116, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 50, 44, 34, 78, 111, 110, 101, 34, 44, 34, 76, 105, 110, 101,
  115, 34, 44, 34, 83, 112, 108, 105, 110, 101, 115, 34, 44, 34, 66, 97,
  114, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 101,
  114, 116, 101, 120, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 48, 44, 34, 78, 111, 110, 101, 34, 44, 34, 80, 111, 105,
  110, 116, 115, 34, 44, 34, 67, 114, 111, 115, 115, 101, 115, 32, 49, 34,
  44, 34, 67, 114, 111, 115, 115, 101, 115, 32, 50, 34, 44, 34, 67, 105,
  114, 99, 108, 101, 115, 32, 49, 34, 44, 34, 67, 105, 114, 99, 108, 101,
  115, 32, 50, 34, 44, 34, 83, 113, 117, 97, 114, 101, 32, 49, 34, 44,
  34, 83, 113, 117, 97, 114, 101, 32, 50, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 98, 62,
  78, 111, 116, 101, 60, 47, 98, 62, 32, 58, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 85, 115, 101, 32, 118, 97, 114, 105, 97, 98, 108, 101,
  32, 60, 98, 62, 88, 60, 47, 98, 62, 32, 105, 110, 115, 116, 101, 97,
  100, 32, 111, 102, 32, 60, 98, 62, 120, 60, 47, 98, 62, 32, 105, 110,
  32, 116, 104, 101, 32, 97, 98, 111, 118, 101, 32, 101, 113, 117, 97, 116,
  105, 111, 110, 32, 116, 111, 32, 116, 97, 107, 101, 32, 99, 97, 114, 101,
  32, 111, 102, 32, 116, 104, 101, 32, 88, 45, 109, 105, 110, 47, 109, 97,
  120, 32, 115, 101, 116, 116, 105, 110, 103, 115, 46, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 86, 97, 114, 105, 97, 98, 108, 101, 32, 60, 98,
  62, 99, 60, 47, 98, 62, 32, 114, 101, 102, 101, 114, 115, 32, 116, 111,
  32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 99, 104, 97,
  110, 110, 101, 108, 32, 110, 117, 109, 98, 101, 114, 46, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 86, 97, 114, 105, 97, 98, 108, 101, 32, 60,
  98, 62, 63, 60, 47, 98, 62, 32, 114, 101, 102, 101, 114, 115, 32, 116,
  111, 32, 97, 32, 117, 110, 105, 102, 111, 114, 109, 108, 121, 32, 100, 105,
  115, 116, 114, 105, 98, 117, 116, 101, 100, 32, 114, 97, 110, 100, 111, 109,
  32, 118, 97, 108, 117, 101, 32, 105, 110, 32, 91, 48, 44, 49, 93, 46,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 100, 117, 99, 101,
  32, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 32, 116, 111, 32, 98,
  101, 32, 97, 98, 108, 101, 32, 116, 111, 32, 118, 105, 101, 119, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 115, 101, 112, 97, 114, 97, 116, 101,
  32, 103, 114, 97, 112, 104, 32, 118, 101, 114, 116, 105, 99, 101, 115, 46,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  101, 113, 117, 97, 116, 105, 111, 110, 95, 112, 108, 111, 116, 32, 58, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 32, 45, 114,
  109, 10, 36, 52, 44, 49, 44, 49, 44, 36, 53, 44, 34, 88, 61, 36,
  50, 43, 40, 36, 51, 45, 36, 50, 41, 42, 120, 47, 40, 36, 52, 45,
  49, 41, 59, 36, 49, 34, 10, 45, 100, 103, 32, 36, 119, 44, 36, 104,
  44, 36, 54, 44, 36, 55, 44, 36, 50, 44, 36, 51, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32,
  71, 114, 97, 100, 105, 101, 110, 116, 32, 91, 99, 111, 114, 110, 101, 114,
  115, 93, 32, 58, 32, 103, 105, 109, 112, 95, 99, 111, 114, 110, 101, 114,
  95, 103, 114, 97, 100, 105, 101, 110, 116, 44, 32, 103, 105, 109, 112, 95,
  99, 111, 114, 110, 101, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 49,
  32, 40, 117, 112, 47, 108, 101, 102, 116, 32, 99, 111, 114, 110, 101, 114,
  41, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 50, 32, 40, 117, 112, 47,
  114, 105, 103, 104, 116, 32, 99, 111, 114, 110, 101, 114, 41, 32, 61, 32,
  99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 48, 44, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111,
  114, 32, 51, 32, 40, 98, 111, 116, 116, 111, 109, 47, 108, 101, 102, 116,
  32, 99, 111, 114, 110, 101, 114, 41, 32, 61, 32, 99, 111, 108, 111, 114,
  40, 48, 44, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 52, 32, 40,
  98, 111, 116, 116, 111, 109, 47, 114, 105, 103, 104, 116, 32, 99, 111, 114,
  110, 101, 114, 41, 32, 61, 32, 99, 111, 108, 111, 114, 40, 48, 44, 48,
  44, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47,
  50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 99, 111, 114, 110, 101, 114, 95, 103, 114,
  97, 100, 105, 101, 110, 116, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 10, 40, 123, 119, 125, 44, 123, 104, 125, 41, 32, 45, 114,
  109, 91, 45, 50, 93, 10, 40, 36, 49, 44, 36, 53, 59, 36, 57, 44,
  36, 49, 51, 94, 36, 50, 44, 36, 54, 59, 36, 49, 48, 44, 36, 49,
  52, 94, 36, 51, 44, 36, 55, 59, 36, 49, 49, 44, 36, 49, 53, 94,
  36, 52, 44, 36, 56, 59, 36, 49, 50, 44, 36, 49, 54, 41, 32, 45,
  114, 91, 45, 49, 93, 32, 64, 45, 50, 44, 49, 44, 52, 44, 51, 32,
  45, 114, 109, 91, 45, 50, 93, 10, 45, 109, 118, 91, 45, 49, 93, 32,
  48, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 71,
  114, 97, 100, 105, 101, 110, 116, 32, 91, 99, 117, 115, 116, 111, 109, 32,
  115, 104, 97, 112, 101, 93, 32, 58, 32, 103, 105, 109, 112, 95, 99, 117,
  115, 116, 111, 109, 95, 103, 114, 97, 100, 105, 101, 110, 116, 44, 32, 103,
  105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 103, 114, 97, 100, 105,
  101, 110, 116, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 83,
  104, 97, 112, 101, 32, 115, 101, 108, 101, 99, 116, 105, 111, 110, 58, 60,
  47, 98, 62, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 108, 101, 99, 116, 32, 98, 121,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 117, 116, 111, 34,
  44, 34, 68, 97, 114, 107, 32, 112, 105, 120, 101, 108, 115, 34, 44, 34,
  66, 114, 105, 103, 104, 116, 32, 112, 105, 120, 101, 108, 115, 34, 44, 34,
  79, 112, 97, 113, 117, 101, 32, 112, 105, 120, 101, 108, 115, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114,
  101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 80, 114, 101, 118, 105, 101, 119, 32, 115, 104, 97, 112, 101, 32, 61,
  32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 60, 98, 62, 78, 111, 116, 101, 58, 60, 47,
  98, 62, 32, 83, 104, 97, 112, 101, 115, 32, 119, 105, 116, 104, 32, 115,
  109, 97, 108, 108, 32, 115, 116, 114, 111, 107, 101, 115, 32, 109, 97, 121,
  32, 108, 101, 97, 100, 32, 116, 111, 32, 105, 110, 99, 111, 114, 114, 101,
  99, 116, 32, 112, 114, 101, 118, 105, 101, 119, 115, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60,
  98, 62, 71, 114, 97, 100, 105, 101, 110, 116, 32, 112, 97, 114, 97, 109,
  101, 116, 101, 114, 115, 58, 60, 47, 98, 62, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 117,
  109, 98, 101, 114, 32, 111, 102, 32, 99, 111, 108, 111, 114, 115, 32, 61,
  32, 105, 110, 116, 40, 52, 44, 50, 44, 49, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 121, 99, 108, 101, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 44, 49, 44, 49, 54, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 79, 102, 102, 115, 101, 116, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 100, 105, 110, 103, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 50, 56, 44, 49, 44, 50, 53, 54,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 110, 101, 114,
  32, 108, 101, 110, 103, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 48, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 79, 117, 116, 101, 114, 32, 108, 101, 110, 103, 116, 104,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 97,
  116, 105, 97, 108, 32, 109, 101, 116, 114, 105, 99, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 50, 44, 34, 67, 104, 101, 98, 121, 115, 104, 101,
  118, 34, 44, 34, 77, 97, 110, 104, 97, 116, 116, 97, 110, 34, 44, 34,
  69, 117, 99, 108, 105, 100, 101, 97, 110, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 109, 101, 116, 114, 105,
  99, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 82, 71, 66, 34,
  44, 34, 72, 83, 86, 34, 44, 34, 76, 97, 98, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 100, 101, 32, 98, 97, 99,
  107, 32, 116, 111, 32, 102, 105, 114, 115, 116, 32, 99, 111, 108, 111, 114,
  32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 80, 114, 101, 118, 105, 101, 119, 32, 103, 114, 97, 100,
  105, 101, 110, 116, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 97, 118, 101, 32, 103, 114, 97,
  100, 105, 101, 110, 116, 32, 97, 115, 32, 61, 32, 95, 116, 101, 120, 116,
  40, 34, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62,
  67, 111, 108, 111, 114, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110,
  115, 58, 60, 47, 98, 62, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 109,
  97, 112, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 49, 44, 34, 80, 114, 101, 45, 100, 101, 102, 105, 110, 101, 100, 34,
  44, 34, 85, 115, 101, 114, 45, 100, 101, 102, 105, 110, 101, 100, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 45, 100, 101,
  102, 105, 110, 101, 100, 32, 99, 111, 108, 111, 114, 109, 97, 112, 32, 61,
  32, 105, 110, 116, 40, 48, 44, 48, 44, 54, 53, 53, 51, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 49, 115, 116, 32, 99, 111, 108,
  111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 48, 44, 48, 44, 48,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 50,
  110, 100, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114,
  40, 50, 53, 53, 44, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 51, 114, 100, 32, 99, 111, 108, 111, 114,
  32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53,
  44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 52, 116, 104, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108,
  111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 53, 116, 104,
  32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 48,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 54, 116, 104, 32, 99, 111, 108, 111, 114,
  32, 61, 32, 99, 111, 108, 111, 114, 40, 48, 44, 50, 53, 53, 44, 48,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 55,
  116, 104, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114,
  40, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 56, 116, 104, 32, 99, 111, 108, 111, 114,
  32, 61, 32, 99, 111, 108, 111, 114, 40, 49, 50, 56, 44, 49, 50, 56,
  44, 49, 50, 56, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 57, 116, 104, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99,
  111, 108, 111, 114, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 49, 48, 116,
  104, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40,
  48, 44, 48, 44, 48, 44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109,
  112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 49, 48, 47, 48,
  51, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 103, 114, 97,
  100, 105, 101, 110, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 34, 36, 123, 49, 53, 61, 125, 34, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 105, 102, 32, 36, 52, 10, 45, 45, 95, 103, 105, 109, 112, 95,
  99, 117, 115, 116, 111, 109, 95, 103, 114, 97, 100, 105, 101, 110, 116, 49,
  32, 36, 123, 49, 45, 49, 52, 125, 44, 34, 36, 49, 53, 34, 44, 36,
  123, 49, 54, 45, 45, 49, 125, 32, 45, 45, 101, 114, 111, 100, 101, 91,
  45, 49, 93, 32, 51, 32, 45, 45, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 53, 32, 45,
  97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 110, 91, 45, 49,
  93, 32, 48, 44, 50, 53, 53, 10, 45, 103, 105, 109, 112, 95, 99, 117,
  115, 116, 111, 109, 95, 103, 114, 97, 100, 105, 101, 110, 116, 91, 48, 93,
  32, 36, 123, 49, 45, 49, 52, 125, 44, 34, 36, 49, 53, 34, 44, 36,
  123, 49, 54, 45, 45, 49, 125, 44, 45, 49, 32, 45, 98, 108, 101, 110,
  100, 32, 97, 108, 112, 104, 97, 10, 45, 101, 108, 115, 101, 32, 45, 103,
  105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 103, 114, 97, 100, 105,
  101, 110, 116, 32, 36, 123, 49, 45, 49, 52, 125, 44, 34, 36, 49, 53,
  34, 44, 36, 123, 49, 54, 45, 45, 49, 125, 44, 45, 49, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 49, 52, 10, 45, 45, 95,
  103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 103, 114, 97, 100,
  105, 101, 110, 116, 48, 91, 93, 32, 36, 123, 49, 45, 49, 52, 125, 44,
  34, 36, 49, 53, 34, 44, 36, 123, 49, 54, 45, 45, 49, 125, 32, 45,
  114, 91, 45, 49, 93, 32, 123, 64, 123, 48, 44, 119, 125, 45, 49, 54,
  125, 44, 49, 54, 44, 49, 44, 52, 32, 45, 102, 114, 97, 109, 101, 91,
  45, 49, 93, 32, 49, 44, 49, 44, 48, 32, 45, 106, 91, 48, 93, 32,
  91, 45, 49, 93, 44, 56, 44, 64, 123, 48, 44, 104, 45, 50, 53, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112,
  95, 99, 117, 115, 116, 111, 109, 95, 103, 114, 97, 100, 105, 101, 110, 116,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36, 123, 49, 53, 61, 125,
  34, 10, 45, 95, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95,
  103, 114, 97, 100, 105, 101, 110, 116, 48, 32, 36, 123, 49, 45, 49, 52,
  125, 44, 34, 36, 49, 53, 34, 44, 36, 123, 49, 54, 45, 45, 49, 125,
  10, 45, 105, 102, 32, 123, 36, 45, 49, 62, 61, 48, 38, 38, 110, 97,
  114, 103, 40, 34, 36, 49, 53, 34, 41, 125, 10, 100, 105, 114, 95, 103,
  103, 114, 61, 64, 123, 45, 112, 97, 116, 104, 95, 103, 105, 109, 112, 125,
  47, 103, 114, 97, 100, 105, 101, 110, 116, 115, 10, 48, 32, 45, 110, 109,
  91, 45, 49, 93, 32, 64, 123, 34, 45, 110, 111, 114, 109, 97, 108, 105,
  122, 101, 95, 102, 105, 108, 101, 110, 97, 109, 101, 32, 92, 34, 36, 49,
  53, 92, 34, 34, 125, 32, 110, 97, 109, 101, 95, 103, 103, 114, 61, 64,
  123, 45, 49, 44, 98, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  111, 117, 116, 112, 117, 116, 95, 103, 103, 114, 91, 45, 49, 93, 32, 36,
  100, 105, 114, 95, 103, 103, 114, 47, 36, 110, 97, 109, 101, 95, 103, 103,
  114, 46, 103, 103, 114, 44, 34, 36, 49, 53, 34, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 91, 45, 50, 93, 32, 40, 48, 94, 48, 94, 48,
  94, 48, 41, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 45,
  108, 91, 36, 62, 44, 45, 49, 93, 10, 45, 95, 103, 105, 109, 112, 95,
  99, 117, 115, 116, 111, 109, 95, 103, 114, 97, 100, 105, 101, 110, 116, 49,
  91, 48, 93, 32, 36, 123, 49, 45, 49, 52, 125, 44, 34, 36, 49, 53,
  34, 44, 36, 123, 49, 54, 45, 45, 49, 125, 10, 45, 45, 100, 105, 115,
  116, 97, 110, 99, 101, 91, 48, 93, 32, 49, 44, 36, 49, 49, 32, 45,
  45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 48, 93, 32, 48, 44, 36,
  49, 49, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 43, 91,
  48, 93, 32, 49, 32, 45, 43, 91, 48, 44, 45, 50, 44, 45, 49, 93,
  10, 109, 61, 123, 36, 57, 37, 42, 64, 123, 48, 44, 105, 109, 125, 125,
  32, 77, 61, 123, 36, 49, 48, 37, 42, 64, 123, 48, 44, 105, 77, 125,
  125, 10, 45, 45, 91, 48, 93, 32, 36, 109, 32, 45, 42, 91, 48, 93,
  32, 123, 64, 123, 49, 44, 119, 45, 50, 125, 47, 40, 36, 77, 45, 36,
  109, 41, 125, 32, 45, 43, 91, 48, 93, 32, 49, 10, 45, 114, 111, 117,
  110, 100, 91, 48, 93, 32, 45, 109, 97, 112, 91, 48, 93, 32, 91, 45,
  49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45,
  114, 109, 91, 45, 49, 93, 10, 95, 103, 105, 109, 112, 95, 99, 117, 115,
  116, 111, 109, 95, 103, 114, 97, 100, 105, 101, 110, 116, 48, 32, 58, 10,
  45, 105, 102, 32, 36, 49, 54, 32, 52, 44, 56, 44, 49, 44, 49, 44,
  36, 123, 49, 56, 45, 53, 54, 125, 32, 45, 112, 101, 114, 109, 117, 116,
  101, 91, 45, 49, 93, 32, 121, 122, 99, 120, 10, 45, 101, 108, 115, 101,
  32, 56, 44, 49, 44, 49, 44, 51, 32, 45, 115, 114, 97, 110, 100, 32,
  36, 49, 55, 32, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 32, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 122, 91, 45, 49, 93, 32, 48,
  44, 123, 36, 53, 45, 49, 125, 10, 45, 105, 102, 32, 36, 49, 51, 10,
  45, 114, 91, 45, 49, 93, 32, 123, 50, 48, 48, 42, 36, 54, 125, 37,
  44, 49, 44, 49, 44, 52, 44, 48, 44, 50, 10, 45, 95, 95, 103, 105,
  109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 103, 114, 97, 100, 105, 101,
  110, 116, 48, 91, 45, 49, 93, 32, 36, 49, 50, 44, 36, 56, 10, 45,
  115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 123, 45, 36, 55, 47, 50,
  125, 37, 44, 48, 44, 48, 44, 48, 44, 50, 32, 45, 122, 91, 45, 49,
  93, 32, 48, 44, 123, 119, 47, 50, 45, 49, 125, 10, 45, 101, 108, 115,
  101, 10, 45, 95, 95, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109,
  95, 103, 114, 97, 100, 105, 101, 110, 116, 48, 91, 45, 49, 93, 32, 36,
  49, 50, 44, 36, 56, 10, 45, 114, 91, 45, 49, 93, 32, 123, 49, 48,
  48, 42, 36, 54, 125, 37, 44, 49, 44, 49, 44, 52, 44, 48, 44, 50,
  32, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 45, 36, 55, 37,
  44, 48, 44, 48, 44, 48, 44, 50, 10, 45, 101, 110, 100, 105, 102, 10,
  95, 95, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 103, 114,
  97, 100, 105, 101, 110, 116, 48, 32, 58, 10, 45, 105, 102, 32, 123, 36,
  49, 61, 61, 49, 125, 32, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44,
  50, 32, 45, 114, 103, 98, 50, 104, 115, 118, 91, 45, 49, 93, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49,
  61, 61, 50, 125, 32, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 50,
  32, 45, 115, 114, 103, 98, 50, 114, 103, 98, 91, 45, 49, 93, 32, 45,
  114, 103, 98, 50, 108, 97, 98, 91, 45, 49, 93, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 91, 45, 49,
  93, 32, 123, 36, 50, 42, 119, 125, 44, 49, 44, 49, 44, 52, 44, 51,
  10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 32, 45, 115, 104,
  91, 45, 49, 93, 32, 48, 44, 50, 32, 45, 104, 115, 118, 50, 114, 103,
  98, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 49, 61, 61, 50, 125, 32, 45, 115, 104, 91,
  45, 49, 93, 32, 48, 44, 50, 32, 45, 108, 97, 98, 50, 114, 103, 98,
  91, 45, 49, 93, 32, 45, 114, 103, 98, 50, 115, 114, 103, 98, 91, 45,
  49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105,
  102, 10, 95, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 103,
  114, 97, 100, 105, 101, 110, 116, 49, 32, 58, 10, 45, 98, 32, 36, 50,
  37, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 125, 10, 45, 116,
  111, 95, 97, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105,
  116, 121, 10, 45, 105, 102, 32, 123, 105, 77, 62, 105, 109, 43, 51, 50,
  125, 10, 45, 114, 109, 91, 45, 50, 93, 32, 45, 103, 101, 91, 48, 93,
  32, 123, 49, 48, 48, 45, 36, 51, 125, 37, 10, 45, 101, 108, 115, 101,
  10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 110, 111, 114, 109, 32, 45,
  110, 32, 48, 44, 49, 10, 45, 105, 102, 32, 123, 105, 97, 62, 48, 46,
  53, 125, 32, 45, 108, 101, 91, 48, 93, 32, 36, 51, 37, 32, 45, 101,
  108, 115, 101, 32, 45, 103, 101, 91, 48, 93, 32, 123, 49, 48, 48, 45,
  36, 51, 125, 37, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125,
  10, 45, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121,
  32, 45, 110, 111, 114, 109, 32, 45, 108, 101, 32, 36, 51, 37, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 50, 125, 10, 45, 114, 101,
  109, 111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 110, 111,
  114, 109, 32, 45, 103, 101, 32, 123, 49, 48, 48, 45, 36, 51, 125, 37,
  10, 45, 101, 108, 115, 101, 10, 45, 116, 111, 95, 97, 32, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 32, 49, 48, 48, 37, 32, 45, 103, 101, 32,
  123, 49, 48, 48, 45, 36, 51, 125, 37, 10, 45, 101, 110, 100, 105, 102,
  10, 35, 64, 103, 105, 109, 112, 32, 71, 114, 97, 100, 105, 101, 110, 116,
  32, 91, 102, 114, 111, 109, 32, 108, 105, 110, 101, 93, 32, 58, 32, 103,
  105, 109, 112, 95, 108, 105, 110, 101, 95, 103, 114, 97, 100, 105, 101, 110,
  116, 44, 32, 103, 105, 109, 112, 95, 108, 105, 110, 101, 95, 103, 114, 97,
  100, 105, 101, 110, 116, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98,
  62, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110,
  100, 61, 34, 114, 101, 100, 34, 62, 83, 116, 97, 114, 116, 105, 110, 103,
  32, 112, 111, 105, 110, 116, 58, 60, 47, 115, 112, 97, 110, 62, 60, 47,
  98, 62, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 88, 48, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 89, 48, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 60, 98, 62, 60, 115, 112, 97, 110, 32, 102, 111, 114,
  101, 103, 114, 111, 117, 110, 100, 61, 34, 98, 108, 117, 101, 34, 62, 69,
  110, 100, 105, 110, 103, 32, 112, 111, 105, 110, 116, 58, 60, 47, 115, 112,
  97, 110, 62, 60, 47, 98, 62, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 49, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 48, 48, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 49, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 48, 48, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 97, 109, 112, 108, 105, 110, 103, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 48, 48, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 101, 110, 103, 116, 104, 32,
  61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 52, 48, 57, 54, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62,
  78, 111, 116, 101, 58, 60, 47, 98, 62, 32, 83, 101, 116, 32, 108, 101,
  110, 103, 116, 104, 32, 116, 111, 32, 60, 105, 62, 48, 60, 47, 105, 62,
  32, 116, 111, 32, 114, 101, 108, 101, 97, 115, 101, 32, 103, 114, 97, 100,
  105, 101, 110, 116, 32, 108, 101, 110, 103, 116, 104, 32, 99, 111, 110, 115,
  116, 114, 97, 105, 110, 116, 115, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 111, 114, 116,
  32, 99, 111, 108, 111, 114, 115, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 68, 111, 110, 39, 116, 32, 115, 111, 114, 116, 34, 44, 34, 66,
  121, 32, 114, 101, 100, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 66, 121, 32, 103, 114, 101, 101, 110, 32, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 66, 121, 32, 98, 108, 117, 101, 32, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 66, 121, 32, 108, 117,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 121, 32, 98, 108, 117,
  101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  66, 121, 32, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 34, 66, 121, 32, 108, 105, 103, 104, 116, 110, 101, 115,
  115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118,
  101, 114, 115, 101, 32, 103, 114, 97, 100, 105, 101, 110, 116, 32, 61, 32,
  98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 103, 114, 97, 100, 105, 101, 110, 116, 32, 61, 32, 98,
  111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 97, 118, 101, 32, 103, 114, 97, 100, 105, 101, 110, 116, 32, 97, 115,
  32, 61, 32, 95, 116, 101, 120, 116, 40, 34, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115,
  99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47,
  49, 48, 47, 48, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 108, 105, 110, 101, 95, 103,
  114, 97, 100, 105, 101, 110, 116, 32, 58, 32, 45, 115, 107, 105, 112, 32,
  34, 36, 123, 49, 48, 61, 125, 34, 10, 45, 95, 103, 105, 109, 112, 95,
  108, 105, 110, 101, 95, 103, 114, 97, 100, 105, 101, 110, 116, 32, 36, 42,
  10, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40, 34, 36, 49, 48, 34,
  41, 125, 10, 100, 105, 114, 95, 103, 103, 114, 61, 64, 123, 45, 112, 97,
  116, 104, 95, 103, 105, 109, 112, 125, 47, 103, 114, 97, 100, 105, 101, 110,
  116, 115, 10, 48, 32, 45, 110, 109, 91, 45, 49, 93, 32, 64, 123, 34,
  45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 102, 105, 108, 101, 110,
  97, 109, 101, 32, 92, 34, 36, 49, 48, 92, 34, 34, 125, 32, 110, 97,
  109, 101, 95, 103, 103, 114, 61, 64, 123, 45, 49, 44, 98, 125, 32, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 111, 117, 116, 112, 117, 116, 95, 103,
  103, 114, 91, 45, 49, 93, 32, 36, 100, 105, 114, 95, 103, 103, 114, 47,
  36, 110, 97, 109, 101, 95, 103, 103, 114, 46, 103, 103, 114, 44, 34, 36,
  49, 48, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 114, 91, 36, 62, 93, 32, 49, 48, 48,
  37, 44, 54, 52, 44, 49, 44, 49, 48, 48, 37, 32, 45, 100, 111, 110,
  101, 10, 103, 105, 109, 112, 95, 108, 105, 110, 101, 95, 103, 114, 97, 100,
  105, 101, 110, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 116, 111, 95, 114, 103, 98, 97, 10, 45, 105, 102, 32, 36, 57,
  32, 45, 45, 95, 103, 105, 109, 112, 95, 108, 105, 110, 101, 95, 103, 114,
  97, 100, 105, 101, 110, 116, 32, 36, 42, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 108, 91, 48, 93, 10, 45, 108, 105, 110, 101, 32, 36, 49, 37,
  44, 36, 50, 37, 44, 36, 51, 37, 44, 36, 52, 37, 44, 49, 44, 48,
  120, 70, 48, 70, 48, 70, 48, 70, 48, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 108, 105, 110, 101, 32,
  36, 49, 37, 44, 36, 50, 37, 44, 36, 51, 37, 44, 36, 52, 37, 44,
  49, 44, 48, 120, 48, 70, 48, 70, 48, 70, 48, 70, 44, 48, 44, 48,
  44, 48, 44, 50, 53, 53, 10, 45, 99, 105, 114, 99, 108, 101, 32, 36,
  49, 37, 44, 36, 50, 37, 44, 52, 44, 49, 44, 50, 53, 53, 44, 48,
  44, 48, 44, 50, 53, 53, 10, 45, 99, 105, 114, 99, 108, 101, 32, 36,
  51, 37, 44, 36, 52, 37, 44, 52, 44, 49, 44, 48, 44, 48, 44, 50,
  53, 53, 44, 50, 53, 53, 10, 45, 99, 105, 114, 99, 108, 101, 32, 36,
  49, 37, 44, 36, 50, 37, 44, 52, 44, 49, 44, 48, 120, 70, 70, 70,
  70, 70, 70, 70, 70, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 10,
  45, 99, 105, 114, 99, 108, 101, 32, 36, 51, 37, 44, 36, 52, 37, 44,
  52, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48,
  44, 48, 44, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 10, 45,
  105, 102, 32, 123, 64, 35, 62, 49, 125, 32, 45, 114, 91, 45, 49, 93,
  32, 123, 64, 123, 48, 44, 119, 125, 45, 51, 50, 125, 44, 51, 50, 44,
  49, 44, 52, 44, 49, 32, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93,
  32, 49, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 32, 45,
  106, 91, 48, 93, 32, 91, 49, 93, 44, 49, 54, 44, 123, 64, 123, 48,
  44, 104, 125, 45, 52, 56, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 95, 103, 105, 109, 112, 95, 108, 105, 110, 101, 95, 103, 114,
  97, 100, 105, 101, 110, 116, 32, 58, 10, 45, 97, 116, 95, 108, 105, 110,
  101, 32, 36, 49, 37, 44, 36, 50, 37, 44, 48, 44, 36, 51, 37, 44,
  36, 52, 37, 44, 48, 32, 45, 114, 32, 123, 109, 97, 120, 40, 48, 46,
  49, 44, 36, 53, 41, 125, 37, 44, 49, 44, 49, 44, 49, 48, 48, 37,
  44, 49, 10, 45, 109, 32, 34, 102, 101, 97, 116, 117, 114, 101, 49, 32,
  58, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48, 34, 10, 45,
  109, 32, 34, 102, 101, 97, 116, 117, 114, 101, 50, 32, 58, 32, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 49, 34, 10, 45, 109, 32, 34, 102,
  101, 97, 116, 117, 114, 101, 51, 32, 58, 32, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 50, 34, 10, 45, 109, 32, 34, 102, 101, 97, 116, 117,
  114, 101, 52, 32, 58, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 108,
  117, 109, 105, 110, 97, 110, 99, 101, 34, 10, 45, 109, 32, 34, 102, 101,
  97, 116, 117, 114, 101, 53, 32, 58, 32, 45, 116, 111, 95, 114, 103, 98,
  32, 45, 114, 103, 98, 50, 121, 99, 98, 99, 114, 32, 45, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 49, 34, 10, 45, 109, 32, 34, 102, 101, 97,
  116, 117, 114, 101, 54, 32, 58, 32, 45, 116, 111, 95, 114, 103, 98, 32,
  45, 114, 103, 98, 50, 121, 99, 98, 99, 114, 32, 45, 99, 104, 97, 110,
  110, 101, 108, 115, 32, 50, 34, 10, 45, 109, 32, 34, 102, 101, 97, 116,
  117, 114, 101, 55, 32, 58, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45,
  115, 114, 103, 98, 50, 114, 103, 98, 32, 45, 114, 103, 98, 50, 108, 97,
  98, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48, 34, 10, 45,
  105, 102, 32, 36, 55, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 45, 45, 102, 101, 97, 116, 117, 114,
  101, 36, 55, 32, 45, 114, 118, 32, 45, 97, 32, 121, 32, 45, 115, 111,
  114, 116, 32, 43, 44, 120, 32, 45, 114, 111, 119, 115, 32, 49, 32, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 36, 54, 32, 45, 114, 32, 36, 54, 44, 49,
  44, 49, 44, 49, 48, 48, 37, 44, 51, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 36, 56, 32, 45, 109, 105, 114, 114, 111, 114, 32,
  120, 32, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103, 105, 109, 112, 32,
  71, 114, 97, 100, 105, 101, 110, 116, 32, 91, 108, 105, 110, 101, 97, 114,
  93, 32, 58, 32, 103, 105, 109, 112, 95, 108, 105, 110, 101, 97, 114, 95,
  103, 114, 97, 100, 105, 101, 110, 116, 44, 32, 103, 105, 109, 112, 95, 108,
  105, 110, 101, 97, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 116, 97, 114, 116, 105, 110, 103,
  32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 48,
  44, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 69, 110, 100, 105, 110, 103, 32, 99, 111, 108, 111, 114, 32,
  61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 119, 97, 112, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32,
  98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 65, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52,
  53, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 70, 97, 100, 101, 32, 115, 116, 97, 114, 116, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 70, 97, 100, 101, 32, 101, 110, 100, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  108, 105, 110, 101, 97, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 32,
  58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 40, 123, 119,
  125, 44, 123, 104, 125, 41, 32, 45, 114, 109, 91, 45, 50, 93, 10, 40,
  36, 49, 94, 36, 50, 94, 36, 51, 94, 36, 52, 41, 32, 40, 36, 53,
  94, 36, 54, 94, 36, 55, 94, 36, 56, 41, 10, 45, 105, 102, 32, 36,
  57, 32, 45, 114, 118, 91, 45, 50, 44, 45, 49, 93, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 114, 91, 45, 50, 44, 45, 49, 93, 32, 64, 45,
  51, 32, 45, 114, 109, 91, 45, 51, 93, 10, 45, 102, 97, 100, 101, 95,
  108, 105, 110, 101, 97, 114, 32, 36, 49, 48, 44, 36, 49, 49, 44, 36,
  49, 50, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111,
  110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 71, 114, 97, 100, 105, 101,
  110, 116, 32, 91, 114, 97, 100, 105, 97, 108, 93, 32, 58, 32, 103, 105,
  109, 112, 95, 114, 97, 100, 105, 97, 108, 95, 103, 114, 97, 100, 105, 101,
  110, 116, 44, 32, 103, 105, 109, 112, 95, 114, 97, 100, 105, 97, 108, 95,
  103, 114, 97, 100, 105, 101, 110, 116, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 116, 97, 114, 116, 105, 110, 103, 32, 99, 111, 108, 111, 114,
  32, 61, 32, 99, 111, 108, 111, 114, 40, 48, 44, 48, 44, 48, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 110, 100,
  105, 110, 103, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111,
  114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 119, 97, 112,
  32, 99, 111, 108, 111, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 97, 100, 101, 32,
  115, 116, 97, 114, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  70, 97, 100, 101, 32, 101, 110, 100, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 48, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 88, 45, 99, 101, 110, 116, 101, 114, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 101, 110, 116, 101,
  114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68,
  97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38,
  35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112,
  95, 114, 97, 100, 105, 97, 108, 95, 103, 114, 97, 100, 105, 101, 110, 116,
  32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 40, 123,
  119, 125, 44, 123, 104, 125, 41, 32, 45, 114, 109, 91, 45, 50, 93, 10,
  40, 36, 49, 94, 36, 50, 94, 36, 51, 94, 36, 52, 41, 32, 40, 36,
  53, 94, 36, 54, 94, 36, 55, 94, 36, 56, 41, 10, 45, 105, 102, 32,
  36, 57, 32, 45, 114, 118, 91, 45, 50, 44, 45, 49, 93, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 91, 45, 50, 44, 45, 49, 93, 32, 64,
  45, 51, 32, 45, 114, 109, 91, 45, 51, 93, 10, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 32, 45, 61, 91, 45, 49, 93, 32, 49, 44, 36, 49,
  50, 37, 44, 36, 49, 51, 37, 32, 45, 100, 105, 115, 116, 97, 110, 99,
  101, 91, 45, 49, 93, 32, 49, 32, 45, 95, 102, 97, 100, 101, 32, 36,
  49, 48, 44, 36, 49, 49, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48,
  32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 72, 101,
  97, 114, 116, 32, 58, 32, 103, 105, 109, 112, 95, 104, 101, 97, 114, 116,
  44, 32, 103, 105, 109, 112, 95, 104, 101, 97, 114, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 105,
  122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 55, 53, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40,
  50, 53, 53, 44, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115,
  99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47,
  49, 49, 47, 49, 51, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 104, 101, 97, 114, 116, 32,
  58, 10, 45, 105, 102, 32, 123, 64, 35, 62, 48, 125, 32, 119, 104, 61,
  64, 123, 45, 109, 97, 120, 95, 119, 104, 125, 32, 119, 61, 123, 36, 49,
  37, 42, 109, 105, 110, 40, 53, 49, 50, 44, 97, 114, 103, 40, 49, 44,
  36, 119, 104, 41, 41, 125, 32, 104, 61, 123, 36, 49, 37, 42, 109, 105,
  110, 40, 53, 49, 50, 44, 97, 114, 103, 40, 50, 44, 36, 119, 104, 41,
  41, 125, 32, 45, 101, 108, 115, 101, 32, 119, 61, 123, 36, 49, 37, 42,
  53, 49, 50, 125, 32, 104, 61, 123, 36, 49, 37, 42, 53, 49, 50, 125,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 104, 101, 97, 114, 116, 32, 123,
  109, 97, 120, 40, 49, 44, 36, 119, 41, 125, 44, 123, 109, 97, 120, 40,
  49, 44, 36, 104, 41, 125, 32, 45, 116, 111, 95, 114, 103, 98, 97, 91,
  45, 49, 93, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108,
  111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 49, 44, 49, 44, 49,
  44, 50, 53, 53, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54,
  10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91,
  45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 50, 53,
  53, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 48, 10, 45, 98, 91,
  45, 49, 93, 32, 36, 50, 37, 32, 45, 109, 118, 91, 45, 49, 93, 32,
  48, 10, 103, 105, 109, 112, 95, 104, 101, 97, 114, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 104, 101, 97,
  114, 116, 32, 36, 42, 32, 45, 98, 108, 101, 110, 100, 91, 48, 44, 45,
  49, 93, 32, 97, 108, 112, 104, 97, 44, 49, 44, 49, 10, 35, 64, 103,
  105, 109, 112, 32, 76, 105, 115, 115, 97, 106, 111, 117, 115, 32, 58, 32,
  103, 105, 109, 112, 95, 108, 105, 115, 115, 97, 106, 111, 117, 115, 44, 32,
  103, 105, 109, 112, 95, 108, 105, 115, 115, 97, 106, 111, 117, 115, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 115, 111, 108,
  117, 116, 105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 52, 48, 57, 54,
  44, 50, 44, 56, 49, 57, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 115,
  105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 57, 44,
  48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45,
  115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 57,
  44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90,
  45, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44,
  49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 109, 117, 108, 116,
  105, 112, 108, 105, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 56,
  44, 48, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  89, 45, 109, 117, 108, 116, 105, 112, 108, 105, 101, 114, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 55, 44, 48, 44, 51, 50, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 90, 45, 109, 117, 108, 116, 105, 112, 108, 105,
  101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 51,
  50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 88, 45, 111, 102, 102, 115, 101, 116, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 111, 102, 102, 115, 101, 116,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 45, 111, 102, 102, 115, 101,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 88, 45, 97, 110, 103, 108, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 89, 45, 97, 110, 103, 108, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 51, 54, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 45, 97, 110, 103, 108, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 51, 54, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 84, 104, 105, 99, 107, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 53, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 61,
  32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32,
  60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112,
  101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48, 52, 47, 49, 56,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  103, 105, 109, 112, 95, 108, 105, 115, 115, 97, 106, 111, 117, 115, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 32, 45, 116, 111, 95, 114, 103, 98, 97, 10, 123, 119, 125, 44,
  123, 104, 125, 10, 45, 102, 51, 100, 32, 123, 48, 46, 53, 42, 109, 97,
  120, 40, 119, 44, 104, 41, 47, 116, 97, 110, 40, 36, 52, 42, 112, 105,
  47, 51, 54, 48, 41, 125, 10, 45, 108, 105, 115, 115, 97, 106, 111, 117,
  115, 51, 100, 32, 36, 49, 44, 36, 53, 44, 36, 56, 44, 36, 54, 44,
  36, 57, 44, 36, 55, 44, 36, 49, 48, 10, 45, 114, 51, 100, 91, 45,
  49, 93, 32, 48, 44, 48, 44, 49, 44, 36, 49, 51, 32, 45, 114, 51,
  100, 91, 45, 49, 93, 32, 48, 44, 49, 44, 48, 44, 36, 49, 50, 32,
  45, 114, 51, 100, 91, 45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 36,
  49, 49, 10, 45, 42, 51, 100, 91, 45, 49, 93, 32, 123, 48, 46, 53,
  42, 36, 50, 42, 64, 123, 45, 50, 44, 119, 125, 125, 44, 123, 48, 46,
  53, 42, 36, 51, 42, 64, 123, 45, 50, 44, 104, 125, 125, 44, 123, 48,
  46, 53, 42, 36, 52, 42, 109, 97, 120, 40, 64, 123, 45, 50, 44, 119,
  125, 44, 64, 123, 45, 50, 44, 104, 125, 41, 125, 10, 45, 99, 111, 108,
  51, 100, 91, 45, 49, 93, 32, 49, 32, 45, 111, 98, 106, 101, 99, 116,
  51, 100, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 53, 48, 37, 44,
  53, 48, 37, 44, 48, 44, 49, 44, 49, 44, 48, 44, 48, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91,
  45, 49, 93, 32, 49, 32, 45, 103, 116, 91, 45, 49, 93, 32, 36, 49,
  52, 37, 32, 45, 42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45,
  101, 113, 91, 45, 49, 93, 32, 48, 10, 45, 114, 91, 45, 49, 93, 32,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 52, 10, 45, 115,
  104, 91, 45, 49, 93, 32, 48, 44, 48, 32, 45, 42, 91, 45, 49, 93,
  32, 36, 49, 53, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104,
  91, 45, 49, 93, 32, 49, 44, 49, 32, 45, 42, 91, 45, 49, 93, 32,
  36, 49, 54, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91,
  45, 49, 93, 32, 50, 44, 50, 32, 45, 42, 91, 45, 49, 93, 32, 36,
  49, 55, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 45,
  49, 93, 32, 51, 44, 51, 32, 45, 42, 91, 45, 49, 93, 32, 36, 49,
  56, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 43, 91, 45, 50, 44,
  45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  35, 64, 103, 105, 109, 112, 32, 77, 97, 110, 100, 101, 108, 98, 114, 111,
  116, 45, 106, 117, 108, 105, 97, 32, 115, 101, 116, 115, 32, 58, 32, 103,
  105, 109, 112, 95, 109, 97, 110, 100, 101, 108, 98, 114, 111, 116, 44, 32,
  103, 105, 109, 112, 95, 109, 97, 110, 100, 101, 108, 98, 114, 111, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 88, 45, 99, 101, 110, 116, 101, 114, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 45, 50, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 89, 45, 99, 101, 110, 116, 101, 114, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 50, 44, 50, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 90, 111, 111, 109, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 61,
  32, 105, 110, 116, 40, 49, 50, 56, 44, 49, 44, 53, 49, 50, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 114, 97, 99, 116, 97, 108,
  32, 115, 101, 116, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 77, 97,
  110, 100, 101, 108, 98, 114, 111, 116, 44, 32, 74, 117, 108, 105, 97, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 115, 101, 101, 100,
  32, 40, 106, 117, 108, 105, 97, 41, 32, 61, 32, 116, 101, 120, 116, 40,
  34, 48, 46, 51, 49, 55, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 89, 45, 115, 101, 101, 100, 32, 40, 106, 117, 108, 105, 97, 41,
  32, 61, 32, 116, 101, 120, 116, 40, 34, 48, 46, 48, 51, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 49,
  32, 61, 32, 99, 111, 108, 111, 114, 40, 48, 44, 48, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114,
  32, 50, 32, 61, 32, 99, 111, 108, 111, 114, 40, 48, 44, 50, 53, 53,
  44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108,
  111, 114, 32, 51, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53,
  44, 48, 44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  111, 108, 111, 114, 32, 52, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50,
  53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47,
  50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 109, 97, 110, 100, 101, 108, 98, 114, 111,
  116, 32, 58, 10, 40, 48, 94, 48, 94, 48, 41, 32, 40, 36, 56, 94,
  36, 57, 94, 36, 49, 48, 41, 32, 40, 36, 49, 49, 94, 36, 49, 50,
  94, 36, 49, 51, 41, 32, 40, 36, 49, 52, 94, 36, 49, 53, 94, 36,
  49, 54, 41, 32, 40, 36, 49, 55, 94, 36, 49, 56, 94, 36, 49, 57,
  41, 10, 45, 97, 91, 45, 52, 45, 45, 49, 93, 32, 120, 32, 45, 114,
  91, 45, 49, 93, 32, 36, 52, 44, 49, 44, 49, 44, 51, 44, 51, 32,
  45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 109, 118, 91,
  45, 49, 93, 32, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64,
  35, 45, 49, 125, 10, 119, 104, 61, 123, 119, 125, 44, 123, 104, 125, 32,
  45, 114, 109, 91, 45, 49, 93, 32, 36, 119, 104, 10, 45, 109, 97, 110,
  100, 101, 108, 98, 114, 111, 116, 91, 45, 49, 93, 32, 123, 36, 49, 45,
  50, 47, 40, 49, 43, 36, 51, 41, 125, 44, 123, 36, 50, 45, 50, 47,
  40, 49, 43, 36, 51, 41, 125, 44, 123, 36, 49, 43, 50, 47, 40, 49,
  43, 36, 51, 41, 125, 44, 123, 36, 50, 43, 50, 47, 40, 49, 43, 36,
  51, 41, 125, 44, 36, 52, 44, 36, 53, 44, 123, 105, 102, 40, 36, 53,
  44, 36, 54, 44, 48, 41, 125, 44, 123, 105, 102, 40, 36, 53, 44, 36,
  55, 44, 48, 41, 125, 10, 45, 109, 97, 112, 91, 45, 49, 93, 32, 91,
  48, 93, 10, 45, 109, 118, 91, 45, 49, 93, 32, 49, 32, 45, 100, 111,
  110, 101, 32, 45, 114, 109, 91, 48, 93, 10, 103, 105, 109, 112, 95, 109,
  97, 110, 100, 101, 108, 98, 114, 111, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 109, 97, 110, 100, 101, 108,
  98, 114, 111, 116, 32, 36, 123, 94, 48, 125, 10, 45, 108, 105, 110, 101,
  32, 48, 44, 53, 48, 37, 44, 49, 48, 48, 37, 44, 53, 48, 37, 44,
  48, 46, 53, 44, 50, 53, 53, 10, 45, 108, 105, 110, 101, 32, 53, 48,
  37, 44, 48, 44, 53, 48, 37, 44, 49, 48, 48, 37, 44, 48, 46, 53,
  44, 50, 53, 53, 10, 35, 64, 103, 105, 109, 112, 32, 81, 117, 105, 99,
  107, 32, 99, 111, 112, 121, 114, 105, 103, 104, 116, 32, 58, 32, 103, 105,
  109, 112, 95, 113, 117, 105, 99, 107, 95, 99, 111, 112, 121, 114, 105, 103,
  104, 116, 44, 32, 103, 105, 109, 112, 95, 113, 117, 105, 99, 107, 95, 99,
  111, 112, 121, 114, 105, 103, 104, 116, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 84, 101, 120, 116, 32, 61, 32, 116, 101, 120, 116,
  123, 34, 40, 99, 41, 32, 71, 39, 77, 73, 67, 34, 125, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 105, 110,
  116, 40, 50, 52, 44, 49, 51, 44, 49, 50, 56, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 61, 32, 99, 111,
  108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117,
  116, 108, 105, 110, 101, 32, 61, 32, 105, 110, 116, 40, 49, 44, 48, 44,
  52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 111, 115, 105,
  116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 51, 44,
  34, 85, 112, 45, 108, 101, 102, 116, 34, 44, 34, 85, 112, 45, 114, 105,
  103, 104, 116, 34, 44, 34, 66, 111, 116, 116, 111, 109, 45, 108, 101, 102,
  116, 34, 44, 34, 66, 111, 116, 116, 111, 109, 45, 114, 105, 103, 104, 116,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 102, 102, 115,
  101, 116, 32, 61, 32, 105, 110, 116, 40, 53, 44, 48, 44, 52, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 114, 105, 101, 110, 116,
  97, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49,
  44, 34, 45, 57, 48, 32, 100, 101, 103, 46, 34, 44, 34, 48, 32, 100,
  101, 103, 46, 34, 44, 34, 43, 57, 48, 32, 100, 101, 103, 46, 34, 44,
  34, 43, 49, 56, 48, 32, 100, 101, 103, 46, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115,
  99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47,
  49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 113, 117, 105, 99, 107, 95,
  99, 111, 112, 121, 114, 105, 103, 104, 116, 32, 58, 10, 45, 105, 91, 48,
  93, 32, 48, 32, 45, 116, 91, 48, 93, 32, 34, 36, 49, 34, 44, 48,
  44, 48, 44, 36, 50, 44, 49, 44, 36, 51, 44, 36, 52, 44, 36, 53,
  32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 48, 93, 32, 48, 32,
  45, 114, 91, 48, 93, 32, 123, 64, 123, 48, 44, 119, 125, 43, 50, 42,
  36, 55, 125, 44, 123, 64, 123, 48, 44, 104, 125, 43, 50, 42, 36, 55,
  125, 44, 49, 44, 51, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46,
  53, 10, 45, 105, 91, 49, 93, 32, 48, 32, 45, 116, 91, 49, 93, 32,
  34, 36, 49, 34, 44, 48, 44, 48, 44, 36, 50, 44, 49, 44, 49, 32,
  45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 49, 93, 32, 48, 32, 45,
  114, 91, 49, 93, 32, 123, 64, 123, 49, 44, 119, 125, 43, 50, 42, 36,
  55, 125, 44, 123, 64, 123, 49, 44, 104, 125, 43, 50, 42, 36, 55, 125,
  44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53,
  32, 45, 100, 105, 108, 97, 116, 101, 91, 49, 93, 32, 123, 49, 43, 50,
  42, 36, 55, 125, 10, 45, 114, 111, 116, 97, 116, 101, 91, 48, 44, 49,
  93, 32, 123, 57, 48, 42, 40, 36, 49, 48, 45, 49, 41, 125, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 50, 125, 10, 45, 105,
  102, 32, 123, 36, 56, 61, 61, 48, 125, 32, 45, 106, 91, 45, 49, 93,
  32, 91, 48, 93, 44, 36, 57, 44, 36, 57, 44, 48, 44, 48, 44, 123,
  36, 54, 47, 50, 53, 53, 125, 44, 91, 49, 93, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 56, 61, 61, 49, 125, 32, 45, 106, 91, 45, 49, 93,
  32, 91, 48, 93, 44, 123, 119, 45, 49, 45, 64, 123, 48, 44, 119, 125,
  45, 36, 57, 125, 44, 36, 57, 44, 48, 44, 48, 44, 123, 36, 54, 47,
  50, 53, 53, 125, 44, 91, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 56, 61, 61, 50, 125, 32, 45, 106, 91, 45, 49, 93, 32, 91, 48,
  93, 44, 36, 57, 44, 123, 104, 45, 49, 45, 64, 123, 48, 44, 104, 125,
  45, 36, 57, 125, 44, 48, 44, 48, 44, 123, 36, 54, 47, 50, 53, 53,
  125, 44, 91, 49, 93, 10, 45, 101, 108, 115, 101, 32, 45, 106, 91, 45,
  49, 93, 32, 91, 48, 93, 44, 123, 119, 45, 49, 45, 64, 123, 48, 44,
  119, 125, 45, 36, 57, 125, 44, 123, 104, 45, 49, 45, 64, 123, 48, 44,
  104, 125, 45, 36, 57, 125, 44, 48, 44, 48, 44, 123, 36, 54, 47, 50,
  53, 53, 125, 44, 91, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  109, 118, 91, 45, 49, 93, 32, 50, 32, 45, 100, 111, 110, 101, 10, 45,
  114, 109, 91, 48, 44, 49, 93, 10, 35, 64, 103, 105, 109, 112, 32, 82,
  97, 105, 110, 98, 111, 119, 32, 58, 32, 103, 105, 109, 112, 95, 114, 97,
  105, 110, 98, 111, 119, 44, 32, 103, 105, 109, 112, 95, 114, 97, 105, 110,
  98, 111, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 101, 102,
  116, 32, 112, 111, 115, 105, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 56, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 82, 105, 103, 104, 116, 32, 112, 111, 115, 105,
  116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 56, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  76, 101, 102, 116, 32, 115, 108, 111, 112, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 55, 53, 44, 48, 44, 52, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 105, 103, 104, 116, 32, 115, 108, 111,
  112, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 55, 53, 44, 48,
  44, 52, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84,
  104, 105, 110, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  51, 44, 48, 46, 49, 44, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 56, 48, 44, 48, 44, 49, 57, 57, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49,
  50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 114, 97, 105, 110, 98, 111, 119,
  32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45,
  115, 112, 108, 105, 110, 101, 91, 45, 49, 93, 32, 48, 44, 36, 49, 37,
  44, 49, 48, 48, 44, 123, 45, 36, 51, 125, 37, 44, 49, 48, 48, 37,
  44, 36, 50, 37, 44, 49, 48, 48, 44, 36, 52, 37, 44, 50, 53, 54,
  44, 49, 44, 49, 10, 45, 102, 108, 111, 111, 100, 91, 45, 49, 93, 32,
  48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 49, 32, 45, 102,
  108, 111, 111, 100, 91, 45, 49, 93, 32, 123, 119, 45, 49, 125, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 49, 44, 49, 10, 45, 100, 105, 115, 116,
  97, 110, 99, 101, 91, 45, 49, 93, 32, 48, 32, 45, 99, 91, 45, 49,
  93, 32, 48, 44, 50, 53, 53, 32, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 123, 36, 53, 42, 50, 53, 53, 125, 10, 45, 114, 97, 105, 110, 98,
  111, 119, 95, 108, 117, 116, 32, 45, 45, 108, 117, 109, 105, 110, 97, 110,
  99, 101, 91, 45, 49, 93, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44,
  123, 109, 105, 110, 40, 49, 48, 48, 44, 50, 48, 48, 45, 36, 54, 41,
  125, 37, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32,
  45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 109, 97, 112,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 105, 102, 32, 123, 36, 54, 60, 49, 48, 48, 125, 32, 45,
  115, 104, 91, 45, 49, 93, 32, 51, 44, 51, 32, 45, 42, 91, 45, 49,
  93, 32, 123, 36, 54, 47, 49, 48, 48, 125, 32, 45, 114, 109, 91, 45,
  49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 98, 108, 101, 110, 100,
  32, 97, 108, 112, 104, 97, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 83, 104, 97, 100, 101, 32,
  98, 111, 98, 115, 32, 58, 32, 103, 105, 109, 112, 95, 115, 104, 97, 100,
  101, 98, 111, 98, 115, 44, 32, 103, 105, 109, 112, 95, 115, 104, 97, 100,
  101, 98, 111, 98, 115, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 66, 111, 98, 115, 32, 112, 97, 114, 97, 109, 101, 116, 101,
  114, 115, 32, 58, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 110, 115, 105, 116, 121, 32,
  61, 32, 105, 110, 116, 40, 53, 48, 44, 49, 44, 50, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 100, 105, 117, 115, 32,
  61, 32, 105, 110, 116, 40, 53, 44, 49, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 117, 114, 97, 116, 105, 111, 110,
  32, 61, 32, 105, 110, 116, 40, 50, 48, 48, 44, 49, 44, 53, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 101, 108, 111, 99,
  105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 67, 117, 114, 118,
  101, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 58, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 82, 120, 32, 61, 32, 102, 108, 111, 97, 116, 40, 45, 49, 44,
  45, 51, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 45, 51, 44, 51,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 122, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 45, 51, 44, 51, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 116, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 56, 44, 45, 51, 44, 51, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 82, 99, 120, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 45, 51, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 111, 108, 111, 114, 109, 97, 112, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 56, 44, 34, 71, 114, 97, 121, 115, 99, 97, 108, 101,
  34, 44, 34, 83, 116, 97, 110, 100, 97, 114, 100, 34, 44, 34, 72, 83,
  86, 34, 44, 34, 76, 105, 110, 101, 115, 34, 44, 34, 72, 111, 116, 34,
  44, 34, 67, 111, 111, 108, 34, 44, 34, 74, 101, 116, 34, 44, 34, 70,
  108, 97, 103, 34, 44, 34, 67, 117, 98, 101, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115,
  99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 50, 47,
  48, 52, 47, 49, 56, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 115, 104, 97, 100, 101, 98,
  111, 98, 115, 32, 58, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  48, 32, 45, 102, 32, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 116, 61, 48, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 36, 51, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  36, 49, 10, 114, 61, 123, 36, 54, 43, 36, 53, 42, 99, 111, 115, 40,
  54, 42, 36, 55, 42, 36, 116, 41, 43, 40, 49, 45, 36, 53, 41, 42,
  115, 105, 110, 40, 54, 42, 36, 56, 42, 36, 116, 41, 125, 10, 97, 61,
  123, 40, 51, 54, 48, 42, 115, 105, 110, 40, 36, 55, 42, 36, 116, 41,
  43, 51, 48, 42, 36, 54, 42, 36, 62, 41, 42, 112, 105, 47, 49, 56,
  48, 125, 10, 97, 120, 61, 123, 50, 42, 36, 62, 42, 112, 105, 47, 36,
  49, 43, 36, 116, 125, 10, 99, 120, 61, 123, 40, 49, 43, 36, 57, 42,
  99, 111, 115, 40, 36, 97, 120, 41, 43, 36, 114, 42, 99, 111, 115, 40,
  36, 97, 41, 41, 42, 119, 47, 50, 125, 10, 99, 121, 61, 123, 40, 49,
  43, 36, 57, 42, 115, 105, 110, 40, 36, 97, 120, 41, 43, 36, 114, 42,
  115, 105, 110, 40, 36, 97, 41, 41, 42, 104, 47, 50, 125, 10, 45, 101,
  108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 99, 120, 44, 36,
  99, 121, 44, 36, 50, 37, 44, 36, 50, 37, 44, 48, 44, 45, 49, 44,
  49, 10, 45, 100, 111, 110, 101, 10, 116, 61, 123, 36, 116, 43, 36, 52,
  47, 49, 48, 48, 125, 10, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 45, 97, 110, 100, 32, 50, 53, 53,
  32, 45, 105, 102, 32, 36, 49, 48, 32, 45, 109, 97, 112, 32, 123, 36,
  49, 48, 45, 49, 125, 32, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103,
  105, 109, 112, 32, 83, 105, 101, 114, 112, 105, 110, 115, 107, 105, 32, 116,
  114, 105, 97, 110, 103, 108, 101, 32, 58, 32, 103, 105, 109, 112, 95, 115,
  105, 101, 114, 112, 105, 110, 115, 107, 105, 44, 32, 103, 105, 109, 112, 95,
  115, 105, 101, 114, 112, 105, 110, 115, 107, 105, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 101, 99, 117, 114, 115, 105, 111, 110,
  115, 32, 61, 32, 105, 110, 116, 40, 54, 44, 48, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 49, 115, 116, 32, 120, 45, 99,
  111, 111, 114, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  49, 115, 116, 32, 121, 45, 99, 111, 111, 114, 100, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 50, 110, 100, 32, 120, 45, 99, 111, 111, 114,
  100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 50, 110, 100, 32,
  121, 45, 99, 111, 111, 114, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 48, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 51, 114, 100, 32, 120, 45, 99, 111, 111, 114, 100, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 51, 114, 100, 32,
  121, 45, 99, 111, 111, 114, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 48, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111,
  114, 40, 49, 50, 56, 44, 49, 50, 56, 44, 49, 50, 56, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65,
  117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32,
  84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59,
  60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49,
  48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 115, 105, 101, 114,
  112, 105, 110, 115, 107, 105, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105,
  116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91, 48, 93, 10,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 115, 105, 101, 114, 112,
  105, 110, 115, 107, 105, 91, 45, 49, 93, 32, 36, 123, 49, 45, 55, 125,
  10, 45, 45, 102, 99, 91, 45, 50, 93, 32, 36, 56, 44, 36, 57, 44,
  36, 49, 48, 32, 45, 106, 91, 48, 93, 32, 91, 45, 49, 93, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 36, 49, 49, 44, 91, 45, 50, 93, 44,
  50, 53, 53, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45,
  101, 110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 83, 110, 111,
  119, 102, 108, 97, 107, 101, 32, 58, 32, 103, 105, 109, 112, 95, 115, 110,
  111, 119, 102, 108, 97, 107, 101, 44, 32, 103, 105, 109, 112, 95, 115, 110,
  111, 119, 102, 108, 97, 107, 101, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 82, 101, 99, 117, 114, 115, 105, 111, 110, 115, 32, 61,
  32, 105, 110, 116, 40, 51, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 49, 115, 116, 32, 120, 45, 99, 111, 111, 114, 100,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 49, 115, 116, 32,
  121, 45, 99, 111, 111, 114, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  55, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 50, 110, 100, 32, 120, 45, 99, 111, 111, 114, 100, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 56, 48, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 50, 110, 100, 32, 121, 45,
  99, 111, 111, 114, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 55, 48,
  44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 51, 114, 100, 32, 120, 45, 99, 111, 111, 114, 100, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 51, 114, 100, 32, 121, 45, 99, 111,
  111, 114, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79,
  112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 49, 50, 56,
  44, 49, 50, 56, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47,
  50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 115, 110, 111, 119, 102, 108, 97, 107, 101,
  32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99,
  105, 116, 121, 32, 45, 108, 91, 48, 93, 10, 45, 115, 110, 111, 119, 102,
  108, 97, 107, 101, 32, 36, 123, 49, 45, 49, 49, 125, 10, 45, 101, 110,
  100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 83, 112, 105, 114, 97,
  108, 32, 58, 32, 109, 97, 116, 104, 109, 97, 112, 95, 115, 112, 105, 114,
  97, 108, 44, 32, 109, 97, 116, 104, 109, 97, 112, 95, 115, 112, 105, 114,
  97, 108, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 111, 116, 97,
  116, 105, 111, 110, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44,
  48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84,
  105, 109, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 41, 10, 109, 97, 116, 104, 109, 97, 112, 95, 115, 112, 105, 114, 97,
  108, 58, 10, 113, 61, 34, 115, 105, 110, 40, 114, 109, 97, 116, 104, 42,
  36, 49, 42, 112, 105, 42, 50, 45, 97, 109, 97, 116, 104, 43, 36, 50,
  42, 50, 42, 112, 105, 41, 42, 48, 46, 53, 43, 48, 46, 53, 34, 10,
  45, 109, 97, 116, 104, 109, 97, 112, 95, 103, 114, 97, 121, 67, 111, 108,
  111, 114, 32, 36, 113, 10, 109, 97, 116, 104, 109, 97, 112, 95, 120, 121,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 109, 97, 116, 104, 109,
  97, 112, 32, 120, 121, 58, 32, 102, 111, 110, 99, 116, 105, 111, 110, 32,
  119, 105, 116, 104, 32, 102, 111, 114, 109, 117, 108, 97, 115, 32, 58, 32,
  34, 36, 49, 34, 32, 97, 110, 100, 32, 34, 36, 50, 34, 46, 34, 10,
  45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 111, 99, 97, 108, 91, 64, 123, 62, 44, 45, 49, 125, 93, 10,
  123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 49, 32, 91, 45, 49, 93,
  32, 45, 114, 101, 118, 101, 114, 115, 101, 10, 45, 102, 105, 108, 108, 91,
  48, 93, 32, 34, 72, 61, 50, 42, 104, 47, 109, 97, 120, 40, 119, 44,
  104, 41, 59, 87, 61, 50, 42, 119, 47, 109, 97, 120, 40, 119, 44, 104,
  41, 59, 120, 48, 61, 40, 119, 45, 49, 41, 47, 50, 43, 49, 101, 45,
  49, 48, 59, 32, 121, 48, 61, 40, 104, 45, 49, 41, 47, 50, 59, 32,
  120, 109, 97, 116, 104, 61, 40, 120, 45, 120, 48, 41, 42, 87, 47, 119,
  59, 32, 32, 121, 109, 97, 116, 104, 61, 45, 40, 121, 45, 121, 48, 41,
  42, 72, 47, 104, 59, 32, 40, 36, 49, 41, 42, 119, 47, 87, 43, 120,
  48, 34, 10, 45, 102, 105, 108, 108, 91, 49, 93, 32, 34, 72, 61, 50,
  42, 104, 47, 109, 97, 120, 40, 119, 44, 104, 41, 59, 87, 61, 50, 42,
  119, 47, 109, 97, 120, 40, 119, 44, 104, 41, 59, 120, 48, 61, 40, 119,
  45, 49, 41, 47, 50, 43, 49, 101, 45, 49, 48, 59, 32, 121, 48, 61,
  40, 104, 45, 49, 41, 47, 50, 59, 32, 120, 109, 97, 116, 104, 61, 40,
  120, 45, 120, 48, 41, 42, 87, 47, 119, 59, 32, 32, 121, 109, 97, 116,
  104, 61, 45, 40, 121, 45, 121, 48, 41, 42, 72, 47, 104, 59, 32, 45,
  40, 36, 50, 41, 42, 104, 47, 72, 43, 121, 48, 34, 10, 45, 97, 91,
  48, 44, 49, 93, 32, 99, 10, 45, 119, 97, 114, 112, 91, 45, 49, 93,
  32, 91, 48, 93, 44, 48, 44, 49, 44, 48, 10, 45, 107, 91, 45, 49,
  93, 10, 45, 101, 110, 100, 108, 111, 99, 97, 108, 32, 45, 100, 111, 110,
  101, 10, 45, 118, 32, 43, 10, 109, 97, 116, 104, 109, 97, 112, 95, 114,
  97, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 109, 97, 116, 104,
  109, 97, 112, 32, 114, 97, 58, 32, 102, 111, 110, 99, 116, 105, 111, 110,
  32, 119, 105, 116, 104, 32, 102, 111, 114, 109, 117, 108, 97, 115, 32, 58,
  32, 34, 36, 49, 34, 32, 97, 110, 100, 32, 34, 36, 50, 34, 46, 34,
  10, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 111, 99, 97, 108, 91, 64, 123, 62, 44, 45, 49, 125, 93,
  10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 49, 32, 91, 45, 49,
  93, 32, 45, 114, 101, 118, 101, 114, 115, 101, 10, 45, 102, 105, 108, 108,
  91, 48, 93, 32, 34, 120, 48, 61, 40, 119, 45, 49, 41, 47, 50, 43,
  49, 101, 45, 49, 48, 59, 32, 121, 48, 61, 40, 104, 45, 49, 41, 47,
  50, 59, 32, 114, 109, 97, 116, 104, 61, 40, 40, 120, 45, 120, 48, 41,
  94, 50, 43, 40, 121, 45, 121, 48, 41, 94, 50, 41, 94, 48, 46, 53,
  42, 50, 47, 119, 59, 32, 97, 109, 97, 116, 104, 61, 40, 97, 116, 97,
  110, 40, 45, 40, 121, 45, 121, 48, 41, 47, 40, 120, 45, 120, 48, 41,
  41, 43, 112, 105, 47, 50, 42, 40, 115, 105, 103, 110, 40, 120, 45, 120,
  48, 41, 45, 49, 41, 41, 37, 40, 50, 42, 112, 105, 41, 59, 32, 120,
  48, 43, 40, 36, 49, 41, 42, 120, 48, 42, 99, 111, 115, 40, 36, 50,
  41, 34, 10, 45, 102, 105, 108, 108, 91, 49, 93, 32, 34, 120, 48, 61,
  40, 119, 45, 49, 41, 47, 50, 43, 49, 101, 45, 49, 48, 59, 32, 121,
  48, 61, 40, 104, 45, 49, 41, 47, 50, 59, 32, 114, 109, 97, 116, 104,
  61, 40, 40, 120, 45, 120, 48, 41, 94, 50, 43, 40, 121, 45, 121, 48,
  41, 94, 50, 41, 94, 48, 46, 53, 42, 50, 47, 119, 59, 32, 97, 109,
  97, 116, 104, 61, 40, 97, 116, 97, 110, 40, 45, 40, 121, 45, 121, 48,
  41, 47, 40, 120, 45, 120, 48, 41, 41, 43, 112, 105, 47, 50, 42, 40,
  115, 105, 103, 110, 40, 120, 45, 120, 48, 41, 45, 49, 41, 41, 37, 40,
  50, 42, 112, 105, 41, 59, 32, 121, 48, 45, 40, 36, 49, 41, 42, 120,
  48, 42, 115, 105, 110, 40, 36, 50, 41, 34, 10, 45, 97, 91, 48, 44,
  49, 93, 32, 99, 10, 45, 119, 97, 114, 112, 91, 45, 49, 93, 32, 91,
  48, 93, 44, 48, 44, 49, 44, 48, 10, 45, 107, 91, 45, 49, 93, 10,
  45, 101, 110, 100, 108, 111, 99, 97, 108, 32, 45, 100, 111, 110, 101, 10,
  45, 118, 32, 43, 10, 109, 97, 116, 104, 109, 97, 112, 95, 103, 114, 97,
  121, 67, 111, 108, 111, 114, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 109, 97, 116, 104, 109, 97, 112, 32, 103, 114, 97, 121, 67, 111, 108,
  111, 114, 58, 32, 102, 111, 110, 99, 116, 105, 111, 110, 32, 119, 105, 116,
  104, 32, 102, 111, 114, 109, 117, 108, 97, 115, 32, 58, 32, 34, 36, 49,
  34, 46, 34, 10, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 111, 99, 97, 108, 91, 64, 123, 62, 44, 45,
  49, 125, 93, 10, 45, 114, 101, 115, 105, 122, 101, 32, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 44, 49, 10, 45, 102, 105, 108, 108, 32,
  34, 72, 61, 50, 42, 104, 47, 109, 97, 120, 40, 119, 44, 104, 41, 59,
  87, 61, 50, 42, 119, 47, 109, 97, 120, 40, 119, 44, 104, 41, 59, 120,
  48, 61, 40, 119, 45, 49, 41, 47, 50, 43, 49, 101, 45, 49, 48, 59,
  32, 121, 48, 61, 40, 104, 45, 49, 41, 47, 50, 59, 32, 114, 109, 97,
  116, 104, 61, 40, 40, 120, 45, 120, 48, 41, 94, 50, 43, 40, 121, 45,
  121, 48, 41, 94, 50, 41, 94, 48, 46, 53, 42, 50, 47, 119, 59, 32,
  97, 109, 97, 116, 104, 61, 40, 97, 116, 97, 110, 40, 45, 40, 121, 45,
  121, 48, 41, 47, 40, 120, 45, 120, 48, 41, 41, 43, 112, 105, 47, 50,
  42, 40, 115, 105, 103, 110, 40, 120, 45, 120, 48, 41, 45, 49, 41, 41,
  37, 40, 50, 42, 112, 105, 41, 59, 32, 40, 36, 49, 41, 34, 10, 45,
  110, 32, 48, 44, 50, 53, 53, 32, 45, 116, 111, 95, 114, 103, 98, 97,
  10, 45, 101, 110, 100, 108, 111, 99, 97, 108, 32, 45, 100, 111, 110, 101,
  10, 45, 118, 32, 43, 10, 35, 64, 103, 105, 109, 112, 32, 83, 117, 112,
  101, 114, 102, 111, 114, 109, 117, 108, 97, 32, 58, 32, 103, 105, 109, 112,
  95, 115, 117, 112, 101, 114, 102, 111, 114, 109, 117, 108, 97, 44, 32, 103,
  105, 109, 112, 95, 115, 117, 112, 101, 114, 102, 111, 114, 109, 117, 108, 97,
  40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 115,
  111, 108, 117, 116, 105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 52, 48,
  57, 54, 44, 50, 44, 56, 49, 57, 50, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88,
  45, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  57, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  89, 45, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  46, 57, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 32, 61, 32,
  105, 110, 116, 40, 56, 44, 49, 44, 51, 50, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 49, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 44, 45, 51, 50, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 50, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44,
  45, 51, 50, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 51, 32, 61, 32, 102, 108, 111, 97, 116, 40, 56, 44, 45, 51,
  50, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 97, 110, 103, 108,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 51, 54,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 97, 110,
  103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 45,
  97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 105, 99, 107,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44, 48,
  44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111,
  108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 49, 50, 56, 44,
  50, 53, 53, 44, 49, 50, 56, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115,
  99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47,
  48, 52, 47, 49, 56, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 115, 117, 112, 101, 114, 102,
  111, 114, 109, 117, 108, 97, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 116, 111, 95, 114,
  103, 98, 97, 10, 123, 119, 125, 44, 123, 104, 125, 10, 45, 102, 51, 100,
  32, 123, 48, 46, 53, 42, 109, 97, 120, 40, 119, 44, 104, 41, 47, 116,
  97, 110, 40, 36, 52, 42, 112, 105, 47, 51, 54, 48, 41, 125, 10, 45,
  115, 117, 112, 101, 114, 102, 111, 114, 109, 117, 108, 97, 51, 100, 32, 36,
  49, 44, 36, 123, 52, 45, 55, 125, 10, 45, 114, 51, 100, 91, 45, 49,
  93, 32, 48, 44, 48, 44, 49, 44, 36, 49, 48, 32, 45, 114, 51, 100,
  91, 45, 49, 93, 32, 48, 44, 49, 44, 48, 44, 36, 57, 32, 45, 114,
  51, 100, 91, 45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 36, 56, 10,
  45, 42, 51, 100, 91, 45, 49, 93, 32, 123, 48, 46, 53, 42, 36, 50,
  42, 64, 123, 45, 50, 44, 119, 125, 125, 44, 123, 48, 46, 53, 42, 36,
  51, 42, 64, 123, 45, 50, 44, 104, 125, 125, 10, 45, 99, 111, 108, 51,
  100, 91, 45, 49, 93, 32, 49, 32, 45, 111, 98, 106, 101, 99, 116, 51,
  100, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 53, 48, 37, 44, 53,
  48, 37, 44, 48, 44, 49, 44, 49, 44, 48, 44, 48, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45,
  49, 93, 32, 49, 32, 45, 103, 116, 91, 45, 49, 93, 32, 36, 49, 49,
  37, 32, 45, 42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 101,
  113, 91, 45, 49, 93, 32, 48, 10, 45, 114, 91, 45, 49, 93, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 52, 10, 45, 115, 104,
  91, 45, 49, 93, 32, 48, 44, 48, 32, 45, 42, 91, 45, 49, 93, 32,
  36, 49, 50, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91,
  45, 49, 93, 32, 49, 44, 49, 32, 45, 42, 91, 45, 49, 93, 32, 36,
  49, 51, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 45,
  49, 93, 32, 50, 44, 50, 32, 45, 42, 91, 45, 49, 93, 32, 36, 49,
  52, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 91, 45, 49,
  93, 32, 51, 44, 51, 32, 45, 42, 91, 45, 49, 93, 32, 36, 49, 53,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 43, 91, 45, 50, 44, 45,
  49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103,
  105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 52, 61,
  49, 125, 44, 36, 123, 53, 61, 48, 125, 44, 36, 123, 54, 61, 36, 53,
  125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 105, 102,
  32, 36, 53, 32, 119, 105, 100, 116, 104, 61, 36, 53, 32, 45, 101, 108,
  115, 101, 32, 119, 105, 100, 116, 104, 61, 123, 119, 125, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 36, 54, 32, 104, 101, 105, 103, 104,
  116, 61, 36, 54, 32, 45, 101, 108, 115, 101, 32, 104, 101, 105, 103, 104,
  116, 61, 123, 104, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 36, 52, 32, 45, 115, 91, 45, 49, 93, 32, 120, 44, 50, 32, 45,
  101, 108, 115, 101, 32, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 36, 49, 91, 45, 50, 93, 32, 36, 50, 32, 45, 36, 49, 91,
  45, 49, 93, 32, 36, 51, 10, 45, 114, 91, 45, 50, 44, 45, 49, 93,
  32, 123, 109, 97, 120, 40, 119, 44, 64, 123, 45, 50, 44, 119, 125, 41,
  125, 44, 123, 109, 97, 120, 40, 104, 44, 64, 123, 45, 50, 44, 104, 125,
  41, 125, 44, 49, 44, 49, 48, 48, 37, 44, 51, 10, 45, 105, 102, 32,
  123, 33, 36, 52, 125, 32, 45, 99, 111, 108, 117, 109, 110, 115, 91, 45,
  50, 93, 32, 48, 44, 53, 48, 37, 32, 45, 99, 111, 108, 117, 109, 110,
  115, 91, 45, 49, 93, 32, 53, 48, 37, 44, 49, 48, 48, 37, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32,
  120, 32, 45, 114, 91, 45, 49, 93, 32, 36, 119, 105, 100, 116, 104, 44,
  36, 104, 101, 105, 103, 104, 116, 44, 49, 44, 49, 48, 48, 37, 44, 50,
  32, 45, 100, 114, 103, 98, 97, 91, 45, 49, 93, 10, 45, 108, 105, 110,
  101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 48, 44, 53, 48, 37, 44,
  49, 48, 48, 37, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53,
  10, 45, 116, 101, 120, 116, 95, 111, 117, 116, 108, 105, 110, 101, 91, 45,
  49, 93, 32, 34, 83, 116, 97, 114, 116, 34, 44, 49, 44, 48, 44, 49,
  51, 44, 49, 44, 49, 44, 50, 53, 53, 32, 45, 116, 101, 120, 116, 95,
  111, 117, 116, 108, 105, 110, 101, 91, 45, 49, 93, 32, 34, 69, 110, 100,
  34, 44, 123, 119, 45, 50, 51, 125, 44, 123, 104, 45, 49, 54, 125, 44,
  49, 51, 44, 49, 44, 49, 44, 50, 53, 53, 10, 45, 109, 118, 91, 45,
  49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109,
  112, 32, 95, 10, 35, 64, 103, 105, 109, 112, 32, 60, 98, 62, 82, 101,
  112, 97, 105, 114, 60, 47, 98, 62, 10, 35, 64, 103, 105, 109, 112, 32,
  66, 97, 110, 100, 105, 110, 103, 32, 100, 101, 110, 111, 105, 115, 101, 32,
  58, 32, 98, 97, 110, 100, 105, 110, 103, 95, 100, 101, 110, 111, 105, 115,
  101, 44, 32, 98, 97, 110, 100, 105, 110, 103, 95, 100, 101, 110, 111, 105,
  115, 101, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 86, 32, 99, 117, 116, 111, 102, 102, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 53, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 32, 99, 117, 116, 111, 102,
  102, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 53, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 97, 99, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 50, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108, 117, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 111, 119, 32,
  100, 105, 102, 102, 101, 114, 101, 110, 99, 101, 32, 61, 32, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 32, 58, 32, 60, 105, 62, 73, 97, 105, 110, 32, 70, 101,
  114, 103, 117, 115, 115, 111, 110, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 98, 97, 110, 100, 105, 110, 103, 95, 100,
  101, 110, 111, 105, 115, 101, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  50, 32, 45, 45, 98, 105, 108, 97, 116, 101, 114, 97, 108, 91, 45, 49,
  93, 32, 36, 51, 44, 36, 52, 32, 45, 107, 101, 101, 112, 91, 48, 44,
  45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 45, 99, 111, 109, 112,
  111, 115, 101, 95, 103, 114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116,
  91, 48, 44, 49, 93, 10, 45, 102, 102, 116, 112, 111, 108, 97, 114, 91,
  45, 49, 93, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 50, 93,
  32, 52, 44, 48, 44, 123, 40, 104, 47, 50, 41, 43, 49, 125, 44, 123,
  53, 48, 45, 36, 49, 125, 37, 44, 123, 40, 104, 47, 50, 41, 43, 49,
  125, 44, 123, 53, 48, 45, 36, 49, 125, 37, 44, 123, 40, 104, 47, 50,
  41, 45, 49, 125, 44, 48, 44, 123, 40, 104, 47, 50, 41, 45, 49, 125,
  10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 50, 93, 32, 52, 44,
  123, 53, 48, 43, 36, 49, 125, 37, 44, 123, 40, 104, 47, 50, 41, 43,
  49, 125, 44, 123, 119, 125, 44, 123, 40, 104, 47, 50, 41, 43, 49, 125,
  44, 123, 119, 125, 44, 123, 40, 104, 47, 50, 41, 45, 49, 125, 44, 123,
  53, 48, 43, 36, 49, 125, 37, 44, 123, 40, 104, 47, 50, 41, 45, 49,
  125, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 50, 93, 32, 52,
  44, 123, 40, 119, 47, 50, 41, 43, 49, 125, 44, 48, 44, 123, 40, 119,
  47, 50, 41, 43, 49, 125, 44, 123, 53, 48, 45, 36, 50, 125, 37, 44,
  123, 40, 119, 47, 50, 41, 45, 49, 125, 44, 123, 53, 48, 45, 36, 50,
  125, 37, 44, 123, 40, 119, 47, 50, 41, 45, 49, 125, 44, 48, 10, 45,
  112, 111, 108, 121, 103, 111, 110, 91, 45, 50, 93, 32, 52, 44, 123, 40,
  119, 47, 50, 41, 45, 49, 125, 44, 123, 104, 125, 44, 123, 40, 119, 47,
  50, 41, 43, 49, 125, 44, 123, 104, 125, 44, 123, 40, 119, 47, 50, 41,
  43, 49, 125, 44, 123, 53, 48, 43, 36, 50, 125, 37, 44, 123, 40, 119,
  47, 50, 41, 45, 49, 125, 44, 123, 53, 48, 43, 36, 50, 125, 37, 10,
  45, 105, 102, 102, 116, 112, 111, 108, 97, 114, 91, 45, 49, 44, 45, 50,
  93, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110,
  109, 101, 114, 103, 101, 91, 49, 44, 50, 93, 10, 45, 107, 101, 101, 112,
  91, 45, 49, 93, 10, 98, 97, 110, 100, 105, 110, 103, 95, 100, 101, 110,
  111, 105, 115, 101, 95, 112, 114, 101, 118, 105, 101, 119, 58, 10, 45, 105,
  102, 32, 123, 36, 53, 61, 61, 48, 125, 10, 45, 98, 97, 110, 100, 105,
  110, 103, 95, 100, 101, 110, 111, 105, 115, 101, 32, 36, 123, 49, 45, 45,
  49, 125, 10, 45, 101, 108, 115, 101, 10, 45, 45, 98, 97, 110, 100, 105,
  110, 103, 95, 100, 101, 110, 111, 105, 115, 101, 32, 36, 123, 49, 45, 45,
  49, 125, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105,
  110, 101, 120, 116, 114, 97, 99, 116, 91, 48, 44, 49, 93, 10, 45, 45,
  91, 45, 49, 93, 32, 49, 50, 56, 32, 45, 42, 91, 45, 49, 93, 32,
  53, 32, 45, 43, 91, 45, 49, 93, 32, 49, 50, 56, 10, 45, 101, 110,
  100, 105, 102, 10, 35, 64, 103, 105, 109, 112, 32, 66, 97, 121, 101, 114,
  32, 114, 101, 99, 111, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 32,
  58, 32, 98, 97, 121, 101, 114, 50, 114, 103, 98, 44, 32, 103, 105, 109,
  112, 95, 110, 111, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 71, 47, 109, 32, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 61, 32, 95, 102, 108, 111, 97, 116, 40, 54, 44,
  48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  47, 98, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 40, 112,
  114, 105, 110, 99, 105, 112, 97, 108, 41, 32, 61, 32, 95, 102, 108, 111,
  97, 116, 40, 54, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 82, 47, 98, 32, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 40, 115, 101, 99, 111, 110, 100, 97, 114, 121, 41, 32, 61,
  32, 95, 102, 108, 111, 97, 116, 40, 52, 44, 48, 44, 50, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 68,
  101, 105, 110, 116, 101, 114, 108, 97, 99, 101, 32, 58, 32, 100, 101, 105,
  110, 116, 101, 114, 108, 97, 99, 101, 44, 32, 103, 105, 109, 112, 95, 100,
  101, 105, 110, 116, 101, 114, 108, 97, 99, 101, 95, 112, 114, 101, 118, 105,
  101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  108, 103, 111, 114, 105, 116, 104, 109, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 83, 116, 97, 110, 100, 97, 114, 100, 34, 44, 34, 77, 111,
  116, 105, 111, 110, 45, 99, 111, 109, 112, 101, 110, 115, 97, 116, 101, 100,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80,
  114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68,
  117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104,
  117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50,
  47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 103, 105, 109, 112, 95, 100, 101, 105, 110, 116, 101, 114, 108,
  97, 99, 101, 32, 58, 10, 45, 100, 101, 105, 110, 116, 101, 114, 108, 97,
  99, 101, 32, 48, 32, 45, 115, 107, 105, 112, 32, 36, 123, 94, 48, 125,
  10, 103, 105, 109, 112, 95, 100, 101, 105, 110, 116, 101, 114, 108, 97, 99,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 100, 101, 105, 110, 116, 101, 114, 108, 97,
  99, 101, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 68, 101, 115, 112, 101, 99, 107, 108, 101, 32, 58, 32, 103, 99,
  100, 95, 100, 101, 115, 112, 101, 99, 107, 108, 101, 44, 32, 103, 99, 100,
  95, 100, 101, 115, 112, 101, 99, 107, 108, 101, 40, 51, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 105, 62, 82, 101, 109, 111, 118, 101, 32, 115, 109,
  97, 108, 108, 32, 100, 111, 116, 115, 32, 97, 110, 100, 32, 115, 112, 101,
  99, 107, 115, 60, 47, 105, 62, 34, 41, 44, 32, 115, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 84, 111, 108, 101, 114, 97, 110, 99, 101, 32,
  61, 32, 105, 110, 116, 40, 50, 48, 44, 48, 44, 53, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 77, 97, 120, 32, 97, 114, 101, 97,
  32, 61, 32, 105, 110, 116, 40, 49, 48, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 71, 97, 114,
  97, 103, 101, 99, 111, 100, 101, 114, 60, 47, 105, 62, 46, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32,
  60, 105, 62, 50, 48, 49, 51, 47, 48, 50, 47, 48, 49, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 92, 110, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 60,
  117, 62, 78, 111, 116, 101, 115, 60, 47, 117, 62, 60, 47, 98, 62, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 83, 101, 116, 32, 109, 97, 120, 32, 97,
  114, 101, 97, 32, 116, 111, 32, 48, 32, 102, 111, 114, 32, 110, 111, 32,
  97, 114, 101, 97, 32, 115, 105, 122, 101, 32, 108, 105, 109, 105, 116, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 99, 100, 95, 100,
  101, 115, 112, 101, 99, 107, 108, 101, 32, 58, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 49, 61, 49, 53, 125, 44, 36, 123, 50, 61, 51, 48, 125,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 109, 97, 61, 123, 105, 102, 40, 33, 36, 50, 44, 119, 42,
  104, 44, 36, 50, 41, 125, 10, 45, 45, 108, 97, 98, 101, 108, 91, 45,
  49, 93, 32, 36, 49, 44, 49, 32, 110, 98, 61, 64, 123, 45, 49, 44,
  49, 43, 105, 77, 125, 10, 45, 45, 104, 105, 115, 116, 111, 103, 114, 97,
  109, 91, 45, 49, 93, 32, 36, 110, 98, 44, 48, 44, 123, 36, 110, 98,
  45, 49, 125, 10, 45, 109, 97, 112, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 108, 101, 91, 45, 49,
  93, 32, 36, 109, 97, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53,
  10, 45, 105, 110, 112, 97, 105, 110, 116, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 73, 97,
  105, 110, 39, 115, 32, 102, 97, 115, 116, 32, 100, 101, 110, 111, 105, 115,
  101, 32, 112, 32, 58, 32, 105, 97, 105, 110, 95, 102, 97, 115, 116, 95,
  100, 101, 110, 111, 105, 115, 101, 95, 112, 44, 105, 97, 105, 110, 95, 102,
  97, 115, 116, 95, 100, 101, 110, 111, 105, 115, 101, 95, 112, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 76, 117, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  104, 114, 111, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 97,
  109, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 49, 44, 46,
  53, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101,
  115, 112, 101, 99, 107, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  68, 105, 116, 104, 101, 114, 32, 111, 117, 116, 112, 117, 116, 32, 61, 32,
  98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 80, 114, 101, 118, 105, 101, 119, 32, 115, 104, 111, 119, 115, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 32, 40, 48, 44, 34, 78, 111, 114, 109,
  97, 108, 32, 79, 117, 116, 112, 117, 116, 34, 44, 34, 76, 117, 109, 97,
  32, 78, 111, 105, 115, 101, 34, 44, 32, 32, 34, 67, 104, 114, 111, 109,
  97, 32, 78, 111, 105, 115, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80,
  97, 114, 97, 108, 108, 101, 108, 32, 112, 114, 111, 99, 101, 115, 115, 105,
  110, 103, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 79,
  102, 102, 34, 44, 34, 65, 117, 116, 111, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 84, 104, 105,
  115, 32, 110, 111, 105, 115, 101, 32, 114, 101, 100, 117, 99, 116, 105, 111,
  110, 32, 102, 105, 108, 116, 101, 114, 32, 105, 115, 32, 100, 101, 115, 105,
  103, 110, 101, 100, 32, 102, 111, 114, 32, 115, 112, 101, 101, 100, 44, 32,
  97, 110, 100, 32, 115, 111, 109, 101, 32, 113, 117, 97, 108, 105, 116, 121,
  32, 104, 97, 115, 32, 98, 101, 101, 110, 32, 115, 97, 99, 114, 105, 102,
  105, 99, 101, 100, 46, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 58, 32, 73, 97, 105, 110, 32, 70, 101,
  114, 103, 117, 115, 115, 111, 110, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 85,
  112, 100, 97, 116, 101, 32, 50, 54, 32, 79, 99, 116, 32, 50, 48, 49,
  51, 32, 45, 32, 112, 97, 114, 97, 108, 108, 101, 108, 32, 112, 114, 111,
  99, 101, 115, 115, 105, 110, 103, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 82,
  101, 108, 101, 97, 115, 101, 100, 32, 50, 50, 32, 70, 101, 98, 32, 50,
  48, 49, 51, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 105, 97,
  105, 110, 95, 102, 97, 115, 116, 95, 100, 101, 110, 111, 105, 115, 101, 95,
  112, 58, 10, 45, 116, 105, 99, 10, 45, 105, 102, 32, 36, 55, 10, 45,
  97, 112, 112, 108, 121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111,
  118, 101, 114, 108, 97, 112, 32, 34, 45, 105, 97, 105, 110, 95, 102, 97,
  115, 116, 95, 100, 101, 110, 111, 105, 115, 101, 32, 36, 123, 49, 45, 45,
  49, 125, 34, 44, 54, 52, 44, 48, 10, 45, 101, 108, 115, 101, 10, 45,
  105, 97, 105, 110, 95, 102, 97, 115, 116, 95, 100, 101, 110, 111, 105, 115,
  101, 32, 36, 123, 49, 45, 45, 49, 125, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 116, 111, 99, 10, 105, 97, 105, 110, 95, 102, 97, 115, 116, 95,
  100, 101, 110, 111, 105, 115, 101, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105,
  116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91, 48, 93, 10,
  102, 97, 115, 116, 108, 117, 109, 97, 49, 61, 123, 36, 49, 42, 53, 48,
  48, 48, 125, 10, 102, 97, 115, 116, 108, 117, 109, 97, 50, 61, 123, 36,
  102, 97, 115, 116, 108, 117, 109, 97, 49, 42, 46, 57, 125, 10, 102, 97,
  115, 116, 108, 117, 109, 97, 51, 61, 123, 36, 102, 97, 115, 116, 108, 117,
  109, 97, 49, 42, 46, 54, 53, 125, 10, 102, 97, 115, 116, 108, 117, 109,
  97, 52, 61, 123, 36, 102, 97, 115, 116, 108, 117, 109, 97, 49, 42, 46,
  52, 52, 125, 10, 102, 97, 115, 116, 99, 104, 114, 111, 109, 97, 49, 61,
  123, 36, 50, 42, 53, 48, 48, 48, 125, 10, 102, 97, 115, 116, 99, 104,
  114, 111, 109, 97, 50, 61, 36, 102, 97, 115, 116, 99, 104, 114, 111, 109,
  97, 49, 10, 102, 97, 115, 116, 99, 104, 114, 111, 109, 97, 51, 61, 123,
  36, 102, 97, 115, 116, 99, 104, 114, 111, 109, 97, 50, 47, 50, 125, 10,
  102, 97, 115, 116, 99, 104, 114, 111, 109, 97, 52, 61, 123, 36, 102, 97,
  115, 116, 99, 104, 114, 111, 109, 97, 51, 47, 50, 125, 10, 100, 101, 115,
  112, 101, 99, 107, 108, 101, 95, 116, 104, 114, 101, 115, 104, 111, 108, 100,
  61, 123, 40, 36, 52, 47, 50, 53, 41, 42, 49, 48, 48, 48, 48, 48,
  125, 10, 45, 105, 102, 32, 123, 36, 51, 33, 61, 49, 125, 10, 115, 99,
  97, 108, 101, 61, 123, 50, 53, 53, 42, 49, 48, 48, 48, 125, 10, 101,
  120, 61, 123, 36, 51, 125, 10, 112, 116, 49, 120, 61, 123, 36, 115, 99,
  97, 108, 101, 42, 48, 46, 48, 50, 53, 125, 10, 112, 116, 50, 120, 61,
  123, 36, 115, 99, 97, 108, 101, 42, 48, 46, 48, 53, 125, 10, 112, 116,
  51, 120, 61, 123, 36, 115, 99, 97, 108, 101, 42, 48, 46, 48, 55, 53,
  125, 10, 112, 116, 52, 120, 61, 123, 36, 115, 99, 97, 108, 101, 42, 48,
  46, 49, 125, 10, 112, 116, 53, 120, 61, 123, 36, 115, 99, 97, 108, 101,
  42, 48, 46, 49, 50, 53, 125, 10, 112, 116, 54, 120, 61, 123, 36, 115,
  99, 97, 108, 101, 42, 48, 46, 49, 53, 125, 10, 112, 116, 55, 120, 61,
  123, 36, 115, 99, 97, 108, 101, 42, 48, 46, 49, 55, 53, 125, 10, 112,
  116, 56, 120, 61, 123, 36, 115, 99, 97, 108, 101, 42, 48, 46, 50, 125,
  10, 112, 116, 57, 120, 61, 123, 36, 115, 99, 97, 108, 101, 42, 48, 46,
  50, 50, 53, 125, 10, 112, 116, 49, 48, 120, 61, 123, 36, 115, 99, 97,
  108, 101, 42, 48, 46, 50, 53, 125, 10, 112, 116, 49, 49, 120, 61, 123,
  36, 115, 99, 97, 108, 101, 42, 48, 46, 50, 55, 53, 125, 10, 112, 116,
  49, 50, 120, 61, 123, 36, 115, 99, 97, 108, 101, 42, 48, 46, 51, 125,
  10, 112, 116, 49, 51, 120, 61, 123, 36, 115, 99, 97, 108, 101, 42, 48,
  46, 51, 50, 53, 125, 10, 112, 116, 49, 52, 120, 61, 123, 36, 115, 99,
  97, 108, 101, 42, 48, 46, 51, 53, 125, 10, 112, 116, 49, 53, 120, 61,
  123, 36, 115, 99, 97, 108, 101, 42, 48, 46, 51, 55, 53, 125, 10, 112,
  116, 49, 54, 120, 61, 123, 36, 115, 99, 97, 108, 101, 42, 48, 46, 52,
  125, 10, 112, 116, 49, 55, 120, 61, 123, 36, 115, 99, 97, 108, 101, 42,
  48, 46, 52, 50, 53, 125, 10, 112, 116, 49, 56, 120, 61, 123, 36, 115,
  99, 97, 108, 101, 42, 48, 46, 52, 53, 125, 10, 112, 116, 49, 57, 120,
  61, 123, 36, 115, 99, 97, 108, 101, 42, 48, 46, 52, 55, 53, 125, 10,
  112, 116, 50, 48, 120, 61, 123, 36, 115, 99, 97, 108, 101, 42, 48, 46,
  53, 125, 10, 112, 116, 50, 49, 120, 61, 123, 36, 115, 99, 97, 108, 101,
  42, 48, 46, 53, 50, 53, 125, 10, 112, 116, 50, 50, 120, 61, 123, 36,
  115, 99, 97, 108, 101, 42, 48, 46, 53, 53, 125, 10, 112, 116, 50, 51,
  120, 61, 123, 36, 115, 99, 97, 108, 101, 42, 48, 46, 53, 55, 53, 125,
  10, 112, 116, 50, 52, 120, 61, 123, 36, 115, 99, 97, 108, 101, 42, 48,
  46, 54, 125, 10, 112, 116, 50, 53, 120, 61, 123, 36, 115, 99, 97, 108,
  101, 42, 48, 46, 54, 50, 53, 125, 10, 112, 116, 50, 54, 120, 61, 123,
  36, 115, 99, 97, 108, 101, 42, 48, 46, 54, 53, 125, 10, 112, 116, 50,
  55, 120, 61, 123, 36, 115, 99, 97, 108, 101, 42, 48, 46, 54, 55, 53,
  125, 10, 112, 116, 50, 56, 120, 61, 123, 36, 115, 99, 97, 108, 101, 42,
  48, 46, 55, 125, 10, 112, 116, 50, 57, 120, 61, 123, 36, 115, 99, 97,
  108, 101, 42, 48, 46, 55, 50, 53, 125, 10, 112, 116, 51, 48, 120, 61,
  123, 36, 115, 99, 97, 108, 101, 42, 48, 46, 55, 53, 125, 10, 112, 116,
  51, 49, 120, 61, 123, 36, 115, 99, 97, 108, 101, 42, 48, 46, 55, 55,
  53, 125, 10, 112, 116, 51, 50, 120, 61, 123, 36, 115, 99, 97, 108, 101,
  42, 48, 46, 56, 125, 10, 112, 116, 51, 51, 120, 61, 123, 36, 115, 99,
  97, 108, 101, 42, 48, 46, 56, 50, 53, 125, 10, 112, 116, 51, 52, 120,
  61, 123, 36, 115, 99, 97, 108, 101, 42, 48, 46, 56, 53, 125, 10, 112,
  116, 51, 53, 120, 61, 123, 36, 115, 99, 97, 108, 101, 42, 48, 46, 56,
  55, 53, 125, 10, 112, 116, 51, 54, 120, 61, 123, 36, 115, 99, 97, 108,
  101, 42, 48, 46, 57, 125, 10, 112, 116, 51, 55, 120, 61, 123, 36, 115,
  99, 97, 108, 101, 42, 48, 46, 57, 50, 53, 125, 10, 112, 116, 51, 56,
  120, 61, 123, 36, 115, 99, 97, 108, 101, 42, 48, 46, 57, 53, 125, 10,
  112, 116, 51, 57, 120, 61, 123, 36, 115, 99, 97, 108, 101, 42, 48, 46,
  57, 55, 53, 125, 10, 112, 116, 52, 48, 120, 61, 123, 36, 115, 99, 97,
  108, 101, 42, 49, 125, 10, 112, 116, 49, 121, 61, 123, 40, 48, 46, 48,
  50, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10,
  112, 116, 50, 121, 61, 123, 40, 48, 46, 48, 53, 94, 36, 101, 120, 41,
  42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 51, 121, 61, 123, 40,
  48, 46, 48, 55, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108,
  101, 125, 10, 112, 116, 52, 121, 61, 123, 40, 48, 46, 49, 94, 36, 101,
  120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 53, 121, 61,
  123, 40, 48, 46, 49, 50, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99,
  97, 108, 101, 125, 10, 112, 116, 54, 121, 61, 123, 40, 48, 46, 49, 53,
  94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116,
  55, 121, 61, 123, 40, 48, 46, 49, 55, 53, 94, 36, 101, 120, 41, 42,
  36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 56, 121, 61, 123, 40, 48,
  46, 50, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10,
  112, 116, 57, 121, 61, 123, 40, 48, 46, 50, 50, 53, 94, 36, 101, 120,
  41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 49, 48, 121, 61,
  123, 40, 48, 46, 50, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97,
  108, 101, 125, 10, 112, 116, 49, 49, 121, 61, 123, 40, 48, 46, 50, 55,
  53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112,
  116, 49, 50, 121, 61, 123, 40, 48, 46, 51, 94, 36, 101, 120, 41, 42,
  36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 49, 51, 121, 61, 123, 40,
  48, 46, 51, 50, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108,
  101, 125, 10, 112, 116, 49, 52, 121, 61, 123, 40, 48, 46, 51, 53, 94,
  36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 49,
  53, 121, 61, 123, 40, 48, 46, 51, 55, 53, 94, 36, 101, 120, 41, 42,
  36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 49, 54, 121, 61, 123, 40,
  48, 46, 52, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125,
  10, 112, 116, 49, 55, 121, 61, 123, 40, 48, 46, 52, 50, 53, 94, 36,
  101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 49, 56,
  121, 61, 123, 40, 48, 46, 52, 53, 94, 36, 101, 120, 41, 42, 36, 115,
  99, 97, 108, 101, 125, 10, 112, 116, 49, 57, 121, 61, 123, 40, 48, 46,
  52, 55, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125,
  10, 112, 116, 50, 48, 121, 61, 123, 40, 48, 46, 53, 94, 36, 101, 120,
  41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 50, 49, 121, 61,
  123, 40, 48, 46, 53, 50, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99,
  97, 108, 101, 125, 10, 112, 116, 50, 50, 121, 61, 123, 40, 48, 46, 53,
  53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112,
  116, 50, 51, 121, 61, 123, 40, 48, 46, 53, 55, 53, 94, 36, 101, 120,
  41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 50, 52, 121, 61,
  123, 40, 48, 46, 54, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108,
  101, 125, 10, 112, 116, 50, 53, 121, 61, 123, 40, 48, 46, 54, 50, 53,
  94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116,
  50, 54, 121, 61, 123, 40, 48, 46, 54, 53, 94, 36, 101, 120, 41, 42,
  36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 50, 55, 121, 61, 123, 40,
  48, 46, 54, 55, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108,
  101, 125, 10, 112, 116, 50, 56, 121, 61, 123, 40, 48, 46, 55, 94, 36,
  101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 50, 57,
  121, 61, 123, 40, 48, 46, 55, 50, 53, 94, 36, 101, 120, 41, 42, 36,
  115, 99, 97, 108, 101, 125, 10, 112, 116, 51, 48, 121, 61, 123, 40, 48,
  46, 55, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125,
  10, 112, 116, 51, 49, 121, 61, 123, 40, 48, 46, 55, 55, 53, 94, 36,
  101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 51, 50,
  121, 61, 123, 40, 48, 46, 56, 94, 36, 101, 120, 41, 42, 36, 115, 99,
  97, 108, 101, 125, 10, 112, 116, 51, 51, 121, 61, 123, 40, 48, 46, 56,
  50, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10,
  112, 116, 51, 52, 121, 61, 123, 40, 48, 46, 56, 53, 94, 36, 101, 120,
  41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 51, 53, 121, 61,
  123, 40, 48, 46, 56, 55, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99,
  97, 108, 101, 125, 10, 112, 116, 51, 54, 121, 61, 123, 40, 48, 46, 57,
  94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116,
  51, 55, 121, 61, 123, 40, 48, 46, 57, 50, 53, 94, 36, 101, 120, 41,
  42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 51, 56, 121, 61, 123,
  40, 48, 46, 57, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108,
  101, 125, 10, 112, 116, 51, 57, 121, 61, 123, 40, 48, 46, 57, 55, 53,
  94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116,
  52, 48, 121, 61, 123, 40, 49, 94, 36, 101, 120, 41, 42, 36, 115, 99,
  97, 108, 101, 125, 10, 45, 101, 110, 100, 105, 102, 10, 105, 110, 116, 101,
  114, 112, 111, 108, 97, 116, 105, 111, 110, 61, 49, 10, 45, 116, 105, 99,
  10, 45, 116, 111, 95, 114, 103, 98, 10, 45, 109, 117, 108, 91, 48, 93,
  32, 49, 48, 48, 48, 10, 45, 105, 102, 32, 123, 36, 51, 33, 61, 49,
  125, 10, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 48,
  93, 32, 48, 44, 48, 44, 48, 44, 36, 112, 116, 49, 120, 44, 36, 112,
  116, 49, 121, 44, 36, 112, 116, 50, 120, 44, 36, 112, 116, 50, 121, 44,
  36, 112, 116, 51, 120, 44, 36, 112, 116, 51, 121, 44, 36, 112, 116, 52,
  120, 44, 36, 112, 116, 52, 121, 44, 36, 112, 116, 53, 120, 44, 36, 112,
  116, 53, 121, 44, 36, 112, 116, 54, 120, 44, 36, 112, 116, 54, 121, 44,
  36, 112, 116, 55, 120, 44, 36, 112, 116, 55, 121, 44, 36, 112, 116, 56,
  120, 44, 36, 112, 116, 56, 121, 44, 36, 112, 116, 57, 120, 44, 36, 112,
  116, 57, 121, 44, 36, 112, 116, 49, 48, 120, 44, 36, 112, 116, 49, 48,
  121, 44, 36, 112, 116, 49, 49, 120, 44, 36, 112, 116, 49, 49, 121, 44,
  36, 112, 116, 49, 50, 120, 44, 36, 112, 116, 49, 50, 121, 44, 36, 112,
  116, 49, 51, 120, 44, 36, 112, 116, 49, 51, 121, 44, 36, 112, 116, 49,
  52, 120, 44, 36, 112, 116, 49, 52, 121, 44, 36, 112, 116, 49, 53, 120,
  44, 36, 112, 116, 49, 53, 121, 44, 36, 112, 116, 49, 54, 120, 44, 36,
  112, 116, 49, 54, 121, 44, 36, 112, 116, 49, 55, 120, 44, 36, 112, 116,
  49, 55, 121, 44, 36, 112, 116, 49, 56, 120, 44, 36, 112, 116, 49, 56,
  121, 44, 36, 112, 116, 49, 57, 120, 44, 36, 112, 116, 49, 57, 121, 44,
  36, 112, 116, 50, 48, 120, 44, 36, 112, 116, 50, 48, 121, 44, 36, 112,
  116, 50, 49, 120, 44, 36, 112, 116, 50, 49, 121, 44, 36, 112, 116, 50,
  50, 120, 44, 36, 112, 116, 50, 50, 121, 44, 36, 112, 116, 50, 51, 120,
  44, 36, 112, 116, 50, 51, 121, 44, 36, 112, 116, 50, 52, 120, 44, 36,
  112, 116, 50, 52, 121, 44, 36, 112, 116, 50, 53, 120, 44, 36, 112, 116,
  50, 53, 121, 44, 36, 112, 116, 50, 54, 120, 44, 36, 112, 116, 50, 54,
  121, 44, 36, 112, 116, 50, 55, 120, 44, 36, 112, 116, 50, 55, 121, 44,
  36, 112, 116, 50, 56, 120, 44, 36, 112, 116, 50, 56, 121, 44, 36, 112,
  116, 50, 57, 120, 44, 36, 112, 116, 50, 57, 121, 44, 36, 112, 116, 51,
  48, 120, 44, 36, 112, 116, 51, 48, 121, 44, 36, 112, 116, 51, 49, 120,
  44, 36, 112, 116, 51, 49, 121, 44, 36, 112, 116, 51, 50, 120, 44, 36,
  112, 116, 51, 50, 121, 44, 36, 112, 116, 51, 51, 120, 44, 36, 112, 116,
  51, 51, 121, 44, 36, 112, 116, 51, 52, 120, 44, 36, 112, 116, 51, 52,
  121, 44, 36, 112, 116, 51, 53, 120, 44, 36, 112, 116, 51, 53, 121, 44,
  36, 112, 116, 51, 54, 120, 44, 36, 112, 116, 51, 54, 121, 44, 36, 112,
  116, 51, 55, 120, 44, 36, 112, 116, 51, 55, 121, 44, 36, 112, 116, 51,
  56, 120, 44, 36, 112, 116, 51, 56, 121, 44, 36, 112, 116, 51, 57, 120,
  44, 36, 112, 116, 51, 57, 121, 44, 36, 112, 116, 52, 48, 120, 44, 36,
  112, 116, 52, 48, 121, 10, 45, 101, 110, 100, 105, 102, 10, 114, 101, 100,
  109, 117, 108, 61, 46, 50, 57, 57, 10, 103, 114, 101, 101, 110, 109, 117,
  108, 61, 46, 53, 56, 55, 10, 98, 108, 117, 101, 109, 117, 108, 61, 46,
  49, 49, 52, 10, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 10, 45,
  45, 115, 112, 108, 105, 116, 91, 48, 93, 32, 99, 10, 45, 109, 117, 108,
  91, 49, 93, 32, 36, 114, 101, 100, 109, 117, 108, 10, 45, 109, 117, 108,
  91, 50, 93, 32, 36, 103, 114, 101, 101, 110, 109, 117, 108, 10, 45, 109,
  117, 108, 91, 51, 93, 32, 36, 98, 108, 117, 101, 109, 117, 108, 10, 45,
  97, 100, 100, 91, 49, 45, 51, 93, 10, 45, 115, 112, 108, 105, 116, 91,
  48, 93, 32, 99, 10, 45, 110, 97, 109, 101, 91, 48, 93, 32, 114, 101,
  100, 10, 45, 110, 97, 109, 101, 91, 49, 93, 32, 103, 114, 101, 101, 110,
  10, 45, 110, 97, 109, 101, 91, 50, 93, 32, 98, 108, 117, 101, 10, 45,
  110, 97, 109, 101, 91, 51, 93, 32, 108, 117, 109, 97, 10, 45, 45, 115,
  117, 98, 91, 98, 108, 117, 101, 93, 32, 91, 108, 117, 109, 97, 93, 10,
  45, 110, 97, 109, 101, 91, 45, 49, 93, 32, 99, 98, 10, 45, 45, 115,
  117, 98, 91, 114, 101, 100, 93, 32, 91, 108, 117, 109, 97, 93, 10, 45,
  110, 97, 109, 101, 91, 45, 49, 93, 32, 99, 114, 10, 45, 107, 101, 101,
  112, 91, 108, 117, 109, 97, 44, 99, 98, 44, 99, 114, 93, 10, 45, 105,
  102, 32, 123, 36, 100, 101, 115, 112, 101, 99, 107, 108, 101, 95, 116, 104,
  114, 101, 115, 104, 111, 108, 100, 62, 48, 125, 10, 45, 105, 97, 105, 110,
  95, 102, 97, 115, 116, 95, 100, 101, 115, 112, 101, 99, 107, 108, 101, 91,
  48, 93, 32, 123, 49, 45, 36, 100, 101, 115, 112, 101, 99, 107, 108, 101,
  95, 116, 104, 114, 101, 115, 104, 111, 108, 100, 125, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 62, 48, 125, 10, 45, 105,
  97, 105, 110, 95, 102, 97, 115, 116, 95, 100, 101, 110, 111, 105, 115, 101,
  95, 109, 97, 105, 110, 91, 48, 93, 32, 123, 36, 102, 97, 115, 116, 108,
  117, 109, 97, 49, 125, 44, 123, 36, 102, 97, 115, 116, 108, 117, 109, 97,
  50, 125, 44, 123, 36, 102, 97, 115, 116, 108, 117, 109, 97, 51, 125, 44,
  123, 36, 102, 97, 115, 116, 108, 117, 109, 97, 52, 125, 44, 36, 105, 110,
  116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 50, 62, 48, 125, 10, 45, 105,
  97, 105, 110, 95, 102, 97, 115, 116, 95, 100, 101, 110, 111, 105, 115, 101,
  95, 109, 97, 105, 110, 91, 49, 93, 32, 123, 36, 102, 97, 115, 116, 99,
  104, 114, 111, 109, 97, 49, 125, 44, 123, 36, 102, 97, 115, 116, 99, 104,
  114, 111, 109, 97, 50, 125, 44, 123, 36, 102, 97, 115, 116, 99, 104, 114,
  111, 109, 97, 51, 125, 44, 123, 36, 102, 97, 115, 116, 99, 104, 114, 111,
  109, 97, 52, 125, 44, 36, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116,
  105, 111, 110, 10, 45, 105, 97, 105, 110, 95, 102, 97, 115, 116, 95, 100,
  101, 110, 111, 105, 115, 101, 95, 109, 97, 105, 110, 91, 50, 93, 32, 123,
  36, 102, 97, 115, 116, 99, 104, 114, 111, 109, 97, 49, 125, 44, 123, 36,
  102, 97, 115, 116, 99, 104, 114, 111, 109, 97, 50, 125, 44, 123, 36, 102,
  97, 115, 116, 99, 104, 114, 111, 109, 97, 51, 125, 44, 123, 36, 102, 97,
  115, 116, 99, 104, 114, 111, 109, 97, 52, 125, 44, 36, 105, 110, 116, 101,
  114, 112, 111, 108, 97, 116, 105, 111, 110, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 110, 97, 109, 101, 91, 48, 93, 32, 108, 117, 109, 97, 10, 45,
  110, 97, 109, 101, 91, 49, 93, 32, 99, 98, 10, 45, 110, 97, 109, 101,
  91, 50, 93, 32, 99, 114, 10, 45, 45, 97, 100, 100, 91, 99, 98, 93,
  32, 91, 108, 117, 109, 97, 93, 10, 45, 110, 97, 109, 101, 91, 45, 49,
  93, 32, 98, 108, 117, 101, 111, 117, 116, 10, 45, 45, 97, 100, 100, 91,
  99, 114, 93, 32, 91, 108, 117, 109, 97, 93, 10, 45, 110, 97, 109, 101,
  91, 45, 49, 93, 32, 114, 101, 100, 111, 117, 116, 10, 45, 114, 101, 109,
  111, 118, 101, 91, 49, 44, 50, 93, 10, 45, 45, 109, 117, 108, 91, 114,
  101, 100, 111, 117, 116, 93, 32, 36, 114, 101, 100, 109, 117, 108, 10, 45,
  45, 109, 117, 108, 91, 98, 108, 117, 101, 111, 117, 116, 93, 32, 36, 98,
  108, 117, 101, 109, 117, 108, 10, 45, 115, 117, 98, 91, 108, 117, 109, 97,
  93, 32, 91, 45, 49, 93, 10, 45, 115, 117, 98, 91, 108, 117, 109, 97,
  93, 32, 91, 45, 50, 93, 10, 45, 100, 105, 118, 91, 108, 117, 109, 97,
  93, 32, 36, 103, 114, 101, 101, 110, 109, 117, 108, 10, 45, 114, 101, 109,
  111, 118, 101, 91, 45, 49, 44, 45, 50, 93, 10, 45, 109, 111, 118, 101,
  91, 50, 93, 32, 48, 10, 45, 97, 112, 112, 101, 110, 100, 32, 99, 10,
  45, 105, 102, 32, 123, 36, 53, 61, 61, 49, 125, 10, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 48, 10, 45, 110, 111, 105,
  115, 101, 91, 45, 49, 93, 32, 48, 46, 55, 44, 48, 10, 45, 45, 108,
  97, 112, 108, 97, 99, 105, 97, 110, 91, 48, 93, 10, 45, 116, 104, 114,
  101, 115, 104, 111, 108, 100, 91, 45, 49, 93, 32, 52, 10, 45, 100, 105,
  108, 97, 116, 101, 91, 45, 49, 93, 32, 51, 10, 45, 109, 117, 108, 91,
  45, 49, 93, 32, 45, 49, 10, 45, 97, 100, 100, 91, 45, 49, 93, 32,
  49, 10, 45, 109, 117, 108, 91, 45, 50, 93, 32, 91, 45, 49, 93, 10,
  45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 93, 10, 45, 97, 100, 100,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 51, 33,
  61, 49, 125, 10, 115, 99, 97, 108, 101, 61, 123, 50, 53, 53, 42, 49,
  48, 48, 48, 125, 10, 101, 120, 61, 123, 49, 47, 36, 51, 125, 10, 112,
  116, 49, 121, 61, 123, 40, 48, 46, 48, 50, 53, 94, 36, 101, 120, 41,
  42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 50, 121, 61, 123, 40,
  48, 46, 48, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101,
  125, 10, 112, 116, 51, 121, 61, 123, 40, 48, 46, 48, 55, 53, 94, 36,
  101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 52, 121,
  61, 123, 40, 48, 46, 49, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97,
  108, 101, 125, 10, 112, 116, 53, 121, 61, 123, 40, 48, 46, 49, 50, 53,
  94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116,
  54, 121, 61, 123, 40, 48, 46, 49, 53, 94, 36, 101, 120, 41, 42, 36,
  115, 99, 97, 108, 101, 125, 10, 112, 116, 55, 121, 61, 123, 40, 48, 46,
  49, 55, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125,
  10, 112, 116, 56, 121, 61, 123, 40, 48, 46, 50, 94, 36, 101, 120, 41,
  42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 57, 121, 61, 123, 40,
  48, 46, 50, 50, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108,
  101, 125, 10, 112, 116, 49, 48, 121, 61, 123, 40, 48, 46, 50, 53, 94,
  36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 49,
  49, 121, 61, 123, 40, 48, 46, 50, 55, 53, 94, 36, 101, 120, 41, 42,
  36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 49, 50, 121, 61, 123, 40,
  48, 46, 51, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125,
  10, 112, 116, 49, 51, 121, 61, 123, 40, 48, 46, 51, 50, 53, 94, 36,
  101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 49, 52,
  121, 61, 123, 40, 48, 46, 51, 53, 94, 36, 101, 120, 41, 42, 36, 115,
  99, 97, 108, 101, 125, 10, 112, 116, 49, 53, 121, 61, 123, 40, 48, 46,
  51, 55, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125,
  10, 112, 116, 49, 54, 121, 61, 123, 40, 48, 46, 52, 94, 36, 101, 120,
  41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 49, 55, 121, 61,
  123, 40, 48, 46, 52, 50, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99,
  97, 108, 101, 125, 10, 112, 116, 49, 56, 121, 61, 123, 40, 48, 46, 52,
  53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112,
  116, 49, 57, 121, 61, 123, 40, 48, 46, 52, 55, 53, 94, 36, 101, 120,
  41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 50, 48, 121, 61,
  123, 40, 48, 46, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108,
  101, 125, 10, 112, 116, 50, 49, 121, 61, 123, 40, 48, 46, 53, 50, 53,
  94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116,
  50, 50, 121, 61, 123, 40, 48, 46, 53, 53, 94, 36, 101, 120, 41, 42,
  36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 50, 51, 121, 61, 123, 40,
  48, 46, 53, 55, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108,
  101, 125, 10, 112, 116, 50, 52, 121, 61, 123, 40, 48, 46, 54, 94, 36,
  101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 50, 53,
  121, 61, 123, 40, 48, 46, 54, 50, 53, 94, 36, 101, 120, 41, 42, 36,
  115, 99, 97, 108, 101, 125, 10, 112, 116, 50, 54, 121, 61, 123, 40, 48,
  46, 54, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125,
  10, 112, 116, 50, 55, 121, 61, 123, 40, 48, 46, 54, 55, 53, 94, 36,
  101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 50, 56,
  121, 61, 123, 40, 48, 46, 55, 94, 36, 101, 120, 41, 42, 36, 115, 99,
  97, 108, 101, 125, 10, 112, 116, 50, 57, 121, 61, 123, 40, 48, 46, 55,
  50, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10,
  112, 116, 51, 48, 121, 61, 123, 40, 48, 46, 55, 53, 94, 36, 101, 120,
  41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 51, 49, 121, 61,
  123, 40, 48, 46, 55, 55, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99,
  97, 108, 101, 125, 10, 112, 116, 51, 50, 121, 61, 123, 40, 48, 46, 56,
  94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116,
  51, 51, 121, 61, 123, 40, 48, 46, 56, 50, 53, 94, 36, 101, 120, 41,
  42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 51, 52, 121, 61, 123,
  40, 48, 46, 56, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108,
  101, 125, 10, 112, 116, 51, 53, 121, 61, 123, 40, 48, 46, 56, 55, 53,
  94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116,
  51, 54, 121, 61, 123, 40, 48, 46, 57, 94, 36, 101, 120, 41, 42, 36,
  115, 99, 97, 108, 101, 125, 10, 112, 116, 51, 55, 121, 61, 123, 40, 48,
  46, 57, 50, 53, 94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101,
  125, 10, 112, 116, 51, 56, 121, 61, 123, 40, 48, 46, 57, 53, 94, 36,
  101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 112, 116, 51, 57,
  121, 61, 123, 40, 48, 46, 57, 55, 53, 94, 36, 101, 120, 41, 42, 36,
  115, 99, 97, 108, 101, 125, 10, 112, 116, 52, 48, 121, 61, 123, 40, 49,
  94, 36, 101, 120, 41, 42, 36, 115, 99, 97, 108, 101, 125, 10, 45, 97,
  112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 48, 93, 32, 48, 44,
  48, 44, 48, 44, 36, 112, 116, 49, 120, 44, 36, 112, 116, 49, 121, 44,
  36, 112, 116, 50, 120, 44, 36, 112, 116, 50, 121, 44, 36, 112, 116, 51,
  120, 44, 36, 112, 116, 51, 121, 44, 36, 112, 116, 52, 120, 44, 36, 112,
  116, 52, 121, 44, 36, 112, 116, 53, 120, 44, 36, 112, 116, 53, 121, 44,
  36, 112, 116, 54, 120, 44, 36, 112, 116, 54, 121, 44, 36, 112, 116, 55,
  120, 44, 36, 112, 116, 55, 121, 44, 36, 112, 116, 56, 120, 44, 36, 112,
  116, 56, 121, 44, 36, 112, 116, 57, 120, 44, 36, 112, 116, 57, 121, 44,
  36, 112, 116, 49, 48, 120, 44, 36, 112, 116, 49, 48, 121, 44, 36, 112,
  116, 49, 49, 120, 44, 36, 112, 116, 49, 49, 121, 44, 36, 112, 116, 49,
  50, 120, 44, 36, 112, 116, 49, 50, 121, 44, 36, 112, 116, 49, 51, 120,
  44, 36, 112, 116, 49, 51, 121, 44, 36, 112, 116, 49, 52, 120, 44, 36,
  112, 116, 49, 52, 121, 44, 36, 112, 116, 49, 53, 120, 44, 36, 112, 116,
  49, 53, 121, 44, 36, 112, 116, 49, 54, 120, 44, 36, 112, 116, 49, 54,
  121, 44, 36, 112, 116, 49, 55, 120, 44, 36, 112, 116, 49, 55, 121, 44,
  36, 112, 116, 49, 56, 120, 44, 36, 112, 116, 49, 56, 121, 44, 36, 112,
  116, 49, 57, 120, 44, 36, 112, 116, 49, 57, 121, 44, 36, 112, 116, 50,
  48, 120, 44, 36, 112, 116, 50, 48, 121, 44, 36, 112, 116, 50, 49, 120,
  44, 36, 112, 116, 50, 49, 121, 44, 36, 112, 116, 50, 50, 120, 44, 36,
  112, 116, 50, 50, 121, 44, 36, 112, 116, 50, 51, 120, 44, 36, 112, 116,
  50, 51, 121, 44, 36, 112, 116, 50, 52, 120, 44, 36, 112, 116, 50, 52,
  121, 44, 36, 112, 116, 50, 53, 120, 44, 36, 112, 116, 50, 53, 121, 44,
  36, 112, 116, 50, 54, 120, 44, 36, 112, 116, 50, 54, 121, 44, 36, 112,
  116, 50, 55, 120, 44, 36, 112, 116, 50, 55, 121, 44, 36, 112, 116, 50,
  56, 120, 44, 36, 112, 116, 50, 56, 121, 44, 36, 112, 116, 50, 57, 120,
  44, 36, 112, 116, 50, 57, 121, 44, 36, 112, 116, 51, 48, 120, 44, 36,
  112, 116, 51, 48, 121, 44, 36, 112, 116, 51, 49, 120, 44, 36, 112, 116,
  51, 49, 121, 44, 36, 112, 116, 51, 50, 120, 44, 36, 112, 116, 51, 50,
  121, 44, 36, 112, 116, 51, 51, 120, 44, 36, 112, 116, 51, 51, 121, 44,
  36, 112, 116, 51, 52, 120, 44, 36, 112, 116, 51, 52, 121, 44, 36, 112,
  116, 51, 53, 120, 44, 36, 112, 116, 51, 53, 121, 44, 36, 112, 116, 51,
  54, 120, 44, 36, 112, 116, 51, 54, 121, 44, 36, 112, 116, 51, 55, 120,
  44, 36, 112, 116, 51, 55, 121, 44, 36, 112, 116, 51, 56, 120, 44, 36,
  112, 116, 51, 56, 121, 44, 36, 112, 116, 51, 57, 120, 44, 36, 112, 116,
  51, 57, 121, 44, 36, 112, 116, 52, 48, 120, 44, 36, 112, 116, 52, 48,
  121, 10, 45, 101, 110, 100, 105, 102, 10, 45, 109, 117, 108, 91, 48, 93,
  32, 48, 46, 48, 48, 49, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10,
  45, 116, 111, 99, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 102, 97, 115, 116,
  98, 108, 117, 114, 58, 10, 40, 48, 46, 48, 53, 55, 57, 55, 49, 48,
  49, 52, 53, 44, 48, 46, 49, 51, 48, 52, 51, 52, 55, 56, 50, 54,
  44, 48, 46, 48, 53, 55, 57, 55, 49, 48, 49, 52, 53, 59, 48, 46,
  49, 51, 48, 52, 51, 52, 55, 56, 50, 54, 44, 48, 46, 50, 52, 54,
  51, 55, 54, 56, 49, 49, 54, 44, 48, 46, 49, 51, 48, 52, 51, 52,
  55, 56, 50, 54, 59, 48, 46, 48, 53, 55, 57, 55, 49, 48, 49, 52,
  53, 44, 48, 46, 49, 51, 48, 52, 51, 52, 55, 56, 50, 54, 44, 48,
  46, 48, 53, 55, 57, 55, 49, 48, 49, 52, 53, 41, 10, 45, 99, 111,
  110, 118, 111, 108, 118, 101, 91, 48, 93, 32, 91, 49, 93, 10, 45, 114,
  101, 109, 111, 118, 101, 91, 45, 49, 93, 10, 105, 97, 105, 110, 95, 102,
  97, 115, 116, 95, 100, 101, 115, 112, 101, 99, 107, 108, 101, 58, 10, 40,
  48, 44, 48, 46, 50, 44, 48, 59, 48, 46, 50, 44, 48, 46, 50, 44,
  48, 46, 50, 59, 48, 44, 48, 46, 50, 44, 48, 41, 10, 45, 45, 99,
  111, 110, 118, 111, 108, 118, 101, 91, 48, 93, 32, 91, 49, 93, 10, 45,
  45, 115, 117, 98, 91, 45, 49, 93, 32, 91, 48, 93, 10, 45, 97, 98,
  115, 91, 45, 49, 93, 10, 45, 45, 99, 111, 110, 118, 111, 108, 118, 101,
  91, 45, 49, 93, 32, 91, 49, 93, 10, 45, 115, 117, 98, 91, 45, 49,
  93, 32, 91, 45, 50, 93, 10, 45, 97, 98, 115, 91, 45, 49, 93, 10,
  45, 107, 101, 101, 112, 91, 48, 44, 50, 44, 45, 49, 93, 10, 45, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 91, 45, 49, 93, 32, 36, 49, 10,
  45, 109, 117, 108, 91, 45, 49, 93, 32, 50, 53, 53, 10, 45, 97, 112,
  112, 101, 110, 100, 91, 49, 44, 50, 93, 32, 99, 10, 45, 98, 108, 101,
  110, 100, 32, 97, 108, 112, 104, 97, 10, 105, 97, 105, 110, 95, 102, 97,
  115, 116, 95, 100, 101, 110, 111, 105, 115, 101, 95, 109, 97, 105, 110, 58,
  10, 99, 114, 111, 112, 119, 105, 100, 116, 104, 61, 123, 119, 125, 10, 99,
  114, 111, 112, 104, 101, 105, 103, 104, 116, 61, 123, 104, 125, 10, 45, 114,
  101, 115, 105, 122, 101, 91, 48, 93, 32, 123, 119, 43, 40, 56, 45, 119,
  37, 56, 41, 125, 44, 123, 104, 43, 40, 56, 45, 104, 37, 56, 41, 125,
  44, 49, 44, 123, 115, 125, 44, 48, 44, 49, 10, 119, 105, 100, 116, 104,
  61, 123, 119, 125, 10, 104, 101, 105, 103, 104, 116, 61, 123, 104, 125, 10,
  45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 53, 48, 37, 44,
  53, 48, 37, 44, 123, 100, 125, 44, 123, 115, 125, 44, 50, 10, 45, 45,
  114, 101, 115, 105, 122, 101, 91, 49, 93, 32, 36, 119, 105, 100, 116, 104,
  44, 36, 104, 101, 105, 103, 104, 116, 44, 123, 100, 125, 44, 123, 115, 125,
  44, 36, 53, 10, 45, 102, 97, 115, 116, 98, 108, 117, 114, 91, 45, 49,
  93, 10, 45, 115, 117, 98, 91, 48, 93, 32, 91, 50, 93, 10, 45, 114,
  101, 109, 111, 118, 101, 91, 50, 93, 10, 45, 45, 114, 101, 115, 105, 122,
  101, 91, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 123, 100, 125,
  44, 123, 115, 125, 44, 50, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91,
  50, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 50, 125, 44, 123, 36,
  104, 101, 105, 103, 104, 116, 47, 50, 125, 44, 123, 100, 125, 44, 123, 115,
  125, 44, 36, 53, 10, 45, 102, 97, 115, 116, 98, 108, 117, 114, 91, 45,
  49, 93, 10, 45, 115, 117, 98, 91, 49, 93, 32, 91, 51, 93, 10, 45,
  114, 101, 109, 111, 118, 101, 91, 51, 93, 10, 45, 45, 114, 101, 115, 105,
  122, 101, 91, 50, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 123, 100,
  125, 44, 123, 115, 125, 44, 50, 10, 45, 45, 114, 101, 115, 105, 122, 101,
  91, 51, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 52, 125, 44, 123,
  36, 104, 101, 105, 103, 104, 116, 47, 52, 125, 44, 123, 100, 125, 44, 123,
  115, 125, 44, 36, 53, 10, 45, 102, 97, 115, 116, 98, 108, 117, 114, 91,
  45, 49, 93, 10, 45, 115, 117, 98, 91, 50, 93, 32, 91, 52, 93, 10,
  45, 114, 101, 109, 111, 118, 101, 91, 52, 93, 10, 45, 45, 114, 101, 115,
  105, 122, 101, 91, 51, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 123,
  100, 125, 44, 123, 115, 125, 44, 50, 10, 45, 45, 114, 101, 115, 105, 122,
  101, 91, 52, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 56, 125, 44,
  123, 36, 104, 101, 105, 103, 104, 116, 47, 56, 125, 44, 123, 100, 125, 44,
  123, 115, 125, 44, 36, 53, 10, 45, 102, 97, 115, 116, 98, 108, 117, 114,
  91, 45, 49, 93, 10, 45, 115, 117, 98, 91, 51, 93, 32, 91, 53, 93,
  10, 45, 114, 101, 109, 111, 118, 101, 91, 53, 93, 10, 45, 114, 109, 115,
  116, 104, 114, 101, 115, 104, 91, 48, 93, 32, 36, 49, 10, 45, 114, 109,
  115, 116, 104, 114, 101, 115, 104, 91, 49, 93, 32, 36, 50, 10, 45, 114,
  109, 115, 116, 104, 114, 101, 115, 104, 91, 50, 93, 32, 36, 51, 10, 45,
  114, 109, 115, 116, 104, 114, 101, 115, 104, 91, 51, 93, 32, 36, 52, 10,
  45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 51, 44,
  119, 125, 44, 64, 123, 51, 44, 104, 125, 44, 123, 100, 125, 44, 123, 115,
  125, 44, 36, 53, 10, 45, 102, 97, 115, 116, 98, 108, 117, 114, 91, 45,
  49, 93, 10, 45, 97, 100, 100, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 93, 10, 45, 114, 101,
  115, 105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 50, 44, 119, 125, 44,
  64, 123, 50, 44, 104, 125, 44, 123, 100, 125, 44, 123, 115, 125, 44, 36,
  53, 10, 45, 102, 97, 115, 116, 98, 108, 117, 114, 91, 45, 49, 93, 10,
  45, 97, 100, 100, 91, 45, 50, 93, 32, 91, 45, 49, 93, 10, 45, 114,
  101, 109, 111, 118, 101, 91, 45, 49, 93, 10, 45, 114, 101, 115, 105, 122,
  101, 91, 45, 49, 93, 32, 64, 123, 49, 44, 119, 125, 44, 64, 123, 49,
  44, 104, 125, 44, 123, 100, 125, 44, 123, 115, 125, 44, 36, 53, 10, 45,
  102, 97, 115, 116, 98, 108, 117, 114, 91, 45, 49, 93, 10, 45, 97, 100,
  100, 91, 45, 50, 93, 32, 91, 45, 49, 93, 10, 45, 114, 101, 109, 111,
  118, 101, 91, 45, 49, 93, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45,
  49, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125,
  44, 123, 100, 125, 44, 123, 115, 125, 44, 36, 53, 10, 45, 102, 97, 115,
  116, 98, 108, 117, 114, 91, 45, 49, 93, 10, 45, 97, 100, 100, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91,
  45, 49, 93, 10, 45, 99, 114, 111, 112, 32, 48, 44, 48, 44, 123, 36,
  99, 114, 111, 112, 119, 105, 100, 116, 104, 45, 49, 125, 44, 123, 36, 99,
  114, 111, 112, 104, 101, 105, 103, 104, 116, 45, 49, 125, 10, 114, 109, 115,
  116, 104, 114, 101, 115, 104, 58, 10, 45, 45, 97, 98, 115, 91, 48, 93,
  10, 45, 102, 97, 115, 116, 98, 108, 117, 114, 91, 49, 93, 10, 45, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 91, 49, 93, 32, 123, 36, 49, 125,
  10, 45, 102, 97, 115, 116, 98, 108, 117, 114, 91, 49, 93, 10, 45, 109,
  117, 108, 91, 48, 93, 32, 91, 49, 93, 10, 45, 107, 101, 101, 112, 91,
  48, 93, 10, 105, 97, 105, 110, 95, 102, 97, 115, 116, 95, 100, 101, 110,
  111, 105, 115, 101, 95, 112, 95, 112, 114, 101, 118, 105, 101, 119, 58, 10,
  45, 105, 102, 32, 123, 36, 45, 50, 61, 61, 48, 125, 10, 45, 105, 97,
  105, 110, 95, 102, 97, 115, 116, 95, 100, 101, 110, 111, 105, 115, 101, 32,
  36, 123, 49, 45, 45, 51, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 45, 50, 61, 61, 49, 125, 10, 45, 45, 105, 97,
  105, 110, 95, 102, 97, 115, 116, 95, 100, 101, 110, 111, 105, 115, 101, 95,
  112, 32, 36, 49, 44, 48, 44, 49, 44, 36, 52, 44, 48, 44, 48, 44,
  36, 55, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105,
  110, 101, 120, 116, 114, 97, 99, 116, 10, 45, 115, 117, 98, 32, 49, 50,
  56, 10, 45, 109, 117, 108, 32, 51, 10, 45, 97, 100, 100, 32, 49, 50,
  56, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 45,
  50, 61, 61, 50, 125, 10, 45, 45, 105, 97, 105, 110, 95, 102, 97, 115,
  116, 95, 100, 101, 110, 111, 105, 115, 101, 95, 112, 32, 48, 44, 36, 50,
  44, 49, 44, 36, 52, 44, 48, 44, 48, 44, 36, 55, 10, 45, 99, 111,
  109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 101, 120, 116, 114, 97,
  99, 116, 10, 45, 115, 117, 98, 32, 49, 50, 56, 10, 45, 109, 117, 108,
  32, 51, 10, 45, 97, 100, 100, 32, 49, 50, 56, 10, 45, 101, 110, 100,
  105, 102, 10, 35, 64, 103, 105, 109, 112, 32, 73, 97, 105, 110, 39, 115,
  32, 110, 111, 105, 115, 101, 32, 114, 101, 100, 117, 99, 116, 105, 111, 110,
  32, 58, 32, 105, 97, 105, 110, 95, 105, 97, 105, 110, 115, 95, 110, 114,
  44, 105, 97, 105, 110, 95, 105, 97, 105, 110, 115, 95, 110, 114, 95, 112,
  114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 49, 32, 108, 117, 109, 97, 32, 110, 114, 32, 61, 32, 102,
  108, 111, 97, 116, 32, 40, 51, 44, 48, 44, 50, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 50, 32, 99, 104, 114, 111, 109, 97, 32,
  110, 114, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 51, 44, 48, 44,
  50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 51, 32, 100,
  101, 115, 112, 101, 99, 107, 108, 101, 32, 61, 32, 105, 110, 116, 32, 40,
  49, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 32, 32, 32,
  32, 32, 32, 32, 60, 115, 109, 97, 108, 108, 62, 65, 100, 106, 117, 115,
  116, 32, 110, 111, 105, 115, 101, 32, 114, 101, 100, 117, 99, 116, 105, 111,
  110, 32, 98, 121, 32, 116, 111, 110, 101, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 52, 32, 104,
  105, 103, 104, 108, 105, 103, 104, 116, 115, 32, 61, 32, 102, 108, 111, 97,
  116, 32, 40, 48, 44, 45, 53, 48, 48, 48, 48, 44, 53, 48, 48, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 53, 32, 115, 104,
  97, 100, 111, 119, 115, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 48,
  44, 45, 51, 50, 48, 48, 48, 44, 51, 50, 48, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 98, 62, 82, 101, 99, 111, 118, 101, 114, 32, 68, 101, 116, 97,
  105, 108, 115, 60, 47, 98, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 54, 32, 114, 101, 99, 111, 118, 101, 114, 32, 100, 101, 116,
  97, 105, 108, 115, 32, 61, 32, 99, 104, 111, 105, 99, 101, 32, 40, 48,
  44, 34, 68, 111, 32, 110, 111, 116, 32, 82, 101, 99, 111, 118, 101, 114,
  32, 68, 101, 116, 97, 105, 108, 115, 34, 44, 34, 82, 101, 99, 111, 118,
  101, 114, 32, 68, 101, 116, 97, 105, 108, 115, 34, 44, 32, 34, 82, 101,
  99, 111, 118, 101, 114, 32, 68, 101, 116, 97, 105, 108, 115, 32, 97, 115,
  32, 115, 101, 112, 97, 114, 97, 116, 101, 32, 108, 97, 121, 101, 114, 34,
  41, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 55, 32, 114, 101,
  99, 111, 118, 101, 114, 121, 32, 97, 109, 111, 117, 110, 116, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 46, 49, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 32, 32, 32, 32, 32, 32, 32, 60, 115, 109, 97,
  108, 108, 62, 65, 100, 106, 117, 115, 116, 32, 100, 101, 116, 105, 97, 108,
  32, 114, 101, 99, 111, 118, 101, 114, 121, 32, 98, 121, 32, 115, 105, 122,
  101, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 56, 32, 97, 100, 106, 117, 115, 116, 32, 102, 105,
  110, 101, 32, 100, 101, 116, 97, 105, 108, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 32, 40, 48, 44, 45, 53, 48, 48, 44, 53, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 57, 32, 97, 100, 106, 117, 115,
  116, 32, 109, 101, 100, 105, 117, 109, 32, 100, 101, 116, 97, 105, 108, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 48, 44, 45, 53, 48, 48,
  44, 53, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 49,
  48, 32, 97, 100, 106, 117, 115, 116, 32, 108, 97, 114, 103, 101, 32, 100,
  101, 116, 97, 105, 108, 115, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40,
  48, 44, 45, 53, 48, 48, 44, 53, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 49, 49, 32, 100, 101, 116, 97, 105, 108, 32, 101,
  109, 112, 104, 97, 115, 105, 115, 32, 61, 32, 102, 108, 111, 97, 116, 32,
  40, 49, 46, 51, 53, 44, 49, 44, 52, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  49, 50, 32, 115, 104, 97, 114, 112, 101, 110, 32, 101, 100, 103, 101, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 48, 44, 48, 44, 52, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 98, 62, 80, 114, 101, 118, 105, 101,
  119, 32, 111, 112, 116, 105, 111, 110, 115, 60, 47, 98, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 49, 51, 32, 112, 114, 101, 118,
  105, 101, 119, 32, 115, 104, 111, 119, 115, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 32, 40, 48, 44, 34, 78, 111, 114, 109, 97, 108, 32, 79, 117,
  116, 112, 117, 116, 34, 44, 34, 76, 117, 109, 97, 32, 78, 111, 105, 115,
  101, 34, 44, 32, 32, 34, 67, 104, 114, 111, 109, 97, 32, 78, 111, 105,
  115, 101, 34, 44, 34, 68, 101, 116, 97, 105, 108, 115, 34, 41, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 65, 117, 116, 104, 111, 114, 58, 32, 73, 97, 105, 110, 32, 70,
  101, 114, 103, 117, 115, 115, 111, 110, 32, 45, 32, 117, 112, 100, 97, 116,
  101, 32, 49, 48, 32, 74, 97, 110, 32, 50, 48, 49, 51, 34, 41, 10,
  105, 97, 105, 110, 95, 105, 97, 105, 110, 115, 95, 110, 114, 58, 10, 108,
  110, 114, 61, 36, 49, 10, 99, 110, 114, 61, 36, 50, 10, 100, 101, 115,
  112, 101, 107, 61, 36, 51, 10, 104, 105, 103, 104, 115, 61, 36, 52, 10,
  115, 104, 97, 100, 111, 119, 61, 36, 53, 10, 114, 101, 99, 111, 118, 101,
  114, 121, 95, 99, 104, 111, 105, 99, 101, 61, 36, 54, 10, 100, 101, 116,
  97, 105, 108, 95, 114, 101, 99, 111, 118, 101, 114, 121, 61, 123, 53, 48,
  48, 48, 45, 40, 36, 55, 42, 53, 48, 48, 41, 125, 10, 102, 97, 115,
  116, 61, 49, 10, 102, 105, 110, 101, 95, 100, 101, 116, 61, 36, 56, 10,
  109, 101, 100, 95, 100, 101, 116, 61, 36, 57, 10, 108, 97, 114, 103, 101,
  95, 100, 101, 116, 61, 36, 49, 48, 10, 100, 101, 116, 95, 101, 109, 112,
  104, 97, 115, 105, 115, 61, 36, 49, 49, 10, 115, 104, 97, 114, 112, 61,
  36, 49, 50, 10, 45, 116, 111, 95, 114, 103, 98, 10, 45, 97, 112, 112,
  108, 121, 95, 103, 97, 109, 109, 97, 32, 123, 49, 47, 49, 46, 51, 125,
  10, 45, 109, 117, 108, 32, 57, 48, 48, 10, 45, 97, 112, 112, 108, 121,
  95, 99, 117, 114, 118, 101, 32, 49, 44, 48, 44, 48, 44, 51, 50, 48,
  48, 48, 44, 123, 51, 50, 48, 48, 48, 45, 36, 115, 104, 97, 100, 111,
  119, 125, 44, 49, 54, 48, 48, 48, 48, 44, 123, 49, 54, 48, 48, 48,
  48, 45, 36, 115, 104, 97, 100, 111, 119, 125, 44, 50, 53, 54, 48, 48,
  48, 44, 123, 50, 53, 54, 48, 48, 48, 45, 36, 104, 105, 103, 104, 115,
  45, 36, 115, 104, 97, 100, 111, 119, 125, 10, 45, 100, 105, 118, 32, 50,
  48, 48, 48, 10, 45, 105, 97, 105, 110, 95, 114, 103, 98, 50, 121, 99,
  98, 99, 114, 10, 45, 115, 112, 108, 105, 116, 32, 99, 10, 45, 105, 102,
  32, 123, 36, 108, 110, 114, 62, 48, 125, 10, 45, 105, 102, 32, 123, 36,
  114, 101, 99, 111, 118, 101, 114, 121, 95, 99, 104, 111, 105, 99, 101, 61,
  61, 48, 125, 10, 45, 105, 97, 105, 110, 115, 95, 110, 114, 95, 112, 97,
  116, 99, 104, 98, 91, 48, 93, 32, 49, 48, 44, 36, 108, 110, 114, 44,
  51, 44, 51, 44, 48, 44, 36, 102, 97, 115, 116, 44, 49, 44, 36, 100,
  101, 115, 112, 101, 107, 44, 46, 53, 44, 46, 52, 44, 46, 50, 44, 48,
  44, 49, 44, 49, 44, 50, 44, 48, 10, 45, 117, 110, 115, 104, 97, 114,
  112, 91, 48, 93, 32, 46, 55, 44, 36, 115, 104, 97, 114, 112, 44, 48,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 114, 101,
  99, 111, 118, 101, 114, 121, 95, 99, 104, 111, 105, 99, 101, 61, 61, 49,
  125, 10, 45, 45, 105, 97, 105, 110, 115, 95, 110, 114, 95, 112, 97, 116,
  99, 104, 98, 91, 48, 93, 32, 49, 48, 44, 36, 108, 110, 114, 44, 51,
  44, 51, 44, 48, 44, 36, 102, 97, 115, 116, 44, 49, 44, 36, 100, 101,
  115, 112, 101, 107, 44, 46, 53, 44, 46, 52, 44, 46, 50, 44, 48, 44,
  49, 44, 49, 44, 50, 44, 48, 10, 45, 45, 115, 117, 98, 91, 48, 93,
  32, 91, 45, 49, 93, 10, 45, 97, 100, 100, 91, 45, 49, 93, 32, 123,
  49, 50, 56, 125, 10, 45, 114, 101, 109, 111, 118, 101, 91, 48, 93, 10,
  45, 117, 110, 115, 104, 97, 114, 112, 91, 50, 93, 32, 46, 55, 44, 36,
  115, 104, 97, 114, 112, 44, 48, 10, 45, 114, 101, 115, 105, 122, 101, 91,
  45, 49, 93, 32, 123, 119, 43, 52, 56, 125, 44, 123, 104, 43, 52, 56,
  125, 44, 123, 100, 125, 44, 123, 115, 125, 44, 48, 44, 48, 44, 48, 44,
  48, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 119,
  43, 52, 56, 125, 44, 123, 104, 43, 52, 56, 125, 44, 123, 100, 125, 44,
  123, 115, 125, 44, 48, 44, 48, 44, 49, 44, 49, 10, 45, 114, 101, 99,
  116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 49,
  48, 48, 37, 44, 52, 56, 44, 49, 44, 49, 50, 56, 10, 45, 114, 101,
  99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44,
  52, 56, 44, 49, 48, 48, 37, 44, 49, 44, 49, 50, 56, 10, 45, 114,
  101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48, 44, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 123, 104, 45, 52, 56, 125, 44,
  49, 44, 49, 50, 56, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101,
  91, 45, 49, 93, 32, 123, 119, 45, 52, 56, 125, 44, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 48, 44, 49, 44, 49, 50, 56, 10, 45, 105,
  97, 105, 110, 115, 95, 110, 114, 95, 102, 102, 116, 95, 116, 105, 108, 101,
  51, 91, 45, 49, 93, 32, 123, 36, 100, 101, 116, 97, 105, 108, 95, 114,
  101, 99, 111, 118, 101, 114, 121, 125, 44, 52, 56, 44, 48, 44, 36, 102,
  105, 110, 101, 95, 100, 101, 116, 44, 36, 109, 101, 100, 95, 100, 101, 116,
  44, 36, 108, 97, 114, 103, 101, 95, 100, 101, 116, 44, 49, 44, 51, 10,
  45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 52, 56, 44, 52, 56, 44,
  123, 119, 45, 52, 57, 125, 44, 123, 104, 45, 52, 57, 125, 10, 45, 115,
  117, 98, 91, 45, 49, 93, 32, 123, 49, 50, 56, 125, 10, 45, 109, 117,
  108, 91, 45, 49, 93, 32, 36, 100, 101, 116, 95, 101, 109, 112, 104, 97,
  115, 105, 115, 10, 45, 97, 100, 100, 91, 50, 93, 32, 91, 45, 49, 93,
  10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 93, 10, 45, 109, 111,
  118, 101, 91, 45, 49, 93, 32, 48, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 114, 101, 99, 111, 118, 101, 114, 121, 95, 99,
  104, 111, 105, 99, 101, 61, 61, 50, 125, 10, 45, 45, 105, 97, 105, 110,
  115, 95, 110, 114, 95, 112, 97, 116, 99, 104, 98, 91, 48, 93, 32, 49,
  48, 44, 36, 108, 110, 114, 44, 51, 44, 51, 44, 48, 44, 36, 102, 97,
  115, 116, 44, 49, 44, 36, 100, 101, 115, 112, 101, 107, 44, 46, 53, 44,
  46, 52, 44, 46, 50, 44, 48, 44, 49, 44, 49, 44, 50, 44, 48, 10,
  45, 45, 115, 117, 98, 91, 48, 93, 32, 91, 45, 49, 93, 10, 45, 97,
  100, 100, 91, 45, 49, 93, 32, 123, 49, 50, 56, 125, 10, 45, 114, 101,
  109, 111, 118, 101, 91, 48, 93, 10, 45, 117, 110, 115, 104, 97, 114, 112,
  91, 50, 93, 32, 46, 55, 44, 36, 115, 104, 97, 114, 112, 44, 48, 10,
  45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 119, 43, 52,
  56, 125, 44, 123, 104, 43, 52, 56, 125, 44, 123, 100, 125, 44, 123, 115,
  125, 44, 48, 44, 48, 44, 48, 44, 48, 10, 45, 114, 101, 115, 105, 122,
  101, 91, 45, 49, 93, 32, 123, 119, 43, 52, 56, 125, 44, 123, 104, 43,
  52, 56, 125, 44, 123, 100, 125, 44, 123, 115, 125, 44, 48, 44, 48, 44,
  49, 44, 49, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45,
  49, 93, 32, 48, 44, 48, 44, 49, 48, 48, 37, 44, 52, 56, 44, 49,
  44, 49, 50, 56, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91,
  45, 49, 93, 32, 48, 44, 48, 44, 52, 56, 44, 49, 48, 48, 37, 44,
  49, 44, 49, 50, 56, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101,
  91, 45, 49, 93, 32, 48, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 123, 104, 45, 52, 56, 125, 44, 49, 44, 49, 50, 56, 10, 45, 114,
  101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 123, 119, 45,
  52, 56, 125, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48, 44,
  49, 44, 49, 50, 56, 10, 45, 105, 97, 105, 110, 115, 95, 110, 114, 95,
  102, 102, 116, 95, 116, 105, 108, 101, 51, 91, 45, 49, 93, 32, 123, 36,
  100, 101, 116, 97, 105, 108, 95, 114, 101, 99, 111, 118, 101, 114, 121, 125,
  44, 52, 56, 44, 48, 44, 36, 102, 105, 110, 101, 95, 100, 101, 116, 44,
  36, 109, 101, 100, 95, 100, 101, 116, 44, 36, 108, 97, 114, 103, 101, 95,
  100, 101, 116, 44, 49, 44, 51, 10, 45, 99, 114, 111, 112, 91, 45, 49,
  93, 32, 52, 56, 44, 52, 56, 44, 123, 119, 45, 52, 57, 125, 44, 123,
  104, 45, 52, 57, 125, 10, 45, 115, 117, 98, 91, 45, 49, 93, 32, 49,
  50, 56, 10, 45, 109, 117, 108, 91, 45, 49, 93, 32, 36, 100, 101, 116,
  95, 101, 109, 112, 104, 97, 115, 105, 115, 10, 45, 97, 100, 100, 91, 45,
  49, 93, 32, 49, 50, 56, 10, 45, 109, 111, 118, 101, 91, 45, 50, 93,
  32, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 99, 110, 114, 62, 48, 125, 10, 45, 97,
  100, 100, 91, 49, 44, 50, 93, 32, 51, 48, 48, 10, 45, 105, 97, 105,
  110, 115, 95, 110, 114, 95, 112, 97, 116, 99, 104, 98, 91, 49, 93, 32,
  49, 48, 44, 36, 99, 110, 114, 44, 51, 44, 51, 44, 48, 44, 49, 44,
  49, 44, 52, 44, 46, 53, 44, 46, 52, 44, 46, 50, 44, 48, 44, 49,
  44, 49, 44, 50, 44, 48, 10, 45, 105, 97, 105, 110, 115, 95, 110, 114,
  95, 112, 97, 116, 99, 104, 98, 91, 50, 93, 32, 49, 48, 44, 36, 99,
  110, 114, 44, 51, 44, 51, 44, 48, 44, 49, 44, 49, 44, 52, 44, 46,
  53, 44, 46, 52, 44, 46, 50, 44, 48, 44, 49, 44, 49, 44, 50, 44,
  48, 10, 45, 115, 117, 98, 91, 49, 44, 50, 93, 32, 51, 48, 48, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 97, 112, 112, 101, 110, 100, 91, 48,
  44, 49, 44, 50, 93, 32, 99, 10, 45, 105, 97, 105, 110, 95, 121, 99,
  98, 99, 114, 50, 114, 103, 98, 91, 48, 93, 10, 45, 109, 117, 108, 91,
  48, 93, 32, 50, 48, 48, 48, 10, 45, 97, 112, 112, 108, 121, 95, 99,
  117, 114, 118, 101, 91, 48, 93, 32, 49, 44, 48, 44, 48, 44, 123, 51,
  50, 48, 48, 48, 45, 36, 115, 104, 97, 100, 111, 119, 125, 44, 51, 50,
  48, 48, 48, 44, 123, 49, 54, 48, 48, 48, 48, 45, 36, 115, 104, 97,
  100, 111, 119, 125, 44, 49, 54, 48, 48, 48, 48, 44, 123, 50, 53, 54,
  48, 48, 48, 45, 36, 104, 105, 103, 104, 115, 45, 36, 115, 104, 97, 100,
  111, 119, 125, 44, 50, 53, 54, 48, 48, 48, 10, 45, 100, 105, 118, 91,
  48, 93, 32, 57, 48, 48, 10, 45, 97, 112, 112, 108, 121, 95, 103, 97,
  109, 109, 97, 91, 48, 93, 32, 49, 46, 51, 10, 45, 99, 32, 48, 44,
  50, 53, 53, 10, 105, 97, 105, 110, 115, 95, 110, 114, 95, 109, 101, 100,
  51, 115, 116, 97, 99, 107, 49, 54, 58, 10, 45, 45, 109, 97, 120, 91,
  48, 44, 49, 93, 10, 45, 45, 109, 105, 110, 91, 48, 44, 49, 93, 10,
  45, 107, 101, 101, 112, 91, 50, 44, 51, 44, 52, 93, 10, 45, 45, 109,
  97, 120, 91, 48, 44, 50, 93, 10, 45, 45, 109, 105, 110, 91, 49, 44,
  51, 93, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 105, 97, 105,
  110, 115, 95, 110, 114, 95, 109, 101, 100, 53, 115, 116, 97, 99, 107, 49,
  54, 58, 10, 45, 45, 109, 105, 110, 91, 48, 44, 49, 93, 10, 45, 45,
  109, 97, 120, 91, 48, 44, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101,
  91, 48, 44, 49, 93, 10, 45, 45, 109, 105, 110, 91, 48, 44, 52, 93,
  10, 45, 45, 109, 97, 120, 91, 48, 44, 52, 93, 10, 45, 114, 101, 109,
  111, 118, 101, 91, 48, 44, 52, 93, 10, 45, 45, 109, 105, 110, 91, 48,
  44, 52, 93, 10, 45, 45, 109, 97, 120, 91, 48, 44, 52, 93, 10, 45,
  114, 101, 109, 111, 118, 101, 91, 48, 44, 52, 93, 10, 45, 45, 109, 105,
  110, 91, 48, 44, 52, 93, 10, 45, 45, 109, 97, 120, 91, 48, 44, 52,
  93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 48, 44, 52, 93, 10, 45,
  45, 109, 105, 110, 91, 48, 44, 49, 93, 10, 45, 45, 109, 97, 120, 91,
  48, 44, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 48, 44, 49,
  93, 10, 45, 45, 109, 105, 110, 91, 48, 44, 52, 93, 10, 45, 45, 109,
  97, 120, 91, 48, 44, 52, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91,
  48, 44, 52, 93, 10, 45, 45, 109, 105, 110, 91, 48, 44, 52, 93, 10,
  45, 45, 109, 97, 120, 91, 48, 44, 52, 93, 10, 45, 114, 101, 109, 111,
  118, 101, 91, 48, 44, 52, 93, 10, 45, 45, 109, 105, 110, 91, 49, 44,
  50, 93, 10, 45, 45, 109, 97, 120, 91, 49, 44, 50, 93, 10, 45, 114,
  101, 109, 111, 118, 101, 91, 49, 44, 50, 93, 10, 45, 45, 109, 97, 120,
  91, 49, 44, 52, 93, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10,
  105, 97, 105, 110, 115, 95, 110, 114, 95, 102, 102, 116, 95, 116, 105, 108,
  101, 51, 95, 102, 102, 116, 58, 10, 45, 45, 102, 102, 116, 112, 111, 108,
  97, 114, 91, 48, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  49, 44, 49, 44, 49, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45,
  49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 53, 48, 37, 44, 53,
  48, 37, 44, 48, 44, 49, 44, 36, 52, 10, 45, 101, 108, 108, 105, 112,
  115, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 49,
  53, 37, 44, 49, 53, 37, 44, 48, 44, 49, 44, 36, 53, 10, 45, 101,
  108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53,
  48, 37, 44, 53, 37, 44, 53, 37, 44, 48, 44, 49, 44, 36, 54, 10,
  45, 45, 97, 100, 100, 91, 49, 93, 32, 91, 45, 49, 93, 10, 45, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 91, 45, 49, 93, 32, 36, 49, 10,
  45, 115, 101, 116, 91, 45, 49, 93, 32, 49, 44, 53, 48, 37, 44, 53,
  48, 37, 10, 45, 109, 117, 108, 91, 49, 93, 32, 91, 45, 49, 93, 10,
  45, 45, 105, 102, 102, 116, 112, 111, 108, 97, 114, 91, 49, 44, 50, 93,
  10, 45, 114, 101, 109, 111, 118, 101, 91, 48, 44, 49, 44, 50, 93, 10,
  45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 105, 97, 105, 110, 115, 95,
  110, 114, 95, 102, 102, 116, 95, 116, 105, 108, 101, 51, 95, 99, 108, 101,
  97, 110, 58, 10, 116, 99, 61, 123, 114, 111, 117, 110, 100, 40, 119, 47,
  36, 50, 41, 125, 32, 116, 114, 61, 123, 114, 111, 117, 110, 100, 40, 104,
  47, 36, 50, 41, 125, 10, 45, 115, 112, 108, 105, 116, 95, 116, 105, 108,
  101, 115, 32, 36, 116, 99, 44, 36, 116, 114, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 111, 99, 97, 108, 91, 64, 123, 62,
  44, 45, 49, 125, 93, 10, 45, 105, 97, 105, 110, 115, 95, 110, 114, 95,
  102, 102, 116, 95, 116, 105, 108, 101, 51, 95, 102, 102, 116, 91, 48, 45,
  45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44,
  36, 53, 44, 36, 54, 10, 45, 101, 110, 100, 108, 111, 99, 97, 108, 32,
  45, 100, 111, 110, 101, 10, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105,
  108, 101, 115, 32, 36, 116, 99, 44, 36, 116, 114, 10, 45, 99, 32, 48,
  44, 50, 53, 53, 10, 105, 97, 105, 110, 115, 95, 110, 114, 95, 102, 102,
  116, 95, 116, 105, 108, 101, 51, 58, 10, 45, 45, 114, 101, 115, 105, 122,
  101, 91, 48, 93, 32, 123, 119, 43, 36, 50, 125, 44, 123, 104, 43, 36,
  50, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49, 10, 45,
  114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 119, 43, 36, 50,
  125, 44, 123, 104, 43, 36, 50, 125, 44, 49, 44, 49, 44, 48, 44, 49,
  44, 48, 44, 48, 10, 45, 105, 97, 105, 110, 115, 95, 110, 114, 95, 102,
  102, 116, 95, 116, 105, 108, 101, 51, 95, 99, 108, 101, 97, 110, 91, 45,
  49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36,
  53, 44, 36, 54, 10, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 36,
  50, 44, 36, 50, 44, 123, 119, 45, 36, 50, 45, 49, 125, 44, 123, 104,
  45, 36, 50, 45, 49, 125, 10, 45, 105, 102, 32, 123, 36, 56, 62, 50,
  125, 10, 112, 117, 115, 104, 61, 123, 114, 111, 117, 110, 100, 40, 36, 50,
  42, 49, 46, 53, 41, 125, 10, 112, 117, 108, 108, 61, 123, 36, 50, 45,
  36, 112, 117, 115, 104, 125, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91,
  48, 93, 32, 123, 119, 43, 36, 112, 117, 115, 104, 125, 44, 123, 104, 43,
  36, 50, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49, 10,
  45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 119, 43, 36,
  112, 117, 108, 108, 125, 44, 123, 104, 43, 36, 50, 125, 44, 49, 44, 49,
  44, 48, 44, 49, 44, 48, 44, 48, 10, 45, 105, 97, 105, 110, 115, 95,
  110, 114, 95, 102, 102, 116, 95, 116, 105, 108, 101, 51, 95, 99, 108, 101,
  97, 110, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44,
  36, 52, 44, 36, 53, 44, 36, 54, 10, 45, 99, 114, 111, 112, 91, 45,
  49, 93, 32, 123, 36, 112, 117, 115, 104, 125, 44, 123, 36, 50, 125, 44,
  123, 119, 45, 36, 112, 117, 108, 108, 45, 49, 125, 44, 123, 104, 45, 40,
  36, 50, 41, 45, 49, 125, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91,
  48, 93, 32, 123, 119, 43, 36, 50, 125, 44, 123, 104, 43, 36, 112, 117,
  115, 104, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49, 10,
  45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 119, 43, 36,
  50, 125, 44, 123, 104, 43, 36, 112, 117, 108, 108, 125, 44, 49, 44, 49,
  44, 48, 44, 49, 44, 48, 44, 48, 10, 45, 105, 97, 105, 110, 115, 95,
  110, 114, 95, 102, 102, 116, 95, 116, 105, 108, 101, 51, 95, 99, 108, 101,
  97, 110, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44,
  36, 52, 44, 36, 53, 44, 36, 54, 10, 45, 99, 114, 111, 112, 91, 45,
  49, 93, 32, 36, 50, 44, 123, 36, 112, 117, 115, 104, 125, 44, 123, 119,
  45, 36, 50, 45, 49, 125, 44, 123, 104, 45, 36, 112, 117, 108, 108, 45,
  49, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  56, 62, 49, 125, 10, 100, 105, 97, 49, 61, 123, 114, 111, 117, 110, 100,
  40, 36, 50, 47, 51, 41, 125, 10, 100, 105, 97, 50, 61, 123, 36, 50,
  45, 36, 100, 105, 97, 49, 125, 10, 45, 45, 114, 101, 115, 105, 122, 101,
  91, 48, 93, 32, 123, 119, 43, 36, 100, 105, 97, 49, 125, 44, 123, 104,
  43, 36, 100, 105, 97, 49, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44,
  49, 44, 49, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32,
  123, 119, 43, 36, 100, 105, 97, 50, 125, 44, 123, 104, 43, 36, 100, 105,
  97, 50, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 48, 44, 48, 10,
  45, 105, 97, 105, 110, 115, 95, 110, 114, 95, 102, 102, 116, 95, 116, 105,
  108, 101, 51, 95, 99, 108, 101, 97, 110, 91, 45, 49, 93, 32, 36, 49,
  44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 10,
  45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 123, 36, 100, 105, 97, 49,
  125, 44, 123, 36, 100, 105, 97, 49, 125, 44, 123, 119, 45, 36, 100, 105,
  97, 50, 45, 49, 125, 44, 123, 104, 45, 36, 100, 105, 97, 50, 45, 49,
  125, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 123, 119,
  43, 36, 100, 105, 97, 50, 125, 44, 123, 104, 43, 36, 100, 105, 97, 50,
  125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49, 10, 45, 114,
  101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 119, 43, 36, 100, 105,
  97, 49, 125, 44, 123, 104, 43, 36, 100, 105, 97, 49, 125, 44, 49, 44,
  49, 44, 48, 44, 49, 44, 48, 44, 48, 10, 45, 105, 97, 105, 110, 115,
  95, 110, 114, 95, 102, 102, 116, 95, 116, 105, 108, 101, 51, 95, 99, 108,
  101, 97, 110, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51,
  44, 36, 52, 44, 36, 53, 44, 36, 54, 10, 45, 99, 114, 111, 112, 91,
  45, 49, 93, 32, 123, 36, 100, 105, 97, 50, 125, 44, 123, 36, 100, 105,
  97, 50, 125, 44, 123, 119, 45, 36, 100, 105, 97, 49, 45, 49, 125, 44,
  123, 104, 45, 36, 100, 105, 97, 49, 45, 49, 125, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 114, 101, 109, 111, 118, 101, 91, 48, 93, 10, 45, 105,
  102, 32, 123, 36, 56, 61, 61, 51, 125, 10, 45, 105, 97, 105, 110, 115,
  95, 110, 114, 95, 109, 101, 100, 53, 115, 116, 97, 99, 107, 49, 54, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 56, 61, 61,
  50, 125, 10, 45, 105, 97, 105, 110, 115, 95, 110, 114, 95, 109, 101, 100,
  51, 115, 116, 97, 99, 107, 49, 54, 10, 45, 101, 110, 100, 105, 102, 10,
  105, 97, 105, 110, 115, 95, 110, 114, 95, 112, 97, 116, 99, 104, 98, 95,
  115, 109, 111, 111, 116, 104, 105, 110, 103, 58, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 36, 55, 32, 45, 100, 101, 110, 111, 105, 115, 101, 32, 36,
  49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54,
  32, 45, 100, 111, 110, 101, 10, 105, 97, 105, 110, 115, 95, 110, 114, 95,
  112, 97, 116, 99, 104, 98, 95, 50, 58, 10, 45, 45, 114, 101, 115, 105,
  122, 101, 91, 48, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 49, 44,
  123, 115, 125, 44, 50, 10, 45, 45, 105, 97, 105, 110, 115, 95, 110, 114,
  95, 112, 97, 116, 99, 104, 98, 95, 115, 109, 111, 111, 116, 104, 105, 110,
  103, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36,
  52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 10, 45, 45,
  114, 101, 115, 105, 122, 101, 91, 49, 93, 32, 64, 123, 48, 44, 119, 125,
  44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 123, 115, 125, 44, 53, 10,
  45, 45, 115, 117, 98, 91, 48, 93, 32, 91, 51, 93, 10, 45, 114, 101,
  115, 105, 122, 101, 91, 50, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64,
  123, 48, 44, 104, 125, 44, 49, 44, 123, 115, 125, 44, 53, 10, 45, 45,
  97, 100, 100, 91, 50, 93, 32, 91, 52, 93, 10, 45, 107, 101, 101, 112,
  91, 45, 49, 93, 10, 105, 97, 105, 110, 115, 95, 110, 114, 95, 112, 97,
  116, 99, 104, 98, 95, 51, 58, 10, 45, 45, 114, 101, 115, 105, 122, 101,
  91, 48, 93, 32, 50, 53, 37, 44, 50, 53, 37, 44, 49, 44, 123, 115,
  125, 44, 50, 10, 45, 45, 105, 97, 105, 110, 115, 95, 110, 114, 95, 112,
  97, 116, 99, 104, 98, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 91,
  45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44,
  36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 10, 45, 45, 114, 101,
  115, 105, 122, 101, 91, 49, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64,
  123, 48, 44, 104, 125, 44, 49, 44, 123, 115, 125, 44, 53, 10, 45, 45,
  115, 117, 98, 91, 48, 93, 32, 91, 51, 93, 10, 45, 114, 101, 115, 105,
  122, 101, 91, 50, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48,
  44, 104, 125, 44, 49, 44, 123, 115, 125, 44, 53, 10, 45, 45, 97, 100,
  100, 91, 50, 93, 32, 91, 52, 93, 10, 45, 107, 101, 101, 112, 91, 45,
  49, 93, 10, 105, 97, 105, 110, 115, 95, 110, 114, 95, 112, 97, 116, 99,
  104, 98, 95, 52, 58, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48,
  93, 32, 49, 50, 46, 53, 37, 44, 49, 50, 46, 53, 37, 44, 49, 44,
  123, 115, 125, 44, 50, 10, 45, 45, 105, 97, 105, 110, 115, 95, 110, 114,
  95, 112, 97, 116, 99, 104, 98, 95, 115, 109, 111, 111, 116, 104, 105, 110,
  103, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36,
  52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 10, 45, 45,
  114, 101, 115, 105, 122, 101, 91, 49, 93, 32, 64, 123, 48, 44, 119, 125,
  44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 123, 115, 125, 44, 53, 10,
  45, 45, 115, 117, 98, 91, 48, 93, 32, 91, 51, 93, 10, 45, 114, 101,
  115, 105, 122, 101, 91, 50, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64,
  123, 48, 44, 104, 125, 44, 49, 44, 123, 115, 125, 44, 53, 10, 45, 45,
  97, 100, 100, 91, 50, 93, 32, 91, 52, 93, 10, 45, 107, 101, 101, 112,
  91, 45, 49, 93, 10, 105, 97, 105, 110, 115, 95, 110, 114, 95, 112, 97,
  116, 99, 104, 98, 95, 53, 58, 10, 45, 45, 114, 101, 115, 105, 122, 101,
  91, 48, 93, 32, 54, 46, 49, 50, 53, 37, 44, 54, 46, 49, 50, 53,
  37, 44, 49, 44, 123, 115, 125, 44, 50, 10, 45, 45, 105, 97, 105, 110,
  115, 95, 110, 114, 95, 112, 97, 116, 99, 104, 98, 95, 115, 109, 111, 111,
  116, 104, 105, 110, 103, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44,
  36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36,
  56, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 49, 93, 32, 64, 123,
  48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 123, 115,
  125, 44, 53, 10, 45, 45, 115, 117, 98, 91, 48, 93, 32, 91, 51, 93,
  10, 45, 114, 101, 115, 105, 122, 101, 91, 50, 93, 32, 64, 123, 48, 44,
  119, 125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 123, 115, 125, 44,
  53, 10, 45, 45, 97, 100, 100, 91, 50, 93, 32, 91, 52, 93, 10, 45,
  107, 101, 101, 112, 91, 45, 49, 93, 10, 105, 97, 105, 110, 115, 95, 110,
  114, 95, 112, 97, 116, 99, 104, 98, 58, 10, 45, 97, 112, 112, 108, 121,
  95, 103, 97, 109, 109, 97, 32, 123, 49, 47, 36, 49, 52, 125, 10, 45,
  105, 102, 32, 123, 36, 56, 61, 61, 49, 125, 10, 45, 104, 121, 98, 114,
  105, 100, 95, 109, 101, 100, 105, 97, 110, 91, 45, 49, 93, 32, 49, 44,
  48, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 56, 61, 61, 50, 125, 10, 45, 104, 121, 98, 114, 105, 100, 95, 109,
  101, 100, 105, 97, 110, 91, 45, 49, 93, 32, 51, 44, 48, 44, 48, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 56, 61, 61,
  51, 125, 10, 45, 109, 101, 100, 105, 97, 110, 91, 45, 49, 93, 32, 51,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 56, 61,
  61, 52, 125, 10, 45, 109, 101, 100, 105, 97, 110, 91, 45, 49, 93, 32,
  51, 10, 45, 109, 101, 100, 105, 97, 110, 91, 45, 49, 93, 32, 51, 10,
  45, 109, 101, 100, 105, 97, 110, 91, 45, 49, 93, 32, 51, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 53,
  10, 45, 105, 102, 32, 123, 36, 56, 60, 52, 125, 10, 45, 105, 102, 32,
  123, 36, 49, 51, 61, 61, 49, 125, 10, 45, 105, 97, 105, 110, 115, 95,
  110, 114, 95, 112, 97, 116, 99, 104, 98, 95, 115, 109, 111, 111, 116, 104,
  105, 110, 103, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51,
  44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  97, 105, 110, 115, 95, 110, 114, 95, 112, 97, 116, 99, 104, 98, 95, 50,
  32, 36, 49, 44, 123, 36, 50, 42, 36, 57, 125, 44, 36, 51, 44, 36,
  52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 10, 45, 105,
  97, 105, 110, 115, 95, 110, 114, 95, 112, 97, 116, 99, 104, 98, 95, 51,
  32, 36, 49, 44, 123, 36, 50, 42, 36, 49, 48, 125, 44, 36, 51, 44,
  36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 10, 45,
  105, 97, 105, 110, 115, 95, 110, 114, 95, 112, 97, 116, 99, 104, 98, 95,
  52, 32, 36, 49, 44, 123, 36, 50, 42, 36, 49, 49, 125, 44, 36, 51,
  44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 10,
  45, 105, 97, 105, 110, 115, 95, 110, 114, 95, 112, 97, 116, 99, 104, 98,
  95, 53, 32, 36, 49, 44, 123, 36, 50, 42, 36, 49, 50, 125, 44, 36,
  51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56,
  10, 45, 100, 111, 110, 101, 10, 45, 97, 112, 112, 108, 121, 95, 103, 97,
  109, 109, 97, 32, 36, 49, 52, 10, 105, 97, 105, 110, 95, 114, 103, 98,
  50, 121, 99, 98, 99, 114, 58, 10, 114, 101, 100, 109, 117, 108, 61, 46,
  50, 57, 57, 10, 103, 114, 101, 101, 110, 109, 117, 108, 61, 46, 53, 56,
  55, 10, 98, 108, 117, 101, 109, 117, 108, 61, 46, 49, 49, 52, 10, 45,
  116, 111, 95, 114, 103, 98, 91, 48, 93, 10, 45, 45, 115, 112, 108, 105,
  116, 91, 48, 93, 32, 99, 10, 45, 109, 117, 108, 91, 49, 93, 32, 36,
  114, 101, 100, 109, 117, 108, 10, 45, 109, 117, 108, 91, 50, 93, 32, 36,
  103, 114, 101, 101, 110, 109, 117, 108, 10, 45, 109, 117, 108, 91, 51, 93,
  32, 36, 98, 108, 117, 101, 109, 117, 108, 10, 45, 97, 100, 100, 91, 49,
  45, 51, 93, 10, 45, 115, 112, 108, 105, 116, 91, 48, 93, 32, 99, 10,
  45, 110, 97, 109, 101, 91, 48, 93, 32, 114, 101, 100, 10, 45, 110, 97,
  109, 101, 91, 49, 93, 32, 103, 114, 101, 101, 110, 10, 45, 110, 97, 109,
  101, 91, 50, 93, 32, 98, 108, 117, 101, 10, 45, 110, 97, 109, 101, 91,
  51, 93, 32, 108, 117, 109, 97, 10, 45, 45, 115, 117, 98, 91, 98, 108,
  117, 101, 93, 32, 91, 108, 117, 109, 97, 93, 10, 45, 110, 97, 109, 101,
  91, 45, 49, 93, 32, 99, 98, 10, 45, 45, 115, 117, 98, 91, 114, 101,
  100, 93, 32, 91, 108, 117, 109, 97, 93, 10, 45, 110, 97, 109, 101, 91,
  45, 49, 93, 32, 99, 114, 10, 45, 107, 101, 101, 112, 91, 108, 117, 109,
  97, 44, 99, 98, 44, 99, 114, 93, 10, 45, 97, 112, 112, 101, 110, 100,
  91, 108, 117, 109, 97, 44, 99, 98, 44, 99, 114, 93, 32, 99, 10, 105,
  97, 105, 110, 95, 121, 99, 98, 99, 114, 50, 114, 103, 98, 58, 10, 114,
  101, 100, 109, 117, 108, 61, 46, 50, 57, 57, 10, 103, 114, 101, 101, 110,
  109, 117, 108, 61, 46, 53, 56, 55, 10, 98, 108, 117, 101, 109, 117, 108,
  61, 46, 49, 49, 52, 10, 45, 115, 112, 108, 105, 116, 32, 99, 10, 45,
  110, 97, 109, 101, 91, 48, 93, 32, 108, 117, 109, 97, 10, 45, 110, 97,
  109, 101, 91, 49, 93, 32, 99, 98, 10, 45, 110, 97, 109, 101, 91, 50,
  93, 32, 99, 114, 10, 45, 45, 97, 100, 100, 91, 99, 98, 93, 32, 91,
  108, 117, 109, 97, 93, 10, 45, 110, 97, 109, 101, 91, 45, 49, 93, 32,
  98, 108, 117, 101, 111, 117, 116, 10, 45, 45, 97, 100, 100, 91, 99, 114,
  93, 32, 91, 108, 117, 109, 97, 93, 10, 45, 110, 97, 109, 101, 91, 45,
  49, 93, 32, 114, 101, 100, 111, 117, 116, 10, 45, 114, 101, 109, 111, 118,
  101, 91, 49, 44, 50, 93, 10, 45, 45, 109, 117, 108, 91, 114, 101, 100,
  111, 117, 116, 93, 32, 36, 114, 101, 100, 109, 117, 108, 10, 45, 45, 109,
  117, 108, 91, 98, 108, 117, 101, 111, 117, 116, 93, 32, 36, 98, 108, 117,
  101, 109, 117, 108, 10, 45, 115, 117, 98, 91, 108, 117, 109, 97, 93, 32,
  91, 45, 49, 93, 10, 45, 115, 117, 98, 91, 108, 117, 109, 97, 93, 32,
  91, 45, 50, 93, 10, 45, 100, 105, 118, 91, 108, 117, 109, 97, 93, 32,
  36, 103, 114, 101, 101, 110, 109, 117, 108, 10, 45, 114, 101, 109, 111, 118,
  101, 91, 45, 49, 44, 45, 50, 93, 10, 45, 109, 111, 118, 101, 91, 50,
  93, 32, 48, 10, 45, 97, 112, 112, 101, 110, 100, 32, 99, 10, 105, 97,
  105, 110, 95, 105, 97, 105, 110, 115, 95, 110, 114, 95, 112, 114, 101, 118,
  105, 101, 119, 58, 10, 45, 105, 102, 32, 123, 36, 45, 49, 61, 61, 48,
  125, 10, 45, 105, 97, 105, 110, 95, 105, 97, 105, 110, 115, 95, 110, 114,
  32, 36, 123, 49, 45, 45, 50, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 45, 49, 61, 61, 49, 125, 10, 45, 45, 105,
  97, 105, 110, 95, 105, 97, 105, 110, 115, 95, 110, 114, 32, 36, 49, 44,
  48, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55,
  44, 36, 56, 44, 36, 57, 44, 36, 49, 48, 44, 49, 46, 51, 44, 48,
  10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 101,
  120, 116, 114, 97, 99, 116, 10, 45, 115, 117, 98, 32, 49, 50, 56, 10,
  45, 109, 117, 108, 32, 51, 10, 45, 97, 100, 100, 32, 49, 50, 56, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 45, 49, 61,
  61, 50, 125, 10, 45, 45, 105, 97, 105, 110, 95, 105, 97, 105, 110, 115,
  95, 110, 114, 32, 48, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36,
  53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 44, 36, 57, 44, 36, 49,
  48, 44, 36, 49, 49, 44, 48, 10, 45, 99, 111, 109, 112, 111, 115, 101,
  95, 103, 114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116, 10, 45, 115,
  117, 98, 32, 49, 50, 56, 10, 45, 109, 117, 108, 32, 51, 10, 45, 97,
  100, 100, 32, 49, 50, 56, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 45, 49, 61, 61, 51, 125, 10, 45, 105, 97, 105, 110,
  95, 105, 97, 105, 110, 115, 95, 110, 114, 32, 36, 49, 44, 36, 50, 44,
  36, 51, 44, 36, 52, 44, 36, 53, 44, 50, 44, 36, 55, 44, 36, 56,
  44, 36, 57, 44, 36, 49, 48, 44, 36, 49, 49, 44, 48, 10, 45, 107,
  101, 101, 112, 91, 45, 49, 93, 10, 45, 115, 117, 98, 32, 49, 50, 56,
  10, 45, 109, 117, 108, 32, 51, 10, 45, 97, 100, 100, 32, 49, 50, 56,
  10, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103, 105, 109, 112, 32, 73,
  110, 112, 97, 105, 110, 116, 32, 91, 100, 105, 102, 102, 117, 115, 105, 111,
  110, 93, 32, 58, 32, 103, 105, 109, 112, 95, 105, 110, 112, 97, 105, 110,
  116, 95, 100, 105, 102, 102, 117, 115, 105, 111, 110, 44, 32, 103, 105, 109,
  112, 95, 105, 110, 112, 97, 105, 110, 116, 95, 100, 105, 102, 102, 117, 115,
  105, 111, 110, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 32, 105,
  110, 112, 97, 105, 110, 116, 32, 61, 32, 98, 111, 111, 108, 40, 116, 114,
  117, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 108, 111,
  98, 97, 108, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 61,
  32, 105, 110, 116, 40, 49, 48, 44, 49, 44, 51, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 76, 111, 99, 97, 108, 32, 105, 116, 101,
  114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 49, 48,
  44, 49, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  84, 105, 109, 101, 32, 115, 116, 101, 112, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 50, 48, 44, 53, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 71, 114, 97, 100, 105, 101, 110, 116, 32, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 55, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 84, 101, 110, 115, 111, 114, 32, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 50, 44,
  48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 97, 115, 107, 32, 116, 121,
  112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 79,
  112, 97, 113, 117, 101, 32, 114, 101, 103, 105, 111, 110, 115, 32, 105, 110,
  32, 116, 111, 112, 32, 108, 97, 121, 101, 114, 34, 44, 34, 77, 97, 115,
  107, 32, 98, 121, 32, 99, 111, 108, 111, 114, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 73, 102, 32, 60, 105, 62,
  77, 97, 115, 107, 32, 98, 121, 32, 99, 111, 108, 111, 114, 60, 47, 105,
  62, 32, 104, 97, 115, 32, 98, 101, 101, 110, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 32, 58, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 97, 115, 107, 32, 99, 111,
  108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44,
  48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 60, 98, 62, 78, 111, 116, 101, 58, 60, 47, 98, 62, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 87, 104, 101, 110, 32, 60, 105, 62, 39,
  77, 97, 115, 107, 32, 98, 121, 32, 99, 111, 108, 111, 114, 39, 60, 47,
  105, 62, 32, 109, 111, 100, 101, 32, 105, 115, 32, 115, 101, 108, 101, 99,
  116, 101, 100, 44, 32, 112, 114, 101, 118, 105, 101, 119, 32, 105, 115, 32,
  108, 105, 107, 101, 108, 121, 32, 116, 111, 32, 98, 101, 32, 105, 110, 97,
  99, 99, 117, 114, 97, 116, 101, 46, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115,
  99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47,
  49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 105, 110, 112, 97, 105, 110,
  116, 95, 100, 105, 102, 102, 117, 115, 105, 111, 110, 32, 58, 10, 45, 105,
  102, 32, 36, 55, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 45, 115, 101, 108, 101, 99, 116, 95,
  99, 111, 108, 111, 114, 32, 48, 44, 36, 123, 56, 45, 49, 49, 125, 32,
  45, 114, 118, 10, 45, 105, 102, 32, 36, 49, 32, 45, 105, 110, 112, 97,
  105, 110, 116, 95, 102, 108, 111, 119, 32, 36, 50, 44, 36, 51, 44, 36,
  52, 44, 36, 53, 37, 44, 36, 54, 37, 32, 45, 99, 32, 48, 44, 50,
  53, 53, 32, 45, 101, 108, 115, 101, 32, 45, 105, 110, 112, 97, 105, 110,
  116, 91, 49, 93, 32, 91, 48, 93, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 114, 109, 91, 48, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 45, 101, 108, 115, 101, 10, 45, 105, 102, 32, 123, 64, 35,
  61, 61, 49, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 116, 111, 95, 97, 91, 48, 93, 32, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 48, 93, 32, 49, 48, 48, 37, 32, 45,
  103, 101, 91, 48, 93, 32, 53, 48, 37, 10, 45, 105, 102, 32, 36, 49,
  32, 45, 105, 110, 112, 97, 105, 110, 116, 95, 102, 108, 111, 119, 32, 36,
  50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 37, 44, 36, 54, 37, 32,
  45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 115, 101, 32, 45,
  105, 110, 112, 97, 105, 110, 116, 91, 94, 48, 93, 32, 91, 48, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 97, 91, 48, 93, 32,
  45, 102, 91, 48, 93, 32, 48, 10, 45, 101, 110, 100, 105, 102, 10, 103,
  105, 109, 112, 95, 105, 110, 112, 97, 105, 110, 116, 95, 100, 105, 102, 102,
  117, 115, 105, 111, 110, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 105, 110, 112, 97, 105, 110, 116, 95, 100, 105,
  102, 102, 117, 115, 105, 111, 110, 32, 36, 123, 94, 48, 125, 10, 45, 105,
  102, 32, 123, 33, 36, 55, 34, 32, 38, 38, 32, 34, 64, 35, 62, 49,
  125, 32, 45, 114, 109, 91, 48, 93, 32, 45, 101, 110, 100, 105, 102, 10,
  35, 64, 103, 105, 109, 112, 32, 73, 110, 112, 97, 105, 110, 116, 32, 91,
  112, 97, 116, 99, 104, 45, 98, 97, 115, 101, 100, 93, 32, 58, 32, 103,
  105, 109, 112, 95, 105, 110, 112, 97, 105, 110, 116, 95, 112, 97, 116, 99,
  104, 44, 32, 103, 105, 109, 112, 95, 110, 111, 95, 112, 114, 101, 118, 105,
  101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 116, 99,
  104, 32, 115, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 55, 44, 49,
  44, 54, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 111,
  111, 107, 117, 112, 32, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 54, 44, 49, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 76, 111, 111, 107, 117, 112, 32, 102, 97, 99, 116, 111,
  114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 49, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 101, 110,
  100, 32, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  46, 50, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 66, 108, 101, 110, 100, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 101, 110, 100, 32, 100,
  101, 99, 97, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 48,
  53, 44, 48, 44, 48, 46, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 66, 108, 101, 110, 100, 32, 115, 99, 97, 108, 101, 115, 32, 61,
  32, 105, 110, 116, 40, 49, 48, 44, 49, 44, 50, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 65, 108, 108, 111, 119, 32, 111, 117, 116,
  101, 114, 32, 98, 108, 101, 110, 100, 105, 110, 103, 32, 61, 32, 98, 111,
  111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 97, 115, 107, 32, 116,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34,
  79, 112, 97, 113, 117, 101, 32, 114, 101, 103, 105, 111, 110, 115, 32, 105,
  110, 32, 116, 111, 112, 32, 108, 97, 121, 101, 114, 34, 44, 34, 77, 97,
  115, 107, 32, 98, 121, 32, 99, 111, 108, 111, 114, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 73, 102, 32, 60, 105,
  62, 77, 97, 115, 107, 32, 98, 121, 32, 99, 111, 108, 111, 114, 60, 47,
  105, 62, 32, 104, 97, 115, 32, 98, 101, 101, 110, 32, 115, 101, 108, 101,
  99, 116, 101, 100, 32, 58, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 97, 115, 107, 32, 99,
  111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53,
  44, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 32, 113, 117, 105, 99,
  107, 32, 116, 117, 116, 111, 114, 105, 97, 108, 32, 111, 110, 32, 104, 111,
  119, 32, 116, 111, 32, 117, 115, 101, 32, 116, 104, 105, 115, 32, 102, 105,
  108, 116, 101, 114, 32, 99, 97, 110, 32, 98, 101, 32, 102, 111, 117, 110,
  100, 32, 104, 101, 114, 101, 58, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 110, 107, 32,
  61, 32, 108, 105, 110, 107, 40, 34, 71, 39, 77, 73, 67, 32, 73, 110,
  112, 97, 105, 110, 116, 105, 110, 103, 32, 116, 117, 116, 111, 114, 105, 97,
  108, 32, 111, 110, 32, 80, 97, 116, 114, 105, 99, 107, 32, 68, 97, 118,
  105, 100, 39, 115, 32, 98, 108, 111, 103, 46, 34, 44, 34, 104, 116, 116,
  112, 58, 47, 47, 98, 108, 111, 103, 46, 112, 97, 116, 100, 97, 118, 105,
  100, 46, 110, 101, 116, 47, 50, 48, 49, 52, 47, 48, 50, 47, 103, 101,
  116, 116, 105, 110, 103, 45, 97, 114, 111, 117, 110, 100, 45, 105, 110, 45,
  103, 105, 109, 112, 45, 103, 109, 105, 99, 45, 105, 110, 112, 97, 105, 110,
  116, 105, 110, 103, 46, 104, 116, 109, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 115, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115,
  99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47,
  105, 62, 32, 97, 110, 100, 32, 60, 105, 62, 77, 97, 120, 105, 109, 101,
  32, 68, 97, 105, 115, 121, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 51, 47, 48, 51, 47, 50, 53, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 105, 110, 112, 97, 105, 110, 116, 95, 112, 97, 116, 99, 104, 32,
  58, 10, 45, 105, 102, 32, 123, 64, 46, 62, 61, 49, 53, 56, 49, 125,
  32, 105, 110, 112, 97, 105, 110, 116, 61, 105, 110, 112, 97, 105, 110, 116,
  32, 45, 101, 108, 115, 101, 32, 105, 110, 112, 97, 105, 110, 116, 61, 114,
  101, 112, 97, 105, 114, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 36, 57, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 45, 115, 101, 108, 101, 99, 116, 95, 99,
  111, 108, 111, 114, 32, 48, 44, 36, 123, 49, 48, 45, 49, 51, 125, 10,
  45, 105, 102, 32, 123, 64, 46, 62, 61, 49, 53, 56, 52, 125, 32, 45,
  36, 105, 110, 112, 97, 105, 110, 116, 91, 48, 93, 32, 91, 49, 93, 44,
  36, 49, 44, 123, 36, 49, 42, 36, 50, 125, 44, 36, 51, 44, 49, 44,
  123, 36, 52, 42, 36, 49, 125, 44, 36, 123, 53, 45, 56, 125, 10, 45,
  101, 108, 105, 102, 32, 123, 64, 46, 62, 61, 49, 53, 56, 51, 125, 32,
  45, 36, 105, 110, 112, 97, 105, 110, 116, 91, 48, 93, 32, 91, 49, 93,
  44, 36, 49, 44, 123, 36, 49, 42, 36, 50, 125, 44, 36, 51, 44, 123,
  36, 52, 42, 36, 49, 125, 44, 36, 123, 53, 45, 56, 125, 10, 45, 101,
  108, 115, 101, 32, 45, 36, 105, 110, 112, 97, 105, 110, 116, 91, 48, 93,
  32, 91, 49, 93, 44, 36, 49, 44, 123, 36, 49, 42, 36, 50, 125, 44,
  123, 114, 111, 117, 110, 100, 40, 49, 43, 36, 51, 41, 125, 44, 123, 36,
  52, 42, 36, 49, 125, 44, 36, 123, 53, 45, 56, 125, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 114, 109, 91, 49, 93, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 115, 101, 10, 45, 105, 102,
  32, 123, 64, 35, 61, 61, 49, 125, 32, 45, 114, 101, 116, 117, 114, 110,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 97, 91, 48, 93,
  32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48, 93, 32, 49, 48,
  48, 37, 32, 45, 103, 101, 91, 48, 93, 32, 53, 48, 37, 10, 45, 105,
  102, 32, 123, 64, 46, 62, 61, 49, 53, 56, 52, 125, 32, 45, 36, 105,
  110, 112, 97, 105, 110, 116, 91, 94, 48, 93, 32, 91, 48, 93, 44, 36,
  49, 44, 123, 36, 49, 42, 36, 50, 125, 44, 36, 51, 44, 49, 44, 123,
  36, 52, 42, 36, 49, 125, 44, 36, 123, 53, 45, 56, 125, 10, 45, 101,
  108, 105, 102, 32, 123, 64, 46, 62, 61, 49, 53, 56, 51, 125, 32, 45,
  36, 105, 110, 112, 97, 105, 110, 116, 91, 94, 48, 93, 32, 91, 48, 93,
  44, 36, 49, 44, 123, 36, 49, 42, 36, 50, 125, 44, 36, 51, 44, 123,
  36, 52, 42, 36, 49, 125, 44, 36, 123, 53, 45, 56, 125, 10, 45, 101,
  108, 115, 101, 32, 45, 36, 105, 110, 112, 97, 105, 110, 116, 91, 94, 48,
  93, 32, 91, 48, 93, 44, 36, 49, 44, 123, 36, 49, 42, 36, 50, 125,
  44, 123, 114, 111, 117, 110, 100, 40, 49, 43, 36, 51, 41, 125, 44, 123,
  36, 52, 42, 36, 49, 125, 44, 36, 123, 53, 45, 56, 125, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 116, 111, 95, 97, 91, 48, 93, 32, 45, 102,
  91, 48, 93, 32, 48, 10, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103,
  105, 109, 112, 32, 73, 110, 112, 97, 105, 110, 116, 32, 91, 115, 111, 108,
  105, 100, 105, 102, 121, 93, 32, 58, 32, 103, 105, 109, 112, 95, 115, 111,
  108, 105, 100, 105, 102, 121, 44, 32, 103, 105, 109, 112, 95, 115, 111, 108,
  105, 100, 105, 102, 121, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 105, 111, 110, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 76, 105, 110, 101, 97, 114, 34, 44, 34,
  77, 111, 114, 112, 104, 111, 108, 111, 103, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  60, 98, 62, 70, 111, 114, 32, 108, 105, 110, 101, 97, 114, 32, 109, 101,
  116, 104, 111, 100, 32, 111, 110, 108, 121, 32, 58, 60, 47, 98, 62, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 46, 53, 44, 49, 44, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 102, 97, 99, 116, 111, 114, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 44, 49, 44, 49, 46, 50, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 80, 114, 101, 99, 105, 115, 105, 111, 110, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105,
  99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 78, 111, 116, 101, 58, 60,
  47, 98, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 105,
  115, 32, 102, 105, 108, 116, 101, 114, 32, 114, 101, 112, 108, 97, 99, 101,
  115, 32, 116, 114, 97, 110, 115, 112, 97, 114, 101, 110, 116, 32, 114, 101,
  103, 105, 111, 110, 115, 32, 98, 121, 32, 105, 110, 116, 101, 114, 112, 111,
  108, 97, 116, 101, 100, 32, 99, 111, 108, 111, 114, 115, 46, 32, 73, 116,
  32, 109, 97, 121, 32, 116, 97, 107, 101, 32, 108, 111, 110, 103, 32, 116,
  111, 32, 114, 101, 110, 100, 101, 114, 33, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84,
  115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49,
  47, 49, 50, 47, 48, 49, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 115, 111, 108, 105, 100,
  105, 102, 121, 32, 58, 10, 45, 105, 102, 32, 36, 49, 32, 45, 115, 111,
  108, 105, 100, 105, 102, 121, 10, 45, 101, 108, 115, 101, 32, 45, 115, 111,
  108, 105, 100, 105, 102, 121, 95, 108, 105, 110, 101, 97, 114, 32, 36, 50,
  44, 36, 51, 44, 36, 52, 10, 45, 101, 110, 100, 105, 102, 10, 103, 105,
  109, 112, 95, 115, 111, 108, 105, 100, 105, 102, 121, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112,
  95, 115, 111, 108, 105, 100, 105, 102, 121, 32, 36, 42, 34, 44, 36, 45,
  49, 10, 35, 64, 103, 105, 109, 112, 32, 76, 111, 99, 97, 108, 32, 115,
  105, 109, 105, 108, 97, 114, 105, 116, 121, 32, 109, 97, 115, 107, 32, 58,
  32, 108, 111, 99, 97, 108, 95, 115, 105, 109, 105, 108, 97, 114, 105, 116,
  121, 95, 109, 97, 115, 107, 44, 32, 108, 111, 99, 97, 108, 95, 115, 105,
  109, 105, 108, 97, 114, 105, 116, 121, 95, 109, 97, 115, 107, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 83,
  101, 108, 101, 99, 116, 32, 112, 105, 120, 101, 108, 115, 32, 97, 116, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 101, 110, 116, 114,
  101, 32, 104, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 53, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 101, 110, 116, 114, 101, 32, 118, 32, 61, 32, 102, 108, 111, 97, 116,
  32, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 87, 105, 116, 104, 32, 115, 105, 109, 105, 108, 97, 114, 105, 116,
  121, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 75, 101, 101,
  112, 32, 61, 32, 105, 110, 116, 32, 40, 53, 48, 44, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 106, 101,
  99, 116, 32, 61, 32, 105, 110, 116, 32, 40, 49, 50, 56, 44, 48, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 79, 110, 32, 116, 104,
  101, 115, 101, 32, 99, 104, 97, 110, 110, 101, 108, 115, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40,
  115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 52, 44, 34, 82,
  71, 66, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110,
  34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 76, 117, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105,
  111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 76, 105, 103,
  104, 116, 110, 101, 115, 115, 34, 44, 34, 91, 67, 121, 97, 110, 93, 77,
  89, 75, 34, 44, 34, 67, 91, 77, 97, 103, 101, 110, 116, 97, 93, 89,
  75, 34, 44, 34, 67, 77, 91, 89, 101, 108, 108, 111, 119, 93, 75, 34,
  44, 34, 67, 77, 89, 91, 75, 101, 121, 93, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 70, 97, 115, 116, 32, 61, 32, 98, 111, 111,
  108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 84, 104, 105, 115, 32, 102, 105, 108, 116, 101,
  114, 32, 99, 114, 101, 97, 116, 101, 115, 32, 97, 32, 109, 97, 115, 107,
  32, 98, 97, 115, 101, 100, 32, 111, 110, 32, 112, 105, 120, 101, 108, 115,
  32, 116, 104, 97, 116, 32, 97, 114, 101, 32, 99, 108, 111, 115, 101, 32,
  116, 111, 44, 32, 97, 110, 100, 32, 115, 105, 109, 105, 108, 97, 114, 32,
  116, 111, 44, 32, 116, 104, 101, 32, 115, 101, 108, 101, 99, 116, 101, 100,
  32, 112, 105, 120, 101, 108, 46, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  84, 104, 101, 32, 60, 105, 62, 102, 97, 115, 116, 60, 47, 105, 62, 32,
  111, 112, 116, 105, 111, 110, 32, 115, 99, 97, 108, 101, 115, 32, 116, 104,
  101, 32, 105, 109, 97, 103, 101, 32, 116, 111, 32, 104, 97, 108, 102, 45,
  115, 105, 122, 101, 32, 116, 111, 32, 100, 111, 32, 116, 104, 101, 32, 99,
  97, 108, 99, 117, 108, 97, 116, 105, 111, 110, 115, 32, 97, 110, 100, 32,
  103, 105, 118, 101, 115, 32, 97, 32, 115, 111, 102, 116, 101, 114, 32, 114,
  101, 115, 117, 108, 116, 32, 105, 110, 32, 97, 114, 111, 117, 110, 100, 32,
  111, 110, 101, 32, 113, 117, 97, 114, 116, 101, 114, 32, 111, 102, 32, 116,
  104, 101, 32, 116, 105, 109, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  83, 112, 101, 101, 100, 32, 105, 115, 32, 97, 108, 115, 111, 32, 100, 101,
  116, 101, 114, 109, 105, 110, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32,
  100, 105, 102, 102, 101, 114, 101, 110, 99, 101, 32, 98, 101, 116, 119, 101,
  101, 110, 32, 60, 105, 62, 75, 101, 101, 112, 60, 47, 105, 62, 32, 97,
  110, 100, 32, 60, 105, 62, 82, 101, 106, 101, 99, 116, 60, 47, 105, 62,
  32, 108, 97, 114, 103, 101, 32, 100, 105, 102, 102, 101, 114, 101, 110, 99,
  101, 115, 32, 119, 105, 108, 108, 32, 100, 114, 97, 115, 116, 105, 99, 97,
  108, 108, 121, 32, 115, 108, 111, 119, 32, 100, 111, 119, 110, 32, 116, 104,
  101, 32, 102, 105, 108, 116, 101, 114, 46, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62,
  73, 97, 105, 110, 32, 70, 101, 114, 103, 117, 115, 115, 111, 110, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 108, 111,
  99, 97, 108, 95, 115, 105, 109, 105, 108, 97, 114, 105, 116, 121, 95, 109,
  97, 115, 107, 58, 10, 45, 105, 102, 32, 123, 36, 54, 61, 61, 49, 125,
  10, 45, 114, 101, 115, 105, 122, 101, 32, 53, 48, 37, 44, 53, 48, 37,
  44, 49, 44, 51, 44, 50, 10, 45, 101, 110, 100, 105, 102, 10, 45, 116,
  111, 95, 114, 103, 98, 10, 45, 105, 102, 32, 123, 36, 53, 33, 61, 48,
  125, 10, 45, 105, 102, 32, 123, 36, 53, 61, 61, 49, 125, 32, 32, 45,
  115, 112, 108, 105, 116, 91, 48, 93, 32, 99, 32, 45, 107, 101, 101, 112,
  91, 48, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 53, 61, 61, 50, 125, 32, 32, 45, 115, 112, 108, 105, 116, 91, 48,
  93, 32, 99, 32, 45, 107, 101, 101, 112, 91, 49, 93, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 53, 61, 61, 51, 125, 32,
  32, 45, 115, 112, 108, 105, 116, 91, 48, 93, 32, 99, 32, 45, 107, 101,
  101, 112, 91, 50, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 53, 61, 61, 52, 125, 32, 45, 108, 117, 109, 105, 110, 97,
  110, 99, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 53, 61, 61, 53, 125, 32, 45, 114, 103, 98, 50, 108, 97, 98, 91,
  48, 93, 32, 45, 115, 112, 108, 105, 116, 91, 48, 93, 32, 99, 32, 45,
  107, 101, 101, 112, 91, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 53, 61, 61, 54, 125, 32, 45, 114, 103, 98, 50,
  108, 97, 98, 91, 48, 93, 32, 45, 115, 112, 108, 105, 116, 91, 48, 93,
  32, 99, 32, 45, 107, 101, 101, 112, 91, 50, 93, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 53, 61, 61, 55, 125, 32, 45,
  114, 103, 98, 50, 104, 115, 118, 91, 48, 93, 32, 45, 115, 112, 108, 105,
  116, 91, 48, 93, 32, 99, 32, 45, 107, 101, 101, 112, 91, 48, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 53, 61, 61,
  56, 125, 32, 45, 114, 103, 98, 50, 104, 115, 118, 91, 48, 93, 32, 45,
  115, 112, 108, 105, 116, 91, 48, 93, 32, 99, 32, 45, 107, 101, 101, 112,
  91, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 53, 61, 61, 57, 125, 32, 45, 114, 103, 98, 50, 104, 115, 118, 91,
  48, 93, 32, 45, 115, 112, 108, 105, 116, 91, 48, 93, 32, 99, 32, 45,
  107, 101, 101, 112, 91, 50, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 53, 61, 61, 49, 48, 125, 32, 45, 114, 103, 98,
  50, 104, 115, 108, 91, 48, 93, 32, 45, 115, 112, 108, 105, 116, 91, 48,
  93, 32, 99, 32, 45, 107, 101, 101, 112, 91, 50, 93, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 53, 61, 61, 49, 49, 125,
  32, 45, 114, 103, 98, 50, 99, 109, 121, 107, 91, 48, 93, 32, 45, 115,
  112, 108, 105, 116, 91, 48, 93, 32, 99, 32, 45, 107, 101, 101, 112, 91,
  48, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  53, 61, 61, 49, 50, 125, 32, 45, 114, 103, 98, 50, 99, 109, 121, 107,
  91, 48, 93, 32, 45, 115, 112, 108, 105, 116, 91, 48, 93, 32, 99, 32,
  45, 107, 101, 101, 112, 91, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 53, 61, 61, 49, 51, 125, 32, 45, 114, 103,
  98, 50, 99, 109, 121, 107, 91, 48, 93, 32, 45, 115, 112, 108, 105, 116,
  91, 48, 93, 32, 99, 32, 45, 107, 101, 101, 112, 91, 50, 93, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 53, 61, 61, 49,
  52, 125, 32, 45, 114, 103, 98, 50, 99, 109, 121, 107, 91, 48, 93, 32,
  45, 115, 112, 108, 105, 116, 91, 48, 93, 32, 99, 32, 45, 107, 101, 101,
  112, 91, 51, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 109, 117, 108,
  91, 48, 93, 32, 48, 46, 57, 10, 123, 119, 125, 44, 123, 104, 125, 44,
  49, 44, 49, 44, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36,
  52, 45, 36, 51, 125, 10, 45, 45, 102, 108, 111, 111, 100, 91, 48, 93,
  32, 36, 49, 37, 44, 36, 50, 37, 44, 48, 44, 123, 36, 51, 43, 36,
  62, 125, 44, 48, 44, 49, 44, 50, 53, 53, 32, 45, 116, 104, 114, 101,
  115, 104, 111, 108, 100, 91, 45, 49, 93, 32, 57, 57, 37, 10, 45, 97,
  100, 100, 91, 45, 49, 44, 45, 50, 93, 10, 45, 100, 111, 110, 101, 10,
  45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 45, 110, 32, 48, 44, 50,
  53, 53, 10, 45, 105, 102, 32, 123, 36, 54, 61, 61, 49, 125, 10, 45,
  114, 101, 115, 105, 122, 101, 32, 50, 48, 48, 37, 44, 50, 48, 48, 37,
  44, 49, 44, 51, 44, 51, 10, 45, 101, 110, 100, 105, 102, 10, 108, 111,
  99, 97, 108, 95, 115, 105, 109, 105, 108, 97, 114, 105, 116, 121, 95, 109,
  97, 115, 107, 95, 112, 114, 101, 118, 105, 101, 119, 58, 10, 45, 108, 111,
  99, 97, 108, 95, 115, 105, 109, 105, 108, 97, 114, 105, 116, 121, 95, 109,
  97, 115, 107, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44,
  36, 53, 44, 48, 10, 45, 116, 111, 95, 114, 103, 98, 10, 45, 108, 105,
  110, 101, 32, 49, 48, 48, 37, 44, 36, 50, 37, 44, 123, 36, 49, 43,
  53, 125, 37, 44, 36, 50, 37, 44, 48, 46, 53, 44, 50, 53, 53, 44,
  48, 44, 48, 10, 45, 108, 105, 110, 101, 32, 48, 37, 44, 36, 50, 37,
  44, 123, 36, 49, 45, 53, 125, 37, 44, 36, 50, 37, 44, 48, 46, 53,
  44, 50, 53, 53, 44, 48, 44, 48, 10, 45, 108, 105, 110, 101, 32, 36,
  49, 37, 44, 49, 48, 48, 37, 44, 36, 49, 37, 44, 123, 36, 50, 43,
  53, 125, 37, 44, 48, 46, 53, 44, 50, 53, 53, 44, 48, 44, 48, 10,
  45, 108, 105, 110, 101, 32, 36, 49, 37, 44, 48, 37, 44, 36, 49, 37,
  44, 123, 36, 50, 45, 53, 125, 37, 44, 48, 46, 53, 44, 50, 53, 53,
  44, 48, 44, 48, 10, 35, 64, 103, 105, 109, 112, 32, 80, 105, 120, 101,
  108, 32, 100, 101, 110, 111, 105, 115, 101, 32, 58, 32, 105, 97, 105, 110,
  95, 112, 105, 120, 101, 108, 95, 100, 101, 110, 111, 105, 115, 101, 95, 112,
  44, 32, 105, 97, 105, 110, 95, 112, 105, 120, 101, 108, 95, 100, 101, 110,
  111, 105, 115, 101, 95, 112, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 101, 116, 104, 111,
  100, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 79, 108, 100, 32,
  77, 101, 116, 104, 111, 100, 34, 44, 34, 72, 121, 98, 114, 105, 100, 32,
  77, 101, 100, 105, 97, 110, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101,
  114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 49, 44,
  49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 51, 44, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65,
  34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117,
  101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34,
  44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34,
  83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108,
  117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 65, 108, 112, 104, 97,
  34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115,
  34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82,
  101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117,
  101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 115, 104, 111, 119, 115, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 79, 117, 116, 112, 117, 116,
  34, 44, 34, 68, 105, 102, 102, 101, 114, 101, 110, 99, 101, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 80, 97, 114, 97, 108, 108, 101, 108, 32, 112, 114, 111,
  99, 101, 115, 115, 105, 110, 103, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 49, 44, 34, 79, 102, 102, 34, 44, 34, 65, 117, 116, 111, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32,
  58, 32, 60, 105, 62, 73, 97, 105, 110, 32, 70, 101, 114, 103, 117, 115,
  115, 111, 110, 60, 47, 105, 62, 46, 32, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 85, 112, 100, 97, 116, 101, 32, 45, 32, 49, 32, 68, 101, 99, 101,
  109, 98, 101, 114, 32, 50, 48, 49, 51, 32, 45, 32, 70, 105, 120, 101,
  100, 32, 115, 111, 109, 101, 32, 98, 117, 103, 115, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 85, 112, 100, 97, 116, 101, 32, 45, 32, 50, 48, 32,
  79, 99, 116, 111, 98, 101, 114, 32, 50, 48, 49, 51, 32, 45, 32, 80,
  97, 114, 97, 108, 108, 101, 108, 32, 80, 114, 111, 99, 101, 115, 115, 105,
  110, 103, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 85, 112, 100, 97, 116, 101,
  32, 45, 32, 56, 32, 77, 97, 114, 99, 104, 32, 50, 48, 49, 51, 32,
  45, 32, 73, 110, 99, 111, 114, 112, 101, 114, 97, 116, 101, 100, 32, 72,
  121, 98, 114, 105, 100, 32, 77, 101, 100, 105, 97, 110, 32, 105, 110, 116,
  111, 32, 116, 104, 105, 115, 32, 102, 105, 108, 116, 101, 114, 32, 97, 110,
  100, 32, 97, 100, 100, 101, 100, 32, 97, 32, 99, 104, 111, 105, 99, 101,
  32, 98, 101, 116, 119, 101, 101, 110, 32, 116, 104, 101, 32, 111, 108, 100,
  32, 109, 101, 116, 104, 111, 100, 32, 97, 110, 100, 32, 104, 121, 98, 114,
  105, 100, 32, 109, 101, 100, 105, 97, 110, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 99, 114, 101, 97, 116, 101, 98, 99, 58, 10, 40, 48,
  46, 53, 44, 48, 46, 53, 44, 48, 59, 48, 44, 48, 44, 48, 59, 48,
  44, 48, 44, 48, 41, 10, 40, 48, 46, 53, 44, 48, 44, 48, 46, 53,
  59, 48, 44, 48, 44, 48, 59, 48, 44, 48, 44, 48, 41, 10, 45, 45,
  99, 111, 110, 118, 111, 108, 118, 101, 91, 48, 93, 32, 91, 49, 93, 10,
  45, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 48, 93, 32, 91, 50,
  93, 10, 45, 107, 101, 101, 112, 91, 48, 44, 45, 49, 44, 45, 50, 93,
  10, 45, 105, 97, 105, 110, 95, 109, 101, 100, 105, 97, 110, 95, 51, 95,
  115, 116, 97, 99, 107, 91, 48, 44, 49, 44, 50, 93, 10, 45, 107, 101,
  101, 112, 91, 45, 49, 93, 10, 99, 114, 101, 97, 116, 101, 98, 100, 58,
  10, 40, 48, 46, 53, 44, 48, 44, 48, 59, 48, 44, 48, 44, 48, 46,
  53, 59, 48, 44, 48, 44, 48, 41, 10, 40, 48, 46, 53, 44, 48, 44,
  48, 59, 48, 44, 48, 44, 48, 59, 48, 44, 48, 44, 48, 46, 53, 41,
  10, 45, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 48, 93, 32, 91,
  49, 93, 10, 45, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 48, 93,
  32, 91, 50, 93, 10, 45, 107, 101, 101, 112, 91, 48, 44, 45, 49, 44,
  45, 50, 93, 10, 45, 105, 97, 105, 110, 95, 109, 101, 100, 105, 97, 110,
  95, 51, 95, 115, 116, 97, 99, 107, 91, 48, 44, 49, 44, 50, 93, 10,
  45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 99, 114, 101, 97, 116, 101,
  98, 101, 58, 10, 40, 48, 46, 53, 44, 48, 44, 48, 59, 48, 44, 48,
  44, 48, 59, 48, 44, 48, 46, 53, 44, 48, 41, 10, 40, 48, 46, 53,
  44, 48, 44, 48, 59, 48, 44, 48, 44, 48, 59, 48, 46, 53, 44, 48,
  44, 48, 41, 10, 45, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 48,
  93, 32, 91, 49, 93, 10, 45, 45, 99, 111, 110, 118, 111, 108, 118, 101,
  91, 48, 93, 32, 91, 50, 93, 10, 45, 107, 101, 101, 112, 91, 48, 44,
  45, 49, 44, 45, 50, 93, 10, 45, 105, 97, 105, 110, 95, 109, 101, 100,
  105, 97, 110, 95, 51, 95, 115, 116, 97, 99, 107, 91, 48, 44, 49, 44,
  50, 93, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 99, 114, 101,
  97, 116, 101, 98, 102, 58, 10, 40, 48, 46, 53, 44, 48, 44, 48, 59,
  48, 46, 53, 44, 48, 44, 48, 59, 48, 44, 48, 44, 48, 41, 10, 40,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 59, 48, 44, 48, 44, 48, 59,
  48, 44, 48, 44, 48, 41, 10, 45, 45, 99, 111, 110, 118, 111, 108, 118,
  101, 91, 48, 93, 32, 91, 49, 93, 10, 45, 45, 99, 111, 110, 118, 111,
  108, 118, 101, 91, 48, 93, 32, 91, 50, 93, 10, 45, 107, 101, 101, 112,
  91, 48, 44, 45, 49, 44, 45, 50, 93, 10, 45, 105, 97, 105, 110, 95,
  109, 101, 100, 105, 97, 110, 95, 51, 95, 115, 116, 97, 99, 107, 91, 48,
  44, 49, 44, 50, 93, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10,
  99, 114, 101, 97, 116, 101, 98, 103, 58, 10, 40, 48, 44, 48, 46, 53,
  44, 48, 59, 48, 44, 48, 44, 48, 46, 53, 59, 48, 44, 48, 44, 48,
  41, 10, 40, 48, 44, 48, 46, 53, 44, 48, 59, 48, 44, 48, 44, 48,
  59, 48, 44, 48, 44, 48, 46, 53, 41, 10, 45, 45, 99, 111, 110, 118,
  111, 108, 118, 101, 91, 48, 93, 32, 91, 49, 93, 10, 45, 45, 99, 111,
  110, 118, 111, 108, 118, 101, 91, 48, 93, 32, 91, 50, 93, 10, 45, 107,
  101, 101, 112, 91, 48, 44, 45, 49, 44, 45, 50, 93, 10, 45, 105, 97,
  105, 110, 95, 109, 101, 100, 105, 97, 110, 95, 51, 95, 115, 116, 97, 99,
  107, 91, 48, 44, 49, 44, 50, 93, 10, 45, 107, 101, 101, 112, 91, 45,
  49, 93, 10, 99, 114, 101, 97, 116, 101, 98, 104, 58, 10, 40, 48, 44,
  48, 46, 53, 44, 48, 59, 48, 44, 48, 44, 48, 59, 48, 44, 48, 46,
  53, 44, 48, 41, 10, 40, 48, 44, 48, 46, 53, 44, 48, 59, 48, 44,
  48, 44, 48, 59, 48, 46, 53, 44, 48, 44, 48, 41, 10, 45, 45, 99,
  111, 110, 118, 111, 108, 118, 101, 91, 48, 93, 32, 91, 49, 93, 10, 45,
  45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 48, 93, 32, 91, 50, 93,
  10, 45, 107, 101, 101, 112, 91, 48, 44, 45, 49, 44, 45, 50, 93, 10,
  45, 105, 97, 105, 110, 95, 109, 101, 100, 105, 97, 110, 95, 51, 95, 115,
  116, 97, 99, 107, 91, 48, 44, 49, 44, 50, 93, 10, 45, 107, 101, 101,
  112, 91, 45, 49, 93, 10, 99, 114, 101, 97, 116, 101, 98, 105, 58, 10,
  40, 48, 44, 48, 46, 53, 44, 48, 59, 48, 46, 53, 44, 48, 44, 48,
  59, 48, 44, 48, 44, 48, 41, 10, 40, 48, 44, 48, 44, 48, 46, 53,
  59, 48, 44, 48, 44, 48, 46, 53, 59, 48, 44, 48, 44, 48, 41, 10,
  45, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 48, 93, 32, 91, 49,
  93, 10, 45, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 48, 93, 32,
  91, 50, 93, 10, 45, 107, 101, 101, 112, 91, 48, 44, 45, 49, 44, 45,
  50, 93, 10, 45, 105, 97, 105, 110, 95, 109, 101, 100, 105, 97, 110, 95,
  51, 95, 115, 116, 97, 99, 107, 91, 48, 44, 49, 44, 50, 93, 10, 45,
  107, 101, 101, 112, 91, 45, 49, 93, 10, 99, 114, 101, 97, 116, 101, 98,
  106, 58, 10, 40, 48, 44, 48, 44, 48, 46, 53, 59, 48, 44, 48, 44,
  48, 59, 48, 44, 48, 44, 48, 46, 53, 41, 10, 40, 48, 44, 48, 44,
  48, 46, 53, 59, 48, 44, 48, 44, 48, 59, 48, 44, 48, 46, 53, 44,
  48, 41, 10, 45, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 48, 93,
  32, 91, 49, 93, 10, 45, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91,
  48, 93, 32, 91, 50, 93, 10, 45, 107, 101, 101, 112, 91, 48, 44, 45,
  49, 44, 45, 50, 93, 10, 45, 105, 97, 105, 110, 95, 109, 101, 100, 105,
  97, 110, 95, 51, 95, 115, 116, 97, 99, 107, 91, 48, 44, 49, 44, 50,
  93, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 99, 114, 101, 97,
  116, 101, 98, 107, 58, 10, 40, 48, 44, 48, 44, 48, 46, 53, 59, 48,
  44, 48, 44, 48, 59, 48, 46, 53, 44, 48, 44, 48, 41, 10, 40, 48,
  44, 48, 44, 48, 46, 53, 59, 48, 46, 53, 44, 48, 44, 48, 59, 48,
  44, 48, 44, 48, 41, 10, 45, 45, 99, 111, 110, 118, 111, 108, 118, 101,
  91, 48, 93, 32, 91, 49, 93, 10, 45, 45, 99, 111, 110, 118, 111, 108,
  118, 101, 91, 48, 93, 32, 91, 50, 93, 10, 45, 107, 101, 101, 112, 91,
  48, 44, 45, 49, 44, 45, 50, 93, 10, 45, 105, 97, 105, 110, 95, 109,
  101, 100, 105, 97, 110, 95, 51, 95, 115, 116, 97, 99, 107, 91, 48, 44,
  49, 44, 50, 93, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 99,
  114, 101, 97, 116, 101, 98, 108, 58, 10, 40, 48, 44, 48, 44, 48, 59,
  48, 44, 48, 44, 48, 46, 53, 59, 48, 44, 48, 44, 48, 46, 53, 41,
  10, 40, 48, 44, 48, 44, 48, 59, 48, 44, 48, 44, 48, 46, 53, 59,
  48, 44, 48, 46, 53, 44, 48, 41, 10, 45, 45, 99, 111, 110, 118, 111,
  108, 118, 101, 91, 48, 93, 32, 91, 49, 93, 10, 45, 45, 99, 111, 110,
  118, 111, 108, 118, 101, 91, 48, 93, 32, 91, 50, 93, 10, 45, 107, 101,
  101, 112, 91, 48, 44, 45, 49, 44, 45, 50, 93, 10, 45, 105, 97, 105,
  110, 95, 109, 101, 100, 105, 97, 110, 95, 51, 95, 115, 116, 97, 99, 107,
  91, 48, 44, 49, 44, 50, 93, 10, 45, 107, 101, 101, 112, 91, 45, 49,
  93, 10, 99, 114, 101, 97, 116, 101, 98, 109, 58, 10, 40, 48, 44, 48,
  44, 48, 59, 48, 44, 48, 44, 48, 46, 53, 59, 48, 46, 53, 44, 48,
  44, 48, 41, 10, 40, 48, 44, 48, 44, 48, 59, 48, 46, 53, 44, 48,
  44, 48, 46, 53, 59, 48, 44, 48, 44, 48, 41, 10, 45, 45, 99, 111,
  110, 118, 111, 108, 118, 101, 91, 48, 93, 32, 91, 49, 93, 10, 45, 45,
  99, 111, 110, 118, 111, 108, 118, 101, 91, 48, 93, 32, 91, 50, 93, 10,
  45, 107, 101, 101, 112, 91, 48, 44, 45, 49, 44, 45, 50, 93, 10, 45,
  105, 97, 105, 110, 95, 109, 101, 100, 105, 97, 110, 95, 51, 95, 115, 116,
  97, 99, 107, 91, 48, 44, 49, 44, 50, 93, 10, 45, 107, 101, 101, 112,
  91, 45, 49, 93, 10, 99, 114, 101, 97, 116, 101, 98, 110, 58, 10, 40,
  48, 44, 48, 44, 48, 59, 48, 44, 48, 44, 48, 59, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 41, 10, 40, 48, 44, 48, 44, 48, 59, 48, 44,
  48, 44, 48, 59, 48, 46, 53, 44, 48, 44, 48, 46, 53, 41, 10, 45,
  45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 48, 93, 32, 91, 49, 93,
  10, 45, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 48, 93, 32, 91,
  50, 93, 10, 45, 107, 101, 101, 112, 91, 48, 44, 45, 49, 44, 45, 50,
  93, 10, 45, 105, 97, 105, 110, 95, 109, 101, 100, 105, 97, 110, 95, 51,
  95, 115, 116, 97, 99, 107, 91, 48, 44, 49, 44, 50, 93, 10, 45, 107,
  101, 101, 112, 91, 45, 49, 93, 10, 99, 114, 101, 97, 116, 101, 98, 111,
  58, 10, 40, 48, 44, 48, 44, 48, 59, 48, 46, 53, 44, 48, 44, 48,
  59, 48, 44, 48, 44, 48, 46, 53, 41, 10, 40, 48, 44, 48, 44, 48,
  59, 48, 44, 48, 44, 48, 59, 48, 46, 53, 44, 48, 46, 53, 44, 48,
  41, 10, 45, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 48, 93, 32,
  91, 49, 93, 10, 45, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 48,
  93, 32, 91, 50, 93, 10, 45, 107, 101, 101, 112, 91, 48, 44, 45, 49,
  44, 45, 50, 93, 10, 45, 105, 97, 105, 110, 95, 109, 101, 100, 105, 97,
  110, 95, 51, 95, 115, 116, 97, 99, 107, 91, 48, 44, 49, 44, 50, 93,
  10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 99, 114, 101, 97, 116,
  101, 98, 112, 58, 10, 40, 48, 44, 48, 44, 48, 59, 48, 46, 53, 44,
  48, 44, 48, 59, 48, 44, 48, 46, 53, 44, 48, 41, 10, 40, 48, 44,
  48, 44, 48, 59, 48, 46, 53, 44, 48, 44, 48, 59, 48, 46, 53, 44,
  48, 44, 48, 41, 10, 45, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91,
  48, 93, 32, 91, 49, 93, 10, 45, 45, 99, 111, 110, 118, 111, 108, 118,
  101, 91, 48, 93, 32, 91, 50, 93, 10, 45, 107, 101, 101, 112, 91, 48,
  44, 45, 49, 44, 45, 50, 93, 10, 45, 105, 97, 105, 110, 95, 109, 101,
  100, 105, 97, 110, 95, 51, 95, 115, 116, 97, 99, 107, 91, 48, 44, 49,
  44, 50, 93, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 99, 114,
  101, 97, 116, 101, 98, 113, 58, 10, 45, 45, 99, 114, 101, 97, 116, 101,
  98, 99, 91, 48, 93, 10, 45, 45, 99, 114, 101, 97, 116, 101, 98, 100,
  91, 48, 93, 10, 45, 105, 97, 105, 110, 95, 109, 101, 100, 105, 97, 110,
  95, 51, 95, 115, 116, 97, 99, 107, 91, 48, 44, 49, 44, 50, 93, 10,
  45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 99, 114, 101, 97, 116, 101,
  98, 114, 58, 10, 45, 45, 99, 114, 101, 97, 116, 101, 98, 101, 91, 48,
  93, 10, 45, 45, 99, 114, 101, 97, 116, 101, 98, 102, 91, 48, 93, 10,
  45, 105, 97, 105, 110, 95, 109, 101, 100, 105, 97, 110, 95, 51, 95, 115,
  116, 97, 99, 107, 91, 48, 44, 49, 44, 50, 93, 10, 45, 107, 101, 101,
  112, 91, 45, 49, 93, 10, 99, 114, 101, 97, 116, 101, 98, 115, 58, 10,
  45, 45, 99, 114, 101, 97, 116, 101, 98, 103, 91, 48, 93, 10, 45, 45,
  99, 114, 101, 97, 116, 101, 98, 104, 91, 48, 93, 10, 45, 105, 97, 105,
  110, 95, 109, 101, 100, 105, 97, 110, 95, 51, 95, 115, 116, 97, 99, 107,
  91, 48, 44, 49, 44, 50, 93, 10, 45, 107, 101, 101, 112, 91, 45, 49,
  93, 10, 99, 114, 101, 97, 116, 101, 98, 116, 58, 10, 45, 45, 99, 114,
  101, 97, 116, 101, 98, 105, 91, 48, 93, 10, 45, 45, 99, 114, 101, 97,
  116, 101, 98, 106, 91, 48, 93, 10, 45, 105, 97, 105, 110, 95, 109, 101,
  100, 105, 97, 110, 95, 51, 95, 115, 116, 97, 99, 107, 91, 48, 44, 49,
  44, 50, 93, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 99, 114,
  101, 97, 116, 101, 98, 117, 58, 10, 45, 45, 99, 114, 101, 97, 116, 101,
  98, 107, 91, 48, 93, 10, 45, 45, 99, 114, 101, 97, 116, 101, 98, 108,
  91, 48, 93, 10, 45, 105, 97, 105, 110, 95, 109, 101, 100, 105, 97, 110,
  95, 51, 95, 115, 116, 97, 99, 107, 91, 48, 44, 49, 44, 50, 93, 10,
  45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 99, 114, 101, 97, 116, 101,
  98, 118, 58, 10, 45, 45, 99, 114, 101, 97, 116, 101, 98, 109, 91, 48,
  93, 10, 45, 45, 99, 114, 101, 97, 116, 101, 98, 110, 91, 48, 93, 10,
  45, 105, 97, 105, 110, 95, 109, 101, 100, 105, 97, 110, 95, 51, 95, 115,
  116, 97, 99, 107, 91, 48, 44, 49, 44, 50, 93, 10, 45, 107, 101, 101,
  112, 91, 45, 49, 93, 10, 99, 114, 101, 97, 116, 101, 98, 119, 58, 10,
  45, 45, 99, 114, 101, 97, 116, 101, 98, 111, 91, 48, 93, 10, 45, 45,
  99, 114, 101, 97, 116, 101, 98, 112, 91, 48, 93, 10, 45, 105, 97, 105,
  110, 95, 109, 101, 100, 105, 97, 110, 95, 51, 95, 115, 116, 97, 99, 107,
  91, 48, 44, 49, 44, 50, 93, 10, 45, 107, 101, 101, 112, 91, 45, 49,
  93, 10, 99, 114, 101, 97, 116, 101, 98, 120, 58, 10, 45, 45, 99, 114,
  101, 97, 116, 101, 98, 113, 91, 48, 93, 10, 45, 45, 99, 114, 101, 97,
  116, 101, 98, 114, 91, 48, 93, 10, 45, 105, 97, 105, 110, 95, 109, 101,
  100, 105, 97, 110, 95, 51, 95, 115, 116, 97, 99, 107, 91, 48, 44, 49,
  44, 50, 93, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 99, 114,
  101, 97, 116, 101, 98, 121, 58, 10, 45, 45, 99, 114, 101, 97, 116, 101,
  98, 115, 91, 48, 93, 10, 45, 45, 99, 114, 101, 97, 116, 101, 98, 116,
  91, 48, 93, 10, 45, 105, 97, 105, 110, 95, 109, 101, 100, 105, 97, 110,
  95, 51, 95, 115, 116, 97, 99, 107, 91, 48, 44, 49, 44, 50, 93, 10,
  45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 99, 114, 101, 97, 116, 101,
  98, 122, 58, 10, 45, 45, 99, 114, 101, 97, 116, 101, 98, 117, 91, 48,
  93, 10, 45, 45, 99, 114, 101, 97, 116, 101, 98, 118, 91, 48, 93, 10,
  45, 105, 97, 105, 110, 95, 109, 101, 100, 105, 97, 110, 95, 51, 95, 115,
  116, 97, 99, 107, 91, 48, 44, 49, 44, 50, 93, 10, 45, 107, 101, 101,
  112, 91, 45, 49, 93, 10, 99, 114, 101, 97, 116, 101, 99, 97, 58, 10,
  45, 45, 99, 114, 101, 97, 116, 101, 98, 120, 91, 48, 93, 10, 45, 45,
  99, 114, 101, 97, 116, 101, 98, 121, 91, 48, 93, 10, 45, 105, 97, 105,
  110, 95, 109, 101, 100, 105, 97, 110, 95, 51, 95, 115, 116, 97, 99, 107,
  91, 48, 44, 49, 44, 50, 93, 10, 45, 107, 101, 101, 112, 91, 45, 49,
  93, 10, 99, 114, 101, 97, 116, 101, 99, 98, 58, 10, 45, 45, 99, 114,
  101, 97, 116, 101, 98, 122, 91, 48, 93, 10, 45, 45, 99, 114, 101, 97,
  116, 101, 98, 119, 91, 48, 93, 10, 45, 105, 97, 105, 110, 95, 109, 101,
  100, 105, 97, 110, 95, 51, 95, 115, 116, 97, 99, 107, 91, 48, 44, 49,
  44, 50, 93, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 109, 101,
  103, 97, 99, 108, 101, 97, 110, 58, 10, 45, 45, 99, 114, 101, 97, 116,
  101, 99, 97, 91, 48, 93, 10, 45, 45, 99, 114, 101, 97, 116, 101, 99,
  98, 91, 48, 93, 10, 45, 105, 97, 105, 110, 95, 109, 101, 100, 105, 97,
  110, 95, 51, 95, 115, 116, 97, 99, 107, 91, 48, 44, 49, 44, 50, 93,
  10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 99, 114, 111, 115, 115,
  58, 10, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93, 32, 48, 44, 49,
  44, 48, 44, 48, 44, 50, 10, 45, 45, 115, 104, 105, 102, 116, 91, 48,
  93, 32, 48, 44, 45, 49, 44, 48, 44, 48, 44, 50, 10, 45, 45, 115,
  104, 105, 102, 116, 91, 48, 93, 32, 49, 44, 48, 44, 48, 44, 48, 44,
  50, 10, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93, 32, 45, 49, 44,
  48, 44, 48, 44, 48, 44, 50, 10, 45, 105, 97, 105, 110, 95, 109, 101,
  100, 105, 97, 110, 95, 53, 95, 115, 116, 97, 99, 107, 10, 101, 120, 58,
  10, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93, 32, 49, 44, 49, 44,
  48, 44, 48, 44, 50, 10, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93,
  32, 49, 44, 45, 49, 44, 48, 44, 48, 44, 50, 10, 45, 45, 115, 104,
  105, 102, 116, 91, 48, 93, 32, 45, 49, 44, 45, 49, 44, 48, 44, 48,
  44, 50, 10, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93, 32, 45, 49,
  44, 49, 44, 48, 44, 48, 44, 50, 10, 45, 105, 97, 105, 110, 95, 109,
  101, 100, 105, 97, 110, 95, 53, 95, 115, 116, 97, 99, 107, 10, 104, 121,
  98, 114, 105, 100, 95, 109, 101, 100, 105, 97, 110, 58, 10, 45, 97, 112,
  112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 36, 49, 10, 45, 45, 99, 114, 111, 115,
  115, 91, 48, 93, 10, 45, 45, 101, 120, 91, 48, 93, 10, 45, 105, 97,
  105, 110, 95, 109, 101, 100, 105, 97, 110, 95, 51, 95, 115, 116, 97, 99,
  107, 91, 48, 44, 49, 44, 50, 93, 10, 45, 100, 111, 110, 101, 10, 34,
  44, 36, 50, 10, 105, 97, 105, 110, 95, 104, 121, 98, 114, 105, 100, 95,
  109, 101, 100, 105, 97, 110, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  36, 49, 10, 45, 45, 99, 114, 111, 115, 115, 91, 48, 93, 10, 45, 45,
  101, 120, 91, 48, 93, 10, 45, 105, 97, 105, 110, 95, 109, 101, 100, 105,
  97, 110, 95, 51, 95, 115, 116, 97, 99, 107, 91, 48, 44, 49, 44, 50,
  93, 10, 45, 100, 111, 110, 101, 10, 105, 97, 105, 110, 95, 112, 105, 120,
  101, 108, 95, 100, 101, 110, 111, 105, 115, 101, 58, 10, 45, 105, 102, 32,
  123, 36, 49, 61, 61, 48, 125, 10, 45, 97, 112, 112, 108, 121, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 34, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 36, 50, 10, 45, 109, 101, 103, 97, 99, 108, 101, 97, 110, 10,
  45, 100, 111, 110, 101, 10, 34, 44, 36, 51, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 61, 61, 49, 125, 10, 45, 104, 121, 98, 114, 105, 100,
  95, 109, 101, 100, 105, 97, 110, 91, 48, 93, 32, 36, 50, 44, 36, 51,
  10, 45, 101, 110, 100, 105, 102, 10, 105, 97, 105, 110, 95, 112, 105, 120,
  101, 108, 95, 100, 101, 110, 111, 105, 115, 101, 95, 112, 58, 10, 45, 105,
  102, 32, 36, 53, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 125,
  10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 50, 10, 45, 97,
  112, 112, 108, 121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118,
  101, 114, 108, 97, 112, 32, 92, 34, 45, 109, 101, 103, 97, 99, 108, 101,
  97, 110, 32, 92, 34, 44, 52, 44, 48, 10, 45, 100, 111, 110, 101, 10,
  34, 44, 36, 51, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61,
  49, 125, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101,
  108, 115, 32, 34, 10, 45, 97, 112, 112, 108, 121, 95, 112, 97, 114, 97,
  108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 32, 92, 34, 45,
  105, 97, 105, 110, 95, 104, 121, 98, 114, 105, 100, 95, 109, 101, 100, 105,
  97, 110, 91, 48, 93, 32, 36, 50, 92, 34, 44, 52, 44, 48, 10, 34,
  44, 36, 51, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101,
  10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 125, 10, 45, 97, 112,
  112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 36, 50, 10, 45, 109, 101, 103, 97, 99,
  108, 101, 97, 110, 10, 45, 100, 111, 110, 101, 10, 34, 44, 36, 51, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 10, 45, 97,
  112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 10,
  45, 105, 97, 105, 110, 95, 104, 121, 98, 114, 105, 100, 95, 109, 101, 100,
  105, 97, 110, 95, 112, 91, 48, 93, 32, 36, 50, 10, 34, 44, 36, 51,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 105,
  97, 105, 110, 95, 112, 105, 120, 101, 108, 95, 100, 101, 110, 111, 105, 115,
  101, 95, 112, 95, 112, 114, 101, 118, 105, 101, 119, 58, 10, 45, 105, 102,
  32, 123, 36, 52, 61, 61, 48, 125, 10, 45, 105, 97, 105, 110, 95, 112,
  105, 120, 101, 108, 95, 100, 101, 110, 111, 105, 115, 101, 95, 112, 32, 36,
  123, 49, 45, 45, 49, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 52, 61, 61, 49, 125, 10, 45, 45, 105, 97, 105, 110,
  95, 112, 105, 120, 101, 108, 95, 100, 101, 110, 111, 105, 115, 101, 95, 112,
  32, 36, 123, 49, 45, 45, 49, 125, 10, 45, 115, 117, 98, 91, 48, 93,
  32, 91, 49, 93, 10, 45, 107, 101, 101, 112, 91, 48, 93, 10, 45, 110,
  32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 35, 64,
  103, 105, 109, 112, 32, 82, 101, 99, 117, 114, 115, 105, 118, 101, 32, 109,
  101, 100, 105, 97, 110, 32, 58, 32, 105, 97, 105, 110, 95, 114, 101, 99,
  117, 114, 115, 105, 118, 101, 95, 109, 101, 100, 105, 97, 110, 95, 112, 44,
  32, 105, 97, 105, 110, 95, 114, 101, 99, 117, 114, 115, 105, 118, 101, 95,
  109, 101, 100, 105, 97, 110, 95, 112, 95, 112, 114, 101, 118, 105, 101, 119,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 101, 100,
  105, 97, 110, 32, 114, 97, 100, 105, 117, 115, 32, 61, 32, 105, 110, 116,
  40, 51, 44, 49, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 82, 101, 112, 101, 97, 116, 115, 32, 61, 32, 105, 110, 116, 40,
  49, 44, 49, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65,
  34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117,
  101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34,
  44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34,
  83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108,
  117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 65, 108, 112, 104, 97,
  34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115,
  34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82,
  101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117,
  101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 115, 104, 111, 119, 115, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 79, 117, 116, 112, 117, 116, 34, 44,
  34, 68, 105, 102, 102, 101, 114, 101, 110, 99, 101, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 80, 97, 114, 97, 108, 108, 101, 108, 32, 112, 114, 111, 99, 101,
  115, 115, 105, 110, 103, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49,
  44, 34, 79, 102, 102, 34, 44, 34, 65, 117, 116, 111, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32,
  60, 105, 62, 73, 97, 105, 110, 32, 70, 101, 114, 103, 117, 115, 115, 111,
  110, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 85, 112,
  100, 97, 116, 101, 32, 45, 32, 50, 53, 32, 79, 99, 116, 111, 98, 101,
  114, 32, 50, 48, 49, 51, 32, 45, 32, 80, 97, 114, 97, 108, 108, 101,
  108, 32, 80, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 119, 97, 115,
  32, 110, 111, 116, 32, 119, 111, 114, 107, 105, 110, 103, 32, 112, 114, 111,
  112, 101, 114, 108, 121, 44, 32, 102, 105, 120, 101, 100, 32, 110, 111, 119,
  46, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 85,
  112, 100, 97, 116, 101, 32, 45, 32, 50, 48, 32, 79, 99, 116, 111, 98,
  101, 114, 32, 50, 48, 49, 51, 32, 45, 32, 80, 97, 114, 97, 108, 108,
  101, 108, 32, 80, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 97, 110,
  100, 32, 67, 111, 110, 116, 114, 111, 108, 32, 76, 97, 121, 111, 117, 116,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 105, 97, 105, 110, 95,
  114, 101, 99, 117, 114, 115, 105, 118, 101, 95, 109, 101, 100, 105, 97, 110,
  95, 112, 58, 10, 45, 105, 102, 32, 36, 53, 10, 45, 97, 112, 112, 108,
  121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 10, 45, 97, 112,
  112, 108, 121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101,
  114, 108, 97, 112, 32, 92, 34, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  36, 50, 32, 45, 109, 101, 100, 105, 97, 110, 32, 36, 49, 32, 45, 100,
  111, 110, 101, 10, 92, 34, 44, 123, 36, 49, 42, 50, 125, 44, 48, 10,
  34, 44, 36, 51, 44, 48, 10, 45, 101, 108, 115, 101, 10, 45, 97, 112,
  112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 36, 50, 32, 45, 109, 101, 100, 105, 97,
  110, 32, 36, 49, 32, 45, 100, 111, 110, 101, 10, 34, 44, 36, 51, 44,
  48, 10, 45, 101, 110, 100, 105, 102, 10, 114, 101, 99, 117, 114, 115, 105,
  118, 101, 95, 109, 101, 100, 105, 97, 110, 58, 10, 45, 97, 112, 112, 108,
  121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 114, 101, 112,
  101, 97, 116, 32, 36, 51, 32, 45, 109, 101, 100, 105, 97, 110, 32, 36,
  49, 32, 45, 100, 111, 110, 101, 34, 44, 36, 50, 44, 48, 10, 105, 97,
  105, 110, 95, 114, 101, 99, 117, 114, 115, 105, 118, 101, 95, 109, 101, 100,
  105, 97, 110, 95, 112, 95, 112, 114, 101, 118, 105, 101, 119, 58, 10, 45,
  105, 102, 32, 123, 36, 45, 50, 61, 61, 48, 125, 10, 45, 105, 97, 105,
  110, 95, 114, 101, 99, 117, 114, 115, 105, 118, 101, 95, 109, 101, 100, 105,
  97, 110, 95, 112, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52,
  44, 36, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 45, 50, 61, 61, 49, 125, 10, 45, 114, 101, 109, 111, 118, 101, 95,
  111, 112, 97, 99, 105, 116, 121, 10, 45, 45, 105, 97, 105, 110, 95, 114,
  101, 99, 117, 114, 115, 105, 118, 101, 95, 109, 101, 100, 105, 97, 110, 95,
  112, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53,
  10, 45, 115, 117, 98, 91, 48, 93, 32, 91, 49, 93, 10, 45, 107, 101,
  101, 112, 91, 48, 93, 10, 45, 109, 117, 108, 32, 50, 10, 45, 97, 100,
  100, 32, 49, 50, 56, 10, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103,
  105, 109, 112, 32, 82, 101, 100, 45, 101, 121, 101, 32, 97, 116, 116, 101,
  110, 117, 97, 116, 105, 111, 110, 32, 58, 32, 114, 101, 100, 95, 101, 121,
  101, 44, 32, 114, 101, 100, 95, 101, 121, 101, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 55, 53, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 46, 53, 44,
  48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70,
  97, 99, 116, 111, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60,
  105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101,
  114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 82, 101, 109, 111, 118, 101, 32, 104, 111, 116,
  32, 112, 105, 120, 101, 108, 115, 32, 58, 32, 103, 105, 109, 112, 95, 114,
  101, 109, 111, 118, 101, 95, 104, 111, 116, 112, 105, 120, 101, 108, 115, 44,
  32, 103, 105, 109, 112, 95, 114, 101, 109, 111, 118, 101, 95, 104, 111, 116,
  112, 105, 120, 101, 108, 115, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 97, 115, 107, 32,
  115, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 51, 44, 51, 44, 50,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101,
  115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48,
  44, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105,
  99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 74, 38, 35, 50, 51,
  51, 59, 114, 111, 109, 101, 32, 66, 111, 117, 108, 97, 110, 103, 101, 114,
  60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49,
  48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 114, 101, 109, 111,
  118, 101, 95, 104, 111, 116, 112, 105, 120, 101, 108, 115, 32, 58, 10, 45,
  114, 101, 109, 111, 118, 101, 95, 104, 111, 116, 112, 105, 120, 101, 108, 115,
  32, 36, 49, 44, 36, 50, 10, 103, 105, 109, 112, 95, 114, 101, 109, 111,
  118, 101, 95, 104, 111, 116, 112, 105, 120, 101, 108, 115, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109,
  112, 95, 114, 101, 109, 111, 118, 101, 95, 104, 111, 116, 112, 105, 120, 101,
  108, 115, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 82, 101, 112, 97, 105, 114, 32, 115, 99, 97, 110, 110, 101, 100,
  32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 58, 32, 106, 101, 106, 101,
  95, 115, 99, 97, 110, 100, 111, 99, 44, 32, 106, 101, 106, 101, 95, 115,
  99, 97, 110, 100, 111, 99, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 85, 115, 101, 32, 102, 105, 108, 116, 101,
  114, 32, 105, 115, 32, 117, 115, 101, 102, 117, 108, 32, 116, 111, 32, 112,
  111, 115, 116, 32, 112, 114, 111, 99, 101, 115, 115, 32, 100, 111, 99, 117,
  109, 101, 110, 116, 32, 121, 111, 117, 32, 115, 99, 97, 110, 32, 119, 105,
  116, 104, 32, 97, 32, 100, 105, 103, 105, 116, 97, 108, 32, 99, 97, 109,
  101, 114, 97, 46, 32, 73, 116, 32, 112, 101, 102, 111, 114, 109, 115, 32,
  115, 109, 111, 111, 116, 104, 105, 110, 103, 44, 32, 98, 97, 99, 107, 103,
  114, 111, 117, 110, 100, 32, 99, 111, 114, 114, 101, 99, 116, 105, 111, 110,
  32, 97, 110, 100, 32, 119, 104, 105, 116, 101, 32, 98, 97, 108, 97, 110,
  99, 101, 32, 97, 100, 106, 117, 115, 116, 101, 109, 101, 110, 116, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 105, 110, 116, 40, 51, 44, 49, 44, 55, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 97, 99, 107, 103, 114,
  111, 117, 110, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 49,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  87, 104, 105, 116, 101, 32, 108, 101, 118, 101, 108, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 57, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 66, 108, 97, 99, 107, 32, 108, 101, 118,
  101, 108, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 74, 38, 35, 50,
  51, 51, 59, 114, 38, 35, 50, 52, 52, 59, 109, 101, 32, 66, 111, 117,
  108, 97, 110, 103, 101, 114, 60, 47, 105, 62, 46, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 51, 47, 49, 49, 47, 48, 51, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 106, 101, 106, 101, 95, 115, 99, 97,
  110, 100, 111, 99, 32, 58, 10, 45, 115, 99, 97, 110, 100, 111, 99, 32,
  36, 49, 44, 36, 50, 37, 44, 36, 51, 37, 44, 36, 52, 37, 10, 106,
  101, 106, 101, 95, 115, 99, 97, 110, 100, 111, 99, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 106, 101, 106, 101,
  95, 115, 99, 97, 110, 100, 111, 99, 32, 36, 49, 44, 36, 50, 44, 36,
  51, 44, 36, 52, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112,
  32, 83, 109, 111, 111, 116, 104, 32, 91, 97, 110, 105, 115, 111, 116, 114,
  111, 112, 105, 99, 93, 32, 58, 32, 103, 105, 109, 112, 95, 97, 110, 105,
  115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105,
  110, 103, 44, 32, 103, 105, 109, 112, 95, 97, 110, 105, 115, 111, 116, 114,
  111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 95, 112,
  114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 54, 48, 44, 48, 44, 49, 48, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 114, 112, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 44, 48,
  44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 105,
  115, 111, 116, 114, 111, 112, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 51, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 71, 114, 97, 100, 105, 101, 110, 116, 32, 115, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  54, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 84, 101, 110, 115, 111, 114, 32, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 49, 44, 48,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112,
  97, 116, 105, 97, 108, 32, 112, 114, 101, 99, 105, 115, 105, 111, 110, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 56, 44, 48, 46, 49, 44,
  50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 117,
  108, 97, 114, 32, 112, 114, 101, 99, 105, 115, 105, 111, 110, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 51, 48, 44, 49, 44, 49, 56, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108, 117, 101, 32, 112,
  114, 101, 99, 105, 115, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 44, 48, 46, 49, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 78, 101, 97,
  114, 101, 115, 116, 32, 110, 101, 105, 103, 104, 98, 111, 114, 34, 44, 34,
  76, 105, 110, 101, 97, 114, 34, 44, 34, 82, 117, 110, 103, 101, 45, 75,
  117, 116, 116, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  70, 97, 115, 116, 32, 97, 112, 112, 114, 111, 120, 105, 109, 97, 116, 105,
  111, 110, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115,
  32, 61, 32, 105, 110, 116, 40, 49, 44, 49, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40,
  115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108,
  34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34,
  76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101,
  47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101,
  115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111,
  110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34,
  44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34,
  66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 80, 97, 114, 97, 108, 108, 101, 108, 32, 112, 114, 111, 99,
  101, 115, 115, 105, 110, 103, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 65, 117, 116, 111, 34, 44, 34, 79, 110, 101, 32, 116, 104, 114, 101,
  97, 100, 34, 44, 34, 84, 119, 111, 32, 116, 104, 114, 101, 97, 100, 115,
  34, 44, 34, 70, 111, 117, 114, 32, 116, 104, 114, 101, 97, 100, 115, 34,
  44, 34, 69, 105, 103, 104, 116, 32, 116, 104, 114, 101, 97, 100, 115, 34,
  44, 34, 83, 105, 120, 116, 101, 101, 110, 32, 116, 104, 114, 101, 97, 100,
  115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 97,
  116, 105, 97, 108, 32, 111, 118, 101, 114, 108, 97, 112, 32, 61, 32, 105,
  110, 116, 40, 50, 52, 44, 48, 44, 50, 53, 54, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97,
  116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 51, 47, 48, 56, 47, 50, 55, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 97, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109,
  111, 111, 116, 104, 105, 110, 103, 32, 58, 32, 45, 115, 107, 105, 112, 32,
  36, 123, 49, 51, 61, 49, 125, 44, 36, 123, 49, 52, 61, 48, 125, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 34, 45, 103, 105, 109, 112, 95, 112, 97, 114, 97, 108, 108, 101,
  108, 95, 111, 118, 101, 114, 108, 97, 112, 32, 92, 34, 45, 114, 101, 112,
  101, 97, 116, 32, 36, 49, 49, 32, 45, 115, 109, 111, 111, 116, 104, 32,
  36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36,
  54, 44, 36, 55, 44, 36, 56, 44, 36, 57, 44, 36, 49, 48, 32, 45,
  100, 111, 110, 101, 92, 34, 44, 36, 49, 51, 44, 36, 49, 52, 34, 44,
  36, 49, 50, 44, 48, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10, 103, 105, 109, 112, 95,
  97, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111,
  116, 104, 105, 110, 103, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 97, 110, 105, 115, 111,
  116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32,
  83, 109, 111, 111, 116, 104, 32, 91, 98, 105, 108, 97, 116, 101, 114, 97,
  108, 93, 32, 58, 32, 103, 105, 109, 112, 95, 98, 105, 108, 97, 116, 101,
  114, 97, 108, 44, 32, 103, 105, 109, 112, 95, 98, 105, 108, 97, 116, 101,
  114, 97, 108, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 97, 116, 105, 97, 108, 32,
  118, 97, 114, 105, 97, 110, 99, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 86, 97, 108, 117, 101, 32, 118, 97, 114, 105, 97, 110,
  99, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 55, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101,
  114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 50, 44,
  49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44,
  34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101,
  34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32,
  99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101,
  100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97,
  116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101,
  34, 44, 34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71,
  114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108,
  112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 114, 97, 108, 108,
  101, 108, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 65, 117, 116, 111, 34, 44, 34, 79,
  110, 101, 32, 116, 104, 114, 101, 97, 100, 34, 44, 34, 84, 119, 111, 32,
  116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 70, 111, 117, 114, 32, 116,
  104, 114, 101, 97, 100, 115, 34, 44, 34, 69, 105, 103, 104, 116, 32, 116,
  104, 114, 101, 97, 100, 115, 34, 44, 34, 83, 105, 120, 116, 101, 101, 110,
  32, 116, 104, 114, 101, 97, 100, 115, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 112, 97, 116, 105, 97, 108, 32, 111, 118, 101, 114,
  108, 97, 112, 32, 61, 32, 105, 110, 116, 40, 50, 52, 44, 48, 44, 50,
  53, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48,
  56, 47, 50, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 98, 105, 108, 97, 116, 101, 114,
  97, 108, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 53, 61, 48,
  125, 44, 36, 123, 54, 61, 48, 125, 10, 45, 97, 112, 112, 108, 121, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 103, 105, 109, 112, 95,
  112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112,
  32, 92, 34, 45, 114, 101, 112, 101, 97, 116, 32, 36, 51, 32, 45, 98,
  105, 108, 97, 116, 101, 114, 97, 108, 32, 36, 49, 44, 36, 50, 32, 45,
  100, 111, 110, 101, 92, 34, 44, 36, 53, 44, 36, 54, 34, 44, 36, 52,
  44, 48, 10, 103, 105, 109, 112, 95, 98, 105, 108, 97, 116, 101, 114, 97,
  108, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 98, 105, 108, 97, 116, 101, 114, 97, 108,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32,
  83, 109, 111, 111, 116, 104, 32, 91, 98, 108, 111, 99, 107, 32, 112, 99,
  97, 93, 32, 58, 32, 106, 101, 106, 101, 95, 100, 101, 110, 111, 105, 115,
  101, 95, 112, 97, 116, 99, 104, 95, 100, 105, 99, 116, 44, 32, 106, 101,
  106, 101, 95, 100, 101, 110, 111, 105, 115, 101, 95, 112, 97, 116, 99, 104,
  95, 100, 105, 99, 116, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 80, 97, 116, 99, 104, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 49, 44, 52, 44, 56, 44, 49, 54, 44, 51,
  50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 121, 99, 108,
  101, 115, 32, 61, 32, 105, 110, 116, 40, 56, 44, 49, 44, 51, 50, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 109, 112, 111, 110,
  101, 110, 116, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 49,
  44, 49, 44, 57, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  111, 101, 102, 102, 105, 99, 105, 101, 110, 116, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 46, 49, 44, 48, 44, 57, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 82, 101, 109, 105, 120, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117,
  108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 60,
  98, 62, 78, 111, 116, 101, 58, 60, 47, 98, 62, 84, 104, 105, 115, 32,
  102, 105, 108, 116, 101, 114, 32, 105, 115, 32, 113, 117, 105, 116, 101, 32,
  116, 105, 109, 101, 32, 99, 111, 110, 115, 117, 109, 105, 110, 103, 46, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 74, 38, 35,
  50, 51, 51, 59, 114, 38, 35, 50, 52, 52, 59, 109, 101, 32, 66, 111,
  117, 108, 97, 110, 103, 101, 114, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 51, 47, 50, 57, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 106, 101,
  106, 101, 95, 100, 101, 110, 111, 105, 115, 101, 95, 112, 97, 116, 99, 104,
  95, 100, 105, 99, 116, 58, 10, 45, 45, 100, 101, 110, 111, 105, 115, 101,
  95, 112, 97, 116, 99, 104, 95, 100, 105, 99, 116, 32, 123, 50, 94, 40,
  36, 49, 43, 50, 41, 125, 44, 36, 50, 44, 36, 51, 44, 36, 52, 10,
  45, 42, 91, 48, 93, 32, 36, 53, 32, 45, 42, 91, 49, 93, 32, 123,
  49, 45, 36, 53, 125, 32, 45, 43, 32, 45, 99, 32, 48, 44, 50, 53,
  53, 10, 106, 101, 106, 101, 95, 100, 101, 110, 111, 105, 115, 101, 95, 112,
  97, 116, 99, 104, 95, 100, 105, 99, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 106, 101, 106, 101, 95, 100, 101,
  110, 111, 105, 115, 101, 95, 112, 97, 116, 99, 104, 95, 100, 105, 99, 116,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32,
  83, 109, 111, 111, 116, 104, 32, 91, 100, 105, 102, 102, 117, 115, 105, 111,
  110, 93, 32, 58, 32, 103, 105, 109, 112, 95, 100, 105, 102, 102, 117, 115,
  105, 111, 110, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 44, 32, 103,
  105, 109, 112, 95, 100, 105, 102, 102, 117, 115, 105, 111, 110, 95, 115, 109,
  111, 111, 116, 104, 105, 110, 103, 95, 112, 114, 101, 118, 105, 101, 119, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 114,
  112, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  55, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  65, 110, 105, 115, 111, 116, 114, 111, 112, 121, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 51, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 71, 114, 97, 100, 105, 101, 110, 116, 32, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 54, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 84, 101, 110, 115, 111, 114, 32, 115, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46,
  49, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 84, 105, 109, 101, 32, 115, 116, 101, 112, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 53, 44, 53, 44, 53, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32,
  61, 32, 105, 110, 116, 40, 56, 44, 49, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40,
  115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108,
  34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34,
  76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101,
  47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101,
  115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111,
  110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34,
  44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34,
  66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 80, 97, 114, 97, 108, 108, 101, 108, 32, 112, 114, 111, 99,
  101, 115, 115, 105, 110, 103, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 65, 117, 116, 111, 34, 44, 34, 79, 110, 101, 32, 116, 104, 114, 101,
  97, 100, 34, 44, 34, 84, 119, 111, 32, 116, 104, 114, 101, 97, 100, 115,
  34, 44, 34, 70, 111, 117, 114, 32, 116, 104, 114, 101, 97, 100, 115, 34,
  44, 34, 69, 105, 103, 104, 116, 32, 116, 104, 114, 101, 97, 100, 115, 34,
  44, 34, 83, 105, 120, 116, 101, 101, 110, 32, 116, 104, 114, 101, 97, 100,
  115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 97,
  116, 105, 97, 108, 32, 111, 118, 101, 114, 108, 97, 112, 32, 61, 32, 105,
  110, 116, 40, 50, 52, 44, 48, 44, 50, 53, 54, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97,
  116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 51, 47, 48, 56, 47, 50, 55, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 100, 105, 102, 102, 117, 115, 105, 111, 110, 95, 115, 109, 111, 111,
  116, 104, 105, 110, 103, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 103, 105, 109, 112, 95, 112,
  97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 32,
  92, 34, 45, 115, 109, 111, 111, 116, 104, 32, 36, 54, 44, 36, 49, 44,
  36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 48, 32, 45, 99,
  32, 48, 44, 50, 53, 53, 92, 34, 44, 36, 56, 44, 36, 57, 34, 44,
  36, 55, 44, 48, 10, 103, 105, 109, 112, 95, 100, 105, 102, 102, 117, 115,
  105, 111, 110, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112,
  108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105,
  109, 112, 95, 100, 105, 102, 102, 117, 115, 105, 111, 110, 95, 115, 109, 111,
  111, 116, 104, 105, 110, 103, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35,
  64, 103, 105, 109, 112, 32, 83, 109, 111, 111, 116, 104, 32, 91, 105, 117,
  119, 116, 93, 32, 58, 32, 106, 101, 106, 101, 95, 100, 101, 110, 111, 105,
  115, 101, 95, 105, 117, 119, 116, 44, 106, 101, 106, 101, 95, 100, 101, 110,
  111, 105, 115, 101, 95, 105, 117, 119, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115,
  104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44, 48,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 117,
  109, 98, 101, 114, 32, 111, 102, 32, 115, 99, 97, 108, 101, 115, 32, 61,
  32, 105, 110, 116, 40, 51, 44, 50, 44, 54, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 87, 97, 118, 101, 108, 101, 116, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 83, 112, 108, 105, 110, 101, 32, 66, 49,
  34, 44, 34, 83, 112, 108, 105, 110, 101, 32, 66, 50, 34, 44, 34, 83,
  112, 108, 105, 110, 101, 32, 66, 51, 34, 44, 34, 83, 112, 108, 105, 110,
  101, 32, 66, 52, 34, 44, 34, 83, 112, 108, 105, 110, 101, 32, 66, 53,
  34, 44, 34, 83, 112, 108, 105, 110, 101, 32, 66, 54, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 78, 111,
  116, 101, 58, 60, 47, 98, 62, 68, 101, 110, 111, 105, 115, 101, 32, 116,
  104, 101, 32, 105, 109, 97, 103, 101, 32, 98, 121, 32, 116, 104, 114, 101,
  115, 104, 111, 108, 100, 105, 110, 103, 32, 116, 104, 101, 32, 99, 111, 101,
  102, 102, 105, 99, 105, 101, 110, 116, 32, 111, 102, 32, 116, 104, 101, 32,
  73, 115, 111, 116, 114, 111, 112, 105, 99, 32, 85, 110, 100, 101, 99, 105,
  109, 97, 116, 101, 100, 32, 87, 97, 118, 101, 108, 101, 116, 32, 84, 114,
  97, 110, 115, 102, 111, 114, 109, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 74,
  38, 35, 50, 51, 51, 59, 114, 38, 35, 50, 52, 52, 59, 109, 101, 32,
  66, 111, 117, 108, 97, 110, 103, 101, 114, 60, 47, 105, 62, 46, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 51, 47, 49, 55, 47, 49, 50, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 106, 101, 106, 101, 95,
  100, 101, 110, 111, 105, 115, 101, 95, 105, 117, 119, 116, 32, 58, 10, 45,
  100, 101, 110, 111, 105, 115, 101, 95, 105, 117, 119, 116, 32, 36, 49, 44,
  36, 50, 44, 123, 36, 51, 43, 49, 125, 10, 106, 101, 106, 101, 95, 100,
  101, 110, 111, 105, 115, 101, 95, 105, 117, 119, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 106, 101, 106, 101, 95,
  100, 101, 110, 111, 105, 115, 101, 95, 105, 117, 119, 116, 32, 36, 49, 44,
  36, 50, 44, 36, 51, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 83, 109, 111, 111, 116, 104, 32, 91, 109, 101, 97, 110, 45, 99,
  117, 114, 118, 97, 116, 117, 114, 101, 93, 32, 58, 32, 103, 105, 109, 112,
  95, 109, 101, 97, 110, 99, 117, 114, 118, 97, 116, 117, 114, 101, 95, 115,
  109, 111, 111, 116, 104, 105, 110, 103, 44, 32, 103, 105, 109, 112, 95, 109,
  101, 97, 110, 99, 117, 114, 118, 97, 116, 117, 114, 101, 95, 115, 109, 111,
  111, 116, 104, 105, 110, 103, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 105, 109, 101, 32,
  115, 116, 101, 112, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 48, 44,
  53, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73,
  116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40,
  52, 44, 49, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 75, 101, 101, 112, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115,
  32, 97, 115, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32, 108, 97,
  121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108, 115,
  101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110,
  110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71,
  66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114,
  111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103,
  104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114,
  97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34,
  75, 101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101,
  110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 80, 97, 114, 97, 108, 108, 101, 108, 32,
  112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 65, 117, 116, 111, 34, 44, 34, 79, 110, 101, 32,
  116, 104, 114, 101, 97, 100, 34, 44, 34, 84, 119, 111, 32, 116, 104, 114,
  101, 97, 100, 115, 34, 44, 34, 70, 111, 117, 114, 32, 116, 104, 114, 101,
  97, 100, 115, 34, 44, 34, 69, 105, 103, 104, 116, 32, 116, 104, 114, 101,
  97, 100, 115, 34, 44, 34, 83, 105, 120, 116, 101, 101, 110, 32, 116, 104,
  114, 101, 97, 100, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 112, 97, 116, 105, 97, 108, 32, 111, 118, 101, 114, 108, 97, 112,
  32, 61, 32, 105, 110, 116, 40, 50, 52, 44, 48, 44, 50, 53, 54, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101,
  118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112,
  108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109,
  112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 56, 47, 50,
  55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 103, 105, 109, 112, 95, 109, 101, 97, 110, 99, 117, 114, 118, 97, 116,
  117, 114, 101, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 32, 58, 10,
  45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  34, 45, 103, 105, 109, 112, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95,
  111, 118, 101, 114, 108, 97, 112, 32, 92, 34, 45, 109, 101, 97, 110, 99,
  117, 114, 118, 97, 116, 117, 114, 101, 95, 102, 108, 111, 119, 32, 36, 50,
  44, 36, 49, 44, 36, 51, 32, 45, 99, 32, 48, 44, 50, 53, 53, 92,
  34, 44, 36, 53, 44, 36, 54, 34, 44, 36, 52, 44, 48, 10, 103, 105,
  109, 112, 95, 109, 101, 97, 110, 99, 117, 114, 118, 97, 116, 117, 114, 101,
  95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95,
  109, 101, 97, 110, 99, 117, 114, 118, 97, 116, 117, 114, 101, 95, 115, 109,
  111, 111, 116, 104, 105, 110, 103, 32, 36, 42, 34, 44, 36, 45, 49, 10,
  35, 64, 103, 105, 109, 112, 32, 83, 109, 111, 111, 116, 104, 32, 91, 109,
  101, 100, 105, 97, 110, 93, 32, 58, 32, 103, 105, 109, 112, 95, 109, 101,
  100, 105, 97, 110, 44, 32, 103, 105, 109, 112, 95, 109, 101, 100, 105, 97,
  110, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 82, 97, 100, 105, 117, 115, 32, 61, 32, 105,
  110, 116, 40, 51, 44, 49, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44, 34, 82,
  71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105,
  110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100,
  32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34,
  66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44,
  34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44,
  34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101,
  34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34,
  86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 71, 114,
  101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34,
  44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34,
  44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34,
  104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101,
  100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101,
  34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117,
  108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117,
  112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  109, 101, 100, 105, 97, 110, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 109, 101, 100, 105, 97,
  110, 32, 36, 49, 34, 44, 36, 50, 44, 48, 10, 103, 105, 109, 112, 95,
  109, 101, 100, 105, 97, 110, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 109, 101, 100, 105,
  97, 110, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 83, 109, 111, 111, 116, 104, 32, 91, 112, 97, 116, 99, 104, 45,
  98, 97, 115, 101, 100, 93, 32, 58, 32, 103, 105, 109, 112, 95, 112, 97,
  116, 99, 104, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 44, 32, 103,
  105, 109, 112, 95, 112, 97, 116, 99, 104, 95, 115, 109, 111, 111, 116, 104,
  105, 110, 103, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 97, 116, 105, 97, 108, 32,
  118, 97, 114, 105, 97, 110, 99, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 48, 44, 48, 46, 49, 44, 50, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 80, 97, 116, 99, 104, 32, 118, 97, 114, 105,
  97, 110, 99, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44,
  48, 46, 49, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 80, 97, 116, 99, 104, 32, 115, 105, 122, 101, 32, 61, 32, 105,
  110, 116, 40, 51, 44, 50, 44, 50, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 76, 111, 111, 107, 117, 112, 32, 115, 105, 122, 101, 32,
  61, 32, 105, 110, 116, 40, 53, 44, 50, 44, 50, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 80, 97, 116, 99, 104, 32, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  70, 97, 115, 116, 32, 97, 112, 112, 114, 111, 120, 105, 109, 97, 116, 105,
  111, 110, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115,
  32, 61, 32, 105, 110, 116, 40, 49, 44, 49, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40,
  115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108,
  34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34,
  76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101,
  47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101,
  115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111,
  110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34,
  44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34,
  66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 80, 97, 114, 97, 108, 108, 101, 108, 32, 112, 114, 111, 99,
  101, 115, 115, 105, 110, 103, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 65, 117, 116, 111, 34, 44, 34, 79, 110, 101, 32, 116, 104, 114, 101,
  97, 100, 34, 44, 34, 84, 119, 111, 32, 116, 104, 114, 101, 97, 100, 115,
  34, 44, 34, 70, 111, 117, 114, 32, 116, 104, 114, 101, 97, 100, 115, 34,
  44, 34, 69, 105, 103, 104, 116, 32, 116, 104, 114, 101, 97, 100, 115, 34,
  44, 34, 83, 105, 120, 116, 101, 101, 110, 32, 116, 104, 114, 101, 97, 100,
  115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 97,
  116, 105, 97, 108, 32, 111, 118, 101, 114, 108, 97, 112, 32, 61, 32, 105,
  110, 116, 40, 50, 52, 44, 48, 44, 50, 53, 54, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97,
  116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 51, 47, 48, 56, 47, 50, 55, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 112, 97, 116, 99, 104, 95, 115, 109, 111, 111, 116, 104, 105, 110,
  103, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 34, 45, 103, 105, 109, 112, 95, 112, 97, 114, 97, 108,
  108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 32, 92, 34, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 55, 32, 45, 100, 101, 110, 111, 105, 115,
  101, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53,
  44, 36, 54, 32, 45, 100, 111, 110, 101, 32, 45, 99, 32, 48, 44, 50,
  53, 53, 92, 34, 44, 36, 57, 44, 36, 49, 48, 34, 44, 36, 56, 44,
  48, 10, 103, 105, 109, 112, 95, 112, 97, 116, 99, 104, 95, 115, 109, 111,
  111, 116, 104, 105, 110, 103, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 112, 97, 116, 99,
  104, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 32, 36, 42, 34, 44,
  36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 83, 109, 111, 111, 116,
  104, 32, 91, 115, 101, 108, 101, 99, 116, 105, 118, 101, 32, 103, 97, 117,
  115, 115, 105, 97, 110, 93, 32, 58, 32, 103, 105, 109, 112, 95, 115, 101,
  108, 101, 99, 116, 105, 118, 101, 95, 115, 109, 111, 111, 116, 104, 105, 110,
  103, 44, 32, 103, 105, 109, 112, 95, 115, 101, 108, 101, 99, 116, 105, 118,
  101, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 95, 112, 114, 101, 118,
  105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 53, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 69, 100, 103, 101, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 53, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 99, 97, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40,
  53, 44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110,
  116, 40, 49, 44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71,
  66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32,
  99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66,
  108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34,
  44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34,
  97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34,
  97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34,
  44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86,
  97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 71, 114, 101,
  101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44,
  34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100,
  34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34,
  44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97,
  114, 97, 108, 108, 101, 108, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110,
  103, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 117, 116, 111,
  34, 44, 34, 79, 110, 101, 32, 116, 104, 114, 101, 97, 100, 34, 44, 34,
  84, 119, 111, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 70, 111,
  117, 114, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 69, 105, 103,
  104, 116, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 83, 105, 120,
  116, 101, 101, 110, 32, 116, 104, 114, 101, 97, 100, 115, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 97, 116, 105, 97, 108, 32,
  111, 118, 101, 114, 108, 97, 112, 32, 61, 32, 105, 110, 116, 40, 50, 52,
  44, 48, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105,
  99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 51, 47, 48, 56, 47, 50, 55, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 115, 101, 108,
  101, 99, 116, 105, 118, 101, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103,
  32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101,
  108, 115, 32, 34, 45, 103, 105, 109, 112, 95, 112, 97, 114, 97, 108, 108,
  101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 32, 92, 34, 45, 114, 101,
  112, 101, 97, 116, 32, 36, 52, 32, 45, 98, 108, 117, 114, 95, 115, 101,
  108, 101, 99, 116, 105, 118, 101, 32, 36, 49, 44, 36, 50, 44, 36, 51,
  32, 45, 100, 111, 110, 101, 32, 45, 99, 32, 48, 44, 50, 53, 53, 92,
  34, 44, 36, 54, 44, 36, 55, 34, 44, 36, 53, 44, 48, 10, 103, 105,
  109, 112, 95, 115, 101, 108, 101, 99, 116, 105, 118, 101, 95, 115, 109, 111,
  111, 116, 104, 105, 110, 103, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 115, 101, 108, 101,
  99, 116, 105, 118, 101, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 32,
  36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 83,
  109, 111, 111, 116, 104, 32, 91, 115, 107, 105, 110, 93, 32, 58, 32, 103,
  105, 109, 112, 95, 115, 109, 111, 111, 116, 104, 95, 115, 107, 105, 110, 44,
  32, 103, 105, 109, 112, 95, 115, 109, 111, 111, 116, 104, 95, 115, 107, 105,
  110, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 83, 116, 101,
  112, 32, 49, 58, 60, 47, 98, 62, 32, 83, 107, 105, 110, 32, 100, 101,
  116, 101, 99, 116, 105, 111, 110, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 107, 105, 110, 32,
  101, 115, 116, 105, 109, 97, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 50, 44, 34, 78, 111, 110, 101, 34, 44, 34, 77, 97,
  110, 117, 97, 108, 34, 44, 34, 65, 117, 116, 111, 109, 97, 116, 105, 99,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 111, 108, 101,
  114, 97, 110, 99, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 80, 114, 101, 45, 110, 111, 114, 109, 97, 108,
  105, 122, 101, 32, 105, 109, 97, 103, 101, 32, 61, 32, 98, 111, 111, 108,
  40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 99,
  111, 111, 114, 100, 105, 110, 97, 116, 101, 32, 91, 109, 97, 110, 117, 97,
  108, 93, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45,
  99, 111, 111, 114, 100, 105, 110, 97, 116, 101, 32, 91, 109, 97, 110, 117,
  97, 108, 93, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  97, 100, 105, 117, 115, 32, 91, 109, 97, 110, 117, 97, 108, 93, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 50, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 83, 116, 101, 112, 32, 50,
  58, 60, 47, 98, 62, 32, 77, 101, 100, 105, 117, 109, 32, 115, 99, 97,
  108, 101, 32, 115, 109, 111, 111, 116, 104, 105, 110, 103, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  66, 97, 115, 101, 32, 115, 99, 97, 108, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 50, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 70, 105, 110, 101, 32, 115, 99, 97, 108, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 50, 44, 48, 44, 48, 46, 56,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44,
  48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 116, 121, 112, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 71, 97, 117, 115, 115,
  105, 97, 110, 34, 44, 34, 66, 105, 108, 97, 116, 101, 114, 97, 108, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 83, 116, 101,
  112, 32, 51, 58, 60, 47, 98, 62, 32, 68, 101, 116, 97, 105, 108, 115,
  32, 101, 110, 104, 97, 110, 99, 101, 109, 101, 110, 116, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  71, 97, 105, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 48,
  53, 44, 48, 44, 48, 46, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101,
  118, 105, 101, 119, 32, 100, 97, 116, 97, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 123, 53, 44, 34, 83, 107, 105, 110, 32, 109, 97, 115, 107, 34,
  44, 34, 66, 97, 115, 101, 32, 115, 99, 97, 108, 101, 34, 44, 34, 77,
  101, 100, 105, 117, 109, 32, 115, 99, 97, 108, 101, 32, 40, 111, 114, 105,
  103, 105, 110, 97, 108, 41, 34, 44, 34, 77, 101, 100, 105, 117, 109, 32,
  115, 99, 97, 108, 101, 32, 40, 115, 109, 111, 111, 116, 104, 101, 100, 41,
  34, 44, 34, 70, 105, 110, 101, 32, 115, 99, 97, 108, 101, 34, 44, 34,
  82, 101, 115, 117, 108, 116, 32, 105, 109, 97, 103, 101, 34, 125, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 118, 105, 101, 119, 32,
  116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70,
  117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116,
  101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68,
  117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68,
  97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38,
  35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 51, 47, 49, 50, 47, 50, 48, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112,
  95, 115, 109, 111, 111, 116, 104, 95, 115, 107, 105, 110, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32,
  45, 108, 91, 48, 93, 32, 45, 116, 111, 95, 114, 103, 98, 10, 45, 105,
  102, 32, 36, 53, 32, 45, 45, 98, 97, 108, 97, 110, 99, 101, 95, 103,
  97, 109, 109, 97, 32, 49, 50, 56, 44, 49, 50, 56, 44, 49, 50, 56,
  32, 45, 101, 108, 115, 101, 32, 91, 48, 93, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 125, 32, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 32, 45, 102,
  91, 45, 49, 93, 32, 49, 32, 45, 101, 108, 105, 102, 32, 123, 36, 49,
  61, 61, 50, 125, 32, 45, 100, 101, 116, 101, 99, 116, 95, 115, 107, 105,
  110, 91, 45, 49, 93, 32, 36, 50, 32, 45, 101, 108, 115, 101, 32, 45,
  100, 101, 116, 101, 99, 116, 95, 115, 107, 105, 110, 91, 45, 49, 93, 32,
  36, 50, 44, 36, 54, 37, 44, 36, 55, 37, 44, 36, 56, 37, 32, 45,
  101, 110, 100, 105, 102, 10, 77, 61, 123, 105, 77, 125, 32, 45, 98, 91,
  45, 49, 93, 32, 36, 51, 37, 32, 45, 42, 91, 45, 49, 93, 32, 123,
  36, 77, 47, 105, 77, 125, 32, 45, 42, 91, 45, 49, 93, 32, 36, 52,
  32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 49, 10, 45, 115, 112, 108,
  105, 116, 95, 100, 101, 116, 97, 105, 108, 115, 91, 48, 93, 32, 52, 44,
  36, 57, 37, 44, 36, 49, 48, 37, 10, 45, 45, 95, 103, 105, 109, 112,
  95, 115, 109, 111, 111, 116, 104, 95, 115, 107, 105, 110, 91, 50, 93, 32,
  36, 49, 50, 44, 36, 49, 49, 10, 45, 106, 91, 50, 93, 32, 91, 45,
  49, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 50,
  93, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 45, 42, 91,
  45, 49, 93, 32, 123, 49, 48, 94, 36, 49, 51, 125, 32, 45, 43, 32,
  45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45,
  97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  95, 103, 105, 109, 112, 95, 115, 109, 111, 111, 116, 104, 95, 115, 107, 105,
  110, 32, 58, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 125, 32,
  45, 98, 32, 123, 36, 50, 47, 56, 125, 37, 10, 45, 101, 108, 115, 101,
  10, 45, 105, 102, 32, 123, 36, 50, 62, 48, 125, 10, 109, 61, 123, 105,
  109, 125, 32, 77, 61, 123, 105, 77, 125, 32, 45, 110, 32, 48, 44, 50,
  53, 53, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40,
  36, 50, 47, 53, 41, 125, 32, 45, 98, 105, 108, 97, 116, 101, 114, 97,
  108, 32, 51, 37, 44, 123, 53, 42, 51, 125, 32, 45, 100, 111, 110, 101,
  10, 45, 98, 105, 108, 97, 116, 101, 114, 97, 108, 32, 51, 37, 44, 123,
  40, 36, 50, 37, 53, 41, 42, 51, 125, 10, 45, 42, 32, 123, 40, 36,
  77, 45, 36, 109, 41, 47, 50, 53, 53, 125, 32, 45, 43, 32, 36, 109,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 103,
  105, 109, 112, 95, 115, 109, 111, 111, 116, 104, 95, 115, 107, 105, 110, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 105, 102, 32, 123, 36,
  45, 50, 61, 61, 48, 125, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 105, 102, 32,
  36, 53, 32, 45, 98, 97, 108, 97, 110, 99, 101, 95, 103, 97, 109, 109,
  97, 32, 49, 50, 56, 44, 49, 50, 56, 44, 49, 50, 56, 32, 45, 101,
  110, 100, 105, 102, 32, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 125,
  32, 45, 102, 32, 49, 32, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61,
  61, 50, 125, 32, 45, 100, 101, 116, 101, 99, 116, 95, 115, 107, 105, 110,
  32, 36, 50, 32, 45, 101, 108, 115, 101, 32, 45, 100, 101, 116, 101, 99,
  116, 95, 115, 107, 105, 110, 32, 36, 50, 44, 36, 54, 37, 44, 36, 55,
  37, 44, 36, 56, 37, 32, 45, 101, 110, 100, 105, 102, 32, 77, 61, 123,
  105, 77, 125, 32, 45, 98, 32, 36, 51, 37, 32, 45, 42, 32, 123, 50,
  53, 53, 42, 36, 77, 47, 105, 77, 125, 32, 45, 42, 32, 36, 52, 32,
  45, 99, 32, 48, 44, 50, 53, 53, 34, 44, 36, 45, 49, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 45, 50, 61, 61, 49, 125, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 98, 32, 36, 57, 37, 34, 44, 36, 45, 49, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 45, 50, 61, 61, 50, 125, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 115, 112, 108, 105, 116, 95, 100, 101, 116, 97, 105, 108, 115,
  32, 52, 44, 36, 57, 37, 44, 36, 49, 48, 37, 32, 45, 107, 91, 45,
  50, 93, 32, 45, 110, 32, 48, 44, 50, 53, 53, 34, 44, 36, 45, 49,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 45, 50, 61, 61, 51, 125, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 115, 112, 108, 105, 116, 95, 100, 101, 116, 97,
  105, 108, 115, 32, 52, 44, 36, 57, 37, 44, 36, 49, 48, 37, 32, 45,
  107, 91, 45, 50, 93, 32, 45, 95, 103, 105, 109, 112, 95, 115, 109, 111,
  111, 116, 104, 95, 115, 107, 105, 110, 32, 36, 49, 50, 44, 36, 49, 49,
  32, 45, 110, 32, 48, 44, 50, 53, 53, 34, 44, 36, 45, 49, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 45, 50, 61, 61, 52, 125, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 115, 112, 108, 105, 116, 95, 100, 101, 116, 97, 105, 108,
  115, 32, 52, 44, 36, 57, 37, 44, 36, 49, 48, 37, 32, 45, 107, 91,
  45, 49, 93, 32, 45, 110, 32, 48, 44, 50, 53, 53, 34, 44, 36, 45,
  49, 10, 45, 101, 108, 115, 101, 10, 45, 103, 105, 109, 112, 95, 115, 112,
  108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105,
  109, 112, 95, 115, 109, 111, 111, 116, 104, 95, 115, 107, 105, 110, 32, 36,
  42, 34, 44, 36, 45, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 49, 61, 61, 49, 125, 10, 45, 116, 111, 95, 114, 103,
  98, 10, 45, 99, 105, 114, 99, 108, 101, 32, 36, 54, 37, 44, 36, 55,
  37, 44, 36, 56, 37, 44, 48, 46, 50, 44, 48, 44, 50, 53, 53, 44,
  48, 10, 45, 99, 105, 114, 99, 108, 101, 32, 36, 54, 37, 44, 36, 55,
  37, 44, 36, 56, 37, 44, 48, 46, 52, 44, 48, 120, 70, 70, 70, 70,
  70, 70, 70, 70, 44, 48, 44, 50, 53, 53, 44, 48, 10, 45, 108, 105,
  110, 101, 32, 123, 36, 54, 45, 48, 46, 50, 53, 42, 36, 56, 125, 37,
  44, 123, 36, 55, 45, 48, 46, 50, 53, 42, 36, 56, 125, 37, 44, 123,
  36, 54, 43, 48, 46, 50, 53, 42, 36, 56, 125, 37, 44, 123, 36, 55,
  43, 48, 46, 50, 53, 42, 36, 56, 125, 37, 44, 48, 46, 56, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 48, 10, 45, 108, 105, 110, 101, 32, 123,
  36, 54, 43, 48, 46, 50, 53, 42, 36, 56, 125, 37, 44, 123, 36, 55,
  45, 48, 46, 50, 53, 42, 36, 56, 125, 37, 44, 123, 36, 54, 45, 48,
  46, 50, 53, 42, 36, 56, 125, 37, 44, 123, 36, 55, 43, 48, 46, 50,
  53, 42, 36, 56, 125, 37, 44, 48, 46, 56, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103, 105,
  109, 112, 32, 83, 109, 111, 111, 116, 104, 32, 91, 116, 104, 105, 110, 32,
  98, 114, 117, 115, 104, 93, 32, 58, 32, 103, 105, 109, 112, 95, 97, 110,
  105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104,
  105, 110, 103, 44, 32, 103, 105, 109, 112, 95, 97, 110, 105, 115, 111, 116,
  114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108,
  105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 54, 48,
  44, 48, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 104, 97, 114, 112, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 57, 44, 48, 44, 50, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 65, 110, 105, 115, 111, 116, 114, 111, 112, 121,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 54, 52, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 97, 100,
  105, 101, 110, 116, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 51, 46, 49, 44, 48, 44, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 101, 110, 115, 111,
  114, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 46, 49, 48, 44, 48, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 97, 116, 105, 97, 108,
  32, 112, 114, 101, 99, 105, 115, 105, 111, 110, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 56, 44, 48, 46, 49, 44, 50, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 117, 108, 97, 114, 32, 112,
  114, 101, 99, 105, 115, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 51, 48, 44, 49, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 86, 97, 108, 117, 101, 32, 112, 114, 101, 99, 105, 115,
  105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 46,
  49, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110,
  116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 48, 44, 34, 78, 101, 97, 114, 101, 115, 116, 32,
  110, 101, 105, 103, 104, 98, 111, 114, 34, 44, 34, 76, 105, 110, 101, 97,
  114, 34, 44, 34, 82, 117, 110, 103, 101, 45, 75, 117, 116, 116, 97, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 97, 115, 116, 32,
  97, 112, 112, 114, 111, 120, 105, 109, 97, 116, 105, 111, 110, 32, 61, 32,
  98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110,
  116, 40, 49, 44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 82, 71, 66, 34, 44, 34, 76, 117,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 32, 38,
  32, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 114,
  97, 108, 108, 101, 108, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 117, 116, 111, 34,
  44, 34, 79, 110, 101, 32, 116, 104, 114, 101, 97, 100, 34, 44, 34, 84,
  119, 111, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 70, 111, 117,
  114, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 69, 105, 103, 104,
  116, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 83, 105, 120, 116,
  101, 101, 110, 32, 116, 104, 114, 101, 97, 100, 115, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 112, 97, 116, 105, 97, 108, 32, 111,
  118, 101, 114, 108, 97, 112, 32, 61, 32, 105, 110, 116, 40, 50, 52, 44,
  48, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 92, 110, 60,
  115, 109, 97, 108, 108, 62, 60, 98, 62, 78, 111, 116, 101, 58, 32, 60,
  47, 98, 62, 84, 104, 105, 115, 32, 115, 101, 116, 32, 111, 102, 32, 97,
  110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 32, 115, 109, 111, 111, 116,
  104, 105, 110, 103, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32,
  104, 97, 115, 32, 98, 101, 101, 110, 32, 115, 117, 103, 103, 101, 115, 116,
  101, 100, 32, 98, 121, 32, 80, 104, 111, 116, 111, 67, 111, 109, 105, 88,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 125, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 80, 104, 111, 116, 111, 67, 111, 109, 105,
  88, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 48, 47, 49, 50, 47, 50, 54, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 83,
  109, 111, 111, 116, 104, 32, 91, 116, 111, 116, 97, 108, 32, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 93, 32, 58, 32, 103, 105, 109, 112, 95, 116,
  118, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 44, 32, 103, 105, 109,
  112, 95, 116, 118, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 95, 112,
  114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 84, 105, 109, 101, 32, 115, 116, 101, 112, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 51, 48, 44, 53, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101, 114, 97, 116, 105, 111,
  110, 115, 32, 61, 32, 105, 110, 116, 40, 49, 48, 44, 49, 44, 52, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 75, 101, 101, 112, 32,
  105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 97, 115, 32, 100, 105,
  102, 102, 101, 114, 101, 110, 116, 32, 108, 97, 121, 101, 114, 115, 32, 61,
  32, 98, 111, 111, 108, 40, 102, 97, 108, 115, 101, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44,
  34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114,
  101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34,
  44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115,
  34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115,
  34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72,
  117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34,
  44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34,
  71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34,
  82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108,
  117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 80, 97, 114, 97, 108, 108, 101, 108, 32, 112, 114, 111, 99, 101, 115,
  115, 105, 110, 103, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65,
  117, 116, 111, 34, 44, 34, 79, 110, 101, 32, 116, 104, 114, 101, 97, 100,
  34, 44, 34, 84, 119, 111, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44,
  34, 70, 111, 117, 114, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34,
  69, 105, 103, 104, 116, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34,
  83, 105, 120, 116, 101, 101, 110, 32, 116, 104, 114, 101, 97, 100, 115, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 97, 116, 105,
  97, 108, 32, 111, 118, 101, 114, 108, 97, 112, 32, 61, 32, 105, 110, 116,
  40, 50, 52, 44, 48, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117,
  108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117,
  112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 51, 47, 48, 56, 47, 50, 55, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  116, 118, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 32, 58, 10, 45,
  97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34,
  45, 103, 105, 109, 112, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111,
  118, 101, 114, 108, 97, 112, 32, 92, 34, 45, 116, 118, 95, 102, 108, 111,
  119, 32, 36, 50, 44, 36, 49, 44, 36, 51, 32, 45, 99, 32, 48, 44,
  50, 53, 53, 92, 34, 44, 36, 53, 44, 36, 54, 34, 44, 36, 52, 44,
  48, 10, 103, 105, 109, 112, 95, 116, 118, 95, 115, 109, 111, 111, 116, 104,
  105, 110, 103, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 103, 105, 109, 112, 95, 116, 118, 95, 115, 109, 111, 111,
  116, 104, 105, 110, 103, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64,
  103, 105, 109, 112, 32, 83, 109, 111, 111, 116, 104, 32, 91, 119, 97, 118,
  101, 108, 101, 116, 115, 93, 32, 58, 32, 103, 105, 109, 112, 95, 104, 97,
  97, 114, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 44, 32, 103, 105,
  109, 112, 95, 104, 97, 97, 114, 95, 115, 109, 111, 111, 116, 104, 105, 110,
  103, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101, 114, 97, 116, 105,
  111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 49, 48, 44, 49, 44, 51,
  50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 97, 108,
  101, 115, 32, 61, 32, 105, 110, 116, 40, 49, 48, 44, 50, 44, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110,
  101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66,
  34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66,
  108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104,
  116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97,
  116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75,
  101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110,
  34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 80, 97, 114, 97, 108, 108, 101, 108, 32, 112,
  114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 65, 117, 116, 111, 34, 44, 34, 79, 110, 101, 32, 116,
  104, 114, 101, 97, 100, 34, 44, 34, 84, 119, 111, 32, 116, 104, 114, 101,
  97, 100, 115, 34, 44, 34, 70, 111, 117, 114, 32, 116, 104, 114, 101, 97,
  100, 115, 34, 44, 34, 69, 105, 103, 104, 116, 32, 116, 104, 114, 101, 97,
  100, 115, 34, 44, 34, 83, 105, 120, 116, 101, 101, 110, 32, 116, 104, 114,
  101, 97, 100, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 112, 97, 116, 105, 97, 108, 32, 111, 118, 101, 114, 108, 97, 112, 32,
  61, 32, 105, 110, 116, 40, 50, 52, 44, 48, 44, 50, 53, 54, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108,
  105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32,
  60, 105, 62, 74, 38, 35, 50, 51, 51, 59, 114, 111, 109, 101, 32, 66,
  111, 117, 108, 97, 110, 103, 101, 114, 32, 97, 110, 100, 32, 68, 97, 118,
  105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50,
  51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62,
  50, 48, 49, 51, 47, 48, 56, 47, 50, 55, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 104,
  97, 97, 114, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 32, 58, 10,
  45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  34, 45, 103, 105, 109, 112, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95,
  111, 118, 101, 114, 108, 97, 112, 32, 92, 34, 45, 100, 101, 110, 111, 105,
  115, 101, 95, 104, 97, 97, 114, 32, 36, 49, 44, 36, 51, 44, 36, 50,
  32, 45, 99, 32, 48, 44, 50, 53, 53, 92, 34, 44, 36, 53, 44, 36,
  54, 34, 44, 36, 52, 44, 48, 10, 103, 105, 109, 112, 95, 104, 97, 97,
  114, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112,
  95, 104, 97, 97, 114, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 32,
  36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 83,
  109, 111, 111, 116, 104, 32, 91, 119, 105, 101, 110, 101, 114, 93, 32, 58,
  32, 106, 101, 106, 101, 95, 108, 111, 99, 97, 108, 95, 119, 105, 101, 110,
  101, 114, 44, 32, 106, 101, 106, 101, 95, 108, 111, 99, 97, 108, 95, 119,
  105, 101, 110, 101, 114, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 50, 44, 46, 53, 44, 49, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101,
  119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  32, 58, 32, 60, 105, 62, 74, 38, 35, 50, 51, 51, 59, 114, 38, 35,
  50, 52, 52, 59, 109, 101, 32, 66, 111, 117, 108, 97, 110, 103, 101, 114,
  60, 47, 105, 62, 46, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 54, 47,
  48, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 106, 101, 106, 101, 95, 108, 111, 99, 97, 108, 95, 119, 105, 101,
  110, 101, 114, 32, 58, 10, 45, 108, 111, 99, 97, 108, 95, 119, 105, 101,
  110, 101, 114, 32, 36, 49, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10,
  106, 101, 106, 101, 95, 108, 111, 99, 97, 108, 95, 119, 105, 101, 110, 101,
  114, 95, 112, 114, 101, 118, 105, 101, 119, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 106, 101, 106, 101, 95, 108, 111, 99, 97, 108, 95, 119, 105, 101, 110,
  101, 114, 32, 36, 49, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 85, 110, 115, 116, 114, 105, 112, 32, 58, 32, 106, 101, 106, 101,
  95, 117, 110, 115, 116, 114, 105, 112, 44, 32, 106, 101, 106, 101, 95, 117,
  110, 115, 116, 114, 105, 112, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 105, 122, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 49, 44, 53, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 110, 115, 105,
  116, 105, 118, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52,
  44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 114, 109, 97, 108, 105, 122, 101, 32, 61, 32, 98, 111, 111, 108,
  40, 116, 114, 117, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  70, 102, 116, 32, 112, 114, 101, 118, 105, 101, 119, 32, 61, 32, 98, 111,
  111, 108, 40, 102, 97, 108, 115, 101, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121,
  112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60,
  105, 62, 74, 38, 35, 50, 51, 51, 59, 114, 38, 35, 50, 52, 52, 59,
  109, 101, 32, 66, 111, 117, 108, 97, 110, 103, 101, 114, 60, 47, 105, 62,
  46, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 54, 47, 49, 48, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 106, 101,
  106, 101, 95, 117, 110, 115, 116, 114, 105, 112, 32, 58, 10, 45, 117, 110,
  115, 116, 114, 105, 112, 32, 36, 49, 44, 36, 50, 44, 36, 51, 10, 45,
  105, 102, 32, 36, 53, 32, 45, 116, 97, 112, 101, 32, 45, 112, 111, 119,
  101, 114, 115, 112, 101, 99, 116, 114, 117, 109, 32, 45, 101, 108, 115, 101,
  10, 45, 105, 102, 32, 45, 36, 52, 32, 45, 110, 32, 48, 44, 50, 53,
  53, 32, 45, 101, 108, 115, 101, 32, 45, 99, 32, 48, 44, 50, 53, 53,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 106,
  101, 106, 101, 95, 117, 110, 115, 116, 114, 105, 112, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 106, 101, 106, 101,
  95, 117, 110, 115, 116, 114, 105, 112, 32, 36, 49, 44, 36, 50, 44, 36,
  51, 44, 36, 52, 44, 36, 53, 34, 44, 36, 45, 49, 10, 35, 64, 103,
  105, 109, 112, 32, 85, 112, 115, 99, 97, 108, 101, 32, 91, 100, 105, 102,
  102, 117, 115, 105, 111, 110, 93, 32, 58, 32, 103, 105, 109, 112, 95, 117,
  112, 115, 99, 97, 108, 101, 95, 115, 109, 97, 114, 116, 44, 32, 103, 105,
  109, 112, 95, 117, 112, 115, 99, 97, 108, 101, 95, 115, 109, 97, 114, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 87, 105, 100, 116, 104, 32, 61, 32, 116, 101, 120,
  116, 40, 34, 50, 48, 48, 37, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 72, 101, 105, 103, 104, 116, 32, 61, 32, 116, 101, 120, 116,
  40, 34, 50, 48, 48, 37, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 50, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 65, 110, 105, 115, 111, 116, 114, 111, 112, 121,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 52, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 114, 112,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60,
  105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101,
  114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103,
  105, 109, 112, 95, 117, 112, 115, 99, 97, 108, 101, 95, 115, 109, 97, 114,
  116, 32, 58, 10, 45, 116, 111, 95, 114, 103, 98, 32, 45, 117, 112, 115,
  99, 97, 108, 101, 95, 115, 109, 97, 114, 116, 32, 36, 49, 44, 36, 50,
  44, 49, 44, 36, 51, 44, 36, 52, 44, 36, 53, 32, 45, 99, 32, 48,
  44, 50, 53, 53, 10, 103, 105, 109, 112, 95, 117, 112, 115, 99, 97, 108,
  101, 95, 115, 109, 97, 114, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 45, 114,
  91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 49, 44, 49, 44, 48,
  10, 45, 105, 102, 32, 123, 119, 60, 64, 123, 45, 50, 44, 119, 125, 124,
  124, 104, 60, 64, 123, 45, 50, 44, 104, 125, 125, 10, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 47, 91, 45, 49, 93, 32, 52, 10, 48, 32, 45,
  116, 91, 45, 49, 93, 32, 34, 68, 111, 119, 110, 115, 99, 97, 108, 105,
  110, 103, 32, 105, 115, 92, 110, 110, 111, 116, 32, 97, 108, 108, 111, 119,
  101, 100, 33, 34, 44, 53, 44, 53, 44, 50, 48, 44, 49, 44, 50, 53,
  53, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45,
  50, 93, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48,
  46, 53, 10, 45, 111, 114, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101,
  108, 115, 101, 10, 45, 122, 91, 45, 50, 93, 32, 123, 53, 48, 45, 53,
  48, 42, 64, 123, 45, 50, 44, 119, 125, 47, 119, 125, 37, 44, 123, 53,
  48, 45, 53, 48, 42, 64, 123, 45, 50, 44, 104, 125, 47, 104, 125, 37,
  44, 123, 53, 48, 43, 53, 48, 42, 64, 123, 45, 50, 44, 119, 125, 47,
  119, 125, 37, 44, 123, 53, 48, 43, 53, 48, 42, 64, 123, 45, 50, 44,
  104, 125, 47, 104, 125, 37, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  103, 105, 109, 112, 95, 117, 112, 115, 99, 97, 108, 101, 95, 115, 109, 97,
  114, 116, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44,
  36, 52, 44, 36, 53, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 109, 118, 91, 45, 49,
  93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112,
  32, 85, 112, 115, 99, 97, 108, 101, 32, 91, 115, 99, 97, 108, 101, 50,
  120, 93, 32, 58, 32, 103, 105, 109, 112, 95, 115, 99, 97, 108, 101, 110,
  120, 44, 32, 103, 105, 109, 112, 95, 115, 99, 97, 108, 101, 110, 120, 95,
  112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 99, 97, 108, 105, 110, 103, 32, 102, 97, 99, 116,
  111, 114, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 120, 32, 50,
  34, 44, 34, 120, 32, 51, 34, 44, 34, 120, 32, 52, 34, 44, 34, 120,
  32, 54, 34, 44, 34, 120, 32, 56, 34, 44, 34, 120, 32, 57, 34, 44,
  34, 120, 32, 49, 50, 34, 44, 34, 120, 32, 49, 54, 34, 44, 34, 120,
  32, 49, 56, 34, 44, 34, 120, 32, 50, 55, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 98, 97, 115, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 82, 71, 66, 34,
  44, 34, 89, 67, 98, 67, 114, 34, 44, 34, 76, 97, 98, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 123, 34, 92, 110, 60, 115, 109, 97, 108, 108, 62, 60,
  98, 62, 78, 111, 116, 101, 58, 32, 60, 47, 98, 62, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 84, 104, 105, 115, 32, 102, 105, 108, 116, 101,
  114, 32, 114, 101, 45, 105, 109, 112, 108, 101, 109, 101, 110, 116, 115, 32,
  116, 104, 101, 32, 115, 99, 97, 108, 105, 110, 103, 32, 97, 108, 103, 111,
  114, 105, 116, 104, 109, 32, 100, 101, 115, 99, 114, 105, 98, 101, 100, 32,
  97, 116, 32, 58, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 104,
  116, 116, 112, 58, 47, 47, 115, 99, 97, 108, 101, 50, 120, 46, 115, 111,
  117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 123, 34, 60, 115, 109, 97, 108, 108, 62, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 84, 104, 105, 115, 32, 102, 105, 108, 116,
  101, 114, 32, 105, 115, 32, 117, 115, 101, 102, 117, 108, 32, 102, 111, 114,
  32, 114, 101, 115, 105, 122, 105, 110, 103, 32, 105, 109, 97, 103, 101, 115,
  32, 116, 104, 97, 116, 32, 104, 97, 118, 101, 32, 118, 101, 114, 121, 32,
  102, 101, 119, 32, 99, 111, 108, 111, 114, 115, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 40, 101, 46, 103, 46, 32, 105, 110, 100, 101, 120, 101,
  100, 32, 105, 109, 97, 103, 101, 115, 41, 46, 32, 73, 116, 32, 105, 115,
  32, 103, 101, 110, 101, 114, 97, 108, 108, 121, 32, 117, 115, 101, 108, 101,
  115, 115, 32, 102, 111, 114, 32, 116, 114, 117, 101, 32, 99, 111, 108, 111,
  114, 115, 32, 105, 109, 97, 103, 101, 115, 46, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 60, 47, 115, 109, 97, 108, 108, 62, 34, 125, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65,
  117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32,
  84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59,
  60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49,
  48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 115, 99, 97, 108,
  101, 110, 120, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111,
  112, 97, 99, 105, 116, 121, 10, 45, 105, 102, 32, 123, 36, 50, 61, 61,
  49, 125, 32, 45, 114, 103, 98, 50, 121, 99, 98, 99, 114, 91, 48, 93,
  32, 45, 114, 111, 117, 110, 100, 91, 48, 93, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 50, 61, 61, 50, 125, 32, 45, 114, 103, 98, 50, 108, 97,
  98, 56, 91, 48, 93, 32, 45, 114, 111, 117, 110, 100, 91, 48, 93, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61,
  48, 125, 32, 45, 115, 99, 97, 108, 101, 50, 120, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 61, 61, 49, 125, 32, 45, 115, 99, 97, 108, 101,
  51, 120, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 50, 125,
  32, 45, 115, 99, 97, 108, 101, 50, 120, 32, 45, 115, 99, 97, 108, 101,
  50, 120, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 51, 125,
  32, 45, 115, 99, 97, 108, 101, 51, 120, 32, 45, 115, 99, 97, 108, 101,
  50, 120, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 52, 125,
  32, 45, 115, 99, 97, 108, 101, 50, 120, 32, 45, 115, 99, 97, 108, 101,
  50, 120, 32, 45, 115, 99, 97, 108, 101, 50, 120, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 61, 61, 53, 125, 32, 45, 115, 99, 97, 108, 101,
  51, 120, 32, 45, 115, 99, 97, 108, 101, 51, 120, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 61, 61, 54, 125, 32, 45, 115, 99, 97, 108, 101,
  51, 120, 32, 45, 115, 99, 97, 108, 101, 50, 120, 32, 45, 115, 99, 97,
  108, 101, 50, 120, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61,
  55, 125, 32, 45, 115, 99, 97, 108, 101, 50, 120, 32, 45, 115, 99, 97,
  108, 101, 50, 120, 32, 45, 115, 99, 97, 108, 101, 50, 120, 32, 45, 115,
  99, 97, 108, 101, 50, 120, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49,
  61, 61, 56, 125, 32, 45, 115, 99, 97, 108, 101, 51, 120, 32, 45, 115,
  99, 97, 108, 101, 51, 120, 32, 45, 115, 99, 97, 108, 101, 50, 120, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 57, 125, 32, 45, 115,
  99, 97, 108, 101, 51, 120, 32, 45, 115, 99, 97, 108, 101, 51, 120, 32,
  45, 115, 99, 97, 108, 101, 51, 120, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 50, 61, 61, 49, 125, 32, 45, 121, 99, 98,
  99, 114, 50, 114, 103, 98, 91, 48, 93, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 50, 61, 61, 50, 125, 32, 45, 108, 97, 98, 56, 50, 114, 103,
  98, 91, 48, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 97, 32, 99,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109,
  112, 95, 115, 99, 97, 108, 101, 110, 120, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 122, 32, 52, 48, 37, 44, 52, 48, 37, 44, 54,
  48, 37, 44, 54, 48, 37, 10, 45, 103, 105, 109, 112, 95, 115, 99, 97,
  108, 101, 110, 120, 32, 36, 49, 44, 36, 50, 10, 103, 105, 109, 112, 95,
  114, 101, 110, 100, 101, 114, 51, 100, 32, 58, 10, 45, 110, 51, 100, 32,
  45, 99, 51, 100, 32, 45, 109, 51, 100, 32, 36, 49, 51, 32, 102, 51,
  100, 61, 123, 48, 46, 53, 42, 109, 97, 120, 40, 36, 49, 44, 36, 50,
  41, 47, 116, 97, 110, 40, 36, 55, 42, 112, 105, 47, 51, 54, 48, 41,
  125, 10, 45, 102, 51, 100, 32, 36, 102, 51, 100, 32, 45, 108, 51, 100,
  32, 123, 36, 56, 42, 36, 102, 51, 100, 125, 44, 123, 36, 57, 42, 36,
  102, 51, 100, 125, 44, 123, 36, 49, 48, 42, 36, 102, 51, 100, 125, 32,
  45, 115, 108, 51, 100, 32, 36, 49, 49, 32, 45, 115, 115, 51, 100, 32,
  36, 49, 50, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 42, 51, 100, 32, 123, 36, 51, 42, 109,
  97, 120, 40, 36, 49, 44, 36, 50, 41, 125, 32, 45, 114, 51, 100, 32,
  48, 44, 48, 44, 49, 44, 36, 54, 32, 45, 114, 51, 100, 32, 48, 44,
  49, 44, 48, 44, 36, 53, 32, 45, 114, 51, 100, 32, 49, 44, 48, 44,
  48, 44, 36, 52, 10, 36, 49, 44, 36, 50, 44, 49, 44, 51, 44, 45,
  49, 32, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 49, 93, 32,
  91, 45, 50, 93, 44, 53, 48, 37, 44, 53, 48, 37, 32, 45, 114, 109,
  91, 45, 50, 93, 10, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 114,
  101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 32, 48, 44, 48,
  44, 45, 49, 44, 45, 49, 44, 45, 49, 44, 50, 53, 53, 44, 48, 44,
  48, 44, 48, 44, 48, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 35, 64, 103, 105, 109, 112, 32, 95, 10, 35, 64, 103, 105, 109,
  112, 32, 60, 98, 62, 83, 101, 113, 117, 101, 110, 99, 101, 115, 60, 47,
  98, 62, 10, 35, 64, 103, 105, 109, 112, 32, 51, 100, 32, 101, 108, 101,
  118, 97, 116, 105, 111, 110, 32, 91, 97, 110, 105, 109, 97, 116, 101, 100,
  93, 32, 58, 32, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101,
  95, 101, 108, 101, 118, 97, 116, 105, 111, 110, 51, 100, 44, 32, 103, 105,
  109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 101, 108, 101, 118, 97,
  116, 105, 111, 110, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 114, 97, 109, 101,
  115, 32, 61, 32, 95, 105, 110, 116, 40, 49, 48, 44, 50, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112,
  117, 116, 32, 97, 115, 32, 102, 114, 97, 109, 101, 115, 32, 61, 32, 95,
  98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 79, 117, 116, 112, 117, 116, 32, 97, 115, 32, 102, 105, 108, 101, 115,
  32, 61, 32, 95, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 102, 111, 108, 100,
  101, 114, 32, 61, 32, 95, 102, 111, 108, 100, 101, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 123, 34, 92, 110, 60, 98, 62, 71, 108, 111, 98, 97, 108,
  32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 58, 60, 47, 98,
  62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 97, 99,
  116, 111, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 48, 44,
  45, 49, 48, 48, 48, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 87, 105, 100, 116, 104, 32, 61,
  32, 95, 105, 110, 116, 40, 49, 48, 50, 52, 44, 56, 44, 52, 48, 57,
  54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 101, 105, 103,
  104, 116, 32, 61, 32, 95, 105, 110, 116, 40, 49, 48, 50, 52, 44, 56,
  44, 52, 48, 57, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  82, 101, 110, 100, 101, 114, 105, 110, 103, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 50, 44, 34, 68, 111, 116, 115, 34, 44, 34, 87, 105, 114,
  101, 102, 114, 97, 109, 101, 34, 44, 34, 70, 108, 97, 116, 34, 44, 34,
  70, 108, 97, 116, 32, 115, 104, 97, 100, 101, 100, 34, 44, 34, 71, 111,
  117, 114, 97, 117, 100, 34, 44, 34, 80, 104, 111, 110, 103, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 123, 34, 92, 110, 60, 98, 62, 83, 116, 97, 114, 116,
  105, 110, 103, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 58,
  60, 47, 98, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 56,
  44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88,
  45, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51,
  53, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 89, 45, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 90, 45, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 70, 111, 118, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 52, 53, 44, 49, 44, 57, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 88, 45, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 108, 105, 103, 104, 116,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 48, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 45,
  108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 45, 49,
  48, 48, 44, 45, 49, 48, 48, 44, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 112, 101, 99, 117, 108, 97, 114, 32, 108, 105, 103,
  104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 112, 101, 99, 117, 108, 97, 114, 32, 115, 104, 105, 110, 105, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 44,
  48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 92, 110, 60, 98, 62,
  69, 110, 100, 105, 110, 103, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114,
  115, 32, 58, 60, 47, 98, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 56, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 45, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 51, 53, 44, 48, 44, 49, 52, 52, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 89, 45, 97, 110, 103, 108, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 52, 52, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 45, 97, 110, 103, 108, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 54, 48, 44, 48, 44, 49,
  52, 52, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 111,
  118, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 53, 44, 49, 44, 57,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 108, 105,
  103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49,
  48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 89, 45, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 90, 45, 108, 105, 103, 104, 116, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 45, 49, 48, 48, 44, 45, 49, 48, 48, 44,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 101, 99,
  117, 108, 97, 114, 32, 108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 101, 99, 117, 108, 97,
  114, 32, 115, 104, 105, 110, 105, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 55, 44, 48, 44, 51, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115,
  99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47,
  49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116,
  101, 95, 101, 108, 101, 118, 97, 116, 105, 111, 110, 51, 100, 32, 58, 10,
  45, 105, 102, 32, 36, 51, 32, 102, 105, 108, 101, 110, 97, 109, 101, 61,
  34, 36, 52, 47, 103, 109, 105, 99, 95, 101, 108, 101, 118, 97, 116, 105,
  111, 110, 51, 100, 46, 112, 110, 103, 34, 32, 45, 101, 108, 115, 101, 32,
  102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 34, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 101, 108, 101, 118, 97, 116,
  105, 111, 110, 51, 100, 32, 36, 123, 53, 45, 54, 125, 10, 45, 97, 110,
  105, 109, 97, 116, 101, 32, 103, 105, 109, 112, 95, 114, 101, 110, 100, 101,
  114, 51, 100, 44, 34, 36, 123, 55, 45, 56, 125, 44, 36, 123, 49, 48,
  45, 49, 57, 125, 44, 36, 57, 34, 44, 92, 10, 34, 36, 123, 55, 45,
  56, 125, 44, 36, 123, 50, 48, 45, 50, 57, 125, 44, 36, 57, 34, 44,
  36, 49, 44, 36, 50, 44, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32,
  36, 102, 105, 108, 101, 110, 97, 109, 101, 125, 10, 103, 105, 109, 112, 95,
  97, 110, 105, 109, 97, 116, 101, 95, 101, 108, 101, 118, 97, 116, 105, 111,
  110, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 119, 61,
  123, 119, 125, 32, 104, 61, 123, 104, 125, 10, 45, 95, 103, 105, 109, 112,
  95, 101, 108, 101, 118, 97, 116, 105, 111, 110, 51, 100, 32, 36, 123, 53,
  45, 54, 125, 10, 45, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 103, 105, 109, 112, 95, 114,
  101, 110, 100, 101, 114, 51, 100, 44, 36, 119, 34, 44, 34, 36, 104, 34,
  44, 36, 123, 49, 48, 45, 49, 57, 125, 44, 36, 57, 34, 44, 92, 10,
  36, 119, 34, 44, 34, 36, 104, 34, 44, 36, 123, 50, 48, 45, 50, 57,
  125, 44, 36, 57, 34, 44, 48, 44, 36, 119, 44, 36, 104, 10, 35, 64,
  103, 105, 109, 112, 32, 51, 100, 32, 101, 120, 116, 114, 117, 115, 105, 111,
  110, 32, 91, 97, 110, 105, 109, 97, 116, 101, 100, 93, 32, 58, 32, 103,
  105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 101, 120, 116, 114,
  117, 100, 101, 51, 100, 44, 32, 103, 105, 109, 112, 95, 97, 110, 105, 109,
  97, 116, 101, 95, 101, 120, 116, 114, 117, 100, 101, 51, 100, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 70, 114, 97, 109, 101, 115, 32, 61, 32, 95, 105, 110, 116, 40,
  49, 48, 44, 50, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 97, 115, 32, 102, 114, 97,
  109, 101, 115, 32, 61, 32, 95, 98, 111, 111, 108, 40, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 97,
  115, 32, 102, 105, 108, 101, 115, 32, 61, 32, 95, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112,
  117, 116, 32, 102, 111, 108, 100, 101, 114, 32, 61, 32, 95, 102, 111, 108,
  100, 101, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 92, 110, 60, 98,
  62, 71, 108, 111, 98, 97, 108, 32, 112, 97, 114, 97, 109, 101, 116, 101,
  114, 115, 32, 58, 60, 47, 98, 62, 34, 125, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 68, 101, 112, 116, 104, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 48, 44, 49, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 32,
  61, 32, 105, 110, 116, 40, 53, 49, 50, 44, 49, 44, 49, 48, 50, 52,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  54, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  87, 105, 100, 116, 104, 32, 61, 32, 95, 105, 110, 116, 40, 49, 48, 50,
  52, 44, 56, 44, 52, 48, 57, 54, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 72, 101, 105, 103, 104, 116, 32, 61, 32, 95, 105, 110, 116,
  40, 49, 48, 50, 52, 44, 56, 44, 52, 48, 57, 54, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 101, 110, 100, 101, 114, 105, 110, 103,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 52, 44, 34, 68, 111, 116,
  115, 34, 44, 34, 87, 105, 114, 101, 102, 114, 97, 109, 101, 34, 44, 34,
  70, 108, 97, 116, 34, 44, 34, 70, 108, 97, 116, 32, 115, 104, 97, 100,
  101, 100, 34, 44, 34, 71, 111, 117, 114, 97, 117, 100, 34, 44, 34, 80,
  104, 111, 110, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 92, 110, 60,
  98, 62, 83, 116, 97, 114, 116, 105, 110, 103, 32, 112, 97, 114, 97, 109,
  101, 116, 101, 114, 115, 32, 58, 60, 47, 98, 62, 34, 125, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 56, 44, 48, 44, 51, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 88, 45, 97, 110, 103, 108, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 51, 53, 44, 48, 44, 51, 54, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 97, 110, 103, 108, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 51, 54, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 45, 97, 110, 103,
  108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 51,
  54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 111, 118,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 53, 44, 49, 44, 57, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 108, 105, 103,
  104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 48,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  89, 45, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 90, 45, 108, 105, 103, 104, 116, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 45, 49, 48, 48, 44, 45, 49, 48, 48, 44, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 101, 99, 117,
  108, 97, 114, 32, 108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 101, 99, 117, 108, 97, 114,
  32, 115, 104, 105, 110, 105, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 55, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  123, 34, 92, 110, 60, 98, 62, 69, 110, 100, 105, 110, 103, 32, 112, 97,
  114, 97, 109, 101, 116, 101, 114, 115, 32, 58, 60, 47, 98, 62, 34, 125,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 105, 122, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 56, 44, 48, 44, 51, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 97, 110, 103, 108, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 53, 44, 48, 44, 49, 52,
  52, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 97,
  110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 54, 48,
  44, 48, 44, 49, 52, 52, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 90, 45, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 48, 44, 49, 52, 52, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 70, 111, 118, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 52, 53, 44, 49, 44, 57, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 88, 45, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 108, 105, 103, 104, 116, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 48, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 45, 108,
  105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 45, 49, 48,
  48, 44, 45, 49, 48, 48, 44, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 112, 101, 99, 117, 108, 97, 114, 32, 108, 105, 103, 104,
  116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 112, 101, 99, 117, 108, 97, 114, 32, 115, 104, 105, 110, 105, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 44, 48,
  44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68,
  97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38,
  35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112,
  95, 97, 110, 105, 109, 97, 116, 101, 95, 101, 120, 116, 114, 117, 100, 101,
  51, 100, 32, 58, 10, 45, 105, 102, 32, 36, 51, 32, 102, 105, 108, 101,
  110, 97, 109, 101, 61, 34, 36, 52, 47, 103, 109, 105, 99, 95, 101, 120,
  116, 114, 117, 100, 101, 51, 100, 46, 112, 110, 103, 34, 32, 45, 101, 108,
  115, 101, 32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 34, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 101, 120, 116,
  114, 117, 100, 101, 51, 100, 32, 36, 123, 53, 45, 55, 125, 10, 45, 97,
  110, 105, 109, 97, 116, 101, 32, 103, 105, 109, 112, 95, 114, 101, 110, 100,
  101, 114, 51, 100, 44, 34, 36, 123, 56, 45, 57, 125, 44, 36, 123, 49,
  49, 45, 50, 48, 125, 44, 36, 49, 48, 34, 44, 92, 10, 34, 36, 123,
  56, 45, 57, 125, 44, 36, 123, 50, 49, 45, 51, 48, 125, 44, 36, 49,
  48, 34, 44, 36, 49, 44, 36, 50, 44, 64, 123, 45, 113, 117, 111, 116,
  101, 92, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 125, 10, 103, 105,
  109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 101, 120, 116, 114, 117,
  100, 101, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 119,
  61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 10, 45, 95, 103, 105, 109,
  112, 95, 101, 120, 116, 114, 117, 100, 101, 51, 100, 32, 36, 123, 53, 45,
  55, 125, 10, 45, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 103, 105, 109, 112, 95, 114, 101,
  110, 100, 101, 114, 51, 100, 44, 36, 119, 34, 44, 34, 36, 104, 34, 44,
  36, 123, 49, 49, 45, 50, 48, 125, 44, 36, 49, 48, 34, 44, 92, 10,
  36, 119, 34, 44, 34, 36, 104, 34, 44, 36, 123, 50, 49, 45, 51, 48,
  125, 44, 36, 49, 48, 34, 44, 48, 44, 36, 119, 44, 36, 104, 10, 35,
  64, 103, 105, 109, 112, 32, 51, 100, 32, 105, 109, 97, 103, 101, 32, 111,
  98, 106, 101, 99, 116, 32, 91, 97, 110, 105, 109, 97, 116, 101, 100, 93,
  32, 58, 32, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95,
  105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 44, 32, 103,
  105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 105, 109, 97, 103,
  101, 111, 98, 106, 101, 99, 116, 51, 100, 95, 112, 114, 101, 118, 105, 101,
  119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 114,
  97, 109, 101, 115, 32, 61, 32, 95, 105, 110, 116, 40, 49, 48, 44, 50,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79,
  117, 116, 112, 117, 116, 32, 97, 115, 32, 102, 114, 97, 109, 101, 115, 32,
  61, 32, 95, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 97, 115, 32, 102, 105,
  108, 101, 115, 32, 61, 32, 95, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 102,
  111, 108, 100, 101, 114, 32, 61, 32, 95, 102, 111, 108, 100, 101, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 123, 34, 92, 110, 60, 98, 62, 71, 108, 111,
  98, 97, 108, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 58,
  60, 47, 98, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  84, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 123, 49, 44,
  34, 80, 108, 97, 110, 101, 34, 44, 34, 67, 117, 98, 101, 34, 44, 34,
  80, 121, 114, 97, 109, 105, 100, 34, 44, 34, 83, 112, 104, 101, 114, 101,
  34, 44, 34, 84, 111, 114, 117, 115, 34, 44, 34, 71, 121, 114, 111, 105,
  100, 34, 44, 34, 87, 101, 105, 114, 100, 34, 44, 34, 67, 117, 112, 34,
  44, 34, 82, 117, 98, 105, 107, 34, 125, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 87, 105, 100, 116, 104, 32, 61, 32, 95, 105, 110, 116, 40,
  49, 48, 50, 52, 44, 49, 44, 52, 48, 57, 54, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 72, 101, 105, 103, 104, 116, 32, 61, 32, 95,
  105, 110, 116, 40, 49, 48, 50, 52, 44, 49, 44, 52, 48, 57, 54, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 110, 100, 101, 114,
  105, 110, 103, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 52, 44, 34,
  68, 111, 116, 115, 34, 44, 34, 87, 105, 114, 101, 102, 114, 97, 109, 101,
  34, 44, 34, 70, 108, 97, 116, 34, 44, 34, 70, 108, 97, 116, 32, 115,
  104, 97, 100, 101, 100, 34, 44, 34, 71, 111, 117, 114, 97, 117, 100, 34,
  44, 34, 80, 104, 111, 110, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34,
  92, 110, 60, 98, 62, 83, 116, 97, 114, 116, 105, 110, 103, 32, 112, 97,
  114, 97, 109, 101, 116, 101, 114, 115, 32, 58, 60, 47, 98, 62, 34, 125,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 105, 122, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 51, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 97, 110, 103, 108, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 55, 44, 48, 44, 51, 54,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 97, 110,
  103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 49, 44, 48,
  44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90,
  45, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50,
  49, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 70, 111, 118, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 53,
  44, 49, 44, 57, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  88, 45, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 89, 45, 108, 105, 103, 104, 116, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 45, 108, 105, 103, 104,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 45, 49, 48, 48, 44, 45,
  49, 48, 48, 44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 112, 101, 99, 117, 108, 97, 114, 32, 108, 105, 103, 104, 116, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 101,
  99, 117, 108, 97, 114, 32, 115, 104, 105, 110, 105, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 44, 48, 44, 51, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 123, 34, 92, 110, 60, 98, 62, 69, 110, 100, 105,
  110, 103, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 58, 60,
  47, 98, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44,
  48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45,
  97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 55,
  44, 48, 44, 49, 52, 52, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 89, 45, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 52, 48, 49, 44, 48, 44, 49, 52, 52, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 90, 45, 97, 110, 103, 108, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 50, 49, 44, 48, 44, 49, 52, 52, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 111, 118, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 52, 53, 44, 49, 44, 57, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 108, 105, 103, 104, 116,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 48, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45,
  108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 90, 45, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 45, 49, 48, 48, 44, 45, 49, 48, 48, 44, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 101, 99, 117, 108, 97,
  114, 32, 108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 112, 101, 99, 117, 108, 97, 114, 32, 115,
  104, 105, 110, 105, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 55, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47,
  50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 105,
  109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 32, 58, 10, 45,
  105, 102, 32, 36, 51, 32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34,
  36, 52, 47, 103, 109, 105, 99, 95, 105, 109, 97, 103, 101, 111, 98, 106,
  101, 99, 116, 51, 100, 46, 112, 110, 103, 34, 32, 45, 101, 108, 115, 101,
  32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 34, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 105, 109, 97, 103, 101,
  111, 98, 106, 101, 99, 116, 51, 100, 32, 34, 95, 34, 44, 36, 53, 10,
  45, 97, 110, 105, 109, 97, 116, 101, 32, 103, 105, 109, 112, 95, 114, 101,
  110, 100, 101, 114, 51, 100, 44, 34, 36, 123, 54, 45, 55, 125, 44, 36,
  123, 57, 45, 49, 56, 125, 44, 36, 56, 34, 44, 92, 10, 34, 36, 123,
  54, 45, 55, 125, 44, 36, 123, 49, 57, 45, 50, 56, 125, 44, 36, 56,
  34, 44, 36, 49, 44, 36, 50, 44, 64, 123, 45, 113, 117, 111, 116, 101,
  92, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 125, 10, 103, 105, 109,
  112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 105, 109, 97, 103, 101, 111,
  98, 106, 101, 99, 116, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 10, 45, 95,
  103, 105, 109, 112, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116,
  51, 100, 32, 34, 95, 112, 114, 101, 118, 105, 101, 119, 95, 34, 44, 36,
  53, 10, 45, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 103, 105, 109, 112, 95, 114, 101, 110,
  100, 101, 114, 51, 100, 44, 36, 119, 34, 44, 34, 36, 104, 34, 44, 36,
  123, 57, 45, 49, 56, 125, 44, 36, 56, 34, 44, 92, 10, 36, 119, 34,
  44, 34, 36, 104, 34, 44, 36, 123, 49, 57, 45, 50, 56, 125, 44, 36,
  56, 34, 44, 48, 44, 36, 119, 44, 36, 104, 10, 35, 64, 103, 105, 109,
  112, 32, 51, 100, 32, 116, 101, 120, 116, 32, 112, 111, 105, 110, 116, 99,
  108, 111, 117, 100, 32, 58, 32, 103, 105, 109, 112, 95, 116, 101, 120, 116,
  95, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 51, 100, 44, 32, 103,
  105, 109, 112, 95, 116, 101, 120, 116, 95, 112, 111, 105, 110, 116, 99, 108,
  111, 117, 100, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 70, 114, 97, 109, 101, 115, 32, 61, 32,
  95, 105, 110, 116, 40, 54, 52, 44, 49, 44, 50, 53, 54, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 49, 115, 116, 32, 116, 101, 120, 116,
  32, 61, 32, 116, 101, 120, 116, 40, 34, 71, 39, 77, 73, 67, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 50, 110, 100, 32, 116, 101,
  120, 116, 32, 61, 32, 116, 101, 120, 116, 40, 34, 82, 111, 99, 107, 115,
  33, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 48,
  48, 44, 50, 50, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 66, 97, 99, 107, 103, 114, 111, 117, 110, 100, 32, 61,
  32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 88, 45, 115, 104, 97, 100, 111, 119, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 50, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 89, 45, 115, 104, 97, 100, 111, 119, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 50, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 104, 97, 100, 111, 119, 32, 115, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  116, 97, 116, 105, 111, 110, 97, 114, 121, 32, 102, 114, 97, 109, 101, 115,
  32, 61, 32, 95, 105, 110, 116, 40, 49, 57, 44, 49, 44, 51, 50, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 50, 47, 48, 57, 47, 48, 49, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 116, 101,
  120, 116, 95, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 51, 100, 32,
  58, 10, 87, 61, 123, 119, 125, 32, 72, 61, 123, 104, 125, 32, 77, 61,
  123, 114, 111, 117, 110, 100, 40, 49, 46, 53, 42, 109, 97, 120, 40, 119,
  44, 104, 41, 41, 125, 32, 45, 114, 109, 10, 45, 116, 101, 120, 116, 95,
  112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 51, 100, 32, 34, 36, 50,
  34, 44, 34, 36, 51, 34, 44, 36, 52, 10, 45, 99, 111, 108, 51, 100,
  91, 45, 49, 93, 32, 36, 123, 53, 45, 55, 125, 32, 45, 42, 51, 100,
  91, 45, 49, 93, 32, 123, 48, 46, 55, 42, 36, 77, 125, 10, 45, 102,
  51, 100, 32, 52, 48, 48, 48, 32, 45, 100, 98, 51, 100, 32, 48, 32,
  45, 109, 51, 100, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 10,
  45, 114, 112, 114, 111, 103, 114, 101, 115, 115, 32, 123, 54, 48, 42, 36,
  62, 47, 36, 49, 125, 10, 97, 110, 103, 108, 101, 61, 123, 36, 62, 42,
  51, 54, 48, 47, 36, 49, 125, 10, 45, 45, 114, 51, 100, 91, 48, 93,
  32, 49, 44, 48, 44, 49, 44, 36, 97, 110, 103, 108, 101, 10, 36, 77,
  44, 36, 77, 44, 49, 44, 51, 44, 45, 49, 32, 45, 111, 98, 106, 101,
  99, 116, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 53, 48,
  37, 44, 53, 48, 37, 44, 48, 44, 49, 32, 45, 114, 109, 91, 45, 50,
  93, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 48, 93, 32, 45,
  97, 32, 122, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 45, 49,
  32, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 115, 32, 122, 32, 45,
  114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 32, 48, 44,
  48, 44, 45, 49, 44, 45, 49, 44, 45, 49, 44, 50, 53, 53, 44, 48,
  44, 48, 44, 48, 44, 48, 10, 45, 105, 102, 32, 36, 49, 49, 32, 78,
  61, 64, 35, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 32, 45, 114, 112, 114, 111, 103, 114, 101, 115, 115,
  32, 123, 54, 48, 43, 52, 48, 42, 36, 62, 47, 36, 78, 125, 10, 45,
  105, 91, 48, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 52, 32, 45, 102, 99, 91, 48, 93, 32, 36, 123, 56, 45, 49, 49,
  125, 32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93,
  32, 51, 44, 51, 32, 45, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91,
  45, 49, 93, 32, 45, 98, 91, 45, 50, 44, 45, 49, 93, 32, 36, 49,
  52, 37, 32, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 10,
  45, 106, 91, 48, 93, 32, 91, 45, 49, 93, 44, 36, 49, 50, 37, 44,
  36, 49, 51, 37, 44, 48, 44, 48, 44, 49, 44, 91, 45, 50, 93, 44,
  50, 53, 53, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  98, 108, 101, 110, 100, 32, 97, 108, 112, 104, 97, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 87, 62, 36, 72, 125, 32, 45, 114, 50, 100, 120,
  32, 36, 87, 32, 45, 101, 108, 115, 101, 32, 45, 114, 50, 100, 121, 32,
  36, 72, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  49, 53, 62, 49, 125, 10, 45, 105, 91, 123, 105, 110, 116, 40, 36, 49,
  47, 50, 41, 125, 93, 32, 91, 123, 105, 110, 116, 40, 36, 49, 47, 50,
  41, 125, 93, 120, 123, 36, 49, 53, 45, 49, 125, 10, 45, 105, 91, 48,
  93, 32, 91, 48, 93, 120, 123, 36, 49, 53, 45, 49, 125, 10, 45, 101,
  110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 116, 101, 120, 116, 95, 112,
  111, 105, 110, 116, 99, 108, 111, 117, 100, 51, 100, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 116, 101, 120, 116,
  95, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 51, 100, 32, 52, 44,
  34, 36, 50, 34, 44, 34, 36, 51, 34, 44, 36, 52, 44, 36, 123, 53,
  45, 55, 125, 44, 36, 123, 56, 45, 49, 49, 125, 44, 36, 123, 49, 50,
  45, 49, 52, 125, 44, 49, 32, 45, 100, 114, 103, 98, 97, 10, 45, 102,
  114, 97, 109, 101, 32, 49, 44, 49, 44, 48, 32, 45, 97, 112, 112, 101,
  110, 100, 95, 116, 105, 108, 101, 115, 32, 50, 44, 50, 10, 35, 64, 103,
  105, 109, 112, 32, 51, 100, 32, 116, 105, 108, 101, 115, 32, 58, 32, 103,
  105, 109, 112, 95, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 51, 100,
  44, 32, 103, 105, 109, 112, 95, 116, 114, 97, 110, 115, 105, 116, 105, 111,
  110, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 116, 101, 114, 45, 102, 114,
  97, 109, 101, 115, 32, 61, 32, 95, 105, 110, 116, 40, 49, 48, 44, 51,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88,
  45, 116, 105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 56, 44, 49,
  44, 54, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45,
  116, 105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 56, 44, 49, 44,
  54, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 114,
  111, 116, 97, 116, 105, 111, 110, 32, 61, 32, 116, 101, 120, 116, 40, 34,
  49, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 114,
  111, 116, 97, 116, 105, 111, 110, 32, 61, 32, 116, 101, 120, 116, 40, 34,
  49, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 45, 114,
  111, 116, 97, 116, 105, 111, 110, 32, 61, 32, 116, 101, 120, 116, 40, 34,
  48, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 111, 99,
  97, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 56, 48, 48, 44,
  49, 48, 48, 44, 50, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 69, 110, 97, 98, 108, 101, 32, 97, 110, 116, 105, 97, 108,
  105, 97, 115, 105, 110, 103, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 115, 109, 97, 108, 108,
  62, 60, 98, 62, 78, 111, 116, 101, 58, 60, 47, 98, 62, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 84, 104, 105, 115, 32, 102, 105, 108, 116,
  101, 114, 32, 110, 101, 101, 100, 115, 32, 116, 119, 111, 32, 108, 97, 121,
  101, 114, 115, 32, 116, 111, 32, 119, 111, 114, 107, 32, 112, 114, 111, 112,
  101, 114, 108, 121, 46, 32, 83, 101, 116, 32, 116, 104, 101, 32, 60, 105,
  62, 73, 110, 112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 60, 47, 105,
  62, 32, 111, 112, 116, 105, 111, 110, 32, 116, 111, 32, 104, 97, 110, 100,
  108, 101, 32, 109, 117, 108, 116, 105, 112, 108, 101, 32, 105, 110, 112, 117,
  116, 32, 108, 97, 121, 101, 114, 115, 46, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 60, 47, 115, 109, 97, 108, 108, 62, 34, 125, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84,
  115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 50,
  47, 48, 56, 47, 49, 51, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 116, 114, 97, 110, 115,
  105, 116, 105, 111, 110, 51, 100, 32, 58, 10, 45, 102, 51, 100, 32, 36,
  55, 10, 45, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 51, 100, 32,
  36, 49, 44, 36, 50, 44, 36, 51, 44, 34, 36, 52, 34, 44, 34, 36,
  53, 34, 44, 34, 36, 54, 34, 44, 36, 56, 10, 103, 105, 109, 112, 95,
  116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 51, 100, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 102, 51, 100, 32, 36, 55, 10, 45,
  105, 102, 32, 123, 64, 35, 61, 61, 49, 125, 32, 45, 114, 101, 116, 117,
  114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 107, 91, 48, 44, 49,
  93, 32, 45, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 51, 100, 32,
  52, 44, 36, 50, 44, 36, 51, 44, 34, 36, 52, 34, 44, 34, 36, 53,
  34, 44, 34, 36, 54, 34, 44, 36, 56, 10, 45, 107, 91, 49, 44, 50,
  93, 10, 45, 114, 91, 48, 93, 32, 53, 48, 37, 44, 49, 48, 48, 37,
  44, 49, 44, 49, 48, 48, 37, 44, 48, 10, 45, 114, 91, 49, 93, 32,
  53, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 48, 48, 37, 44,
  48, 44, 48, 44, 49, 10, 45, 97, 32, 120, 10, 45, 108, 105, 110, 101,
  32, 53, 48, 37, 44, 48, 44, 53, 48, 37, 44, 49, 48, 48, 37, 44,
  49, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 10, 35, 64, 103, 105,
  109, 112, 32, 66, 38, 97, 109, 112, 59, 87, 32, 112, 101, 110, 99, 105,
  108, 32, 91, 97, 110, 105, 109, 97, 116, 101, 100, 93, 32, 58, 32, 103,
  105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 112, 101, 110, 99,
  105, 108, 98, 119, 44, 32, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97,
  116, 101, 95, 112, 101, 110, 99, 105, 108, 98, 119, 95, 112, 114, 101, 118,
  105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  70, 114, 97, 109, 101, 115, 32, 61, 32, 95, 105, 110, 116, 40, 49, 48,
  44, 50, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 79, 117, 116, 112, 117, 116, 32, 102, 114, 97, 109, 101, 115, 32, 61,
  32, 95, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 102, 105, 108, 101, 115, 32,
  61, 32, 95, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 102, 111, 108, 100, 101,
  114, 32, 61, 32, 95, 102, 111, 108, 100, 101, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 123, 34, 92, 110, 60, 98, 62, 83, 116, 97, 114, 116, 105, 110,
  103, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 58, 60, 47,
  98, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 101,
  110, 99, 105, 108, 32, 116, 121, 112, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 50, 46, 51, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 48, 48, 44, 48, 44, 50, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 123, 34, 92, 110, 60, 98, 62, 69, 110, 100, 105,
  110, 103, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 58, 60,
  47, 98, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80,
  101, 110, 99, 105, 108, 32, 116, 121, 112, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 51, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 54, 48, 44, 48, 44, 50, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 97, 110,
  105, 109, 97, 116, 101, 95, 112, 101, 110, 99, 105, 108, 98, 119, 32, 58,
  10, 45, 105, 102, 32, 36, 51, 32, 102, 105, 108, 101, 110, 97, 109, 101,
  61, 34, 36, 52, 47, 103, 109, 105, 99, 95, 112, 101, 110, 99, 105, 108,
  98, 119, 46, 112, 110, 103, 34, 32, 45, 101, 108, 115, 101, 32, 102, 105,
  108, 101, 110, 97, 109, 101, 61, 34, 34, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 97, 110, 105, 109, 97, 116, 101, 32, 112, 101, 110, 99, 105, 108,
  98, 119, 44, 34, 36, 123, 53, 45, 54, 125, 34, 44, 92, 10, 34, 36,
  123, 55, 45, 56, 125, 34, 44, 36, 49, 44, 36, 50, 44, 64, 123, 45,
  113, 117, 111, 116, 101, 92, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101,
  125, 10, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 112,
  101, 110, 99, 105, 108, 98, 119, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 112, 101, 110, 99, 105, 108, 98, 119,
  44, 34, 36, 123, 53, 45, 54, 125, 34, 44, 92, 10, 34, 36, 123, 55,
  45, 56, 125, 34, 10, 35, 64, 103, 105, 109, 112, 32, 66, 38, 97, 109,
  112, 59, 87, 32, 115, 116, 101, 110, 99, 105, 108, 32, 91, 97, 110, 105,
  109, 97, 116, 101, 100, 93, 32, 58, 32, 103, 105, 109, 112, 95, 97, 110,
  105, 109, 97, 116, 101, 95, 115, 116, 101, 110, 99, 105, 108, 98, 119, 44,
  32, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 115, 116,
  101, 110, 99, 105, 108, 98, 119, 95, 112, 114, 101, 118, 105, 101, 119, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 114, 97, 109,
  101, 115, 32, 61, 32, 95, 105, 110, 116, 40, 49, 48, 44, 50, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116,
  112, 117, 116, 32, 102, 114, 97, 109, 101, 115, 32, 61, 32, 95, 98, 111,
  111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79,
  117, 116, 112, 117, 116, 32, 102, 105, 108, 101, 115, 32, 61, 32, 95, 98,
  111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  79, 117, 116, 112, 117, 116, 32, 102, 111, 108, 100, 101, 114, 32, 61, 32,
  95, 102, 111, 108, 100, 101, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34,
  92, 110, 60, 98, 62, 83, 116, 97, 114, 116, 105, 110, 103, 32, 112, 97,
  114, 97, 109, 101, 116, 101, 114, 115, 32, 58, 60, 47, 98, 62, 34, 125,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101, 32, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 48, 44, 48, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 51, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 123, 34, 92, 110, 60, 98, 62, 69, 110, 100, 105, 110, 103,
  32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 58, 60, 47, 98,
  62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103,
  101, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 48, 44, 48, 44, 51, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 48, 44, 51, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118,
  105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50,
  51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62,
  50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 97,
  110, 105, 109, 97, 116, 101, 95, 115, 116, 101, 110, 99, 105, 108, 98, 119,
  32, 58, 10, 45, 105, 102, 32, 36, 51, 32, 102, 105, 108, 101, 110, 97,
  109, 101, 61, 34, 36, 52, 47, 103, 109, 105, 99, 95, 115, 116, 101, 110,
  99, 105, 108, 98, 119, 46, 112, 110, 103, 34, 32, 45, 101, 108, 115, 101,
  32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 34, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 97, 110, 105, 109, 97, 116, 101, 32, 115, 116, 101,
  110, 99, 105, 108, 98, 119, 44, 34, 36, 123, 53, 45, 54, 125, 34, 44,
  92, 10, 34, 36, 123, 55, 45, 56, 125, 34, 44, 36, 49, 44, 36, 50,
  44, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 36, 102, 105, 108, 101,
  110, 97, 109, 101, 125, 10, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97,
  116, 101, 95, 115, 116, 101, 110, 99, 105, 108, 98, 119, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 97, 110, 105,
  109, 97, 116, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 115, 116, 101,
  110, 99, 105, 108, 98, 119, 44, 34, 36, 123, 53, 45, 54, 125, 34, 44,
  92, 10, 34, 36, 123, 55, 45, 56, 125, 34, 10, 35, 64, 103, 105, 109,
  112, 32, 67, 97, 114, 116, 111, 111, 110, 32, 91, 97, 110, 105, 109, 97,
  116, 101, 100, 93, 32, 58, 32, 103, 105, 109, 112, 95, 97, 110, 105, 109,
  97, 116, 101, 95, 99, 97, 114, 116, 111, 111, 110, 44, 32, 103, 105, 109,
  112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 99, 97, 114, 116, 111, 111,
  110, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 70, 114, 97, 109, 101, 115, 32, 61, 32, 95,
  105, 110, 116, 40, 49, 48, 44, 50, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 102, 114,
  97, 109, 101, 115, 32, 61, 32, 95, 98, 111, 111, 108, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32,
  102, 105, 108, 101, 115, 32, 61, 32, 95, 98, 111, 111, 108, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116,
  32, 102, 111, 108, 100, 101, 114, 32, 61, 32, 95, 102, 111, 108, 100, 101,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 92, 110, 60, 98, 62, 71,
  108, 111, 98, 97, 108, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115,
  32, 58, 60, 47, 98, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 111, 108, 111, 114, 32, 113, 117, 97, 110, 116, 105, 122, 97,
  116, 105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 52, 44, 50, 44, 50,
  53, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 92, 110, 60, 98, 62, 83,
  116, 97, 114, 116, 105, 110, 103, 32, 112, 97, 114, 97, 109, 101, 116, 101,
  114, 115, 32, 58, 60, 47, 98, 62, 34, 125, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 50, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 114, 112, 101, 110,
  105, 110, 103, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 48, 44,
  48, 44, 52, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  69, 100, 103, 101, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 49, 44, 51, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101, 32, 116, 104,
  105, 99, 107, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 111, 108, 111, 114, 32, 115, 116, 114, 101, 110, 103, 116, 104,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 53, 44, 48, 44, 51,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 123, 34, 92, 110, 60, 98, 62, 69, 110, 100,
  105, 110, 103, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 58,
  60, 47, 98, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 51, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 104, 97, 114, 112, 101, 110, 105, 110, 103, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 50, 48, 48, 44, 48, 44, 52, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101, 32, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 48, 44, 49, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 69, 100, 103, 101, 32, 116, 104, 105, 99, 107, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 49, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111,
  114, 32, 115, 116, 114, 101, 110, 103, 116, 104, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 46, 53, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49,
  50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101,
  95, 99, 97, 114, 116, 111, 111, 110, 32, 58, 10, 45, 105, 102, 32, 36,
  51, 32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 36, 52, 47, 103,
  109, 105, 99, 95, 99, 97, 114, 116, 111, 111, 110, 46, 112, 110, 103, 34,
  32, 45, 101, 108, 115, 101, 32, 102, 105, 108, 101, 110, 97, 109, 101, 61,
  34, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 110, 105, 109, 97,
  116, 101, 32, 99, 97, 114, 116, 111, 111, 110, 44, 34, 36, 123, 54, 45,
  49, 48, 125, 44, 36, 53, 34, 44, 92, 10, 34, 36, 123, 49, 49, 45,
  49, 53, 125, 44, 36, 53, 34, 44, 36, 49, 44, 36, 50, 44, 64, 123,
  45, 113, 117, 111, 116, 101, 92, 32, 36, 102, 105, 108, 101, 110, 97, 109,
  101, 125, 10, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95,
  99, 97, 114, 116, 111, 111, 110, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 99, 97, 114, 116, 111, 111, 110, 44,
  34, 36, 123, 54, 45, 49, 48, 125, 44, 36, 53, 34, 44, 92, 10, 34,
  36, 123, 49, 49, 45, 49, 53, 125, 44, 36, 53, 34, 10, 35, 64, 103,
  105, 109, 112, 32, 69, 100, 103, 101, 115, 32, 111, 110, 32, 102, 105, 114,
  101, 32, 58, 32, 103, 105, 109, 112, 95, 102, 105, 114, 101, 95, 101, 100,
  103, 101, 115, 44, 32, 103, 105, 109, 112, 95, 102, 105, 114, 101, 95, 101,
  100, 103, 101, 115, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 44, 48, 44, 51, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 116, 116, 101, 110, 117, 97,
  116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 50,
  53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 53, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 50, 53, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 117, 109, 98, 101, 114, 32, 111, 102, 32, 102,
  114, 97, 109, 101, 115, 32, 61, 32, 95, 105, 110, 116, 40, 50, 48, 44,
  49, 44, 57, 57, 57, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 116, 97, 114, 116, 105, 110, 103, 32, 102, 114, 97, 109, 101, 32, 61,
  32, 105, 110, 116, 40, 50, 48, 44, 48, 44, 49, 57, 57, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 70, 114, 97, 109, 101, 32, 115, 107,
  105, 112, 32, 61, 32, 95, 105, 110, 116, 40, 48, 44, 48, 44, 50, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 68, 117,
  112, 108, 105, 99, 97, 116, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48, 55, 47,
  48, 54, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 102, 105, 114, 101, 95, 101, 100, 103, 101,
  115, 32, 58, 10, 45, 102, 105, 114, 101, 95, 101, 100, 103, 101, 115, 32,
  36, 123, 49, 45, 55, 125, 32, 45, 114, 118, 10, 103, 105, 109, 112, 95,
  102, 105, 114, 101, 95, 101, 100, 103, 101, 115, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 102, 105, 114, 101, 95,
  101, 100, 103, 101, 115, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36,
  52, 44, 49, 44, 36, 54, 44, 48, 34, 44, 36, 45, 49, 10, 35, 64,
  103, 105, 109, 112, 32, 69, 100, 103, 101, 115, 32, 91, 97, 110, 105, 109,
  97, 116, 101, 100, 93, 32, 58, 32, 103, 105, 109, 112, 95, 97, 110, 105,
  109, 97, 116, 101, 95, 101, 100, 103, 101, 115, 44, 32, 103, 105, 109, 112,
  95, 97, 110, 105, 109, 97, 116, 101, 95, 101, 100, 103, 101, 115, 95, 112,
  114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 70, 114, 97, 109, 101, 115, 32, 61, 32, 95, 105, 110, 116,
  40, 49, 48, 44, 50, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 102, 114, 97, 109, 101,
  115, 32, 61, 32, 95, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 102, 105, 108,
  101, 115, 32, 61, 32, 95, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 102, 111,
  108, 100, 101, 114, 32, 61, 32, 95, 102, 111, 108, 100, 101, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 123, 34, 92, 110, 60, 98, 62, 71, 108, 111, 98,
  97, 108, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 58, 60,
  47, 98, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  101, 103, 97, 116, 105, 118, 101, 32, 99, 111, 108, 111, 114, 115, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 92,
  110, 60, 98, 62, 83, 116, 97, 114, 116, 105, 110, 103, 32, 112, 97, 114,
  97, 109, 101, 116, 101, 114, 115, 32, 58, 60, 47, 98, 62, 34, 125, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103,
  101, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 48, 44, 48, 44, 51, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 123, 34, 92, 110, 60, 98, 62, 69, 110, 100, 105, 110, 103, 32, 112,
  97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 58, 60, 47, 98, 62, 34,
  125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69,
  100, 103, 101, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 51, 48, 44, 48, 44, 51, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65,
  117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32,
  84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59,
  60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49,
  48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 97, 110, 105, 109,
  97, 116, 101, 95, 101, 100, 103, 101, 115, 32, 58, 10, 45, 105, 102, 32,
  36, 51, 32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 36, 52, 47,
  103, 109, 105, 99, 95, 101, 100, 103, 101, 115, 46, 112, 110, 103, 34, 32,
  45, 101, 108, 115, 101, 32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34,
  34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 110, 105, 109, 97, 116,
  101, 32, 103, 105, 109, 112, 95, 101, 100, 103, 101, 115, 44, 34, 36, 123,
  54, 45, 55, 125, 44, 36, 53, 34, 44, 92, 10, 34, 36, 123, 56, 45,
  57, 125, 44, 36, 53, 34, 44, 36, 49, 44, 36, 50, 44, 64, 123, 45,
  113, 117, 111, 116, 101, 92, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101,
  125, 10, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 101,
  100, 103, 101, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 103, 105, 109, 112, 95, 101, 100, 103, 101, 115, 44,
  34, 36, 123, 54, 45, 55, 125, 44, 36, 53, 34, 44, 92, 10, 34, 36,
  123, 56, 45, 57, 125, 44, 36, 53, 34, 10, 35, 64, 103, 105, 109, 112,
  32, 76, 97, 118, 97, 32, 108, 97, 109, 112, 32, 58, 32, 103, 105, 109,
  112, 95, 108, 97, 118, 97, 108, 97, 109, 112, 98, 119, 44, 32, 103, 105,
  109, 112, 95, 108, 97, 118, 97, 108, 97, 109, 112, 98, 119, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 117, 109, 98, 101, 114, 32, 111, 102, 32, 107, 101, 121, 45,
  102, 114, 97, 109, 101, 115, 32, 61, 32, 95, 105, 110, 116, 40, 51, 44,
  50, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  117, 109, 98, 101, 114, 32, 111, 102, 32, 105, 110, 116, 101, 114, 45, 102,
  114, 97, 109, 101, 115, 32, 61, 32, 95, 105, 110, 116, 40, 51, 48, 44,
  50, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 109, 111, 111, 116, 104, 32, 108, 111, 111, 112, 105, 110, 103, 32, 61,
  32, 95, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101,
  115, 111, 108, 117, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 48, 44, 49, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 44, 48, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 95,
  102, 108, 111, 97, 116, 40, 48, 46, 48, 49, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 114, 97, 110, 115, 112, 97,
  114, 101, 110, 116, 32, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 32,
  61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48, 55, 47,
  48, 54, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 108, 97, 118, 97, 108, 97, 109, 112, 98,
  119, 32, 58, 10, 45, 105, 102, 32, 123, 33, 64, 35, 125, 32, 40, 50,
  53, 53, 59, 49, 48, 48, 94, 54, 52, 59, 49, 54, 94, 49, 50, 56,
  59, 48, 41, 32, 45, 114, 91, 45, 49, 93, 32, 53, 49, 50, 44, 53,
  49, 50, 44, 49, 44, 51, 44, 51, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 60,
  93, 10, 119, 61, 123, 119, 125, 32, 104, 61, 123, 104, 125, 10, 45, 45,
  114, 32, 36, 52, 37, 44, 36, 52, 37, 44, 49, 44, 49, 44, 48, 32,
  91, 45, 49, 93, 120, 123, 36, 49, 45, 49, 125, 32, 45, 114, 97, 110,
  100, 91, 94, 48, 93, 32, 48, 44, 49, 32, 45, 115, 116, 101, 110, 99,
  105, 108, 91, 94, 48, 93, 32, 36, 53, 44, 48, 10, 45, 105, 102, 32,
  36, 51, 32, 91, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 109,
  111, 114, 112, 104, 91, 94, 48, 93, 32, 36, 50, 44, 36, 54, 44, 48,
  10, 45, 115, 116, 101, 110, 99, 105, 108, 91, 94, 48, 93, 32, 36, 53,
  44, 48, 10, 45, 114, 91, 94, 48, 93, 32, 36, 119, 44, 36, 104, 44,
  49, 44, 49, 44, 51, 32, 45, 98, 91, 94, 48, 93, 32, 49, 48, 32,
  45, 103, 101, 91, 94, 48, 93, 32, 53, 48, 37, 32, 45, 42, 91, 94,
  48, 93, 32, 50, 53, 53, 10, 45, 114, 91, 94, 48, 93, 32, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 52, 32, 45, 106, 91, 94,
  48, 93, 32, 91, 48, 93, 32, 45, 114, 109, 91, 48, 93, 10, 45, 105,
  102, 32, 36, 51, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  45, 105, 102, 32, 123, 33, 36, 55, 125, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108,
  105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 110, 91, 45, 49,
  93, 32, 48, 44, 49, 32, 45, 42, 91, 94, 45, 49, 93, 32, 91, 45,
  49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 10, 103, 105,
  109, 112, 95, 108, 97, 118, 97, 108, 97, 109, 112, 98, 119, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 108, 97,
  118, 97, 108, 97, 109, 112, 98, 119, 32, 50, 44, 50, 44, 49, 44, 36,
  52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 32, 45, 107, 91, 48, 93,
  10, 35, 64, 103, 105, 109, 112, 32, 76, 105, 115, 115, 97, 106, 111, 117,
  115, 32, 91, 97, 110, 105, 109, 97, 116, 101, 100, 93, 32, 58, 32, 103,
  105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 108, 105, 115, 115,
  97, 106, 111, 117, 115, 44, 32, 103, 105, 109, 112, 95, 97, 110, 105, 109,
  97, 116, 101, 95, 108, 105, 115, 115, 97, 106, 111, 117, 115, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 70, 114, 97, 109, 101, 115, 32, 61, 32, 95, 105, 110, 116, 40,
  49, 48, 44, 50, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 97, 115, 32, 102, 114, 97,
  109, 101, 115, 32, 61, 32, 95, 98, 111, 111, 108, 40, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 97,
  115, 32, 102, 105, 108, 101, 115, 32, 61, 32, 95, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112,
  117, 116, 32, 102, 111, 108, 100, 101, 114, 32, 61, 32, 95, 102, 111, 108,
  100, 101, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 123, 34, 60, 98, 62, 83, 116, 97, 114, 116, 105,
  110, 103, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 58, 60,
  47, 98, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  101, 115, 111, 108, 117, 116, 105, 111, 110, 32, 61, 32, 105, 110, 116, 40,
  52, 48, 57, 54, 44, 50, 44, 56, 49, 57, 50, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 88, 45, 115, 105, 122, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 57, 44, 48, 44, 50, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 89, 45, 115, 105, 122, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 57, 44, 48, 44, 50, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 90, 45, 115, 105, 122, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 51, 44, 49, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 109, 117, 108, 116, 105, 112,
  108, 105, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 56, 44, 48,
  44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45,
  109, 117, 108, 116, 105, 112, 108, 105, 101, 114, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 55, 44, 48, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 90, 45, 109, 117, 108, 116, 105, 112, 108, 105, 101, 114,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 51, 50, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 111, 102, 102, 115,
  101, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 111, 102, 102,
  115, 101, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 45, 111, 102,
  102, 115, 101, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 97,
  110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89,
  45, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 90, 45, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 84, 104, 105, 99, 107, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 53, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 61, 32, 99, 111,
  108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 123, 34, 60, 98, 62, 69, 110, 100, 105, 110, 103, 32,
  112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 58, 60, 47, 98, 62,
  34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 115, 111,
  108, 117, 116, 105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 52, 48, 57,
  54, 44, 50, 44, 56, 49, 57, 50, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 88, 45, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 57, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 89, 45, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 57, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 90, 45, 115, 105, 122, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 51, 44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 88, 45, 109, 117, 108, 116, 105, 112, 108, 105, 101,
  114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 56, 44, 48, 44, 51, 50,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 109, 117, 108,
  116, 105, 112, 108, 105, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  55, 44, 48, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 90, 45, 109, 117, 108, 116, 105, 112, 108, 105, 101, 114, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 51, 50, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 88, 45, 111, 102, 102, 115, 101, 116, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 111, 102, 102, 115, 101, 116,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 45, 111, 102, 102, 115, 101,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 97, 110, 103, 108,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 51, 54,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 97, 110,
  103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 45,
  97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  84, 104, 105, 99, 107, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114,
  40, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118,
  105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50,
  51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62,
  50, 48, 49, 49, 47, 48, 52, 47, 49, 56, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 97,
  110, 105, 109, 97, 116, 101, 95, 108, 105, 115, 115, 97, 106, 111, 117, 115,
  32, 58, 10, 45, 105, 102, 32, 36, 51, 32, 102, 105, 108, 101, 110, 97,
  109, 101, 61, 34, 36, 52, 47, 103, 109, 105, 99, 95, 108, 105, 115, 115,
  97, 106, 111, 117, 115, 46, 112, 110, 103, 34, 32, 45, 101, 108, 115, 101,
  32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 34, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 97, 110, 105, 109, 97, 116, 101, 32, 103, 105, 109,
  112, 95, 108, 105, 115, 115, 97, 106, 111, 117, 115, 44, 34, 36, 123, 53,
  45, 50, 50, 125, 34, 44, 92, 10, 34, 36, 123, 50, 51, 45, 52, 48,
  125, 34, 44, 36, 49, 44, 36, 50, 44, 64, 123, 45, 113, 117, 111, 116,
  101, 92, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 125, 10, 103, 105,
  109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 108, 105, 115, 115, 97,
  106, 111, 117, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 103, 105, 109, 112, 95, 108, 105, 115, 115, 97, 106,
  111, 117, 115, 44, 34, 36, 123, 53, 45, 50, 50, 125, 34, 44, 92, 10,
  34, 36, 123, 50, 51, 45, 52, 48, 125, 34, 44, 48, 10, 35, 64, 103,
  105, 109, 112, 32, 77, 111, 114, 112, 104, 111, 108, 111, 103, 105, 99, 97,
  108, 32, 102, 105, 108, 116, 101, 114, 32, 91, 97, 110, 105, 109, 97, 116,
  101, 100, 93, 32, 58, 32, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97,
  116, 101, 95, 109, 111, 114, 112, 104, 111, 44, 32, 103, 105, 109, 112, 95,
  97, 110, 105, 109, 97, 116, 101, 95, 109, 111, 114, 112, 104, 111, 95, 112,
  114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 70, 114, 97, 109, 101, 115, 32, 61, 32, 95, 105, 110, 116,
  40, 49, 48, 44, 50, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 97, 115, 32, 102, 114,
  97, 109, 101, 115, 32, 61, 32, 95, 98, 111, 111, 108, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32,
  97, 115, 32, 102, 105, 108, 101, 115, 32, 61, 32, 95, 98, 111, 111, 108,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116,
  112, 117, 116, 32, 102, 111, 108, 100, 101, 114, 32, 61, 32, 95, 102, 111,
  108, 100, 101, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 92, 110, 60,
  98, 62, 71, 108, 111, 98, 97, 108, 32, 112, 97, 114, 97, 109, 101, 116,
  101, 114, 115, 32, 58, 60, 47, 98, 62, 34, 125, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 99, 116, 105, 111, 110, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 69, 114, 111, 115, 105, 111, 110, 34, 44, 34,
  68, 105, 108, 97, 116, 105, 111, 110, 34, 44, 34, 79, 112, 101, 110, 105,
  110, 103, 34, 44, 34, 67, 108, 111, 115, 105, 110, 103, 34, 44, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 34, 79, 114, 105, 103, 105, 110, 97,
  108, 32, 45, 32, 69, 114, 111, 115, 105, 111, 110, 34, 44, 34, 68, 105,
  108, 97, 116, 105, 111, 110, 32, 45, 32, 79, 114, 105, 103, 105, 110, 97,
  108, 34, 44, 34, 79, 114, 105, 103, 105, 110, 97, 108, 32, 45, 32, 79,
  112, 101, 110, 105, 110, 103, 34, 44, 34, 67, 108, 111, 115, 105, 110, 103,
  32, 45, 32, 79, 114, 105, 103, 105, 110, 97, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 73, 110, 118, 101, 114, 116, 32, 99, 111,
  108, 111, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108, 115,
  101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 83, 113,
  117, 97, 114, 101, 34, 44, 34, 79, 99, 116, 97, 103, 111, 110, 97, 108,
  34, 44, 34, 67, 105, 114, 99, 117, 108, 97, 114, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 123, 34, 92, 110, 60, 98, 62, 83, 116, 97, 114, 116, 105, 110,
  103, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 58, 60, 47,
  98, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 105,
  122, 101, 32, 61, 32, 105, 110, 116, 40, 53, 44, 49, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 123, 34, 92, 110, 60, 98, 62, 69, 110, 100,
  105, 110, 103, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 58,
  60, 47, 98, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 53, 48, 44, 50, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 109, 111, 114, 112, 104, 111,
  32, 58, 10, 45, 105, 102, 32, 36, 51, 32, 102, 105, 108, 101, 110, 97,
  109, 101, 61, 34, 36, 52, 47, 103, 109, 105, 99, 95, 109, 111, 114, 112,
  104, 111, 46, 112, 110, 103, 34, 32, 45, 101, 108, 115, 101, 32, 102, 105,
  108, 101, 110, 97, 109, 101, 61, 34, 34, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 97, 110, 105, 109, 97, 116, 101, 32, 103, 105, 109, 112, 95, 109,
  111, 114, 112, 104, 111, 44, 34, 36, 53, 44, 36, 56, 44, 36, 54, 44,
  36, 55, 44, 48, 44, 49, 34, 44, 92, 10, 34, 36, 53, 44, 36, 57,
  44, 36, 54, 44, 36, 55, 44, 48, 44, 49, 34, 44, 36, 49, 44, 36,
  50, 44, 64, 123, 45, 113, 117, 111, 116, 101, 92, 32, 36, 102, 105, 108,
  101, 110, 97, 109, 101, 125, 10, 103, 105, 109, 112, 95, 97, 110, 105, 109,
  97, 116, 101, 95, 109, 111, 114, 112, 104, 111, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97,
  116, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 103, 105, 109, 112, 95,
  109, 111, 114, 112, 104, 111, 44, 34, 36, 53, 44, 36, 56, 44, 36, 54,
  44, 36, 55, 44, 48, 44, 49, 34, 44, 92, 10, 34, 36, 53, 44, 36,
  57, 44, 36, 54, 44, 36, 55, 44, 48, 44, 49, 34, 10, 35, 64, 103,
  105, 109, 112, 32, 79, 98, 106, 101, 99, 116, 32, 97, 110, 105, 109, 97,
  116, 105, 111, 110, 32, 58, 32, 103, 105, 109, 112, 95, 116, 107, 95, 97,
  110, 105, 109, 97, 116, 101, 111, 98, 106, 101, 99, 116, 44, 32, 103, 105,
  109, 112, 95, 116, 107, 95, 97, 110, 105, 109, 97, 116, 101, 111, 98, 106,
  101, 99, 116, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  79, 98, 106, 101, 99, 116, 32, 109, 111, 116, 105, 111, 110, 58, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 109, 111, 116, 105,
  111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 48,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  89, 45, 109, 111, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 90, 45, 109, 111, 116, 105, 111, 110, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 48, 44, 53, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 67, 97, 109, 101, 114, 97, 32, 112, 111, 115, 105, 116, 105, 111,
  110, 58, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 97,
  109, 101, 114, 97, 32, 120, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 97, 109, 101, 114, 97, 32, 121, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 70, 114, 97, 109,
  101, 32, 115, 101, 116, 116, 105, 110, 103, 115, 58, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 70, 114, 97, 109, 101, 32, 115, 105, 122,
  101, 32, 61, 32, 105, 110, 116, 40, 52, 48, 48, 44, 53, 48, 44, 49,
  57, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 114,
  97, 109, 101, 115, 32, 61, 32, 105, 110, 116, 40, 50, 44, 50, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118,
  101, 114, 115, 101, 32, 109, 111, 116, 105, 111, 110, 32, 61, 32, 98, 111,
  111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 89, 111, 117, 114, 32, 109, 97, 115, 107, 32, 109, 117, 115,
  116, 32, 98, 101, 32, 112, 108, 97, 99, 101, 100, 32, 98, 101, 108, 111,
  119, 32, 121, 111, 117, 114, 32, 105, 109, 97, 103, 101, 46, 32, 83, 119,
  105, 116, 99, 104, 32, 105, 110, 112, 117, 116, 32, 108, 97, 121, 101, 114,
  115, 32, 116, 111, 32, 60, 105, 62, 60, 98, 62, 65, 99, 116, 105, 118,
  101, 32, 97, 110, 100, 32, 98, 101, 108, 111, 119, 60, 47, 98, 62, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 87, 111, 114, 107, 32, 111, 110, 32, 102, 114, 97, 109, 101,
  115, 101, 116, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 84, 111, 32, 117, 115,
  101, 32, 116, 104, 105, 115, 32, 111, 112, 116, 105, 111, 110, 32, 121, 111,
  117, 114, 32, 109, 97, 115, 107, 32, 109, 117, 115, 116, 32, 98, 101, 32,
  112, 108, 97, 99, 101, 100, 32, 98, 101, 108, 111, 119, 32, 121, 111, 117,
  114, 32, 102, 114, 97, 109, 101, 115, 46, 32, 83, 119, 105, 116, 99, 104,
  32, 105, 110, 112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 32, 116, 111,
  32, 60, 105, 62, 60, 98, 62, 65, 108, 108, 60, 47, 98, 62, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 65,
  100, 118, 97, 110, 99, 101, 100, 32, 115, 101, 116, 116, 105, 110, 103, 115,
  58, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97,
  114, 112, 101, 110, 32, 111, 98, 106, 101, 99, 116, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 69, 120, 112, 97, 110, 100, 32, 98, 97, 99, 107,
  103, 114, 111, 117, 110, 100, 32, 114, 101, 99, 111, 110, 115, 116, 114, 117,
  99, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  109, 111, 111, 116, 104, 101, 110, 32, 98, 97, 99, 107, 103, 114, 111, 117,
  110, 100, 32, 114, 101, 99, 111, 110, 115, 116, 114, 117, 99, 116, 105, 111,
  110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 100, 106, 117, 115, 116,
  32, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 32, 114, 101, 111, 110,
  115, 116, 114, 117, 99, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 44, 49, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66,
  108, 117, 101, 32, 115, 99, 114, 101, 101, 110, 32, 109, 111, 100, 101, 32,
  61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 76, 97, 121, 101, 114, 32, 115, 116, 97,
  99, 107, 32, 102, 111, 114, 32, 105, 109, 97, 103, 101, 115, 58, 32, 79,
  98, 106, 101, 99, 116, 32, 105, 109, 97, 103, 101, 32, 116, 111, 112, 44,
  32, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 32, 105, 109, 97, 103,
  101, 32, 98, 101, 108, 111, 119, 44, 32, 109, 97, 115, 107, 32, 98, 111,
  116, 116, 111, 109, 46, 32, 76, 97, 121, 101, 114, 32, 115, 116, 97, 99,
  107, 32, 102, 111, 114, 32, 102, 114, 97, 109, 101, 115, 101, 116, 115, 58,
  32, 70, 114, 97, 109, 101, 115, 101, 116, 32, 116, 111, 112, 44, 32, 111,
  98, 106, 101, 99, 116, 32, 105, 109, 97, 103, 101, 32, 98, 101, 108, 111,
  119, 44, 32, 109, 97, 115, 107, 32, 98, 111, 116, 116, 111, 109, 46, 32,
  83, 119, 105, 116, 99, 104, 32, 105, 110, 112, 117, 116, 32, 108, 97, 121,
  101, 114, 115, 32, 116, 111, 32, 60, 105, 62, 60, 98, 62, 65, 108, 108,
  60, 47, 98, 62, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 97, 109, 101, 114, 97, 32, 109,
  111, 116, 105, 111, 110, 32, 111, 110, 108, 121, 32, 61, 32, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 108,
  111, 115, 101, 117, 112, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44,
  49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 85, 115, 101, 32, 116, 104, 105, 115, 32, 111, 112, 116, 105,
  111, 110, 32, 119, 105, 116, 104, 111, 117, 116, 32, 109, 97, 115, 107, 32,
  108, 97, 121, 101, 114, 46, 32, 83, 119, 105, 116, 99, 104, 32, 105, 110,
  112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 32, 116, 111, 32, 60, 105,
  62, 60, 98, 62, 65, 99, 116, 105, 118, 101, 60, 47, 98, 62, 60, 47,
  105, 62, 32, 111, 114, 32, 60, 105, 62, 60, 98, 62, 65, 108, 108, 60,
  47, 98, 62, 60, 47, 105, 62, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 84, 111,
  109, 32, 75, 101, 105, 108, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 50, 47, 48, 52, 47, 48, 56, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110,
  107, 40, 34, 70, 105, 108, 116, 101, 114, 32, 101, 120, 112, 108, 97, 105,
  110, 101, 100, 32, 104, 101, 114, 101, 34, 44, 104, 116, 116, 112, 58, 47,
  47, 119, 119, 119, 46, 116, 107, 102, 105, 108, 116, 101, 114, 46, 98, 112,
  108, 97, 99, 101, 100, 46, 110, 101, 116, 47, 84, 75, 70, 105, 108, 116,
  101, 114, 37, 50, 48, 116, 117, 116, 111, 114, 105, 97, 108, 115, 37, 50,
  48, 97, 110, 105, 109, 97, 116, 101, 100, 37, 50, 48, 111, 98, 106, 101,
  99, 116, 115, 46, 104, 116, 109, 108, 41, 10, 103, 105, 109, 112, 95, 116,
  107, 95, 97, 110, 105, 109, 97, 116, 101, 111, 98, 106, 101, 99, 116, 32,
  58, 10, 45, 105, 102, 32, 123, 64, 35, 60, 61, 49, 125, 32, 45, 114,
  101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 49, 53, 61, 61, 48, 125, 10, 45, 116, 111, 95, 114, 103,
  98, 32, 45, 105, 102, 32, 123, 36, 57, 61, 61, 48, 125, 10, 45, 114,
  32, 123, 119, 42, 123, 36, 54, 47, 109, 97, 120, 40, 119, 44, 104, 41,
  125, 125, 44, 123, 104, 42, 123, 36, 54, 47, 109, 97, 120, 40, 119, 44,
  104, 41, 125, 125, 44, 49, 44, 123, 115, 125, 44, 54, 32, 45, 99, 32,
  48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36, 49, 52, 61, 61,
  48, 125, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116,
  104, 105, 110, 103, 91, 45, 49, 44, 45, 50, 93, 32, 45, 45, 103, 105,
  109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 48, 93,
  32, 45, 114, 118, 91, 48, 44, 49, 93, 10, 45, 98, 108, 117, 114, 95,
  120, 121, 91, 48, 93, 32, 36, 49, 49, 32, 45, 116, 50, 91, 48, 93,
  32, 36, 49, 51, 44, 50, 53, 54, 32, 45, 110, 91, 48, 93, 32, 48,
  44, 50, 53, 53, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 114, 101,
  112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 48, 93, 32, 49,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 48, 44, 48,
  44, 48, 44, 48, 10, 45, 98, 108, 117, 114, 95, 120, 121, 91, 48, 93,
  32, 36, 49, 50, 32, 45, 105, 110, 112, 97, 105, 110, 116, 91, 49, 93,
  32, 91, 48, 93, 10, 45, 114, 109, 91, 48, 93, 32, 45, 114, 118, 91,
  45, 49, 44, 45, 50, 93, 10, 45, 101, 108, 115, 101, 32, 45, 45, 103,
  105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 48,
  93, 32, 45, 114, 118, 91, 48, 44, 49, 93, 32, 45, 114, 118, 91, 45,
  49, 44, 45, 50, 93, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95,
  110, 111, 116, 104, 105, 110, 103, 91, 48, 93, 32, 45, 45, 103, 105, 109,
  112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 48, 93, 10,
  45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110,
  103, 91, 45, 51, 93, 32, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95,
  110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 116, 111, 95,
  103, 114, 97, 121, 91, 45, 49, 44, 45, 50, 93, 32, 45, 116, 50, 91,
  45, 49, 44, 45, 50, 93, 32, 49, 50, 56, 44, 50, 53, 54, 32, 45,
  110, 91, 45, 49, 44, 45, 50, 93, 32, 48, 44, 50, 53, 53, 10, 45,
  115, 91, 49, 93, 32, 99, 32, 45, 97, 91, 49, 44, 50, 44, 51, 44,
  45, 49, 93, 32, 99, 10, 45, 115, 91, 50, 93, 32, 99, 32, 45, 97,
  91, 50, 44, 51, 44, 52, 44, 45, 49, 93, 32, 99, 10, 45, 114, 118,
  91, 49, 44, 45, 49, 93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  114, 103, 98, 97, 91, 49, 44, 45, 49, 93, 10, 45, 114, 118, 91, 50,
  44, 45, 49, 93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 114, 103,
  98, 97, 91, 50, 44, 45, 49, 93, 10, 45, 116, 111, 95, 114, 103, 98,
  91, 49, 44, 50, 93, 10, 45, 101, 110, 100, 105, 102, 10, 100, 120, 61,
  123, 36, 49, 47, 36, 55, 125, 32, 100, 121, 61, 123, 36, 50, 47, 36,
  55, 125, 32, 100, 122, 61, 49, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  36, 55, 10, 45, 115, 104, 105, 102, 116, 91, 45, 49, 44, 45, 50, 93,
  32, 36, 100, 120, 37, 44, 36, 100, 121, 37, 10, 45, 105, 102, 32, 123,
  36, 51, 62, 61, 48, 125, 32, 100, 122, 61, 123, 36, 100, 122, 43, 123,
  123, 36, 51, 125, 47, 36, 55, 125, 125, 10, 45, 101, 108, 115, 101, 32,
  100, 122, 61, 123, 36, 100, 122, 45, 123, 123, 123, 49, 45, 123, 49, 48,
  46, 48, 49, 43, 36, 51, 125, 47, 49, 48, 125, 125, 47, 36, 55, 125,
  125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 103, 105, 109, 112, 95,
  122, 111, 111, 109, 91, 45, 49, 44, 45, 50, 93, 32, 36, 100, 122, 44,
  36, 52, 44, 36, 53, 44, 48, 10, 45, 116, 111, 95, 103, 114, 97, 121,
  91, 45, 49, 93, 32, 45, 116, 50, 91, 45, 49, 93, 32, 49, 50, 56,
  44, 50, 53, 54, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 32, 45, 116, 111, 95, 114, 103, 98, 91, 45, 50, 93, 10, 45, 115,
  91, 45, 50, 93, 32, 99, 32, 45, 97, 91, 45, 52, 44, 45, 51, 44,
  45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 105, 102, 32, 123, 36, 49,
  48, 33, 61, 48, 125, 32, 45, 117, 110, 115, 104, 97, 114, 112, 91, 45,
  49, 93, 32, 123, 36, 49, 48, 47, 53, 125, 44, 123, 36, 49, 48, 47,
  50, 125, 44, 48, 32, 45, 99, 117, 116, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 32, 32, 45, 101, 110, 100, 105, 102, 10, 45, 109, 118, 91,
  45, 49, 93, 32, 45, 51, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109,
  91, 45, 49, 44, 45, 50, 93, 32, 45, 114, 118, 32, 45, 114, 118, 91,
  45, 49, 44, 45, 50, 93, 10, 105, 110, 100, 101, 120, 61, 123, 45, 51,
  125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 55, 10, 45, 45, 103,
  105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45,
  50, 93, 32, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 32, 105, 110,
  100, 101, 120, 61, 123, 36, 105, 110, 100, 101, 120, 45, 49, 125, 10, 45,
  114, 118, 91, 45, 51, 44, 36, 105, 110, 100, 101, 120, 93, 32, 45, 99,
  111, 109, 112, 111, 115, 101, 95, 114, 103, 98, 97, 91, 45, 51, 44, 36,
  105, 110, 100, 101, 120, 93, 10, 45, 100, 111, 110, 101, 32, 45, 114, 109,
  91, 45, 50, 93, 32, 45, 105, 102, 32, 123, 36, 56, 61, 61, 49, 125,
  32, 45, 114, 118, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115,
  101, 10, 45, 105, 102, 32, 123, 36, 49, 52, 61, 61, 48, 125, 32, 102,
  114, 97, 109, 101, 115, 61, 123, 64, 35, 45, 49, 125, 32, 99, 111, 117,
  110, 116, 101, 114, 61, 123, 45, 53, 125, 10, 45, 45, 103, 105, 109, 112,
  95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 44, 45,
  50, 93, 10, 45, 45, 98, 108, 117, 114, 95, 120, 121, 91, 45, 49, 93,
  32, 36, 49, 49, 32, 45, 116, 50, 91, 45, 49, 93, 32, 36, 49, 51,
  44, 50, 53, 54, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 114, 101, 112, 108, 97,
  99, 101, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 49, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48,
  44, 48, 10, 45, 98, 108, 117, 114, 95, 120, 121, 91, 45, 49, 93, 32,
  36, 49, 50, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 102, 114, 97,
  109, 101, 115, 32, 45, 105, 110, 112, 97, 105, 110, 116, 91, 36, 99, 111,
  117, 110, 116, 101, 114, 93, 32, 91, 45, 49, 93, 10, 99, 111, 117, 110,
  116, 101, 114, 61, 123, 36, 99, 111, 117, 110, 116, 101, 114, 45, 49, 125,
  32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 45, 49, 44, 45, 52,
  93, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104,
  105, 110, 103, 91, 45, 49, 44, 45, 50, 93, 10, 45, 101, 108, 115, 101,
  32, 102, 114, 97, 109, 101, 115, 61, 123, 64, 35, 45, 50, 125, 32, 45,
  45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 49, 93, 10, 45, 115, 91,
  45, 51, 93, 32, 99, 32, 45, 97, 91, 45, 53, 44, 45, 52, 44, 45,
  51, 44, 45, 49, 93, 32, 99, 10, 45, 45, 116, 111, 95, 103, 114, 97,
  121, 91, 45, 49, 93, 32, 45, 45, 102, 99, 91, 45, 49, 93, 32, 48,
  44, 48, 44, 48, 10, 45, 114, 118, 91, 45, 49, 44, 45, 52, 93, 32,
  45, 99, 111, 109, 112, 111, 115, 101, 95, 114, 103, 98, 97, 91, 45, 49,
  44, 45, 52, 93, 32, 45, 109, 118, 91, 45, 49, 93, 32, 45, 51, 10,
  45, 101, 110, 100, 105, 102, 10, 99, 111, 117, 110, 116, 101, 114, 61, 123,
  45, 54, 125, 32, 100, 120, 61, 48, 32, 100, 121, 61, 48, 32, 100, 122,
  61, 49, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 102, 114, 97,
  109, 101, 115, 125, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110,
  111, 116, 104, 105, 110, 103, 91, 45, 49, 44, 45, 50, 93, 10, 45, 115,
  104, 105, 102, 116, 91, 45, 49, 44, 45, 50, 93, 32, 36, 100, 120, 37,
  44, 36, 100, 121, 37, 10, 45, 105, 102, 32, 123, 36, 51, 62, 61, 48,
  125, 32, 100, 122, 61, 123, 36, 100, 122, 43, 123, 123, 36, 51, 125, 47,
  36, 102, 114, 97, 109, 101, 115, 125, 125, 10, 45, 101, 108, 115, 101, 32,
  100, 122, 61, 123, 36, 100, 122, 45, 123, 123, 123, 49, 45, 123, 49, 48,
  46, 48, 49, 43, 36, 51, 125, 47, 49, 48, 125, 125, 47, 36, 102, 114,
  97, 109, 101, 115, 125, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45,
  103, 105, 109, 112, 95, 122, 111, 111, 109, 91, 45, 49, 44, 45, 50, 93,
  32, 36, 100, 122, 44, 36, 52, 44, 36, 53, 44, 48, 10, 45, 116, 111,
  95, 103, 114, 97, 121, 91, 45, 49, 93, 32, 45, 116, 50, 91, 45, 49,
  93, 32, 49, 50, 56, 44, 50, 53, 54, 32, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 32, 45, 116, 111, 95, 114, 103, 98, 91, 45,
  50, 93, 10, 45, 115, 91, 45, 50, 93, 32, 99, 32, 45, 97, 91, 45,
  52, 44, 45, 51, 44, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 105,
  102, 32, 123, 36, 49, 48, 33, 61, 48, 125, 32, 45, 117, 110, 115, 104,
  97, 114, 112, 91, 45, 49, 93, 32, 123, 36, 49, 48, 47, 53, 125, 44,
  123, 36, 49, 48, 47, 50, 125, 44, 48, 32, 45, 99, 117, 116, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 109, 118, 91, 45, 49, 93, 32, 36, 99, 111, 117, 110, 116, 101, 114,
  10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 114, 103, 98, 97, 91, 36,
  99, 111, 117, 110, 116, 101, 114, 44, 123, 36, 99, 111, 117, 110, 116, 101,
  114, 45, 49, 125, 93, 10, 100, 120, 61, 123, 36, 100, 120, 43, 123, 36,
  49, 47, 36, 102, 114, 97, 109, 101, 115, 125, 125, 32, 100, 121, 61, 123,
  36, 100, 121, 43, 123, 36, 50, 47, 36, 102, 114, 97, 109, 101, 115, 125,
  125, 10, 99, 111, 117, 110, 116, 101, 114, 61, 123, 36, 99, 111, 117, 110,
  116, 101, 114, 45, 49, 125, 10, 45, 114, 109, 91, 45, 49, 44, 45, 50,
  93, 10, 45, 100, 111, 110, 101, 32, 32, 45, 114, 109, 91, 45, 49, 44,
  45, 50, 44, 45, 51, 44, 48, 93, 10, 45, 101, 110, 100, 105, 102, 10,
  35, 99, 97, 109, 101, 114, 97, 32, 109, 111, 116, 105, 111, 110, 32, 111,
  110, 108, 121, 10, 45, 101, 108, 115, 101, 10, 45, 116, 111, 95, 114, 103,
  98, 32, 45, 105, 102, 32, 123, 36, 57, 61, 61, 48, 125, 10, 45, 114,
  32, 123, 119, 42, 123, 36, 54, 47, 109, 97, 120, 40, 119, 44, 104, 41,
  125, 125, 44, 123, 104, 42, 123, 36, 54, 47, 109, 97, 120, 40, 119, 44,
  104, 41, 125, 125, 44, 49, 44, 123, 115, 125, 44, 54, 32, 45, 99, 32,
  48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 100, 120, 61,
  48, 32, 100, 121, 61, 48, 32, 100, 122, 61, 49, 32, 45, 105, 102, 32,
  123, 36, 57, 61, 61, 48, 125, 32, 99, 111, 117, 110, 116, 101, 114, 61,
  36, 55, 32, 45, 101, 108, 115, 101, 32, 99, 111, 117, 110, 116, 101, 114,
  61, 123, 64, 35, 45, 49, 125, 32, 45, 101, 110, 100, 105, 102, 10, 105,
  110, 100, 101, 120, 61, 123, 45, 50, 125, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 36, 99, 111, 117, 110, 116, 101, 114, 10, 45, 105, 102, 32, 123,
  36, 57, 61, 61, 48, 125, 32, 45, 45, 103, 105, 109, 112, 95, 100, 111,
  95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 32, 45, 109, 118,
  91, 45, 49, 93, 32, 36, 105, 110, 100, 101, 120, 32, 45, 101, 110, 100,
  105, 102, 10, 100, 120, 61, 123, 36, 100, 120, 43, 123, 36, 49, 47, 36,
  55, 125, 125, 32, 100, 121, 61, 123, 36, 100, 121, 43, 123, 36, 50, 47,
  36, 55, 125, 125, 10, 45, 115, 104, 105, 102, 116, 91, 36, 105, 110, 100,
  101, 120, 93, 32, 36, 100, 120, 37, 44, 36, 100, 121, 37, 10, 45, 105,
  102, 32, 123, 36, 51, 62, 61, 48, 125, 32, 100, 122, 61, 123, 36, 100,
  122, 43, 123, 123, 36, 51, 125, 47, 36, 55, 125, 125, 10, 45, 101, 108,
  115, 101, 32, 100, 122, 61, 123, 36, 100, 122, 45, 123, 123, 123, 49, 45,
  123, 49, 48, 46, 48, 49, 43, 36, 51, 125, 47, 49, 48, 125, 125, 47,
  36, 55, 125, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109,
  112, 95, 122, 111, 111, 109, 91, 36, 105, 110, 100, 101, 120, 93, 32, 36,
  49, 54, 44, 36, 52, 44, 36, 53, 44, 48, 10, 45, 103, 105, 109, 112,
  95, 122, 111, 111, 109, 91, 36, 105, 110, 100, 101, 120, 93, 32, 36, 100,
  122, 44, 36, 52, 44, 36, 53, 44, 48, 10, 45, 105, 102, 32, 123, 36,
  49, 48, 33, 61, 48, 125, 32, 45, 117, 110, 115, 104, 97, 114, 112, 91,
  36, 105, 110, 100, 101, 120, 93, 32, 123, 36, 49, 48, 47, 53, 125, 44,
  123, 36, 49, 48, 47, 50, 125, 44, 48, 32, 45, 99, 117, 116, 91, 36,
  105, 110, 100, 101, 120, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110,
  100, 105, 102, 10, 105, 110, 100, 101, 120, 61, 123, 36, 105, 110, 100, 101,
  120, 45, 49, 125, 32, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123,
  36, 49, 54, 33, 61, 49, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 35, 112,
  114, 101, 118, 105, 101, 119, 32, 102, 117, 110, 99, 116, 105, 111, 110, 10,
  103, 105, 109, 112, 95, 116, 107, 95, 97, 110, 105, 109, 97, 116, 101, 111,
  98, 106, 101, 99, 116, 95, 112, 114, 101, 118, 105, 101, 119, 58, 10, 45,
  105, 102, 32, 123, 36, 49, 53, 61, 61, 48, 125, 32, 115, 116, 97, 114,
  116, 95, 120, 61, 123, 123, 120, 77, 47, 119, 125, 42, 49, 48, 48, 125,
  32, 115, 116, 97, 114, 116, 95, 121, 61, 123, 123, 121, 77, 47, 104, 125,
  42, 49, 48, 48, 125, 32, 45, 101, 108, 115, 101, 32, 115, 116, 97, 114,
  116, 95, 120, 61, 53, 48, 32, 115, 116, 97, 114, 116, 95, 121, 61, 53,
  48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 116,
  107, 95, 97, 110, 105, 109, 97, 116, 101, 111, 98, 106, 101, 99, 116, 32,
  36, 123, 49, 45, 54, 125, 44, 49, 44, 36, 123, 56, 45, 45, 49, 125,
  32, 45, 107, 91, 48, 93, 10, 45, 108, 105, 110, 101, 91, 48, 93, 32,
  123, 36, 49, 43, 36, 115, 116, 97, 114, 116, 95, 120, 125, 37, 44, 123,
  36, 50, 43, 36, 115, 116, 97, 114, 116, 95, 121, 45, 49, 48, 125, 37,
  44, 123, 36, 49, 43, 36, 115, 116, 97, 114, 116, 95, 120, 125, 37, 44,
  123, 36, 50, 43, 36, 115, 116, 97, 114, 116, 95, 121, 43, 49, 48, 125,
  37, 44, 49, 44, 50, 53, 53, 44, 48, 44, 48, 10, 45, 108, 105, 110,
  101, 91, 48, 93, 32, 123, 36, 49, 43, 36, 115, 116, 97, 114, 116, 95,
  120, 45, 49, 48, 125, 37, 44, 123, 36, 50, 43, 36, 115, 116, 97, 114,
  116, 95, 121, 125, 37, 44, 123, 36, 49, 43, 36, 115, 116, 97, 114, 116,
  95, 120, 43, 49, 48, 125, 37, 44, 123, 36, 50, 43, 36, 115, 116, 97,
  114, 116, 95, 121, 125, 37, 44, 49, 44, 50, 53, 53, 44, 48, 44, 48,
  10, 45, 108, 105, 110, 101, 91, 48, 93, 32, 123, 36, 52, 42, 49, 48,
  48, 125, 37, 44, 48, 37, 44, 123, 36, 52, 42, 49, 48, 48, 125, 37,
  44, 123, 123, 36, 53, 42, 49, 48, 48, 125, 45, 53, 125, 37, 44, 49,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 10, 45, 108, 105, 110, 101,
  91, 48, 93, 32, 123, 36, 52, 42, 49, 48, 48, 125, 37, 44, 123, 123,
  36, 53, 42, 49, 48, 48, 125, 43, 53, 125, 37, 44, 123, 36, 52, 42,
  49, 48, 48, 125, 37, 44, 49, 48, 48, 37, 44, 49, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 48, 10, 45, 108, 105, 110, 101, 91, 48, 93, 32,
  48, 37, 44, 123, 36, 53, 42, 49, 48, 48, 125, 37, 44, 123, 123, 36,
  52, 42, 49, 48, 48, 125, 45, 53, 125, 37, 44, 123, 36, 53, 42, 49,
  48, 48, 125, 37, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48,
  10, 45, 108, 105, 110, 101, 91, 48, 93, 32, 123, 123, 36, 52, 42, 49,
  48, 48, 125, 43, 53, 125, 37, 44, 123, 36, 53, 42, 49, 48, 48, 125,
  37, 44, 49, 48, 48, 37, 44, 123, 36, 53, 42, 49, 48, 48, 125, 37,
  44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 10, 35, 64, 103,
  105, 109, 112, 32, 80, 108, 97, 115, 109, 97, 32, 116, 114, 97, 110, 115,
  105, 116, 105, 111, 110, 32, 58, 32, 103, 105, 109, 112, 95, 116, 114, 97,
  110, 115, 105, 116, 105, 111, 110, 95, 112, 108, 97, 115, 109, 97, 44, 32,
  103, 105, 109, 112, 95, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 95,
  112, 108, 97, 115, 109, 97, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 114, 97, 109, 101,
  115, 32, 61, 32, 95, 105, 110, 116, 40, 51, 48, 44, 50, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 97, 108,
  101, 32, 61, 32, 105, 110, 116, 40, 53, 44, 48, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44,
  48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 115,
  109, 97, 108, 108, 62, 60, 98, 62, 78, 111, 116, 101, 58, 60, 47, 98,
  62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 105, 115, 32,
  102, 105, 108, 116, 101, 114, 32, 110, 101, 101, 100, 115, 32, 116, 119, 111,
  32, 108, 97, 121, 101, 114, 115, 32, 116, 111, 32, 119, 111, 114, 107, 32,
  112, 114, 111, 112, 101, 114, 108, 121, 46, 32, 83, 101, 116, 32, 116, 104,
  101, 32, 60, 105, 62, 73, 110, 112, 117, 116, 32, 108, 97, 121, 101, 114,
  115, 60, 47, 105, 62, 32, 111, 112, 116, 105, 111, 110, 32, 116, 111, 32,
  104, 97, 110, 100, 108, 101, 32, 109, 117, 108, 116, 105, 112, 108, 101, 32,
  105, 110, 112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 46, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118,
  105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50,
  51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62,
  50, 48, 49, 50, 47, 49, 49, 47, 48, 57, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 116,
  114, 97, 110, 115, 105, 116, 105, 111, 110, 95, 112, 108, 97, 115, 109, 97,
  32, 58, 10, 45, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 95, 112,
  108, 97, 115, 109, 97, 32, 36, 49, 44, 36, 50, 44, 36, 51, 37, 10,
  103, 105, 109, 112, 95, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 95,
  112, 108, 97, 115, 109, 97, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 105, 102, 32, 123, 64, 35, 61, 61, 49, 125, 32, 45, 114, 101,
  116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 107, 91, 48,
  44, 49, 93, 32, 45, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 95,
  112, 108, 97, 115, 109, 97, 32, 54, 44, 36, 50, 44, 36, 51, 37, 32,
  45, 107, 91, 49, 45, 45, 50, 93, 32, 45, 102, 114, 97, 109, 101, 32,
  49, 44, 49, 44, 48, 32, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105,
  108, 101, 115, 32, 44, 10, 35, 64, 103, 105, 109, 112, 32, 82, 111, 100,
  105, 108, 105, 117, 115, 32, 91, 97, 110, 105, 109, 97, 116, 101, 100, 93,
  32, 58, 32, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95,
  114, 111, 100, 105, 108, 105, 117, 115, 44, 32, 103, 105, 109, 112, 95, 97,
  110, 105, 109, 97, 116, 101, 95, 114, 111, 100, 105, 108, 105, 117, 115, 95,
  112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 70, 114, 97, 109, 101, 115, 32, 61, 32, 95, 105, 110,
  116, 40, 49, 48, 44, 50, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 97, 115, 32, 102,
  114, 97, 109, 101, 115, 32, 61, 32, 95, 98, 111, 111, 108, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116,
  32, 97, 115, 32, 102, 105, 108, 101, 115, 32, 61, 32, 95, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117,
  116, 112, 117, 116, 32, 102, 111, 108, 100, 101, 114, 32, 61, 32, 95, 102,
  111, 108, 100, 101, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 111, 108, 111, 114, 32, 109, 111, 100, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 49, 44, 34, 68, 97, 114, 107, 101, 114, 34, 44,
  34, 76, 105, 103, 104, 116, 101, 114, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123,
  34, 92, 110, 60, 98, 62, 83, 116, 97, 114, 116, 105, 110, 103, 32, 112,
  97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 58, 60, 47, 98, 62, 34,
  125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105,
  116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44,
  48, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84,
  104, 105, 99, 107, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 104, 97, 114, 112, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 51, 48, 48, 44, 48, 44, 49, 48, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 114, 105, 101, 110,
  116, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 53, 44,
  50, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79,
  102, 102, 115, 101, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 92, 110, 60,
  98, 62, 69, 110, 100, 105, 110, 103, 32, 112, 97, 114, 97, 109, 101, 116,
  101, 114, 115, 32, 58, 60, 47, 98, 62, 34, 125, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 51, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 105, 99, 107, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104,
  97, 114, 112, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  51, 48, 48, 44, 48, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 79, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110,
  115, 32, 61, 32, 105, 110, 116, 40, 53, 44, 50, 44, 50, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 102, 102, 115, 101, 116, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 56, 48, 44, 48, 44, 49, 56,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  97, 110, 105, 109, 97, 116, 101, 95, 114, 111, 100, 105, 108, 105, 117, 115,
  32, 58, 10, 45, 105, 102, 32, 36, 51, 32, 102, 105, 108, 101, 110, 97,
  109, 101, 61, 34, 36, 52, 47, 103, 109, 105, 99, 95, 114, 111, 100, 105,
  108, 105, 117, 115, 46, 112, 110, 103, 34, 32, 45, 101, 108, 115, 101, 32,
  102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 34, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 97, 110, 105, 109, 97, 116, 101, 32, 114, 111, 100, 105,
  108, 105, 117, 115, 44, 34, 36, 123, 54, 45, 49, 48, 125, 44, 36, 53,
  34, 44, 92, 10, 34, 36, 123, 49, 49, 45, 49, 53, 125, 44, 36, 53,
  34, 44, 36, 49, 44, 36, 50, 44, 64, 123, 45, 113, 117, 111, 116, 101,
  92, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 125, 10, 103, 105, 109,
  112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 114, 111, 100, 105, 108, 105,
  117, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 114, 111, 100, 105, 108, 105, 117, 115, 44, 34, 36, 123, 54,
  45, 49, 48, 125, 44, 36, 53, 34, 44, 92, 10, 34, 36, 123, 49, 49,
  45, 49, 53, 125, 44, 36, 53, 34, 10, 35, 64, 103, 105, 109, 112, 32,
  83, 111, 102, 116, 32, 103, 108, 111, 119, 32, 91, 97, 110, 105, 109, 97,
  116, 101, 100, 93, 32, 58, 32, 103, 105, 109, 112, 95, 97, 110, 105, 109,
  97, 116, 101, 95, 103, 108, 111, 119, 44, 32, 103, 105, 109, 112, 95, 97,
  110, 105, 109, 97, 116, 101, 95, 103, 108, 111, 119, 95, 112, 114, 101, 118,
  105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  70, 114, 97, 109, 101, 115, 32, 61, 32, 95, 105, 110, 116, 40, 49, 48,
  44, 50, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 79, 117, 116, 112, 117, 116, 32, 97, 115, 32, 102, 114, 97, 109, 101,
  115, 32, 61, 32, 95, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 97, 115, 32,
  102, 105, 108, 101, 115, 32, 61, 32, 95, 98, 111, 111, 108, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116,
  32, 102, 111, 108, 100, 101, 114, 32, 61, 32, 95, 102, 111, 108, 100, 101,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 92, 110, 60, 98, 62, 83,
  116, 97, 114, 116, 105, 110, 103, 32, 112, 97, 114, 97, 109, 101, 116, 101,
  114, 115, 32, 58, 60, 47, 98, 62, 34, 125, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 56, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 123, 34, 92, 110, 60, 98, 62, 69, 110, 100, 105, 110, 103, 32, 112,
  97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 58, 60, 47, 98, 62, 34,
  125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105,
  116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44, 48,
  44, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68,
  97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38,
  35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112,
  95, 97, 110, 105, 109, 97, 116, 101, 95, 103, 108, 111, 119, 32, 58, 10,
  45, 105, 102, 32, 36, 51, 32, 102, 105, 108, 101, 110, 97, 109, 101, 61,
  34, 36, 52, 47, 103, 109, 105, 99, 95, 103, 108, 111, 119, 46, 112, 110,
  103, 34, 32, 45, 101, 108, 115, 101, 32, 102, 105, 108, 101, 110, 97, 109,
  101, 61, 34, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 110, 105,
  109, 97, 116, 101, 32, 103, 108, 111, 119, 44, 34, 36, 53, 34, 44, 92,
  10, 34, 36, 54, 34, 44, 36, 49, 44, 36, 50, 44, 64, 123, 45, 113,
  117, 111, 116, 101, 92, 32, 36, 102, 105, 108, 101, 110, 97, 109, 101, 125,
  10, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 103, 108,
  111, 119, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 103, 108, 111, 119, 44, 34, 36, 53, 34, 44, 92, 10, 34,
  36, 54, 34, 10, 35, 64, 103, 105, 109, 112, 32, 95, 10, 35, 64, 103,
  105, 109, 112, 32, 60, 98, 62, 83, 112, 101, 99, 116, 114, 97, 108, 32,
  102, 105, 108, 116, 101, 114, 115, 60, 47, 98, 62, 10, 35, 64, 103, 105,
  109, 112, 32, 66, 97, 110, 100, 112, 97, 115, 115, 32, 58, 32, 103, 105,
  109, 112, 95, 98, 97, 110, 100, 112, 97, 115, 115, 44, 32, 103, 105, 109,
  112, 95, 98, 97, 110, 100, 112, 97, 115, 115, 95, 112, 114, 101, 118, 105,
  101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76,
  111, 119, 32, 102, 114, 101, 113, 117, 101, 110, 99, 121, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 72, 105, 103, 104, 32, 102, 114, 101, 113,
  117, 101, 110, 99, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48,
  48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66,
  65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108,
  117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97,
  98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44,
  34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97,
  108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101,
  110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34,
  99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34,
  44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44,
  34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 86, 97, 108, 117, 101, 32, 114, 97, 110, 103, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 67, 117, 116, 34, 44, 34,
  78, 111, 114, 109, 97, 108, 105, 122, 101, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32,
  116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70,
  117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116,
  101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68,
  117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68,
  97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38,
  35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112,
  95, 98, 97, 110, 100, 112, 97, 115, 115, 32, 58, 10, 45, 97, 112, 112,
  108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 98, 97,
  110, 100, 112, 97, 115, 115, 32, 36, 49, 37, 44, 36, 50, 37, 34, 44,
  36, 51, 44, 36, 52, 10, 103, 105, 109, 112, 95, 98, 97, 110, 100, 112,
  97, 115, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 103, 105, 109, 112, 95, 98, 97, 110, 100, 112, 97, 115,
  115, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112,
  32, 70, 111, 117, 114, 105, 101, 114, 32, 97, 110, 97, 108, 121, 115, 105,
  115, 32, 58, 32, 103, 105, 109, 112, 95, 100, 105, 115, 112, 108, 97, 121,
  95, 102, 102, 116, 44, 32, 103, 105, 109, 112, 95, 100, 105, 115, 112, 108,
  97, 121, 95, 102, 102, 116, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117,
  109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47,
  50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 100, 105, 115, 112, 108, 97, 121, 95, 102,
  102, 116, 32, 58, 10, 45, 116, 111, 95, 114, 103, 98, 32, 45, 100, 105,
  115, 112, 108, 97, 121, 95, 102, 102, 116, 10, 35, 64, 103, 105, 109, 112,
  32, 70, 111, 117, 114, 105, 101, 114, 32, 116, 114, 97, 110, 115, 102, 111,
  114, 109, 32, 58, 32, 103, 105, 109, 112, 95, 102, 111, 117, 114, 105, 101,
  114, 44, 32, 103, 105, 109, 112, 95, 102, 111, 117, 114, 105, 101, 114, 95,
  112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 84, 114, 97, 110, 115, 102, 111, 114, 109, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 68, 105, 114, 101, 99, 116,
  34, 44, 34, 73, 110, 118, 101, 114, 115, 101, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115,
  99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47,
  49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 102, 111, 117, 114, 105, 101,
  114, 32, 58, 10, 45, 105, 102, 32, 36, 49, 32, 45, 102, 102, 116, 56,
  50, 102, 108, 111, 97, 116, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10,
  45, 101, 108, 115, 101, 32, 45, 102, 108, 111, 97, 116, 50, 102, 102, 116,
  56, 10, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 102, 111,
  117, 114, 105, 101, 114, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 105, 102, 32, 36, 49, 32, 45, 103, 105, 109, 112, 95, 110, 111, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 48, 10, 45, 101, 108, 115, 101, 32,
  45, 100, 102, 102, 116, 10, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103,
  105, 109, 112, 32, 70, 111, 117, 114, 105, 101, 114, 32, 119, 97, 116, 101,
  114, 109, 97, 114, 107, 32, 58, 32, 103, 105, 109, 112, 95, 119, 97, 116,
  101, 114, 109, 97, 114, 107, 95, 102, 111, 117, 114, 105, 101, 114, 44, 32,
  95, 110, 111, 110, 101, 95, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  84, 101, 120, 116, 32, 61, 32, 116, 101, 120, 116, 123, 34, 40, 99, 41,
  32, 71, 39, 77, 73, 67, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 53, 55, 44,
  49, 51, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  60, 98, 62, 78, 111, 116, 101, 58, 32, 60, 47, 98, 62, 32, 84, 111,
  32, 109, 97, 107, 101, 32, 116, 104, 101, 32, 119, 97, 116, 101, 114, 109,
  97, 114, 107, 32, 118, 105, 115, 105, 98, 108, 101, 32, 97, 102, 116, 101,
  114, 119, 97, 114, 100, 115, 44, 32, 117, 115, 101, 32, 116, 104, 101, 32,
  39, 70, 111, 117, 114, 105, 101, 114, 32, 65, 110, 97, 108, 121, 115, 105,
  115, 39, 32, 102, 105, 108, 116, 101, 114, 46, 32, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105,
  62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114,
  108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 119, 97, 116, 101, 114, 109, 97, 114, 107, 95, 102, 111, 117,
  114, 105, 101, 114, 32, 58, 10, 45, 119, 97, 116, 101, 114, 109, 97, 114,
  107, 95, 102, 111, 117, 114, 105, 101, 114, 32, 34, 36, 49, 34, 44, 36,
  50, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10, 35, 64, 103, 105, 109,
  112, 32, 95, 10, 35, 64, 103, 105, 109, 112, 32, 60, 98, 62, 83, 116,
  101, 114, 101, 111, 115, 99, 111, 112, 105, 99, 32, 51, 100, 60, 47, 98,
  62, 10, 35, 64, 103, 105, 109, 112, 32, 51, 100, 32, 99, 111, 110, 118,
  101, 114, 115, 105, 111, 110, 32, 58, 32, 103, 105, 109, 112, 95, 116, 107,
  95, 109, 97, 107, 101, 51, 68, 44, 32, 103, 105, 109, 112, 95, 116, 107,
  95, 109, 97, 107, 101, 51, 68, 95, 112, 114, 101, 118, 105, 101, 119, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 83, 116, 101, 114, 101, 111, 115, 99, 111, 112, 105, 99,
  32, 115, 101, 116, 116, 105, 110, 103, 115, 58, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 99, 101, 110, 101, 32, 115, 101, 108, 101,
  99, 116, 111, 114, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 97,
  117, 116, 111, 109, 97, 116, 105, 99, 32, 100, 101, 112, 116, 104, 32, 101,
  115, 116, 105, 109, 97, 116, 105, 111, 110, 34, 44, 34, 100, 97, 121, 108,
  105, 103, 104, 116, 32, 115, 99, 101, 110, 101, 34, 44, 34, 111, 112, 116,
  105, 109, 105, 122, 101, 100, 32, 108, 97, 116, 101, 114, 97, 108, 32, 105,
  110, 104, 105, 98, 105, 116, 105, 111, 110, 34, 44, 34, 108, 105, 103, 104,
  116, 32, 109, 111, 116, 105, 118, 101, 34, 44, 34, 100, 97, 114, 107, 32,
  109, 111, 116, 105, 118, 101, 34, 44, 34, 108, 97, 110, 100, 115, 99, 97,
  112, 101, 34, 44, 34, 99, 101, 110, 116, 101, 114, 32, 102, 111, 114, 101,
  103, 114, 111, 117, 110, 100, 34, 44, 34, 99, 101, 110, 116, 101, 114, 32,
  98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 34, 44, 34, 108, 101, 102,
  116, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 34, 44, 34, 108,
  101, 102, 116, 32, 100, 105, 97, 103, 111, 110, 97, 108, 32, 102, 111, 114,
  101, 103, 114, 111, 117, 110, 100, 34, 44, 34, 114, 105, 103, 104, 116, 32,
  102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 34, 44, 34, 114, 105, 103,
  104, 116, 32, 100, 105, 97, 103, 111, 110, 97, 108, 32, 102, 111, 114, 101,
  103, 114, 111, 117, 110, 100, 34, 44, 34, 108, 101, 102, 116, 32, 97, 110,
  100, 32, 114, 105, 103, 104, 116, 32, 102, 111, 114, 101, 103, 114, 111, 117,
  110, 100, 34, 44, 34, 108, 101, 102, 116, 32, 97, 110, 100, 32, 114, 105,
  103, 104, 116, 32, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 34, 44,
  34, 98, 111, 116, 116, 111, 109, 32, 97, 110, 100, 32, 116, 111, 112, 32,
  102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 34, 44, 34, 98, 111, 116,
  116, 111, 109, 32, 97, 110, 100, 32, 108, 101, 102, 116, 32, 102, 111, 114,
  101, 103, 114, 111, 117, 110, 100, 34, 44, 34, 98, 111, 116, 116, 111, 109,
  32, 97, 110, 100, 32, 114, 105, 103, 104, 116, 32, 102, 111, 114, 101, 103,
  114, 111, 117, 110, 100, 34, 44, 34, 99, 101, 110, 116, 114, 97, 108, 32,
  112, 101, 114, 115, 112, 101, 99, 116, 105, 118, 101, 32, 111, 117, 116, 100,
  111, 111, 114, 34, 44, 34, 99, 101, 110, 116, 114, 97, 108, 32, 112, 101,
  114, 115, 112, 101, 99, 116, 105, 118, 101, 32, 105, 110, 100, 111, 111, 114,
  34, 44, 34, 112, 111, 114, 116, 114, 97, 105, 116, 34, 44, 34, 104, 117,
  109, 97, 110, 32, 49, 34, 44, 34, 104, 117, 109, 97, 110, 32, 50, 34,
  44, 34, 115, 116, 117, 100, 105, 111, 34, 44, 34, 117, 110, 100, 101, 114,
  119, 97, 116, 101, 114, 34, 44, 34, 102, 108, 97, 116, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 70, 97, 114, 32, 112, 111, 105, 110,
  116, 32, 100, 101, 118, 105, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 50, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 116, 101, 114, 101, 111,
  115, 99, 111, 112, 105, 99, 32, 119, 105, 110, 100, 111, 119, 32, 112, 111,
  115, 105, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 68, 101, 112, 116, 104, 32, 102, 105, 101, 108, 100, 32,
  99, 111, 110, 116, 114, 111, 108, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  50, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 70, 101, 97, 116, 117, 114, 101, 32, 97, 110, 97, 108, 121,
  122, 101, 114, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 70, 101, 97, 116, 117, 114, 101, 32, 97, 110,
  97, 108, 121, 122, 101, 114, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 111, 99, 97, 108, 32,
  100, 101, 116, 97, 105, 108, 32, 101, 110, 104, 97, 110, 99, 101, 114, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 111, 102, 32, 97, 110, 97, 108,
  121, 122, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 114, 101,
  113, 117, 101, 110, 99, 121, 32, 97, 110, 97, 108, 121, 122, 101, 114, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 70, 108, 105, 112, 32, 108, 101, 102,
  116, 32, 47, 32, 114, 105, 103, 104, 116, 32, 61, 32, 98, 111, 111, 108,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 85, 115, 101,
  32, 105, 110, 100, 105, 118, 105, 100, 117, 97, 108, 32, 100, 101, 112, 116,
  104, 32, 109, 97, 112, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 84, 111, 32,
  117, 115, 101, 32, 116, 104, 105, 115, 32, 111, 112, 116, 105, 111, 110, 32,
  121, 111, 117, 114, 32, 100, 101, 112, 116, 104, 32, 109, 97, 112, 32, 109,
  117, 115, 116, 32, 98, 101, 32, 112, 108, 97, 99, 101, 100, 32, 98, 101,
  108, 111, 119, 32, 121, 111, 117, 114, 32, 105, 109, 97, 103, 101, 46, 32,
  83, 119, 105, 116, 99, 104, 32, 105, 110, 112, 117, 116, 32, 108, 97, 121,
  101, 114, 115, 32, 116, 111, 32, 60, 105, 62, 60, 98, 62, 65, 99, 116,
  105, 118, 101, 32, 97, 110, 100, 32, 98, 101, 108, 111, 119, 60, 47, 98,
  62, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 73, 109, 97, 103, 101, 32, 115, 101, 116, 116, 105, 110, 103, 115,
  58, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 97,
  99, 107, 32, 38, 32, 119, 104, 105, 116, 101, 32, 61, 32, 98, 111, 111,
  108, 32, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79,
  117, 116, 112, 117, 116, 32, 102, 111, 114, 109, 97, 116, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 65, 110, 97, 103, 108, 121, 112, 104, 32,
  114, 101, 100, 47, 99, 121, 97, 110, 34, 44, 34, 65, 110, 97, 103, 108,
  121, 112, 104, 32, 114, 101, 100, 47, 99, 121, 97, 110, 32, 111, 112, 116,
  105, 109, 105, 122, 101, 100, 34, 44, 34, 65, 110, 97, 103, 108, 121, 112,
  104, 32, 98, 108, 117, 101, 47, 121, 101, 108, 108, 111, 119, 34, 44, 34,
  65, 110, 97, 103, 108, 121, 112, 104, 32, 98, 108, 117, 101, 47, 121, 101,
  108, 108, 111, 119, 32, 111, 112, 116, 105, 109, 105, 122, 101, 100, 34, 44,
  34, 65, 110, 97, 103, 108, 121, 112, 104, 32, 103, 114, 101, 101, 110, 47,
  109, 97, 103, 101, 110, 116, 97, 34, 44, 34, 65, 110, 97, 103, 108, 121,
  112, 104, 32, 103, 114, 101, 101, 110, 47, 109, 97, 103, 101, 110, 116, 97,
  32, 111, 112, 116, 105, 109, 105, 122, 101, 100, 34, 44, 34, 70, 117, 108,
  108, 32, 115, 105, 100, 101, 32, 98, 121, 32, 115, 105, 100, 101, 32, 107,
  101, 101, 112, 32, 119, 105, 100, 116, 104, 34, 44, 34, 70, 117, 108, 108,
  32, 115, 105, 100, 101, 32, 98, 121, 32, 115, 105, 100, 101, 32, 107, 101,
  101, 112, 32, 117, 110, 99, 111, 109, 112, 114, 101, 115, 115, 101, 100, 34,
  44, 34, 70, 117, 108, 108, 32, 98, 111, 116, 116, 111, 109, 47, 116, 111,
  112, 34, 44, 34, 72, 97, 108, 102, 32, 115, 105, 100, 101, 32, 32, 98,
  121, 32, 115, 105, 100, 101, 34, 44, 34, 72, 97, 108, 102, 32, 98, 111,
  116, 116, 111, 109, 47, 116, 111, 112, 34, 44, 34, 73, 110, 116, 101, 114,
  108, 97, 99, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 73, 110, 116, 101, 114, 108, 97, 99, 101, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 70, 117, 108, 108, 32, 72, 68, 32, 102,
  114, 97, 109, 101, 32, 112, 97, 99, 107, 105, 110, 103, 34, 44, 34, 85,
  110, 97, 108, 105, 103, 110, 101, 100, 32, 105, 109, 97, 103, 101, 115, 34,
  44, 34, 68, 101, 112, 116, 104, 32, 109, 97, 112, 32, 111, 110, 108, 121,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 97, 109, 109,
  97, 32, 99, 111, 109, 112, 101, 110, 115, 97, 116, 105, 111, 110, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 46, 50, 44, 48, 44, 52, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 116, 105, 45, 103, 104,
  111, 115, 116, 105, 110, 103, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50,
  53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 111, 108, 111, 114, 32, 98, 111, 111, 115, 116, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 65, 110, 97, 103, 108, 121, 112, 104, 32, 103,
  108, 97, 115, 115, 101, 115, 32, 97, 100, 106, 117, 115, 116, 109, 101, 110,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 48, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  117, 116, 111, 99, 114, 111, 112, 32, 61, 32, 98, 111, 111, 108, 32, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 105, 100, 105,
  114, 101, 99, 116, 105, 111, 110, 97, 108, 32, 114, 101, 110, 100, 101, 114,
  105, 110, 103, 32, 61, 32, 98, 111, 111, 108, 32, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  70, 114, 97, 109, 101, 32, 115, 101, 116, 116, 105, 110, 103, 115, 58, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 110, 100, 101,
  114, 32, 109, 117, 108, 116, 105, 112, 108, 101, 32, 102, 114, 97, 109, 101,
  115, 32, 61, 32, 98, 111, 111, 108, 32, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 82, 101, 110, 100, 101, 114, 32, 114, 111, 117,
  116, 105, 110, 101, 32, 102, 111, 114, 32, 119, 105, 103, 103, 108, 101, 32,
  97, 110, 105, 109, 97, 116, 105, 111, 110, 115, 32, 61, 32, 98, 111, 111,
  108, 32, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70,
  114, 97, 109, 101, 115, 32, 61, 32, 105, 110, 116, 40, 50, 44, 50, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 114,
  97, 109, 101, 32, 115, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 50,
  48, 48, 44, 53, 48, 44, 49, 57, 50, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 84, 111, 109, 32, 75, 101, 105, 108, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 50,
  47, 48, 57, 47, 50, 48, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 70, 105, 108, 116,
  101, 114, 32, 101, 120, 112, 108, 97, 105, 110, 101, 100, 32, 104, 101, 114,
  101, 34, 44, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 116, 107,
  102, 105, 108, 116, 101, 114, 46, 98, 112, 108, 97, 99, 101, 100, 46, 110,
  101, 116, 47, 84, 75, 70, 105, 108, 116, 101, 114, 37, 50, 48, 116, 117,
  116, 111, 114, 105, 97, 108, 115, 37, 50, 48, 50, 68, 116, 111, 51, 68,
  37, 50, 48, 51, 68, 45, 97, 117, 116, 111, 109, 97, 116, 105, 99, 37,
  50, 48, 115, 116, 101, 114, 101, 111, 115, 99, 111, 112, 105, 99, 37, 50,
  48, 99, 111, 110, 118, 101, 114, 115, 105, 111, 110, 46, 104, 116, 109, 108,
  41, 10, 103, 105, 109, 112, 95, 116, 107, 95, 109, 97, 107, 101, 51, 68,
  32, 58, 10, 35, 32, 112, 114, 101, 112, 97, 114, 101, 32, 105, 109, 97,
  103, 101, 10, 115, 104, 61, 123, 45, 36, 50, 125, 32, 115, 119, 61, 123,
  45, 36, 115, 104, 45, 36, 51, 125, 32, 115, 105, 122, 101, 49, 61, 123,
  119, 125, 32, 115, 105, 122, 101, 50, 61, 123, 104, 125, 32, 45, 116, 111,
  95, 114, 103, 98, 91, 48, 93, 32, 45, 114, 91, 48, 93, 32, 36, 115,
  105, 122, 101, 49, 44, 36, 115, 105, 122, 101, 50, 32, 45, 45, 103, 105,
  109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 48, 93,
  10, 35, 32, 99, 114, 101, 97, 116, 101, 32, 100, 101, 112, 116, 104, 32,
  109, 97, 112, 10, 45, 105, 102, 32, 123, 36, 49, 49, 61, 61, 48, 125,
  10, 45, 45, 103, 105, 109, 112, 95, 116, 107, 95, 100, 101, 112, 116, 104,
  109, 97, 112, 91, 45, 49, 93, 32, 36, 49, 44, 36, 52, 44, 36, 53,
  44, 36, 54, 44, 36, 55, 44, 36, 56, 44, 36, 57, 44, 48, 44, 48,
  44, 48, 32, 45, 114, 91, 45, 49, 93, 32, 36, 115, 105, 122, 101, 49,
  44, 36, 115, 105, 122, 101, 50, 10, 45, 103, 105, 109, 112, 95, 103, 97,
  117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 45, 49, 93, 32,
  48, 44, 123, 123, 119, 43, 104, 125, 47, 55, 48, 48, 125, 44, 123, 123,
  119, 43, 104, 125, 47, 51, 53, 48, 125, 44, 49, 44, 48, 44, 48, 44,
  48, 10, 35, 32, 105, 110, 100, 105, 118, 105, 100, 117, 97, 108, 32, 100,
  101, 112, 116, 104, 32, 109, 97, 112, 10, 45, 101, 108, 115, 101, 32, 45,
  105, 102, 32, 123, 123, 64, 35, 125, 33, 61, 51, 125, 10, 45, 101, 114,
  114, 111, 114, 91, 93, 32, 34, 70, 111, 114, 32, 105, 110, 100, 105, 118,
  105, 100, 117, 97, 108, 32, 100, 101, 112, 116, 104, 32, 109, 97, 112, 32,
  115, 101, 108, 101, 99, 116, 32, 105, 110, 112, 117, 116, 32, 109, 111, 100,
  101, 32, 65, 67, 84, 73, 86, 69, 32, 65, 78, 68, 32, 66, 69, 76,
  79, 87, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 118, 91, 49,
  44, 45, 49, 93, 32, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93,
  32, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 45, 49, 93, 10,
  35, 32, 97, 110, 97, 108, 121, 122, 101, 32, 105, 109, 97, 103, 101, 32,
  102, 101, 97, 116, 117, 114, 101, 115, 32, 116, 111, 32, 101, 110, 114, 105,
  99, 104, 32, 105, 110, 100, 105, 118, 105, 100, 117, 97, 108, 32, 109, 97,
  112, 115, 10, 45, 105, 102, 32, 123, 36, 49, 49, 61, 61, 49, 125, 10,
  45, 105, 102, 32, 123, 36, 57, 33, 61, 48, 125, 10, 45, 45, 102, 99,
  91, 48, 93, 32, 49, 50, 56, 44, 49, 50, 56, 44, 49, 50, 56, 32,
  45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48, 93, 32, 50, 32,
  45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32, 45, 99,
  91, 45, 49, 93, 32, 48, 44, 57, 48, 10, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 49, 50, 56, 32, 45, 114, 118, 91, 45, 49, 44, 45, 50,
  93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101,
  110, 91, 45, 49, 44, 45, 50, 93, 10, 45, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 91, 48, 93, 32, 48, 32, 45, 110, 101, 103, 97, 116, 105,
  118, 101, 91, 45, 49, 93, 32, 45, 99, 91, 45, 49, 93, 32, 49, 54,
  53, 44, 50, 53, 53, 32, 45, 110, 91, 45, 49, 93, 32, 49, 50, 56,
  44, 50, 53, 53, 32, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 10,
  45, 99, 111, 109, 112, 111, 115, 101, 95, 104, 97, 114, 100, 108, 105, 103,
  104, 116, 91, 45, 49, 44, 45, 50, 93, 32, 45, 114, 118, 91, 45, 49,
  44, 45, 50, 93, 10, 45, 105, 102, 32, 123, 36, 49, 49, 61, 61, 48,
  125, 32, 45, 105, 102, 32, 123, 36, 49, 33, 61, 50, 48, 125, 32, 45,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 97, 118, 101,
  114, 97, 103, 101, 91, 45, 49, 44, 45, 50, 93, 32, 123, 36, 57, 47,
  53, 125, 10, 45, 101, 108, 115, 101, 32, 45, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 118, 97, 108, 117, 101, 91, 45, 49, 44,
  45, 50, 93, 32, 123, 36, 57, 47, 53, 125, 44, 48, 10, 45, 116, 107,
  95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114,
  111, 99, 101, 115, 115, 105, 110, 103, 91, 45, 49, 93, 32, 49, 44, 123,
  36, 52, 47, 50, 53, 125, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49,
  48, 48, 44, 50, 53, 54, 44, 48, 44, 48, 44, 48, 44, 50, 44, 48,
  44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101, 32,
  45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 118, 97,
  108, 117, 101, 91, 45, 49, 44, 45, 50, 93, 32, 123, 36, 57, 47, 53,
  125, 44, 48, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 56, 33, 61, 48, 125, 32, 45, 45,
  103, 105, 109, 112, 95, 104, 105, 103, 104, 112, 97, 115, 115, 91, 48, 93,
  32, 50, 44, 50, 44, 48, 44, 48, 44, 48, 10, 45, 116, 107, 95, 103,
  105, 109, 112, 95, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111,
  114, 91, 45, 49, 93, 32, 53, 44, 48, 44, 49, 50, 56, 44, 49, 50,
  56, 44, 49, 50, 56, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44,
  50, 53, 53, 10, 45, 103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111,
  91, 45, 49, 93, 32, 51, 44, 55, 48, 44, 48, 44, 48, 44, 48, 44,
  49, 44, 48, 32, 32, 32, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45,
  49, 93, 32, 97, 118, 61, 64, 123, 45, 49, 44, 97, 125, 10, 45, 116,
  50, 91, 45, 49, 93, 32, 36, 97, 118, 44, 50, 53, 53, 32, 45, 110,
  91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 98, 108, 117, 114,
  95, 120, 121, 91, 45, 49, 93, 32, 50, 53, 10, 45, 114, 118, 91, 45,
  49, 44, 45, 50, 93, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 111, 118, 101, 114, 108, 97, 121, 91, 45, 49, 44, 45,
  50, 93, 32, 123, 36, 56, 47, 53, 125, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 53, 33, 61, 48, 125, 32, 45, 45, 103,
  105, 109, 112, 95, 105, 115, 111, 112, 104, 111, 116, 101, 115, 91, 48, 93,
  32, 123, 123, 36, 53, 42, 51, 125, 43, 50, 125, 44, 48, 44, 48, 44,
  48, 10, 45, 103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111, 91, 45,
  49, 93, 32, 51, 44, 123, 53, 45, 123, 36, 53, 47, 50, 125, 125, 44,
  48, 44, 48, 44, 48, 44, 49, 44, 48, 10, 45, 116, 107, 95, 103, 105,
  109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101,
  115, 115, 105, 110, 103, 91, 45, 49, 93, 32, 49, 44, 49, 44, 50, 53,
  53, 44, 48, 44, 48, 44, 48, 44, 49, 48, 48, 44, 50, 53, 54, 44,
  48, 44, 48, 44, 48, 44, 50, 44, 48, 44, 48, 10, 45, 114, 118, 91,
  45, 49, 44, 45, 50, 93, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 111, 118, 101, 114, 108, 97, 121, 91, 45, 49, 44,
  45, 50, 93, 32, 123, 36, 53, 47, 49, 48, 125, 10, 45, 45, 103, 105,
  109, 112, 95, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109,
  91, 48, 93, 32, 123, 36, 54, 42, 50, 125, 44, 123, 49, 46, 53, 45,
  123, 48, 46, 49, 43, 123, 36, 53, 47, 51, 46, 54, 125, 125, 125, 44,
  48, 44, 49, 48, 48, 44, 48, 44, 48, 10, 45, 114, 118, 91, 45, 49,
  44, 45, 50, 93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105,
  103, 104, 116, 101, 110, 91, 45, 49, 44, 45, 50, 93, 32, 45, 103, 105,
  109, 112, 95, 115, 101, 103, 109, 101, 110, 116, 95, 119, 97, 116, 101, 114,
  115, 104, 101, 100, 91, 45, 49, 93, 32, 36, 53, 44, 36, 54, 44, 48,
  44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  55, 33, 61, 48, 125, 32, 45, 45, 108, 117, 109, 105, 110, 97, 110, 99,
  101, 91, 48, 93, 32, 45, 103, 105, 109, 112, 95, 109, 97, 112, 95, 116,
  111, 110, 101, 115, 91, 45, 49, 93, 32, 49, 44, 123, 48, 46, 50, 53,
  45, 123, 36, 55, 47, 50, 48, 125, 125, 44, 48, 44, 51, 48, 44, 51,
  44, 48, 10, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 32, 45, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 111, 118, 101, 114,
  108, 97, 121, 91, 45, 49, 44, 45, 50, 93, 32, 123, 36, 55, 47, 49,
  48, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 32, 45, 101,
  110, 100, 105, 102, 10, 35, 102, 114, 97, 109, 101, 32, 115, 105, 122, 101,
  32, 102, 111, 114, 32, 109, 117, 108, 116, 105, 112, 108, 101, 32, 102, 114,
  97, 109, 101, 115, 10, 45, 105, 102, 32, 123, 36, 50, 48, 61, 61, 49,
  125, 32, 45, 114, 32, 123, 119, 42, 123, 36, 50, 51, 47, 109, 97, 120,
  40, 119, 44, 104, 41, 125, 125, 44, 123, 104, 42, 123, 36, 50, 51, 47,
  109, 97, 120, 40, 119, 44, 104, 41, 125, 125, 44, 49, 44, 51, 44, 54,
  32, 45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102,
  10, 35, 99, 114, 101, 97, 116, 101, 32, 115, 101, 99, 111, 110, 100, 32,
  118, 105, 101, 119, 10, 45, 105, 102, 32, 123, 36, 50, 48, 61, 61, 48,
  125, 10, 45, 105, 102, 32, 123, 36, 49, 51, 33, 61, 49, 53, 125, 32,
  45, 105, 102, 32, 123, 36, 49, 57, 61, 61, 48, 125, 10, 45, 105, 102,
  32, 123, 36, 115, 119, 60, 61, 48, 125, 32, 45, 110, 101, 103, 97, 116,
  105, 118, 101, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 91, 45, 49, 93, 32, 36, 115, 105, 122, 101, 49, 44, 36, 115, 105,
  122, 101, 50, 44, 49, 44, 50, 32, 45, 115, 91, 45, 49, 93, 32, 99,
  32, 45, 102, 91, 45, 49, 93, 32, 48, 32, 45, 110, 91, 45, 50, 93,
  32, 48, 44, 36, 115, 119, 32, 45, 97, 91, 45, 49, 44, 45, 50, 93,
  32, 99, 10, 45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 49, 32, 45, 115, 104, 105, 102, 116, 91, 45, 50, 93, 32, 36,
  115, 104, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 108,
  115, 101, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116,
  104, 105, 110, 103, 91, 45, 49, 93, 32, 45, 114, 91, 45, 49, 44, 45,
  50, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 50,
  10, 45, 115, 91, 45, 49, 93, 32, 99, 32, 45, 102, 91, 45, 49, 93,
  32, 48, 32, 45, 110, 91, 45, 50, 93, 32, 48, 44, 123, 97, 98, 115,
  40, 36, 115, 119, 47, 50, 41, 125, 32, 45, 97, 91, 45, 49, 44, 45,
  50, 93, 32, 99, 10, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45,
  50, 93, 32, 45, 115, 91, 45, 50, 93, 32, 99, 32, 45, 102, 91, 45,
  50, 93, 32, 48, 32, 45, 110, 91, 45, 51, 93, 32, 48, 44, 123, 45,
  97, 98, 115, 40, 36, 115, 119, 47, 50, 41, 125, 32, 45, 97, 91, 45,
  50, 44, 45, 51, 93, 32, 99, 10, 45, 119, 97, 114, 112, 91, 45, 52,
  93, 32, 91, 45, 50, 93, 44, 49, 32, 45, 119, 97, 114, 112, 91, 45,
  51, 93, 32, 91, 45, 49, 93, 44, 49, 10, 45, 115, 104, 105, 102, 116,
  91, 45, 51, 93, 32, 36, 115, 104, 44, 48, 32, 45, 114, 109, 91, 45,
  49, 44, 45, 50, 93, 10, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 108, 115, 101, 10, 35, 99, 114, 101, 97, 116,
  101, 32, 109, 117, 108, 116, 105, 112, 108, 101, 32, 102, 114, 97, 109, 101,
  115, 10, 45, 105, 102, 32, 123, 36, 49, 57, 61, 61, 48, 125, 10, 99,
  111, 117, 110, 116, 61, 123, 36, 50, 50, 125, 32, 100, 101, 118, 61, 48,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 99, 111, 117, 110, 116, 32,
  100, 101, 118, 61, 123, 36, 100, 101, 118, 43, 123, 36, 115, 119, 47, 36,
  50, 50, 125, 125, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110,
  111, 116, 104, 105, 110, 103, 91, 48, 93, 32, 45, 114, 118, 91, 45, 49,
  44, 45, 50, 93, 10, 45, 105, 102, 32, 123, 36, 115, 119, 60, 61, 48,
  125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 114, 91, 45, 49, 93, 32, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 50, 32, 45, 115, 91, 45,
  49, 93, 32, 99, 32, 45, 102, 91, 45, 49, 93, 32, 48, 10, 45, 105,
  102, 32, 123, 36, 50, 49, 61, 61, 48, 125, 32, 45, 110, 91, 45, 50,
  93, 32, 48, 44, 36, 100, 101, 118, 32, 45, 101, 108, 115, 101, 32, 45,
  110, 91, 45, 50, 93, 32, 123, 45, 36, 100, 101, 118, 125, 44, 36, 100,
  101, 118, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 91, 45, 49, 44,
  45, 50, 93, 32, 99, 32, 45, 119, 97, 114, 112, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 49, 32, 45, 116, 111, 95, 103, 114, 97, 121, 91,
  45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  10, 45, 105, 102, 32, 123, 36, 115, 119, 60, 61, 48, 125, 32, 45, 110,
  101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 45, 49, 44,
  48, 93, 32, 45, 114, 118, 10, 45, 101, 108, 115, 101, 10, 99, 111, 117,
  110, 116, 61, 123, 97, 98, 115, 40, 36, 50, 50, 47, 50, 41, 125, 32,
  100, 101, 118, 61, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 99,
  111, 117, 110, 116, 32, 100, 101, 118, 61, 123, 36, 100, 101, 118, 43, 123,
  36, 115, 119, 47, 36, 99, 111, 117, 110, 116, 125, 125, 10, 45, 45, 103,
  105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45,
  50, 93, 32, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 10, 45, 45,
  103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91,
  45, 50, 93, 32, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 10, 45,
  45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103,
  91, 45, 49, 93, 32, 45, 114, 91, 45, 49, 44, 45, 50, 93, 32, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 50, 10, 45, 115, 91,
  45, 49, 93, 32, 99, 32, 45, 102, 91, 45, 49, 93, 32, 48, 10, 45,
  105, 102, 32, 123, 36, 50, 49, 61, 61, 48, 125, 32, 45, 110, 91, 45,
  50, 93, 32, 48, 44, 123, 97, 98, 115, 40, 36, 100, 101, 118, 47, 50,
  41, 125, 10, 45, 101, 108, 115, 101, 32, 45, 110, 91, 45, 50, 93, 32,
  123, 45, 97, 98, 115, 40, 36, 100, 101, 118, 47, 50, 41, 125, 44, 123,
  97, 98, 115, 40, 36, 100, 101, 118, 47, 50, 41, 125, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 97, 91, 45, 49, 44, 45, 50, 93, 32, 99, 10,
  45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 50, 93, 32, 45, 115,
  91, 45, 50, 93, 32, 99, 32, 45, 102, 91, 45, 50, 93, 32, 48, 10,
  45, 105, 102, 32, 123, 36, 50, 49, 61, 61, 48, 125, 32, 45, 110, 91,
  45, 51, 93, 32, 48, 44, 123, 45, 97, 98, 115, 40, 36, 100, 101, 118,
  47, 50, 41, 125, 10, 45, 101, 108, 115, 101, 32, 45, 110, 91, 45, 51,
  93, 32, 123, 45, 97, 98, 115, 40, 36, 100, 101, 118, 47, 50, 41, 125,
  44, 123, 97, 98, 115, 40, 36, 100, 101, 118, 47, 50, 41, 125, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 97, 91, 45, 50, 44, 45, 51, 93, 32,
  99, 10, 45, 119, 97, 114, 112, 91, 45, 52, 93, 32, 91, 45, 50, 93,
  44, 49, 32, 45, 119, 97, 114, 112, 91, 45, 51, 93, 32, 91, 45, 49,
  93, 44, 49, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45, 116, 111, 95,
  103, 114, 97, 121, 91, 45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 10, 45, 109, 118, 91, 45, 52, 93, 32, 45, 49,
  32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 45, 49, 44, 45, 50,
  93, 32, 45, 109, 118, 91, 48, 45, 45, 49, 58, 50, 93, 32, 45, 49,
  32, 45, 114, 118, 91, 48, 45, 53, 48, 37, 93, 32, 45, 109, 118, 91,
  48, 93, 32, 53, 48, 37, 10, 45, 101, 110, 100, 105, 102, 32, 45, 101,
  110, 100, 105, 102, 10, 35, 99, 114, 111, 112, 32, 105, 109, 97, 103, 101,
  115, 10, 45, 105, 102, 32, 123, 36, 50, 48, 61, 61, 48, 125, 32, 45,
  105, 102, 32, 123, 36, 49, 56, 61, 61, 49, 125, 32, 45, 105, 102, 32,
  123, 36, 49, 51, 33, 61, 49, 53, 125, 10, 45, 105, 102, 32, 123, 36,
  115, 104, 62, 61, 48, 125, 32, 45, 99, 114, 111, 112, 91, 45, 49, 44,
  45, 50, 93, 32, 36, 115, 104, 44, 48, 44, 123, 119, 125, 44, 123, 104,
  125, 32, 45, 101, 108, 115, 101, 32, 45, 99, 114, 111, 112, 91, 45, 49,
  44, 45, 50, 93, 32, 48, 44, 48, 44, 123, 119, 43, 36, 115, 104, 125,
  44, 123, 104, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 49, 57, 61, 61, 48, 125, 10, 45, 105, 102, 32, 123, 36, 115,
  119, 62, 61, 48, 125, 32, 45, 99, 114, 111, 112, 91, 45, 49, 44, 45,
  50, 93, 32, 36, 115, 119, 44, 48, 44, 123, 119, 125, 44, 123, 104, 125,
  32, 45, 101, 108, 115, 101, 32, 45, 99, 114, 111, 112, 91, 45, 49, 44,
  45, 50, 93, 32, 48, 44, 48, 44, 123, 119, 43, 36, 115, 119, 125, 44,
  123, 104, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101,
  32, 45, 99, 114, 111, 112, 91, 45, 49, 44, 45, 50, 93, 32, 123, 97,
  98, 115, 40, 36, 115, 119, 47, 50, 41, 125, 44, 48, 44, 123, 119, 45,
  97, 98, 115, 40, 36, 115, 119, 47, 50, 41, 125, 44, 123, 104, 125, 10,
  45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101,
  110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 35, 97, 108, 105,
  103, 110, 32, 115, 116, 101, 114, 101, 111, 115, 99, 111, 112, 105, 99, 32,
  105, 109, 97, 103, 101, 10, 45, 105, 102, 32, 123, 36, 49, 50, 61, 61,
  49, 125, 32, 45, 103, 105, 109, 112, 95, 98, 108, 97, 99, 107, 97, 110,
  100, 119, 104, 105, 116, 101, 32, 48, 46, 50, 57, 57, 44, 48, 44, 48,
  46, 53, 56, 55, 44, 48, 44, 48, 46, 49, 49, 52, 44, 48, 44, 49,
  44, 49, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 50,
  44, 48, 44, 48, 44, 48, 44, 49, 54, 44, 52, 44, 48, 44, 48, 44,
  48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 50,
  48, 61, 61, 48, 125, 10, 45, 105, 102, 32, 123, 123, 36, 49, 51, 33,
  61, 49, 52, 125, 38, 38, 123, 36, 49, 51, 33, 61, 49, 53, 125, 125,
  10, 45, 103, 105, 109, 112, 95, 116, 107, 95, 115, 116, 101, 114, 101, 111,
  105, 109, 97, 103, 101, 91, 48, 44, 49, 93, 32, 36, 49, 51, 44, 36,
  49, 48, 44, 36, 49, 52, 44, 36, 49, 53, 44, 36, 49, 54, 44, 36,
  49, 55, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 51, 61, 61, 49,
  52, 125, 32, 45, 107, 91, 48, 44, 49, 93, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 51, 61, 61, 49, 53, 125, 32, 45, 107, 91, 45, 49,
  93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 49, 51, 61, 61, 49, 52, 125, 32, 45, 97,
  112, 112, 108, 121, 95, 103, 97, 109, 109, 97, 32, 36, 49, 52, 32, 45,
  116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95,
  112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 49, 44, 49, 44, 36,
  49, 53, 44, 48, 44, 48, 44, 48, 44, 49, 48, 48, 44, 50, 53, 54,
  44, 48, 44, 48, 44, 49, 44, 49, 48, 44, 55, 44, 48, 10, 45, 103,
  105, 109, 112, 95, 109, 105, 120, 95, 108, 97, 98, 32, 49, 44, 48, 44,
  48, 44, 36, 49, 54, 44, 48, 44, 48, 44, 36, 49, 54, 44, 48, 44,
  48, 44, 48, 44, 50, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 103,
  105, 109, 112, 95, 116, 107, 95, 109, 97, 107, 101, 51, 68, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 105, 102, 32, 123, 36, 50, 48,
  61, 61, 48, 125, 32, 115, 104, 112, 114, 101, 61, 123, 36, 50, 47, 51,
  125, 32, 115, 119, 112, 114, 101, 61, 123, 36, 51, 47, 51, 125, 32, 45,
  101, 108, 115, 101, 32, 115, 104, 112, 114, 101, 61, 123, 36, 50, 42, 123,
  52, 48, 48, 47, 36, 50, 51, 125, 125, 32, 115, 119, 112, 114, 101, 61,
  123, 36, 51, 42, 123, 52, 48, 48, 47, 36, 50, 51, 125, 125, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 123, 36, 49, 49, 61,
  61, 49, 125, 38, 38, 123, 123, 64, 35, 125, 33, 61, 50, 125, 125, 32,
  45, 102, 99, 91, 48, 93, 32, 50, 53, 53, 44, 48, 44, 49, 50, 56,
  44, 50, 53, 53, 32, 45, 107, 91, 48, 93, 32, 45, 116, 101, 120, 116,
  32, 34, 70, 111, 114, 32, 105, 110, 100, 105, 118, 105, 100, 117, 97, 108,
  32, 100, 101, 112, 116, 104, 32, 109, 97, 112, 34, 44, 49, 48, 44, 56,
  48, 37, 44, 50, 48, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 53,
  53, 10, 45, 116, 101, 120, 116, 32, 34, 115, 101, 108, 101, 99, 116, 32,
  105, 110, 112, 117, 116, 32, 109, 111, 100, 101, 32, 65, 67, 84, 73, 86,
  69, 32, 65, 78, 68, 32, 66, 69, 76, 79, 87, 46, 34, 44, 49, 48,
  44, 57, 48, 37, 44, 50, 48, 44, 49, 44, 48, 44, 48, 44, 48, 44,
  50, 53, 53, 10, 45, 101, 108, 115, 101, 10, 45, 103, 105, 109, 112, 95,
  116, 107, 95, 109, 97, 107, 101, 51, 68, 32, 36, 49, 44, 36, 115, 104,
  112, 114, 101, 44, 36, 115, 119, 112, 114, 101, 44, 36, 123, 52, 45, 49,
  50, 125, 44, 123, 105, 102, 40, 123, 36, 50, 48, 61, 61, 49, 125, 44,
  49, 52, 44, 36, 49, 51, 41, 125, 44, 36, 123, 49, 52, 45, 49, 57,
  125, 44, 48, 44, 36, 123, 50, 49, 45, 50, 51, 125, 32, 45, 105, 102,
  32, 123, 123, 36, 49, 51, 61, 61, 49, 52, 125, 124, 124, 123, 36, 50,
  48, 61, 61, 49, 125, 125, 32, 45, 107, 91, 49, 93, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103, 105, 109,
  112, 32, 51, 100, 32, 118, 105, 100, 101, 111, 32, 99, 111, 110, 118, 101,
  114, 115, 105, 111, 110, 32, 58, 32, 103, 105, 109, 112, 95, 116, 107, 95,
  118, 105, 100, 101, 111, 51, 68, 44, 32, 103, 105, 109, 112, 95, 116, 107,
  95, 118, 105, 100, 101, 111, 51, 68, 95, 112, 114, 101, 118, 105, 101, 119,
  40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 98, 62, 83, 116, 101, 114, 101, 111, 115, 99,
  111, 112, 105, 99, 32, 115, 101, 116, 116, 105, 110, 103, 115, 58, 60, 47,
  98, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99,
  101, 110, 101, 32, 115, 101, 108, 101, 99, 116, 111, 114, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 97, 117, 116, 111, 109, 97, 116, 105, 99,
  32, 100, 101, 112, 116, 104, 32, 101, 115, 116, 105, 109, 97, 116, 105, 111,
  110, 34, 44, 34, 100, 97, 121, 108, 105, 103, 104, 116, 32, 115, 99, 101,
  110, 101, 34, 44, 34, 111, 112, 116, 105, 109, 105, 122, 101, 100, 32, 108,
  97, 116, 101, 114, 97, 108, 32, 105, 110, 104, 105, 98, 105, 116, 105, 111,
  110, 34, 44, 34, 108, 105, 103, 104, 116, 32, 109, 111, 116, 105, 118, 101,
  34, 44, 34, 100, 97, 114, 107, 32, 32, 109, 111, 116, 105, 118, 101, 34,
  44, 34, 108, 97, 110, 100, 115, 99, 97, 112, 101, 34, 44, 34, 99, 101,
  110, 116, 101, 114, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 34,
  44, 34, 99, 101, 110, 116, 101, 114, 32, 98, 97, 99, 107, 103, 114, 111,
  117, 110, 100, 34, 44, 34, 108, 101, 102, 116, 32, 32, 102, 111, 114, 101,
  103, 114, 111, 117, 110, 100, 34, 44, 34, 108, 101, 102, 116, 32, 100, 105,
  97, 103, 111, 110, 97, 108, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110,
  100, 34, 44, 34, 114, 105, 103, 104, 116, 32, 102, 111, 114, 101, 103, 114,
  111, 117, 110, 100, 34, 44, 34, 114, 105, 103, 104, 116, 32, 100, 105, 97,
  103, 111, 110, 97, 108, 32, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110,
  100, 34, 44, 34, 108, 101, 102, 116, 32, 97, 110, 100, 32, 114, 105, 103,
  104, 116, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 34, 44, 34,
  108, 101, 102, 116, 32, 97, 110, 100, 32, 114, 105, 103, 104, 116, 32, 98,
  97, 99, 107, 103, 114, 111, 117, 110, 100, 34, 44, 34, 98, 111, 116, 116,
  111, 109, 32, 97, 110, 100, 32, 116, 111, 112, 32, 102, 111, 114, 101, 103,
  114, 111, 117, 110, 100, 34, 44, 34, 98, 111, 116, 116, 111, 109, 32, 97,
  110, 100, 32, 108, 101, 102, 116, 32, 102, 111, 114, 101, 103, 114, 111, 117,
  110, 100, 34, 44, 34, 98, 111, 116, 116, 111, 109, 32, 97, 110, 100, 32,
  114, 105, 103, 104, 116, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100,
  34, 44, 34, 99, 101, 110, 116, 114, 97, 108, 32, 32, 112, 101, 114, 115,
  112, 101, 99, 116, 105, 118, 101, 32, 111, 117, 116, 100, 111, 111, 114, 34,
  44, 34, 99, 101, 110, 116, 114, 97, 108, 32, 112, 101, 114, 115, 112, 101,
  99, 116, 105, 118, 101, 32, 105, 110, 100, 111, 111, 114, 34, 44, 34, 112,
  111, 114, 116, 114, 97, 105, 116, 34, 44, 34, 104, 117, 109, 97, 110, 32,
  49, 34, 44, 34, 104, 117, 109, 97, 110, 32, 32, 50, 34, 44, 34, 115,
  116, 117, 100, 105, 111, 34, 44, 34, 117, 110, 100, 101, 114, 119, 97, 116,
  101, 114, 34, 44, 34, 102, 108, 97, 116, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 70, 97, 114, 32, 112, 111, 105, 110, 116, 32, 100,
  101, 118, 105, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 116, 101, 114, 101, 111, 32, 119, 105,
  110, 100, 111, 119, 32, 112, 111, 115, 105, 116, 105, 111, 110, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 45, 49, 48, 44, 45, 49, 48, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 112,
  116, 104, 32, 102, 105, 101, 108, 100, 32, 99, 111, 110, 116, 114, 111, 108,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 101, 97, 116,
  117, 114, 101, 32, 97, 110, 97, 108, 121, 122, 101, 114, 32, 116, 104, 114,
  101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70,
  101, 97, 116, 117, 114, 101, 32, 97, 110, 97, 108, 121, 122, 101, 114, 32,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 76, 111, 99, 97, 108, 32, 100, 101, 116, 97, 105, 108, 32,
  101, 110, 104, 97, 110, 99, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 68, 111, 102, 32, 97, 110, 97, 108, 121, 122, 101, 114, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 70, 114, 101, 113, 117, 101, 110, 99, 121, 32,
  97, 110, 97, 108, 121, 122, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 77, 111, 116, 105, 111, 110, 32, 97, 110, 97, 108, 121, 122, 101, 114,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 53, 44, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 108, 105, 112, 32, 108,
  101, 102, 116, 32, 47, 32, 114, 105, 103, 104, 116, 32, 61, 32, 98, 111,
  111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 98, 62, 70, 114, 97, 109, 101, 115,
  32, 115, 101, 116, 116, 105, 110, 103, 115, 58, 60, 47, 98, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 97, 99, 107, 32,
  38, 32, 119, 104, 105, 116, 101, 32, 61, 32, 98, 111, 111, 108, 32, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112,
  117, 116, 32, 102, 111, 114, 109, 97, 116, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 65, 110, 97, 103, 108, 121, 112, 104, 32, 114, 101, 100,
  47, 99, 121, 97, 110, 34, 44, 34, 65, 110, 97, 103, 108, 121, 112, 104,
  32, 114, 101, 100, 47, 99, 121, 97, 110, 32, 111, 112, 116, 105, 109, 105,
  122, 101, 100, 34, 44, 34, 65, 110, 97, 103, 108, 121, 112, 104, 32, 98,
  108, 117, 101, 47, 121, 101, 108, 108, 111, 119, 34, 44, 34, 65, 110, 97,
  103, 108, 121, 112, 104, 32, 98, 108, 117, 101, 47, 121, 101, 108, 108, 111,
  119, 32, 111, 112, 116, 105, 109, 105, 122, 101, 100, 34, 44, 34, 65, 110,
  97, 103, 108, 121, 112, 104, 32, 103, 114, 101, 101, 110, 47, 109, 97, 103,
  101, 110, 116, 97, 34, 44, 34, 65, 110, 97, 103, 108, 121, 112, 104, 32,
  103, 114, 101, 101, 110, 47, 109, 97, 103, 101, 110, 116, 97, 32, 111, 112,
  116, 105, 109, 105, 122, 101, 100, 34, 44, 34, 70, 117, 108, 108, 32, 115,
  105, 100, 101, 32, 98, 121, 32, 115, 105, 100, 101, 32, 107, 101, 101, 112,
  32, 119, 105, 100, 116, 104, 34, 44, 34, 70, 117, 108, 108, 32, 115, 105,
  100, 101, 32, 98, 121, 32, 117, 110, 99, 111, 109, 112, 114, 101, 115, 115,
  101, 100, 34, 44, 34, 70, 117, 108, 108, 32, 98, 111, 116, 116, 111, 109,
  47, 116, 111, 112, 34, 44, 34, 72, 97, 108, 102, 32, 115, 105, 100, 101,
  32, 32, 98, 121, 32, 115, 105, 100, 101, 34, 44, 34, 72, 97, 108, 102,
  32, 98, 111, 116, 116, 111, 109, 47, 116, 111, 112, 34, 44, 34, 73, 110,
  116, 101, 114, 108, 97, 99, 101, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 73, 110, 116, 101, 114, 108, 97, 99, 101, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 70, 117, 108, 108, 32, 72,
  68, 32, 102, 114, 97, 109, 101, 32, 112, 97, 99, 107, 105, 110, 103, 34,
  44, 34, 76, 101, 102, 116, 32, 97, 110, 100, 32, 114, 105, 103, 104, 116,
  32, 105, 109, 97, 103, 101, 32, 115, 116, 114, 101, 97, 109, 115, 34, 44,
  34, 68, 101, 112, 116, 104, 32, 109, 97, 112, 115, 32, 111, 110, 108, 121,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112,
  117, 116, 32, 116, 111, 32, 102, 111, 108, 100, 101, 114, 32, 61, 32, 98,
  111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  70, 111, 108, 100, 101, 114, 32, 110, 97, 109, 101, 32, 61, 32, 102, 111,
  108, 100, 101, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  71, 97, 109, 109, 97, 32, 99, 111, 109, 112, 101, 110, 115, 97, 116, 105,
  111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 50, 44, 48,
  44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 116,
  105, 45, 103, 104, 111, 115, 116, 105, 110, 103, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 50, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 98, 111, 111, 115,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 97, 103, 108, 121,
  112, 104, 32, 103, 108, 97, 115, 115, 101, 115, 32, 97, 100, 106, 117, 115,
  116, 109, 101, 110, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 117, 116, 111, 99, 114, 111, 112, 32, 61, 32, 98, 111,
  111, 108, 32, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 116, 32, 102, 114, 97, 109, 101, 32, 102, 111, 114, 109, 97, 116,
  32, 61, 32, 98, 111, 111, 108, 32, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 70, 114, 97, 109, 101, 32, 119, 105, 100, 116, 104,
  32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 48, 44, 49, 50, 56, 44,
  52, 48, 57, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70,
  114, 97, 109, 101, 32, 102, 111, 114, 109, 97, 116, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 49, 44, 34, 52, 58, 51, 34, 44, 34, 49, 54,
  58, 57, 34, 44, 34, 51, 58, 50, 34, 44, 34, 50, 58, 49, 34, 44,
  34, 50, 49, 58, 57, 34, 44, 34, 75, 101, 101, 112, 32, 97, 115, 112,
  101, 99, 116, 32, 114, 97, 116, 105, 111, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 70, 114, 97, 109, 101, 115, 32, 111, 102, 102, 115,
  101, 116, 32, 61, 32, 105, 110, 116, 40, 48, 44, 45, 53, 44, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 115,
  101, 32, 102, 114, 97, 109, 101, 32, 115, 116, 97, 99, 107, 32, 61, 32,
  98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 98, 62, 73, 110, 112, 117,
  116, 32, 115, 101, 116, 116, 105, 110, 103, 115, 58, 60, 47, 98, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 111, 99, 101,
  115, 115, 105, 110, 103, 32, 109, 111, 100, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 76, 97, 121, 101, 114, 32, 112, 114, 111, 99, 101,
  115, 115, 105, 110, 103, 34, 44, 34, 66, 97, 116, 99, 104, 32, 112, 114,
  111, 99, 101, 115, 115, 105, 110, 103, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 73, 110, 112, 117, 116, 32, 102, 111, 108, 100, 101, 114,
  32, 61, 32, 102, 111, 108, 100, 101, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 73, 110, 112, 117, 116, 32, 102, 114, 97, 109, 101,
  32, 102, 105, 108, 101, 115, 32, 110, 97, 109, 101, 32, 61, 32, 116, 101,
  120, 116, 40, 34, 102, 114, 97, 109, 101, 95, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 116, 97, 114, 116, 32, 102, 114, 97, 109,
  101, 32, 110, 117, 109, 98, 101, 114, 32, 61, 32, 105, 110, 116, 40, 48,
  44, 48, 44, 57, 57, 57, 57, 56, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 69, 110, 100, 32, 102, 114, 97, 109, 101, 32, 110, 117, 109,
  98, 101, 114, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49, 44, 57, 57,
  57, 57, 57, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 114,
  97, 109, 101, 32, 102, 105, 108, 101, 115, 32, 102, 111, 114, 109, 97, 116,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 46, 112, 110, 103, 34,
  44, 34, 46, 98, 109, 112, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 98, 62, 65, 100, 118,
  97, 110, 99, 101, 100, 32, 101, 100, 105, 116, 105, 110, 103, 58, 60, 47,
  98, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 99,
  116, 105, 118, 97, 116, 101, 32, 99, 117, 115, 116, 111, 109, 32, 102, 105,
  108, 116, 101, 114, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 111,
  102, 102, 34, 44, 34, 111, 110, 34, 44, 34, 108, 101, 102, 116, 32, 115,
  116, 114, 101, 97, 109, 32, 111, 110, 108, 121, 34, 44, 32, 34, 114, 105,
  103, 104, 116, 32, 115, 116, 114, 101, 97, 109, 32, 111, 110, 108, 121, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 115, 116, 111,
  109, 32, 102, 105, 108, 116, 101, 114, 32, 99, 111, 100, 101, 32, 61, 32,
  116, 101, 120, 116, 40, 49, 44, 34, 35, 32, 111, 108, 100, 32, 109, 111,
  118, 105, 101, 32, 35, 92, 110, 35, 45, 108, 117, 109, 105, 110, 97, 110,
  99, 101, 32, 45, 103, 105, 109, 112, 95, 115, 116, 114, 105, 112, 101, 115,
  95, 121, 32, 49, 48, 44, 51, 44, 48, 32, 45, 115, 101, 112, 105, 97,
  32, 92, 110, 92, 110, 35, 115, 105, 109, 112, 108, 101, 32, 118, 105, 110,
  116, 97, 103, 101, 35, 92, 110, 35, 45, 45, 102, 99, 32, 48, 44, 49,
  53, 44, 49, 50, 53, 32, 45, 114, 118, 32, 45, 103, 105, 109, 112, 95,
  99, 111, 109, 112, 111, 115, 101, 95, 101, 120, 99, 108, 117, 115, 105, 111,
  110, 32, 48, 46, 51, 32, 92, 110, 92, 110, 35, 32, 72, 68, 82, 32,
  112, 111, 112, 111, 117, 116, 32, 35, 92, 110, 35, 45, 103, 105, 109, 112,
  95, 109, 97, 112, 95, 116, 111, 110, 101, 115, 95, 102, 97, 115, 116, 32,
  50, 44, 48, 46, 51, 44, 51, 44, 50, 32, 45, 103, 105, 109, 112, 95,
  117, 110, 115, 104, 97, 114, 112, 95, 111, 99, 116, 97, 118, 101, 32, 52,
  44, 53, 44, 51, 44, 48, 44, 48, 44, 48, 92, 110, 92, 110, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 112, 116, 104, 32,
  102, 97, 100, 101, 32, 105, 110, 32, 102, 114, 97, 109, 101, 115, 32, 61,
  32, 105, 110, 116, 40, 48, 44, 48, 44, 49, 50, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 68, 101, 112, 116, 104, 32, 102, 97, 100,
  101, 32, 111, 117, 116, 32, 102, 114, 97, 109, 101, 115, 32, 61, 32, 105,
  110, 116, 40, 48, 44, 48, 44, 49, 50, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 98, 62,
  65, 100, 118, 97, 110, 99, 101, 100, 32, 113, 117, 97, 108, 105, 116, 121,
  32, 99, 111, 110, 116, 114, 111, 108, 58, 60, 47, 98, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 75, 101, 121, 32, 102, 114, 97,
  109, 101, 32, 114, 97, 116, 101, 32, 61, 32, 105, 110, 116, 40, 49, 44,
  49, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 116, 97, 98, 105, 108, 105, 122, 101, 114, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 53, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 80, 114, 101, 112, 114, 111, 99, 101, 115, 115, 111,
  114, 32, 114, 97, 100, 105, 117, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 80, 114, 101, 112, 114, 111, 99, 101, 115, 115, 111, 114, 32, 112, 111,
  119, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 115, 116,
  111, 109, 32, 100, 101, 112, 116, 104, 32, 99, 111, 114, 114, 101, 99, 116,
  105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 78, 111,
  110, 101, 34, 44, 34, 67, 117, 115, 116, 111, 109, 32, 99, 111, 114, 114,
  101, 99, 116, 105, 111, 110, 32, 109, 97, 112, 34, 44, 34, 83, 105, 110,
  103, 108, 101, 32, 99, 117, 115, 116, 111, 109, 32, 100, 101, 112, 116, 104,
  32, 109, 97, 112, 34, 44, 34, 67, 117, 115, 116, 111, 109, 32, 100, 101,
  112, 116, 104, 32, 109, 97, 112, 115, 32, 115, 116, 114, 101, 97, 109, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 110, 100, 101,
  114, 105, 110, 103, 32, 109, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 49, 44, 34, 82, 105, 103, 104, 116, 32, 101, 121, 101, 32,
  118, 105, 101, 119, 34, 44, 34, 66, 105, 100, 105, 114, 101, 99, 116, 105,
  111, 110, 97, 108, 32, 114, 101, 110, 100, 101, 114, 105, 110, 103, 34, 44,
  34, 65, 108, 105, 103, 110, 32, 105, 109, 97, 103, 101, 32, 115, 116, 114,
  101, 97, 109, 115, 34, 44, 34, 65, 110, 97, 103, 108, 121, 112, 104, 32,
  114, 101, 99, 111, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 98, 62, 80, 114, 101, 118, 105, 101, 119, 58, 60, 47, 98,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101,
  118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 67, 104, 111, 105,
  99, 101, 40, 34, 102, 105, 114, 115, 116, 32, 102, 114, 97, 109, 101, 34,
  44, 34, 108, 97, 115, 116, 32, 102, 114, 97, 109, 101, 34, 44, 34, 115,
  101, 108, 101, 99, 116, 101, 100, 32, 102, 114, 97, 109, 101, 34, 44, 34,
  102, 117, 108, 108, 32, 108, 97, 121, 101, 114, 32, 115, 116, 97, 99, 107,
  32, 45, 115, 108, 111, 119, 33, 45, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 80, 114, 101, 118, 105, 101, 119, 32, 102, 114, 97, 109,
  101, 32, 115, 101, 108, 101, 99, 116, 105, 111, 110, 32, 61, 32, 105, 110,
  116, 40, 48, 44, 48, 44, 57, 57, 57, 57, 57, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62,
  83, 119, 105, 116, 99, 104, 32, 105, 110, 112, 117, 116, 32, 108, 97, 121,
  101, 114, 115, 32, 116, 111, 32, 65, 108, 108, 46, 60, 47, 98, 62, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 84, 111, 109, 32, 75, 101, 105, 108, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 50, 47,
  49, 48, 47, 48, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 70, 105, 108, 116, 101,
  114, 32, 101, 120, 112, 108, 97, 105, 110, 101, 100, 32, 32, 104, 101, 114,
  101, 34, 44, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 116, 107,
  102, 105, 108, 116, 101, 114, 46, 98, 112, 108, 97, 99, 101, 100, 46, 110,
  101, 116, 47, 84, 75, 70, 105, 108, 116, 101, 114, 37, 50, 48, 116, 117,
  116, 111, 114, 105, 97, 108, 115, 37, 50, 48, 50, 68, 116, 111, 51, 68,
  37, 50, 48, 51, 68, 45, 97, 117, 116, 111, 109, 97, 116, 105, 99, 37,
  50, 48, 115, 116, 101, 114, 101, 111, 115, 99, 111, 112, 105, 99, 37, 50,
  48, 99, 111, 110, 118, 101, 114, 115, 105, 111, 110, 46, 104, 116, 109, 108,
  41, 10, 103, 105, 109, 112, 95, 116, 107, 95, 118, 105, 100, 101, 111, 51,
  68, 32, 58, 10, 115, 104, 61, 123, 45, 36, 50, 125, 32, 115, 119, 61,
  123, 45, 36, 115, 104, 45, 36, 51, 125, 32, 115, 105, 122, 101, 49, 61,
  123, 119, 125, 32, 115, 105, 122, 101, 50, 61, 123, 104, 125, 10, 45, 105,
  102, 32, 123, 110, 97, 114, 103, 40, 36, 95, 112, 114, 101, 118, 105, 101,
  119, 102, 108, 97, 103, 41, 61, 61, 48, 125, 32, 95, 112, 114, 101, 118,
  105, 101, 119, 102, 108, 97, 103, 61, 48, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 95, 112, 114, 101, 118, 105, 101, 119, 102,
  108, 97, 103, 33, 61, 48, 125, 32, 115, 104, 61, 123, 36, 115, 104, 42,
  123, 52, 48, 48, 47, 36, 50, 50, 125, 125, 32, 115, 119, 61, 123, 36,
  115, 119, 42, 123, 52, 48, 48, 47, 36, 50, 50, 125, 125, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 50, 54, 61, 61, 48,
  125, 10, 35, 35, 35, 35, 108, 97, 121, 101, 114, 32, 98, 97, 115, 101,
  100, 32, 99, 111, 110, 118, 101, 114, 115, 105, 111, 110, 35, 35, 35, 35,
  10, 45, 105, 102, 32, 123, 123, 36, 51, 52, 33, 61, 48, 125, 124, 124,
  123, 36, 51, 53, 33, 61, 48, 125, 125, 10, 45, 105, 102, 32, 123, 123,
  36, 51, 52, 62, 61, 123, 123, 64, 35, 125, 45, 36, 51, 53, 125, 125,
  124, 124, 123, 36, 51, 53, 62, 61, 123, 123, 64, 35, 125, 45, 36, 51,
  52, 125, 125, 125, 32, 45, 101, 114, 114, 111, 114, 91, 93, 32, 34, 70,
  97, 100, 101, 32, 111, 117, 116, 32, 111, 102, 32, 102, 114, 97, 109, 101,
  32, 114, 97, 110, 103, 101, 46, 34, 10, 45, 101, 110, 100, 105, 102, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 51, 33,
  61, 49, 52, 125, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48,
  44, 50, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  95, 112, 114, 101, 118, 105, 101, 119, 102, 108, 97, 103, 33, 61, 50, 125,
  32, 32, 102, 114, 97, 109, 101, 115, 61, 123, 64, 35, 125, 32, 45, 101,
  108, 115, 101, 32, 102, 114, 97, 109, 101, 115, 61, 49, 32, 32, 45, 101,
  110, 100, 105, 102, 10, 99, 111, 117, 110, 116, 101, 114, 61, 123, 64, 35,
  125, 32, 105, 110, 100, 101, 120, 61, 48, 10, 45, 105, 102, 32, 123, 36,
  95, 112, 114, 101, 118, 105, 101, 119, 102, 108, 97, 103, 33, 61, 48, 125,
  32, 45, 114, 32, 52, 48, 48, 44, 51, 50, 56, 32, 45, 101, 110, 100,
  105, 102, 10, 35, 32, 105, 109, 97, 103, 101, 32, 115, 116, 114, 101, 97,
  109, 32, 97, 108, 105, 103, 110, 109, 101, 110, 116, 32, 97, 110, 100, 32,
  50, 68, 32, 102, 105, 108, 116, 101, 114, 105, 110, 103, 32, 111, 110, 108,
  121, 32, 109, 111, 100, 101, 115, 10, 35, 45, 105, 102, 32, 123, 123, 36,
  52, 49, 61, 61, 51, 125, 38, 38, 123, 36, 95, 112, 114, 101, 118, 105,
  101, 119, 102, 108, 97, 103, 61, 61, 48, 125, 125, 32, 45, 101, 114, 114,
  111, 114, 91, 93, 32, 34, 65, 110, 97, 103, 108, 121, 112, 104, 32, 118,
  105, 100, 101, 111, 32, 114, 101, 99, 111, 110, 115, 116, 114, 117, 99, 116,
  105, 111, 110, 32, 105, 110, 32, 98, 97, 116, 99, 104, 32, 112, 114, 111,
  99, 101, 115, 115, 105, 110, 103, 32, 109, 111, 100, 101, 32, 111, 110, 108,
  121, 34, 32, 45, 101, 110, 100, 105, 102, 10, 102, 108, 97, 103, 51, 100,
  61, 48, 32, 45, 105, 102, 32, 123, 36, 52, 49, 33, 61, 50, 125, 10,
  45, 105, 102, 32, 123, 33, 123, 123, 36, 50, 61, 61, 48, 125, 38, 38,
  123, 36, 51, 61, 61, 48, 125, 38, 38, 123, 36, 49, 61, 61, 50, 52,
  125, 38, 38, 123, 36, 49, 51, 61, 61, 49, 52, 125, 38, 38, 123, 36,
  51, 50, 33, 61, 48, 125, 125, 125, 32, 102, 108, 97, 103, 51, 100, 61,
  49, 10, 35, 32, 115, 116, 97, 114, 116, 32, 51, 68, 32, 99, 111, 110,
  118, 101, 114, 115, 105, 111, 110, 32, 112, 101, 114, 32, 102, 114, 97, 109,
  101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 102, 114, 97, 109,
  101, 115, 125, 10, 35, 32, 112, 114, 101, 112, 97, 114, 101, 32, 105, 109,
  97, 103, 101, 115, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110,
  111, 116, 104, 105, 110, 103, 91, 36, 105, 110, 100, 101, 120, 93, 10, 35,
  32, 99, 114, 101, 97, 116, 101, 32, 100, 101, 112, 116, 104, 32, 109, 97,
  112, 115, 10, 45, 105, 102, 32, 123, 123, 36, 52, 48, 61, 61, 48, 125,
  124, 124, 123, 36, 52, 48, 61, 61, 49, 125, 125, 10, 45, 45, 103, 105,
  109, 112, 95, 116, 107, 95, 100, 101, 112, 116, 104, 109, 97, 112, 91, 36,
  105, 110, 100, 101, 120, 93, 32, 36, 49, 44, 36, 52, 44, 36, 53, 44,
  36, 54, 44, 36, 55, 44, 36, 56, 44, 36, 57, 44, 36, 51, 56, 44,
  36, 51, 57, 44, 123, 119, 42, 123, 36, 51, 55, 47, 49, 48, 48, 48,
  125, 125, 10, 45, 114, 91, 45, 49, 93, 32, 36, 115, 105, 122, 101, 49,
  44, 36, 115, 105, 122, 101, 50, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 52, 48, 61, 61, 49, 125, 10, 105, 110, 102, 105,
  108, 101, 99, 61, 34, 99, 111, 114, 114, 101, 99, 116, 105, 111, 110, 46,
  112, 110, 103, 34, 32, 105, 110, 112, 97, 116, 104, 99, 61, 34, 36, 50,
  55, 47, 34, 36, 105, 110, 102, 105, 108, 101, 99, 34, 34, 10, 45, 105,
  110, 112, 117, 116, 91, 45, 49, 93, 32, 64, 123, 34, 45, 113, 117, 111,
  116, 101, 32, 92, 34, 34, 36, 105, 110, 112, 97, 116, 104, 99, 34, 92,
  34, 34, 125, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 44,
  45, 50, 93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 114, 103, 98,
  97, 91, 45, 49, 44, 45, 50, 93, 32, 45, 116, 111, 95, 114, 103, 98,
  91, 45, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 52, 48, 61,
  61, 50, 125, 10, 105, 110, 102, 105, 108, 101, 99, 61, 34, 100, 101, 112,
  116, 104, 109, 97, 112, 46, 112, 110, 103, 34, 32, 105, 110, 112, 97, 116,
  104, 99, 61, 34, 36, 50, 55, 47, 34, 36, 105, 110, 102, 105, 108, 101,
  99, 34, 34, 10, 45, 105, 110, 112, 117, 116, 91, 45, 49, 93, 32, 64,
  123, 34, 45, 113, 117, 111, 116, 101, 32, 92, 34, 34, 36, 105, 110, 112,
  97, 116, 104, 99, 34, 92, 34, 34, 125, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 52, 48, 61, 61, 51, 125, 10, 45, 105, 102, 32, 123, 36, 95,
  112, 114, 101, 118, 105, 101, 119, 102, 108, 97, 103, 61, 61, 50, 125, 10,
  105, 110, 102, 105, 108, 101, 99, 61, 34, 100, 101, 112, 116, 104, 109, 97,
  112, 95, 34, 36, 95, 109, 97, 112, 105, 110, 34, 46, 112, 110, 103, 34,
  32, 105, 110, 112, 97, 116, 104, 99, 61, 34, 36, 50, 55, 47, 100, 101,
  112, 116, 104, 109, 97, 112, 115, 47, 34, 36, 105, 110, 102, 105, 108, 101,
  99, 34, 34, 10, 45, 101, 108, 115, 101, 10, 105, 110, 102, 105, 108, 101,
  99, 61, 34, 100, 101, 112, 116, 104, 109, 97, 112, 95, 34, 123, 36, 102,
  114, 97, 109, 101, 115, 45, 36, 105, 110, 100, 101, 120, 125, 34, 46, 112,
  110, 103, 34, 32, 105, 110, 112, 97, 116, 104, 99, 61, 34, 36, 50, 55,
  47, 100, 101, 112, 116, 104, 109, 97, 112, 115, 47, 34, 36, 105, 110, 102,
  105, 108, 101, 99, 34, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  110, 112, 117, 116, 91, 45, 49, 93, 32, 64, 123, 34, 45, 113, 117, 111,
  116, 101, 32, 92, 34, 34, 36, 105, 110, 112, 97, 116, 104, 99, 34, 92,
  34, 34, 125, 10, 45, 114, 118, 91, 36, 105, 110, 100, 101, 120, 44, 45,
  50, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  95, 112, 114, 101, 118, 105, 101, 119, 102, 108, 97, 103, 33, 61, 48, 125,
  32, 45, 114, 32, 52, 48, 48, 44, 51, 50, 56, 32, 45, 101, 110, 100,
  105, 102, 10, 35, 32, 109, 111, 116, 105, 111, 110, 32, 97, 110, 97, 108,
  121, 115, 105, 115, 10, 45, 105, 102, 32, 123, 36, 49, 48, 33, 61, 48,
  125, 10, 45, 105, 102, 32, 123, 36, 95, 112, 114, 101, 118, 105, 101, 119,
  102, 108, 97, 103, 61, 61, 50, 125, 32, 45, 45, 103, 105, 109, 112, 95,
  100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 48, 93, 32, 45, 109,
  118, 91, 45, 52, 93, 32, 45, 49, 10, 45, 99, 111, 109, 112, 111, 115,
  101, 95, 100, 105, 102, 102, 101, 114, 101, 110, 99, 101, 91, 45, 49, 44,
  45, 50, 93, 32, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 45,
  49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10,
  45, 116, 50, 91, 45, 49, 93, 32, 48, 44, 123, 123, 36, 51, 55, 47,
  50, 125, 43, 49, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91,
  45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  10, 45, 101, 108, 115, 101, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111,
  95, 110, 111, 116, 104, 105, 110, 103, 91, 36, 105, 110, 100, 101, 120, 93,
  32, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105,
  110, 103, 91, 123, 36, 105, 110, 100, 101, 120, 43, 49, 125, 93, 10, 45,
  99, 111, 109, 112, 111, 115, 101, 95, 100, 105, 102, 102, 101, 114, 101, 110,
  99, 101, 91, 45, 49, 44, 45, 50, 93, 32, 45, 108, 117, 109, 105, 110,
  97, 110, 99, 101, 91, 45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 10, 45, 116, 50, 91, 45, 49, 93, 32, 48, 44,
  123, 123, 36, 51, 55, 47, 50, 125, 43, 49, 125, 10, 45, 110, 101, 103,
  97, 116, 105, 118, 101, 91, 45, 49, 93, 32, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36, 105, 110, 100,
  101, 120, 60, 61, 123, 36, 102, 114, 97, 109, 101, 115, 45, 50, 125, 125,
  32, 45, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  110, 100, 105, 102, 10, 105, 110, 100, 101, 120, 61, 123, 36, 105, 110, 100,
  101, 120, 43, 49, 125, 32, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32,
  123, 36, 49, 48, 33, 61, 48, 125, 10, 45, 105, 102, 32, 123, 36, 95,
  112, 114, 101, 118, 105, 101, 119, 102, 108, 97, 103, 61, 61, 50, 125, 10,
  45, 105, 102, 32, 123, 36, 52, 50, 61, 61, 48, 125, 32, 32, 105, 110,
  102, 105, 108, 101, 61, 123, 36, 50, 57, 125, 32, 45, 101, 108, 105, 102,
  32, 123, 36, 52, 50, 61, 61, 49, 125, 32, 105, 110, 102, 105, 108, 101,
  61, 123, 36, 51, 48, 125, 32, 45, 101, 108, 105, 102, 32, 123, 36, 52,
  50, 61, 61, 50, 125, 32, 105, 110, 102, 105, 108, 101, 61, 123, 36, 52,
  51, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  105, 110, 102, 105, 108, 101, 61, 61, 50, 125, 32, 45, 114, 118, 91, 45,
  49, 44, 45, 50, 93, 32, 45, 101, 108, 115, 101, 32, 45, 105, 102, 32,
  123, 36, 105, 110, 102, 105, 108, 101, 62, 61, 123, 36, 50, 57, 43, 50,
  125, 125, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 100, 105, 102, 102,
  101, 114, 101, 110, 99, 101, 91, 45, 52, 44, 45, 53, 93, 32, 45, 108,
  117, 109, 105, 110, 97, 110, 99, 101, 91, 45, 52, 93, 32, 45, 110, 91,
  45, 52, 93, 32, 48, 44, 50, 53, 53, 10, 45, 116, 50, 91, 45, 52,
  93, 32, 48, 44, 49, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91,
  45, 52, 93, 32, 45, 110, 91, 45, 52, 93, 32, 48, 44, 50, 53, 53,
  10, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 52, 93, 32, 45,
  99, 111, 109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101, 110, 91, 45,
  49, 44, 45, 52, 93, 10, 45, 109, 118, 91, 45, 51, 93, 32, 45, 49,
  32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  98, 108, 117, 114, 95, 120, 121, 91, 45, 50, 93, 32, 123, 119, 42, 123,
  36, 51, 55, 47, 49, 48, 48, 48, 125, 125, 10, 45, 105, 102, 32, 123,
  36, 105, 110, 102, 105, 108, 101, 33, 61, 36, 50, 57, 125, 32, 45, 105,
  102, 32, 123, 36, 49, 48, 62, 61, 48, 125, 32, 45, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103, 104, 116, 101, 110,
  91, 45, 49, 44, 45, 50, 93, 32, 123, 97, 98, 115, 40, 36, 49, 48,
  41, 47, 53, 125, 10, 45, 101, 108, 115, 101, 32, 45, 110, 101, 103, 97,
  116, 105, 118, 101, 91, 45, 50, 93, 32, 45, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101, 110, 91, 45, 49,
  44, 45, 50, 93, 32, 123, 97, 98, 115, 40, 36, 49, 48, 41, 47, 53,
  125, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 108, 115, 101, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 114,
  109, 91, 123, 36, 99, 111, 117, 110, 116, 101, 114, 43, 51, 125, 93, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 102, 114, 97, 109, 101, 115,
  45, 50, 125, 10, 45, 109, 118, 91, 123, 36, 99, 111, 117, 110, 116, 101,
  114, 43, 54, 125, 93, 32, 123, 36, 99, 111, 117, 110, 116, 101, 114, 43,
  50, 125, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 100, 97, 114, 107,
  101, 110, 91, 123, 36, 99, 111, 117, 110, 116, 101, 114, 43, 50, 125, 44,
  123, 36, 99, 111, 117, 110, 116, 101, 114, 43, 51, 125, 93, 10, 45, 114,
  118, 91, 123, 36, 99, 111, 117, 110, 116, 101, 114, 43, 49, 125, 44, 123,
  36, 99, 111, 117, 110, 116, 101, 114, 43, 50, 125, 93, 10, 45, 98, 108,
  117, 114, 95, 120, 121, 91, 123, 36, 99, 111, 117, 110, 116, 101, 114, 43,
  49, 125, 93, 32, 123, 119, 42, 123, 36, 51, 55, 47, 49, 48, 48, 48,
  125, 125, 10, 45, 105, 102, 32, 123, 36, 49, 48, 62, 61, 48, 125, 10,
  45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105,
  103, 104, 116, 101, 110, 91, 123, 36, 99, 111, 117, 110, 116, 101, 114, 43,
  49, 125, 44, 123, 36, 99, 111, 117, 110, 116, 101, 114, 43, 50, 125, 93,
  32, 123, 97, 98, 115, 40, 36, 49, 48, 41, 47, 53, 125, 10, 45, 101,
  108, 115, 101, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 123, 36,
  99, 111, 117, 110, 116, 101, 114, 43, 49, 125, 93, 10, 45, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101, 110,
  91, 123, 36, 99, 111, 117, 110, 116, 101, 114, 43, 49, 125, 44, 123, 36,
  99, 111, 117, 110, 116, 101, 114, 43, 50, 125, 93, 32, 123, 97, 98, 115,
  40, 36, 49, 48, 41, 47, 53, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  99, 111, 117, 110, 116, 101, 114, 61, 123, 36, 99, 111, 117, 110, 116, 101,
  114, 43, 50, 125, 32, 45, 100, 111, 110, 101, 10, 45, 114, 118, 91, 45,
  51, 44, 45, 52, 93, 32, 45, 98, 108, 117, 114, 95, 120, 121, 91, 45,
  52, 93, 32, 123, 119, 42, 123, 36, 51, 55, 47, 49, 48, 48, 48, 125,
  125, 10, 45, 105, 102, 32, 123, 36, 49, 48, 62, 61, 48, 125, 32, 45,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103,
  104, 116, 101, 110, 91, 45, 51, 44, 45, 52, 93, 32, 123, 97, 98, 115,
  40, 36, 49, 48, 41, 47, 53, 125, 10, 45, 101, 108, 115, 101, 32, 45,
  110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 52, 93, 32, 45, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101,
  110, 91, 45, 51, 44, 45, 52, 93, 32, 123, 97, 98, 115, 40, 36, 49,
  48, 41, 47, 53, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 35, 32, 99, 114, 101,
  97, 116, 101, 32, 115, 101, 99, 111, 110, 100, 32, 118, 105, 101, 119, 32,
  102, 114, 97, 109, 101, 115, 101, 116, 10, 45, 105, 102, 32, 123, 36, 95,
  112, 114, 101, 118, 105, 101, 119, 102, 108, 97, 103, 61, 61, 50, 125, 32,
  45, 105, 102, 32, 123, 36, 50, 52, 33, 61, 48, 125, 32, 45, 114, 109,
  91, 45, 50, 93, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100,
  105, 102, 10, 105, 110, 100, 101, 120, 61, 123, 45, 49, 125, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 102, 114, 97, 109, 101, 115, 10, 45, 105,
  102, 32, 123, 36, 49, 51, 33, 61, 49, 53, 125, 10, 45, 105, 102, 32,
  123, 36, 52, 49, 61, 61, 48, 125, 32, 45, 105, 102, 32, 123, 36, 115,
  119, 60, 61, 48, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91,
  36, 105, 110, 100, 101, 120, 93, 32, 45, 101, 110, 100, 105, 102, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 95, 112, 114, 101,
  118, 105, 101, 119, 102, 108, 97, 103, 33, 61, 50, 125, 10, 45, 105, 102,
  32, 123, 36, 51, 52, 33, 61, 48, 125, 32, 45, 105, 102, 32, 123, 123,
  45, 36, 105, 110, 100, 101, 120, 125, 60, 61, 36, 51, 52, 125, 32, 115,
  119, 61, 123, 123, 123, 45, 36, 105, 110, 100, 101, 120, 125, 47, 36, 51,
  52, 125, 42, 36, 115, 119, 125, 32, 115, 104, 61, 123, 123, 123, 45, 36,
  105, 110, 100, 101, 120, 125, 47, 36, 51, 52, 125, 42, 36, 115, 104, 125,
  10, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 51, 53, 33, 61, 48, 125, 32, 45, 105, 102, 32,
  123, 45, 123, 36, 105, 110, 100, 101, 120, 43, 49, 125, 62, 61, 123, 36,
  102, 114, 97, 109, 101, 115, 45, 36, 51, 53, 125, 125, 32, 115, 119, 61,
  123, 36, 115, 119, 42, 123, 123, 36, 102, 114, 97, 109, 101, 115, 45, 123,
  45, 123, 36, 105, 110, 100, 101, 120, 43, 49, 125, 125, 125, 47, 36, 51,
  53, 125, 125, 10, 115, 104, 61, 123, 36, 115, 104, 42, 123, 123, 36, 102,
  114, 97, 109, 101, 115, 45, 123, 45, 123, 36, 105, 110, 100, 101, 120, 43,
  49, 125, 125, 125, 47, 36, 51, 53, 125, 125, 32, 45, 101, 110, 100, 105,
  102, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 52, 49, 61, 61, 48, 125, 10, 45, 114, 91,
  36, 105, 110, 100, 101, 120, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 44, 49, 44, 50, 32, 45, 115, 91, 36, 105, 110, 100, 101, 120, 93,
  32, 99, 32, 45, 102, 91, 36, 105, 110, 100, 101, 120, 93, 32, 48, 32,
  45, 110, 91, 123, 36, 105, 110, 100, 101, 120, 45, 49, 125, 93, 32, 48,
  44, 36, 115, 119, 10, 45, 97, 91, 36, 105, 110, 100, 101, 120, 44, 123,
  36, 105, 110, 100, 101, 120, 45, 49, 125, 93, 32, 99, 32, 45, 119, 97,
  114, 112, 91, 123, 36, 105, 110, 100, 101, 120, 45, 49, 125, 93, 32, 91,
  36, 105, 110, 100, 101, 120, 93, 44, 49, 10, 45, 115, 104, 105, 102, 116,
  91, 123, 36, 105, 110, 100, 101, 120, 45, 49, 125, 93, 32, 36, 115, 104,
  44, 48, 32, 45, 114, 109, 91, 36, 105, 110, 100, 101, 120, 93, 10, 45,
  101, 108, 115, 101, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110,
  111, 116, 104, 105, 110, 103, 91, 36, 105, 110, 100, 101, 120, 93, 10, 45,
  109, 118, 91, 45, 49, 93, 32, 123, 36, 102, 114, 97, 109, 101, 115, 43,
  123, 36, 105, 110, 100, 101, 120, 43, 49, 125, 125, 10, 45, 114, 91, 36,
  105, 110, 100, 101, 120, 44, 123, 36, 102, 114, 97, 109, 101, 115, 43, 123,
  36, 105, 110, 100, 101, 120, 43, 49, 125, 125, 93, 32, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 44, 50, 10, 45, 115, 91, 36, 105, 110,
  100, 101, 120, 93, 32, 99, 32, 45, 102, 91, 36, 105, 110, 100, 101, 120,
  93, 32, 48, 32, 45, 110, 91, 123, 36, 105, 110, 100, 101, 120, 45, 49,
  125, 93, 32, 48, 44, 123, 97, 98, 115, 40, 36, 115, 119, 47, 50, 41,
  125, 32, 45, 97, 91, 36, 105, 110, 100, 101, 120, 44, 123, 36, 105, 110,
  100, 101, 120, 45, 49, 125, 93, 32, 99, 10, 45, 110, 101, 103, 97, 116,
  105, 118, 101, 91, 123, 36, 102, 114, 97, 109, 101, 115, 43, 123, 36, 105,
  110, 100, 101, 120, 43, 49, 125, 125, 93, 32, 45, 115, 91, 123, 36, 102,
  114, 97, 109, 101, 115, 43, 123, 36, 105, 110, 100, 101, 120, 43, 49, 125,
  125, 93, 32, 99, 10, 45, 102, 91, 123, 36, 102, 114, 97, 109, 101, 115,
  43, 123, 36, 105, 110, 100, 101, 120, 43, 50, 125, 125, 93, 32, 48, 32,
  45, 110, 91, 123, 36, 102, 114, 97, 109, 101, 115, 43, 123, 36, 105, 110,
  100, 101, 120, 43, 49, 125, 125, 93, 32, 48, 44, 123, 45, 97, 98, 115,
  40, 36, 115, 119, 47, 50, 41, 125, 10, 45, 97, 91, 123, 36, 102, 114,
  97, 109, 101, 115, 43, 123, 36, 105, 110, 100, 101, 120, 43, 49, 125, 125,
  44, 123, 36, 102, 114, 97, 109, 101, 115, 43, 123, 36, 105, 110, 100, 101,
  120, 43, 50, 125, 125, 93, 32, 99, 10, 45, 119, 97, 114, 112, 91, 123,
  36, 102, 114, 97, 109, 101, 115, 43, 123, 36, 105, 110, 100, 101, 120, 43,
  48, 125, 125, 93, 32, 91, 123, 36, 102, 114, 97, 109, 101, 115, 43, 123,
  36, 105, 110, 100, 101, 120, 43, 49, 125, 125, 93, 44, 49, 10, 45, 119,
  97, 114, 112, 91, 123, 36, 105, 110, 100, 101, 120, 45, 49, 125, 93, 32,
  91, 36, 105, 110, 100, 101, 120, 93, 44, 49, 10, 45, 115, 104, 105, 102,
  116, 91, 123, 36, 105, 110, 100, 101, 120, 45, 49, 125, 93, 32, 36, 115,
  104, 44, 48, 10, 45, 114, 109, 91, 36, 105, 110, 100, 101, 120, 44, 123,
  36, 102, 114, 97, 109, 101, 115, 43, 123, 36, 105, 110, 100, 101, 120, 43,
  49, 125, 125, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  105, 102, 10, 115, 104, 61, 123, 45, 36, 50, 125, 32, 115, 119, 61, 123,
  45, 36, 115, 104, 45, 36, 51, 125, 10, 45, 105, 102, 32, 123, 36, 95,
  112, 114, 101, 118, 105, 101, 119, 102, 108, 97, 103, 33, 61, 48, 125, 32,
  115, 104, 61, 123, 36, 115, 104, 42, 123, 52, 48, 48, 47, 36, 50, 50,
  125, 125, 32, 115, 119, 61, 123, 36, 115, 119, 42, 123, 52, 48, 48, 47,
  36, 50, 50, 125, 125, 32, 45, 101, 110, 100, 105, 102, 10, 105, 110, 100,
  101, 120, 61, 123, 36, 105, 110, 100, 101, 120, 45, 49, 125, 32, 45, 100,
  111, 110, 101, 10, 35, 32, 102, 114, 97, 109, 101, 115, 32, 111, 102, 102,
  115, 101, 116, 10, 45, 105, 102, 32, 123, 36, 49, 51, 33, 61, 49, 53,
  125, 32, 45, 105, 102, 32, 123, 36, 95, 112, 114, 101, 118, 105, 101, 119,
  102, 108, 97, 103, 33, 61, 50, 125, 10, 45, 105, 102, 32, 123, 36, 50,
  52, 62, 61, 48, 125, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 50,
  52, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 45, 103, 105, 109, 112,
  95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 36, 102, 114, 97,
  109, 101, 115, 93, 10, 45, 109, 118, 91, 45, 49, 93, 32, 36, 102, 114,
  97, 109, 101, 115, 32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 115, 101,
  32, 99, 111, 117, 110, 116, 101, 114, 61, 123, 49, 125, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 97, 98, 115, 40, 36, 50, 52, 41, 125, 32,
  45, 114, 109, 91, 36, 102, 114, 97, 109, 101, 115, 93, 10, 45, 45, 103,
  105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 123,
  45, 36, 99, 111, 117, 110, 116, 101, 114, 125, 93, 32, 45, 109, 118, 91,
  45, 49, 93, 32, 123, 45, 36, 99, 111, 117, 110, 116, 101, 114, 45, 49,
  125, 32, 99, 111, 117, 110, 116, 101, 114, 61, 123, 36, 99, 111, 117, 110,
  116, 101, 114, 43, 49, 125, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105,
  102, 10, 35, 32, 97, 117, 116, 111, 99, 114, 111, 112, 32, 102, 114, 97,
  109, 101, 115, 10, 45, 105, 102, 32, 123, 36, 50, 48, 61, 61, 49, 125,
  32, 45, 105, 102, 32, 123, 36, 49, 51, 33, 61, 49, 53, 125, 10, 45,
  105, 102, 32, 123, 36, 115, 104, 62, 61, 48, 125, 32, 45, 99, 114, 111,
  112, 32, 36, 115, 104, 44, 48, 44, 123, 119, 125, 44, 123, 104, 125, 32,
  45, 101, 108, 115, 101, 32, 45, 99, 114, 111, 112, 32, 48, 44, 48, 44,
  123, 119, 43, 36, 115, 104, 125, 44, 123, 104, 125, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 115, 119, 62, 61, 48, 125, 32,
  45, 99, 114, 111, 112, 32, 36, 115, 119, 44, 48, 44, 123, 119, 125, 44,
  123, 104, 125, 32, 45, 101, 108, 115, 101, 32, 45, 99, 114, 111, 112, 32,
  48, 44, 48, 44, 123, 119, 43, 36, 115, 119, 125, 44, 123, 104, 125, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 32, 45, 101,
  110, 100, 105, 102, 10, 35, 101, 110, 100, 32, 105, 109, 97, 103, 101, 32,
  115, 116, 114, 101, 97, 109, 32, 97, 108, 105, 103, 110, 109, 101, 110, 116,
  32, 97, 110, 100, 32, 50, 68, 32, 109, 111, 100, 101, 32, 98, 121, 112,
  97, 115, 115, 10, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105,
  102, 10, 35, 32, 97, 112, 112, 108, 121, 32, 99, 117, 115, 116, 111, 109,
  32, 102, 105, 108, 116, 101, 114, 10, 45, 105, 102, 32, 123, 36, 95, 112,
  114, 101, 118, 105, 101, 119, 102, 108, 97, 103, 33, 61, 50, 125, 10, 45,
  105, 102, 32, 123, 36, 51, 50, 33, 61, 48, 125, 32, 45, 105, 102, 32,
  123, 36, 49, 51, 33, 61, 49, 53, 125, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 103, 105, 109,
  112, 95, 99, 117, 115, 116, 111, 109, 95, 99, 111, 100, 101, 32, 34, 36,
  51, 51, 34, 44, 48, 44, 48, 44, 48, 32, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 108, 115, 101, 10, 45, 105, 102, 32, 123, 36,
  51, 50, 61, 61, 49, 125, 32, 45, 105, 102, 32, 123, 36, 49, 51, 33,
  61, 49, 53, 125, 32, 45, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111,
  109, 95, 99, 111, 100, 101, 91, 48, 44, 49, 93, 32, 34, 36, 51, 51,
  34, 44, 48, 44, 48, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 51, 50, 61, 61, 50, 125, 32, 45, 105,
  102, 32, 123, 36, 49, 51, 33, 61, 49, 53, 125, 32, 45, 108, 91, 48,
  93, 32, 45, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 99,
  111, 100, 101, 32, 34, 36, 51, 51, 34, 44, 48, 44, 48, 44, 48, 32,
  45, 101, 110, 100, 108, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 51, 50, 61, 61, 51, 125, 32, 45, 105, 102, 32,
  123, 36, 49, 51, 33, 61, 49, 53, 125, 32, 45, 108, 91, 49, 93, 32,
  45, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 99, 111, 100,
  101, 32, 34, 36, 51, 51, 34, 44, 48, 44, 48, 44, 48, 32, 45, 101,
  110, 100, 108, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105,
  102, 32, 45, 101, 110, 100, 105, 102, 10, 35, 32, 97, 108, 105, 103, 110,
  32, 115, 116, 101, 114, 101, 111, 115, 99, 111, 112, 105, 99, 32, 105, 109,
  97, 103, 101, 115, 10, 45, 105, 102, 32, 123, 36, 52, 49, 61, 61, 50,
  125, 32, 45, 105, 102, 32, 123, 123, 36, 49, 51, 61, 61, 49, 52, 125,
  124, 124, 123, 36, 49, 51, 61, 61, 49, 53, 125, 125, 32, 45, 101, 114,
  114, 111, 114, 91, 93, 32, 34, 79, 117, 116, 112, 117, 116, 32, 102, 111,
  114, 109, 97, 116, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100,
  32, 102, 111, 114, 32, 105, 109, 97, 103, 101, 32, 115, 116, 114, 101, 97,
  109, 32, 97, 108, 105, 103, 110, 109, 101, 110, 116, 34, 32, 45, 101, 110,
  100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 49, 50, 61, 61, 49, 125, 32, 45, 97, 112, 112, 108, 121, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 103, 105, 109, 112, 95, 98,
  108, 97, 99, 107, 97, 110, 100, 119, 104, 105, 116, 101, 32, 48, 46, 51,
  44, 48, 44, 48, 46, 54, 44, 48, 44, 48, 46, 49, 44, 48, 44, 49,
  44, 49, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 50,
  44, 48, 44, 48, 44, 48, 44, 49, 54, 44, 52, 44, 48, 44, 48, 44,
  48, 34, 44, 50, 32, 45, 101, 110, 100, 105, 102, 10, 99, 111, 117, 110,
  116, 101, 114, 61, 123, 36, 102, 114, 97, 109, 101, 115, 45, 49, 125, 32,
  105, 110, 100, 101, 120, 61, 123, 45, 50, 125, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 36, 102, 114, 97, 109, 101, 115, 10, 45, 105, 102, 32, 123,
  123, 36, 49, 51, 33, 61, 49, 52, 125, 38, 38, 123, 36, 49, 51, 33,
  61, 49, 53, 125, 125, 10, 45, 103, 105, 109, 112, 95, 116, 107, 95, 115,
  116, 101, 114, 101, 111, 105, 109, 97, 103, 101, 91, 45, 49, 44, 36, 99,
  111, 117, 110, 116, 101, 114, 93, 32, 36, 49, 51, 44, 36, 49, 49, 44,
  36, 49, 54, 44, 36, 49, 55, 44, 36, 49, 56, 44, 36, 49, 57, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 51, 61, 61, 49, 53, 125, 32,
  45, 114, 109, 91, 48, 44, 36, 105, 110, 100, 101, 120, 93, 10, 45, 101,
  110, 100, 105, 102, 32, 99, 111, 117, 110, 116, 101, 114, 61, 123, 36, 99,
  111, 117, 110, 116, 101, 114, 45, 49, 125, 32, 105, 110, 100, 101, 120, 61,
  123, 36, 105, 110, 100, 101, 120, 45, 49, 125, 32, 45, 100, 111, 110, 101,
  10, 35, 32, 97, 100, 106, 117, 115, 116, 32, 111, 117, 116, 112, 117, 116,
  32, 105, 109, 97, 103, 101, 32, 115, 116, 114, 101, 97, 109, 115, 10, 45,
  105, 102, 32, 123, 36, 49, 51, 61, 61, 49, 52, 125, 32, 45, 97, 112,
  112, 108, 121, 95, 103, 97, 109, 109, 97, 32, 36, 49, 54, 32, 45, 116,
  107, 95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112,
  114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 49, 44, 49, 44, 36, 49,
  55, 44, 48, 44, 48, 44, 48, 44, 49, 48, 48, 44, 50, 53, 54, 44,
  48, 44, 48, 44, 49, 44, 49, 48, 44, 55, 44, 48, 10, 45, 103, 105,
  109, 112, 95, 109, 105, 120, 95, 108, 97, 98, 32, 49, 44, 48, 44, 48,
  44, 36, 49, 56, 44, 48, 44, 48, 44, 36, 49, 56, 44, 48, 44, 48,
  44, 48, 44, 50, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 35, 32,
  114, 101, 115, 105, 122, 101, 32, 102, 114, 97, 109, 101, 115, 32, 116, 111,
  32, 111, 117, 116, 112, 117, 116, 32, 102, 111, 114, 109, 97, 116, 10, 45,
  105, 102, 32, 123, 36, 50, 49, 61, 61, 49, 125, 32, 45, 105, 102, 32,
  123, 36, 49, 51, 33, 61, 49, 51, 125, 10, 45, 105, 102, 32, 123, 36,
  50, 51, 61, 61, 48, 125, 32, 45, 114, 32, 36, 50, 50, 44, 123, 36,
  50, 50, 42, 48, 46, 55, 53, 125, 44, 49, 44, 123, 115, 125, 44, 54,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 51, 61, 61, 49, 125, 32,
  45, 114, 32, 36, 50, 50, 44, 123, 123, 36, 50, 50, 42, 57, 125, 47,
  49, 54, 125, 44, 49, 44, 123, 115, 125, 44, 54, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 50, 51, 61, 61, 50, 125, 32, 45, 114, 32, 36, 50,
  50, 44, 123, 123, 36, 50, 50, 42, 50, 125, 47, 51, 125, 44, 49, 44,
  123, 115, 125, 44, 54, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 51,
  61, 61, 51, 125, 32, 45, 114, 32, 36, 50, 50, 44, 123, 36, 50, 50,
  42, 48, 46, 53, 125, 44, 49, 44, 123, 115, 125, 44, 54, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 50, 51, 61, 61, 52, 125, 32, 45, 114, 32,
  36, 50, 50, 44, 123, 123, 36, 50, 50, 42, 57, 125, 47, 50, 49, 125,
  44, 49, 44, 123, 115, 125, 44, 54, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 50, 51, 61, 61, 53, 125, 32, 45, 114, 32, 36, 50, 50, 44, 123,
  36, 50, 50, 42, 123, 104, 47, 119, 125, 125, 44, 49, 44, 123, 115, 125,
  44, 54, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102,
  32, 45, 101, 110, 100, 105, 102, 32, 32, 45, 99, 32, 48, 44, 50, 53,
  53, 10, 45, 105, 102, 32, 123, 36, 50, 53, 61, 61, 49, 125, 32, 45,
  114, 118, 32, 45, 101, 110, 100, 105, 102, 10, 35, 32, 115, 97, 118, 101,
  32, 102, 114, 97, 109, 101, 115, 32, 116, 111, 32, 102, 111, 108, 100, 101,
  114, 10, 45, 105, 102, 32, 123, 36, 49, 52, 61, 61, 49, 125, 10, 45,
  105, 102, 32, 123, 123, 36, 51, 49, 61, 61, 48, 125, 124, 124, 123, 36,
  49, 51, 61, 61, 49, 53, 125, 125, 32, 101, 110, 100, 61, 34, 46, 112,
  110, 103, 34, 32, 45, 101, 108, 115, 101, 32, 101, 110, 100, 61, 34, 46,
  98, 109, 112, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 118, 10,
  105, 110, 100, 101, 120, 61, 123, 48, 125, 32, 110, 97, 109, 101, 61, 48,
  10, 45, 105, 102, 32, 123, 123, 36, 49, 51, 61, 61, 49, 52, 125, 38,
  38, 123, 36, 102, 108, 97, 103, 51, 100, 61, 61, 49, 125, 125, 10, 102,
  105, 108, 101, 108, 101, 102, 116, 61, 34, 36, 49, 53, 47, 102, 114, 97,
  109, 101, 95, 108, 101, 102, 116, 95, 34, 123, 36, 110, 97, 109, 101, 43,
  49, 125, 36, 101, 110, 100, 32, 102, 105, 108, 101, 114, 105, 103, 104, 116,
  61, 34, 36, 49, 53, 47, 102, 114, 97, 109, 101, 95, 114, 105, 103, 104,
  116, 95, 34, 123, 36, 110, 97, 109, 101, 43, 49, 125, 36, 101, 110, 100,
  10, 45, 101, 108, 115, 101, 32, 32, 45, 105, 102, 32, 123, 36, 49, 51,
  33, 61, 49, 53, 125, 32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34,
  36, 49, 53, 47, 102, 114, 97, 109, 101, 95, 34, 123, 36, 105, 110, 100,
  101, 120, 43, 49, 125, 36, 101, 110, 100, 10, 45, 101, 108, 115, 101, 32,
  32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 36, 49, 53, 47, 100,
  101, 112, 116, 104, 109, 97, 112, 95, 34, 123, 36, 105, 110, 100, 101, 120,
  43, 49, 125, 36, 101, 110, 100, 32, 45, 101, 110, 100, 105, 102, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 102,
  114, 97, 109, 101, 115, 10, 45, 105, 102, 32, 123, 123, 36, 49, 51, 61,
  61, 49, 52, 125, 38, 38, 123, 36, 102, 108, 97, 103, 51, 100, 61, 61,
  49, 125, 125, 10, 45, 111, 117, 116, 112, 117, 116, 91, 36, 105, 110, 100,
  101, 120, 93, 32, 64, 123, 34, 45, 113, 117, 111, 116, 101, 32, 92, 34,
  34, 36, 102, 105, 108, 101, 114, 105, 103, 104, 116, 34, 92, 34, 34, 125,
  10, 45, 111, 117, 116, 112, 117, 116, 91, 123, 36, 105, 110, 100, 101, 120,
  43, 36, 102, 114, 97, 109, 101, 115, 125, 93, 32, 64, 123, 34, 45, 113,
  117, 111, 116, 101, 32, 92, 34, 34, 36, 102, 105, 108, 101, 108, 101, 102,
  116, 34, 92, 34, 34, 125, 10, 105, 110, 100, 101, 120, 61, 123, 36, 105,
  110, 100, 101, 120, 43, 49, 125, 32, 110, 97, 109, 101, 61, 123, 36, 110,
  97, 109, 101, 43, 49, 125, 10, 102, 105, 108, 101, 108, 101, 102, 116, 61,
  34, 36, 49, 53, 47, 102, 114, 97, 109, 101, 95, 108, 101, 102, 116, 95,
  34, 123, 36, 110, 97, 109, 101, 43, 49, 125, 36, 101, 110, 100, 32, 102,
  105, 108, 101, 114, 105, 103, 104, 116, 61, 34, 36, 49, 53, 47, 102, 114,
  97, 109, 101, 95, 114, 105, 103, 104, 116, 95, 34, 123, 36, 110, 97, 109,
  101, 43, 49, 125, 36, 101, 110, 100, 10, 45, 101, 108, 115, 101, 10, 45,
  111, 117, 116, 112, 117, 116, 91, 36, 105, 110, 100, 101, 120, 93, 32, 64,
  123, 34, 45, 113, 117, 111, 116, 101, 32, 92, 34, 34, 36, 102, 105, 108,
  101, 110, 97, 109, 101, 34, 92, 34, 34, 125, 10, 105, 110, 100, 101, 120,
  61, 123, 36, 105, 110, 100, 101, 120, 43, 49, 125, 32, 45, 105, 102, 32,
  123, 36, 49, 51, 33, 61, 49, 53, 125, 32, 102, 105, 108, 101, 110, 97,
  109, 101, 61, 34, 36, 49, 53, 47, 102, 114, 97, 109, 101, 95, 34, 123,
  36, 105, 110, 100, 101, 120, 43, 49, 125, 36, 101, 110, 100, 32, 45, 101,
  108, 115, 101, 32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 36, 49,
  53, 47, 100, 101, 112, 116, 104, 109, 97, 112, 95, 34, 123, 36, 105, 110,
  100, 101, 120, 43, 49, 125, 36, 101, 110, 100, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 32, 45,
  114, 118, 10, 45, 101, 110, 100, 105, 102, 10, 35, 35, 35, 35, 98, 97,
  116, 99, 104, 32, 98, 97, 115, 101, 100, 32, 99, 111, 110, 118, 101, 114,
  115, 105, 111, 110, 35, 35, 35, 35, 10, 45, 101, 108, 115, 101, 10, 35,
  32, 108, 111, 97, 100, 32, 105, 109, 97, 103, 101, 115, 32, 105, 110, 32,
  98, 97, 116, 99, 104, 32, 109, 111, 100, 101, 10, 45, 105, 102, 32, 123,
  36, 51, 49, 61, 61, 48, 125, 32, 101, 110, 100, 61, 34, 46, 112, 110,
  103, 34, 32, 45, 101, 108, 115, 101, 32, 101, 110, 100, 61, 34, 46, 98,
  109, 112, 34, 32, 45, 101, 110, 100, 105, 102, 10, 105, 110, 102, 105, 108,
  101, 61, 123, 36, 50, 57, 125, 32, 105, 110, 112, 97, 116, 104, 61, 34,
  36, 50, 55, 47, 36, 50, 56, 34, 36, 105, 110, 102, 105, 108, 101, 34,
  34, 36, 101, 110, 100, 34, 34, 32, 111, 117, 116, 102, 105, 108, 101, 61,
  123, 36, 50, 57, 125, 10, 102, 114, 97, 109, 101, 115, 61, 123, 123, 36,
  51, 48, 45, 36, 50, 57, 125, 43, 49, 125, 32, 99, 111, 117, 110, 116,
  101, 114, 61, 49, 10, 45, 105, 102, 32, 123, 123, 36, 51, 52, 33, 61,
  48, 125, 124, 124, 123, 36, 51, 53, 33, 61, 48, 125, 125, 10, 45, 105,
  102, 32, 123, 123, 36, 51, 52, 62, 61, 123, 36, 102, 114, 97, 109, 101,
  115, 45, 36, 51, 53, 125, 125, 124, 124, 123, 36, 51, 53, 62, 61, 123,
  36, 102, 114, 97, 109, 101, 115, 45, 36, 51, 52, 125, 125, 125, 32, 45,
  101, 114, 114, 111, 114, 91, 93, 32, 34, 70, 97, 100, 101, 32, 111, 117,
  116, 32, 111, 102, 32, 102, 114, 97, 109, 101, 32, 114, 97, 110, 103, 101,
  34, 10, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 52, 49, 61, 61, 50, 125, 10, 105, 110, 112,
  97, 116, 104, 108, 101, 102, 116, 61, 34, 36, 50, 55, 47, 36, 50, 56,
  34, 34, 108, 101, 102, 116, 95, 34, 36, 105, 110, 102, 105, 108, 101, 36,
  101, 110, 100, 32, 105, 110, 112, 97, 116, 104, 114, 105, 103, 104, 116, 61,
  34, 36, 50, 55, 47, 36, 50, 56, 34, 34, 114, 105, 103, 104, 116, 95,
  34, 36, 105, 110, 102, 105, 108, 101, 36, 101, 110, 100, 10, 45, 101, 110,
  100, 105, 102, 10, 97, 118, 61, 49, 32, 118, 97, 114, 61, 49, 32, 97,
  118, 112, 114, 101, 118, 61, 49, 32, 118, 97, 114, 112, 114, 101, 118, 61,
  49, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 102, 114, 97, 109, 101,
  115, 10, 45, 105, 102, 32, 123, 36, 52, 49, 33, 61, 50, 125, 10, 45,
  114, 109, 32, 45, 105, 110, 112, 117, 116, 91, 48, 93, 32, 64, 123, 34,
  45, 113, 117, 111, 116, 101, 32, 92, 34, 34, 36, 105, 110, 112, 97, 116,
  104, 34, 92, 34, 34, 125, 10, 45, 105, 102, 32, 123, 123, 36, 50, 52,
  61, 61, 48, 125, 125, 32, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95,
  110, 111, 116, 104, 105, 110, 103, 91, 48, 93, 10, 45, 101, 108, 115, 101,
  32, 105, 110, 102, 105, 108, 101, 50, 61, 123, 36, 105, 110, 102, 105, 108,
  101, 43, 36, 50, 52, 125, 10, 45, 105, 102, 32, 123, 36, 105, 110, 102,
  105, 108, 101, 50, 60, 61, 36, 50, 57, 125, 32, 105, 110, 102, 105, 108,
  101, 50, 61, 123, 36, 50, 57, 125, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 105, 110, 102, 105, 108, 101, 50, 62, 61, 36,
  51, 48, 125, 32, 105, 110, 102, 105, 108, 101, 50, 61, 123, 36, 51, 48,
  125, 32, 45, 101, 110, 100, 105, 102, 10, 105, 110, 112, 97, 116, 104, 50,
  61, 34, 36, 50, 55, 47, 36, 50, 56, 34, 36, 105, 110, 102, 105, 108,
  101, 50, 34, 34, 36, 101, 110, 100, 34, 34, 10, 45, 105, 110, 112, 117,
  116, 91, 49, 93, 32, 64, 123, 34, 45, 113, 117, 111, 116, 101, 32, 92,
  34, 34, 36, 105, 110, 112, 97, 116, 104, 50, 34, 92, 34, 34, 125, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101, 10, 45, 114, 109,
  32, 45, 105, 110, 112, 117, 116, 91, 48, 93, 32, 64, 123, 34, 45, 113,
  117, 111, 116, 101, 32, 92, 34, 34, 36, 105, 110, 112, 97, 116, 104, 108,
  101, 102, 116, 34, 92, 34, 34, 125, 10, 45, 105, 110, 112, 117, 116, 91,
  49, 93, 32, 64, 123, 34, 45, 113, 117, 111, 116, 101, 32, 92, 34, 34,
  36, 105, 110, 112, 97, 116, 104, 114, 105, 103, 104, 116, 34, 92, 34, 34,
  125, 10, 45, 101, 110, 100, 105, 102, 10, 115, 105, 122, 101, 49, 61, 123,
  119, 125, 32, 115, 105, 122, 101, 50, 61, 123, 104, 125, 10, 35, 32, 105,
  109, 97, 103, 101, 32, 115, 116, 114, 101, 97, 109, 32, 97, 108, 105, 103,
  110, 109, 101, 110, 116, 32, 97, 110, 100, 32, 50, 68, 32, 102, 105, 108,
  116, 101, 114, 105, 110, 103, 32, 111, 110, 108, 121, 32, 109, 111, 100, 101,
  115, 10, 102, 108, 97, 103, 51, 100, 61, 48, 32, 45, 105, 102, 32, 123,
  36, 52, 49, 61, 61, 51, 125, 32, 102, 108, 97, 103, 51, 100, 61, 49,
  32, 45, 101, 110, 100, 105, 102, 32, 45, 105, 102, 32, 123, 123, 36, 52,
  49, 33, 61, 50, 125, 38, 38, 123, 36, 52, 49, 33, 61, 51, 125, 125,
  10, 45, 105, 102, 32, 123, 33, 123, 123, 36, 50, 61, 61, 48, 125, 38,
  38, 123, 36, 51, 61, 61, 48, 125, 38, 38, 123, 36, 49, 61, 61, 50,
  52, 125, 38, 38, 123, 36, 49, 51, 61, 61, 49, 52, 125, 38, 38, 123,
  36, 51, 50, 33, 61, 48, 125, 125, 125, 32, 102, 108, 97, 103, 51, 100,
  61, 49, 10, 35, 32, 112, 114, 101, 112, 97, 114, 101, 32, 105, 109, 97,
  103, 101, 115, 10, 45, 105, 102, 32, 123, 36, 49, 51, 33, 61, 49, 52,
  125, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48, 44, 49, 93,
  32, 48, 44, 50, 32, 45, 101, 110, 100, 105, 102, 10, 35, 32, 99, 114,
  101, 97, 116, 101, 32, 100, 101, 112, 116, 104, 32, 109, 97, 112, 10, 45,
  105, 102, 32, 123, 123, 36, 52, 48, 61, 61, 48, 125, 124, 124, 123, 36,
  52, 48, 61, 61, 49, 125, 125, 10, 97, 118, 61, 64, 123, 48, 44, 97,
  125, 32, 118, 97, 114, 61, 64, 123, 48, 44, 118, 125, 32, 100, 105, 102,
  102, 97, 118, 61, 123, 123, 36, 97, 118, 45, 36, 97, 118, 112, 114, 101,
  118, 125, 47, 36, 97, 118, 112, 114, 101, 118, 42, 49, 48, 48, 125, 32,
  100, 105, 102, 102, 118, 97, 114, 61, 123, 123, 36, 118, 97, 114, 45, 36,
  118, 97, 114, 112, 114, 101, 118, 125, 47, 36, 118, 97, 114, 112, 114, 101,
  118, 42, 49, 48, 48, 125, 10, 45, 105, 102, 32, 123, 123, 97, 98, 115,
  40, 36, 100, 105, 102, 102, 97, 118, 41, 62, 61, 49, 48, 125, 124, 124,
  123, 97, 98, 115, 40, 36, 100, 105, 102, 102, 118, 97, 114, 41, 62, 61,
  49, 48, 125, 125, 32, 115, 99, 101, 110, 101, 99, 104, 97, 110, 103, 101,
  61, 49, 32, 45, 101, 108, 115, 101, 32, 115, 99, 101, 110, 101, 99, 104,
  97, 110, 103, 101, 61, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 123, 36, 99, 111, 117, 110, 116, 101, 114, 61, 61, 49, 125,
  124, 124, 123, 36, 115, 99, 101, 110, 101, 99, 104, 97, 110, 103, 101, 61,
  61, 49, 125, 124, 124, 123, 123, 36, 99, 111, 117, 110, 116, 101, 114, 47,
  36, 51, 54, 125, 61, 61, 123, 114, 111, 117, 110, 100, 40, 36, 99, 111,
  117, 110, 116, 101, 114, 47, 36, 51, 54, 44, 49, 41, 125, 125, 125, 10,
  45, 45, 103, 105, 109, 112, 95, 116, 107, 95, 100, 101, 112, 116, 104, 109,
  97, 112, 91, 48, 93, 32, 36, 49, 44, 36, 52, 44, 36, 53, 44, 36,
  54, 44, 36, 55, 44, 36, 56, 44, 36, 57, 44, 36, 51, 56, 44, 36,
  51, 57, 44, 123, 119, 42, 123, 36, 51, 55, 47, 49, 48, 48, 48, 125,
  125, 32, 45, 114, 91, 45, 49, 93, 32, 36, 115, 105, 122, 101, 49, 44,
  36, 115, 105, 122, 101, 50, 10, 45, 105, 102, 32, 123, 36, 97, 118, 33,
  61, 48, 125, 32, 97, 118, 112, 114, 101, 118, 61, 36, 97, 118, 32, 45,
  101, 110, 100, 105, 102, 32, 45, 105, 102, 32, 123, 36, 118, 97, 114, 33,
  61, 48, 125, 32, 118, 97, 114, 112, 114, 101, 118, 61, 36, 118, 97, 114,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 51, 54,
  33, 61, 49, 125, 32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 36,
  49, 53, 47, 100, 101, 112, 116, 104, 109, 97, 112, 95, 116, 101, 109, 112,
  46, 112, 110, 103, 34, 10, 45, 111, 117, 116, 112, 117, 116, 91, 45, 49,
  93, 32, 64, 123, 34, 45, 113, 117, 111, 116, 101, 32, 92, 34, 34, 36,
  102, 105, 108, 101, 110, 97, 109, 101, 34, 92, 34, 34, 125, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 108, 115, 101, 10, 102, 105, 108, 101, 110,
  97, 109, 101, 61, 34, 36, 49, 53, 47, 100, 101, 112, 116, 104, 109, 97,
  112, 95, 116, 101, 109, 112, 46, 112, 110, 103, 34, 10, 45, 105, 110, 112,
  117, 116, 91, 45, 49, 93, 32, 64, 123, 34, 45, 113, 117, 111, 116, 101,
  32, 92, 34, 34, 36, 102, 105, 108, 101, 110, 97, 109, 101, 34, 92, 34,
  34, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 52, 48, 61, 61, 49, 125, 10, 105, 110,
  102, 105, 108, 101, 99, 61, 34, 99, 111, 114, 114, 101, 99, 116, 105, 111,
  110, 46, 112, 110, 103, 34, 32, 105, 110, 112, 97, 116, 104, 99, 61, 34,
  36, 50, 55, 47, 34, 36, 105, 110, 102, 105, 108, 101, 99, 34, 34, 10,
  45, 105, 110, 112, 117, 116, 91, 45, 49, 93, 32, 64, 123, 34, 45, 113,
  117, 111, 116, 101, 32, 92, 34, 34, 36, 105, 110, 112, 97, 116, 104, 99,
  34, 92, 34, 34, 125, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 114,
  103, 98, 97, 91, 45, 49, 44, 45, 50, 93, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 52, 48, 61, 61, 50, 125, 10, 105, 110, 102, 105, 108, 101,
  99, 61, 34, 100, 101, 112, 116, 104, 109, 97, 112, 46, 112, 110, 103, 34,
  32, 105, 110, 112, 97, 116, 104, 99, 61, 34, 36, 50, 55, 47, 34, 36,
  105, 110, 102, 105, 108, 101, 99, 34, 34, 10, 45, 105, 110, 112, 117, 116,
  91, 45, 49, 93, 32, 64, 123, 34, 45, 113, 117, 111, 116, 101, 32, 92,
  34, 34, 36, 105, 110, 112, 97, 116, 104, 99, 34, 92, 34, 34, 125, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 52, 48, 61, 61, 51, 125, 10, 105,
  110, 102, 105, 108, 101, 99, 61, 34, 100, 101, 112, 116, 104, 109, 97, 112,
  95, 34, 36, 105, 110, 102, 105, 108, 101, 34, 46, 112, 110, 103, 34, 32,
  105, 110, 112, 97, 116, 104, 99, 61, 34, 36, 50, 55, 47, 100, 101, 112,
  116, 104, 109, 97, 112, 115, 47, 34, 36, 105, 110, 102, 105, 108, 101, 99,
  34, 34, 10, 45, 105, 110, 112, 117, 116, 91, 45, 49, 93, 32, 64, 123,
  34, 45, 113, 117, 111, 116, 101, 32, 92, 34, 34, 36, 105, 110, 112, 97,
  116, 104, 99, 34, 92, 34, 34, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  35, 32, 109, 111, 116, 105, 111, 110, 32, 97, 110, 97, 108, 121, 115, 105,
  115, 10, 45, 105, 102, 32, 123, 36, 49, 48, 33, 61, 48, 125, 32, 45,
  105, 102, 32, 123, 36, 105, 110, 102, 105, 108, 101, 33, 61, 36, 50, 57,
  125, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104,
  105, 110, 103, 91, 48, 93, 10, 105, 110, 102, 105, 108, 101, 109, 111, 118,
  61, 123, 36, 105, 110, 102, 105, 108, 101, 45, 49, 125, 32, 105, 110, 112,
  97, 116, 104, 109, 111, 118, 61, 34, 36, 50, 55, 47, 36, 50, 56, 34,
  36, 105, 110, 102, 105, 108, 101, 109, 111, 118, 34, 34, 36, 101, 110, 100,
  34, 34, 10, 45, 105, 110, 112, 117, 116, 91, 45, 49, 93, 32, 64, 123,
  34, 45, 113, 117, 111, 116, 101, 32, 92, 34, 34, 36, 105, 110, 112, 97,
  116, 104, 109, 111, 118, 34, 92, 34, 34, 125, 10, 45, 99, 111, 109, 112,
  111, 115, 101, 95, 100, 105, 102, 102, 101, 114, 101, 110, 99, 101, 91, 45,
  49, 44, 45, 50, 93, 32, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101,
  91, 45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 10, 45, 116, 50, 91, 45, 49, 93, 32, 48, 44, 123, 123, 36, 51,
  55, 47, 50, 125, 43, 49, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118,
  101, 91, 45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 10, 45, 105, 102, 32, 123, 36, 105, 110, 102, 105, 108, 101, 62,
  61, 123, 36, 50, 57, 43, 50, 125, 125, 10, 105, 110, 102, 105, 108, 101,
  109, 111, 118, 50, 61, 123, 36, 105, 110, 102, 105, 108, 101, 45, 50, 125,
  32, 105, 110, 112, 97, 116, 104, 109, 111, 118, 50, 61, 34, 36, 50, 55,
  47, 36, 50, 56, 34, 36, 105, 110, 102, 105, 108, 101, 109, 111, 118, 50,
  34, 34, 36, 101, 110, 100, 34, 34, 10, 45, 105, 110, 112, 117, 116, 91,
  45, 49, 93, 32, 64, 123, 34, 45, 113, 117, 111, 116, 101, 32, 92, 34,
  34, 36, 105, 110, 112, 97, 116, 104, 109, 111, 118, 50, 34, 92, 34, 34,
  125, 10, 105, 110, 102, 105, 108, 101, 109, 111, 118, 51, 61, 123, 36, 105,
  110, 102, 105, 108, 101, 45, 49, 125, 32, 105, 110, 112, 97, 116, 104, 109,
  111, 118, 51, 61, 34, 36, 50, 55, 47, 36, 50, 56, 34, 36, 105, 110,
  102, 105, 108, 101, 109, 111, 118, 51, 34, 34, 36, 101, 110, 100, 34, 34,
  10, 45, 105, 110, 112, 117, 116, 91, 45, 49, 93, 32, 64, 123, 34, 45,
  113, 117, 111, 116, 101, 32, 92, 34, 34, 36, 105, 110, 112, 97, 116, 104,
  109, 111, 118, 51, 34, 92, 34, 34, 125, 10, 45, 99, 111, 109, 112, 111,
  115, 101, 95, 100, 105, 102, 102, 101, 114, 101, 110, 99, 101, 91, 45, 49,
  44, 45, 50, 93, 32, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91,
  45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  10, 45, 116, 50, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 110, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 99, 111, 109, 112, 111,
  115, 101, 95, 100, 97, 114, 107, 101, 110, 91, 45, 49, 44, 45, 50, 93,
  10, 45, 101, 110, 100, 105, 102, 32, 45, 98, 108, 117, 114, 95, 120, 121,
  91, 45, 49, 93, 32, 123, 119, 42, 123, 36, 51, 55, 47, 49, 48, 48,
  48, 125, 125, 32, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 10, 45,
  105, 102, 32, 123, 36, 49, 48, 62, 61, 48, 125, 10, 45, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103, 104, 116, 101,
  110, 91, 45, 49, 44, 45, 50, 93, 32, 123, 97, 98, 115, 40, 36, 49,
  48, 41, 47, 53, 125, 10, 45, 101, 108, 115, 101, 10, 45, 110, 101, 103,
  97, 116, 105, 118, 101, 91, 45, 50, 93, 10, 45, 103, 105, 109, 112, 95,
  99, 111, 109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101, 110, 91, 45,
  49, 44, 45, 50, 93, 32, 123, 97, 98, 115, 40, 36, 49, 48, 41, 47,
  53, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102,
  32, 45, 101, 110, 100, 105, 102, 10, 35, 32, 99, 114, 101, 97, 116, 101,
  32, 115, 101, 99, 111, 110, 100, 32, 118, 105, 101, 119, 10, 45, 105, 102,
  32, 123, 36, 49, 51, 33, 61, 49, 53, 125, 10, 45, 105, 102, 32, 123,
  36, 52, 49, 61, 61, 48, 125, 10, 45, 105, 102, 32, 123, 36, 115, 119,
  60, 61, 48, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 50,
  93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 51,
  52, 33, 61, 48, 125, 32, 45, 105, 102, 32, 123, 36, 99, 111, 117, 110,
  116, 101, 114, 60, 61, 36, 51, 52, 125, 32, 115, 119, 61, 123, 123, 36,
  99, 111, 117, 110, 116, 101, 114, 47, 36, 51, 52, 125, 42, 36, 115, 119,
  125, 32, 115, 104, 61, 123, 123, 36, 99, 111, 117, 110, 116, 101, 114, 47,
  36, 51, 52, 125, 42, 36, 115, 104, 125, 32, 45, 101, 110, 100, 105, 102,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 51, 53,
  33, 61, 48, 125, 32, 45, 105, 102, 32, 123, 36, 99, 111, 117, 110, 116,
  101, 114, 62, 61, 123, 36, 102, 114, 97, 109, 101, 115, 45, 36, 51, 53,
  125, 125, 32, 115, 119, 61, 123, 36, 115, 119, 42, 123, 123, 123, 36, 102,
  114, 97, 109, 101, 115, 45, 36, 99, 111, 117, 110, 116, 101, 114, 125, 43,
  49, 125, 47, 36, 51, 53, 125, 125, 10, 115, 104, 61, 123, 36, 115, 104,
  42, 123, 123, 123, 36, 102, 114, 97, 109, 101, 115, 45, 36, 99, 111, 117,
  110, 116, 101, 114, 125, 43, 49, 125, 47, 36, 51, 53, 125, 125, 32, 45,
  101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 91,
  45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44,
  50, 32, 45, 115, 91, 45, 49, 93, 32, 99, 32, 45, 102, 91, 45, 49,
  93, 32, 48, 32, 45, 110, 91, 45, 50, 93, 32, 48, 44, 36, 115, 119,
  32, 45, 97, 91, 45, 49, 44, 45, 50, 93, 32, 99, 10, 45, 119, 97,
  114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 32, 45, 115,
  104, 105, 102, 116, 91, 45, 50, 93, 32, 36, 115, 104, 44, 48, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 115, 101, 10, 45, 45, 103,
  105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45,
  49, 93, 32, 45, 114, 91, 45, 49, 44, 45, 50, 93, 32, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 49, 44, 50, 10, 45, 115, 91, 45, 49,
  93, 32, 99, 32, 45, 102, 91, 45, 49, 93, 32, 48, 32, 45, 110, 91,
  45, 50, 93, 32, 48, 44, 123, 97, 98, 115, 40, 36, 115, 119, 47, 50,
  41, 125, 32, 45, 97, 91, 45, 49, 44, 45, 50, 93, 32, 99, 10, 45,
  110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 50, 93, 32, 45, 115, 91,
  45, 50, 93, 32, 99, 32, 45, 102, 91, 45, 50, 93, 32, 48, 32, 45,
  110, 91, 45, 51, 93, 32, 48, 44, 123, 45, 97, 98, 115, 40, 36, 115,
  119, 47, 50, 41, 125, 32, 45, 97, 91, 45, 50, 44, 45, 51, 93, 32,
  99, 10, 45, 119, 97, 114, 112, 91, 45, 52, 93, 32, 91, 45, 50, 93,
  44, 49, 32, 45, 119, 97, 114, 112, 91, 45, 51, 93, 32, 91, 45, 49,
  93, 44, 49, 10, 45, 115, 104, 105, 102, 116, 91, 45, 51, 93, 32, 36,
  115, 104, 44, 48, 32, 45, 114, 109, 91, 45, 49, 44, 45, 50, 93, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 115, 104,
  61, 123, 45, 36, 50, 125, 32, 115, 119, 61, 123, 45, 36, 115, 104, 45,
  36, 51, 125, 10, 35, 32, 97, 117, 116, 111, 99, 114, 111, 112, 32, 102,
  114, 97, 109, 101, 115, 10, 45, 105, 102, 32, 123, 36, 50, 48, 61, 61,
  49, 125, 32, 45, 105, 102, 32, 123, 36, 49, 51, 33, 61, 49, 53, 125,
  10, 45, 105, 102, 32, 123, 36, 115, 104, 62, 61, 48, 125, 32, 45, 99,
  114, 111, 112, 32, 36, 115, 104, 44, 48, 44, 123, 119, 125, 44, 123, 104,
  125, 32, 45, 101, 108, 115, 101, 32, 45, 99, 114, 111, 112, 32, 48, 44,
  48, 44, 123, 119, 43, 36, 115, 104, 125, 44, 123, 104, 125, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 115, 119, 62, 61, 48,
  125, 32, 45, 99, 114, 111, 112, 32, 36, 115, 119, 44, 48, 44, 123, 119,
  125, 44, 123, 104, 125, 32, 45, 101, 108, 115, 101, 32, 45, 99, 114, 111,
  112, 32, 48, 44, 48, 44, 123, 119, 43, 36, 115, 119, 125, 44, 123, 104,
  125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 32,
  45, 101, 110, 100, 105, 102, 10, 35, 101, 110, 100, 32, 105, 109, 97, 103,
  101, 32, 115, 116, 114, 101, 97, 109, 32, 97, 108, 105, 103, 110, 109, 101,
  110, 116, 32, 97, 110, 100, 32, 50, 68, 32, 109, 111, 100, 101, 32, 98,
  121, 112, 97, 115, 115, 10, 45, 101, 110, 100, 105, 102, 32, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 52, 49, 61, 61, 51,
  125, 32, 45, 103, 105, 109, 112, 95, 116, 107, 95, 100, 101, 97, 110, 97,
  91, 48, 93, 32, 36, 51, 55, 44, 123, 123, 36, 51, 56, 42, 50, 125,
  43, 48, 46, 49, 125, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 101,
  110, 100, 105, 102, 10, 35, 32, 97, 112, 112, 108, 121, 32, 99, 117, 115,
  116, 111, 109, 32, 102, 105, 108, 116, 101, 114, 10, 45, 105, 102, 32, 123,
  36, 51, 50, 61, 61, 49, 125, 32, 45, 105, 102, 32, 123, 36, 49, 51,
  33, 61, 49, 53, 125, 32, 45, 103, 105, 109, 112, 95, 99, 117, 115, 116,
  111, 109, 95, 99, 111, 100, 101, 91, 48, 44, 49, 93, 32, 34, 36, 51,
  51, 34, 44, 48, 44, 48, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 51, 50, 61, 61, 50, 125, 32, 45,
  105, 102, 32, 123, 36, 49, 51, 33, 61, 49, 53, 125, 32, 45, 108, 91,
  48, 93, 32, 45, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95,
  99, 111, 100, 101, 32, 34, 36, 51, 51, 34, 44, 48, 44, 48, 44, 48,
  32, 45, 101, 110, 100, 108, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 51, 50, 61, 61, 51, 125, 32, 45, 105, 102,
  32, 123, 36, 49, 51, 33, 61, 49, 53, 125, 32, 45, 108, 91, 49, 93,
  32, 45, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 99, 111,
  100, 101, 32, 34, 36, 51, 51, 34, 44, 48, 44, 48, 44, 48, 32, 45,
  101, 110, 100, 108, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  105, 102, 10, 35, 32, 97, 108, 105, 103, 110, 32, 115, 116, 101, 114, 101,
  111, 115, 99, 111, 112, 105, 99, 32, 105, 109, 97, 103, 101, 10, 45, 105,
  102, 32, 123, 36, 49, 50, 61, 61, 49, 125, 32, 45, 97, 112, 112, 108,
  121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48, 44, 49, 93, 32,
  34, 45, 103, 105, 109, 112, 95, 98, 108, 97, 99, 107, 97, 110, 100, 119,
  104, 105, 116, 101, 32, 48, 46, 51, 44, 48, 44, 48, 46, 54, 44, 48,
  44, 48, 46, 49, 44, 48, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 44, 48, 44, 48, 44, 49,
  54, 44, 52, 44, 48, 44, 48, 44, 48, 34, 44, 50, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 123, 36, 52, 49, 61, 61, 50,
  125, 38, 38, 123, 36, 49, 51, 61, 61, 49, 52, 125, 125, 32, 45, 101,
  114, 114, 111, 114, 91, 93, 32, 34, 79, 117, 116, 112, 117, 116, 32, 102,
  111, 114, 109, 97, 116, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101,
  100, 32, 102, 111, 114, 32, 105, 109, 97, 103, 101, 32, 115, 116, 114, 101,
  97, 109, 32, 97, 108, 105, 103, 110, 109, 101, 110, 116, 34, 10, 45, 101,
  108, 105, 102, 32, 123, 123, 36, 52, 49, 61, 61, 51, 125, 38, 38, 123,
  36, 49, 51, 61, 61, 49, 53, 125, 125, 32, 45, 101, 114, 114, 111, 114,
  91, 93, 32, 34, 79, 117, 116, 112, 117, 116, 32, 102, 111, 114, 109, 97,
  116, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 32, 102, 111,
  114, 32, 97, 110, 97, 103, 108, 121, 112, 104, 32, 118, 105, 100, 101, 111,
  32, 114, 101, 99, 111, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 34,
  10, 45, 101, 108, 105, 102, 32, 123, 123, 36, 52, 49, 61, 61, 50, 125,
  38, 38, 123, 36, 49, 51, 61, 61, 49, 53, 125, 125, 32, 45, 45, 103,
  105, 109, 112, 95, 116, 107, 95, 100, 101, 112, 116, 104, 95, 111, 98, 116,
  97, 105, 110, 91, 48, 44, 49, 93, 32, 36, 49, 49, 44, 123, 36, 51,
  55, 47, 49, 48, 48, 125, 44, 123, 49, 48, 48, 45, 123, 36, 51, 56,
  42, 50, 48, 125, 125, 44, 123, 36, 51, 57, 42, 50, 48, 125, 10, 45,
  105, 102, 32, 123, 36, 51, 50, 33, 61, 48, 125, 32, 45, 103, 105, 109,
  112, 95, 99, 117, 115, 116, 111, 109, 95, 99, 111, 100, 101, 91, 48, 44,
  49, 44, 45, 49, 93, 32, 34, 36, 51, 51, 34, 44, 48, 44, 48, 44,
  48, 32, 45, 101, 110, 100, 105, 102, 32, 45, 107, 91, 45, 49, 93, 10,
  45, 101, 108, 105, 102, 32, 123, 123, 36, 52, 49, 33, 61, 50, 125, 38,
  38, 123, 36, 49, 51, 61, 61, 49, 53, 125, 125, 32, 45, 107, 91, 45,
  49, 93, 10, 45, 101, 108, 105, 102, 32, 123, 123, 36, 52, 49, 61, 61,
  51, 125, 38, 38, 123, 36, 49, 51, 61, 61, 49, 52, 125, 125, 32, 45,
  107, 91, 48, 44, 49, 93, 10, 45, 101, 108, 115, 101, 32, 45, 103, 105,
  109, 112, 95, 116, 107, 95, 115, 116, 101, 114, 101, 111, 105, 109, 97, 103,
  101, 91, 48, 44, 49, 93, 32, 36, 49, 51, 44, 36, 49, 49, 44, 36,
  49, 54, 44, 36, 49, 55, 44, 36, 49, 56, 44, 36, 49, 57, 32, 45,
  101, 110, 100, 105, 102, 10, 35, 32, 97, 100, 106, 117, 115, 116, 32, 111,
  117, 116, 112, 117, 116, 32, 105, 109, 97, 103, 101, 32, 115, 116, 114, 101,
  97, 109, 115, 10, 45, 105, 102, 32, 123, 36, 49, 51, 61, 61, 49, 52,
  125, 32, 45, 97, 112, 112, 108, 121, 95, 103, 97, 109, 109, 97, 32, 36,
  49, 54, 32, 45, 116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97, 110,
  110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 49,
  44, 49, 44, 36, 49, 55, 44, 48, 44, 48, 44, 48, 44, 49, 48, 48,
  44, 50, 53, 54, 44, 48, 44, 48, 44, 49, 44, 49, 48, 44, 55, 44,
  48, 10, 45, 103, 105, 109, 112, 95, 109, 105, 120, 95, 108, 97, 98, 32,
  49, 44, 48, 44, 48, 44, 36, 49, 56, 44, 48, 44, 48, 44, 36, 49,
  56, 44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 32, 45, 101, 110, 100,
  105, 102, 10, 35, 32, 114, 101, 115, 105, 122, 101, 32, 102, 114, 97, 109,
  101, 32, 116, 111, 32, 111, 117, 116, 112, 117, 116, 32, 102, 111, 114, 109,
  97, 116, 10, 45, 105, 102, 32, 123, 36, 50, 49, 61, 61, 49, 125, 32,
  45, 105, 102, 32, 123, 36, 49, 51, 33, 61, 49, 51, 125, 10, 45, 105,
  102, 32, 123, 36, 50, 51, 61, 61, 48, 125, 32, 32, 32, 45, 114, 32,
  36, 50, 50, 44, 123, 36, 50, 50, 42, 48, 46, 55, 53, 125, 44, 49,
  44, 123, 115, 125, 44, 54, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50,
  51, 61, 61, 49, 125, 32, 45, 114, 32, 36, 50, 50, 44, 123, 123, 36,
  50, 50, 42, 57, 125, 47, 49, 54, 125, 44, 49, 44, 123, 115, 125, 44,
  54, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 51, 61, 61, 50, 125,
  32, 45, 114, 32, 36, 50, 50, 44, 123, 123, 36, 50, 50, 42, 50, 125,
  47, 51, 125, 44, 49, 44, 123, 115, 125, 44, 54, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 50, 51, 61, 61, 51, 125, 32, 45, 114, 32, 36, 50,
  50, 44, 123, 36, 50, 50, 42, 48, 46, 53, 125, 44, 49, 44, 123, 115,
  125, 44, 54, 10, 45, 101, 108, 105, 102, 32, 123, 36, 50, 51, 61, 61,
  52, 125, 32, 45, 114, 32, 36, 50, 50, 44, 123, 123, 36, 50, 50, 42,
  57, 125, 47, 50, 49, 125, 44, 49, 44, 123, 115, 125, 44, 54, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 50, 51, 61, 61, 53, 125, 32, 45, 114,
  32, 36, 50, 50, 44, 123, 36, 50, 50, 42, 123, 104, 47, 119, 125, 125,
  44, 49, 44, 123, 115, 125, 44, 54, 10, 45, 101, 110, 100, 105, 102, 32,
  45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 32, 45, 99,
  32, 48, 44, 50, 53, 53, 10, 35, 32, 115, 97, 118, 101, 32, 102, 114,
  97, 109, 101, 32, 116, 111, 32, 102, 111, 108, 100, 101, 114, 10, 45, 105,
  102, 32, 123, 123, 36, 49, 51, 61, 61, 49, 52, 125, 38, 38, 123, 36,
  102, 108, 97, 103, 51, 100, 61, 61, 49, 125, 125, 10, 102, 105, 108, 101,
  108, 101, 102, 116, 61, 34, 36, 49, 53, 47, 102, 114, 97, 109, 101, 95,
  108, 101, 102, 116, 95, 34, 36, 111, 117, 116, 102, 105, 108, 101, 36, 101,
  110, 100, 32, 102, 105, 108, 101, 114, 105, 103, 104, 116, 61, 34, 36, 49,
  53, 47, 102, 114, 97, 109, 101, 95, 114, 105, 103, 104, 116, 95, 34, 36,
  111, 117, 116, 102, 105, 108, 101, 36, 101, 110, 100, 10, 45, 101, 108, 115,
  101, 32, 32, 45, 105, 102, 32, 123, 36, 49, 51, 33, 61, 49, 53, 125,
  32, 102, 105, 108, 101, 110, 97, 109, 101, 61, 34, 36, 49, 53, 47, 102,
  114, 97, 109, 101, 95, 34, 36, 111, 117, 116, 102, 105, 108, 101, 36, 101,
  110, 100, 10, 45, 101, 108, 115, 101, 32, 32, 102, 105, 108, 101, 110, 97,
  109, 101, 61, 34, 36, 49, 53, 47, 100, 101, 112, 116, 104, 109, 97, 112,
  95, 34, 36, 111, 117, 116, 102, 105, 108, 101, 36, 101, 110, 100, 32, 45,
  101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 123, 36, 49, 51, 61, 61, 49, 52, 125, 38, 38, 123, 36, 102,
  108, 97, 103, 51, 100, 61, 61, 49, 125, 125, 10, 45, 111, 117, 116, 112,
  117, 116, 91, 48, 93, 32, 64, 123, 34, 45, 113, 117, 111, 116, 101, 32,
  92, 34, 34, 36, 102, 105, 108, 101, 108, 101, 102, 116, 34, 92, 34, 34,
  125, 32, 45, 111, 117, 116, 112, 117, 116, 91, 49, 93, 32, 64, 123, 34,
  45, 113, 117, 111, 116, 101, 32, 92, 34, 34, 36, 102, 105, 108, 101, 114,
  105, 103, 104, 116, 34, 92, 34, 34, 125, 10, 45, 101, 108, 115, 101, 32,
  45, 111, 117, 116, 112, 117, 116, 91, 48, 93, 32, 64, 123, 34, 45, 113,
  117, 111, 116, 101, 32, 92, 34, 34, 36, 102, 105, 108, 101, 110, 97, 109,
  101, 34, 92, 34, 34, 125, 10, 45, 101, 110, 100, 105, 102, 10, 111, 117,
  116, 102, 105, 108, 101, 61, 123, 36, 111, 117, 116, 102, 105, 108, 101, 43,
  49, 125, 10, 35, 32, 101, 110, 100, 32, 98, 97, 116, 99, 104, 32, 112,
  114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 108, 111, 111, 112, 115, 32,
  97, 110, 100, 32, 100, 101, 108, 101, 116, 101, 32, 116, 101, 109, 112, 111,
  114, 97, 114, 121, 32, 102, 105, 108, 101, 10, 105, 110, 102, 105, 108, 101,
  61, 123, 36, 105, 110, 102, 105, 108, 101, 43, 49, 125, 32, 105, 110, 112,
  97, 116, 104, 61, 34, 36, 50, 55, 47, 36, 50, 56, 34, 36, 105, 110,
  102, 105, 108, 101, 34, 34, 36, 101, 110, 100, 34, 34, 10, 45, 105, 102,
  32, 123, 36, 52, 49, 61, 61, 50, 125, 32, 105, 110, 112, 97, 116, 104,
  108, 101, 102, 116, 61, 34, 36, 50, 55, 47, 36, 50, 56, 34, 34, 108,
  101, 102, 116, 95, 34, 36, 105, 110, 102, 105, 108, 101, 36, 101, 110, 100,
  32, 105, 110, 112, 97, 116, 104, 114, 105, 103, 104, 116, 61, 34, 36, 50,
  55, 47, 36, 50, 56, 34, 34, 114, 105, 103, 104, 116, 95, 34, 36, 105,
  110, 102, 105, 108, 101, 36, 101, 110, 100, 32, 45, 101, 110, 100, 105, 102,
  10, 99, 111, 117, 110, 116, 101, 114, 61, 123, 36, 99, 111, 117, 110, 116,
  101, 114, 43, 49, 125, 32, 45, 100, 111, 110, 101, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 123, 36, 95, 112, 114, 101, 118, 105,
  101, 119, 102, 108, 97, 103, 61, 61, 48, 125, 38, 38, 123, 36, 50, 54,
  61, 61, 49, 125, 125, 32, 45, 105, 102, 32, 123, 36, 51, 54, 33, 61,
  49, 125, 10, 45, 105, 102, 32, 64, 123, 45, 105, 115, 95, 119, 105, 110,
  100, 111, 119, 115, 125, 32, 112, 97, 116, 104, 61, 34, 36, 49, 53, 34,
  32, 112, 97, 116, 104, 61, 36, 123, 112, 97, 116, 104, 125, 123, 96, 57,
  50, 96, 125, 10, 45, 120, 32, 34, 99, 100, 32, 92, 34, 34, 36, 112,
  97, 116, 104, 34, 92, 34, 32, 38, 38, 32, 100, 101, 108, 32, 100, 101,
  112, 116, 104, 109, 97, 112, 95, 116, 101, 109, 112, 46, 112, 110, 103, 34,
  10, 45, 101, 108, 115, 101, 32, 102, 105, 108, 101, 61, 34, 36, 49, 53,
  47, 100, 101, 112, 116, 104, 109, 97, 112, 95, 116, 101, 109, 112, 46, 112,
  110, 103, 34, 32, 45, 120, 32, 34, 114, 109, 32, 45, 102, 32, 92, 34,
  36, 102, 105, 108, 101, 92, 34, 34, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 35, 35,
  35, 35, 35, 112, 114, 101, 118, 105, 101, 119, 32, 102, 117, 110, 99, 116,
  105, 111, 110, 35, 35, 35, 35, 10, 103, 105, 109, 112, 95, 116, 107, 95,
  118, 105, 100, 101, 111, 51, 68, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 115, 104, 112, 114, 101, 61, 123, 36, 50, 42, 123, 52, 48, 48,
  47, 36, 50, 50, 125, 125, 32, 115, 119, 112, 114, 101, 61, 123, 36, 51,
  42, 123, 52, 48, 48, 47, 36, 50, 50, 125, 125, 10, 45, 105, 102, 32,
  123, 36, 50, 54, 61, 61, 48, 125, 10, 35, 35, 35, 35, 35, 112, 114,
  101, 118, 105, 101, 119, 32, 108, 97, 121, 101, 114, 32, 109, 111, 100, 101,
  35, 35, 35, 10, 45, 105, 102, 32, 123, 123, 64, 35, 125, 61, 61, 49,
  125, 32, 45, 102, 99, 91, 48, 93, 32, 50, 53, 53, 44, 48, 44, 49,
  50, 56, 44, 50, 53, 53, 32, 45, 107, 91, 48, 93, 32, 45, 116, 101,
  120, 116, 32, 34, 83, 101, 108, 101, 99, 116, 32, 109, 117, 108, 116, 105,
  112, 108, 101, 32, 108, 97, 121, 101, 114, 34, 44, 49, 48, 44, 56, 48,
  37, 44, 50, 52, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53,
  10, 45, 116, 101, 120, 116, 32, 34, 105, 110, 112, 117, 116, 32, 109, 111,
  100, 101, 32, 65, 76, 76, 46, 34, 44, 49, 48, 44, 57, 48, 37, 44,
  50, 52, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 52, 49, 61, 61, 50, 125, 32, 45, 102,
  99, 91, 48, 93, 32, 50, 53, 53, 44, 48, 44, 49, 50, 56, 44, 50,
  53, 53, 32, 45, 107, 91, 48, 93, 32, 45, 116, 101, 120, 116, 32, 34,
  65, 108, 105, 103, 110, 109, 101, 110, 116, 32, 111, 102, 32, 105, 109, 97,
  103, 101, 32, 115, 116, 114, 101, 97, 109, 115, 34, 44, 49, 48, 44, 56,
  48, 37, 44, 50, 52, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 53,
  53, 10, 45, 116, 101, 120, 116, 32, 34, 105, 110, 32, 66, 65, 84, 67,
  72, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 109, 111, 100,
  101, 32, 111, 110, 108, 121, 33, 34, 44, 49, 48, 44, 57, 48, 37, 44,
  50, 52, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 52, 49, 61, 61, 51, 125, 32, 45, 102,
  99, 91, 48, 93, 32, 50, 53, 53, 44, 48, 44, 49, 50, 56, 44, 50,
  53, 53, 32, 45, 107, 91, 48, 93, 32, 45, 116, 101, 120, 116, 32, 34,
  65, 110, 97, 103, 108, 121, 112, 104, 32, 118, 105, 100, 101, 111, 32, 114,
  101, 99, 111, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 34, 44, 49,
  48, 44, 56, 48, 37, 44, 50, 52, 44, 49, 44, 48, 44, 48, 44, 48,
  44, 50, 53, 53, 10, 45, 116, 101, 120, 116, 32, 34, 105, 110, 32, 66,
  65, 84, 67, 72, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32,
  109, 111, 100, 101, 32, 111, 110, 108, 121, 33, 34, 44, 49, 48, 44, 57,
  48, 37, 44, 50, 52, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 53,
  53, 10, 45, 101, 108, 115, 101, 10, 95, 112, 114, 101, 118, 105, 101, 119,
  102, 108, 97, 103, 61, 49, 10, 45, 105, 102, 32, 123, 36, 52, 48, 61,
  61, 51, 125, 32, 45, 105, 102, 32, 123, 36, 52, 50, 61, 61, 48, 125,
  32, 95, 109, 97, 112, 105, 110, 61, 49, 32, 45, 101, 108, 105, 102, 32,
  123, 36, 52, 50, 61, 61, 49, 125, 32, 95, 109, 97, 112, 105, 110, 61,
  123, 64, 35, 125, 32, 45, 101, 108, 105, 102, 32, 123, 36, 52, 50, 61,
  61, 50, 125, 32, 32, 95, 109, 97, 112, 105, 110, 61, 36, 52, 51, 32,
  45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 52, 50, 61, 61, 48, 125, 32, 110, 114, 61, 49, 32,
  112, 118, 61, 123, 45, 49, 125, 32, 45, 101, 108, 105, 102, 32, 123, 36,
  52, 50, 61, 61, 49, 125, 32, 110, 114, 61, 123, 64, 35, 125, 32, 112,
  118, 61, 123, 45, 64, 35, 125, 32, 45, 101, 108, 105, 102, 32, 123, 123,
  36, 52, 50, 61, 61, 50, 125, 124, 124, 123, 36, 52, 50, 61, 61, 51,
  125, 125, 32, 110, 114, 61, 36, 52, 51, 32, 112, 118, 61, 123, 45, 36,
  52, 51, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  123, 36, 52, 50, 61, 61, 50, 125, 124, 124, 123, 36, 52, 50, 61, 61,
  51, 125, 125, 32, 45, 105, 102, 32, 123, 36, 52, 51, 62, 61, 123, 64,
  35, 125, 125, 32, 110, 114, 61, 123, 64, 35, 125, 32, 112, 118, 61, 123,
  45, 64, 35, 125, 32, 95, 109, 97, 112, 105, 110, 61, 123, 64, 35, 125,
  32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 52, 50, 33, 61, 51, 125, 10, 45, 103, 105, 109,
  112, 95, 116, 107, 95, 118, 105, 100, 101, 111, 51, 68, 91, 36, 112, 118,
  93, 32, 36, 49, 44, 36, 115, 104, 112, 114, 101, 44, 36, 115, 119, 112,
  114, 101, 44, 36, 123, 52, 45, 57, 125, 44, 48, 44, 36, 123, 49, 49,
  45, 49, 51, 125, 44, 48, 44, 34, 36, 49, 53, 34, 44, 36, 123, 49,
  54, 45, 50, 51, 125, 44, 48, 44, 36, 123, 50, 53, 45, 50, 54, 125,
  44, 34, 36, 50, 55, 34, 44, 34, 36, 50, 56, 34, 44, 36, 123, 50,
  57, 45, 51, 50, 125, 44, 34, 36, 51, 51, 34, 44, 48, 44, 48, 44,
  36, 123, 51, 54, 45, 51, 57, 125, 44, 48, 44, 36, 123, 52, 49, 45,
  52, 51, 125, 32, 45, 107, 91, 36, 112, 118, 93, 10, 45, 116, 101, 120,
  116, 91, 48, 93, 32, 34, 108, 97, 121, 101, 114, 32, 34, 64, 123, 34,
  45, 113, 117, 111, 116, 101, 32, 92, 34, 34, 36, 110, 114, 34, 92, 34,
  34, 125, 44, 50, 48, 44, 55, 53, 37, 44, 123, 104, 42, 48, 46, 49,
  125, 44, 49, 44, 50, 53, 53, 44, 123, 105, 102, 40, 123, 123, 36, 49,
  51, 61, 61, 50, 125, 124, 124, 123, 36, 49, 51, 61, 61, 51, 125, 124,
  124, 123, 36, 49, 51, 61, 61, 49, 53, 125, 125, 44, 48, 44, 50, 53,
  53, 41, 125, 44, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36,
  50, 52, 33, 61, 48, 125, 32, 45, 116, 101, 120, 116, 32, 34, 70, 111,
  114, 32, 112, 114, 101, 118, 105, 101, 119, 32, 119, 105, 116, 104, 32, 102,
  114, 97, 109, 101, 115, 32, 111, 102, 102, 115, 101, 116, 32, 34, 44, 50,
  48, 44, 55, 48, 37, 44, 123, 104, 42, 48, 46, 48, 53, 125, 44, 49,
  44, 50, 53, 53, 44, 123, 105, 102, 40, 123, 36, 49, 51, 61, 61, 49,
  53, 125, 44, 48, 44, 50, 53, 53, 41, 125, 44, 123, 105, 102, 40, 123,
  36, 49, 51, 61, 61, 49, 53, 125, 44, 48, 44, 50, 53, 53, 41, 125,
  44, 50, 53, 53, 10, 45, 116, 101, 120, 116, 32, 34, 117, 115, 101, 32,
  102, 117, 108, 108, 32, 108, 97, 121, 101, 114, 32, 115, 116, 97, 99, 107,
  32, 112, 114, 101, 118, 105, 101, 119, 32, 109, 111, 100, 101, 33, 34, 44,
  50, 48, 44, 56, 53, 37, 44, 123, 104, 42, 48, 46, 48, 53, 125, 44,
  49, 44, 50, 53, 53, 44, 123, 105, 102, 40, 123, 36, 49, 51, 61, 61,
  49, 53, 125, 44, 48, 44, 50, 53, 53, 41, 125, 44, 123, 105, 102, 40,
  123, 36, 49, 51, 61, 61, 49, 53, 125, 44, 48, 44, 50, 53, 53, 41,
  125, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 123, 36, 51, 52, 33, 61, 48, 125, 124, 124, 123, 36, 51, 53,
  33, 61, 48, 125, 125, 32, 45, 116, 101, 120, 116, 32, 34, 70, 111, 114,
  32, 102, 97, 100, 101, 32, 105, 110, 47, 111, 117, 116, 32, 101, 102, 102,
  101, 99, 116, 32, 112, 114, 101, 118, 105, 101, 119, 34, 44, 50, 48, 44,
  54, 53, 37, 44, 123, 104, 42, 48, 46, 48, 53, 125, 44, 49, 44, 50,
  53, 53, 44, 123, 105, 102, 40, 123, 36, 49, 51, 61, 61, 49, 53, 125,
  44, 48, 44, 50, 53, 53, 41, 125, 44, 123, 105, 102, 40, 123, 36, 49,
  51, 61, 61, 49, 53, 125, 44, 48, 44, 50, 53, 53, 41, 125, 44, 50,
  53, 53, 10, 45, 116, 101, 120, 116, 32, 34, 117, 115, 101, 32, 102, 117,
  108, 108, 32, 108, 97, 121, 101, 114, 32, 115, 116, 97, 99, 107, 32, 112,
  114, 101, 118, 105, 101, 119, 32, 109, 111, 100, 101, 33, 34, 44, 50, 48,
  44, 56, 53, 37, 44, 123, 104, 42, 48, 46, 48, 53, 125, 44, 49, 44,
  50, 53, 53, 44, 123, 105, 102, 40, 123, 36, 49, 51, 61, 61, 49, 53,
  125, 44, 48, 44, 50, 53, 53, 41, 125, 44, 123, 105, 102, 40, 123, 36,
  49, 51, 61, 61, 49, 53, 125, 44, 48, 44, 50, 53, 53, 41, 125, 44,
  50, 53, 53, 32, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 52, 48, 33, 61, 48, 125, 32, 45, 116, 101, 120, 116, 32, 34,
  70, 111, 114, 32, 112, 114, 101, 118, 105, 101, 119, 32, 119, 105, 116, 104,
  32, 99, 117, 115, 116, 111, 109, 32, 100, 101, 112, 116, 104, 32, 99, 111,
  114, 114, 101, 99, 116, 105, 111, 110, 32, 34, 44, 50, 48, 44, 54, 48,
  37, 44, 123, 104, 42, 48, 46, 48, 53, 125, 44, 49, 44, 50, 53, 53,
  44, 123, 105, 102, 40, 123, 36, 49, 51, 61, 61, 49, 53, 125, 44, 48,
  44, 50, 53, 53, 41, 125, 44, 123, 105, 102, 40, 123, 36, 49, 51, 61,
  61, 49, 53, 125, 44, 48, 44, 50, 53, 53, 41, 125, 44, 50, 53, 53,
  10, 45, 116, 101, 120, 116, 32, 34, 117, 115, 101, 32, 102, 117, 108, 108,
  32, 108, 97, 121, 101, 114, 32, 115, 116, 97, 99, 107, 32, 112, 114, 101,
  118, 105, 101, 119, 32, 109, 111, 100, 101, 33, 34, 44, 50, 48, 44, 56,
  53, 37, 44, 123, 104, 42, 48, 46, 48, 53, 125, 44, 49, 44, 50, 53,
  53, 44, 123, 105, 102, 40, 123, 36, 49, 51, 61, 61, 49, 53, 125, 44,
  48, 44, 50, 53, 53, 41, 125, 44, 123, 105, 102, 40, 123, 36, 49, 51,
  61, 61, 49, 53, 125, 44, 48, 44, 50, 53, 53, 41, 125, 44, 50, 53,
  53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49,
  48, 33, 61, 48, 125, 32, 45, 116, 101, 120, 116, 32, 34, 70, 111, 114,
  32, 112, 114, 101, 118, 105, 101, 119, 32, 119, 105, 116, 104, 32, 109, 111,
  116, 105, 111, 110, 32, 97, 110, 97, 108, 121, 122, 101, 114, 32, 34, 44,
  50, 48, 44, 53, 53, 37, 44, 123, 104, 42, 48, 46, 48, 53, 125, 44,
  49, 44, 50, 53, 53, 44, 123, 105, 102, 40, 123, 36, 49, 51, 61, 61,
  49, 53, 125, 44, 48, 44, 50, 53, 53, 41, 125, 44, 123, 105, 102, 40,
  123, 36, 49, 51, 61, 61, 49, 53, 125, 44, 48, 44, 50, 53, 53, 41,
  125, 44, 50, 53, 53, 10, 45, 116, 101, 120, 116, 32, 34, 117, 115, 101,
  32, 102, 117, 108, 108, 32, 108, 97, 121, 101, 114, 32, 115, 116, 97, 99,
  107, 32, 112, 114, 101, 118, 105, 101, 119, 32, 109, 111, 100, 101, 33, 34,
  44, 50, 48, 44, 56, 53, 37, 44, 123, 104, 42, 48, 46, 48, 53, 125,
  44, 49, 44, 50, 53, 53, 44, 123, 105, 102, 40, 123, 36, 49, 51, 61,
  61, 49, 53, 125, 44, 48, 44, 50, 53, 53, 41, 125, 44, 123, 105, 102,
  40, 123, 36, 49, 51, 61, 61, 49, 53, 125, 44, 48, 44, 50, 53, 53,
  41, 125, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 123, 36, 51, 50, 61, 61, 50, 125, 124, 124, 123, 36, 51,
  50, 61, 61, 51, 125, 125, 32, 45, 116, 101, 120, 116, 91, 48, 93, 32,
  34, 83, 101, 112, 97, 114, 97, 116, 101, 32, 115, 116, 114, 101, 97, 109,
  32, 102, 105, 108, 116, 101, 114, 105, 110, 103, 32, 105, 103, 110, 111, 114,
  101, 100, 32, 105, 110, 32, 108, 97, 121, 101, 114, 32, 109, 111, 100, 101,
  34, 44, 50, 48, 44, 53, 48, 37, 44, 123, 104, 42, 48, 46, 48, 53,
  125, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 50, 53,
  53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101, 10, 45,
  103, 105, 109, 112, 95, 116, 107, 95, 118, 105, 100, 101, 111, 51, 68, 32,
  36, 49, 44, 36, 115, 104, 112, 114, 101, 44, 36, 115, 119, 112, 114, 101,
  44, 36, 123, 52, 45, 49, 51, 125, 44, 48, 44, 34, 36, 49, 53, 34,
  44, 36, 123, 49, 54, 45, 50, 54, 125, 44, 34, 36, 50, 55, 34, 44,
  34, 36, 50, 56, 34, 44, 36, 123, 50, 57, 45, 51, 50, 125, 44, 34,
  36, 51, 51, 34, 44, 36, 123, 51, 52, 45, 52, 51, 125, 32, 45, 107,
  91, 36, 112, 118, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 116, 101,
  120, 116, 91, 48, 93, 32, 34, 108, 97, 121, 101, 114, 32, 34, 64, 123,
  34, 45, 113, 117, 111, 116, 101, 32, 92, 34, 34, 36, 110, 114, 34, 92,
  34, 34, 125, 44, 50, 48, 44, 55, 53, 37, 44, 123, 104, 42, 48, 46,
  49, 125, 44, 49, 44, 50, 53, 53, 44, 123, 105, 102, 40, 123, 123, 36,
  49, 51, 61, 61, 50, 125, 124, 124, 123, 36, 49, 51, 61, 61, 51, 125,
  124, 124, 123, 36, 49, 51, 61, 61, 49, 53, 125, 125, 44, 48, 44, 50,
  53, 53, 41, 125, 44, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123,
  123, 36, 50, 61, 61, 48, 125, 38, 38, 123, 36, 51, 61, 61, 48, 125,
  38, 38, 123, 36, 49, 61, 61, 50, 52, 125, 38, 38, 123, 36, 49, 51,
  61, 61, 49, 52, 125, 38, 38, 123, 36, 51, 50, 33, 61, 48, 125, 125,
  32, 45, 116, 101, 120, 116, 91, 48, 93, 32, 34, 50, 68, 32, 102, 105,
  108, 116, 101, 114, 32, 109, 111, 100, 101, 32, 111, 110, 33, 34, 44, 53,
  48, 37, 44, 55, 53, 37, 44, 123, 104, 42, 48, 46, 48, 55, 53, 125,
  44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 50, 53, 53,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 51, 54,
  33, 61, 49, 125, 32, 45, 116, 101, 120, 116, 32, 34, 75, 101, 121, 32,
  102, 114, 97, 109, 101, 32, 115, 101, 116, 116, 105, 110, 103, 115, 32, 105,
  103, 110, 111, 114, 101, 100, 32, 105, 110, 32, 108, 97, 121, 101, 114, 32,
  112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 109, 111, 100, 101, 46,
  32, 34, 44, 50, 48, 44, 53, 48, 37, 44, 123, 104, 42, 48, 46, 48,
  53, 125, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 50,
  53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 95, 112, 114, 101, 118, 105,
  101, 119, 102, 108, 97, 103, 61, 48, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 108, 115, 101, 10, 35, 35, 35, 35, 112, 114, 101, 118, 105, 101,
  119, 32, 98, 97, 116, 99, 104, 32, 109, 111, 100, 101, 35, 35, 35, 35,
  10, 95, 112, 114, 101, 118, 105, 101, 119, 102, 108, 97, 103, 61, 50, 10,
  45, 105, 102, 32, 123, 36, 52, 50, 61, 61, 51, 125, 10, 45, 45, 102,
  99, 91, 48, 93, 32, 50, 53, 53, 44, 48, 44, 49, 50, 56, 44, 50,
  53, 53, 32, 45, 107, 91, 45, 49, 93, 10, 45, 116, 101, 120, 116, 32,
  34, 78, 111, 32, 112, 114, 101, 118, 105, 101, 119, 32, 97, 118, 97, 105,
  108, 97, 98, 108, 101, 34, 44, 50, 48, 44, 53, 48, 44, 50, 56, 44,
  49, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 10, 45, 116, 101, 120,
  116, 32, 34, 102, 111, 114, 32, 98, 97, 116, 99, 104, 32, 105, 110, 112,
  117, 116, 32, 115, 116, 97, 99, 107, 33, 34, 44, 50, 48, 44, 56, 48,
  44, 50, 56, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 10,
  45, 116, 101, 120, 116, 32, 34, 80, 108, 101, 97, 115, 101, 32, 115, 101,
  108, 101, 99, 116, 32, 102, 114, 97, 109, 101, 32, 116, 111, 32, 97, 100,
  106, 117, 115, 116, 32, 115, 101, 116, 116, 105, 110, 103, 115, 46, 34, 44,
  50, 48, 44, 49, 53, 48, 44, 49, 54, 44, 49, 44, 48, 44, 48, 44,
  48, 44, 50, 53, 53, 10, 45, 101, 108, 105, 102, 32, 123, 123, 36, 52,
  50, 61, 61, 50, 125, 38, 38, 123, 123, 36, 52, 51, 60, 61, 123, 36,
  50, 57, 45, 49, 125, 125, 124, 124, 123, 36, 52, 51, 62, 61, 123, 36,
  51, 48, 43, 49, 125, 125, 125, 125, 32, 45, 102, 99, 91, 48, 93, 32,
  50, 53, 53, 44, 48, 44, 49, 50, 56, 44, 50, 53, 53, 32, 45, 107,
  91, 48, 93, 10, 45, 116, 101, 120, 116, 91, 48, 93, 32, 34, 83, 101,
  108, 101, 99, 116, 101, 100, 32, 102, 114, 97, 109, 101, 32, 111, 117, 116,
  32, 111, 102, 32, 114, 97, 110, 103, 101, 33, 32, 34, 44, 49, 48, 44,
  56, 48, 37, 44, 50, 52, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50,
  53, 53, 10, 45, 101, 108, 105, 102, 32, 123, 123, 36, 52, 49, 61, 61,
  50, 125, 38, 38, 123, 36, 49, 51, 61, 61, 49, 52, 125, 125, 32, 45,
  102, 99, 91, 48, 93, 32, 50, 53, 53, 44, 48, 44, 49, 50, 56, 44,
  50, 53, 53, 32, 45, 107, 91, 48, 93, 10, 45, 116, 101, 120, 116, 91,
  48, 93, 32, 34, 79, 117, 116, 112, 117, 116, 32, 102, 111, 114, 109, 97,
  116, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 33, 34, 44,
  49, 48, 44, 56, 48, 37, 44, 50, 52, 44, 49, 44, 48, 44, 48, 44,
  48, 44, 50, 53, 53, 10, 45, 101, 108, 105, 102, 32, 123, 123, 36, 52,
  49, 61, 61, 51, 125, 38, 38, 123, 36, 49, 51, 61, 61, 49, 53, 125,
  125, 32, 45, 102, 99, 91, 48, 93, 32, 50, 53, 53, 44, 48, 44, 49,
  50, 56, 44, 50, 53, 53, 32, 45, 107, 91, 48, 93, 10, 45, 116, 101,
  120, 116, 91, 48, 93, 32, 34, 79, 117, 116, 112, 117, 116, 32, 102, 111,
  114, 109, 97, 116, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100,
  33, 34, 44, 49, 48, 44, 56, 48, 37, 44, 50, 52, 44, 49, 44, 48,
  44, 48, 44, 48, 44, 50, 53, 53, 10, 45, 101, 108, 115, 101, 10, 45,
  114, 109, 10, 45, 105, 102, 32, 123, 36, 51, 49, 61, 61, 48, 125, 32,
  101, 110, 100, 61, 34, 46, 112, 110, 103, 34, 32, 45, 101, 108, 115, 101,
  32, 101, 110, 100, 61, 34, 46, 98, 109, 112, 34, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 52, 50, 61, 61, 48, 125, 32,
  32, 105, 110, 102, 105, 108, 101, 61, 123, 36, 50, 57, 125, 10, 45, 105,
  102, 32, 123, 36, 51, 52, 33, 61, 48, 125, 32, 115, 119, 112, 114, 101,
  61, 123, 123, 49, 47, 36, 51, 52, 125, 42, 36, 115, 119, 112, 114, 101,
  125, 32, 115, 104, 112, 114, 101, 61, 123, 123, 49, 47, 36, 51, 52, 125,
  42, 36, 115, 104, 112, 114, 101, 125, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 52, 50, 61, 61, 49, 125, 32, 105,
  110, 102, 105, 108, 101, 61, 123, 36, 51, 48, 125, 10, 45, 105, 102, 32,
  123, 36, 51, 53, 33, 61, 48, 125, 32, 115, 119, 112, 114, 101, 61, 123,
  123, 49, 45, 123, 49, 47, 36, 51, 53, 125, 125, 42, 36, 115, 119, 112,
  114, 101, 125, 32, 115, 104, 112, 114, 101, 61, 123, 123, 49, 45, 123, 49,
  47, 36, 51, 53, 125, 125, 42, 36, 115, 104, 112, 114, 101, 125, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 108, 105, 102, 32, 123, 36, 52, 50,
  61, 61, 50, 125, 32, 105, 110, 102, 105, 108, 101, 61, 123, 36, 52, 51,
  125, 10, 45, 105, 102, 32, 123, 123, 36, 51, 52, 33, 61, 48, 125, 124,
  124, 123, 36, 51, 53, 33, 61, 48, 125, 125, 10, 45, 105, 102, 32, 123,
  36, 52, 51, 60, 61, 123, 36, 50, 57, 43, 36, 51, 52, 125, 125, 32,
  115, 119, 112, 114, 101, 61, 123, 123, 36, 52, 51, 47, 36, 51, 52, 125,
  42, 36, 115, 119, 112, 114, 101, 125, 32, 115, 104, 112, 114, 101, 61, 123,
  123, 36, 52, 51, 47, 36, 51, 52, 125, 42, 36, 115, 104, 112, 114, 101,
  125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 52,
  51, 62, 61, 123, 36, 51, 48, 45, 36, 51, 53, 125, 125, 32, 115, 119,
  112, 114, 101, 61, 123, 123, 36, 51, 48, 45, 36, 52, 51, 125, 42, 123,
  36, 115, 119, 112, 114, 101, 47, 36, 51, 53, 125, 125, 32, 115, 104, 112,
  114, 101, 61, 123, 123, 36, 51, 48, 45, 36, 52, 51, 125, 42, 123, 36,
  115, 104, 112, 114, 101, 47, 36, 51, 53, 125, 125, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 52, 49, 33, 61, 50, 125, 10, 105, 110,
  112, 97, 116, 104, 49, 61, 34, 36, 50, 55, 47, 36, 50, 56, 34, 36,
  105, 110, 102, 105, 108, 101, 34, 34, 36, 101, 110, 100, 34, 34, 10, 45,
  105, 110, 112, 117, 116, 91, 48, 93, 32, 64, 123, 34, 45, 113, 117, 111,
  116, 101, 32, 92, 34, 34, 36, 105, 110, 112, 97, 116, 104, 49, 34, 92,
  34, 34, 125, 10, 45, 105, 102, 32, 123, 36, 50, 52, 33, 61, 48, 125,
  32, 105, 110, 102, 105, 108, 101, 111, 102, 102, 61, 123, 36, 105, 110, 102,
  105, 108, 101, 43, 36, 50, 52, 125, 10, 45, 105, 102, 32, 123, 36, 105,
  110, 102, 105, 108, 101, 111, 102, 102, 60, 61, 36, 50, 57, 125, 32, 105,
  110, 102, 105, 108, 101, 111, 102, 102, 61, 123, 36, 50, 57, 125, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 105, 110, 102, 105,
  108, 101, 111, 102, 102, 62, 61, 36, 51, 48, 125, 32, 105, 110, 102, 105,
  108, 101, 111, 102, 102, 61, 123, 36, 51, 48, 125, 32, 45, 101, 110, 100,
  105, 102, 10, 105, 110, 112, 97, 116, 104, 111, 102, 102, 61, 34, 36, 50,
  55, 47, 36, 50, 56, 34, 36, 105, 110, 102, 105, 108, 101, 111, 102, 102,
  34, 34, 36, 101, 110, 100, 34, 34, 10, 45, 105, 110, 112, 117, 116, 91,
  49, 93, 32, 64, 123, 34, 45, 113, 117, 111, 116, 101, 32, 92, 34, 34,
  36, 105, 110, 112, 97, 116, 104, 111, 102, 102, 34, 92, 34, 34, 125, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 105, 110, 102,
  105, 108, 101, 33, 61, 36, 50, 57, 125, 32, 45, 105, 102, 32, 123, 36,
  49, 48, 33, 61, 48, 125, 10, 105, 110, 102, 105, 108, 101, 109, 111, 118,
  61, 123, 36, 105, 110, 102, 105, 108, 101, 45, 49, 125, 32, 105, 110, 112,
  97, 116, 104, 109, 111, 118, 61, 34, 36, 50, 55, 47, 36, 50, 56, 34,
  36, 105, 110, 102, 105, 108, 101, 109, 111, 118, 34, 34, 36, 101, 110, 100,
  34, 34, 10, 45, 105, 110, 112, 117, 116, 91, 45, 49, 93, 32, 64, 123,
  34, 45, 113, 117, 111, 116, 101, 32, 92, 34, 34, 36, 105, 110, 112, 97,
  116, 104, 109, 111, 118, 34, 92, 34, 34, 125, 10, 45, 105, 102, 32, 123,
  36, 105, 110, 102, 105, 108, 101, 62, 61, 123, 36, 50, 57, 43, 50, 125,
  125, 10, 105, 110, 102, 105, 108, 101, 109, 111, 118, 50, 61, 123, 36, 105,
  110, 102, 105, 108, 101, 45, 50, 125, 32, 105, 110, 112, 97, 116, 104, 109,
  111, 118, 50, 61, 34, 36, 50, 55, 47, 36, 50, 56, 34, 36, 105, 110,
  102, 105, 108, 101, 109, 111, 118, 50, 34, 34, 36, 101, 110, 100, 34, 34,
  10, 45, 105, 110, 112, 117, 116, 91, 45, 49, 93, 32, 64, 123, 34, 45,
  113, 117, 111, 116, 101, 32, 92, 34, 34, 36, 105, 110, 112, 97, 116, 104,
  109, 111, 118, 50, 34, 92, 34, 34, 125, 10, 105, 110, 102, 105, 108, 101,
  109, 111, 118, 51, 61, 123, 36, 105, 110, 102, 105, 108, 101, 45, 49, 125,
  32, 105, 110, 112, 97, 116, 104, 109, 111, 118, 51, 61, 34, 36, 50, 55,
  47, 36, 50, 56, 34, 36, 105, 110, 102, 105, 108, 101, 109, 111, 118, 51,
  34, 34, 36, 101, 110, 100, 34, 34, 10, 45, 105, 110, 112, 117, 116, 91,
  45, 49, 93, 32, 64, 123, 34, 45, 113, 117, 111, 116, 101, 32, 92, 34,
  34, 36, 105, 110, 112, 97, 116, 104, 109, 111, 118, 51, 34, 92, 34, 34,
  125, 10, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115, 101, 10, 105, 110, 112,
  97, 116, 104, 108, 101, 102, 116, 61, 34, 36, 50, 55, 47, 36, 50, 56,
  34, 34, 108, 101, 102, 116, 95, 34, 36, 105, 110, 102, 105, 108, 101, 36,
  101, 110, 100, 32, 105, 110, 112, 97, 116, 104, 114, 105, 103, 104, 116, 61,
  34, 36, 50, 55, 47, 36, 50, 56, 34, 34, 114, 105, 103, 104, 116, 95,
  34, 36, 105, 110, 102, 105, 108, 101, 36, 101, 110, 100, 10, 45, 114, 109,
  32, 45, 105, 110, 112, 117, 116, 91, 48, 93, 32, 64, 123, 34, 45, 113,
  117, 111, 116, 101, 32, 92, 34, 34, 36, 105, 110, 112, 97, 116, 104, 108,
  101, 102, 116, 34, 92, 34, 34, 125, 10, 45, 105, 110, 112, 117, 116, 91,
  49, 93, 32, 64, 123, 34, 45, 113, 117, 111, 116, 101, 32, 92, 34, 34,
  36, 105, 110, 112, 97, 116, 104, 114, 105, 103, 104, 116, 34, 92, 34, 34,
  125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 52,
  50, 61, 61, 48, 125, 32, 95, 109, 97, 112, 105, 110, 61, 36, 50, 57,
  32, 45, 101, 108, 105, 102, 32, 123, 36, 52, 50, 61, 61, 49, 125, 32,
  95, 109, 97, 112, 105, 110, 61, 36, 51, 48, 32, 45, 101, 108, 105, 102,
  32, 123, 36, 52, 50, 61, 61, 50, 125, 32, 95, 109, 97, 112, 105, 110,
  61, 36, 52, 51, 32, 45, 101, 110, 100, 105, 102, 10, 102, 114, 97, 109,
  101, 115, 110, 61, 123, 123, 36, 51, 48, 45, 36, 50, 57, 125, 43, 49,
  125, 10, 45, 105, 102, 32, 123, 123, 123, 36, 51, 52, 33, 61, 48, 125,
  124, 124, 123, 36, 51, 53, 33, 61, 48, 125, 125, 38, 38, 123, 123, 36,
  51, 52, 62, 61, 123, 36, 102, 114, 97, 109, 101, 115, 110, 45, 36, 51,
  53, 125, 125, 124, 124, 123, 36, 51, 53, 62, 61, 123, 36, 102, 114, 97,
  109, 101, 115, 110, 45, 36, 51, 52, 125, 125, 125, 125, 32, 45, 102, 99,
  91, 48, 93, 32, 50, 53, 53, 44, 48, 44, 49, 50, 56, 44, 50, 53,
  53, 32, 45, 107, 91, 48, 93, 10, 45, 116, 101, 120, 116, 32, 34, 70,
  97, 100, 101, 32, 111, 117, 116, 32, 111, 102, 32, 102, 114, 97, 109, 101,
  32, 114, 97, 110, 103, 101, 33, 32, 34, 44, 49, 48, 44, 56, 48, 37,
  44, 123, 104, 42, 48, 46, 49, 125, 44, 49, 44, 48, 44, 48, 44, 48,
  44, 50, 53, 53, 10, 45, 101, 108, 115, 101, 10, 45, 105, 102, 32, 123,
  123, 36, 52, 49, 61, 61, 50, 125, 38, 38, 123, 36, 49, 51, 61, 61,
  49, 53, 125, 125, 32, 45, 45, 103, 105, 109, 112, 95, 116, 107, 95, 100,
  101, 112, 116, 104, 95, 111, 98, 116, 97, 105, 110, 91, 48, 44, 49, 93,
  32, 36, 49, 49, 44, 123, 36, 51, 55, 47, 49, 48, 48, 125, 44, 123,
  49, 48, 48, 45, 123, 36, 51, 56, 42, 50, 48, 125, 125, 44, 123, 36,
  51, 57, 42, 50, 48, 125, 10, 45, 105, 102, 32, 123, 36, 51, 50, 33,
  61, 48, 125, 32, 45, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109,
  95, 99, 111, 100, 101, 91, 48, 44, 49, 44, 45, 49, 93, 32, 34, 36,
  51, 51, 34, 44, 48, 44, 48, 44, 48, 32, 32, 45, 101, 110, 100, 105,
  102, 32, 45, 107, 91, 45, 49, 93, 10, 45, 101, 108, 115, 101, 10, 45,
  103, 105, 109, 112, 95, 116, 107, 95, 118, 105, 100, 101, 111, 51, 68, 32,
  36, 49, 44, 36, 115, 104, 112, 114, 101, 44, 36, 115, 119, 112, 114, 101,
  44, 36, 123, 52, 45, 57, 125, 44, 123, 105, 102, 40, 123, 36, 105, 110,
  102, 105, 108, 101, 61, 61, 36, 50, 57, 125, 44, 48, 44, 36, 49, 48,
  41, 125, 44, 36, 123, 49, 49, 45, 49, 51, 125, 44, 48, 44, 34, 36,
  49, 53, 34, 44, 36, 123, 49, 54, 45, 50, 53, 125, 44, 48, 44, 34,
  36, 50, 55, 34, 44, 34, 36, 50, 56, 34, 44, 36, 123, 50, 57, 45,
  51, 49, 125, 44, 123, 105, 102, 40, 123, 123, 36, 50, 61, 61, 48, 125,
  38, 38, 123, 36, 51, 61, 61, 48, 125, 38, 38, 123, 36, 49, 61, 61,
  50, 52, 125, 38, 38, 123, 36, 49, 51, 61, 61, 49, 52, 125, 38, 38,
  123, 36, 51, 50, 33, 61, 48, 125, 125, 44, 50, 44, 36, 51, 50, 41,
  125, 44, 34, 36, 51, 51, 34, 44, 48, 44, 48, 44, 49, 44, 36, 123,
  51, 55, 45, 52, 51, 125, 10, 45, 101, 110, 100, 105, 102, 32, 45, 116,
  111, 95, 114, 103, 98, 32, 45, 105, 102, 32, 123, 36, 49, 51, 61, 61,
  49, 52, 125, 32, 45, 107, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 116, 101, 120, 116, 91, 48, 93, 32, 34, 102, 114, 97, 109,
  101, 32, 34, 64, 123, 34, 45, 113, 117, 111, 116, 101, 32, 92, 34, 34,
  36, 105, 110, 102, 105, 108, 101, 34, 92, 34, 34, 125, 44, 50, 48, 44,
  55, 53, 37, 44, 123, 104, 42, 48, 46, 49, 125, 44, 49, 44, 50, 53,
  53, 44, 123, 105, 102, 40, 123, 123, 36, 49, 51, 61, 61, 50, 125, 124,
  124, 123, 36, 49, 51, 61, 61, 51, 125, 124, 124, 123, 36, 49, 51, 61,
  61, 49, 53, 125, 125, 44, 48, 44, 50, 53, 53, 41, 125, 44, 48, 44,
  50, 53, 53, 10, 45, 105, 102, 32, 123, 36, 52, 49, 33, 61, 50, 125,
  32, 45, 105, 102, 32, 123, 36, 51, 54, 33, 61, 49, 125, 32, 45, 105,
  102, 32, 123, 123, 36, 52, 48, 61, 61, 48, 125, 124, 124, 123, 36, 52,
  48, 61, 61, 49, 125, 125, 32, 45, 116, 101, 120, 116, 91, 48, 93, 32,
  34, 80, 114, 101, 118, 105, 101, 119, 32, 97, 108, 119, 97, 121, 115, 32,
  102, 111, 114, 99, 101, 100, 32, 116, 111, 32, 107, 101, 121, 32, 102, 114,
  97, 109, 101, 46, 32, 34, 44, 50, 48, 44, 53, 48, 37, 44, 123, 104,
  42, 48, 46, 48, 53, 125, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 48, 44, 50, 53, 53, 32, 45, 101, 108, 115, 101, 10, 45, 116, 101,
  120, 116, 91, 48, 93, 32, 34, 78, 111, 32, 107, 101, 121, 102, 114, 97,
  109, 101, 32, 99, 111, 109, 112, 117, 116, 97, 116, 105, 111, 110, 32, 102,
  111, 114, 32, 105, 110, 100, 105, 118, 105, 100, 117, 97, 108, 32, 109, 97,
  112, 115, 46, 32, 34, 44, 50, 48, 44, 54, 52, 37, 44, 123, 104, 42,
  48, 46, 48, 53, 125, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110,
  100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  123, 36, 50, 61, 61, 48, 125, 38, 38, 123, 36, 51, 61, 61, 48, 125,
  38, 38, 123, 36, 49, 61, 61, 50, 52, 125, 38, 38, 123, 36, 49, 51,
  61, 61, 49, 52, 125, 38, 38, 123, 36, 51, 50, 33, 61, 48, 125, 125,
  32, 45, 116, 101, 120, 116, 91, 48, 93, 32, 34, 50, 68, 32, 102, 105,
  108, 116, 101, 114, 32, 109, 111, 100, 101, 32, 111, 110, 33, 34, 44, 53,
  48, 37, 44, 55, 53, 37, 44, 123, 104, 42, 48, 46, 48, 55, 53, 125,
  44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 50, 53, 53,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 32, 45,
  101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10, 95, 112, 114,
  101, 118, 105, 101, 119, 102, 108, 97, 103, 61, 48, 10, 35, 64, 103, 105,
  109, 112, 32, 65, 117, 116, 111, 109, 97, 116, 105, 99, 32, 100, 101, 112,
  116, 104, 32, 101, 115, 116, 105, 109, 97, 116, 105, 111, 110, 32, 58, 32,
  103, 105, 109, 112, 95, 116, 107, 95, 97, 117, 116, 111, 100, 101, 112, 116,
  104, 44, 32, 103, 105, 109, 112, 95, 116, 107, 95, 97, 117, 116, 111, 100,
  101, 112, 116, 104, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 84, 104, 105, 115, 32, 102, 105,
  108, 116, 101, 114, 32, 101, 115, 116, 105, 109, 97, 116, 101, 115, 32, 97,
  32, 100, 101, 112, 116, 104, 32, 109, 97, 112, 32, 102, 114, 111, 109, 32,
  97, 32, 50, 68, 32, 105, 109, 97, 103, 101, 32, 98, 121, 32, 97, 110,
  97, 108, 121, 122, 105, 110, 103, 32, 118, 97, 114, 105, 111, 117, 115, 32,
  109, 111, 110, 111, 115, 99, 111, 112, 105, 99, 32, 105, 109, 97, 103, 101,
  32, 112, 114, 111, 112, 101, 114, 116, 105, 101, 115, 46, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65,
  117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 84, 111, 109, 32, 75, 101,
  105, 108, 60, 47, 105, 62, 32, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 50, 47, 48, 55, 47, 51, 48, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 116, 107,
  95, 97, 117, 116, 111, 100, 101, 112, 116, 104, 32, 58, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45,
  116, 111, 95, 114, 103, 98, 32, 115, 105, 122, 101, 49, 61, 123, 119, 125,
  32, 45, 114, 101, 115, 105, 122, 101, 50, 100, 120, 32, 52, 48, 48, 44,
  50, 10, 35, 99, 111, 101, 102, 102, 105, 99, 105, 101, 110, 116, 32, 115,
  101, 116, 116, 105, 110, 103, 115, 10, 119, 104, 112, 111, 115, 61, 49, 50,
  56, 32, 98, 108, 112, 111, 115, 61, 49, 50, 56, 32, 114, 112, 111, 115,
  61, 50, 53, 53, 32, 103, 112, 111, 115, 61, 50, 48, 48, 32, 98, 108,
  117, 112, 111, 115, 61, 50, 48, 48, 32, 99, 114, 103, 97, 61, 49, 46,
  53, 32, 99, 114, 109, 105, 120, 49, 61, 48, 46, 53, 32, 99, 114, 109,
  105, 120, 50, 61, 48, 46, 53, 32, 103, 101, 111, 99, 111, 109, 112, 49,
  61, 55, 53, 32, 103, 101, 111, 99, 111, 109, 112, 50, 61, 51, 48, 10,
  103, 101, 111, 115, 116, 114, 61, 48, 46, 51, 32, 102, 111, 99, 115, 116,
  114, 61, 48, 46, 51, 32, 102, 101, 97, 116, 115, 105, 122, 101, 61, 54,
  48, 32, 102, 101, 97, 116, 112, 111, 115, 61, 49, 50, 56, 32, 102, 101,
  97, 116, 116, 114, 61, 51, 53, 32, 116, 114, 61, 51, 48, 32, 114, 116,
  114, 61, 57, 48, 32, 103, 116, 114, 61, 57, 48, 32, 98, 108, 117, 116,
  114, 61, 57, 48, 32, 99, 111, 110, 116, 115, 116, 114, 61, 48, 46, 57,
  10, 102, 101, 97, 116, 105, 110, 102, 108, 61, 49, 32, 102, 111, 99, 116,
  111, 108, 61, 53, 32, 102, 111, 99, 109, 111, 114, 112, 104, 61, 55, 48,
  32, 102, 111, 99, 97, 118, 116, 61, 56, 53, 32, 102, 111, 99, 97, 118,
  116, 50, 61, 49, 52, 48, 32, 102, 111, 99, 118, 97, 114, 116, 61, 50,
  48, 48, 48, 32, 108, 97, 116, 105, 110, 104, 105, 98, 61, 48, 46, 53,
  10, 35, 100, 101, 112, 116, 104, 32, 102, 114, 111, 109, 32, 103, 114, 97,
  118, 105, 116, 121, 10, 45, 45, 103, 105, 109, 112, 95, 109, 97, 112, 95,
  116, 111, 110, 101, 115, 95, 102, 97, 115, 116, 91, 45, 49, 93, 32, 49,
  48, 44, 48, 46, 53, 44, 48, 44, 48, 32, 45, 108, 117, 109, 105, 110,
  97, 110, 99, 101, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 115,
  101, 103, 109, 101, 110, 116, 95, 119, 97, 116, 101, 114, 115, 104, 101, 100,
  91, 45, 49, 93, 32, 48, 46, 53, 44, 49, 44, 48, 32, 32, 45, 108,
  97, 98, 101, 108, 91, 45, 49, 93, 32, 53, 44, 48, 10, 45, 45, 103,
  105, 109, 112, 95, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114,
  109, 91, 48, 93, 32, 48, 44, 48, 46, 53, 44, 48, 44, 49, 48, 48,
  44, 48, 44, 48, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105,
  103, 104, 116, 101, 110, 91, 45, 49, 44, 45, 50, 93, 10, 45, 103, 105,
  109, 112, 95, 115, 101, 103, 109, 101, 110, 116, 95, 119, 97, 116, 101, 114,
  115, 104, 101, 100, 91, 45, 49, 93, 32, 48, 46, 53, 44, 49, 44, 48,
  32, 45, 108, 97, 98, 101, 108, 91, 45, 49, 93, 32, 53, 44, 48, 32,
  45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 35, 100, 101,
  112, 116, 104, 32, 102, 114, 111, 109, 32, 108, 117, 109, 105, 110, 97, 110,
  99, 101, 32, 97, 110, 100, 32, 99, 111, 109, 112, 101, 110, 115, 97, 116,
  101, 32, 111, 118, 101, 114, 47, 117, 110, 100, 101, 114, 101, 120, 112, 111,
  115, 101, 100, 32, 97, 114, 101, 97, 115, 10, 45, 45, 108, 117, 109, 105,
  110, 97, 110, 99, 101, 91, 48, 93, 10, 45, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 91, 48, 93, 32, 49, 32, 45, 116, 50, 91, 45, 49, 93,
  32, 36, 103, 116, 114, 37, 44, 49, 48, 48, 37, 10, 45, 103, 105, 109,
  112, 95, 109, 111, 114, 112, 104, 111, 91, 45, 49, 93, 32, 50, 44, 50,
  44, 48, 44, 48, 44, 48, 44, 49, 44, 48, 32, 45, 110, 91, 45, 49,
  93, 32, 48, 44, 36, 103, 112, 111, 115, 10, 45, 116, 107, 95, 103, 105,
  109, 112, 95, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114,
  91, 45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 48, 44, 48, 44, 50,
  53, 53, 44, 48, 44, 48, 44, 48, 44, 48, 32, 32, 45, 99, 111, 109,
  112, 111, 115, 101, 95, 97, 108, 112, 104, 97, 91, 45, 49, 44, 45, 50,
  93, 10, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48, 93, 32,
  48, 32, 45, 116, 50, 91, 45, 49, 93, 32, 36, 114, 116, 114, 37, 44,
  49, 48, 48, 37, 10, 45, 103, 105, 109, 112, 95, 109, 111, 114, 112, 104,
  111, 91, 45, 49, 93, 32, 50, 44, 50, 44, 48, 44, 48, 44, 48, 44,
  49, 44, 48, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 36, 114, 112,
  111, 115, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 114, 101, 112, 108,
  97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 49, 44,
  48, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 48, 44, 48, 44,
  48, 44, 48, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 97, 108, 112,
  104, 97, 91, 45, 49, 44, 45, 50, 93, 10, 45, 45, 99, 104, 97, 110,
  110, 101, 108, 115, 91, 48, 93, 32, 50, 32, 45, 116, 50, 91, 45, 49,
  93, 32, 36, 98, 108, 117, 116, 114, 37, 44, 49, 48, 48, 37, 32, 32,
  45, 110, 91, 45, 49, 93, 32, 48, 44, 36, 98, 108, 117, 112, 111, 115,
  10, 45, 103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111, 91, 45, 49,
  93, 32, 50, 44, 50, 44, 48, 44, 48, 44, 48, 44, 49, 44, 48, 10,
  45, 116, 107, 95, 103, 105, 109, 112, 95, 114, 101, 112, 108, 97, 99, 101,
  95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 49, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 48,
  10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 32, 45, 45,
  103, 105, 109, 112, 95, 108, 105, 110, 101, 97, 114, 95, 103, 114, 97, 100,
  105, 101, 110, 116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 48, 44, 57, 48, 44, 48, 44, 49, 48, 48, 10, 45, 115,
  91, 45, 50, 93, 32, 99, 32, 45, 114, 118, 91, 45, 49, 44, 45, 50,
  93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108, 116, 105,
  112, 108, 121, 91, 45, 49, 44, 45, 50, 93, 32, 45, 116, 111, 95, 103,
  114, 97, 121, 91, 45, 49, 93, 32, 45, 97, 91, 45, 52, 44, 45, 51,
  44, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 99, 111, 109, 112, 111,
  115, 101, 95, 97, 108, 112, 104, 97, 91, 45, 49, 44, 45, 50, 93, 10,
  45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48, 93, 32, 48, 32,
  45, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 48, 93, 32, 45,
  99, 111, 109, 112, 111, 115, 101, 95, 97, 118, 101, 114, 97, 103, 101, 91,
  45, 49, 44, 45, 50, 93, 32, 45, 116, 50, 91, 45, 49, 93, 32, 56,
  48, 37, 44, 57, 53, 37, 10, 45, 103, 105, 109, 112, 95, 109, 111, 114,
  112, 104, 111, 91, 45, 49, 93, 32, 50, 44, 50, 44, 48, 44, 48, 44,
  48, 44, 49, 44, 48, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 36,
  119, 104, 112, 111, 115, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 114,
  101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93,
  32, 49, 44, 48, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 48,
  44, 48, 44, 48, 44, 48, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  97, 108, 112, 104, 97, 91, 45, 49, 44, 45, 50, 93, 10, 45, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 91, 48, 93, 32, 48, 32, 45, 45, 108,
  117, 109, 105, 110, 97, 110, 99, 101, 91, 48, 93, 32, 45, 99, 111, 109,
  112, 111, 115, 101, 95, 97, 118, 101, 114, 97, 103, 101, 91, 45, 49, 44,
  45, 50, 93, 32, 45, 116, 50, 91, 45, 49, 93, 32, 53, 37, 44, 50,
  48, 37, 10, 45, 103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111, 91,
  45, 49, 93, 32, 50, 44, 50, 44, 48, 44, 48, 44, 48, 44, 49, 44,
  48, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 36, 98, 108, 112, 111,
  115, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 114, 101, 112, 108, 97,
  99, 101, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 49, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48,
  44, 48, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 97, 108, 112, 104,
  97, 91, 45, 49, 44, 45, 50, 93, 10, 35, 100, 101, 112, 116, 104, 32,
  102, 114, 111, 109, 32, 108, 97, 116, 101, 114, 97, 108, 32, 105, 110, 104,
  105, 98, 105, 116, 105, 111, 110, 10, 45, 45, 103, 105, 109, 112, 95, 103,
  114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 91, 48, 93, 32,
  48, 44, 48, 46, 53, 44, 48, 44, 53, 48, 44, 48, 44, 48, 10, 45,
  45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103,
  91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 109, 111, 114, 112, 104,
  111, 91, 45, 49, 93, 32, 50, 44, 36, 102, 101, 97, 116, 115, 105, 122,
  101, 44, 48, 44, 48, 44, 48, 44, 49, 44, 48, 10, 45, 116, 50, 91,
  45, 49, 93, 32, 36, 102, 101, 97, 116, 116, 114, 37, 44, 49, 48, 48,
  37, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 36, 102, 101, 97, 116,
  112, 111, 115, 10, 45, 98, 108, 117, 114, 95, 120, 121, 91, 45, 49, 93,
  32, 50, 10, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 108, 105, 103, 104, 116, 101, 110, 91, 45, 49, 44, 45, 50, 93, 32,
  36, 99, 111, 110, 116, 115, 116, 114, 10, 45, 98, 108, 117, 114, 95, 120,
  121, 91, 45, 49, 93, 32, 50, 10, 35, 100, 101, 112, 116, 104, 32, 102,
  114, 111, 109, 32, 99, 111, 108, 111, 114, 10, 45, 116, 111, 95, 114, 103,
  98, 91, 48, 93, 32, 45, 114, 103, 98, 50, 121, 99, 98, 99, 114, 91,
  48, 93, 32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48, 93,
  32, 50, 32, 45, 121, 99, 98, 99, 114, 50, 114, 103, 98, 91, 48, 93,
  10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 99,
  91, 45, 49, 93, 32, 50, 53, 37, 44, 49, 48, 48, 37, 32, 32, 45,
  97, 112, 112, 108, 121, 95, 103, 97, 109, 109, 97, 91, 45, 49, 93, 32,
  36, 99, 114, 103, 97, 10, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115,
  91, 48, 93, 32, 50, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91,
  45, 49, 93, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 49, 50, 56,
  10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 32, 45, 45,
  103, 105, 109, 112, 95, 108, 105, 110, 101, 97, 114, 95, 103, 114, 97, 100,
  105, 101, 110, 116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 48, 44, 50, 55, 48, 44, 48, 44, 49, 48, 48, 10, 45,
  115, 91, 45, 50, 93, 32, 99, 32, 45, 114, 118, 91, 45, 49, 44, 45,
  50, 93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108, 116,
  105, 112, 108, 121, 91, 45, 49, 44, 45, 50, 93, 32, 45, 116, 111, 95,
  103, 114, 97, 121, 91, 45, 49, 93, 10, 45, 97, 91, 45, 52, 44, 45,
  51, 44, 45, 50, 44, 45, 49, 93, 32, 99, 32, 45, 114, 118, 91, 45,
  49, 44, 45, 50, 93, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 100, 97, 114, 107, 101, 110, 91, 45, 49, 44, 45, 50,
  93, 32, 36, 99, 114, 109, 105, 120, 49, 10, 35, 100, 101, 112, 116, 104,
  32, 102, 114, 111, 109, 32, 103, 101, 111, 109, 101, 116, 114, 121, 10, 45,
  45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 48, 93, 32, 45, 103,
  105, 109, 112, 95, 104, 111, 117, 103, 104, 115, 107, 101, 116, 99, 104, 98,
  119, 91, 45, 49, 93, 32, 49, 48, 44, 53, 44, 49, 53, 44, 36, 116,
  114, 44, 49, 44, 49, 44, 48, 32, 99, 111, 109, 112, 108, 101, 120, 61,
  64, 123, 45, 49, 44, 97, 125, 10, 45, 105, 102, 32, 123, 36, 99, 111,
  109, 112, 108, 101, 120, 62, 61, 36, 103, 101, 111, 99, 111, 109, 112, 49,
  125, 10, 45, 100, 111, 32, 116, 114, 61, 123, 36, 116, 114, 43, 49, 48,
  125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 45, 108, 117, 109, 105,
  110, 97, 110, 99, 101, 91, 48, 93, 32, 45, 103, 105, 109, 112, 95, 104,
  111, 117, 103, 104, 115, 107, 101, 116, 99, 104, 98, 119, 91, 45, 49, 93,
  32, 49, 48, 44, 53, 44, 49, 53, 44, 36, 116, 114, 44, 49, 44, 49,
  44, 48, 32, 99, 111, 109, 112, 108, 101, 120, 61, 64, 123, 45, 49, 44,
  97, 125, 10, 45, 119, 104, 105, 108, 101, 32, 123, 123, 36, 99, 111, 109,
  112, 108, 101, 120, 62, 61, 36, 103, 101, 111, 99, 111, 109, 112, 50, 125,
  38, 38, 123, 36, 116, 114, 60, 61, 57, 48, 125, 125, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111,
  91, 45, 49, 93, 32, 51, 44, 53, 44, 48, 44, 48, 44, 48, 44, 49,
  44, 48, 32, 45, 98, 108, 117, 114, 95, 120, 121, 91, 45, 49, 93, 32,
  49, 32, 45, 103, 105, 109, 112, 95, 100, 105, 115, 116, 97, 110, 99, 101,
  91, 45, 49, 93, 32, 50, 53, 53, 44, 48, 44, 49, 44, 49, 44, 48,
  10, 99, 111, 109, 112, 108, 101, 120, 61, 64, 123, 45, 49, 44, 97, 125,
  10, 35, 100, 101, 112, 116, 104, 32, 102, 114, 111, 109, 32, 102, 111, 99,
  117, 115, 10, 45, 45, 103, 105, 109, 112, 95, 104, 105, 103, 104, 112, 97,
  115, 115, 91, 48, 93, 32, 50, 44, 50, 44, 48, 44, 48, 44, 48, 10,
  45, 116, 107, 95, 103, 105, 109, 112, 95, 114, 101, 112, 108, 97, 99, 101,
  95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 36, 102, 111, 99, 116,
  111, 108, 44, 48, 44, 49, 50, 56, 44, 49, 50, 56, 44, 49, 50, 56,
  44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 10, 45,
  103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111, 91, 45, 49, 93, 32,
  51, 44, 36, 102, 111, 99, 109, 111, 114, 112, 104, 44, 48, 44, 48, 44,
  48, 44, 49, 44, 48, 32, 32, 32, 45, 116, 111, 95, 103, 114, 97, 121,
  91, 45, 49, 93, 10, 97, 118, 61, 64, 123, 45, 49, 44, 97, 125, 32,
  118, 97, 114, 61, 64, 123, 45, 49, 44, 118, 125, 10, 45, 105, 102, 32,
  123, 123, 36, 97, 118, 60, 61, 36, 102, 111, 99, 97, 118, 116, 125, 124,
  124, 123, 123, 36, 97, 118, 62, 61, 36, 102, 111, 99, 97, 118, 116, 125,
  38, 38, 123, 36, 97, 118, 60, 61, 36, 102, 111, 99, 97, 118, 116, 50,
  125, 38, 38, 123, 36, 118, 97, 114, 60, 61, 36, 102, 111, 99, 118, 97,
  114, 116, 125, 125, 125, 10, 45, 116, 50, 91, 45, 49, 93, 32, 36, 97,
  118, 44, 50, 53, 53, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 32, 45, 98, 108, 117, 114, 95, 120, 121, 91, 45, 49, 93, 32,
  49, 48, 32, 45, 101, 108, 115, 101, 32, 45, 102, 99, 91, 45, 49, 93,
  32, 49, 50, 56, 44, 49, 50, 56, 44, 49, 50, 56, 32, 45, 101, 110,
  100, 105, 102, 10, 35, 108, 97, 116, 101, 114, 97, 108, 32, 105, 110, 104,
  105, 98, 105, 116, 105, 111, 110, 32, 101, 109, 112, 104, 97, 122, 105, 115,
  101, 114, 10, 45, 45, 103, 105, 109, 112, 95, 103, 114, 97, 100, 105, 101,
  110, 116, 95, 110, 111, 114, 109, 91, 48, 93, 32, 48, 44, 48, 46, 53,
  44, 48, 44, 53, 48, 44, 48, 44, 48, 10, 35, 99, 111, 109, 112, 111,
  115, 105, 110, 103, 32, 100, 101, 112, 116, 104, 32, 114, 101, 112, 114, 101,
  115, 101, 110, 116, 97, 116, 105, 111, 110, 115, 10, 45, 114, 109, 91, 48,
  93, 10, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95,
  111, 118, 101, 114, 108, 97, 121, 91, 45, 55, 44, 45, 54, 93, 32, 48,
  46, 53, 10, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 111, 118, 101, 114, 108, 97, 121, 91, 45, 54, 44, 45, 53, 93, 32,
  36, 102, 101, 97, 116, 105, 110, 102, 108, 10, 45, 103, 105, 109, 112, 95,
  99, 111, 109, 112, 111, 115, 101, 95, 118, 97, 108, 117, 101, 91, 45, 53,
  44, 45, 52, 93, 32, 36, 99, 114, 109, 105, 120, 50, 10, 45, 114, 118,
  91, 45, 52, 44, 45, 51, 93, 10, 45, 105, 102, 32, 123, 36, 99, 111,
  109, 112, 108, 101, 120, 33, 61, 48, 125, 32, 45, 103, 105, 109, 112, 95,
  99, 111, 109, 112, 111, 115, 101, 95, 111, 118, 101, 114, 108, 97, 121, 91,
  45, 52, 44, 45, 51, 93, 32, 36, 103, 101, 111, 115, 116, 114, 32, 45,
  101, 108, 115, 101, 32, 45, 114, 109, 91, 45, 51, 93, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 114, 118, 91, 45, 51, 44, 45, 50, 93, 10, 45,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 111, 118, 101,
  114, 108, 97, 121, 91, 45, 51, 44, 45, 50, 93, 32, 36, 102, 111, 99,
  115, 116, 114, 10, 45, 114, 118, 91, 45, 50, 44, 45, 49, 93, 10, 45,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103,
  104, 116, 101, 110, 91, 45, 49, 44, 45, 50, 93, 32, 36, 108, 97, 116,
  105, 110, 104, 105, 98, 10, 35, 102, 105, 110, 97, 108, 32, 115, 101, 103,
  109, 101, 110, 116, 97, 116, 105, 111, 110, 32, 97, 110, 100, 32, 115, 109,
  111, 111, 116, 104, 105, 110, 103, 10, 45, 98, 108, 117, 114, 95, 120, 121,
  91, 45, 49, 93, 32, 50, 32, 32, 45, 103, 105, 109, 112, 95, 109, 111,
  114, 112, 104, 111, 91, 45, 49, 93, 32, 51, 44, 50, 48, 44, 48, 44,
  48, 44, 48, 44, 49, 44, 48, 10, 45, 103, 105, 109, 112, 95, 115, 101,
  103, 109, 101, 110, 116, 95, 119, 97, 116, 101, 114, 115, 104, 101, 100, 91,
  45, 49, 93, 32, 49, 53, 44, 48, 44, 48, 32, 45, 110, 91, 45, 49,
  93, 32, 48, 44, 50, 53, 53, 10, 45, 98, 108, 117, 114, 95, 121, 91,
  45, 49, 93, 32, 50, 32, 45, 98, 108, 117, 114, 95, 120, 91, 45, 49,
  93, 32, 49, 10, 45, 114, 101, 115, 105, 122, 101, 50, 100, 120, 32, 36,
  115, 105, 122, 101, 49, 44, 50, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 68, 101, 45, 97, 110,
  97, 103, 108, 121, 112, 104, 32, 58, 32, 103, 105, 109, 112, 95, 116, 107,
  95, 100, 101, 97, 110, 97, 44, 32, 103, 105, 109, 112, 95, 116, 107, 95,
  100, 101, 97, 110, 97, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 84, 104, 105, 115, 32, 102,
  105, 108, 116, 101, 114, 32, 114, 101, 99, 111, 110, 115, 116, 114, 117, 99,
  116, 115, 32, 115, 116, 114, 101, 114, 101, 111, 115, 99, 111, 112, 105, 99,
  32, 102, 117, 108, 108, 32, 99, 111, 108, 111, 117, 114, 32, 118, 105, 101,
  119, 115, 32, 102, 114, 111, 109, 32, 97, 110, 97, 103, 108, 121, 112, 104,
  115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 117, 114, 32, 115,
  109, 111, 111, 116, 104, 105, 110, 103, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 71, 97, 109, 109, 97, 32, 101, 113, 117, 97, 108, 105,
  122, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 46,
  49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105,
  62, 84, 111, 109, 32, 75, 101, 105, 108, 60, 47, 105, 62, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 50, 47, 48, 57, 47, 50, 48, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 116, 107, 95, 100, 101, 97, 110, 97, 32, 58, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32,
  45, 116, 111, 95, 114, 103, 98, 32, 45, 45, 115, 32, 99, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49,
  44, 45, 50, 93, 32, 45, 114, 103, 98, 50, 108, 97, 98, 91, 45, 49,
  44, 45, 50, 93, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45,
  49, 44, 45, 50, 93, 32, 48, 10, 45, 114, 103, 98, 50, 108, 97, 98,
  91, 48, 93, 32, 45, 115, 91, 48, 93, 32, 99, 32, 45, 98, 108, 117,
  114, 95, 120, 91, 49, 44, 50, 93, 32, 36, 49, 10, 45, 99, 91, 45,
  49, 44, 45, 50, 93, 32, 64, 123, 48, 44, 109, 125, 44, 64, 123, 48,
  44, 77, 125, 10, 45, 97, 112, 112, 108, 121, 95, 103, 97, 109, 109, 97,
  91, 45, 49, 93, 32, 123, 123, 123, 123, 36, 50, 94, 123, 64, 123, 48,
  44, 97, 125, 47, 64, 123, 45, 49, 44, 97, 125, 125, 125, 45, 36, 50,
  125, 42, 36, 50, 125, 43, 49, 125, 10, 45, 97, 112, 112, 108, 121, 95,
  103, 97, 109, 109, 97, 91, 45, 50, 93, 32, 123, 123, 123, 123, 36, 50,
  94, 123, 64, 123, 48, 44, 97, 125, 47, 64, 123, 45, 50, 44, 97, 125,
  125, 125, 45, 36, 50, 125, 42, 36, 50, 125, 43, 49, 125, 10, 45, 45,
  103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91,
  49, 44, 50, 93, 32, 45, 114, 109, 91, 48, 93, 32, 45, 109, 118, 91,
  50, 93, 32, 48, 10, 45, 97, 91, 48, 44, 49, 44, 50, 93, 32, 99,
  32, 45, 97, 91, 49, 44, 50, 44, 51, 93, 32, 99, 32, 45, 108, 97,
  98, 50, 114, 103, 98, 91, 48, 44, 49, 93, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 68, 101,
  112, 116, 104, 32, 109, 97, 112, 32, 99, 111, 110, 115, 116, 114, 117, 99,
  116, 105, 111, 110, 32, 58, 32, 103, 105, 109, 112, 95, 116, 107, 95, 100,
  101, 112, 116, 104, 109, 97, 112, 44, 32, 103, 105, 109, 112, 95, 116, 107,
  95, 100, 101, 112, 116, 104, 109, 97, 112, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 84, 104,
  105, 115, 32, 102, 105, 108, 116, 101, 114, 32, 101, 115, 116, 105, 109, 97,
  116, 101, 115, 32, 97, 110, 100, 32, 99, 111, 110, 115, 116, 114, 117, 99,
  116, 115, 32, 97, 32, 100, 101, 112, 116, 104, 32, 109, 97, 112, 32, 102,
  111, 114, 32, 97, 32, 50, 68, 32, 105, 109, 97, 103, 101, 32, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 101, 110, 101, 32,
  115, 101, 108, 101, 99, 116, 111, 114, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 97, 117, 116, 111, 109, 97, 116, 105, 99, 32, 100, 101, 112,
  116, 104, 32, 101, 115, 116, 105, 109, 97, 116, 105, 111, 110, 34, 44, 34,
  100, 97, 121, 108, 105, 103, 104, 116, 32, 115, 99, 101, 110, 101, 34, 44,
  34, 111, 112, 116, 105, 109, 105, 122, 101, 100, 32, 108, 97, 116, 101, 114,
  97, 108, 32, 105, 110, 104, 105, 98, 105, 116, 105, 111, 110, 34, 44, 34,
  108, 105, 103, 104, 116, 32, 109, 111, 116, 105, 118, 101, 34, 44, 34, 100,
  97, 114, 107, 32, 32, 109, 111, 116, 105, 118, 101, 34, 44, 34, 108, 97,
  110, 100, 115, 99, 97, 112, 101, 34, 44, 34, 99, 101, 110, 116, 101, 114,
  32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 34, 44, 34, 99, 101,
  110, 116, 101, 114, 32, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 34,
  44, 34, 108, 101, 102, 116, 32, 32, 102, 111, 114, 101, 103, 114, 111, 117,
  110, 100, 34, 44, 34, 108, 101, 102, 116, 32, 100, 105, 97, 103, 111, 110,
  97, 108, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 34, 44, 34,
  114, 105, 103, 104, 116, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100,
  34, 44, 34, 114, 105, 103, 104, 116, 32, 100, 105, 97, 103, 111, 110, 97,
  108, 32, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 34, 44, 34,
  108, 101, 102, 116, 32, 97, 110, 100, 32, 114, 105, 103, 104, 116, 32, 102,
  111, 114, 101, 103, 114, 111, 117, 110, 100, 34, 44, 34, 108, 101, 102, 116,
  32, 97, 110, 100, 32, 114, 105, 103, 104, 116, 32, 98, 97, 99, 107, 103,
  114, 111, 117, 110, 100, 34, 44, 34, 98, 111, 116, 116, 111, 109, 32, 97,
  110, 100, 32, 116, 111, 112, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110,
  100, 34, 44, 34, 98, 111, 116, 116, 111, 109, 32, 97, 110, 100, 32, 108,
  101, 102, 116, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 34, 44,
  34, 98, 111, 116, 116, 111, 109, 32, 97, 110, 100, 32, 114, 105, 103, 104,
  116, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 34, 44, 34, 99,
  101, 110, 116, 114, 97, 108, 32, 32, 112, 101, 114, 115, 112, 101, 99, 116,
  105, 118, 101, 32, 111, 117, 116, 100, 111, 111, 114, 34, 44, 34, 99, 101,
  110, 116, 114, 97, 108, 32, 112, 101, 114, 115, 112, 101, 99, 116, 105, 118,
  101, 32, 105, 110, 100, 111, 111, 114, 34, 44, 34, 112, 111, 114, 116, 114,
  97, 105, 116, 34, 44, 34, 104, 117, 109, 97, 110, 32, 49, 34, 44, 34,
  104, 117, 109, 97, 110, 32, 32, 50, 34, 44, 34, 115, 116, 117, 100, 105,
  111, 34, 44, 34, 117, 110, 100, 101, 114, 119, 97, 116, 101, 114, 34, 44,
  34, 102, 108, 97, 116, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 68, 101, 112, 116, 104, 32, 102, 105, 101, 108, 100, 32, 99, 111, 110,
  116, 114, 111, 108, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  70, 101, 97, 116, 117, 114, 101, 32, 97, 110, 97, 108, 121, 122, 101, 114,
  32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 70, 101, 97, 116, 117, 114, 101, 32, 97, 110, 97, 108, 121,
  122, 101, 114, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 76, 111, 99, 97, 108, 32, 100, 101, 116,
  97, 105, 108, 32, 101, 110, 104, 97, 110, 99, 101, 114, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 68, 111, 102, 32, 97, 110, 97, 108, 121, 122, 101,
  114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 114, 101, 113, 117, 101,
  110, 99, 121, 32, 97, 110, 97, 108, 121, 122, 101, 114, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 80, 114, 101, 112, 114, 111, 99, 101, 115, 115, 111,
  114, 32, 114, 97, 100, 105, 117, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 80, 114, 101, 112, 114, 111, 99, 101, 115, 115, 111, 114, 32, 112, 111,
  119, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111,
  116, 104, 105, 110, 103, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60,
  105, 62, 84, 111, 109, 32, 75, 101, 105, 108, 60, 47, 105, 62, 32, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 50, 47, 48, 55, 47, 51,
  48, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 103, 105, 109, 112, 95, 116, 107, 95, 100, 101, 112, 116, 104, 109, 97,
  112, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 32, 45, 116, 111, 95, 114, 103, 98, 32, 115, 105,
  122, 101, 49, 61, 123, 119, 125, 32, 45, 114, 101, 115, 105, 122, 101, 50,
  100, 120, 32, 52, 48, 48, 44, 50, 10, 45, 105, 102, 32, 123, 123, 36,
  56, 33, 61, 48, 125, 124, 124, 123, 36, 56, 33, 61, 48, 125, 125, 32,
  45, 103, 105, 109, 112, 95, 109, 97, 112, 95, 116, 111, 110, 101, 115, 95,
  102, 97, 115, 116, 32, 123, 36, 56, 42, 52, 125, 44, 123, 36, 57, 47,
  53, 125, 44, 51, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 49, 61, 61, 48, 125, 32, 45, 45, 103, 105, 109, 112,
  95, 116, 107, 95, 97, 117, 116, 111, 100, 101, 112, 116, 104, 91, 45, 49,
  93, 10, 45, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 48, 93,
  32, 45, 103, 105, 109, 112, 95, 109, 97, 112, 95, 116, 111, 110, 101, 115,
  91, 45, 49, 93, 32, 49, 44, 48, 46, 50, 53, 44, 48, 44, 51, 48,
  44, 51, 44, 48, 10, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 32,
  45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 118, 97,
  108, 117, 101, 91, 45, 49, 44, 45, 50, 93, 32, 48, 46, 49, 53, 10,
  45, 116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108,
  95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 91, 45, 49, 93, 32,
  49, 44, 123, 36, 50, 47, 50, 48, 125, 44, 48, 44, 48, 44, 48, 44,
  48, 44, 49, 48, 48, 44, 50, 53, 54, 44, 48, 44, 48, 44, 48, 44,
  50, 44, 48, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61,
  61, 49, 125, 32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48,
  93, 32, 50, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97,
  110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 91,
  45, 49, 93, 32, 49, 44, 123, 123, 36, 50, 47, 50, 53, 125, 43, 48,
  46, 49, 125, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 48, 48, 44,
  50, 53, 54, 44, 48, 44, 49, 44, 48, 44, 50, 44, 48, 44, 48, 10,
  45, 45, 103, 105, 109, 112, 95, 108, 105, 110, 101, 97, 114, 95, 103, 114,
  97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 48, 44, 57, 48, 44, 48, 44, 123, 49, 48, 48,
  45, 123, 36, 50, 47, 49, 46, 53, 125, 125, 10, 45, 114, 118, 91, 45,
  49, 44, 45, 50, 93, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 108, 105, 103, 104, 116, 101, 110, 91, 45, 49, 44, 45,
  50, 93, 32, 123, 48, 46, 53, 43, 123, 36, 50, 47, 50, 48, 48, 125,
  125, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 50, 125, 32,
  45, 45, 115, 91, 45, 49, 93, 32, 99, 32, 45, 103, 105, 109, 112, 95,
  100, 111, 103, 91, 45, 49, 93, 32, 48, 46, 52, 44, 48, 44, 48, 44,
  48, 44, 48, 10, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 50,
  93, 32, 32, 45, 103, 105, 109, 112, 95, 100, 111, 103, 91, 45, 51, 93,
  32, 48, 46, 52, 44, 48, 44, 48, 44, 48, 44, 48, 10, 45, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 97, 108, 112, 104, 97,
  91, 45, 49, 44, 45, 50, 93, 32, 48, 46, 52, 52, 44, 48, 10, 45,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 97, 108, 112,
  104, 97, 91, 45, 49, 44, 45, 50, 93, 32, 48, 46, 52, 52, 44, 48,
  10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101,
  108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 91, 45, 49, 93,
  32, 49, 44, 123, 36, 50, 47, 50, 48, 125, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 49, 48, 48, 44, 50, 53, 54, 44, 48, 44, 48, 44, 48,
  44, 50, 44, 48, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49,
  61, 61, 51, 125, 32, 45, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101,
  91, 45, 49, 93, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 99, 104,
  97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103,
  91, 45, 49, 93, 32, 49, 44, 123, 36, 50, 47, 50, 53, 125, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 49, 48, 48, 44, 50, 53, 54, 44, 48,
  44, 48, 44, 48, 44, 50, 44, 48, 44, 48, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 61, 61, 52, 125, 32, 45, 45, 108, 117, 109, 105, 110,
  97, 110, 99, 101, 91, 45, 49, 93, 32, 45, 110, 101, 103, 97, 116, 105,
  118, 101, 91, 45, 49, 93, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95,
  99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105,
  110, 103, 91, 45, 49, 93, 32, 49, 44, 123, 36, 50, 47, 50, 53, 125,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 48, 48, 44, 50, 53, 54,
  44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 44, 48, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 61, 61, 53, 125, 10, 45, 45, 103, 105, 109,
  112, 95, 108, 105, 110, 101, 97, 114, 95, 103, 114, 97, 100, 105, 101, 110,
  116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  48, 44, 57, 48, 44, 48, 44, 123, 49, 48, 48, 45, 36, 50, 125, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 54, 125, 10, 45, 45,
  103, 105, 109, 112, 95, 114, 97, 100, 105, 97, 108, 95, 103, 114, 97, 100,
  105, 101, 110, 116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 49, 44, 36, 50, 44, 49, 48, 48, 44, 53, 48, 44, 53,
  48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 55, 125, 10,
  45, 45, 103, 105, 109, 112, 95, 114, 97, 100, 105, 97, 108, 95, 103, 114,
  97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 48, 44, 48, 44, 123, 49, 48, 48, 45, 36, 50,
  125, 44, 53, 48, 44, 53, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  49, 61, 61, 56, 125, 10, 45, 45, 103, 105, 109, 112, 95, 108, 105, 110,
  101, 97, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93,
  32, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 49, 44, 48, 44, 36,
  50, 44, 49, 48, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61,
  61, 57, 125, 10, 45, 45, 103, 105, 109, 112, 95, 108, 105, 110, 101, 97,
  114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32, 48,
  44, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 49, 44, 51, 49, 53, 44, 36,
  50, 44, 49, 48, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61,
  61, 49, 48, 125, 10, 45, 45, 103, 105, 109, 112, 95, 108, 105, 110, 101,
  97, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32,
  48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44,
  123, 49, 48, 48, 45, 36, 50, 125, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 61, 61, 49, 49, 125, 10, 45, 45, 103, 105, 109, 112, 95, 108,
  105, 110, 101, 97, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45,
  49, 93, 32, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 52,
  53, 44, 48, 44, 123, 49, 48, 48, 45, 36, 50, 125, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 61, 61, 49, 50, 125, 10, 45, 45, 103, 105,
  109, 112, 95, 108, 105, 110, 101, 97, 114, 95, 103, 114, 97, 100, 105, 101,
  110, 116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 48, 44, 48, 44, 53, 48, 44, 123, 49, 48, 48, 45, 123, 36, 50,
  47, 50, 125, 125, 10, 45, 45, 103, 105, 109, 112, 95, 108, 105, 110, 101,
  97, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32,
  48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 49, 56, 48, 44,
  53, 48, 44, 123, 49, 48, 48, 45, 123, 36, 50, 47, 50, 125, 125, 10,
  45, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103, 104, 116, 101, 110,
  91, 45, 49, 44, 45, 50, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  49, 61, 61, 49, 51, 125, 10, 45, 45, 103, 105, 109, 112, 95, 108, 105,
  110, 101, 97, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49,
  93, 32, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 49, 44, 49, 56,
  48, 44, 49, 48, 48, 44, 123, 53, 48, 43, 123, 36, 50, 47, 50, 125,
  125, 10, 45, 45, 103, 105, 109, 112, 95, 108, 105, 110, 101, 97, 114, 95,
  103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32, 48, 44, 48,
  44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 48, 44, 49, 56, 48, 44, 123, 53, 48,
  45, 123, 36, 50, 47, 50, 125, 125, 44, 48, 10, 45, 99, 111, 109, 112,
  111, 115, 101, 95, 100, 97, 114, 107, 101, 110, 91, 45, 49, 44, 45, 50,
  93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 52, 125,
  10, 45, 45, 103, 105, 109, 112, 95, 108, 105, 110, 101, 97, 114, 95, 103,
  114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32, 48, 44, 48, 44,
  48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 48, 44, 57, 48, 44, 53, 48, 44, 123, 49,
  48, 48, 45, 123, 36, 50, 47, 50, 125, 125, 10, 45, 45, 103, 105, 109,
  112, 95, 108, 105, 110, 101, 97, 114, 95, 103, 114, 97, 100, 105, 101, 110,
  116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  48, 44, 50, 55, 48, 44, 53, 48, 44, 123, 49, 48, 48, 45, 123, 36,
  50, 47, 50, 125, 125, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 108,
  105, 103, 104, 116, 101, 110, 91, 45, 49, 44, 45, 50, 93, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 53, 125, 10, 45, 45, 103,
  105, 109, 112, 95, 108, 105, 110, 101, 97, 114, 95, 103, 114, 97, 100, 105,
  101, 110, 116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 48, 44, 49, 56, 48, 44, 53, 48, 44, 123, 49, 48, 48, 45,
  123, 36, 50, 47, 50, 125, 125, 10, 45, 45, 103, 105, 109, 112, 95, 108,
  105, 110, 101, 97, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45,
  49, 93, 32, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 57,
  48, 44, 53, 48, 44, 123, 49, 48, 48, 45, 123, 36, 50, 47, 50, 125,
  125, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103, 104, 116,
  101, 110, 91, 45, 49, 44, 45, 50, 93, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 49, 61, 61, 49, 54, 125, 10, 45, 45, 103, 105, 109, 112, 95,
  108, 105, 110, 101, 97, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 91,
  45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44,
  48, 44, 53, 48, 44, 123, 49, 48, 48, 45, 123, 36, 50, 47, 50, 125,
  125, 10, 45, 45, 103, 105, 109, 112, 95, 108, 105, 110, 101, 97, 114, 95,
  103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32, 48, 44, 48,
  44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 48, 44, 57, 48, 44, 53, 48, 44, 123,
  49, 48, 48, 45, 123, 36, 50, 47, 50, 125, 125, 10, 45, 99, 111, 109,
  112, 111, 115, 101, 95, 108, 105, 103, 104, 116, 101, 110, 91, 45, 49, 44,
  45, 50, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49,
  55, 125, 10, 45, 45, 103, 105, 109, 112, 95, 108, 105, 110, 101, 97, 114,
  95, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32, 48, 44,
  48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 48, 44, 53, 48, 44, 123,
  49, 48, 48, 45, 123, 36, 50, 47, 52, 125, 125, 10, 45, 45, 103, 105,
  109, 112, 95, 108, 105, 110, 101, 97, 114, 95, 103, 114, 97, 100, 105, 101,
  110, 116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 48, 44, 49, 56, 48, 44, 53, 48, 44, 123, 49, 48, 48, 45, 123,
  36, 50, 47, 52, 125, 125, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  108, 105, 103, 104, 116, 101, 110, 91, 45, 49, 44, 45, 50, 93, 10, 45,
  45, 103, 105, 109, 112, 95, 108, 105, 110, 101, 97, 114, 95, 103, 114, 97,
  100, 105, 101, 110, 116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 48, 44, 57, 48, 44, 48, 44, 123, 49, 48, 48, 45,
  123, 36, 50, 47, 50, 125, 125, 10, 45, 99, 111, 109, 112, 111, 115, 101,
  95, 108, 105, 103, 104, 116, 101, 110, 91, 45, 49, 44, 45, 50, 93, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 56, 125, 10, 45,
  45, 103, 105, 109, 112, 95, 108, 105, 110, 101, 97, 114, 95, 103, 114, 97,
  100, 105, 101, 110, 116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 48, 44, 48, 44, 53, 48, 44, 123, 49, 48, 48, 45,
  123, 36, 50, 47, 52, 125, 125, 10, 45, 45, 103, 105, 109, 112, 95, 108,
  105, 110, 101, 97, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45,
  49, 93, 32, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 49,
  56, 48, 44, 53, 48, 44, 123, 49, 48, 48, 45, 123, 36, 50, 47, 52,
  125, 125, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103, 104,
  116, 101, 110, 91, 45, 49, 44, 45, 50, 93, 10, 45, 45, 103, 105, 109,
  112, 95, 108, 105, 110, 101, 97, 114, 95, 103, 114, 97, 100, 105, 101, 110,
  116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  48, 44, 57, 48, 44, 48, 44, 123, 49, 48, 48, 45, 123, 36, 50, 47,
  52, 125, 125, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103,
  104, 116, 101, 110, 91, 45, 49, 44, 45, 50, 93, 10, 45, 45, 103, 105,
  109, 112, 95, 108, 105, 110, 101, 97, 114, 95, 103, 114, 97, 100, 105, 101,
  110, 116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 48, 44, 50, 55, 48, 44, 53, 48, 44, 123, 49, 48, 48, 45, 123,
  36, 50, 47, 52, 125, 125, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  108, 105, 103, 104, 116, 101, 110, 91, 45, 49, 44, 45, 50, 93, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 57, 125, 32, 45, 45,
  99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 10, 45,
  116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95,
  112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 91, 45, 49, 93, 32, 49,
  44, 123, 36, 50, 47, 50, 53, 125, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 49, 48, 48, 44, 50, 53, 54, 44, 48, 44, 48, 44, 48, 44, 50,
  44, 48, 44, 48, 10, 45, 45, 103, 105, 109, 112, 95, 114, 97, 100, 105,
  97, 108, 95, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32,
  48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 49, 44, 36, 50, 44, 49,
  48, 48, 44, 53, 48, 44, 53, 48, 10, 45, 114, 118, 91, 45, 49, 44,
  45, 50, 93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108,
  116, 105, 112, 108, 121, 91, 45, 49, 44, 45, 50, 93, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 61, 61, 50, 48, 125, 10, 45, 45, 103, 105,
  109, 112, 95, 103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114,
  91, 45, 49, 93, 32, 36, 54, 44, 48, 44, 48, 44, 49, 44, 48, 44,
  48, 44, 48, 10, 45, 103, 105, 109, 112, 95, 101, 100, 103, 101, 115, 91,
  45, 49, 93, 32, 123, 36, 52, 47, 50, 125, 44, 123, 53, 48, 45, 123,
  36, 50, 47, 50, 125, 125, 44, 49, 44, 48, 10, 45, 45, 103, 105, 109,
  112, 95, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 91,
  48, 93, 32, 123, 36, 52, 47, 50, 125, 44, 123, 49, 46, 53, 45, 123,
  36, 50, 47, 54, 55, 125, 125, 44, 48, 44, 123, 49, 48, 48, 45, 36,
  50, 125, 44, 48, 44, 48, 10, 45, 114, 118, 91, 45, 49, 44, 45, 50,
  93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103, 104, 116,
  101, 110, 91, 45, 49, 44, 45, 50, 93, 32, 45, 45, 99, 104, 97, 110,
  110, 101, 108, 115, 91, 48, 93, 32, 48, 10, 45, 116, 107, 95, 103, 105,
  109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101,
  115, 115, 105, 110, 103, 91, 45, 49, 93, 32, 49, 44, 123, 123, 36, 50,
  47, 50, 53, 125, 43, 49, 125, 44, 48, 44, 48, 44, 48, 44, 48, 44,
  49, 48, 48, 44, 50, 53, 54, 44, 48, 44, 48, 44, 48, 44, 50, 44,
  48, 44, 48, 10, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 32, 45,
  99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103, 104, 116, 101, 110, 91,
  45, 49, 44, 45, 50, 93, 10, 45, 45, 103, 105, 109, 112, 95, 108, 105,
  110, 101, 97, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49,
  93, 32, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 48, 44,
  53, 48, 44, 123, 49, 48, 48, 45, 123, 36, 50, 47, 52, 125, 125, 10,
  45, 45, 103, 105, 109, 112, 95, 108, 105, 110, 101, 97, 114, 95, 103, 114,
  97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 48, 44, 49, 56, 48, 44, 53, 48, 44, 123, 49,
  48, 48, 45, 123, 36, 50, 47, 52, 125, 125, 10, 45, 99, 111, 109, 112,
  111, 115, 101, 95, 108, 105, 103, 104, 116, 101, 110, 91, 45, 49, 44, 45,
  50, 93, 10, 45, 45, 103, 105, 109, 112, 95, 108, 105, 110, 101, 97, 114,
  95, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32, 48, 44,
  48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 57, 48, 44, 48, 44, 123,
  49, 48, 48, 45, 123, 36, 50, 47, 50, 125, 125, 10, 45, 99, 111, 109,
  112, 111, 115, 101, 95, 108, 105, 103, 104, 116, 101, 110, 91, 45, 49, 44,
  45, 50, 93, 32, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 32, 45,
  99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103, 104, 116, 101, 110, 91,
  45, 49, 44, 45, 50, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49,
  61, 61, 50, 49, 125, 32, 45, 45, 103, 105, 109, 112, 95, 103, 97, 117,
  115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36,
  52, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 10, 45, 103,
  105, 109, 112, 95, 101, 100, 103, 101, 115, 91, 45, 49, 93, 32, 123, 36,
  52, 47, 50, 125, 44, 123, 53, 48, 45, 123, 36, 50, 47, 50, 125, 125,
  44, 49, 44, 48, 10, 45, 45, 103, 105, 109, 112, 95, 103, 114, 97, 100,
  105, 101, 110, 116, 95, 110, 111, 114, 109, 91, 48, 93, 32, 123, 36, 52,
  47, 50, 125, 44, 123, 49, 46, 53, 45, 123, 36, 50, 47, 54, 55, 125,
  125, 44, 48, 44, 123, 49, 48, 48, 45, 36, 50, 125, 44, 48, 44, 48,
  10, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 32, 45, 99, 111, 109,
  112, 111, 115, 101, 95, 108, 105, 103, 104, 116, 101, 110, 91, 45, 49, 44,
  45, 50, 93, 32, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48,
  93, 32, 48, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97,
  110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 91,
  45, 49, 93, 32, 49, 44, 123, 123, 36, 50, 47, 50, 53, 125, 43, 48,
  46, 53, 125, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 48, 48, 44,
  50, 53, 54, 44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 44, 48, 10,
  45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 32, 45, 99, 111, 109, 112,
  111, 115, 101, 95, 108, 105, 103, 104, 116, 101, 110, 91, 45, 49, 44, 45,
  50, 93, 10, 45, 45, 103, 105, 109, 112, 95, 108, 105, 110, 101, 97, 114,
  95, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32, 48, 44,
  48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 123, 49,
  48, 48, 45, 36, 50, 125, 10, 45, 45, 103, 105, 109, 112, 95, 108, 105,
  110, 101, 97, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49,
  93, 32, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 49, 56,
  48, 44, 48, 44, 123, 49, 48, 48, 45, 36, 50, 125, 10, 45, 99, 111,
  109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101, 110, 91, 45, 49, 44,
  45, 50, 93, 32, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 32, 45,
  99, 111, 109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101, 110, 91, 45,
  49, 44, 45, 50, 93, 10, 45, 45, 103, 105, 109, 112, 95, 108, 105, 110,
  101, 97, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93,
  32, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 57, 48, 44,
  55, 53, 44, 123, 49, 48, 48, 45, 123, 36, 50, 47, 52, 125, 125, 10,
  45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 32, 45, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103, 104, 116, 101, 110,
  91, 45, 49, 44, 45, 50, 93, 32, 48, 46, 53, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 61, 61, 50, 50, 125, 32, 45, 45, 103, 105, 109,
  112, 95, 103, 97, 117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91,
  45, 49, 93, 32, 36, 52, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48,
  44, 48, 10, 45, 103, 105, 109, 112, 95, 101, 100, 103, 101, 115, 91, 45,
  49, 93, 32, 123, 36, 52, 47, 50, 125, 44, 123, 53, 48, 45, 123, 36,
  50, 47, 50, 125, 125, 44, 49, 44, 48, 10, 45, 45, 103, 105, 109, 112,
  95, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 91, 48,
  93, 32, 123, 36, 52, 47, 50, 125, 44, 123, 49, 46, 53, 45, 123, 36,
  50, 47, 54, 55, 125, 125, 44, 48, 44, 123, 49, 48, 48, 45, 36, 50,
  125, 44, 48, 44, 48, 10, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93,
  32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103, 104, 116, 101,
  110, 91, 45, 49, 44, 45, 50, 93, 32, 45, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 91, 48, 93, 32, 48, 10, 45, 116, 107, 95, 103, 105, 109,
  112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115,
  115, 105, 110, 103, 91, 45, 49, 93, 32, 49, 44, 123, 123, 36, 50, 47,
  50, 53, 125, 43, 48, 46, 53, 125, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 49, 48, 48, 44, 50, 53, 54, 44, 48, 44, 48, 44, 48, 44, 50,
  44, 48, 44, 48, 10, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 32,
  45, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103, 104, 116, 101, 110,
  91, 45, 49, 44, 45, 50, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  49, 61, 61, 50, 51, 125, 32, 45, 45, 99, 104, 97, 110, 110, 101, 108,
  115, 91, 45, 49, 93, 32, 48, 10, 45, 116, 107, 95, 103, 105, 109, 112,
  95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115,
  105, 110, 103, 91, 45, 49, 93, 32, 49, 44, 123, 36, 50, 47, 50, 53,
  125, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 48, 48, 44, 50, 53,
  54, 44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 44, 48, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 49, 61, 61, 50, 52, 125, 32, 45, 45, 102,
  99, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 10, 45, 101, 110, 100,
  105, 102, 10, 35, 32, 97, 110, 97, 108, 121, 122, 101, 32, 105, 109, 97,
  103, 101, 32, 102, 101, 97, 116, 117, 114, 101, 115, 10, 45, 105, 102, 32,
  123, 36, 55, 33, 61, 48, 125, 10, 45, 45, 102, 99, 91, 48, 93, 32,
  49, 50, 56, 44, 49, 50, 56, 44, 49, 50, 56, 32, 45, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 48, 93, 32, 50, 32, 45, 110, 101, 103,
  97, 116, 105, 118, 101, 91, 45, 49, 93, 32, 45, 99, 91, 45, 49, 93,
  32, 48, 44, 57, 48, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 49,
  50, 56, 32, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 32, 45, 99,
  111, 109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101, 110, 91, 45, 49,
  44, 45, 50, 93, 10, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91,
  48, 93, 32, 48, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45,
  49, 93, 32, 45, 99, 91, 45, 49, 93, 32, 49, 54, 53, 44, 50, 53,
  53, 32, 45, 110, 91, 45, 49, 93, 32, 49, 50, 56, 44, 50, 53, 53,
  32, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 10, 45, 99, 111, 109,
  112, 111, 115, 101, 95, 104, 97, 114, 100, 108, 105, 103, 104, 116, 91, 45,
  49, 44, 45, 50, 93, 32, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93,
  10, 45, 105, 102, 32, 123, 36, 49, 33, 61, 49, 57, 125, 32, 45, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 97, 118, 101, 114,
  97, 103, 101, 91, 45, 49, 44, 45, 50, 93, 32, 123, 36, 55, 47, 53,
  125, 10, 45, 101, 108, 115, 101, 32, 45, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 118, 97, 108, 117, 101, 91, 45, 49, 44, 45,
  50, 93, 32, 123, 36, 55, 47, 53, 125, 44, 48, 10, 45, 116, 107, 95,
  103, 105, 109, 112, 95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111,
  99, 101, 115, 115, 105, 110, 103, 91, 45, 49, 93, 32, 49, 44, 123, 36,
  50, 47, 50, 53, 125, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 48,
  48, 44, 50, 53, 54, 44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 44,
  48, 10, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 54, 33, 61, 48, 125, 32, 45, 45, 103, 105,
  109, 112, 95, 104, 105, 103, 104, 112, 97, 115, 115, 91, 48, 93, 32, 50,
  44, 50, 44, 48, 44, 48, 44, 48, 10, 45, 116, 107, 95, 103, 105, 109,
  112, 95, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91,
  45, 49, 93, 32, 53, 44, 48, 44, 49, 50, 56, 44, 49, 50, 56, 44,
  49, 50, 56, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 50, 53,
  53, 10, 45, 103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111, 91, 45,
  49, 93, 32, 51, 44, 55, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44,
  48, 32, 32, 32, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 49, 93,
  32, 97, 118, 61, 64, 123, 45, 49, 44, 97, 125, 10, 45, 116, 50, 91,
  45, 49, 93, 32, 36, 97, 118, 44, 50, 53, 53, 32, 45, 110, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 98, 108, 117, 114, 95, 120,
  121, 91, 45, 49, 93, 32, 50, 53, 10, 45, 114, 118, 91, 45, 49, 44,
  45, 50, 93, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 111, 118, 101, 114, 108, 97, 121, 91, 45, 49, 44, 45, 50, 93,
  32, 123, 36, 54, 47, 53, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 51, 33, 61, 48, 125, 32, 45, 45, 103, 105, 109,
  112, 95, 105, 115, 111, 112, 104, 111, 116, 101, 115, 91, 48, 93, 32, 123,
  123, 36, 51, 42, 51, 125, 43, 50, 125, 44, 48, 44, 48, 44, 48, 10,
  45, 103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111, 91, 45, 49, 93,
  32, 51, 44, 123, 53, 45, 123, 36, 51, 47, 50, 125, 125, 44, 48, 44,
  48, 44, 48, 44, 49, 44, 48, 10, 45, 116, 107, 95, 103, 105, 109, 112,
  95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115,
  105, 110, 103, 91, 45, 49, 93, 32, 49, 44, 49, 44, 50, 53, 53, 44,
  48, 44, 48, 44, 48, 44, 49, 48, 48, 44, 50, 53, 54, 44, 48, 44,
  48, 44, 48, 44, 50, 44, 48, 44, 48, 10, 45, 114, 118, 91, 45, 49,
  44, 45, 50, 93, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 111, 118, 101, 114, 108, 97, 121, 91, 45, 49, 44, 45, 50,
  93, 32, 123, 36, 51, 47, 49, 48, 125, 10, 45, 45, 103, 105, 109, 112,
  95, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 91, 48,
  93, 32, 123, 36, 52, 42, 50, 125, 44, 123, 49, 46, 53, 45, 123, 48,
  46, 49, 43, 123, 36, 51, 47, 51, 46, 54, 125, 125, 125, 44, 48, 44,
  49, 48, 48, 44, 48, 44, 48, 10, 45, 114, 118, 91, 45, 49, 44, 45,
  50, 93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103, 104,
  116, 101, 110, 91, 45, 49, 44, 45, 50, 93, 32, 45, 103, 105, 109, 112,
  95, 115, 101, 103, 109, 101, 110, 116, 95, 119, 97, 116, 101, 114, 115, 104,
  101, 100, 91, 45, 49, 93, 32, 36, 51, 44, 36, 52, 44, 48, 44, 48,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 98, 108, 117, 114, 95, 121, 91,
  45, 49, 93, 32, 36, 49, 48, 32, 45, 98, 108, 117, 114, 95, 120, 91,
  45, 49, 93, 32, 123, 36, 49, 48, 47, 50, 125, 10, 45, 105, 102, 32,
  123, 36, 53, 33, 61, 48, 125, 32, 45, 45, 108, 117, 109, 105, 110, 97,
  110, 99, 101, 91, 48, 93, 32, 45, 103, 105, 109, 112, 95, 109, 97, 112,
  95, 116, 111, 110, 101, 115, 91, 45, 49, 93, 32, 49, 44, 123, 48, 46,
  50, 53, 45, 123, 36, 53, 47, 50, 48, 125, 125, 44, 48, 44, 51, 48,
  44, 51, 44, 48, 10, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 32,
  45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 111, 118,
  101, 114, 108, 97, 121, 91, 45, 49, 44, 45, 50, 93, 32, 123, 36, 53,
  47, 49, 48, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 110, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 114, 109, 91, 48, 93, 32,
  45, 114, 101, 115, 105, 122, 101, 50, 100, 120, 32, 36, 115, 105, 122, 101,
  49, 44, 50, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  35, 64, 103, 105, 109, 112, 32, 68, 101, 112, 116, 104, 32, 109, 97, 112,
  32, 114, 101, 99, 111, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 32,
  58, 32, 103, 105, 109, 112, 95, 116, 107, 95, 100, 101, 112, 116, 104, 95,
  111, 98, 116, 97, 105, 110, 44, 32, 103, 105, 109, 112, 95, 116, 107, 95,
  100, 101, 112, 116, 104, 95, 111, 98, 116, 97, 105, 110, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 84, 104, 105, 115, 32, 102, 105, 108, 116, 101,
  114, 32, 101, 115, 116, 105, 109, 97, 116, 101, 115, 32, 97, 32, 100, 101,
  112, 116, 104, 32, 109, 97, 112, 32, 102, 114, 111, 109, 32, 116, 104, 101,
  32, 108, 101, 102, 116, 32, 97, 110, 100, 32, 116, 104, 101, 32, 114, 105,
  103, 104, 116, 32, 118, 105, 101, 119, 32, 111, 102, 32, 97, 32, 115, 116,
  101, 114, 101, 111, 115, 99, 111, 112, 105, 99, 32, 105, 109, 97, 103, 101,
  46, 32, 73, 109, 97, 103, 101, 115, 32, 109, 117, 115, 116, 32, 98, 101,
  32, 97, 108, 105, 103, 110, 101, 100, 32, 99, 111, 114, 114, 101, 99, 116,
  32, 116, 111, 32, 99, 111, 109, 112, 117, 116, 101, 32, 99, 111, 114, 114,
  101, 99, 116, 32, 100, 101, 112, 116, 104, 32, 105, 110, 102, 111, 114, 109,
  97, 116, 105, 111, 110, 46, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 70, 108, 105, 112, 32, 108, 101, 102, 116, 47, 114, 105, 103, 104,
  116, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 49, 44, 48, 44, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 101, 110, 116, 101, 114,
  32, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48,
  48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 101, 110, 116, 101, 114, 32, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 84,
  111, 109, 32, 75, 101, 105, 108, 60, 47, 105, 62, 32, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 50, 47, 48, 57, 47, 48, 52, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 116, 107, 95, 100, 101, 112, 116, 104, 95, 111, 98, 116, 97,
  105, 110, 32, 58, 10, 45, 105, 102, 32, 123, 64, 35, 60, 61, 49, 125,
  32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 108, 10, 45, 116, 111, 95, 114, 103, 98, 32, 115, 105, 122, 101, 49,
  61, 123, 119, 125, 32, 115, 105, 122, 101, 50, 61, 123, 104, 125, 32, 45,
  114, 101, 115, 105, 122, 101, 50, 100, 120, 32, 52, 48, 48, 44, 50, 10,
  45, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 32, 45, 114, 118, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 51, 33, 61,
  49, 48, 48, 125, 10, 45, 103, 105, 109, 112, 95, 102, 114, 97, 109, 101,
  95, 114, 111, 117, 110, 100, 32, 49, 48, 44, 123, 49, 48, 48, 45, 36,
  51, 125, 44, 36, 52, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 48, 46, 49, 44, 51, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 100, 105, 115, 112, 108, 97, 99, 101,
  109, 101, 110, 116, 91, 48, 93, 32, 91, 49, 93, 44, 36, 50, 10, 45,
  114, 109, 91, 49, 93, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  48, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 114, 32, 36, 115,
  105, 122, 101, 49, 44, 36, 115, 105, 122, 101, 50, 32, 45, 101, 110, 100,
  108, 10, 35, 64, 103, 105, 109, 112, 32, 76, 101, 110, 116, 105, 99, 117,
  108, 97, 114, 32, 112, 114, 105, 110, 116, 32, 58, 32, 103, 105, 109, 112,
  95, 116, 107, 95, 108, 101, 110, 116, 105, 99, 117, 108, 97, 114, 44, 32,
  103, 105, 109, 112, 95, 116, 107, 95, 108, 101, 110, 116, 105, 99, 117, 108,
  97, 114, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 101, 110, 116, 105, 99,
  117, 108, 97, 114, 32, 100, 101, 110, 115, 105, 116, 121, 32, 108, 112, 105,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 48, 44, 53, 44, 50, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 101, 110, 116,
  105, 99, 117, 108, 97, 114, 32, 111, 114, 105, 101, 110, 116, 97, 116, 105,
  111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114,
  105, 110, 116, 32, 115, 105, 122, 101, 32, 119, 105, 100, 116, 104, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 53, 44, 49, 44, 53, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 105, 110, 116, 32, 115, 105,
  122, 101, 32, 117, 110, 105, 116, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 105, 110, 99, 104, 34, 44, 34, 99, 101, 110, 116, 105, 109, 101,
  116, 101, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80,
  114, 105, 110, 116, 32, 97, 100, 106, 117, 115, 116, 109, 101, 110, 116, 32,
  109, 97, 114, 107, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 117, 116, 111, 109, 97, 116,
  105, 99, 32, 117, 112, 115, 99, 97, 108, 101, 32, 102, 111, 114, 32, 111,
  112, 116, 105, 109, 117, 109, 32, 114, 101, 115, 117, 108, 116, 115, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 84, 111, 109, 32, 75, 101, 105, 108, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48, 54,
  47, 49, 48, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 108, 105, 110, 107, 40, 34, 70, 105, 108, 116, 101, 114, 32,
  101, 120, 112, 108, 97, 105, 110, 101, 100, 32, 104, 101, 114, 101, 34, 44,
  104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 116, 107, 102, 105, 108,
  116, 101, 114, 46, 98, 112, 108, 97, 99, 101, 100, 46, 110, 101, 116, 47,
  84, 75, 70, 105, 108, 116, 101, 114, 37, 50, 48, 116, 117, 116, 111, 114,
  105, 97, 108, 115, 37, 50, 48, 50, 68, 116, 111, 51, 68, 37, 50, 48,
  51, 68, 45, 97, 117, 116, 111, 109, 97, 116, 105, 99, 37, 50, 48, 115,
  116, 101, 114, 101, 111, 115, 99, 111, 112, 105, 99, 37, 50, 48, 99, 111,
  110, 118, 101, 114, 115, 105, 111, 110, 46, 104, 116, 109, 108, 41, 10, 103,
  105, 109, 112, 95, 116, 107, 95, 108, 101, 110, 116, 105, 99, 117, 108, 97,
  114, 32, 58, 10, 45, 105, 102, 32, 123, 64, 35, 60, 61, 61, 49, 125,
  32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10,
  102, 114, 97, 109, 101, 115, 61, 123, 64, 35, 125, 32, 105, 110, 100, 101,
  120, 61, 48, 32, 45, 105, 102, 32, 123, 36, 52, 61, 61, 48, 125, 32,
  108, 101, 110, 103, 116, 104, 61, 36, 51, 32, 45, 101, 108, 115, 101, 32,
  108, 101, 110, 103, 116, 104, 61, 123, 36, 51, 47, 50, 46, 53, 52, 125,
  32, 45, 101, 110, 100, 105, 102, 10, 108, 101, 110, 115, 101, 115, 61, 123,
  36, 108, 101, 110, 103, 116, 104, 42, 36, 49, 125, 32, 108, 101, 110, 115,
  101, 119, 105, 100, 116, 104, 61, 123, 119, 47, 36, 108, 101, 110, 115, 101,
  115, 125, 10, 112, 105, 99, 115, 116, 114, 105, 112, 101, 61, 123, 36, 108,
  101, 110, 115, 101, 119, 105, 100, 116, 104, 47, 36, 102, 114, 97, 109, 101,
  115, 125, 32, 120, 61, 48, 32, 121, 61, 48, 32, 101, 110, 100, 61, 123,
  36, 112, 105, 99, 115, 116, 114, 105, 112, 101, 125, 10, 115, 116, 101, 112,
  61, 123, 36, 108, 101, 110, 115, 101, 119, 105, 100, 116, 104, 45, 36, 112,
  105, 99, 115, 116, 114, 105, 112, 101, 125, 10, 35, 97, 117, 116, 111, 109,
  97, 116, 105, 99, 32, 117, 112, 115, 99, 97, 108, 101, 10, 45, 105, 102,
  32, 123, 36, 54, 61, 61, 49, 125, 10, 45, 105, 102, 32, 123, 36, 112,
  105, 99, 115, 116, 114, 105, 112, 101, 33, 61, 123, 105, 110, 116, 40, 36,
  112, 105, 99, 115, 116, 114, 105, 112, 101, 41, 125, 125, 32, 115, 99, 97,
  108, 101, 61, 123, 123, 105, 110, 116, 40, 36, 112, 105, 99, 115, 116, 114,
  105, 112, 101, 41, 43, 49, 125, 47, 36, 112, 105, 99, 115, 116, 114, 105,
  112, 101, 125, 10, 45, 114, 32, 123, 119, 42, 36, 115, 99, 97, 108, 101,
  125, 44, 123, 104, 42, 36, 115, 99, 97, 108, 101, 125, 32, 108, 101, 110,
  115, 101, 119, 105, 100, 116, 104, 61, 123, 119, 47, 36, 108, 101, 110, 115,
  101, 115, 125, 32, 112, 105, 99, 115, 116, 114, 105, 112, 101, 61, 123, 36,
  108, 101, 110, 115, 101, 119, 105, 100, 116, 104, 47, 36, 102, 114, 97, 109,
  101, 115, 125, 10, 101, 110, 100, 61, 123, 36, 112, 105, 99, 115, 116, 114,
  105, 112, 101, 125, 32, 115, 116, 101, 112, 61, 123, 36, 108, 101, 110, 115,
  101, 119, 105, 100, 116, 104, 45, 36, 112, 105, 99, 115, 116, 114, 105, 112,
  101, 125, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 116, 111, 95, 114, 103, 98, 32, 45, 45, 102, 99, 91, 45, 49,
  93, 32, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 108, 101, 110, 115, 101, 115, 10, 45, 105,
  102, 32, 123, 36, 50, 61, 61, 48, 125, 10, 45, 102, 105, 108, 108, 91,
  45, 49, 93, 32, 105, 102, 40, 120, 62, 61, 36, 101, 110, 100, 44, 48,
  44, 105, 41, 32, 120, 61, 123, 36, 120, 43, 36, 115, 116, 101, 112, 125,
  32, 101, 110, 100, 61, 123, 36, 101, 110, 100, 43, 36, 115, 116, 101, 112,
  125, 10, 45, 102, 105, 108, 108, 91, 45, 49, 93, 32, 105, 102, 40, 120,
  62, 61, 36, 101, 110, 100, 44, 50, 53, 53, 44, 105, 41, 32, 120, 61,
  123, 36, 120, 43, 36, 112, 105, 99, 115, 116, 114, 105, 112, 101, 125, 32,
  101, 110, 100, 61, 123, 36, 101, 110, 100, 43, 36, 112, 105, 99, 115, 116,
  114, 105, 112, 101, 125, 10, 45, 101, 108, 115, 101, 10, 45, 102, 105, 108,
  108, 91, 45, 49, 93, 32, 105, 102, 40, 121, 62, 61, 36, 101, 110, 100,
  44, 48, 44, 105, 41, 32, 121, 61, 123, 36, 121, 43, 36, 115, 116, 101,
  112, 125, 32, 101, 110, 100, 61, 123, 36, 101, 110, 100, 43, 36, 115, 116,
  101, 112, 125, 10, 45, 102, 105, 108, 108, 91, 45, 49, 93, 32, 105, 102,
  40, 121, 62, 61, 36, 101, 110, 100, 44, 50, 53, 53, 44, 105, 41, 32,
  121, 61, 123, 36, 121, 43, 36, 112, 105, 99, 115, 116, 114, 105, 112, 101,
  125, 32, 101, 110, 100, 61, 123, 36, 101, 110, 100, 43, 36, 112, 105, 99,
  115, 116, 114, 105, 112, 101, 125, 10, 45, 101, 110, 100, 105, 102, 32, 45,
  100, 111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 102,
  114, 97, 109, 101, 115, 45, 49, 125, 32, 45, 45, 116, 111, 95, 103, 114,
  97, 121, 91, 45, 49, 93, 32, 45, 116, 50, 91, 45, 49, 93, 32, 49,
  50, 56, 44, 50, 53, 54, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 10, 45, 105, 102, 32, 123, 36, 50, 61, 61, 48, 125, 32,
  45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 123, 123, 36, 112, 105,
  99, 115, 116, 114, 105, 112, 101, 125, 42, 123, 36, 102, 114, 97, 109, 101,
  115, 45, 123, 36, 105, 110, 100, 101, 120, 43, 49, 125, 125, 125, 10, 45,
  101, 108, 115, 101, 32, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32,
  48, 44, 123, 123, 36, 112, 105, 99, 115, 116, 114, 105, 112, 101, 125, 42,
  123, 36, 102, 114, 97, 109, 101, 115, 45, 123, 36, 105, 110, 100, 101, 120,
  43, 49, 125, 125, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 115, 91,
  36, 105, 110, 100, 101, 120, 93, 32, 99, 32, 45, 97, 91, 36, 105, 110,
  100, 101, 120, 44, 123, 36, 105, 110, 100, 101, 120, 43, 49, 125, 44, 123,
  36, 105, 110, 100, 101, 120, 43, 50, 125, 44, 45, 49, 93, 32, 99, 10,
  105, 110, 100, 101, 120, 61, 123, 36, 105, 110, 100, 101, 120, 43, 49, 125,
  32, 45, 100, 111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  36, 102, 114, 97, 109, 101, 115, 45, 49, 125, 32, 45, 114, 118, 91, 48,
  44, 45, 50, 93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 114, 103,
  98, 97, 91, 48, 44, 45, 50, 93, 32, 45, 114, 118, 91, 48, 44, 45,
  50, 93, 32, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 53,
  61, 61, 49, 125, 32, 45, 116, 111, 95, 114, 103, 98, 97, 91, 48, 93,
  10, 45, 105, 102, 32, 123, 36, 50, 61, 61, 48, 125, 32, 45, 115, 104,
  105, 102, 116, 91, 48, 93, 32, 48, 44, 53, 32, 45, 101, 108, 115, 101,
  32, 45, 115, 104, 105, 102, 116, 91, 48, 93, 32, 53, 44, 48, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91,
  45, 49, 93, 32, 45, 114, 118, 32, 45, 99, 111, 109, 112, 111, 115, 101,
  95, 114, 103, 98, 97, 32, 45, 101, 108, 115, 101, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103, 105, 109,
  112, 32, 83, 105, 110, 103, 108, 101, 32, 105, 109, 97, 103, 101, 32, 115,
  116, 101, 114, 101, 111, 103, 114, 97, 109, 32, 58, 32, 103, 105, 109, 112,
  95, 116, 107, 95, 115, 116, 101, 114, 101, 111, 103, 114, 97, 109, 44, 32,
  103, 105, 109, 112, 95, 116, 107, 95, 115, 116, 101, 114, 101, 111, 103, 114,
  97, 109, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 68, 101, 118, 105, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 53, 48, 44, 48, 44, 50, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 80, 97, 116, 116, 101, 114, 110, 32, 103,
  101, 110, 101, 114, 97, 116, 111, 114, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 80, 97, 116, 116, 101, 114, 110, 32, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 32, 49, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 80, 97, 116, 116, 101, 114, 110, 32, 118, 97, 114, 105, 97, 116,
  105, 111, 110, 32, 50, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48,
  44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  80, 97, 116, 116, 101, 114, 110, 32, 118, 97, 114, 105, 97, 116, 105, 111,
  110, 32, 51, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 105, 108, 101,
  115, 32, 61, 32, 105, 110, 116, 40, 52, 48, 44, 49, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111,
  114, 32, 49, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44,
  50, 53, 53, 44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 108, 111, 114, 32, 50, 32, 61, 32, 99, 111, 108, 111, 114, 40,
  50, 53, 53, 44, 48, 44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 111, 108, 111, 114, 32, 51, 32, 61, 32, 99, 111, 108, 111,
  114, 40, 48, 44, 50, 53, 53, 44, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 52, 32, 61, 32, 99, 111,
  108, 111, 114, 40, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 115, 116, 114, 101,
  110, 103, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53,
  44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 84, 111, 109,
  32, 75, 101, 105, 108, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 50, 47, 48, 50, 47, 50, 53, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 73, 110, 112, 117, 116, 32, 105, 109, 97, 103, 101, 32, 115, 104,
  111, 117, 108, 100, 32, 98, 101, 32, 97, 32, 60, 98, 62, 100, 101, 112,
  116, 104, 32, 109, 97, 112, 60, 47, 98, 62, 32, 119, 104, 105, 99, 104,
  32, 105, 115, 32, 116, 117, 114, 110, 101, 100, 32, 105, 110, 116, 111, 32,
  97, 110, 32, 97, 117, 116, 111, 115, 116, 101, 114, 101, 111, 103, 114, 97,
  109, 44, 32, 97, 108, 115, 111, 32, 107, 110, 111, 119, 110, 32, 97, 115,
  32, 109, 97, 103, 105, 99, 32, 101, 121, 101, 32, 105, 109, 97, 103, 101,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 108, 105, 110, 107, 40, 34, 70, 105, 108, 116, 101, 114, 32,
  101, 120, 112, 108, 97, 105, 110, 101, 100, 32, 104, 101, 114, 101, 34, 44,
  104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 116, 107, 102, 105, 108,
  116, 101, 114, 46, 98, 112, 108, 97, 99, 101, 100, 46, 110, 101, 116, 47,
  84, 75, 70, 105, 108, 116, 101, 114, 37, 50, 48, 102, 105, 108, 116, 101,
  114, 46, 104, 116, 109, 108, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 66, 97,
  99, 107, 103, 114, 111, 117, 110, 100, 32, 101, 120, 112, 108, 97, 105, 110,
  101, 100, 32, 104, 101, 114, 101, 34, 44, 34, 104, 116, 116, 112, 58, 47,
  47, 101, 110, 46, 119, 105, 107, 105, 112, 101, 100, 105, 97, 46, 111, 114,
  103, 47, 119, 105, 107, 105, 47, 65, 117, 116, 111, 115, 116, 101, 114, 101,
  111, 103, 114, 97, 109, 34, 41, 41, 10, 103, 105, 109, 112, 95, 116, 107,
  95, 115, 116, 101, 114, 101, 111, 103, 114, 97, 109, 32, 58, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32,
  45, 116, 111, 95, 103, 114, 97, 121, 32, 45, 45, 102, 99, 91, 45, 49,
  93, 32, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 103,
  105, 109, 112, 95, 112, 108, 97, 115, 109, 97, 91, 45, 49, 93, 32, 36,
  50, 44, 36, 51, 44, 56, 44, 48, 44, 48, 10, 45, 103, 105, 109, 112,
  95, 97, 114, 114, 97, 121, 91, 45, 49, 93, 32, 49, 48, 44, 49, 48,
  44, 48, 44, 48, 44, 48, 44, 48, 10, 45, 103, 105, 109, 112, 95, 97,
  114, 114, 97, 121, 95, 102, 97, 100, 101, 91, 45, 49, 93, 32, 123, 36,
  53, 47, 49, 48, 125, 44, 123, 36, 53, 47, 49, 48, 125, 44, 48, 44,
  48, 44, 56, 48, 44, 57, 48, 44, 51, 44, 48, 10, 45, 114, 91, 45,
  49, 93, 32, 91, 48, 93, 44, 91, 48, 93, 10, 45, 103, 105, 109, 112,
  95, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 123, 119, 47, 51, 48,
  125, 44, 48, 44, 51, 44, 48, 44, 48, 10, 45, 45, 103, 105, 109, 112,
  95, 114, 111, 114, 115, 99, 104, 97, 99, 104, 91, 45, 49, 93, 32, 36,
  52, 44, 49, 44, 48, 32, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93,
  32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 109,
  117, 108, 116, 105, 112, 108, 121, 91, 45, 49, 44, 45, 50, 93, 32, 48,
  46, 53, 10, 45, 45, 103, 105, 109, 112, 95, 99, 111, 114, 110, 101, 114,
  95, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32, 36, 54,
  44, 36, 55, 44, 36, 56, 44, 50, 53, 53, 44, 36, 57, 44, 36, 49,
  48, 44, 36, 49, 49, 44, 50, 53, 53, 44, 36, 49, 50, 44, 36, 49,
  51, 44, 36, 49, 52, 44, 50, 53, 53, 44, 36, 49, 53, 44, 36, 49,
  54, 44, 36, 49, 55, 44, 50, 53, 53, 10, 45, 114, 118, 91, 45, 49,
  44, 45, 50, 93, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 104, 97, 114, 100, 108, 105, 103, 104, 116, 91, 45, 49, 44,
  45, 50, 93, 32, 36, 49, 56, 10, 45, 114, 118, 91, 45, 49, 44, 45,
  50, 93, 10, 45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 49, 44, 50, 10, 45, 115, 91, 45, 49, 93, 32, 99,
  32, 45, 102, 91, 45, 49, 93, 32, 48, 32, 45, 110, 91, 45, 50, 93,
  32, 48, 44, 36, 49, 32, 45, 97, 91, 45, 49, 44, 45, 50, 93, 32,
  99, 10, 45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  44, 49, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 116, 107, 95, 115,
  116, 101, 114, 101, 111, 103, 114, 97, 109, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 116,
  107, 95, 115, 116, 101, 114, 101, 111, 103, 114, 97, 109, 32, 36, 123, 49,
  45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112,
  32, 83, 116, 101, 114, 101, 111, 115, 99, 111, 112, 105, 99, 32, 105, 109,
  97, 103, 101, 32, 97, 108, 105, 103, 110, 109, 101, 110, 116, 32, 58, 32,
  103, 105, 109, 112, 95, 116, 107, 95, 115, 116, 101, 114, 101, 111, 105, 109,
  97, 103, 101, 44, 32, 103, 105, 109, 112, 95, 116, 107, 95, 115, 116, 101,
  114, 101, 111, 105, 109, 97, 103, 101, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  77, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65,
  110, 97, 103, 108, 121, 112, 104, 32, 114, 101, 100, 47, 99, 121, 97, 110,
  34, 44, 34, 65, 110, 97, 103, 108, 121, 112, 104, 32, 114, 101, 100, 47,
  99, 121, 97, 110, 32, 111, 112, 116, 105, 109, 105, 122, 101, 100, 34, 44,
  34, 65, 110, 97, 103, 108, 121, 112, 104, 32, 98, 108, 117, 101, 47, 121,
  101, 108, 108, 111, 119, 34, 44, 34, 65, 110, 97, 103, 108, 121, 112, 104,
  32, 98, 108, 117, 101, 47, 121, 101, 108, 108, 111, 119, 32, 111, 112, 116,
  105, 109, 105, 122, 101, 100, 34, 44, 34, 65, 110, 97, 103, 108, 121, 112,
  104, 32, 103, 114, 101, 101, 110, 47, 109, 97, 103, 101, 110, 116, 97, 34,
  44, 34, 65, 110, 97, 103, 108, 121, 112, 103, 104, 32, 103, 114, 101, 101,
  110, 47, 109, 97, 103, 101, 110, 116, 97, 32, 111, 112, 116, 105, 109, 105,
  122, 101, 100, 34, 44, 34, 70, 117, 108, 108, 32, 115, 105, 100, 101, 32,
  98, 121, 32, 115, 105, 100, 101, 32, 107, 101, 101, 112, 32, 119, 105, 100,
  116, 104, 34, 44, 34, 70, 117, 108, 108, 32, 115, 105, 100, 101, 32, 98,
  121, 32, 115, 105, 100, 101, 32, 107, 101, 101, 112, 32, 117, 110, 99, 111,
  109, 112, 114, 101, 115, 115, 101, 100, 34, 44, 34, 70, 117, 108, 108, 32,
  98, 111, 116, 116, 111, 109, 47, 116, 111, 112, 34, 44, 34, 72, 97, 108,
  102, 32, 115, 105, 100, 101, 32, 32, 98, 121, 32, 115, 105, 100, 101, 34,
  44, 34, 72, 97, 108, 102, 32, 98, 111, 116, 116, 111, 109, 47, 116, 111,
  112, 34, 44, 34, 73, 110, 116, 101, 114, 108, 97, 99, 101, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 73, 110, 116, 101, 114,
  108, 97, 99, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  70, 117, 108, 108, 32, 72, 68, 32, 102, 114, 97, 109, 101, 32, 112, 97,
  99, 107, 105, 110, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 70, 108, 105, 112, 32, 108, 101, 102, 116, 32, 47, 32, 114, 105, 103,
  104, 116, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 71, 97, 109, 109, 97, 32, 99, 111, 109, 112,
  101, 110, 115, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 65, 110, 116, 105, 45, 103, 104, 111, 115, 116, 105, 110, 103, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 98,
  111, 111, 115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48,
  44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 97,
  103, 108, 121, 112, 104, 32, 103, 108, 97, 115, 115, 101, 115, 32, 97, 100,
  106, 117, 115, 116, 109, 101, 110, 116, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 32, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 84, 104, 105, 115, 32, 102, 105, 108, 116, 101,
  114, 32, 110, 101, 101, 100, 115, 32, 116, 119, 111, 32, 97, 108, 105, 103,
  110, 101, 100, 32, 105, 110, 112, 117, 116, 32, 105, 109, 97, 103, 101, 115,
  46, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 84,
  111, 109, 32, 75, 101, 105, 108, 60, 47, 105, 62, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 50, 47, 48, 56, 47, 48, 52, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112,
  95, 116, 107, 95, 115, 116, 101, 114, 101, 111, 105, 109, 97, 103, 101, 32,
  58, 10, 45, 105, 102, 32, 123, 64, 35, 60, 61, 49, 125, 32, 45, 114,
  101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 108, 111,
  99, 97, 108, 32, 45, 116, 111, 95, 114, 103, 98, 10, 45, 105, 102, 32,
  123, 36, 52, 33, 61, 48, 125, 32, 45, 116, 107, 95, 103, 105, 109, 112,
  95, 99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115,
  105, 110, 103, 32, 49, 44, 49, 44, 36, 52, 44, 48, 44, 48, 44, 48,
  44, 49, 48, 48, 44, 50, 53, 54, 44, 48, 44, 48, 44, 49, 44, 49,
  48, 44, 55, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 123, 36, 49, 61, 61, 48, 125, 124, 124, 123, 36, 49, 61, 61,
  49, 125, 124, 124, 123, 36, 49, 61, 61, 50, 125, 124, 124, 123, 36, 49,
  61, 61, 51, 125, 124, 124, 123, 36, 49, 61, 61, 52, 125, 124, 124, 123,
  36, 49, 61, 61, 53, 125, 125, 32, 45, 97, 112, 112, 108, 121, 95, 103,
  97, 109, 109, 97, 32, 36, 51, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 49, 61, 61, 48, 125, 32, 45, 105, 102, 32, 123,
  36, 50, 61, 61, 48, 125, 32, 45, 114, 118, 91, 45, 49, 44, 45, 50,
  93, 32, 45, 101, 110, 100, 105, 102, 32, 45, 115, 32, 99, 10, 45, 114,
  109, 91, 45, 51, 44, 45, 52, 44, 45, 53, 93, 32, 45, 97, 91, 45,
  49, 44, 45, 50, 44, 45, 51, 93, 32, 99, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 61, 61, 49, 125, 32, 45, 105, 102, 32, 123, 36, 50,
  61, 61, 49, 125, 32, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 97, 112, 112, 108, 121, 95, 103, 97,
  109, 109, 97, 91, 45, 49, 93, 32, 49, 46, 49, 53, 32, 45, 97, 112,
  112, 108, 121, 95, 103, 97, 109, 109, 97, 91, 45, 50, 93, 32, 49, 46,
  48, 32, 45, 115, 32, 99, 10, 114, 108, 114, 61, 52, 53, 54, 32, 114,
  108, 103, 61, 53, 48, 48, 32, 114, 108, 98, 61, 49, 55, 54, 32, 114,
  114, 114, 61, 123, 45, 52, 51, 125, 32, 114, 114, 103, 61, 123, 45, 56,
  56, 125, 32, 114, 114, 98, 61, 123, 45, 50, 125, 10, 103, 108, 114, 61,
  123, 45, 52, 48, 125, 32, 103, 108, 103, 61, 123, 45, 51, 56, 125, 32,
  103, 108, 98, 61, 123, 45, 49, 54, 125, 32, 103, 114, 114, 61, 51, 55,
  56, 32, 103, 114, 103, 61, 55, 51, 52, 32, 103, 114, 98, 61, 123, 45,
  49, 56, 125, 10, 98, 108, 114, 61, 123, 45, 49, 53, 125, 32, 98, 108,
  103, 61, 123, 45, 50, 49, 125, 32, 98, 108, 98, 61, 123, 45, 53, 125,
  32, 98, 114, 114, 61, 123, 45, 55, 50, 125, 32, 98, 114, 103, 61, 123,
  45, 49, 49, 51, 125, 32, 98, 114, 98, 61, 49, 50, 50, 54, 10, 45,
  45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103,
  91, 48, 45, 53, 93, 10, 45, 42, 91, 45, 51, 93, 32, 36, 114, 108,
  114, 32, 45, 42, 91, 45, 50, 93, 32, 36, 114, 108, 103, 32, 45, 42,
  91, 45, 49, 93, 32, 36, 114, 108, 98, 32, 45, 42, 91, 45, 54, 93,
  32, 36, 114, 114, 114, 32, 45, 42, 91, 45, 53, 93, 32, 36, 114, 114,
  103, 32, 45, 42, 91, 45, 52, 93, 32, 36, 114, 114, 98, 10, 45, 43,
  91, 45, 54, 93, 32, 91, 45, 53, 93, 32, 45, 43, 91, 45, 54, 93,
  32, 91, 45, 52, 93, 32, 45, 43, 91, 45, 54, 93, 32, 91, 45, 51,
  93, 32, 45, 43, 91, 45, 54, 93, 32, 91, 45, 50, 93, 32, 45, 43,
  91, 45, 54, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49,
  45, 45, 53, 93, 10, 45, 47, 91, 45, 49, 93, 32, 49, 48, 48, 48,
  32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 116,
  111, 95, 103, 114, 97, 121, 91, 45, 49, 93, 10, 45, 45, 103, 105, 109,
  112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 48, 45, 53,
  93, 10, 45, 42, 91, 45, 51, 93, 32, 36, 103, 108, 114, 32, 45, 42,
  91, 45, 50, 93, 32, 36, 103, 108, 103, 32, 45, 42, 91, 45, 49, 93,
  32, 36, 103, 108, 98, 32, 45, 42, 91, 45, 54, 93, 32, 36, 103, 114,
  114, 32, 45, 42, 91, 45, 53, 93, 32, 36, 103, 114, 103, 32, 45, 42,
  91, 45, 52, 93, 32, 36, 103, 114, 98, 10, 45, 43, 91, 45, 54, 93,
  32, 91, 45, 53, 93, 32, 45, 43, 91, 45, 54, 93, 32, 91, 45, 52,
  93, 32, 45, 43, 91, 45, 54, 93, 32, 91, 45, 51, 93, 32, 45, 43,
  91, 45, 54, 93, 32, 91, 45, 50, 93, 32, 45, 43, 91, 45, 54, 93,
  32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 45, 45, 53, 93,
  10, 45, 47, 91, 45, 49, 93, 32, 49, 48, 48, 48, 32, 45, 110, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 116, 111, 95, 103, 114,
  97, 121, 91, 45, 49, 93, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111,
  95, 110, 111, 116, 104, 105, 110, 103, 91, 48, 45, 53, 93, 10, 45, 42,
  91, 45, 51, 93, 32, 36, 98, 108, 114, 32, 45, 42, 91, 45, 50, 93,
  32, 36, 98, 108, 103, 32, 45, 42, 91, 45, 49, 93, 32, 36, 98, 108,
  98, 32, 45, 42, 91, 45, 54, 93, 32, 36, 98, 114, 114, 32, 45, 42,
  91, 45, 53, 93, 32, 36, 98, 114, 103, 32, 45, 42, 91, 45, 52, 93,
  32, 36, 98, 114, 98, 10, 45, 43, 91, 45, 54, 93, 32, 91, 45, 53,
  93, 32, 45, 43, 91, 45, 54, 93, 32, 91, 45, 52, 93, 32, 45, 43,
  91, 45, 54, 93, 32, 91, 45, 51, 93, 32, 45, 43, 91, 45, 54, 93,
  32, 91, 45, 50, 93, 32, 45, 43, 91, 45, 54, 93, 32, 91, 45, 49,
  93, 32, 45, 114, 109, 91, 45, 49, 45, 45, 53, 93, 10, 45, 47, 91,
  45, 49, 93, 32, 49, 48, 48, 48, 32, 45, 110, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 32, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45,
  49, 93, 10, 45, 107, 91, 45, 49, 45, 45, 51, 93, 32, 45, 97, 91,
  45, 49, 44, 45, 50, 44, 45, 51, 93, 32, 99, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 61, 61, 50, 125, 32, 45, 105, 102, 32, 123, 36,
  50, 61, 61, 48, 125, 32, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93,
  32, 45, 101, 110, 100, 105, 102, 32, 45, 115, 32, 99, 10, 45, 114, 109,
  91, 45, 54, 44, 45, 53, 44, 45, 49, 93, 32, 45, 109, 118, 91, 48,
  93, 32, 51, 32, 32, 45, 97, 91, 45, 49, 44, 45, 50, 44, 45, 51,
  93, 32, 99, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 51,
  125, 32, 45, 105, 102, 32, 123, 36, 50, 61, 61, 49, 125, 32, 45, 114,
  118, 91, 45, 49, 44, 45, 50, 93, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 97, 112, 112, 108, 121, 95, 103, 97, 109, 109, 97, 91, 45, 49, 93,
  32, 48, 46, 57, 32, 45, 97, 112, 112, 108, 121, 95, 103, 97, 109, 109,
  97, 91, 45, 50, 93, 32, 49, 46, 50, 53, 32, 45, 115, 32, 99, 10,
  114, 114, 114, 61, 49, 48, 54, 50, 32, 114, 114, 103, 61, 123, 45, 50,
  48, 53, 125, 32, 114, 114, 98, 61, 50, 57, 57, 32, 114, 108, 114, 61,
  123, 45, 49, 54, 125, 32, 114, 108, 103, 61, 123, 45, 49, 50, 51, 125,
  32, 114, 108, 98, 61, 123, 45, 49, 55, 125, 10, 103, 114, 114, 61, 123,
  45, 50, 54, 125, 32, 103, 114, 103, 61, 57, 48, 56, 32, 103, 114, 98,
  61, 54, 56, 32, 103, 108, 114, 61, 54, 32, 103, 108, 103, 61, 54, 50,
  32, 103, 108, 98, 61, 123, 45, 49, 55, 125, 10, 98, 114, 114, 61, 123,
  45, 51, 56, 125, 32, 98, 114, 103, 61, 123, 45, 49, 55, 51, 125, 32,
  98, 114, 98, 61, 50, 50, 32, 98, 108, 114, 61, 57, 52, 32, 98, 108,
  103, 61, 49, 56, 53, 32, 98, 108, 98, 61, 57, 49, 49, 10, 45, 45,
  103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91,
  48, 45, 53, 93, 10, 45, 42, 91, 45, 51, 93, 32, 36, 114, 108, 114,
  32, 45, 42, 91, 45, 50, 93, 32, 36, 114, 108, 103, 32, 45, 42, 91,
  45, 49, 93, 32, 36, 114, 108, 98, 32, 45, 42, 91, 45, 54, 93, 32,
  36, 114, 114, 114, 32, 45, 42, 91, 45, 53, 93, 32, 36, 114, 114, 103,
  32, 45, 42, 91, 45, 52, 93, 32, 36, 114, 114, 98, 10, 45, 43, 91,
  45, 54, 93, 32, 91, 45, 53, 93, 32, 45, 43, 91, 45, 54, 93, 32,
  91, 45, 52, 93, 32, 45, 43, 91, 45, 54, 93, 32, 91, 45, 51, 93,
  32, 45, 43, 91, 45, 54, 93, 32, 91, 45, 50, 93, 32, 45, 43, 91,
  45, 54, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 45,
  45, 53, 93, 10, 45, 47, 91, 45, 49, 93, 32, 49, 48, 48, 48, 32,
  45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 116, 111,
  95, 103, 114, 97, 121, 91, 45, 49, 93, 10, 45, 45, 103, 105, 109, 112,
  95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 48, 45, 53, 93,
  10, 45, 42, 91, 45, 51, 93, 32, 36, 103, 108, 114, 32, 45, 42, 91,
  45, 50, 93, 32, 36, 103, 108, 103, 32, 45, 42, 91, 45, 49, 93, 32,
  36, 103, 108, 98, 32, 45, 42, 91, 45, 54, 93, 32, 36, 103, 114, 114,
  32, 45, 42, 91, 45, 53, 93, 32, 36, 103, 114, 103, 32, 45, 42, 91,
  45, 52, 93, 32, 36, 103, 114, 98, 10, 45, 43, 91, 45, 54, 93, 32,
  91, 45, 53, 93, 32, 45, 43, 91, 45, 54, 93, 32, 91, 45, 52, 93,
  32, 45, 43, 91, 45, 54, 93, 32, 91, 45, 51, 93, 32, 45, 43, 91,
  45, 54, 93, 32, 91, 45, 50, 93, 32, 45, 43, 91, 45, 54, 93, 32,
  91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 45, 45, 53, 93, 10,
  45, 47, 91, 45, 49, 93, 32, 49, 48, 48, 48, 32, 45, 110, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 116, 111, 95, 103, 114, 97,
  121, 91, 45, 49, 93, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95,
  110, 111, 116, 104, 105, 110, 103, 91, 48, 45, 53, 93, 10, 45, 42, 91,
  45, 51, 93, 32, 36, 98, 108, 114, 32, 45, 42, 91, 45, 50, 93, 32,
  36, 98, 108, 103, 32, 45, 42, 91, 45, 49, 93, 32, 36, 98, 108, 98,
  32, 45, 42, 91, 45, 54, 93, 32, 36, 98, 114, 114, 32, 45, 42, 91,
  45, 53, 93, 32, 36, 98, 114, 103, 32, 45, 42, 91, 45, 52, 93, 32,
  36, 98, 114, 98, 10, 45, 43, 91, 45, 54, 93, 32, 91, 45, 53, 93,
  32, 45, 43, 91, 45, 54, 93, 32, 91, 45, 52, 93, 32, 45, 43, 91,
  45, 54, 93, 32, 91, 45, 51, 93, 32, 45, 43, 91, 45, 54, 93, 32,
  91, 45, 50, 93, 32, 45, 43, 91, 45, 54, 93, 32, 91, 45, 49, 93,
  32, 45, 114, 109, 91, 45, 49, 45, 45, 53, 93, 10, 45, 47, 91, 45,
  49, 93, 32, 49, 48, 48, 48, 32, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 32, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 49,
  93, 10, 45, 107, 91, 45, 49, 45, 45, 51, 93, 32, 45, 97, 91, 45,
  51, 44, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 61, 61, 52, 125, 32, 45, 105, 102, 32, 123, 36, 50,
  61, 61, 48, 125, 32, 45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 32,
  45, 101, 110, 100, 105, 102, 32, 32, 45, 115, 32, 99, 10, 45, 114, 109,
  91, 45, 49, 44, 45, 51, 44, 45, 53, 93, 32, 45, 109, 118, 91, 45,
  49, 93, 32, 45, 50, 32, 45, 97, 91, 45, 51, 44, 45, 50, 44, 45,
  49, 93, 32, 99, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61,
  53, 125, 32, 45, 105, 102, 32, 123, 36, 50, 61, 61, 49, 125, 32, 45,
  114, 118, 91, 45, 49, 44, 45, 50, 93, 32, 45, 101, 110, 100, 105, 102,
  32, 32, 45, 115, 32, 99, 10, 45, 97, 112, 112, 108, 121, 95, 103, 97,
  109, 109, 97, 91, 45, 49, 93, 32, 49, 32, 45, 97, 112, 112, 108, 121,
  95, 103, 97, 109, 109, 97, 91, 45, 50, 93, 32, 49, 46, 49, 53, 32,
  45, 115, 32, 99, 10, 114, 114, 114, 61, 123, 45, 54, 50, 125, 32, 114,
  114, 103, 61, 123, 45, 49, 53, 56, 125, 32, 114, 114, 98, 61, 123, 45,
  51, 57, 125, 32, 114, 108, 114, 61, 123, 53, 50, 57, 125, 32, 114, 108,
  103, 61, 123, 55, 48, 53, 125, 32, 114, 108, 98, 61, 123, 50, 52, 125,
  10, 103, 114, 114, 61, 123, 50, 56, 52, 125, 32, 103, 114, 103, 61, 54,
  54, 56, 32, 103, 114, 98, 61, 49, 52, 51, 32, 103, 108, 114, 61, 123,
  45, 49, 54, 125, 32, 103, 108, 103, 61, 123, 45, 49, 53, 125, 32, 103,
  108, 98, 61, 123, 45, 54, 53, 125, 10, 98, 114, 114, 61, 123, 45, 49,
  53, 125, 32, 98, 114, 103, 61, 123, 45, 50, 55, 125, 32, 98, 114, 98,
  61, 50, 49, 32, 98, 108, 114, 61, 57, 32, 98, 108, 103, 61, 55, 53,
  32, 98, 108, 98, 61, 57, 51, 55, 10, 45, 45, 103, 105, 109, 112, 95,
  100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 48, 45, 53, 93, 10,
  45, 42, 91, 45, 51, 93, 32, 36, 114, 108, 114, 32, 45, 42, 91, 45,
  50, 93, 32, 36, 114, 108, 103, 32, 45, 42, 91, 45, 49, 93, 32, 36,
  114, 108, 98, 32, 45, 42, 91, 45, 54, 93, 32, 36, 114, 114, 114, 32,
  45, 42, 91, 45, 53, 93, 32, 36, 114, 114, 103, 32, 45, 42, 91, 45,
  52, 93, 32, 36, 114, 114, 98, 10, 45, 43, 91, 45, 54, 93, 32, 91,
  45, 53, 93, 32, 45, 43, 91, 45, 54, 93, 32, 91, 45, 52, 93, 32,
  45, 43, 91, 45, 54, 93, 32, 91, 45, 51, 93, 32, 45, 43, 91, 45,
  54, 93, 32, 91, 45, 50, 93, 32, 45, 43, 91, 45, 54, 93, 32, 91,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 45, 45, 53, 93, 10, 45,
  47, 91, 45, 49, 93, 32, 49, 48, 48, 48, 32, 45, 110, 91, 45, 49,
  93, 32, 48, 44, 50, 53, 53, 32, 45, 116, 111, 95, 103, 114, 97, 121,
  91, 45, 49, 93, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110,
  111, 116, 104, 105, 110, 103, 91, 48, 45, 53, 93, 10, 45, 42, 91, 45,
  51, 93, 32, 36, 103, 108, 114, 32, 45, 42, 91, 45, 50, 93, 32, 36,
  103, 108, 103, 32, 45, 42, 91, 45, 49, 93, 32, 36, 103, 108, 98, 32,
  45, 42, 91, 45, 54, 93, 32, 36, 103, 114, 114, 32, 45, 42, 91, 45,
  53, 93, 32, 36, 103, 114, 103, 32, 45, 42, 91, 45, 52, 93, 32, 36,
  103, 114, 98, 10, 45, 43, 91, 45, 54, 93, 32, 91, 45, 53, 93, 32,
  45, 43, 91, 45, 54, 93, 32, 91, 45, 52, 93, 32, 45, 43, 91, 45,
  54, 93, 32, 91, 45, 51, 93, 32, 45, 43, 91, 45, 54, 93, 32, 91,
  45, 50, 93, 32, 45, 43, 91, 45, 54, 93, 32, 91, 45, 49, 93, 32,
  45, 114, 109, 91, 45, 49, 45, 45, 53, 93, 10, 45, 47, 91, 45, 49,
  93, 32, 49, 48, 48, 48, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 32, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 49, 93,
  10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105,
  110, 103, 91, 48, 45, 53, 93, 10, 45, 42, 91, 45, 51, 93, 32, 36,
  98, 108, 114, 32, 45, 42, 91, 45, 50, 93, 32, 36, 98, 108, 103, 32,
  45, 42, 91, 45, 49, 93, 32, 36, 98, 108, 98, 32, 45, 42, 91, 45,
  54, 93, 32, 36, 98, 114, 114, 32, 45, 42, 91, 45, 53, 93, 32, 36,
  98, 114, 103, 32, 45, 42, 91, 45, 52, 93, 32, 36, 98, 114, 98, 10,
  45, 43, 91, 45, 54, 93, 32, 91, 45, 53, 93, 32, 45, 43, 91, 45,
  54, 93, 32, 91, 45, 52, 93, 32, 45, 43, 91, 45, 54, 93, 32, 91,
  45, 51, 93, 32, 45, 43, 91, 45, 54, 93, 32, 91, 45, 50, 93, 32,
  45, 43, 91, 45, 54, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91,
  45, 49, 45, 45, 53, 93, 10, 45, 47, 91, 45, 49, 93, 32, 49, 48,
  48, 48, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32,
  45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 49, 93, 10, 45, 107, 91,
  45, 49, 45, 45, 51, 93, 32, 45, 97, 91, 45, 51, 44, 45, 50, 44,
  45, 49, 93, 32, 99, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61,
  61, 54, 125, 32, 45, 105, 102, 32, 123, 36, 50, 61, 61, 49, 125, 32,
  45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 114, 91, 45, 49, 44, 45, 50, 93, 32, 53, 48, 37, 44,
  53, 48, 37, 44, 49, 44, 51, 44, 54, 32, 45, 97, 91, 45, 49, 44,
  45, 50, 93, 32, 120, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61,
  61, 55, 125, 32, 45, 105, 102, 32, 123, 36, 50, 61, 61, 49, 125, 32,
  45, 114, 118, 91, 45, 49, 44, 45, 50, 93, 32, 45, 101, 110, 100, 105,
  102, 32, 45, 97, 91, 45, 49, 44, 45, 50, 93, 32, 120, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 49, 61, 61, 56, 125, 32, 45, 105, 102, 32,
  123, 36, 50, 61, 61, 49, 125, 32, 45, 114, 118, 91, 45, 49, 44, 45,
  50, 93, 32, 45, 101, 110, 100, 105, 102, 32, 45, 97, 91, 45, 49, 44,
  45, 50, 93, 32, 121, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61,
  61, 57, 125, 32, 45, 105, 102, 32, 123, 36, 50, 61, 61, 49, 125, 32,
  45, 114, 118, 91, 48, 44, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 114, 91, 48, 44, 49, 93, 32, 53, 48, 37, 44, 49, 48, 48, 37,
  44, 49, 44, 51, 44, 54, 32, 45, 97, 91, 48, 44, 49, 93, 32, 120,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 48, 125, 32,
  45, 105, 102, 32, 123, 36, 50, 61, 61, 49, 125, 32, 45, 114, 118, 91,
  48, 44, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 91, 48,
  44, 49, 93, 32, 49, 48, 48, 37, 44, 53, 48, 37, 44, 49, 44, 51,
  44, 54, 32, 45, 97, 91, 48, 44, 49, 93, 32, 121, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 61, 61, 49, 49, 125, 32, 45, 116, 111, 95,
  114, 103, 98, 97, 91, 48, 44, 49, 93, 10, 45, 105, 102, 32, 123, 36,
  50, 61, 61, 49, 125, 32, 45, 114, 118, 91, 48, 44, 49, 93, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 102, 105, 108, 108, 91, 48, 93, 32, 105,
  102, 40, 121, 37, 50, 61, 61, 48, 44, 48, 44, 105, 41, 32, 45, 114,
  118, 91, 48, 44, 49, 93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  114, 103, 98, 97, 91, 48, 44, 49, 93, 32, 45, 116, 111, 95, 114, 103,
  98, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 50, 125,
  32, 45, 116, 111, 95, 114, 103, 98, 97, 91, 48, 44, 49, 93, 10, 45,
  105, 102, 32, 123, 36, 50, 61, 61, 49, 125, 32, 45, 114, 118, 91, 48,
  44, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 102, 105, 108, 108,
  91, 48, 93, 32, 105, 102, 40, 120, 37, 50, 61, 61, 48, 44, 48, 44,
  105, 41, 32, 45, 114, 118, 91, 48, 44, 49, 93, 32, 45, 99, 111, 109,
  112, 111, 115, 101, 95, 114, 103, 98, 97, 91, 48, 44, 49, 93, 32, 45,
  116, 111, 95, 114, 103, 98, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49,
  61, 61, 49, 51, 125, 10, 45, 105, 102, 32, 123, 36, 50, 61, 61, 49,
  125, 32, 45, 114, 118, 91, 48, 44, 49, 93, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 114, 91, 48, 44, 49, 93, 32, 49, 57, 50, 48, 44, 49,
  48, 56, 48, 44, 49, 44, 51, 44, 54, 32, 45, 45, 102, 99, 91, 45,
  49, 93, 32, 48, 44, 48, 44, 48, 32, 45, 114, 91, 45, 49, 93, 32,
  49, 57, 50, 48, 44, 52, 53, 10, 45, 114, 118, 91, 45, 49, 44, 45,
  50, 93, 32, 45, 97, 91, 45, 49, 44, 45, 50, 93, 32, 121, 32, 45,
  97, 91, 45, 49, 44, 45, 50, 93, 32, 121, 10, 45, 101, 110, 100, 105,
  102, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123,
  123, 36, 49, 61, 61, 54, 125, 124, 124, 123, 36, 49, 61, 61, 55, 125,
  124, 124, 123, 36, 49, 61, 61, 56, 125, 124, 124, 123, 36, 49, 61, 61,
  57, 125, 124, 124, 123, 36, 49, 61, 61, 49, 48, 125, 124, 124, 123, 36,
  49, 61, 61, 49, 49, 125, 124, 124, 123, 36, 49, 61, 61, 49, 50, 125,
  124, 124, 123, 36, 49, 61, 61, 49, 51, 125, 125, 10, 45, 97, 112, 112,
  108, 121, 95, 103, 97, 109, 109, 97, 32, 36, 51, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 103, 105, 109, 112, 95, 109, 105, 120, 95, 108, 97, 98,
  32, 49, 44, 48, 44, 48, 44, 36, 53, 44, 48, 44, 48, 44, 36, 53,
  44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 10, 45, 105, 102, 32, 123,
  123, 36, 49, 61, 61, 48, 125, 124, 124, 123, 36, 49, 61, 61, 49, 125,
  125, 32, 45, 103, 105, 109, 112, 95, 109, 105, 120, 95, 114, 103, 98, 32,
  49, 44, 36, 54, 44, 48, 44, 49, 44, 48, 44, 48, 44, 49, 44, 48,
  44, 48, 44, 48, 44, 50, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 123, 36, 49, 61, 61, 50, 125, 124, 124, 123, 36,
  49, 61, 61, 51, 125, 125, 32, 45, 103, 105, 109, 112, 95, 109, 105, 120,
  95, 114, 103, 98, 32, 49, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48,
  44, 49, 44, 36, 54, 44, 48, 44, 48, 44, 50, 44, 48, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 52, 125,
  32, 45, 103, 105, 109, 112, 95, 109, 105, 120, 95, 114, 103, 98, 32, 49,
  44, 48, 44, 48, 44, 49, 44, 36, 54, 44, 48, 44, 49, 44, 48, 44,
  48, 44, 48, 44, 50, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 49, 61, 61, 53, 125, 32, 45, 103, 105, 109, 112,
  95, 109, 105, 120, 95, 114, 103, 98, 32, 49, 44, 48, 44, 48, 44, 49,
  44, 36, 54, 44, 48, 44, 49, 44, 123, 105, 102, 40, 123, 36, 54, 62,
  61, 48, 125, 44, 36, 54, 44, 48, 41, 125, 44, 48, 44, 48, 44, 50,
  44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 10,
  35, 64, 103, 105, 109, 112, 32, 83, 116, 101, 114, 101, 111, 32, 105, 109,
  97, 103, 101, 32, 58, 32, 103, 99, 100, 95, 115, 116, 101, 114, 101, 111,
  95, 105, 109, 103, 44, 32, 103, 99, 100, 95, 115, 116, 101, 114, 101, 111,
  95, 105, 109, 103, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 117,
  62, 67, 114, 101, 97, 116, 101, 32, 97, 32, 51, 68, 32, 105, 109, 97,
  103, 101, 32, 102, 114, 111, 109, 32, 97, 32, 102, 108, 97, 116, 32, 111,
  110, 101, 60, 47, 117, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 92,
  110, 60, 105, 62, 51, 68, 32, 79, 112, 116, 105, 111, 110, 115, 60, 47,
  105, 62, 34, 41, 44, 32, 115, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 51, 100, 32, 105, 109, 97, 103, 101, 32, 116, 121, 112, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 110, 97, 103, 108, 121, 112,
  104, 58, 32, 82, 101, 100, 47, 67, 121, 97, 110, 34, 44, 34, 83, 105,
  100, 101, 32, 98, 121, 32, 83, 105, 100, 101, 34, 44, 34, 68, 101, 112,
  116, 104, 32, 77, 97, 112, 34, 44, 34, 73, 110, 118, 101, 114, 115, 101,
  32, 68, 101, 112, 116, 104, 32, 77, 97, 112, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 66, 97, 108, 97, 110, 99, 101, 32, 99, 111,
  108, 111, 114, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 52, 44, 34,
  78, 111, 110, 101, 34, 44, 34, 70, 97, 115, 116, 32, 72, 97, 108, 102,
  34, 44, 34, 70, 97, 115, 116, 32, 70, 117, 108, 108, 34, 44, 34, 76,
  111, 119, 34, 44, 34, 77, 101, 100, 105, 117, 109, 34, 44, 34, 72, 105,
  103, 104, 34, 44, 34, 70, 117, 108, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 68, 101, 112, 116, 104, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 46, 50, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 68, 105, 115, 116, 97, 110, 99, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 45, 50, 44, 50, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 92, 110, 60, 105, 62, 68, 101, 112, 116, 104, 32, 77,
  97, 112, 32, 79, 112, 116, 105, 111, 110, 115, 60, 47, 105, 62, 34, 41,
  44, 32, 115, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 117,
  114, 32, 112, 101, 114, 99, 101, 110, 116, 97, 103, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 50, 53, 44, 48, 44, 50, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 98, 106, 101, 99, 116, 32, 114,
  97, 116, 105, 111, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48,
  44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 98, 106,
  101, 99, 116, 32, 116, 111, 108, 101, 114, 97, 110, 99, 101, 32, 61, 32,
  105, 110, 116, 40, 52, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 68, 101, 115, 112, 101, 99, 107, 108, 101, 32, 61, 32,
  98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 92, 110,
  60, 105, 62, 79, 117, 116, 112, 117, 116, 32, 79, 112, 116, 105, 111, 110,
  115, 60, 47, 105, 62, 34, 41, 44, 32, 115, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 117, 116, 111, 32, 99, 114, 111, 112, 32, 61, 32,
  98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58,
  32, 60, 105, 62, 71, 97, 114, 97, 103, 101, 99, 111, 100, 101, 114, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49,
  51, 47, 49, 49, 47, 48, 50, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 103, 99, 100, 95, 115, 116, 101, 114, 101,
  111, 95, 105, 109, 103, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  49, 61, 48, 125, 44, 36, 123, 50, 61, 50, 125, 44, 36, 123, 51, 61,
  49, 46, 50, 125, 44, 36, 123, 52, 61, 49, 125, 44, 36, 123, 53, 61,
  48, 46, 50, 53, 125, 44, 36, 123, 54, 61, 50, 125, 44, 36, 123, 55,
  61, 52, 125, 44, 36, 123, 56, 61, 49, 125, 44, 36, 123, 57, 61, 48,
  125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 32, 98,
  61, 123, 97, 98, 115, 40, 36, 51, 37, 42, 119, 42, 36, 52, 41, 125,
  10, 45, 45, 103, 99, 100, 95, 100, 101, 112, 116, 104, 91, 48, 93, 32,
  36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 10, 45, 103, 99, 100,
  95, 115, 116, 101, 114, 101, 111, 91, 48, 44, 49, 93, 32, 36, 49, 44,
  36, 50, 44, 36, 51, 37, 44, 36, 52, 10, 45, 105, 102, 32, 123, 33,
  36, 49, 34, 32, 38, 38, 32, 34, 36, 57, 125, 32, 45, 122, 91, 45,
  49, 93, 32, 36, 98, 44, 123, 119, 45, 49, 45, 36, 98, 125, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 103, 99, 100, 95, 100, 101, 112, 116, 104, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 49, 61, 48, 46, 50, 53, 125, 44, 36, 123,
  50, 61, 50, 125, 44, 36, 123, 51, 61, 52, 125, 44, 36, 123, 52, 61,
  49, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 119, 62, 104, 125, 32, 45,
  105, 102, 32, 123, 119, 62, 55, 48, 48, 125, 32, 45, 45, 114, 91, 45,
  49, 93, 32, 55, 48, 48, 44, 123, 104, 42, 55, 48, 48, 47, 119, 125,
  32, 45, 101, 108, 115, 101, 32, 91, 48, 93, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 108, 105, 102, 32, 123, 64, 123, 48, 44, 104, 125, 62,
  55, 48, 48, 125, 32, 45, 45, 114, 91, 45, 49, 93, 32, 123, 64, 123,
  48, 44, 119, 125, 42, 55, 48, 48, 47, 64, 123, 48, 44, 104, 125, 125,
  44, 55, 48, 48, 32, 45, 101, 108, 115, 101, 32, 91, 48, 93, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 97, 112, 112, 108, 121, 95, 112, 97, 114,
  97, 108, 108, 101, 108, 95, 111, 118, 101, 114, 108, 97, 112, 91, 45, 49,
  93, 32, 34, 45, 109, 101, 100, 105, 97, 110, 32, 55, 34, 44, 52, 32,
  45, 115, 101, 103, 109, 101, 110, 116, 95, 119, 97, 116, 101, 114, 115, 104,
  101, 100, 91, 45, 49, 93, 32, 49, 44, 49, 10, 45, 105, 102, 32, 36,
  52, 32, 45, 103, 99, 100, 95, 108, 97, 98, 101, 108, 91, 45, 49, 93,
  32, 36, 51, 32, 45, 101, 108, 115, 101, 32, 45, 108, 97, 98, 101, 108,
  91, 45, 49, 93, 32, 36, 51, 44, 49, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 45, 49, 93, 32,
  45, 98, 91, 45, 49, 93, 32, 48, 46, 52, 53, 37, 32, 45, 110, 91,
  45, 49, 93, 32, 48, 44, 36, 50, 10, 45, 114, 91, 45, 49, 93, 32,
  91, 48, 93, 44, 91, 48, 93, 10, 45, 110, 111, 114, 109, 91, 48, 93,
  32, 45, 110, 91, 48, 93, 32, 48, 44, 49, 32, 45, 97, 100, 100, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 98, 91, 45, 49, 93, 32, 36, 49,
  37, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 99, 100, 95, 115,
  116, 101, 114, 101, 111, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  49, 61, 48, 125, 44, 36, 123, 50, 61, 49, 125, 44, 36, 123, 51, 61,
  49, 46, 50, 37, 125, 44, 36, 123, 52, 61, 49, 125, 10, 45, 108, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61,
  50, 125, 32, 45, 107, 101, 101, 112, 91, 45, 49, 93, 32, 45, 114, 101,
  116, 117, 114, 110, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61,
  51, 125, 32, 45, 107, 101, 101, 112, 91, 45, 49, 93, 32, 45, 110, 101,
  103, 97, 116, 105, 118, 101, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45,
  101, 110, 100, 105, 102, 10, 119, 102, 97, 99, 61, 123, 105, 102, 40, 64,
  123, 34, 45, 105, 115, 95, 112, 101, 114, 99, 101, 110, 116, 32, 36, 51,
  34, 125, 44, 36, 51, 42, 119, 44, 36, 51, 41, 125, 32, 45, 110, 91,
  45, 49, 93, 32, 48, 44, 36, 119, 102, 97, 99, 10, 45, 105, 102, 32,
  123, 36, 49, 61, 61, 48, 34, 32, 38, 38, 32, 34, 36, 50, 62, 48,
  125, 32, 45, 103, 99, 100, 95, 98, 97, 108, 97, 110, 99, 101, 95, 97,
  110, 97, 103, 108, 121, 112, 104, 91, 48, 93, 32, 36, 50, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 91, 49, 93, 32, 91, 48, 93, 32, 45,
  119, 97, 114, 112, 91, 48, 93, 32, 91, 45, 49, 93, 44, 49, 32, 45,
  109, 117, 108, 91, 45, 49, 93, 32, 45, 49, 32, 45, 119, 97, 114, 112,
  91, 49, 93, 32, 91, 45, 49, 93, 44, 49, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 105, 102, 32, 36, 49, 32, 45, 114, 118, 91, 48, 44,
  49, 93, 32, 45, 97, 112, 112, 101, 110, 100, 91, 48, 44, 49, 93, 32,
  120, 32, 45, 101, 108, 115, 101, 32, 45, 115, 104, 105, 102, 116, 91, 48,
  93, 32, 123, 45, 36, 119, 102, 97, 99, 42, 36, 52, 125, 32, 45, 115,
  104, 105, 102, 116, 91, 49, 93, 32, 123, 36, 119, 102, 97, 99, 42, 36,
  52, 125, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48, 93, 32,
  48, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 49, 93, 32, 49,
  44, 50, 32, 45, 97, 112, 112, 101, 110, 100, 91, 48, 44, 49, 93, 32,
  99, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 10, 103,
  99, 100, 95, 98, 97, 108, 97, 110, 99, 101, 95, 97, 110, 97, 103, 108,
  121, 112, 104, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  52, 125, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 125, 32, 45,
  114, 101, 116, 117, 114, 110, 32, 45, 101, 108, 105, 102, 32, 123, 36, 49,
  60, 51, 125, 32, 45, 103, 99, 100, 95, 98, 97, 108, 97, 110, 99, 101,
  95, 97, 110, 97, 103, 108, 121, 112, 104, 95, 115, 105, 109, 112, 108, 101,
  32, 36, 49, 10, 45, 101, 108, 115, 101, 32, 45, 103, 99, 100, 95, 98,
  97, 108, 97, 110, 99, 101, 95, 97, 110, 97, 103, 108, 121, 112, 104, 95,
  101, 120, 112, 32, 48, 46, 52, 51, 44, 48, 46, 52, 53, 44, 123, 105,
  102, 40, 36, 49, 60, 53, 44, 105, 102, 40, 36, 49, 61, 61, 51, 44,
  50, 44, 49, 46, 54, 41, 44, 105, 102, 40, 36, 49, 61, 61, 53, 44,
  49, 46, 50, 44, 49, 41, 41, 125, 32, 45, 101, 110, 100, 105, 102, 10,
  103, 99, 100, 95, 98, 97, 108, 97, 110, 99, 101, 95, 97, 110, 97, 103,
  108, 121, 112, 104, 95, 115, 105, 109, 112, 108, 101, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 49, 61, 49, 125, 10, 45, 108, 91, 45, 49,
  93, 32, 45, 115, 32, 99, 10, 45, 45, 45, 91, 49, 93, 32, 91, 48,
  93, 32, 45, 47, 91, 45, 49, 93, 32, 123, 52, 47, 36, 49, 125, 32,
  45, 45, 91, 49, 44, 50, 93, 32, 91, 45, 49, 93, 32, 45, 43, 91,
  48, 44, 45, 49, 93, 10, 45, 45, 45, 91, 50, 93, 32, 91, 48, 93,
  32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 47,
  91, 45, 49, 93, 32, 123, 52, 47, 36, 49, 125, 32, 45, 43, 91, 48,
  44, 45, 49, 93, 10, 45, 110, 91, 48, 93, 32, 123, 49, 48, 42, 36,
  49, 125, 44, 50, 53, 53, 32, 45, 97, 91, 48, 45, 50, 93, 32, 99,
  32, 45, 99, 91, 48, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110,
  100, 108, 10, 103, 99, 100, 95, 98, 97, 108, 97, 110, 99, 101, 95, 97,
  110, 97, 103, 108, 121, 112, 104, 95, 101, 120, 112, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 49, 61, 48, 46, 53, 125, 44, 36, 123, 50,
  61, 48, 46, 53, 125, 44, 36, 123, 51, 61, 49, 125, 10, 45, 108, 91,
  45, 49, 93, 32, 45, 115, 32, 99, 10, 45, 109, 32, 34, 95, 101, 120,
  112, 58, 32, 45, 108, 32, 45, 45, 108, 116, 32, 48, 32, 45, 42, 91,
  45, 49, 93, 32, 45, 50, 32, 45, 43, 91, 45, 49, 93, 32, 49, 32,
  45, 97, 98, 115, 91, 48, 93, 32, 45, 94, 91, 48, 93, 32, 36, 34,
  34, 49, 32, 45, 42, 91, 48, 93, 32, 123, 50, 53, 53, 47, 50, 53,
  53, 94, 36, 34, 34, 49, 125, 32, 45, 42, 91, 48, 44, 45, 49, 93,
  32, 45, 101, 110, 100, 108, 34, 10, 45, 45, 45, 91, 49, 93, 32, 91,
  48, 93, 32, 45, 95, 101, 120, 112, 91, 45, 49, 93, 32, 36, 51, 32,
  45, 42, 91, 45, 49, 93, 32, 36, 49, 32, 45, 45, 91, 49, 44, 50,
  93, 32, 91, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 123, 49,
  47, 36, 49, 42, 40, 49, 45, 36, 49, 41, 125, 32, 45, 43, 91, 48,
  44, 45, 49, 93, 10, 45, 45, 42, 91, 50, 93, 32, 48, 46, 54, 53,
  32, 45, 45, 91, 45, 49, 93, 32, 91, 48, 93, 32, 45, 99, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 42, 91, 45, 49, 93, 32,
  36, 50, 32, 45, 45, 91, 50, 93, 32, 91, 45, 49, 93, 32, 45, 42,
  91, 45, 49, 93, 32, 123, 49, 47, 36, 50, 42, 40, 49, 45, 36, 50,
  41, 125, 32, 45, 43, 91, 48, 44, 45, 49, 93, 10, 45, 97, 112, 112,
  108, 121, 95, 103, 97, 109, 109, 97, 91, 48, 93, 32, 49, 46, 49, 53,
  32, 45, 97, 91, 48, 45, 50, 93, 32, 99, 32, 45, 99, 32, 48, 44,
  50, 53, 53, 32, 45, 117, 110, 99, 111, 109, 109, 97, 110, 100, 32, 95,
  101, 120, 112, 10, 45, 101, 110, 100, 108, 10, 35, 64, 103, 105, 109, 112,
  32, 85, 110, 100, 111, 32, 97, 110, 97, 103, 108, 121, 112, 104, 32, 58,
  32, 103, 99, 100, 95, 117, 110, 115, 116, 101, 114, 101, 111, 44, 32, 103,
  99, 100, 95, 117, 110, 115, 116, 101, 114, 101, 111, 95, 112, 114, 101, 118,
  105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 117, 62,
  65, 116, 116, 101, 109, 112, 116, 32, 116, 111, 32, 114, 101, 118, 101, 114,
  116, 32, 114, 101, 100, 47, 99, 121, 97, 110, 32, 97, 110, 97, 103, 108,
  121, 112, 104, 32, 116, 111, 32, 50, 68, 60, 47, 117, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 98, 62, 87, 97, 114, 110, 105, 110, 103,
  58, 32, 119, 105, 116, 104, 32, 104, 105, 103, 104, 32, 112, 114, 101, 99,
  105, 115, 105, 111, 110, 32, 111, 114, 32, 108, 97, 114, 103, 101, 32, 105,
  109, 97, 103, 101, 32, 116, 104, 105, 115, 32, 99, 97, 110, 32, 98, 101,
  32, 86, 69, 82, 89, 32, 115, 108, 111, 119, 33, 60, 47, 98, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 92, 110, 60, 105, 62, 68, 105, 115,
  112, 108, 97, 99, 101, 109, 101, 110, 116, 32, 83, 101, 116, 116, 105, 110,
  103, 115, 60, 47, 105, 62, 34, 41, 44, 32, 115, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 80, 114, 101, 99, 105, 115, 105, 111, 110, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 53, 44, 49, 44, 54, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 49, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 32, 119, 97, 114, 112, 32, 111, 110, 108, 121,
  32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 70, 97, 115, 116, 32, 40, 108, 111, 119, 32, 112, 114,
  101, 99, 105, 115, 105, 111, 110, 41, 32, 112, 114, 101, 118, 105, 101, 119,
  32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 92, 110, 60, 105, 62, 84, 105, 108, 101, 32, 83, 101, 116, 116, 105,
  110, 103, 115, 60, 47, 105, 62, 34, 41, 44, 32, 115, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 72, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  32, 116, 105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49,
  44, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 101, 114,
  116, 105, 99, 97, 108, 32, 116, 105, 108, 101, 115, 32, 61, 32, 105, 110,
  116, 40, 49, 44, 49, 44, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105,
  62, 71, 97, 114, 97, 103, 101, 99, 111, 100, 101, 114, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 49,
  48, 47, 50, 54, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 99, 100, 95, 117, 110, 115, 116, 101, 114, 101, 111,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 53, 125, 44,
  36, 123, 50, 61, 48, 46, 49, 125, 44, 36, 123, 51, 61, 48, 125, 44,
  36, 123, 52, 61, 49, 125, 44, 36, 123, 53, 61, 49, 125, 44, 36, 123,
  54, 61, 49, 125, 44, 36, 123, 55, 61, 48, 125, 44, 36, 123, 56, 61,
  48, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 36, 52, 34, 32, 38, 38,
  32, 34, 36, 56, 125, 32, 112, 114, 61, 49, 32, 45, 101, 108, 115, 101,
  32, 112, 114, 61, 36, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116,
  111, 95, 114, 103, 98, 91, 48, 93, 32, 45, 115, 112, 108, 105, 116, 95,
  116, 105, 108, 101, 115, 91, 48, 93, 32, 36, 53, 44, 36, 54, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 115, 91, 48, 93, 32, 99, 32, 45, 45, 101, 113, 117, 97, 108,
  105, 122, 101, 91, 48, 44, 49, 93, 32, 50, 53, 54, 10, 45, 45, 100,
  105, 115, 112, 108, 97, 99, 101, 109, 101, 110, 116, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 36, 50, 44, 36, 112, 114, 10, 45, 105, 102, 32,
  36, 51, 32, 45, 115, 104, 91, 45, 49, 93, 32, 49, 44, 49, 32, 45,
  102, 91, 45, 49, 93, 32, 48, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 47, 91, 45, 49, 93, 32, 50, 32,
  45, 119, 97, 114, 112, 91, 49, 44, 50, 93, 32, 91, 45, 49, 93, 44,
  49, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 119, 97, 114,
  112, 91, 48, 93, 32, 91, 45, 49, 93, 44, 49, 10, 45, 107, 101, 101,
  112, 91, 48, 45, 50, 93, 32, 45, 97, 32, 99, 32, 45, 99, 91, 48,
  93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101,
  115, 32, 36, 53, 44, 36, 54, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 10, 103, 99, 100, 95, 117, 110, 115, 116, 101, 114, 101, 111,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 103, 99, 100, 95, 117, 110, 115, 116, 101, 114, 101, 111, 32, 36, 123,
  49, 45, 45, 49, 125, 44, 49, 34, 44, 36, 45, 49, 10, 35, 64, 103,
  105, 109, 112, 32, 95, 10, 35, 64, 103, 105, 109, 112, 32, 60, 98, 62,
  84, 101, 115, 116, 105, 110, 103, 60, 47, 98, 62, 10, 35, 64, 103, 105,
  109, 112, 32, 60, 105, 62, 71, 97, 114, 97, 103, 101, 99, 111, 100, 101,
  114, 60, 47, 105, 62, 10, 35, 64, 103, 105, 109, 112, 32, 65, 110, 116,
  105, 32, 97, 108, 105, 97, 115, 32, 58, 32, 103, 99, 100, 95, 97, 110,
  116, 105, 95, 97, 108, 105, 97, 115, 44, 32, 103, 99, 100, 95, 97, 110,
  116, 105, 95, 97, 108, 105, 97, 115, 95, 112, 114, 101, 118, 105, 101, 119,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 105, 62, 83, 101, 108,
  101, 99, 116, 105, 118, 101, 108, 121, 32, 115, 109, 111, 111, 116, 104, 32,
  114, 101, 115, 105, 122, 105, 110, 103, 32, 112, 105, 120, 101, 108, 97, 116,
  105, 111, 110, 60, 47, 105, 62, 34, 41, 44, 32, 115, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 32, 97, 109, 111,
  117, 110, 116, 32, 61, 32, 105, 110, 116, 40, 54, 48, 44, 48, 44, 50,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103,
  101, 32, 101, 120, 112, 111, 110, 101, 110, 116, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 51, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 76, 105, 103, 104, 116, 101, 110, 32, 101, 100,
  103, 101, 115, 32, 61, 32, 105, 110, 116, 40, 53, 48, 44, 48, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 71, 97, 114, 97,
  103, 101, 99, 111, 100, 101, 114, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32,
  58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 50, 47, 48, 57, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103,
  99, 100, 95, 97, 110, 116, 105, 95, 97, 108, 105, 97, 115, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 48, 125, 44, 36, 123,
  50, 61, 48, 46, 51, 125, 44, 36, 123, 51, 61, 49, 48, 125, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121,
  91, 45, 49, 93, 10, 45, 45, 115, 109, 111, 111, 116, 104, 91, 48, 93,
  32, 36, 49, 44, 48, 44, 49, 44, 49, 46, 54, 44, 49, 46, 49, 44,
  48, 46, 56, 44, 51, 48, 44, 48, 46, 54, 10, 45, 45, 103, 114, 97,
  100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 91, 48, 93, 32, 45, 45,
  110, 91, 45, 49, 93, 32, 48, 44, 36, 51, 32, 45, 97, 100, 100, 91,
  48, 44, 45, 49, 93, 10, 45, 112, 111, 119, 91, 45, 49, 93, 32, 36,
  50, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45,
  45, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 91, 45,
  49, 93, 32, 45, 112, 111, 119, 91, 45, 49, 93, 32, 36, 50, 32, 45,
  110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 98, 108, 101,
  110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 111, 118, 101, 114, 108, 97,
  121, 32, 45, 97, 112, 112, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93,
  32, 99, 10, 45, 98, 108, 101, 110, 100, 91, 48, 44, 49, 93, 32, 97,
  108, 112, 104, 97, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 99, 100, 95, 97, 110,
  116, 105, 95, 97, 108, 105, 97, 115, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 99, 100, 95, 97, 110, 116,
  105, 95, 97, 108, 105, 97, 115, 32, 36, 123, 49, 45, 45, 50, 125, 34,
  44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 67, 111, 109, 112,
  114, 101, 115, 115, 105, 111, 110, 32, 98, 108, 117, 114, 32, 58, 32, 103,
  99, 100, 95, 99, 111, 109, 112, 95, 98, 108, 117, 114, 44, 32, 103, 99,
  100, 95, 99, 111, 109, 112, 95, 98, 108, 117, 114, 95, 112, 114, 101, 118,
  105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 105, 62,
  70, 111, 114, 32, 115, 117, 98, 116, 108, 101, 32, 115, 109, 111, 111, 116,
  104, 105, 110, 103, 32, 111, 102, 32, 99, 111, 109, 112, 114, 101, 115, 115,
  105, 111, 110, 32, 97, 114, 116, 105, 102, 97, 99, 116, 115, 60, 47, 105,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 49, 46, 32, 80, 114, 101, 118, 105, 101, 119, 32, 119,
  105, 108, 108, 32, 60, 98, 62, 110, 111, 116, 60, 47, 98, 62, 32, 115,
  104, 111, 119, 32, 116, 104, 101, 32, 102, 105, 110, 97, 108, 32, 114, 101,
  115, 117, 108, 116, 32, 97, 99, 99, 117, 114, 97, 116, 101, 108, 121, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 50, 46, 32, 66, 101, 32, 115, 117,
  114, 101, 32, 116, 111, 32, 97, 112, 112, 108, 121, 32, 60, 98, 62, 98,
  101, 102, 111, 114, 101, 60, 47, 98, 62, 32, 97, 110, 121, 32, 105, 109,
  97, 103, 101, 32, 114, 101, 115, 105, 122, 105, 110, 103, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 51, 46, 32, 82, 101, 100, 117, 99, 101, 32, 103,
  114, 105, 100, 32, 119, 105, 100, 116, 104, 32, 119, 104, 101, 110, 32, 105,
  110, 99, 114, 101, 97, 115, 105, 110, 103, 32, 100, 105, 118, 105, 115, 105,
  111, 110, 115, 32, 116, 111, 32, 97, 118, 111, 105, 100, 32, 111, 118, 101,
  114, 45, 115, 109, 111, 111, 116, 104, 105, 110, 103, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 52, 46, 32, 83, 101, 116, 32, 103, 114, 105, 100, 32,
  100, 105, 118, 105, 115, 105, 111, 110, 115, 32, 116, 111, 32, 122, 101, 114,
  111, 32, 102, 111, 114, 32, 49, 48, 48, 37, 32, 115, 109, 111, 111, 116,
  104, 105, 110, 103, 46, 92, 110, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 71, 114, 105, 100, 32, 100, 105, 118, 105, 115,
  105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 50, 44, 48, 44, 51,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 105, 100, 32,
  119, 105, 100, 116, 104, 32, 61, 32, 105, 110, 116, 40, 51, 44, 49, 44,
  51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 105, 100,
  32, 115, 109, 111, 111, 116, 104, 105, 110, 103, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 80, 114, 101, 115, 101, 114, 118, 101, 32, 101, 100, 103, 101,
  115, 32, 61, 32, 105, 110, 116, 40, 49, 48, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111,
  117, 114, 32, 99, 104, 97, 110, 110, 101, 108, 115, 32, 61, 32, 98, 111,
  111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66,
  111, 111, 115, 116, 32, 115, 109, 111, 111, 116, 104, 32, 61, 32, 98, 111,
  111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 71, 97,
  114, 97, 103, 101, 99, 111, 100, 101, 114, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 50, 47, 48,
  57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 103, 99, 100, 95, 99, 111, 109, 112, 95, 98, 108, 117, 114, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 50, 125, 44, 36, 123,
  50, 61, 51, 125, 44, 36, 123, 51, 61, 49, 125, 44, 36, 123, 52, 61,
  49, 48, 48, 125, 44, 36, 123, 53, 61, 49, 125, 44, 36, 123, 54, 61,
  48, 125, 10, 103, 115, 122, 61, 123, 50, 94, 40, 53, 45, 36, 49, 41,
  125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99,
  105, 116, 121, 91, 45, 49, 93, 10, 45, 45, 116, 111, 95, 103, 114, 97,
  121, 91, 48, 93, 32, 45, 101, 100, 103, 101, 115, 91, 45, 49, 93, 32,
  49, 52, 46, 53, 37, 32, 45, 110, 91, 45, 49, 93, 32, 123, 49, 48,
  48, 45, 36, 52, 125, 37, 44, 49, 48, 48, 37, 10, 45, 105, 102, 32,
  123, 64, 123, 48, 44, 115, 125, 62, 49, 34, 32, 38, 38, 32, 34, 36,
  53, 125, 10, 45, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110,
  101, 108, 115, 91, 48, 93, 32, 34, 45, 109, 101, 100, 105, 97, 110, 32,
  53, 34, 44, 52, 10, 45, 105, 109, 97, 103, 101, 91, 48, 93, 32, 91,
  45, 49, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45,
  50, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 125, 32, 123, 119,
  125, 44, 123, 104, 125, 44, 49, 44, 49, 44, 50, 53, 53, 32, 45, 109,
  117, 108, 91, 45, 50, 44, 45, 49, 93, 32, 45, 101, 108, 115, 101, 10,
  123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 49, 44, 48, 10, 45, 103,
  114, 105, 100, 91, 45, 49, 93, 32, 36, 103, 115, 122, 44, 36, 103, 115,
  122, 44, 48, 44, 48, 44, 49, 44, 50, 53, 53, 10, 45, 105, 102, 32,
  123, 36, 50, 62, 61, 50, 125, 32, 45, 103, 114, 105, 100, 91, 45, 49,
  93, 32, 36, 103, 115, 122, 44, 36, 103, 115, 122, 44, 49, 44, 49, 44,
  49, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 50, 61, 61, 51, 125, 32, 45, 103, 114, 105, 100, 91, 45,
  49, 93, 32, 36, 103, 115, 122, 44, 36, 103, 115, 122, 44, 45, 49, 44,
  45, 49, 44, 49, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 51, 44, 48, 32, 45,
  109, 117, 108, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 91, 45, 50, 93, 32, 91, 48, 93, 32, 45, 97, 112,
  112, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 115,
  109, 111, 111, 116, 104, 91, 49, 93, 32, 123, 49, 48, 48, 42, 36, 54,
  43, 49, 48, 48, 125, 44, 48, 46, 54, 44, 48, 46, 51, 10, 45, 98,
  108, 101, 110, 100, 91, 48, 44, 49, 93, 32, 97, 108, 112, 104, 97, 10,
  45, 105, 102, 32, 123, 33, 36, 54, 125, 32, 45, 115, 104, 97, 114, 112,
  101, 110, 91, 45, 49, 93, 32, 50, 48, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 99, 100,
  95, 99, 111, 109, 112, 95, 98, 108, 117, 114, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 99, 100, 95, 99,
  111, 109, 112, 95, 98, 108, 117, 114, 32, 36, 123, 49, 45, 45, 50, 125,
  34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 68, 101, 112,
  116, 104, 32, 98, 108, 117, 114, 32, 58, 32, 103, 99, 100, 95, 100, 101,
  112, 116, 104, 95, 98, 108, 117, 114, 44, 32, 103, 99, 100, 95, 100, 101,
  112, 116, 104, 95, 98, 108, 117, 114, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 117, 62, 83, 101, 108, 101, 99, 116, 105, 118, 101, 108, 121,
  32, 98, 108, 117, 114, 32, 98, 97, 115, 101, 100, 32, 111, 110, 32, 101,
  115, 116, 105, 109, 97, 116, 101, 100, 32, 100, 101, 112, 116, 104, 60, 47,
  117, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 109, 111, 117, 110, 116, 32, 111, 102, 32, 98, 108, 117, 114,
  32, 97, 112, 112, 108, 105, 101, 100, 32, 105, 115, 32, 114, 101, 108, 97,
  116, 105, 118, 101, 32, 116, 111, 32, 108, 117, 109, 105, 110, 97, 110, 99,
  101, 32, 111, 102, 32, 116, 104, 101, 32, 100, 101, 112, 116, 104, 32, 109,
  97, 112, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 92, 110, 60, 105, 62, 70, 111, 99, 117, 115, 32, 79, 112,
  116, 105, 111, 110, 115, 60, 47, 105, 62, 34, 41, 44, 32, 115, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 105, 115, 116, 97, 110, 99, 101,
  32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 105, 110, 116,
  40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 66, 108, 117, 114, 32, 97, 109, 111, 117, 110, 116, 32, 61,
  32, 105, 110, 116, 40, 49, 53, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 92, 110, 60, 105, 62, 68, 101, 112, 116, 104, 32,
  77, 97, 112, 32, 79, 112, 116, 105, 111, 110, 115, 60, 47, 105, 62, 34,
  41, 44, 32, 115, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108,
  117, 114, 32, 112, 101, 114, 99, 101, 110, 116, 97, 103, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 50, 53, 44, 48, 44, 50, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 98, 106, 101, 99, 116, 32,
  114, 97, 116, 105, 111, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44,
  48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 98,
  106, 101, 99, 116, 32, 116, 111, 108, 101, 114, 97, 110, 99, 101, 32, 61,
  32, 105, 110, 116, 40, 52, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 114, 101, 97, 116, 101, 47, 118, 105, 101, 119,
  32, 100, 101, 112, 116, 104, 32, 109, 97, 112, 32, 61, 32, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101,
  118, 101, 114, 115, 101, 32, 109, 97, 112, 32, 61, 32, 98, 111, 111, 108,
  40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62,
  71, 97, 114, 97, 103, 101, 99, 111, 100, 101, 114, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 50,
  47, 50, 52, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 103, 99, 100, 95, 100, 101, 112, 116, 104, 95, 98, 108, 117,
  114, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 48, 125,
  44, 36, 123, 50, 61, 49, 53, 125, 44, 36, 123, 51, 61, 48, 46, 50,
  53, 125, 44, 36, 123, 52, 61, 50, 125, 44, 36, 123, 53, 61, 52, 125,
  44, 36, 123, 54, 61, 48, 125, 44, 36, 123, 55, 61, 49, 125, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 115, 97, 61, 123, 36, 50, 42, 109, 97, 120, 40, 119, 44, 104, 41,
  47, 49, 48, 48, 48, 125, 10, 45, 116, 111, 95, 114, 103, 98, 91, 48,
  93, 10, 45, 45, 103, 99, 100, 95, 100, 101, 112, 116, 104, 91, 48, 93,
  32, 36, 51, 44, 36, 52, 44, 36, 53, 10, 45, 105, 102, 32, 36, 55,
  32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100,
  91, 45, 49, 93, 32, 36, 49, 37, 44, 49, 32, 45, 110, 91, 45, 49,
  93, 32, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 36, 54, 32, 45,
  107, 101, 101, 112, 91, 45, 49, 93, 32, 45, 101, 108, 115, 101, 10, 123,
  119, 125, 44, 123, 104, 125, 44, 49, 44, 49, 44, 48, 32, 91, 45, 50,
  93, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 99, 10, 45, 115,
  109, 111, 111, 116, 104, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36,
  115, 97, 44, 51, 48, 44, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  35, 64, 103, 105, 109, 112, 32, 74, 112, 101, 103, 32, 115, 109, 111, 111,
  116, 104, 32, 58, 32, 103, 99, 100, 95, 106, 112, 101, 103, 95, 115, 109,
  111, 111, 116, 104, 44, 32, 103, 99, 100, 95, 106, 112, 101, 103, 95, 115,
  109, 111, 111, 116, 104, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 105, 62, 81, 117, 105, 99, 107, 32,
  74, 80, 69, 71, 32, 99, 108, 101, 97, 110, 117, 112, 32, 102, 111, 114,
  32, 109, 111, 100, 101, 114, 97, 116, 101, 32, 99, 111, 109, 112, 114, 101,
  115, 115, 105, 111, 110, 32, 103, 108, 105, 116, 99, 104, 101, 115, 60, 47,
  105, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 109, 112, 114, 101, 115,
  115, 105, 111, 110, 32, 102, 105, 108, 116, 101, 114, 32, 61, 32, 98, 111,
  111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  110, 116, 105, 32, 97, 108, 105, 97, 115, 32, 61, 32, 98, 111, 111, 108,
  40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 81, 117, 105,
  99, 107, 32, 101, 110, 108, 97, 114, 103, 101, 32, 61, 32, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 71, 97, 114,
  97, 103, 101, 99, 111, 100, 101, 114, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 50, 47, 48, 57,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  103, 99, 100, 95, 106, 112, 101, 103, 95, 115, 109, 111, 111, 116, 104, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 125, 44, 36,
  123, 50, 61, 49, 125, 44, 36, 123, 51, 61, 48, 125, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45,
  105, 102, 32, 36, 49, 32, 45, 103, 99, 100, 95, 99, 111, 109, 112, 95,
  98, 108, 117, 114, 91, 45, 49, 93, 32, 50, 44, 51, 44, 49, 44, 49,
  48, 48, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  36, 51, 32, 45, 114, 91, 45, 49, 93, 32, 49, 52, 48, 37, 44, 49,
  52, 48, 37, 44, 49, 44, 51, 44, 53, 32, 45, 99, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 36, 50, 32, 45, 103, 99, 100, 95, 97, 110, 116, 105, 95, 97,
  108, 105, 97, 115, 91, 45, 49, 93, 32, 49, 48, 44, 48, 46, 51, 44,
  49, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 103, 99, 100, 95, 106, 112, 101, 103, 95, 115,
  109, 111, 111, 116, 104, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 103, 99, 100, 95, 106, 112, 101, 103, 95, 115,
  109, 111, 111, 116, 104, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36,
  45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 82, 101, 99, 111, 108, 111,
  114, 32, 58, 32, 103, 99, 100, 95, 114, 101, 99, 111, 108, 44, 32, 103,
  99, 100, 95, 114, 101, 99, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 105, 62, 65, 112, 112, 108, 121, 32, 99, 111, 108, 111, 114,
  115, 32, 116, 111, 32, 97, 32, 98, 108, 97, 99, 107, 32, 97, 110, 100,
  32, 119, 104, 105, 116, 101, 32, 105, 109, 97, 103, 101, 60, 47, 105, 62,
  34, 41, 44, 32, 115, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77,
  105, 110, 32, 104, 117, 101, 32, 100, 114, 105, 102, 116, 32, 61, 32, 105,
  110, 116, 40, 45, 49, 52, 44, 45, 52, 53, 44, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 77, 97, 120, 32, 104, 117, 101, 32, 100,
  114, 105, 102, 116, 32, 61, 32, 105, 110, 116, 40, 49, 52, 44, 48, 44,
  52, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 98, 62,
  78, 111, 116, 101, 32, 58, 60, 47, 98, 62, 32, 84, 104, 105, 115, 32,
  102, 105, 108, 116, 101, 114, 32, 110, 101, 101, 100, 115, 32, 116, 119, 111,
  32, 108, 97, 121, 101, 114, 115, 32, 116, 111, 32, 119, 111, 114, 107, 32,
  112, 114, 111, 112, 101, 114, 108, 121, 46, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 79, 114, 105, 103, 105, 110, 97,
  108, 32, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 100, 97, 112, 116, 101, 100, 32, 98, 121, 32, 58, 32, 60, 105, 62,
  71, 97, 114, 97, 103, 101, 99, 111, 100, 101, 114, 60, 47, 105, 62, 46,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 49, 47, 49, 54, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103,
  99, 100, 95, 114, 101, 99, 111, 108, 32, 58, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45,
  108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 45, 114, 118,
  91, 45, 50, 44, 45, 49, 93, 10, 45, 99, 104, 97, 110, 110, 101, 108,
  115, 91, 45, 50, 93, 32, 48, 32, 45, 116, 111, 95, 114, 103, 98, 91,
  45, 50, 93, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93,
  32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 91,
  45, 49, 93, 32, 45, 110, 101, 113, 91, 45, 49, 93, 32, 48, 10, 45,
  115, 114, 103, 98, 50, 114, 103, 98, 91, 45, 51, 44, 45, 50, 93, 32,
  45, 114, 103, 98, 50, 108, 97, 98, 56, 91, 45, 51, 44, 45, 50, 93,
  32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 51, 93, 32, 48,
  32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 50, 93, 32, 49,
  44, 50, 10, 45, 43, 91, 45, 50, 93, 32, 49, 32, 45, 42, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 10, 45, 45, 109, 101, 97, 110, 99, 117,
  114, 118, 97, 116, 117, 114, 101, 95, 102, 108, 111, 119, 91, 45, 51, 93,
  32, 51, 32, 45, 109, 101, 100, 105, 97, 110, 91, 45, 49, 93, 32, 51,
  10, 45, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 91,
  45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 119,
  97, 116, 101, 114, 115, 104, 101, 100, 91, 45, 51, 93, 32, 91, 45, 49,
  93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 45, 91, 45, 50, 93,
  32, 49, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 97, 91, 45, 50,
  44, 45, 49, 93, 32, 99, 32, 45, 108, 97, 98, 56, 50, 114, 103, 98,
  91, 45, 49, 93, 32, 45, 114, 103, 98, 50, 115, 114, 103, 98, 91, 45,
  49, 93, 10, 45, 114, 103, 98, 50, 104, 115, 118, 91, 45, 49, 93, 32,
  45, 115, 32, 99, 32, 45, 45, 101, 113, 117, 97, 108, 105, 122, 101, 91,
  50, 93, 32, 53, 49, 50, 32, 45, 110, 91, 45, 49, 93, 32, 36, 49,
  44, 36, 50, 32, 45, 43, 91, 48, 44, 45, 49, 93, 32, 45, 37, 91,
  48, 93, 32, 51, 54, 48, 32, 45, 97, 32, 99, 32, 45, 104, 115, 118,
  50, 114, 103, 98, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 83, 109, 97, 114,
  116, 32, 114, 111, 116, 97, 116, 101, 32, 58, 32, 103, 99, 100, 95, 115,
  114, 111, 116, 97, 116, 101, 44, 32, 103, 99, 100, 95, 115, 114, 111, 116,
  97, 116, 101, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 117, 62,
  82, 111, 116, 97, 116, 101, 32, 97, 110, 32, 105, 109, 97, 103, 101, 32,
  97, 110, 100, 32, 101, 120, 116, 114, 97, 112, 111, 108, 97, 116, 101, 32,
  116, 104, 101, 32, 99, 111, 114, 110, 101, 114, 115, 60, 47, 117, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 92, 110, 60, 105, 62, 82, 111, 116,
  97, 116, 105, 111, 110, 32, 79, 112, 116, 105, 111, 110, 115, 60, 47, 105,
  62, 34, 41, 44, 32, 115, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  65, 110, 103, 108, 101, 32, 61, 32, 105, 110, 116, 40, 48, 44, 45, 57,
  48, 44, 57, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  101, 110, 116, 114, 101, 120, 32, 61, 32, 105, 110, 116, 40, 53, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 101, 110, 116, 114, 101, 121, 32, 61, 32, 105, 110, 116, 40, 53, 48,
  44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 92, 110,
  60, 105, 62, 81, 117, 97, 108, 105, 116, 121, 32, 79, 112, 116, 105, 111,
  110, 115, 60, 47, 105, 62, 34, 41, 44, 32, 115, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 73, 110, 112, 97, 105, 110, 116, 105, 110, 103, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 78, 111, 110, 101,
  34, 44, 34, 76, 111, 119, 34, 44, 34, 78, 111, 114, 109, 97, 108, 34,
  44, 34, 72, 105, 103, 104, 34, 44, 34, 85, 108, 116, 114, 97, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 48, 44, 34, 76, 105, 110, 101, 97, 114, 34, 44, 34, 66, 105, 99,
  117, 98, 105, 99, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32,
  60, 105, 62, 71, 97, 114, 97, 103, 101, 99, 111, 100, 101, 114, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51,
  47, 49, 50, 47, 49, 49, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 92, 110, 60, 115,
  109, 97, 108, 108, 62, 60, 98, 62, 60, 117, 62, 78, 111, 116, 101, 115,
  60, 47, 117, 62, 60, 47, 98, 62, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  42, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110, 115, 32, 97, 114, 101,
  32, 110, 111, 116, 32, 97, 108, 116, 101, 114, 101, 100, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 42, 32, 81, 117, 97, 108, 105, 116, 121, 32, 115, 101,
  116, 116, 105, 110, 103, 115, 32, 97, 102, 102, 101, 99, 116, 32, 115, 112,
  101, 101, 100, 33, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 84, 104, 101, 32,
  112, 114, 101, 118, 105, 101, 119, 32, 105, 115, 32, 97, 32, 114, 111, 117,
  103, 104, 32, 103, 117, 105, 100, 101, 32, 111, 110, 108, 121, 46, 32, 32,
  73, 109, 97, 103, 101, 115, 32, 119, 105, 116, 104, 32, 115, 105, 109, 112,
  108, 101, 32, 101, 100, 103, 101, 115, 32, 116, 101, 110, 100, 32, 116, 111,
  32, 119, 111, 114, 107, 32, 98, 101, 115, 116, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 82, 101, 115, 117, 108, 116, 115, 32, 99, 97, 110, 32, 98,
  101, 32, 105, 109, 112, 114, 111, 118, 101, 100, 32, 98, 121, 32, 115, 101,
  108, 101, 99, 116, 105, 110, 103, 32, 97, 32, 104, 105, 103, 104, 101, 114,
  32, 105, 110, 112, 97, 105, 110, 116, 105, 110, 103, 32, 113, 117, 97, 108,
  105, 116, 121, 44, 32, 98, 117, 116, 32, 112, 114, 111, 99, 101, 115, 115,
  105, 110, 103, 32, 119, 105, 108, 108, 32, 116, 97, 107, 101, 32, 108, 111,
  110, 103, 101, 114, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 66, 105, 99,
  117, 98, 105, 99, 32, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105,
  111, 110, 32, 105, 110, 99, 114, 101, 97, 115, 101, 115, 32, 113, 117, 97,
  108, 105, 116, 121, 32, 98, 117, 116, 32, 105, 110, 102, 108, 117, 101, 110,
  99, 101, 115, 32, 101, 100, 103, 101, 115, 32, 100, 117, 101, 32, 116, 111,
  32, 114, 101, 100, 117, 99, 101, 100, 32, 117, 115, 97, 98, 108, 101, 32,
  97, 114, 101, 97, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  103, 99, 100, 95, 115, 114, 111, 116, 97, 116, 101, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 49, 61, 48, 125, 44, 36, 123, 50, 61, 53,
  48, 125, 44, 36, 123, 51, 61, 53, 48, 125, 44, 36, 123, 52, 61, 49,
  125, 44, 36, 123, 53, 61, 48, 125, 10, 45, 105, 102, 32, 123, 64, 46,
  62, 61, 49, 53, 56, 49, 125, 32, 105, 110, 112, 97, 105, 110, 116, 61,
  105, 110, 112, 97, 105, 110, 116, 32, 45, 101, 108, 115, 101, 32, 105, 110,
  112, 97, 105, 110, 116, 61, 114, 101, 112, 97, 105, 114, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 43, 91, 48, 93, 32, 49, 10, 45, 114,
  111, 116, 97, 116, 101, 91, 48, 93, 32, 36, 49, 44, 123, 36, 53, 43,
  49, 125, 44, 123, 36, 52, 61, 61, 48, 125, 44, 36, 50, 37, 44, 36,
  51, 37, 44, 49, 10, 45, 45, 101, 113, 91, 48, 93, 32, 48, 32, 45,
  100, 105, 108, 97, 116, 101, 91, 49, 93, 32, 123, 40, 36, 53, 43, 49,
  41, 42, 52, 125, 32, 45, 45, 97, 114, 101, 97, 91, 49, 93, 32, 48,
  32, 45, 42, 91, 45, 49, 93, 32, 91, 49, 93, 10, 112, 115, 61, 123,
  109, 97, 120, 40, 114, 111, 117, 110, 100, 40, 105, 77, 94, 48, 46, 53,
  47, 54, 41, 44, 52, 41, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 110, 91, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 36, 105, 110,
  112, 97, 105, 110, 116, 91, 48, 93, 32, 91, 49, 93, 44, 36, 112, 115,
  44, 123, 36, 112, 115, 42, 54, 125, 44, 123, 57, 45, 36, 52, 42, 50,
  125, 44, 36, 112, 115, 44, 48, 44, 48, 46, 48, 56, 44, 49, 48, 44,
  49, 10, 45, 114, 109, 91, 49, 93, 32, 45, 45, 101, 113, 91, 48, 93,
  32, 48, 32, 45, 105, 110, 112, 97, 105, 110, 116, 91, 48, 93, 32, 91,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 45, 91, 48,
  93, 32, 49, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32,
  83, 112, 108, 105, 116, 32, 111, 98, 106, 101, 99, 116, 115, 32, 58, 32,
  103, 99, 100, 95, 115, 112, 108, 105, 116, 111, 98, 106, 44, 32, 103, 99,
  100, 95, 115, 112, 108, 105, 116, 111, 98, 106, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 117, 62, 69, 120, 116, 114, 97, 99, 116, 32, 111,
  98, 106, 101, 99, 116, 115, 32, 102, 114, 111, 109, 32, 97, 110, 32, 105,
  109, 97, 103, 101, 32, 116, 111, 32, 97, 32, 110, 101, 119, 32, 108, 97,
  121, 101, 114, 60, 47, 117, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 49, 46, 32, 67, 114, 101, 97, 116, 101,
  32, 97, 32, 110, 101, 119, 32, 116, 114, 97, 110, 115, 112, 97, 114, 101,
  110, 116, 32, 108, 97, 121, 101, 114, 44, 32, 109, 97, 114, 107, 32, 98,
  97, 99, 107, 103, 114, 111, 117, 110, 100, 32, 114, 101, 100, 32, 97, 110,
  100, 32, 111, 98, 106, 101, 99, 116, 115, 32, 103, 114, 101, 101, 110, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 50, 46, 32, 83, 101, 116, 32, 73, 110,
  112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 32, 116, 111, 32, 60, 98,
  62, 65, 99, 116, 105, 118, 101, 32, 38, 97, 109, 112, 59, 32, 98, 101,
  108, 111, 119, 60, 47, 98, 62, 44, 32, 111, 98, 106, 101, 99, 116, 115,
  32, 119, 105, 108, 108, 32, 98, 101, 32, 115, 112, 108, 105, 116, 32, 116,
  111, 32, 116, 119, 111, 32, 108, 97, 121, 101, 114, 115, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 92, 110, 60,
  105, 62, 69, 100, 103, 101, 32, 68, 101, 116, 101, 99, 116, 105, 111, 110,
  32, 79, 112, 116, 105, 111, 110, 115, 60, 47, 105, 62, 34, 41, 44, 32,
  115, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 108, 112, 104, 97,
  32, 109, 105, 110, 32, 61, 32, 105, 110, 116, 40, 53, 48, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100,
  103, 101, 32, 102, 108, 111, 119, 32, 61, 32, 105, 110, 116, 40, 51, 44,
  48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77,
  101, 100, 105, 97, 110, 32, 61, 32, 105, 110, 116, 40, 51, 44, 48, 44,
  55, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 92, 110, 60, 105, 62, 79, 117,
  116, 112, 117, 116, 32, 79, 112, 116, 105, 111, 110, 115, 60, 47, 105, 62,
  34, 41, 44, 32, 115, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  119, 97, 112, 32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114,
  111, 119, 32, 97, 108, 112, 104, 97, 32, 61, 32, 105, 110, 116, 40, 48,
  44, 45, 50, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 66, 108, 117, 114, 32, 97, 108, 112, 104, 97, 32, 61, 32, 105,
  110, 116, 40, 48, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 73, 110, 112, 97, 105, 110, 116, 105, 110, 103, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 79, 102, 102, 34, 44,
  34, 76, 111, 119, 34, 44, 34, 78, 111, 114, 109, 97, 108, 34, 44, 34,
  72, 105, 103, 104, 34, 44, 34, 85, 108, 116, 114, 97, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 98, 62, 78, 111, 116, 101, 32,
  58, 60, 47, 98, 62, 32, 84, 104, 105, 115, 32, 102, 105, 108, 116, 101,
  114, 32, 110, 101, 101, 100, 115, 32, 116, 119, 111, 32, 108, 97, 121, 101,
  114, 115, 32, 116, 111, 32, 119, 111, 114, 107, 32, 112, 114, 111, 112, 101,
  114, 108, 121, 46, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62,
  71, 97, 114, 97, 103, 101, 99, 111, 100, 101, 114, 60, 47, 105, 62, 46,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 49, 50, 47, 49, 49, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103,
  99, 100, 95, 115, 112, 108, 105, 116, 111, 98, 106, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 49, 61, 53, 48, 125, 44, 36, 123, 50, 61,
  51, 125, 44, 36, 123, 51, 61, 51, 125, 44, 36, 123, 52, 61, 48, 125,
  44, 36, 123, 53, 61, 48, 125, 44, 36, 123, 54, 61, 48, 125, 44, 36,
  123, 55, 61, 48, 125, 10, 45, 105, 102, 32, 123, 64, 46, 62, 61, 49,
  53, 56, 49, 125, 32, 105, 110, 112, 97, 105, 110, 116, 61, 105, 110, 112,
  97, 105, 110, 116, 32, 45, 101, 108, 115, 101, 32, 105, 110, 112, 97, 105,
  110, 116, 61, 114, 101, 112, 97, 105, 114, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35,
  47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49,
  125, 93, 10, 45, 116, 111, 95, 114, 103, 98, 97, 32, 91, 45, 49, 93,
  10, 45, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 49, 93, 32, 49,
  48, 48, 37, 32, 45, 103, 101, 91, 45, 49, 93, 32, 36, 49, 37, 32,
  45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 49, 93, 32, 45, 42,
  91, 49, 44, 45, 49, 93, 10, 45, 115, 112, 108, 105, 116, 95, 111, 112,
  97, 99, 105, 116, 121, 91, 48, 93, 32, 45, 110, 101, 113, 91, 49, 93,
  32, 48, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 48, 93, 32,
  48, 44, 49, 32, 45, 43, 91, 48, 93, 32, 49, 32, 45, 42, 91, 48,
  44, 49, 93, 10, 45, 109, 101, 97, 110, 99, 117, 114, 118, 97, 116, 117,
  114, 101, 95, 102, 108, 111, 119, 91, 49, 93, 32, 36, 50, 32, 45, 109,
  101, 100, 105, 97, 110, 91, 49, 93, 32, 36, 51, 10, 45, 103, 114, 97,
  100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 91, 49, 93, 32, 45, 42,
  91, 49, 93, 32, 45, 49, 32, 45, 119, 97, 116, 101, 114, 115, 104, 101,
  100, 91, 48, 93, 32, 91, 49, 93, 32, 45, 45, 91, 48, 93, 32, 49,
  10, 45, 114, 109, 91, 49, 93, 32, 45, 115, 91, 48, 93, 32, 99, 32,
  45, 110, 91, 48, 44, 49, 93, 32, 48, 44, 49, 10, 45, 105, 102, 32,
  123, 36, 52, 125, 32, 45, 114, 118, 91, 48, 44, 49, 93, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 53, 62, 48, 125, 32,
  45, 100, 105, 108, 97, 116, 101, 91, 49, 93, 32, 36, 53, 32, 45, 101,
  108, 105, 102, 32, 123, 36, 53, 60, 48, 125, 32, 45, 101, 114, 111, 100,
  101, 91, 49, 93, 32, 123, 97, 98, 115, 40, 36, 53, 41, 125, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 54, 32, 45, 98, 91,
  49, 93, 32, 36, 54, 44, 49, 44, 49, 32, 45, 99, 91, 49, 93, 32,
  48, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 42, 91, 50,
  93, 32, 91, 48, 93, 32, 45, 114, 109, 91, 48, 93, 10, 45, 105, 102,
  32, 123, 36, 55, 62, 48, 125, 10, 45, 108, 101, 91, 48, 93, 32, 56,
  48, 37, 32, 45, 45, 97, 114, 101, 97, 91, 48, 93, 32, 48, 32, 45,
  42, 91, 45, 49, 93, 32, 91, 48, 93, 10, 112, 115, 61, 123, 109, 97,
  120, 40, 114, 111, 117, 110, 100, 40, 105, 77, 94, 48, 46, 53, 47, 54,
  41, 44, 52, 41, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 110,
  91, 48, 93, 32, 48, 44, 50, 53, 53, 10, 45, 36, 105, 110, 112, 97,
  105, 110, 116, 91, 49, 93, 32, 91, 48, 93, 44, 36, 112, 115, 44, 123,
  36, 112, 115, 42, 54, 125, 44, 123, 57, 45, 36, 55, 42, 50, 125, 44,
  36, 112, 115, 44, 48, 44, 48, 46, 48, 56, 44, 49, 48, 44, 49, 10,
  45, 101, 108, 115, 101, 32, 45, 42, 91, 49, 93, 32, 91, 48, 93, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 48, 93, 10, 45, 105,
  102, 32, 123, 115, 61, 61, 50, 124, 124, 115, 61, 61, 52, 125, 32, 45,
  115, 104, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 109, 97,
  120, 91, 45, 50, 93, 32, 49, 32, 45, 109, 97, 120, 91, 45, 49, 93,
  32, 49, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 35, 64, 103, 105, 109, 112, 32, 83, 116, 101, 114, 101, 111, 32, 118,
  105, 100, 101, 111, 32, 58, 32, 103, 99, 100, 95, 115, 116, 101, 114, 101,
  111, 95, 118, 105, 100, 44, 32, 103, 99, 100, 95, 115, 116, 101, 114, 101,
  111, 95, 118, 105, 100, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 117, 62, 67, 111, 110, 118, 101, 114,
  116, 32, 97, 32, 115, 101, 114, 105, 101, 115, 32, 111, 102, 32, 105, 109,
  97, 103, 101, 32, 102, 105, 108, 101, 115, 32, 116, 111, 32, 51, 68, 60,
  47, 117, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 92, 110, 60, 105,
  62, 70, 105, 108, 101, 32, 79, 112, 116, 105, 111, 110, 115, 60, 47, 105,
  62, 34, 41, 44, 32, 115, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 116, 97, 114, 116, 32, 105, 109, 97, 103, 101, 32, 61, 32, 102, 105,
  108, 101, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 110,
  100, 32, 105, 109, 97, 103, 101, 32, 61, 32, 102, 105, 108, 101, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116,
  32, 102, 111, 108, 100, 101, 114, 32, 61, 32, 95, 102, 111, 108, 100, 101,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 92, 110, 60, 105, 62, 51,
  68, 32, 79, 112, 116, 105, 111, 110, 115, 60, 47, 105, 62, 34, 41, 44,
  32, 115, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 51, 100, 32, 105,
  109, 97, 103, 101, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 65, 110, 97, 103, 108, 121, 112, 104, 58, 32, 82, 101,
  100, 47, 67, 121, 97, 110, 34, 44, 34, 83, 105, 100, 101, 32, 98, 121,
  32, 83, 105, 100, 101, 34, 44, 34, 68, 101, 112, 116, 104, 32, 77, 97,
  112, 34, 44, 34, 73, 110, 118, 101, 114, 115, 101, 32, 68, 101, 112, 116,
  104, 32, 77, 97, 112, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 66, 97, 108, 97, 110, 99, 101, 32, 99, 111, 108, 111, 114, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 78, 111, 110, 101, 34,
  44, 34, 72, 97, 108, 102, 34, 44, 34, 70, 117, 108, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 112, 116, 104, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 46, 50, 44, 48, 44, 50, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 92, 110, 60, 105, 62, 68, 101, 112, 116, 104,
  32, 77, 97, 112, 32, 79, 112, 116, 105, 111, 110, 115, 60, 47, 105, 62,
  34, 41, 44, 32, 115, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66,
  108, 117, 114, 32, 112, 101, 114, 99, 101, 110, 116, 97, 103, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 50, 53, 44, 48, 44, 50, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 98, 106, 101, 99, 116,
  32, 114, 97, 116, 105, 111, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50,
  44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79,
  98, 106, 101, 99, 116, 32, 116, 111, 108, 101, 114, 97, 110, 99, 101, 32,
  61, 32, 105, 110, 116, 40, 52, 44, 48, 44, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 101, 115, 112, 101, 99, 107, 108, 101, 32,
  61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  92, 110, 60, 105, 62, 86, 105, 100, 101, 111, 32, 79, 112, 116, 105, 111,
  110, 115, 60, 47, 105, 62, 34, 41, 44, 32, 115, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 70, 114, 97, 109, 101, 32, 98, 117, 102, 102, 101,
  114, 32, 61, 32, 95, 105, 110, 116, 40, 53, 44, 49, 44, 49, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 101, 110, 101, 32,
  100, 101, 116, 101, 99, 116, 105, 111, 110, 32, 61, 32, 98, 111, 111, 108,
  40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62,
  71, 97, 114, 97, 103, 101, 99, 111, 100, 101, 114, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 50,
  47, 50, 52, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 103, 99, 100, 95, 115, 116, 101, 114, 101, 111, 95, 118, 105,
  100, 32, 58, 10, 49, 32, 45, 108, 91, 45, 49, 93, 10, 45, 105, 32,
  34, 36, 49, 34, 32, 115, 116, 95, 102, 111, 108, 100, 101, 114, 61, 64,
  123, 45, 49, 44, 102, 125, 32, 115, 116, 95, 102, 105, 108, 101, 61, 64,
  123, 45, 49, 44, 98, 125, 32, 115, 116, 95, 101, 120, 116, 61, 64, 123,
  45, 49, 44, 120, 125, 32, 40, 123, 39, 36, 115, 116, 95, 102, 105, 108,
  101, 39, 125, 41, 32, 99, 112, 120, 61, 64, 123, 45, 49, 44, 119, 125,
  10, 45, 100, 111, 32, 99, 112, 120, 61, 123, 36, 99, 112, 120, 45, 49,
  125, 32, 100, 103, 116, 61, 123, 105, 40, 36, 99, 112, 120, 41, 125, 32,
  105, 115, 110, 117, 109, 61, 123, 40, 36, 100, 103, 116, 62, 52, 55, 41,
  38, 38, 40, 36, 100, 103, 116, 60, 53, 56, 41, 125, 32, 45, 119, 104,
  105, 108, 101, 32, 123, 40, 36, 105, 115, 110, 117, 109, 41, 38, 38, 40,
  36, 99, 112, 120, 62, 48, 41, 125, 10, 45, 105, 102, 32, 123, 36, 99,
  112, 120, 62, 48, 125, 32, 45, 45, 122, 91, 45, 49, 93, 32, 48, 44,
  36, 99, 112, 120, 32, 102, 115, 110, 97, 109, 101, 61, 64, 123, 45, 49,
  44, 116, 125, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 108, 115,
  101, 32, 102, 115, 110, 97, 109, 101, 61, 34, 34, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 122, 91, 45, 49, 93, 32, 123, 36, 99, 112, 120, 43,
  123, 33, 36, 105, 115, 110, 117, 109, 125, 125, 44, 49, 48, 48, 37, 32,
  100, 103, 116, 115, 61, 64, 123, 45, 49, 44, 119, 125, 32, 102, 115, 110,
  117, 109, 61, 123, 64, 123, 45, 49, 44, 116, 125, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 49, 32, 45, 110, 109, 91, 45, 49, 93, 32, 34,
  36, 50, 34, 32, 101, 110, 95, 102, 105, 108, 101, 61, 64, 123, 45, 49,
  44, 98, 125, 32, 40, 123, 39, 36, 101, 110, 95, 102, 105, 108, 101, 39,
  125, 41, 32, 99, 112, 120, 61, 64, 123, 45, 49, 44, 119, 125, 10, 45,
  100, 111, 32, 99, 112, 120, 61, 123, 36, 99, 112, 120, 45, 49, 125, 32,
  100, 103, 116, 61, 123, 105, 40, 36, 99, 112, 120, 41, 125, 32, 105, 115,
  110, 117, 109, 61, 123, 40, 36, 100, 103, 116, 62, 52, 55, 41, 38, 38,
  40, 36, 100, 103, 116, 60, 53, 56, 41, 125, 32, 45, 119, 104, 105, 108,
  101, 32, 123, 40, 36, 105, 115, 110, 117, 109, 41, 38, 38, 40, 36, 99,
  112, 120, 62, 48, 41, 125, 10, 45, 122, 91, 45, 49, 93, 32, 123, 36,
  99, 112, 120, 43, 123, 33, 36, 105, 115, 110, 117, 109, 125, 125, 44, 49,
  48, 48, 37, 32, 102, 101, 110, 117, 109, 61, 123, 64, 123, 45, 49, 44,
  116, 125, 125, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49, 93, 10, 98,
  117, 102, 115, 122, 61, 36, 49, 49, 32, 116, 116, 108, 98, 117, 102, 61,
  123, 36, 98, 117, 102, 115, 122, 42, 50, 125, 32, 116, 116, 108, 105, 109,
  103, 61, 123, 36, 102, 101, 110, 117, 109, 45, 36, 102, 115, 110, 117, 109,
  43, 49, 125, 10, 115, 99, 101, 110, 101, 61, 49, 32, 115, 99, 102, 114,
  97, 109, 101, 61, 48, 32, 111, 118, 61, 64, 123, 45, 49, 44, 118, 125,
  32, 111, 97, 61, 64, 123, 45, 49, 44, 97, 125, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 36, 116, 116, 108, 105, 109, 103, 125, 10, 45, 105,
  102, 32, 123, 36, 115, 99, 101, 110, 101, 34, 32, 38, 38, 32, 34, 36,
  62, 61, 61, 36, 115, 99, 102, 114, 97, 109, 101, 125, 10, 45, 107, 91,
  45, 49, 93, 32, 115, 99, 101, 110, 101, 61, 48, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 109, 105, 110, 40, 36, 116, 116, 108, 98, 117, 102,
  44, 36, 116, 116, 108, 105, 109, 103, 45, 36, 115, 99, 102, 114, 97, 109,
  101, 45, 49, 41, 125, 10, 99, 117, 114, 110, 117, 109, 61, 123, 36, 102,
  115, 110, 117, 109, 43, 36, 115, 99, 102, 114, 97, 109, 101, 43, 36, 62,
  43, 49, 125, 32, 99, 117, 114, 110, 117, 109, 61, 64, 123, 45, 103, 99,
  100, 95, 97, 100, 100, 48, 92, 32, 36, 99, 117, 114, 110, 117, 109, 44,
  36, 100, 103, 116, 115, 125, 10, 45, 105, 32, 34, 34, 36, 123, 115, 116,
  95, 102, 111, 108, 100, 101, 114, 125, 36, 123, 102, 115, 110, 97, 109, 101,
  125, 36, 123, 99, 117, 114, 110, 117, 109, 125, 46, 36, 123, 115, 116, 95,
  101, 120, 116, 125, 34, 34, 10, 118, 114, 61, 64, 123, 45, 49, 44, 118,
  125, 32, 97, 118, 61, 64, 123, 45, 49, 44, 97, 125, 32, 112, 118, 114,
  61, 123, 97, 98, 115, 40, 36, 118, 114, 45, 36, 111, 118, 41, 47, 36,
  118, 114, 125, 32, 112, 97, 118, 61, 123, 97, 98, 115, 40, 36, 97, 118,
  45, 36, 111, 97, 41, 47, 36, 97, 118, 125, 10, 111, 118, 61, 36, 118,
  114, 32, 111, 97, 61, 36, 97, 118, 10, 45, 105, 102, 32, 123, 36, 49,
  50, 38, 38, 40, 36, 112, 118, 114, 62, 48, 46, 49, 34, 32, 124, 124,
  32, 34, 36, 112, 97, 118, 62, 48, 46, 49, 41, 125, 32, 115, 99, 101,
  110, 101, 61, 49, 32, 115, 99, 102, 114, 97, 109, 101, 61, 123, 36, 115,
  99, 102, 114, 97, 109, 101, 43, 36, 62, 43, 49, 125, 32, 45, 98, 114,
  101, 97, 107, 10, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101,
  10, 45, 45, 108, 91, 48, 45, 45, 123, 49, 43, 36, 115, 99, 101, 110,
  101, 125, 93, 32, 45, 97, 112, 112, 108, 121, 95, 112, 97, 114, 97, 108,
  108, 101, 108, 32, 34, 45, 103, 99, 100, 95, 100, 101, 112, 116, 104, 32,
  36, 55, 44, 36, 56, 44, 36, 57, 44, 36, 49, 48, 34, 32, 45, 45,
  97, 100, 100, 91, 48, 45, 45, 49, 93, 32, 45, 97, 91, 48, 45, 45,
  50, 93, 32, 122, 32, 45, 101, 110, 100, 108, 10, 45, 109, 118, 91, 45,
  49, 93, 32, 48, 32, 45, 109, 118, 91, 45, 49, 93, 32, 49, 32, 45,
  97, 91, 50, 45, 45, 123, 49, 43, 36, 115, 99, 101, 110, 101, 125, 93,
  32, 122, 10, 45, 101, 110, 100, 105, 102, 10, 45, 45, 115, 108, 105, 99,
  101, 115, 91, 50, 93, 32, 48, 32, 45, 45, 100, 105, 118, 91, 48, 93,
  32, 64, 123, 49, 44, 100, 125, 32, 45, 103, 99, 100, 95, 115, 116, 101,
  114, 101, 111, 91, 45, 50, 44, 45, 49, 93, 32, 36, 52, 44, 36, 53,
  44, 36, 54, 37, 10, 99, 117, 114, 110, 117, 109, 61, 123, 36, 102, 115,
  110, 117, 109, 43, 36, 62, 125, 32, 99, 117, 114, 110, 117, 109, 61, 64,
  123, 45, 103, 99, 100, 95, 97, 100, 100, 48, 92, 32, 36, 99, 117, 114,
  110, 117, 109, 44, 36, 100, 103, 116, 115, 125, 10, 45, 105, 102, 32, 64,
  123, 45, 105, 115, 95, 119, 105, 110, 100, 111, 119, 115, 125, 32, 45, 111,
  91, 45, 49, 93, 32, 34, 36, 51, 34, 34, 34, 123, 96, 57, 50, 96,
  125, 36, 123, 102, 115, 110, 97, 109, 101, 125, 36, 123, 99, 117, 114, 110,
  117, 109, 125, 46, 36, 123, 115, 116, 95, 101, 120, 116, 125, 34, 34, 10,
  45, 101, 108, 115, 101, 32, 45, 111, 91, 45, 49, 93, 32, 34, 36, 51,
  34, 34, 34, 123, 96, 52, 55, 96, 125, 36, 123, 102, 115, 110, 97, 109,
  101, 125, 36, 123, 99, 117, 114, 110, 117, 109, 125, 46, 36, 123, 115, 116,
  95, 101, 120, 116, 125, 34, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  112, 114, 111, 103, 114, 101, 115, 115, 32, 123, 40, 36, 62, 43, 49, 41,
  47, 36, 116, 116, 108, 105, 109, 103, 42, 49, 48, 48, 125, 10, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 115, 108, 105, 99, 101, 115, 91, 50, 93,
  32, 49, 44, 49, 48, 48, 37, 10, 45, 105, 102, 32, 123, 33, 36, 115,
  99, 101, 110, 101, 34, 32, 38, 38, 32, 34, 40, 36, 62, 62, 61, 40,
  36, 115, 99, 102, 114, 97, 109, 101, 43, 36, 98, 117, 102, 115, 122, 41,
  41, 34, 32, 38, 38, 32, 34, 40, 36, 62, 60, 40, 36, 116, 116, 108,
  105, 109, 103, 45, 36, 98, 117, 102, 115, 122, 45, 49, 41, 41, 125, 10,
  99, 117, 114, 110, 117, 109, 61, 123, 36, 102, 115, 110, 117, 109, 43, 36,
  62, 43, 36, 98, 117, 102, 115, 122, 43, 49, 125, 32, 99, 117, 114, 110,
  117, 109, 61, 64, 123, 45, 103, 99, 100, 95, 97, 100, 100, 48, 92, 32,
  36, 99, 117, 114, 110, 117, 109, 44, 36, 100, 103, 116, 115, 125, 10, 45,
  105, 32, 34, 34, 36, 123, 115, 116, 95, 102, 111, 108, 100, 101, 114, 125,
  36, 123, 102, 115, 110, 97, 109, 101, 125, 36, 123, 99, 117, 114, 110, 117,
  109, 125, 46, 36, 123, 115, 116, 95, 101, 120, 116, 125, 34, 34, 10, 118,
  114, 61, 64, 123, 45, 49, 44, 118, 125, 32, 97, 118, 61, 64, 123, 45,
  49, 44, 97, 125, 32, 112, 118, 114, 61, 123, 97, 98, 115, 40, 36, 118,
  114, 45, 36, 111, 118, 41, 47, 36, 118, 114, 125, 32, 112, 97, 118, 61,
  123, 97, 98, 115, 40, 36, 97, 118, 45, 36, 111, 97, 41, 47, 36, 97,
  118, 125, 10, 111, 118, 61, 36, 118, 114, 32, 111, 97, 61, 36, 97, 118,
  10, 45, 105, 102, 32, 123, 36, 49, 50, 38, 38, 40, 36, 112, 118, 114,
  62, 48, 46, 49, 34, 32, 124, 124, 32, 34, 36, 112, 97, 118, 62, 48,
  46, 49, 41, 125, 32, 115, 99, 101, 110, 101, 61, 49, 32, 115, 99, 102,
  114, 97, 109, 101, 61, 123, 36, 62, 43, 36, 98, 117, 102, 115, 122, 43,
  49, 125, 10, 45, 101, 108, 115, 101, 10, 45, 45, 103, 99, 100, 95, 100,
  101, 112, 116, 104, 91, 45, 49, 93, 32, 36, 55, 44, 36, 56, 44, 36,
  57, 44, 36, 49, 48, 32, 45, 97, 100, 100, 91, 48, 93, 32, 91, 45,
  49, 93, 32, 45, 97, 91, 49, 44, 45, 49, 93, 32, 122, 32, 45, 97,
  91, 50, 44, 45, 49, 93, 32, 122, 10, 45, 45, 115, 108, 105, 99, 101,
  115, 91, 49, 93, 32, 48, 32, 45, 115, 117, 98, 91, 48, 44, 45, 49,
  93, 32, 45, 115, 108, 105, 99, 101, 115, 91, 49, 93, 32, 49, 44, 49,
  48, 48, 37, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109, 10, 45, 101, 110, 100,
  108, 10, 103, 99, 100, 95, 115, 116, 101, 114, 101, 111, 95, 118, 105, 100,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 49, 61, 34, 34, 125, 44, 36, 123, 50, 61, 34, 34, 125,
  10, 49, 48, 48, 44, 49, 48, 48, 44, 49, 44, 51, 44, 48, 32, 45,
  116, 101, 120, 116, 91, 45, 49, 93, 32, 34, 83, 101, 108, 101, 99, 116,
  92, 110, 83, 116, 97, 114, 116, 92, 110, 73, 109, 97, 103, 101, 32, 32,
  32, 34, 44, 48, 44, 48, 44, 51, 50, 44, 49, 44, 50, 53, 53, 10,
  49, 48, 48, 44, 49, 48, 48, 44, 49, 44, 51, 44, 48, 32, 45, 116,
  101, 120, 116, 91, 45, 49, 93, 32, 34, 83, 101, 108, 101, 99, 116, 92,
  110, 69, 110, 100, 92, 110, 73, 109, 97, 103, 101, 32, 32, 32, 34, 44,
  48, 44, 48, 44, 51, 50, 44, 49, 44, 50, 53, 53, 32, 45, 107, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 105, 102, 32, 34, 36, 49, 34, 32,
  45, 105, 32, 34, 36, 49, 34, 32, 45, 114, 118, 91, 48, 44, 45, 49,
  93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 34, 36, 50, 34, 32, 45, 105, 32, 34, 36, 50,
  34, 32, 45, 114, 118, 91, 49, 44, 45, 49, 93, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 97, 91, 48, 44,
  49, 93, 32, 120, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 32,
  45, 45, 103, 99, 100, 95, 100, 101, 112, 116, 104, 91, 45, 49, 93, 32,
  36, 55, 44, 36, 56, 44, 36, 57, 44, 36, 49, 48, 32, 45, 103, 99,
  100, 95, 115, 116, 101, 114, 101, 111, 32, 36, 52, 44, 36, 53, 44, 36,
  54, 37, 10, 103, 99, 100, 95, 97, 100, 100, 48, 32, 58, 10, 40, 123,
  39, 36, 49, 39, 125, 41, 32, 45, 105, 102, 32, 123, 64, 123, 45, 49,
  44, 119, 125, 60, 36, 50, 125, 32, 123, 36, 50, 45, 64, 123, 45, 49,
  44, 119, 125, 125, 44, 49, 44, 49, 44, 49, 44, 52, 56, 32, 45, 114,
  118, 91, 45, 50, 44, 45, 49, 93, 32, 45, 97, 91, 45, 50, 44, 45,
  49, 93, 32, 120, 32, 45, 101, 110, 100, 105, 102, 32, 45, 117, 32, 64,
  123, 45, 49, 44, 116, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 35,
  64, 103, 105, 109, 112, 32, 87, 97, 114, 112, 32, 109, 97, 112, 32, 58,
  32, 103, 99, 100, 95, 119, 97, 114, 112, 109, 97, 112, 44, 32, 103, 99,
  100, 95, 119, 97, 114, 112, 109, 97, 112, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 105, 62, 87, 97, 114, 112, 32, 97, 110, 32, 105, 109,
  97, 103, 101, 32, 117, 115, 105, 110, 103, 32, 97, 110, 111, 116, 104, 101,
  114, 32, 97, 115, 32, 97, 32, 115, 117, 114, 102, 97, 99, 101, 60, 47,
  105, 62, 34, 41, 44, 32, 115, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 68, 101, 112, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53,
  44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  68, 101, 116, 97, 105, 108, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 66, 108, 101, 110, 100, 32, 109, 111, 100, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 87, 97, 114, 112, 34, 44, 34,
  77, 117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 83, 111, 102, 116, 108,
  105, 103, 104, 116, 34, 44, 34, 78, 111, 110, 101, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 119, 97, 112, 32, 108, 97, 121, 101,
  114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 32, 58, 32, 60, 105, 62, 71, 97, 114, 97, 103, 101, 99,
  111, 100, 101, 114, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60,
  105, 62, 50, 48, 49, 51, 47, 48, 50, 47, 48, 57, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 92, 110, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 60, 117,
  62, 78, 111, 116, 101, 115, 60, 47, 117, 62, 60, 47, 98, 62, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 84, 104, 101, 32, 116, 111, 112, 32, 108, 97,
  121, 101, 114, 32, 119, 105, 108, 108, 32, 98, 101, 32, 119, 97, 114, 112,
  101, 100, 32, 117, 115, 105, 110, 103, 32, 116, 104, 101, 32, 98, 111, 116,
  116, 111, 109, 32, 108, 97, 121, 101, 114, 32, 97, 115, 32, 97, 32, 115,
  117, 114, 102, 97, 99, 101, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 92,
  110, 68, 101, 112, 116, 104, 58, 32, 83, 101, 116, 32, 116, 104, 101, 32,
  97, 112, 112, 97, 114, 101, 110, 116, 32, 100, 101, 112, 116, 104, 32, 111,
  102, 32, 116, 104, 101, 32, 115, 117, 114, 102, 97, 99, 101, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 68, 101, 116, 97, 105, 108, 58, 32, 80, 101,
  114, 102, 111, 114, 109, 32, 115, 101, 99, 111, 110, 100, 32, 119, 97, 114,
  112, 32, 119, 105, 116, 104, 32, 110, 111, 32, 115, 109, 111, 111, 116, 104,
  32, 102, 111, 114, 32, 102, 105, 110, 101, 32, 100, 101, 116, 97, 105, 108,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 83, 109, 111, 111, 116, 104, 58,
  32, 83, 101, 116, 32, 108, 111, 119, 32, 102, 111, 114, 32, 101, 109, 98,
  111, 115, 115, 44, 32, 104, 105, 103, 104, 32, 116, 111, 32, 119, 114, 97,
  112, 32, 97, 114, 111, 117, 110, 100, 32, 108, 97, 114, 103, 101, 32, 111,
  98, 106, 101, 99, 116, 115, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 99, 100, 95, 119, 97, 114, 112, 109, 97, 112, 32, 58, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 53, 125, 44, 36, 123, 50,
  61, 48, 125, 44, 36, 123, 51, 61, 48, 125, 44, 36, 123, 52, 61, 48,
  125, 44, 36, 123, 53, 61, 48, 125, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91,
  36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 45, 105, 102, 32, 36,
  53, 32, 45, 114, 118, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 52, 61, 61, 51, 125, 32, 98, 109, 61, 48, 32, 45, 105,
  91, 48, 93, 32, 91, 45, 49, 93, 32, 45, 101, 108, 115, 101, 32, 98,
  109, 61, 36, 52, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  36, 50, 32, 45, 45, 103, 99, 100, 95, 119, 97, 114, 112, 91, 45, 50,
  44, 45, 49, 93, 32, 36, 49, 44, 36, 51, 32, 45, 114, 109, 91, 45,
  51, 93, 32, 45, 114, 118, 91, 45, 50, 44, 45, 49, 93, 32, 45, 103,
  99, 100, 95, 119, 97, 114, 112, 91, 45, 50, 44, 45, 49, 93, 32, 36,
  50, 44, 48, 44, 36, 98, 109, 10, 45, 101, 108, 115, 101, 32, 45, 103,
  99, 100, 95, 119, 97, 114, 112, 91, 45, 50, 44, 45, 49, 93, 32, 36,
  49, 44, 36, 51, 44, 36, 98, 109, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 52, 61, 61, 51, 125, 32, 45, 114, 118, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 103, 99, 100, 95, 119, 97, 114, 112, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 49, 61, 53, 125, 44, 36, 123, 50, 61, 48,
  125, 44, 36, 123, 51, 61, 48, 125, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91,
  36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 119, 102, 97, 99, 61,
  123, 36, 49, 37, 42, 119, 125, 32, 45, 116, 111, 95, 114, 103, 98, 97,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 45, 110, 111, 114, 109, 91, 45,
  49, 93, 10, 45, 98, 108, 117, 114, 95, 120, 121, 91, 45, 49, 93, 32,
  36, 50, 37, 44, 36, 50, 37, 32, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 32, 45, 103, 91, 45, 49, 93, 32, 120, 121, 32, 45,
  97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 42, 91, 45, 49,
  93, 32, 45, 49, 32, 45, 110, 91, 45, 49, 93, 32, 45, 36, 119, 102,
  97, 99, 44, 36, 119, 102, 97, 99, 32, 45, 119, 97, 114, 112, 91, 48,
  93, 32, 91, 45, 49, 93, 44, 49, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 105, 102, 32, 123, 36, 51, 61, 61, 48, 125, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 98, 114, 101, 97, 107, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 51, 61, 61, 49, 125, 32, 45,
  98, 108, 101, 110, 100, 32, 109, 117, 108, 116, 105, 112, 108, 121, 44, 49,
  44, 49, 32, 45, 101, 108, 115, 101, 32, 45, 98, 108, 101, 110, 100, 32,
  115, 111, 102, 116, 108, 105, 103, 104, 116, 44, 49, 44, 49, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 35, 64, 103, 105, 109, 112, 32, 88, 98, 114, 50, 120, 32, 58, 32,
  103, 99, 100, 95, 120, 98, 114, 50, 120, 44, 32, 103, 99, 100, 95, 120,
  98, 114, 50, 120, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 73, 109,
  112, 108, 101, 109, 101, 110, 116, 97, 116, 105, 111, 110, 32, 111, 102, 32,
  116, 104, 101, 32, 120, 66, 82, 32, 50, 120, 32, 91, 110, 111, 98, 108,
  101, 110, 100, 93, 32, 97, 108, 103, 111, 114, 105, 116, 104, 109, 32, 98,
  121, 32, 72, 121, 108, 108, 105, 97, 110, 46, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 70, 111, 114, 32, 109, 111, 114, 101, 32, 105, 110, 102, 111,
  32, 118, 105, 115, 105, 116, 58, 32, 34, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 108, 105, 110, 107, 40, 34, 104, 116, 116, 112, 58, 47, 47,
  98, 111, 97, 114, 100, 46, 98, 121, 117, 117, 46, 111, 114, 103, 47, 118,
  105, 101, 119, 116, 111, 112, 105, 99, 46, 112, 104, 112, 63, 102, 61, 49,
  48, 38, 116, 61, 50, 50, 52, 56, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40,
  34, 104, 116, 116, 112, 58, 47, 47, 99, 111, 100, 101, 46, 103, 111, 111,
  103, 108, 101, 46, 99, 111, 109, 47, 112, 47, 50, 100, 105, 109, 97, 103,
  101, 102, 105, 108, 116, 101, 114, 47, 119, 105, 107, 105, 47, 73, 109, 97,
  103, 101, 82, 101, 115, 105, 122, 101, 114, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 32, 58, 32, 60, 105, 62, 71, 97, 114, 97, 103, 101, 99, 111,
  100, 101, 114, 60, 47, 105, 62, 46, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49,
  51, 47, 48, 53, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 68, 105, 115, 99, 108, 97, 105, 109, 101, 114, 32, 58,
  32, 84, 104, 105, 115, 32, 105, 115, 32, 97, 32, 110, 101, 97, 114, 32,
  99, 111, 109, 112, 108, 101, 116, 101, 32, 114, 101, 99, 111, 100, 101, 32,
  98, 97, 115, 101, 100, 32, 111, 110, 32, 67, 35, 32, 115, 111, 117, 114,
  99, 101, 32, 102, 114, 111, 109, 32, 73, 109, 97, 103, 101, 82, 101, 115,
  105, 122, 101, 114, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 84, 104, 101, 32,
  114, 101, 115, 117, 108, 116, 115, 32, 109, 97, 121, 32, 110, 111, 116, 32,
  102, 117, 108, 108, 121, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 32,
  116, 104, 101, 32, 111, 114, 105, 103, 105, 110, 97, 108, 32, 114, 111, 117,
  116, 105, 110, 101, 33, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  103, 99, 100, 95, 120, 98, 114, 50, 120, 32, 58, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 116,
  111, 95, 114, 103, 98, 91, 48, 93, 10, 40, 45, 49, 44, 45, 49, 59,
  48, 44, 45, 49, 59, 49, 44, 45, 49, 59, 45, 49, 44, 48, 59, 48,
  44, 48, 59, 49, 44, 48, 59, 45, 49, 44, 49, 59, 48, 44, 49, 59,
  49, 44, 49, 59, 92, 10, 45, 49, 44, 45, 50, 59, 48, 44, 45, 50,
  59, 49, 44, 45, 50, 59, 45, 50, 44, 45, 49, 59, 45, 50, 44, 48,
  59, 45, 50, 44, 49, 59, 50, 44, 45, 49, 59, 50, 44, 48, 59, 50,
  44, 49, 59, 45, 49, 44, 50, 59, 48, 44, 50, 59, 49, 44, 50, 41,
  10, 112, 97, 95, 61, 48, 32, 112, 98, 95, 61, 49, 32, 112, 99, 95,
  61, 50, 32, 32, 112, 100, 95, 61, 51, 32, 112, 101, 95, 61, 52, 32,
  112, 102, 95, 61, 53, 32, 32, 112, 103, 95, 61, 54, 32, 112, 104, 95,
  61, 55, 32, 112, 105, 95, 61, 56, 10, 97, 49, 95, 61, 57, 32, 98,
  49, 95, 61, 49, 48, 32, 99, 49, 95, 61, 49, 49, 32, 32, 97, 48,
  95, 61, 49, 50, 32, 100, 48, 95, 61, 49, 51, 32, 103, 48, 95, 61,
  49, 52, 10, 99, 52, 95, 61, 49, 53, 32, 102, 52, 95, 61, 49, 54,
  32, 105, 52, 95, 61, 49, 55, 32, 32, 103, 53, 95, 61, 49, 56, 32,
  104, 53, 95, 61, 49, 57, 32, 105, 53, 95, 61, 50, 48, 10, 101, 48,
  61, 50, 49, 32, 101, 49, 61, 50, 50, 32, 101, 50, 61, 50, 51, 32,
  101, 51, 61, 50, 52, 10, 40, 36, 112, 101, 95, 44, 36, 112, 105, 95,
  44, 36, 112, 104, 95, 44, 36, 112, 102, 95, 44, 36, 112, 103, 95, 44,
  36, 112, 99, 95, 44, 36, 112, 100, 95, 44, 36, 112, 98, 95, 44, 36,
  102, 52, 95, 44, 36, 105, 52, 95, 44, 36, 104, 53, 95, 44, 36, 105,
  53, 95, 44, 36, 101, 49, 44, 36, 101, 50, 44, 36, 101, 51, 59, 92,
  10, 36, 112, 101, 95, 44, 36, 112, 99, 95, 44, 36, 112, 102, 95, 44,
  36, 112, 98, 95, 44, 36, 112, 105, 95, 44, 36, 112, 97, 95, 44, 36,
  112, 104, 95, 44, 36, 112, 100, 95, 44, 36, 98, 49, 95, 44, 36, 99,
  49, 95, 44, 36, 102, 52, 95, 44, 36, 99, 52, 95, 44, 36, 101, 48,
  44, 36, 101, 51, 44, 36, 101, 49, 59, 92, 10, 36, 112, 101, 95, 44,
  36, 112, 97, 95, 44, 36, 112, 98, 95, 44, 36, 112, 100, 95, 44, 36,
  112, 99, 95, 44, 36, 112, 103, 95, 44, 36, 112, 102, 95, 44, 36, 112,
  104, 95, 44, 36, 100, 48, 95, 44, 36, 97, 48, 95, 44, 36, 98, 49,
  95, 44, 36, 97, 49, 95, 44, 36, 101, 50, 44, 36, 101, 49, 44, 36,
  101, 48, 59, 92, 10, 36, 112, 101, 95, 44, 36, 112, 103, 95, 44, 36,
  112, 100, 95, 44, 36, 112, 104, 95, 44, 36, 112, 97, 95, 44, 36, 112,
  105, 95, 44, 36, 112, 98, 95, 44, 36, 112, 102, 95, 44, 36, 104, 53,
  95, 44, 36, 103, 53, 95, 44, 36, 100, 48, 95, 44, 36, 103, 48, 95,
  44, 36, 101, 51, 44, 36, 101, 48, 44, 36, 101, 50, 41, 10, 45, 42,
  91, 49, 93, 32, 45, 49, 10, 45, 114, 101, 112, 101, 97, 116, 32, 50,
  49, 32, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93, 32, 64, 123, 49,
  44, 40, 48, 44, 36, 62, 41, 125, 44, 64, 123, 49, 44, 40, 49, 44,
  36, 62, 41, 125, 44, 48, 44, 48, 44, 49, 32, 45, 100, 111, 110, 101,
  10, 91, 48, 93, 32, 91, 48, 93, 32, 91, 48, 93, 32, 91, 48, 93,
  10, 45, 110, 109, 91, 48, 93, 32, 111, 114, 105, 103, 32, 45, 109, 118,
  91, 48, 93, 32, 64, 35, 32, 45, 114, 109, 91, 48, 93, 32, 45, 110,
  109, 91, 48, 93, 32, 107, 101, 114, 110, 32, 45, 109, 118, 91, 48, 93,
  32, 64, 35, 10, 45, 114, 101, 112, 101, 97, 116, 32, 52, 10, 112, 101,
  61, 64, 123, 107, 101, 114, 110, 44, 40, 48, 44, 36, 62, 41, 125, 32,
  112, 105, 61, 64, 123, 107, 101, 114, 110, 44, 40, 49, 44, 36, 62, 41,
  125, 32, 112, 104, 61, 64, 123, 107, 101, 114, 110, 44, 40, 50, 44, 36,
  62, 41, 125, 10, 112, 102, 61, 64, 123, 107, 101, 114, 110, 44, 40, 51,
  44, 36, 62, 41, 125, 32, 112, 103, 61, 64, 123, 107, 101, 114, 110, 44,
  40, 52, 44, 36, 62, 41, 125, 32, 112, 99, 61, 64, 123, 107, 101, 114,
  110, 44, 40, 53, 44, 36, 62, 41, 125, 10, 112, 100, 61, 64, 123, 107,
  101, 114, 110, 44, 40, 54, 44, 36, 62, 41, 125, 32, 112, 98, 61, 64,
  123, 107, 101, 114, 110, 44, 40, 55, 44, 36, 62, 41, 125, 32, 102, 52,
  61, 64, 123, 107, 101, 114, 110, 44, 40, 56, 44, 36, 62, 41, 125, 10,
  105, 52, 61, 64, 123, 107, 101, 114, 110, 44, 40, 57, 44, 36, 62, 41,
  125, 32, 104, 53, 61, 64, 123, 107, 101, 114, 110, 44, 40, 49, 48, 44,
  36, 62, 41, 125, 32, 105, 53, 61, 64, 123, 107, 101, 114, 110, 44, 40,
  49, 49, 44, 36, 62, 41, 125, 10, 110, 49, 61, 64, 123, 107, 101, 114,
  110, 44, 40, 49, 50, 44, 36, 62, 41, 125, 32, 110, 50, 61, 64, 123,
  107, 101, 114, 110, 44, 40, 49, 51, 44, 36, 62, 41, 125, 32, 110, 51,
  61, 64, 123, 107, 101, 114, 110, 44, 40, 49, 52, 44, 36, 62, 41, 125,
  10, 45, 45, 103, 99, 100, 95, 101, 113, 91, 36, 112, 101, 44, 36, 112,
  102, 93, 32, 45, 45, 103, 99, 100, 95, 101, 113, 91, 36, 112, 101, 44,
  36, 112, 104, 93, 32, 45, 111, 114, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 101, 113, 91, 45, 49, 93, 32, 48, 32, 45, 110, 109, 91, 45, 49,
  93, 32, 108, 118, 108, 49, 10, 45, 45, 103, 99, 100, 95, 121, 117, 118,
  91, 36, 112, 101, 44, 36, 112, 99, 93, 32, 45, 45, 103, 99, 100, 95,
  121, 117, 118, 91, 36, 112, 101, 44, 36, 112, 103, 93, 32, 45, 43, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 45, 103, 99, 100, 95, 121, 117, 118,
  91, 36, 112, 105, 44, 36, 104, 53, 93, 32, 45, 43, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 45, 103, 99, 100, 95, 121, 117, 118, 91, 36, 112,
  105, 44, 36, 102, 52, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93,
  10, 45, 45, 103, 99, 100, 95, 121, 117, 118, 91, 36, 112, 104, 44, 36,
  112, 102, 93, 32, 45, 42, 91, 45, 49, 93, 32, 52, 32, 45, 43, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 110, 109, 91, 45, 49, 93, 32, 114,
  101, 100, 10, 45, 45, 103, 99, 100, 95, 121, 117, 118, 91, 36, 112, 104,
  44, 36, 112, 100, 93, 32, 45, 45, 103, 99, 100, 95, 121, 117, 118, 91,
  36, 112, 104, 44, 36, 105, 53, 93, 32, 45, 43, 91, 45, 50, 44, 45,
  49, 93, 10, 45, 45, 103, 99, 100, 95, 121, 117, 118, 91, 36, 112, 102,
  44, 36, 105, 52, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 45, 103, 99, 100, 95, 121, 117, 118, 91, 36, 112, 102, 44, 36, 112,
  98, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 45, 103,
  99, 100, 95, 121, 117, 118, 91, 36, 112, 101, 44, 36, 112, 105, 93, 32,
  45, 42, 91, 45, 49, 93, 32, 52, 32, 45, 43, 91, 45, 50, 44, 45,
  49, 93, 10, 45, 110, 109, 91, 45, 49, 93, 32, 98, 108, 117, 101, 10,
  45, 45, 103, 99, 100, 95, 121, 117, 118, 91, 36, 112, 101, 44, 36, 112,
  102, 93, 32, 45, 45, 103, 99, 100, 95, 121, 117, 118, 91, 36, 112, 101,
  44, 36, 112, 104, 93, 32, 45, 108, 101, 91, 45, 50, 44, 45, 49, 93,
  10, 45, 45, 105, 109, 97, 103, 101, 91, 36, 112, 104, 93, 32, 91, 36,
  112, 102, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45,
  49, 93, 32, 45, 110, 109, 91, 45, 49, 93, 32, 112, 120, 32, 45, 114,
  109, 91, 45, 50, 93, 10, 45, 45, 108, 116, 91, 114, 101, 100, 44, 98,
  108, 117, 101, 93, 10, 45, 45, 103, 99, 100, 95, 110, 101, 113, 91, 36,
  112, 102, 44, 36, 105, 52, 93, 32, 45, 45, 103, 99, 100, 95, 110, 101,
  113, 91, 36, 112, 104, 44, 36, 105, 53, 93, 32, 45, 97, 110, 100, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 45, 103, 99, 100, 95, 101, 113, 91,
  36, 112, 101, 44, 36, 112, 105, 93, 32, 45, 97, 110, 100, 91, 45, 50,
  44, 45, 49, 93, 10, 45, 45, 103, 99, 100, 95, 110, 101, 113, 91, 36,
  112, 102, 44, 36, 112, 98, 93, 32, 45, 45, 103, 99, 100, 95, 110, 101,
  113, 91, 36, 112, 104, 44, 36, 112, 100, 93, 32, 45, 97, 110, 100, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 111, 114, 91, 45, 50, 44, 45, 49,
  93, 10, 45, 45, 103, 99, 100, 95, 101, 113, 91, 36, 112, 101, 44, 36,
  112, 103, 93, 32, 45, 111, 114, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  45, 103, 99, 100, 95, 101, 113, 91, 36, 112, 101, 44, 36, 112, 99, 93,
  32, 45, 111, 114, 91, 45, 50, 44, 45, 49, 93, 10, 45, 97, 110, 100,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 110, 109, 91, 45, 49, 93, 32,
  108, 118, 108, 50, 10, 45, 45, 103, 99, 100, 95, 121, 117, 118, 91, 36,
  112, 102, 44, 36, 112, 103, 93, 32, 45, 110, 109, 91, 45, 49, 93, 32,
  108, 118, 101, 114, 10, 45, 45, 103, 99, 100, 95, 121, 117, 118, 91, 36,
  112, 104, 44, 36, 112, 99, 93, 32, 45, 110, 109, 91, 45, 49, 93, 32,
  117, 118, 101, 114, 10, 45, 45, 42, 91, 108, 118, 101, 114, 93, 32, 50,
  32, 45, 108, 101, 91, 45, 49, 93, 32, 91, 117, 118, 101, 114, 93, 10,
  45, 45, 103, 99, 100, 95, 110, 101, 113, 91, 36, 112, 103, 44, 36, 112,
  101, 93, 32, 45, 45, 103, 99, 100, 95, 110, 101, 113, 91, 36, 112, 103,
  44, 36, 112, 100, 93, 32, 45, 97, 110, 100, 91, 45, 50, 44, 45, 49,
  93, 10, 45, 97, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 45, 97,
  110, 100, 91, 45, 49, 93, 32, 91, 108, 118, 108, 50, 93, 32, 45, 105,
  109, 97, 103, 101, 91, 36, 110, 51, 93, 32, 91, 112, 120, 93, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 10, 45, 45,
  42, 91, 117, 118, 101, 114, 93, 32, 50, 32, 45, 108, 116, 91, 45, 49,
  93, 32, 91, 108, 118, 101, 114, 93, 10, 45, 45, 103, 99, 100, 95, 110,
  101, 113, 91, 36, 112, 99, 44, 36, 112, 101, 93, 32, 45, 45, 103, 99,
  100, 95, 110, 101, 113, 91, 36, 112, 99, 44, 36, 112, 98, 93, 32, 45,
  97, 110, 100, 91, 45, 50, 44, 45, 49, 93, 10, 45, 97, 110, 100, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 97, 110, 100, 91, 45, 49, 93, 32,
  91, 108, 118, 108, 50, 93, 32, 45, 105, 109, 97, 103, 101, 91, 36, 110,
  51, 93, 32, 91, 112, 120, 93, 44, 48, 44, 48, 44, 48, 44, 48, 44,
  49, 44, 91, 45, 49, 93, 10, 45, 114, 109, 91, 45, 50, 44, 45, 49,
  44, 108, 118, 101, 114, 44, 117, 118, 101, 114, 93, 10, 45, 114, 109, 91,
  114, 101, 100, 44, 98, 108, 117, 101, 44, 108, 118, 108, 49, 44, 108, 118,
  108, 50, 44, 112, 120, 93, 10, 45, 100, 111, 110, 101, 10, 64, 123, 111,
  114, 105, 103, 44, 119, 125, 44, 64, 123, 111, 114, 105, 103, 44, 104, 125,
  44, 49, 44, 49, 44, 49, 32, 45, 114, 50, 100, 120, 91, 45, 49, 93,
  32, 123, 64, 123, 111, 114, 105, 103, 44, 119, 125, 42, 50, 125, 44, 52,
  32, 45, 110, 109, 91, 45, 49, 93, 32, 109, 115, 107, 10, 45, 114, 50,
  100, 120, 91, 111, 114, 105, 103, 44, 36, 101, 48, 44, 36, 101, 49, 44,
  36, 101, 50, 44, 36, 101, 51, 93, 32, 123, 64, 123, 111, 114, 105, 103,
  44, 119, 125, 42, 50, 125, 44, 49, 10, 45, 105, 109, 97, 103, 101, 91,
  111, 114, 105, 103, 93, 32, 91, 36, 101, 48, 93, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 49, 44, 91, 109, 115, 107, 93, 32, 45, 115, 104, 105,
  102, 116, 91, 109, 115, 107, 93, 32, 49, 10, 45, 105, 109, 97, 103, 101,
  91, 111, 114, 105, 103, 93, 32, 91, 36, 101, 49, 93, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 49, 44, 91, 109, 115, 107, 93, 32, 45, 115, 104,
  105, 102, 116, 91, 109, 115, 107, 93, 32, 45, 49, 44, 49, 10, 45, 105,
  109, 97, 103, 101, 91, 111, 114, 105, 103, 93, 32, 91, 36, 101, 50, 93,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 109, 115, 107, 93,
  32, 45, 115, 104, 105, 102, 116, 91, 109, 115, 107, 93, 32, 49, 10, 45,
  105, 109, 97, 103, 101, 91, 111, 114, 105, 103, 93, 32, 91, 36, 101, 51,
  93, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 91, 109, 115, 107,
  93, 10, 45, 107, 91, 111, 114, 105, 103, 93, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 103, 99, 100, 95, 101, 113, 32, 58, 32,
  45, 108, 91, 45, 50, 44, 45, 49, 93, 32, 45, 45, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 110, 111, 114, 109, 91, 45, 49, 93, 32, 45, 101,
  113, 91, 45, 49, 93, 32, 48, 32, 45, 101, 110, 100, 108, 10, 103, 99,
  100, 95, 110, 101, 113, 32, 58, 32, 45, 108, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 45, 91, 45, 50, 44, 45, 49, 93, 32, 45, 110, 111, 114,
  109, 91, 45, 49, 93, 32, 45, 110, 101, 113, 91, 45, 49, 93, 32, 48,
  32, 45, 101, 110, 100, 108, 10, 103, 99, 100, 95, 121, 117, 118, 32, 58,
  32, 45, 108, 91, 45, 50, 44, 45, 49, 93, 32, 45, 45, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 97, 98, 115, 91, 45, 49, 93, 32, 45, 114,
  103, 98, 50, 121, 117, 118, 91, 45, 49, 93, 32, 45, 97, 98, 115, 91,
  45, 49, 93, 32, 45, 115, 91, 45, 49, 93, 32, 99, 32, 45, 42, 91,
  45, 51, 93, 32, 52, 56, 32, 45, 42, 91, 45, 50, 93, 32, 55, 32,
  45, 42, 91, 45, 49, 93, 32, 54, 32, 45, 43, 91, 45, 51, 45, 45,
  49, 93, 32, 45, 101, 110, 100, 108, 10, 103, 99, 100, 95, 108, 97, 98,
  101, 108, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 52,
  125, 44, 36, 123, 50, 61, 48, 46, 50, 125, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 108, 97,
  98, 101, 108, 91, 45, 49, 93, 32, 36, 49, 44, 49, 32, 110, 98, 61,
  64, 123, 45, 49, 44, 49, 43, 105, 77, 125, 10, 45, 45, 104, 105, 115,
  116, 111, 103, 114, 97, 109, 91, 45, 49, 93, 32, 36, 110, 98, 44, 48,
  44, 123, 36, 110, 98, 45, 49, 125, 10, 45, 45, 109, 97, 112, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 93, 10,
  45, 108, 101, 91, 45, 49, 93, 32, 123, 36, 50, 37, 42, 119, 42, 104,
  125, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 10, 45, 105, 110,
  112, 97, 105, 110, 116, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 103, 99, 100, 95, 115, 104, 114, 105, 110, 107, 32, 58, 10,
  95, 103, 99, 100, 95, 119, 61, 64, 123, 48, 44, 119, 125, 32, 95, 103,
  99, 100, 95, 104, 61, 64, 123, 48, 44, 104, 125, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 105,
  102, 32, 123, 109, 97, 120, 40, 119, 44, 104, 41, 62, 55, 48, 48, 125,
  32, 45, 114, 114, 50, 100, 91, 45, 49, 93, 32, 55, 48, 48, 44, 55,
  48, 48, 44, 48, 44, 49, 32, 45, 101, 110, 100, 105, 102, 32, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 99, 100, 95, 117, 110,
  115, 104, 114, 105, 110, 107, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 114, 32, 36, 95,
  103, 99, 100, 95, 119, 44, 36, 95, 103, 99, 100, 95, 104, 32, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112,
  32, 95, 10, 35, 64, 103, 105, 109, 112, 32, 60, 105, 62, 71, 101, 110,
  116, 108, 101, 109, 97, 110, 98, 101, 103, 103, 97, 114, 60, 47, 105, 62,
  10, 35, 64, 103, 105, 109, 112, 32, 54, 48, 39, 115, 32, 99, 105, 110,
  101, 109, 97, 32, 58, 32, 103, 105, 109, 112, 95, 103, 98, 95, 99, 102,
  120, 44, 32, 103, 105, 109, 112, 95, 103, 98, 95, 99, 102, 120, 95, 112,
  114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 71, 114, 97, 105, 110, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 48, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 111, 110, 32, 102, 111, 114, 32, 109, 105, 100, 110,
  105, 103, 104, 116, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 71, 101, 110, 101, 107, 101, 108, 108,
  121, 32, 61, 32, 98, 111, 111, 108, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 82, 97, 121, 104, 97, 114, 114, 121, 104, 97, 117, 115,
  101, 110, 32, 61, 32, 98, 111, 111, 108, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 97, 114, 121, 103, 114, 97, 110, 116, 32, 61,
  32, 98, 111, 111, 108, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 92, 110, 85,
  115, 97, 103, 101, 32, 78, 111, 116, 101, 115, 58, 32, 32, 83, 101, 116,
  32, 79, 117, 116, 112, 117, 116, 32, 109, 111, 100, 101, 32, 116, 111, 32,
  39, 78, 101, 119, 32, 76, 97, 121, 101, 114, 39, 46, 32, 32, 65, 102,
  116, 101, 114, 32, 114, 117, 110, 110, 105, 110, 103, 32, 102, 105, 108, 116,
  101, 114, 44, 32, 73, 32, 114, 101, 99, 111, 109, 109, 101, 110, 100, 32,
  115, 101, 116, 116, 105, 110, 103, 32, 116, 104, 101, 32, 110, 101, 119, 108,
  121, 32, 99, 114, 101, 97, 116, 101, 100, 32, 108, 97, 121, 101, 114, 32,
  98, 108, 101, 110, 100, 32, 109, 111, 100, 101, 32, 116, 111, 32, 39, 104,
  97, 114, 100, 32, 108, 105, 103, 104, 116, 39, 32, 119, 104, 101, 110, 32,
  117, 115, 105, 110, 103, 32, 39, 110, 111, 111, 110, 32, 102, 111, 114, 32,
  109, 105, 100, 110, 105, 103, 104, 116, 39, 32, 97, 110, 100, 32, 39, 115,
  111, 102, 116, 32, 108, 105, 103, 104, 116, 39, 32, 102, 111, 114, 32, 111,
  116, 104, 101, 114, 32, 105, 109, 97, 103, 101, 115, 46, 32, 32, 84, 104,
  105, 115, 32, 102, 105, 108, 116, 101, 114, 32, 108, 111, 111, 107, 115, 32,
  98, 101, 115, 116, 32, 111, 110, 32, 119, 101, 108, 108, 32, 108, 105, 116,
  32, 115, 99, 101, 110, 101, 115, 46, 34, 125, 10, 103, 105, 109, 112, 95,
  103, 98, 95, 99, 102, 120, 32, 58, 10, 45, 105, 102, 32, 123, 36, 53,
  61, 61, 49, 125, 10, 45, 110, 111, 105, 115, 101, 91, 48, 93, 32, 123,
  36, 49, 47, 49, 125, 44, 52, 10, 45, 45, 103, 105, 109, 112, 95, 98,
  119, 114, 101, 99, 111, 108, 111, 114, 105, 122, 101, 32, 49, 44, 49, 44,
  48, 44, 48, 44, 48, 44, 49, 44, 48, 44, 53, 44, 48, 44, 48, 44,
  48, 44, 50, 53, 53, 44, 52, 55, 44, 49, 48, 54, 44, 49, 50, 49,
  44, 50, 53, 53, 44, 50, 48, 57, 44, 49, 51, 54, 44, 52, 57, 44,
  50, 53, 53, 44, 50, 50, 56, 44, 50, 48, 55, 44, 49, 57, 49, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 48, 10, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 101, 100, 103, 101, 115, 32, 48, 46, 57, 44, 48, 46,
  53, 10, 45, 101, 108, 115, 101, 10, 45, 105, 102, 32, 123, 36, 52, 61,
  61, 49, 125, 10, 45, 103, 105, 109, 112, 95, 98, 119, 114, 101, 99, 111,
  108, 111, 114, 105, 122, 101, 32, 49, 44, 49, 44, 48, 44, 48, 44, 48,
  44, 49, 44, 48, 44, 54, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53,
  44, 50, 55, 44, 50, 53, 44, 53, 53, 44, 50, 53, 53, 44, 49, 51,
  55, 44, 49, 53, 50, 44, 49, 56, 57, 44, 50, 53, 53, 44, 49, 57,
  49, 44, 50, 49, 55, 44, 50, 50, 56, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 10,
  45, 45, 110, 111, 105, 115, 101, 91, 48, 93, 32, 123, 36, 49, 47, 49,
  125, 44, 52, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 105, 110, 116,
  101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 10, 45, 101, 108, 115, 101,
  10, 45, 105, 102, 32, 123, 36, 51, 61, 61, 49, 125, 10, 45, 115, 101,
  112, 105, 97, 10, 45, 45, 102, 99, 91, 48, 93, 32, 48, 44, 54, 53,
  44, 48, 48, 32, 45, 116, 111, 95, 114, 103, 98, 97, 91, 48, 93, 10,
  45, 99, 111, 109, 112, 111, 115, 101, 95, 105, 110, 116, 101, 114, 112, 111,
  108, 97, 116, 105, 111, 110, 10, 45, 110, 111, 105, 115, 101, 91, 48, 93,
  32, 123, 36, 49, 47, 49, 125, 44, 52, 10, 45, 99, 111, 109, 112, 111,
  115, 101, 95, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 10, 45, 101,
  108, 115, 101, 10, 45, 105, 102, 32, 123, 36, 50, 61, 61, 48, 125, 10,
  45, 115, 101, 112, 105, 97, 10, 45, 45, 110, 111, 105, 115, 101, 91, 48,
  93, 32, 36, 49, 44, 52, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 10, 45, 101, 108, 115, 101,
  10, 45, 115, 101, 112, 105, 97, 10, 45, 45, 102, 99, 91, 48, 93, 32,
  48, 44, 48, 44, 50, 53, 53, 32, 45, 116, 111, 95, 114, 103, 98, 97,
  91, 48, 93, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 105, 110, 116,
  101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 10, 45, 110, 111, 105, 115,
  101, 91, 48, 93, 32, 123, 36, 49, 47, 50, 125, 44, 52, 10, 45, 99,
  111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 109, 101, 114, 103,
  101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 103, 105,
  109, 112, 95, 103, 98, 95, 99, 102, 120, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 103,
  98, 95, 99, 102, 120, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36,
  45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 65, 98, 111, 117, 116, 32,
  58, 32, 95, 110, 111, 110, 101, 95, 44, 32, 103, 105, 109, 112, 95, 103,
  98, 95, 97, 98, 111, 117, 116, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 60, 115, 112, 97, 110, 32, 102, 111,
  114, 101, 103, 114, 111, 117, 110, 100, 32, 61, 34, 112, 117, 114, 112, 108,
  101, 34, 62, 40, 32, 60, 98, 62, 71, 60, 47, 98, 62, 101, 110, 116,
  108, 101, 109, 97, 110, 98, 101, 103, 103, 97, 114, 63, 115, 32, 60, 98,
  62, 70, 60, 47, 98, 62, 105, 108, 116, 101, 114, 32, 60, 98, 62, 83,
  60, 47, 98, 62, 101, 116, 32, 102, 111, 114, 32, 60, 98, 62, 71, 39,
  77, 73, 67, 60, 47, 98, 62, 41, 60, 47, 115, 112, 97, 110, 62, 92,
  110, 92, 110, 105, 115, 32, 112, 114, 111, 112, 111, 115, 101, 100, 32, 116,
  111, 32, 121, 111, 117, 32, 98, 121, 34, 125, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 71, 101, 110, 116, 108, 101, 109, 97, 110, 98, 101, 103, 103, 97, 114,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 123, 34, 92, 110, 34, 125, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 101, 32, 115, 111, 117,
  114, 99, 101, 32, 99, 111, 100, 101, 32, 111, 102, 32, 116, 104, 105, 115,
  32, 102, 105, 108, 116, 101, 114, 32, 105, 115, 32, 97, 118, 97, 105, 108,
  97, 98, 108, 101, 32, 97, 116, 32, 58, 34, 125, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107,
  40, 34, 104, 116, 116, 112, 58, 47, 47, 103, 101, 110, 116, 108, 101, 109,
  97, 110, 98, 101, 103, 103, 97, 114, 46, 119, 111, 114, 100, 112, 114, 101,
  115, 115, 46, 99, 111, 109, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 123, 34, 92, 110, 84, 104, 101, 32, 102, 105, 108, 116,
  101, 114, 115, 32, 105, 110, 32, 116, 104, 105, 115, 32, 102, 111, 108, 100,
  101, 114, 32, 97, 114, 101, 32, 115, 116, 105, 108, 108, 32, 117, 110, 100,
  101, 114, 32, 100, 101, 118, 101, 108, 111, 112, 109, 101, 110, 116, 32, 97,
  110, 100, 32, 109, 97, 121, 32, 98, 101, 32, 115, 117, 98, 106, 101, 99,
  116, 32, 116, 111, 32, 99, 104, 97, 110, 103, 101, 115, 46, 34, 125, 10,
  103, 105, 109, 112, 95, 103, 98, 95, 97, 98, 111, 117, 116, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 108, 111, 103, 111, 32, 34, 71, 66, 34, 39,
  34, 115, 32, 70, 105, 108, 116, 101, 114, 115, 34, 10, 35, 64, 103, 105,
  109, 112, 32, 76, 101, 110, 115, 32, 98, 108, 117, 114, 32, 58, 32, 103,
  105, 109, 112, 95, 103, 98, 95, 108, 98, 44, 32, 103, 105, 109, 112, 95,
  103, 98, 95, 108, 98, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 123, 34, 92, 110, 85, 115, 97, 103, 101, 32, 78,
  111, 116, 101, 115, 58, 32, 32, 83, 101, 116, 32, 79, 117, 116, 112, 117,
  116, 32, 109, 111, 100, 101, 32, 116, 111, 32, 39, 78, 101, 119, 32, 105,
  109, 97, 103, 101, 39, 32, 111, 114, 32, 39, 105, 110, 32, 112, 108, 97,
  99, 101, 39, 32, 116, 111, 32, 115, 105, 109, 112, 108, 121, 32, 114, 101,
  118, 101, 114, 115, 101, 32, 116, 104, 101, 32, 102, 114, 97, 109, 101, 115,
  32, 105, 110, 32, 116, 104, 105, 115, 32, 105, 109, 97, 103, 101, 46, 32,
  32, 83, 101, 116, 32, 109, 111, 100, 101, 32, 116, 111, 32, 39, 78, 101,
  119, 32, 108, 97, 121, 101, 114, 115, 39, 32, 116, 111, 32, 97, 100, 100,
  32, 116, 104, 101, 32, 114, 101, 118, 101, 114, 115, 105, 110, 103, 32, 101,
  102, 102, 101, 99, 116, 32, 116, 111, 32, 121, 111, 117, 114, 32, 99, 117,
  114, 114, 101, 110, 116, 32, 105, 109, 97, 103, 101, 46, 34, 125, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 53, 44, 50,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 111, 107, 101,
  104, 32, 61, 32, 102, 108, 111, 97, 116, 40, 55, 44, 48, 44, 50, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121,
  112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 41, 10, 103, 105, 109, 112, 95, 103, 98, 95, 108, 98,
  32, 58, 10, 45, 115, 112, 114, 101, 97, 100, 32, 51, 10, 45, 104, 101,
  97, 116, 95, 102, 108, 111, 119, 32, 36, 49, 10, 45, 100, 105, 108, 97,
  116, 101, 95, 99, 105, 114, 99, 32, 36, 50, 10, 45, 99, 111, 109, 112,
  111, 115, 101, 95, 108, 105, 103, 104, 116, 101, 110, 10, 103, 105, 109, 112,
  95, 103, 98, 95, 108, 98, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 103, 98, 95, 108,
  98, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35,
  64, 103, 105, 109, 112, 32, 77, 97, 120, 102, 105, 101, 108, 100, 32, 112,
  97, 114, 114, 105, 115, 104, 32, 58, 32, 103, 105, 109, 112, 95, 103, 98,
  95, 109, 112, 44, 32, 103, 105, 109, 112, 95, 103, 98, 95, 109, 112, 95,
  112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 76, 105, 116, 104, 111, 103, 114, 97, 112, 104, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 50, 44, 46, 53, 44, 51, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 87, 97, 114, 109, 32, 61, 32, 98,
  111, 111, 108, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80,
  114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 103,
  105, 109, 112, 95, 103, 98, 95, 109, 112, 32, 58, 10, 45, 101, 113, 117,
  97, 108, 105, 122, 101, 32, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36,
  50, 61, 61, 49, 125, 10, 45, 45, 103, 105, 109, 112, 95, 99, 111, 114,
  110, 101, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 32, 50, 53, 53,
  44, 50, 52, 54, 44, 50, 49, 57, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 49, 52, 52, 44, 49, 48, 48, 44, 50, 53, 53, 44, 53, 52, 44,
  49, 54, 52, 44, 53, 52, 44, 50, 53, 53, 44, 48, 44, 48, 44, 50,
  53, 53, 44, 50, 53, 53, 10, 45, 101, 108, 115, 101, 10, 45, 45, 103,
  105, 109, 112, 95, 99, 111, 114, 110, 101, 114, 95, 103, 114, 97, 100, 105,
  101, 110, 116, 32, 50, 53, 53, 44, 50, 53, 48, 44, 50, 51, 55, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 48, 48, 44, 49, 55, 56, 44,
  50, 53, 53, 44, 50, 44, 49, 48, 52, 44, 50, 44, 50, 53, 53, 44,
  48, 44, 48, 44, 49, 52, 51, 44, 50, 53, 53, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 114, 118, 10, 45, 103, 105, 109, 112, 95, 116, 114, 97,
  110, 115, 102, 101, 114, 95, 99, 111, 108, 111, 114, 115, 32, 91, 45, 50,
  44, 45, 49, 93, 49, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 118,
  97, 108, 117, 101, 10, 45, 101, 113, 117, 97, 108, 105, 122, 101, 32, 50,
  53, 53, 10, 45, 103, 105, 109, 112, 95, 103, 108, 111, 119, 32, 123, 36,
  49, 125, 44, 48, 44, 48, 10, 103, 105, 109, 112, 95, 103, 98, 95, 109,
  112, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 103, 98, 95, 109, 112, 32, 36, 123, 49,
  45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112,
  32, 77, 111, 100, 101, 114, 110, 32, 99, 105, 110, 101, 109, 97, 32, 58,
  32, 103, 105, 109, 112, 95, 103, 98, 95, 109, 99, 102, 120, 44, 32, 103,
  105, 109, 112, 95, 103, 98, 95, 109, 99, 102, 120, 95, 112, 114, 101, 118,
  105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  71, 101, 110, 114, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  66, 108, 111, 99, 107, 98, 117, 115, 116, 101, 114, 34, 44, 34, 70, 101,
  101, 108, 32, 116, 104, 101, 32, 104, 101, 97, 116, 34, 44, 34, 67, 121,
  98, 101, 114, 112, 117, 110, 107, 45, 111, 45, 114, 97, 109, 97, 34, 44,
  34, 80, 114, 111, 99, 101, 100, 117, 114, 97, 108, 32, 112, 111, 108, 105,
  99, 101, 32, 100, 114, 97, 109, 97, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 101, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  117, 116, 111, 45, 97, 112, 112, 108, 121, 32, 102, 105, 108, 116, 101, 114,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 101, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80,
  114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 85,
  115, 97, 103, 101, 32, 78, 111, 116, 101, 115, 58, 32, 87, 104, 101, 110,
  32, 117, 115, 105, 110, 103, 32, 34, 97, 117, 116, 111, 32, 97, 112, 112,
  108, 121, 34, 32, 116, 104, 101, 32, 97, 100, 106, 117, 115, 116, 109, 101,
  110, 116, 32, 108, 97, 121, 101, 114, 32, 105, 115, 32, 97, 117, 116, 111,
  109, 97, 116, 105, 99, 97, 108, 108, 121, 32, 97, 112, 112, 108, 105, 101,
  100, 32, 116, 111, 32, 116, 104, 101, 32, 105, 109, 97, 103, 101, 32, 117,
  115, 105, 110, 103, 32, 116, 104, 101, 32, 34, 72, 97, 114, 100, 32, 108,
  105, 103, 104, 116, 34, 32, 109, 111, 100, 101, 46, 32, 32, 70, 111, 114,
  32, 109, 111, 114, 101, 32, 99, 111, 110, 116, 114, 111, 108, 32, 97, 110,
  100, 32, 116, 119, 101, 97, 107, 105, 110, 103, 44, 32, 115, 101, 116, 32,
  79, 117, 116, 112, 117, 116, 32, 109, 111, 100, 101, 32, 116, 111, 32, 39,
  78, 101, 119, 32, 76, 97, 121, 101, 114, 39, 46, 32, 32, 65, 102, 116,
  101, 114, 32, 114, 117, 110, 110, 105, 110, 103, 32, 102, 105, 108, 116, 101,
  114, 44, 32, 73, 32, 115, 117, 103, 103, 101, 115, 116, 32, 115, 101, 116,
  116, 105, 110, 103, 32, 116, 104, 101, 32, 110, 101, 119, 108, 121, 32, 99,
  114, 101, 97, 116, 101, 100, 32, 108, 97, 121, 101, 114, 32, 98, 108, 101,
  110, 100, 32, 109, 111, 100, 101, 32, 116, 111, 32, 39, 104, 97, 114, 100,
  32, 108, 105, 103, 104, 116, 39, 32, 102, 111, 114, 32, 109, 111, 115, 116,
  32, 105, 109, 97, 103, 101, 115, 46, 125, 10, 103, 105, 109, 112, 95, 103,
  98, 95, 109, 99, 102, 120, 32, 58, 10, 45, 105, 102, 32, 123, 36, 49,
  61, 61, 48, 125, 10, 45, 45, 103, 105, 109, 112, 95, 99, 111, 114, 110,
  101, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 32, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 57, 51,
  44, 49, 51, 49, 44, 50, 53, 53, 44, 50, 52, 56, 44, 49, 50, 49,
  44, 50, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 10, 45,
  45, 103, 105, 109, 112, 95, 99, 111, 114, 110, 101, 114, 95, 103, 114, 97,
  100, 105, 101, 110, 116, 32, 50, 49, 57, 44, 50, 52, 55, 44, 50, 53,
  49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 49, 52, 53, 44, 49, 49,
  53, 44, 50, 53, 53, 44, 50, 51, 56, 44, 50, 50, 50, 44, 49, 53,
  49, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 50, 125, 10, 45, 45,
  103, 105, 109, 112, 95, 99, 111, 114, 110, 101, 114, 95, 103, 114, 97, 100,
  105, 101, 110, 116, 32, 50, 51, 56, 44, 50, 53, 49, 44, 50, 50, 56,
  44, 50, 53, 53, 44, 48, 44, 49, 49, 55, 44, 55, 44, 50, 53, 53,
  44, 50, 56, 44, 55, 51, 44, 54, 51, 44, 50, 53, 53, 44, 48, 44,
  48, 44, 48, 44, 50, 53, 53, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  49, 61, 61, 51, 125, 10, 45, 45, 103, 105, 109, 112, 95, 99, 111, 114,
  110, 101, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 32, 50, 50, 56,
  44, 50, 53, 49, 44, 50, 53, 48, 44, 50, 53, 53, 44, 48, 44, 55,
  56, 44, 49, 49, 55, 44, 50, 53, 53, 44, 50, 56, 44, 50, 56, 44,
  55, 51, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 109, 111, 118, 101, 91, 45, 49,
  93, 32, 48, 10, 45, 105, 102, 32, 36, 50, 10, 45, 45, 103, 105, 109,
  112, 95, 116, 114, 97, 110, 115, 102, 101, 114, 95, 99, 111, 108, 111, 114,
  115, 32, 48, 32, 45, 114, 109, 91, 48, 93, 10, 45, 99, 111, 109, 112,
  111, 115, 101, 95, 104, 97, 114, 100, 108, 105, 103, 104, 116, 10, 45, 101,
  108, 115, 101, 10, 45, 103, 105, 109, 112, 95, 116, 114, 97, 110, 115, 102,
  101, 114, 95, 99, 111, 108, 111, 114, 115, 32, 48, 10, 45, 101, 110, 100,
  105, 102, 10, 103, 105, 109, 112, 95, 103, 98, 95, 109, 99, 102, 120, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  103, 105, 109, 112, 95, 103, 98, 95, 109, 99, 102, 120, 32, 36, 123, 49,
  45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112,
  32, 80, 105, 110, 103, 32, 112, 111, 110, 103, 32, 58, 32, 103, 105, 109,
  112, 95, 103, 98, 95, 112, 112, 44, 32, 103, 105, 109, 112, 95, 110, 111,
  95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 92,
  110, 85, 115, 97, 103, 101, 32, 78, 111, 116, 101, 115, 58, 32, 32, 83,
  101, 116, 32, 79, 117, 116, 112, 117, 116, 32, 109, 111, 100, 101, 32, 116,
  111, 32, 39, 78, 101, 119, 32, 105, 109, 97, 103, 101, 39, 32, 111, 114,
  32, 39, 105, 110, 32, 112, 108, 97, 99, 101, 39, 32, 116, 111, 32, 115,
  105, 109, 112, 108, 121, 32, 114, 101, 118, 101, 114, 115, 101, 32, 116, 104,
  101, 32, 102, 114, 97, 109, 101, 115, 32, 105, 110, 32, 116, 104, 105, 115,
  32, 105, 109, 97, 103, 101, 46, 32, 32, 83, 101, 116, 32, 109, 111, 100,
  101, 32, 116, 111, 32, 39, 78, 101, 119, 32, 108, 97, 121, 101, 114, 115,
  39, 32, 116, 111, 32, 97, 100, 100, 32, 116, 104, 101, 32, 114, 101, 118,
  101, 114, 115, 105, 110, 103, 32, 101, 102, 102, 101, 99, 116, 32, 116, 111,
  32, 121, 111, 117, 114, 32, 99, 117, 114, 114, 101, 110, 116, 32, 105, 109,
  97, 103, 101, 46, 34, 125, 10, 103, 105, 109, 112, 95, 103, 98, 95, 112,
  112, 32, 58, 10, 45, 114, 118, 10, 35, 64, 103, 105, 109, 112, 32, 85,
  114, 98, 97, 110, 32, 98, 108, 105, 103, 104, 116, 32, 58, 32, 103, 105,
  109, 112, 95, 103, 98, 95, 117, 98, 44, 103, 105, 109, 112, 95, 103, 98,
  95, 117, 98, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 117, 114, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 45, 49, 44, 45, 49, 44, 46, 48, 51,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 103, 105, 109, 112, 95,
  103, 98, 95, 117, 98, 32, 58, 10, 45, 103, 105, 109, 112, 95, 110, 111,
  114, 109, 97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 32, 50, 44,
  56, 44, 53, 44, 50, 48, 44, 49, 44, 51, 44, 48, 10, 45, 45, 103,
  105, 109, 112, 95, 103, 98, 95, 109, 112, 32, 51, 44, 48, 44, 48, 10,
  45, 114, 118, 10, 45, 103, 105, 109, 112, 95, 109, 105, 120, 95, 104, 115,
  118, 32, 49, 44, 48, 44, 48, 44, 49, 44, 123, 36, 49, 125, 44, 46,
  53, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 10, 45, 99,
  111, 109, 112, 111, 115, 101, 95, 111, 118, 101, 114, 108, 97, 121, 10, 103,
  105, 109, 112, 95, 103, 98, 95, 117, 98, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 103,
  98, 95, 117, 98, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45,
  49, 10, 35, 64, 103, 105, 109, 112, 32, 95, 10, 35, 64, 103, 105, 109,
  112, 32, 60, 105, 62, 73, 97, 105, 110, 32, 102, 101, 114, 103, 117, 115,
  115, 111, 110, 60, 47, 105, 62, 10, 35, 64, 103, 105, 109, 112, 32, 65,
  117, 116, 111, 109, 105, 120, 101, 114, 32, 58, 32, 97, 117, 116, 111, 109,
  105, 120, 101, 114, 44, 97, 117, 116, 111, 109, 105, 120, 101, 114, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117,
  116, 32, 99, 111, 108, 111, 117, 114, 32, 100, 105, 102, 102, 101, 114, 101,
  110, 99, 101, 32, 61, 32, 98, 111, 111, 108, 32, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 85, 115, 101, 32, 112, 97, 114, 116,
  105, 97, 108, 32, 105, 109, 97, 103, 101, 32, 102, 111, 114, 32, 110, 111,
  105, 115, 101, 32, 99, 97, 108, 117, 108, 97, 116, 105, 111, 110, 32, 61,
  32, 98, 111, 111, 108, 32, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 84, 104, 105, 115,
  32, 102, 105, 108, 116, 101, 114, 32, 99, 114, 101, 97, 116, 101, 115, 32,
  97, 32, 98, 108, 97, 99, 107, 32, 97, 110, 100, 32, 119, 104, 105, 116,
  101, 32, 109, 97, 103, 101, 32, 119, 105, 116, 104, 32, 116, 104, 101, 32,
  109, 111, 115, 116, 32, 112, 108, 101, 97, 115, 97, 110, 116, 32, 110, 111,
  105, 115, 101, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 105, 115, 116,
  105, 99, 115, 32, 40, 73, 77, 72, 79, 41, 46, 32, 73, 116, 32, 109,
  101, 97, 115, 117, 114, 101, 115, 32, 116, 104, 101, 32, 110, 111, 105, 115,
  101, 32, 105, 110, 32, 101, 97, 99, 104, 32, 99, 111, 108, 111, 117, 114,
  32, 99, 104, 97, 110, 110, 101, 108, 32, 97, 110, 100, 32, 115, 99, 97,
  108, 101, 115, 32, 101, 97, 99, 104, 32, 99, 104, 97, 110, 110, 101, 108,
  32, 115, 111, 32, 116, 104, 97, 116, 32, 116, 104, 101, 32, 110, 111, 105,
  115, 101, 32, 108, 101, 118, 101, 108, 115, 32, 97, 114, 101, 32, 101, 118,
  101, 110, 32, 97, 110, 100, 32, 112, 114, 111, 100, 117, 99, 101, 115, 32,
  97, 32, 103, 114, 101, 121, 115, 99, 97, 108, 101, 32, 111, 117, 116, 112,
  117, 116, 32, 97, 110, 100, 32, 111, 112, 116, 105, 111, 110, 97, 108, 108,
  121, 32, 97, 110, 32, 101, 120, 116, 114, 97, 32, 105, 109, 97, 103, 101,
  32, 119, 105, 116, 104, 32, 116, 104, 101, 32, 99, 111, 108, 111, 117, 114,
  32, 105, 110, 102, 111, 114, 109, 97, 116, 105, 111, 110, 46, 34, 125, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60,
  105, 62, 73, 97, 105, 110, 32, 70, 101, 114, 103, 117, 115, 115, 111, 110,
  60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 50, 48, 49, 50, 47,
  49, 48, 47, 50, 54, 34, 41, 10, 97, 117, 116, 111, 109, 105, 120, 101,
  114, 58, 10, 45, 116, 111, 95, 114, 103, 98, 10, 45, 45, 115, 112, 108,
  105, 116, 91, 45, 49, 93, 32, 99, 10, 45, 105, 102, 32, 123, 36, 50,
  61, 61, 49, 125, 10, 45, 99, 114, 111, 112, 91, 45, 49, 44, 45, 50,
  44, 45, 51, 93, 32, 52, 48, 37, 44, 52, 48, 37, 44, 54, 48, 37,
  44, 54, 48, 37, 10, 45, 101, 110, 100, 105, 102, 10, 98, 108, 117, 101,
  110, 111, 105, 115, 101, 61, 64, 123, 45, 118, 97, 114, 105, 97, 110, 99,
  101, 95, 110, 111, 105, 115, 101, 125, 10, 45, 114, 101, 109, 111, 118, 101,
  91, 45, 49, 93, 10, 103, 114, 101, 101, 110, 110, 111, 105, 115, 101, 61,
  64, 123, 45, 118, 97, 114, 105, 97, 110, 99, 101, 95, 110, 111, 105, 115,
  101, 125, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 93, 10, 114,
  101, 100, 110, 111, 105, 115, 101, 61, 64, 123, 45, 118, 97, 114, 105, 97,
  110, 99, 101, 95, 110, 111, 105, 115, 101, 125, 10, 45, 114, 101, 109, 111,
  118, 101, 91, 45, 49, 93, 10, 103, 114, 101, 101, 110, 110, 111, 105, 115,
  101, 61, 123, 36, 103, 114, 101, 101, 110, 110, 111, 105, 115, 101, 42, 48,
  46, 53, 125, 10, 114, 101, 100, 97, 100, 106, 117, 115, 116, 61, 123, 36,
  103, 114, 101, 101, 110, 110, 111, 105, 115, 101, 47, 36, 114, 101, 100, 110,
  111, 105, 115, 101, 125, 10, 98, 108, 117, 101, 97, 100, 106, 117, 115, 116,
  61, 123, 36, 103, 114, 101, 101, 110, 110, 111, 105, 115, 101, 47, 36, 98,
  108, 117, 101, 110, 111, 105, 115, 101, 125, 10, 45, 116, 111, 95, 114, 103,
  98, 10, 45, 45, 115, 112, 108, 105, 116, 91, 48, 93, 32, 99, 10, 45,
  109, 117, 108, 91, 49, 93, 32, 123, 36, 114, 101, 100, 97, 100, 106, 117,
  115, 116, 47, 40, 36, 114, 101, 100, 97, 100, 106, 117, 115, 116, 43, 49,
  43, 36, 98, 108, 117, 101, 97, 100, 106, 117, 115, 116, 41, 125, 10, 45,
  109, 117, 108, 91, 50, 93, 32, 123, 49, 47, 40, 36, 114, 101, 100, 97,
  100, 106, 117, 115, 116, 43, 49, 43, 36, 98, 108, 117, 101, 97, 100, 106,
  117, 115, 116, 41, 125, 10, 45, 109, 117, 108, 91, 51, 93, 32, 123, 36,
  98, 108, 117, 101, 97, 100, 106, 117, 115, 116, 47, 40, 36, 114, 101, 100,
  97, 100, 106, 117, 115, 116, 43, 49, 43, 36, 98, 108, 117, 101, 97, 100,
  106, 117, 115, 116, 41, 125, 10, 45, 97, 100, 100, 91, 49, 45, 51, 93,
  10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 125, 10, 45, 107, 101,
  101, 112, 91, 45, 49, 93, 10, 45, 101, 108, 115, 101, 10, 45, 45, 99,
  111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 101, 120, 116, 114,
  97, 99, 116, 10, 45, 114, 101, 109, 111, 118, 101, 91, 48, 93, 10, 45,
  101, 110, 100, 105, 102, 10, 35, 64, 103, 105, 109, 112, 32, 67, 97, 32,
  99, 111, 114, 114, 101, 99, 116, 105, 111, 110, 32, 58, 32, 105, 97, 105,
  110, 95, 67, 65, 95, 99, 111, 114, 114, 101, 99, 116, 105, 111, 110, 44,
  32, 105, 97, 105, 110, 95, 67, 65, 95, 99, 111, 114, 114, 101, 99, 116,
  105, 111, 110, 95, 112, 114, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 66, 108, 117, 101, 32, 97, 100, 106, 117, 115, 116, 109, 101,
  110, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 53, 44,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 100, 32,
  97, 100, 106, 117, 115, 116, 109, 101, 110, 116, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 45, 53, 44, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111,
  110, 32, 113, 117, 97, 108, 105, 116, 121, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 32, 40, 50, 44, 34, 76, 111, 119, 34, 44, 34, 77, 101, 100,
  34, 44, 34, 104, 105, 103, 104, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 115, 104, 111, 119, 115, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 32, 40, 34, 79, 117, 116, 112, 117, 116, 34, 44, 34,
  99, 111, 108, 111, 117, 114, 115, 32, 111, 110, 108, 121, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 118, 105, 101, 119, 32,
  99, 111, 114, 110, 101, 114, 32, 61, 32, 99, 104, 111, 105, 99, 101, 32,
  40, 51, 44, 34, 78, 111, 114, 116, 104, 45, 87, 101, 115, 116, 34, 44,
  34, 78, 111, 114, 116, 104, 45, 69, 97, 115, 116, 34, 44, 34, 83, 111,
  117, 116, 104, 45, 69, 97, 115, 116, 34, 44, 34, 83, 111, 117, 116, 104,
  45, 87, 101, 115, 116, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 84, 104,
  101, 32, 112, 114, 101, 118, 105, 101, 119, 32, 105, 115, 32, 111, 110, 108,
  121, 32, 97, 99, 99, 117, 114, 97, 116, 101, 32, 102, 111, 114, 32, 116,
  104, 101, 32, 99, 111, 114, 110, 101, 114, 115, 46, 32, 77, 97, 107, 101,
  32, 115, 117, 114, 101, 32, 121, 111, 117, 32, 110, 97, 118, 105, 103, 97,
  116, 101, 32, 116, 111, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 99,
  111, 114, 110, 101, 114, 32, 97, 115, 32, 115, 101, 108, 101, 99, 116, 101,
  100, 32, 97, 98, 111, 118, 101, 46, 32, 34, 41, 10, 105, 97, 105, 110,
  95, 67, 65, 95, 99, 111, 114, 114, 101, 99, 116, 105, 111, 110, 58, 10,
  45, 116, 111, 95, 114, 103, 98, 10, 108, 111, 110, 103, 101, 115, 116, 95,
  115, 105, 100, 101, 61, 123, 109, 97, 120, 40, 119, 44, 104, 41, 125, 10,
  45, 115, 112, 108, 105, 116, 32, 99, 10, 45, 108, 91, 48, 93, 10, 36,
  108, 111, 110, 103, 101, 115, 116, 95, 115, 105, 100, 101, 44, 36, 108, 111,
  110, 103, 101, 115, 116, 95, 115, 105, 100, 101, 10, 53, 48, 37, 44, 49,
  10, 45, 102, 105, 108, 108, 91, 45, 49, 93, 32, 49, 45, 40, 120, 47,
  119, 41, 10, 45, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32,
  120, 10, 45, 109, 117, 108, 91, 45, 50, 93, 32, 45, 49, 10, 45, 97,
  112, 112, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 120, 10, 45,
  114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 49, 44, 119,
  125, 44, 64, 123, 49, 44, 104, 125, 44, 49, 44, 49, 44, 49, 10, 91,
  45, 49, 93, 10, 45, 114, 111, 116, 97, 116, 101, 91, 45, 49, 93, 32,
  57, 48, 10, 45, 97, 112, 112, 101, 110, 100, 91, 45, 49, 44, 45, 50,
  93, 32, 99, 10, 45, 114, 109, 91, 49, 93, 10, 45, 114, 101, 115, 105,
  122, 101, 91, 49, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48,
  44, 104, 125, 44, 123, 100, 125, 44, 123, 115, 125, 44, 48, 44, 48, 44,
  48, 46, 53, 44, 48, 46, 53, 10, 45, 109, 117, 108, 91, 45, 49, 93,
  32, 36, 50, 10, 45, 119, 97, 114, 112, 91, 48, 93, 32, 91, 49, 93,
  44, 49, 44, 36, 51, 44, 49, 10, 45, 107, 101, 101, 112, 91, 48, 93,
  10, 45, 101, 110, 100, 108, 10, 45, 108, 91, 50, 93, 10, 36, 108, 111,
  110, 103, 101, 115, 116, 95, 115, 105, 100, 101, 44, 36, 108, 111, 110, 103,
  101, 115, 116, 95, 115, 105, 100, 101, 10, 53, 48, 37, 44, 49, 10, 45,
  102, 105, 108, 108, 91, 45, 49, 93, 32, 49, 45, 40, 120, 47, 119, 41,
  10, 45, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 120, 10,
  45, 109, 117, 108, 91, 45, 50, 93, 32, 45, 49, 10, 45, 97, 112, 112,
  101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 120, 10, 45, 114, 101,
  115, 105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 49, 44, 119, 125, 44,
  64, 123, 49, 44, 104, 125, 44, 49, 44, 49, 44, 49, 10, 91, 45, 49,
  93, 10, 45, 114, 111, 116, 97, 116, 101, 91, 45, 49, 93, 32, 57, 48,
  10, 45, 97, 112, 112, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32,
  99, 10, 45, 114, 109, 91, 49, 93, 10, 45, 114, 101, 115, 105, 122, 101,
  91, 49, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104,
  125, 44, 123, 100, 125, 44, 123, 115, 125, 44, 48, 44, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 10, 45, 109, 117, 108, 91, 45, 49, 93, 32, 36,
  49, 10, 45, 119, 97, 114, 112, 91, 48, 93, 32, 91, 49, 93, 44, 49,
  44, 36, 51, 44, 49, 10, 45, 107, 101, 101, 112, 91, 48, 93, 10, 45,
  101, 110, 100, 108, 10, 45, 97, 112, 112, 101, 110, 100, 32, 99, 10, 45,
  99, 32, 48, 44, 50, 53, 53, 10, 105, 97, 105, 110, 95, 67, 65, 95,
  99, 111, 114, 114, 101, 99, 116, 105, 111, 110, 95, 112, 114, 58, 10, 45,
  116, 111, 95, 114, 103, 98, 10, 120, 95, 109, 117, 108, 61, 123, 119, 47,
  109, 97, 120, 40, 119, 44, 104, 41, 125, 10, 121, 95, 109, 117, 108, 61,
  123, 104, 47, 109, 97, 120, 40, 119, 44, 104, 41, 125, 10, 45, 105, 102,
  32, 123, 36, 45, 49, 61, 61, 48, 125, 10, 114, 120, 95, 115, 104, 105,
  102, 116, 61, 123, 36, 50, 42, 45, 49, 42, 36, 120, 95, 109, 117, 108,
  125, 10, 114, 121, 95, 115, 104, 105, 102, 116, 61, 123, 36, 50, 42, 45,
  49, 42, 36, 121, 95, 109, 117, 108, 125, 10, 98, 120, 95, 115, 104, 105,
  102, 116, 61, 123, 36, 49, 42, 45, 49, 42, 36, 120, 95, 109, 117, 108,
  125, 10, 98, 121, 95, 115, 104, 105, 102, 116, 61, 123, 36, 49, 42, 45,
  49, 42, 36, 121, 95, 109, 117, 108, 125, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 45, 49, 61, 61, 49, 125, 10, 114, 120, 95, 115, 104, 105, 102,
  116, 61, 123, 36, 50, 42, 36, 120, 95, 109, 117, 108, 125, 10, 114, 121,
  95, 115, 104, 105, 102, 116, 61, 123, 36, 50, 42, 45, 49, 42, 36, 121,
  95, 109, 117, 108, 125, 10, 98, 120, 95, 115, 104, 105, 102, 116, 61, 123,
  36, 49, 42, 36, 120, 95, 109, 117, 108, 125, 10, 98, 121, 95, 115, 104,
  105, 102, 116, 61, 123, 36, 49, 42, 45, 49, 42, 36, 121, 95, 109, 117,
  108, 125, 10, 45, 101, 108, 105, 102, 32, 123, 36, 45, 49, 61, 61, 50,
  125, 10, 114, 120, 95, 115, 104, 105, 102, 116, 61, 123, 36, 50, 42, 36,
  120, 95, 109, 117, 108, 125, 10, 114, 121, 95, 115, 104, 105, 102, 116, 61,
  123, 36, 50, 42, 36, 121, 95, 109, 117, 108, 125, 10, 98, 120, 95, 115,
  104, 105, 102, 116, 61, 123, 36, 49, 42, 36, 120, 95, 109, 117, 108, 125,
  10, 98, 121, 95, 115, 104, 105, 102, 116, 61, 123, 36, 49, 42, 36, 121,
  95, 109, 117, 108, 125, 10, 45, 101, 108, 105, 102, 32, 32, 123, 36, 45,
  49, 61, 61, 51, 125, 10, 114, 120, 95, 115, 104, 105, 102, 116, 61, 123,
  36, 50, 42, 45, 49, 42, 36, 120, 95, 109, 117, 108, 125, 10, 114, 121,
  95, 115, 104, 105, 102, 116, 61, 123, 36, 50, 42, 36, 121, 95, 109, 117,
  108, 125, 10, 98, 120, 95, 115, 104, 105, 102, 116, 61, 123, 36, 49, 42,
  45, 49, 42, 36, 120, 95, 109, 117, 108, 125, 10, 98, 121, 95, 115, 104,
  105, 102, 116, 61, 123, 36, 49, 42, 36, 121, 95, 109, 117, 108, 125, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 115, 112, 108, 105, 116, 32, 99, 10,
  45, 108, 91, 48, 93, 10, 91, 48, 93, 10, 91, 48, 93, 10, 45, 102,
  105, 108, 108, 91, 49, 93, 32, 36, 114, 120, 95, 115, 104, 105, 102, 116,
  10, 45, 102, 105, 108, 108, 91, 50, 93, 32, 36, 114, 121, 95, 115, 104,
  105, 102, 116, 10, 45, 97, 112, 112, 101, 110, 100, 91, 49, 44, 50, 93,
  32, 99, 10, 45, 119, 97, 114, 112, 91, 48, 93, 32, 91, 49, 93, 44,
  49, 44, 36, 51, 44, 49, 10, 45, 107, 101, 101, 112, 91, 48, 93, 10,
  45, 101, 110, 100, 108, 10, 45, 108, 91, 50, 93, 10, 91, 48, 93, 10,
  91, 48, 93, 10, 45, 102, 105, 108, 108, 91, 49, 93, 32, 36, 98, 120,
  95, 115, 104, 105, 102, 116, 10, 45, 102, 105, 108, 108, 91, 50, 93, 32,
  36, 98, 121, 95, 115, 104, 105, 102, 116, 10, 45, 97, 112, 112, 101, 110,
  100, 91, 49, 44, 50, 93, 32, 99, 10, 45, 119, 97, 114, 112, 91, 48,
  93, 32, 91, 49, 93, 44, 49, 44, 36, 51, 44, 49, 10, 45, 107, 101,
  101, 112, 91, 48, 93, 10, 45, 101, 110, 100, 108, 10, 45, 97, 112, 112,
  101, 110, 100, 32, 99, 10, 45, 105, 102, 32, 123, 36, 45, 50, 125, 10,
  45, 114, 103, 98, 50, 104, 115, 118, 10, 45, 115, 112, 108, 105, 116, 32,
  99, 10, 45, 102, 105, 108, 108, 91, 45, 49, 93, 32, 46, 53, 10, 45,
  97, 112, 112, 101, 110, 100, 32, 99, 10, 45, 104, 115, 118, 50, 114, 103,
  98, 10, 45, 115, 117, 98, 32, 49, 50, 56, 10, 45, 109, 117, 108, 32,
  50, 10, 45, 97, 100, 100, 32, 49, 50, 56, 10, 45, 99, 32, 48, 44,
  50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103, 105, 109,
  112, 32, 69, 97, 115, 121, 32, 115, 107, 105, 110, 32, 114, 101, 116, 111,
  117, 99, 104, 32, 58, 32, 105, 97, 105, 110, 95, 101, 97, 115, 121, 95,
  115, 107, 105, 110, 95, 114, 101, 116, 111, 117, 99, 104, 44, 105, 97, 105,
  110, 95, 101, 97, 115, 121, 95, 115, 107, 105, 110, 95, 114, 101, 116, 111,
  117, 99, 104, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 98, 62, 66, 97, 115, 101, 32, 83, 109, 111,
  111, 116, 104, 105, 110, 103, 60, 47, 98, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 69, 100, 103, 101, 32, 115, 101, 110, 115, 105,
  116, 105, 118, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40,
  55, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110,
  116, 32, 40, 50, 44, 49, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 76, 111, 119, 32, 98, 105, 97, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 46, 55, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 98,
  62, 68, 101, 116, 97, 105, 108, 32, 73, 110, 116, 101, 110, 115, 105, 116,
  121, 60, 47, 98, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 73, 102,
  32, 112, 114, 101, 118, 105, 101, 119, 32, 97, 112, 112, 101, 97, 114, 115,
  32, 100, 97, 114, 107, 44, 32, 105, 110, 99, 114, 101, 97, 115, 101, 32,
  115, 105, 122, 101, 32, 111, 102, 32, 112, 114, 101, 118, 105, 101, 119, 32,
  119, 105, 110, 100, 111, 119, 46, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 79, 110, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 101, 114, 121, 32, 102, 105,
  110, 101, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 49, 44, 48, 44,
  50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 105, 110, 101,
  32, 50, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 46, 55, 44, 48,
  44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 101, 100,
  105, 117, 109, 32, 51, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 46,
  54, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 117, 114, 115, 101, 32, 52, 32, 61, 32, 102, 108, 111, 97, 116,
  32, 40, 46, 53, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 86, 101, 114, 121, 32, 99, 111, 117, 114, 115, 101, 32, 53,
  32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 46, 53, 44, 48, 44, 50,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 100, 117, 99,
  101, 32, 114, 101, 100, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97,
  116, 32, 40, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 112, 108, 105, 116, 32, 98, 97, 115, 101, 32, 97, 110, 100, 32, 100,
  101, 116, 97, 105, 108, 32, 111, 117, 116, 112, 117, 116, 32, 61, 32, 98,
  111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 32,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 65, 117, 116, 104, 111, 114, 58,
  32, 73, 97, 105, 110, 32, 70, 101, 114, 103, 117, 115, 115, 111, 110, 32,
  45, 32, 117, 112, 100, 97, 116, 101, 32, 49, 50, 32, 77, 97, 121, 32,
  50, 48, 49, 51, 32, 45, 32, 110, 111, 119, 32, 104, 97, 110, 100, 108,
  101, 115, 32, 97, 108, 112, 104, 97, 32, 99, 104, 97, 110, 110, 101, 108,
  32, 97, 110, 100, 32, 115, 111, 109, 101, 32, 105, 110, 116, 101, 114, 110,
  97, 108, 32, 99, 104, 97, 110, 103, 101, 115, 34, 41, 10, 105, 97, 105,
  110, 95, 101, 97, 115, 121, 95, 115, 107, 105, 110, 95, 114, 101, 116, 111,
  117, 99, 104, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112,
  97, 99, 105, 116, 121, 32, 45, 108, 91, 48, 93, 10, 115, 116, 114, 49,
  61, 36, 49, 10, 115, 116, 114, 50, 61, 123, 36, 115, 116, 114, 49, 42,
  36, 51, 125, 10, 115, 116, 114, 51, 61, 123, 36, 115, 116, 114, 50, 42,
  36, 51, 125, 10, 115, 116, 114, 52, 61, 123, 36, 115, 116, 114, 51, 42,
  36, 51, 125, 10, 115, 116, 114, 53, 61, 123, 36, 115, 116, 114, 52, 42,
  36, 51, 125, 10, 115, 116, 114, 54, 61, 123, 36, 115, 116, 114, 53, 42,
  36, 51, 125, 10, 115, 116, 114, 55, 61, 123, 36, 115, 116, 114, 54, 42,
  36, 51, 125, 10, 115, 116, 114, 56, 61, 123, 36, 115, 116, 114, 55, 42,
  36, 51, 125, 10, 45, 45, 108, 91, 48, 93, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 36, 50, 10, 99, 114, 111, 112, 119, 105, 100, 116, 104, 61,
  123, 119, 125, 10, 99, 114, 111, 112, 104, 101, 105, 103, 104, 116, 61, 123,
  104, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 123, 119,
  43, 40, 50, 53, 54, 45, 119, 37, 50, 53, 54, 41, 125, 44, 123, 104,
  43, 40, 50, 53, 54, 45, 104, 37, 50, 53, 54, 41, 125, 44, 49, 44,
  123, 115, 125, 44, 48, 44, 49, 10, 119, 105, 100, 116, 104, 61, 123, 119,
  125, 10, 104, 101, 105, 103, 104, 116, 61, 123, 104, 125, 10, 45, 105, 102,
  32, 123, 36, 115, 116, 114, 49, 33, 61, 48, 125, 10, 45, 100, 101, 110,
  111, 105, 115, 101, 91, 48, 93, 32, 49, 48, 44, 36, 115, 116, 114, 49,
  44, 51, 44, 53, 44, 48, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 123, 36, 119, 105,
  100, 116, 104, 47, 50, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47,
  50, 125, 44, 49, 44, 123, 115, 125, 44, 50, 44, 49, 10, 45, 45, 114,
  101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 36, 119, 105, 100, 116, 104,
  44, 36, 104, 101, 105, 103, 104, 116, 44, 49, 44, 123, 115, 125, 44, 51,
  44, 49, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 46, 53, 10,
  45, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 101, 120,
  116, 114, 97, 99, 116, 91, 48, 44, 45, 49, 93, 10, 45, 105, 102, 32,
  123, 36, 115, 116, 114, 50, 33, 61, 48, 125, 10, 45, 100, 101, 110, 111,
  105, 115, 101, 91, 45, 49, 93, 32, 49, 48, 44, 36, 115, 116, 114, 50,
  44, 51, 44, 53, 44, 48, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 119,
  105, 100, 116, 104, 47, 52, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116,
  47, 52, 125, 44, 49, 44, 123, 115, 125, 44, 50, 44, 49, 10, 45, 45,
  114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 119, 105, 100,
  116, 104, 47, 50, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 50,
  125, 44, 49, 44, 123, 115, 125, 44, 51, 44, 49, 10, 45, 98, 108, 117,
  114, 91, 45, 49, 93, 32, 46, 53, 10, 45, 99, 111, 109, 112, 111, 115,
  101, 95, 103, 114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116, 91, 49,
  44, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 115, 116, 114, 51, 33,
  61, 48, 125, 10, 45, 100, 101, 110, 111, 105, 115, 101, 91, 45, 49, 93,
  32, 49, 48, 44, 36, 115, 116, 114, 51, 44, 51, 44, 53, 44, 48, 44,
  49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 45, 114, 101, 115, 105, 122,
  101, 91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 56, 125,
  44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 56, 125, 44, 49, 44, 123,
  115, 125, 44, 50, 44, 49, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91,
  45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 52, 125, 44, 123,
  36, 104, 101, 105, 103, 104, 116, 47, 52, 125, 44, 49, 44, 123, 115, 125,
  44, 51, 44, 49, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 46,
  53, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110,
  101, 120, 116, 114, 97, 99, 116, 91, 50, 44, 45, 49, 93, 10, 45, 105,
  102, 32, 123, 36, 115, 116, 114, 52, 33, 61, 48, 125, 10, 45, 100, 101,
  110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 49, 48, 44, 36, 115, 116,
  114, 52, 44, 51, 44, 53, 44, 48, 44, 49, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123,
  36, 119, 105, 100, 116, 104, 47, 49, 54, 125, 44, 123, 36, 104, 101, 105,
  103, 104, 116, 47, 49, 54, 125, 44, 49, 44, 123, 115, 125, 44, 50, 44,
  49, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123,
  36, 119, 105, 100, 116, 104, 47, 56, 125, 44, 123, 36, 104, 101, 105, 103,
  104, 116, 47, 56, 125, 44, 49, 44, 123, 115, 125, 44, 51, 44, 49, 10,
  45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 46, 53, 10, 45, 99, 111,
  109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 101, 120, 116, 114, 97,
  99, 116, 91, 51, 44, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 115,
  116, 114, 53, 33, 61, 48, 125, 10, 45, 100, 101, 110, 111, 105, 115, 101,
  91, 45, 49, 93, 32, 49, 48, 44, 36, 115, 116, 114, 53, 44, 51, 44,
  53, 44, 48, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 45, 114,
  101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116,
  104, 47, 51, 50, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 51,
  50, 125, 44, 49, 44, 123, 115, 125, 44, 50, 44, 49, 10, 45, 45, 114,
  101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116,
  104, 47, 49, 54, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 49,
  54, 125, 44, 49, 44, 123, 115, 125, 44, 51, 44, 49, 10, 45, 98, 108,
  117, 114, 91, 45, 49, 93, 32, 46, 53, 10, 45, 99, 111, 109, 112, 111,
  115, 101, 95, 103, 114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116, 91,
  52, 44, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 115, 116, 114, 54,
  33, 61, 48, 125, 10, 45, 100, 101, 110, 111, 105, 115, 101, 91, 45, 49,
  93, 32, 49, 48, 44, 36, 115, 116, 114, 54, 44, 51, 44, 53, 44, 48,
  44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 45, 114, 101, 115, 105,
  122, 101, 91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 54,
  52, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 54, 52, 125, 44,
  49, 44, 123, 115, 125, 44, 50, 44, 49, 10, 45, 45, 114, 101, 115, 105,
  122, 101, 91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 51,
  50, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 51, 50, 125, 44,
  49, 44, 123, 115, 125, 44, 51, 44, 49, 10, 45, 98, 108, 117, 114, 91,
  45, 49, 93, 32, 46, 53, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  103, 114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116, 91, 53, 44, 45,
  49, 93, 10, 45, 105, 102, 32, 123, 36, 115, 116, 114, 55, 33, 61, 48,
  125, 10, 45, 100, 101, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 49,
  48, 44, 36, 115, 116, 114, 55, 44, 51, 44, 53, 44, 48, 44, 49, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91,
  45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 49, 50, 56, 125,
  44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 49, 50, 56, 125, 44, 49,
  44, 123, 115, 125, 44, 50, 44, 49, 10, 45, 45, 114, 101, 115, 105, 122,
  101, 91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 54, 52,
  125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 54, 52, 125, 44, 49,
  44, 123, 115, 125, 44, 51, 44, 49, 10, 45, 98, 108, 117, 114, 91, 45,
  49, 93, 32, 46, 53, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 103,
  114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116, 91, 54, 44, 45, 49,
  93, 10, 45, 105, 102, 32, 123, 36, 115, 116, 114, 56, 33, 61, 48, 125,
  10, 45, 100, 101, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 49, 48,
  44, 36, 115, 116, 114, 56, 44, 51, 44, 53, 44, 48, 44, 49, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 45,
  49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 50, 53, 54, 125, 44,
  123, 36, 104, 101, 105, 103, 104, 116, 47, 50, 53, 54, 125, 44, 49, 44,
  123, 115, 125, 44, 50, 44, 49, 10, 45, 45, 114, 101, 115, 105, 122, 101,
  91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 49, 50, 56,
  125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 49, 50, 56, 125, 44,
  49, 44, 123, 115, 125, 44, 51, 44, 49, 10, 45, 98, 108, 117, 114, 91,
  45, 49, 93, 32, 46, 53, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  103, 114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116, 91, 55, 44, 45,
  49, 93, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123,
  36, 119, 105, 100, 116, 104, 47, 49, 50, 56, 125, 44, 123, 36, 104, 101,
  105, 103, 104, 116, 47, 49, 50, 56, 125, 44, 49, 44, 123, 115, 125, 44,
  51, 44, 49, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 46, 53,
  10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 109,
  101, 114, 103, 101, 91, 45, 49, 44, 45, 50, 93, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47,
  54, 52, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 54, 52, 125,
  44, 49, 44, 123, 115, 125, 44, 51, 44, 49, 10, 45, 98, 108, 117, 114,
  91, 45, 49, 93, 32, 46, 53, 10, 45, 99, 111, 109, 112, 111, 115, 101,
  95, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 91, 45, 49, 44, 45,
  50, 93, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123,
  36, 119, 105, 100, 116, 104, 47, 51, 50, 125, 44, 123, 36, 104, 101, 105,
  103, 104, 116, 47, 51, 50, 125, 44, 49, 44, 123, 115, 125, 44, 51, 44,
  49, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 46, 53, 10, 45,
  99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 109, 101, 114,
  103, 101, 91, 45, 49, 44, 45, 50, 93, 10, 45, 114, 101, 115, 105, 122,
  101, 91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 49, 54,
  125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 49, 54, 125, 44, 49,
  44, 123, 115, 125, 44, 51, 44, 49, 10, 45, 98, 108, 117, 114, 91, 45,
  49, 93, 32, 46, 53, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 103,
  114, 97, 105, 110, 109, 101, 114, 103, 101, 91, 45, 49, 44, 45, 50, 93,
  10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 119,
  105, 100, 116, 104, 47, 56, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116,
  47, 56, 125, 44, 49, 44, 123, 115, 125, 44, 51, 44, 49, 10, 45, 98,
  108, 117, 114, 91, 45, 49, 93, 32, 46, 53, 10, 45, 99, 111, 109, 112,
  111, 115, 101, 95, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 91, 45,
  49, 44, 45, 50, 93, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49,
  93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 52, 125, 44, 123, 36, 104,
  101, 105, 103, 104, 116, 47, 52, 125, 44, 49, 44, 123, 115, 125, 44, 51,
  44, 49, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 46, 53, 10,
  45, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 109, 101,
  114, 103, 101, 91, 45, 49, 44, 45, 50, 93, 10, 45, 114, 101, 115, 105,
  122, 101, 91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 50,
  125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 50, 125, 44, 49, 44,
  123, 115, 125, 44, 51, 44, 49, 10, 45, 98, 108, 117, 114, 91, 45, 49,
  93, 32, 46, 53, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114,
  97, 105, 110, 109, 101, 114, 103, 101, 91, 45, 49, 44, 45, 50, 93, 10,
  45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 119, 105,
  100, 116, 104, 47, 49, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47,
  49, 125, 44, 49, 44, 123, 115, 125, 44, 51, 44, 49, 10, 45, 98, 108,
  117, 114, 91, 45, 49, 93, 32, 46, 53, 10, 45, 99, 111, 109, 112, 111,
  115, 101, 95, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 91, 45, 49,
  44, 45, 50, 93, 10, 45, 99, 114, 111, 112, 32, 48, 44, 48, 44, 123,
  36, 99, 114, 111, 112, 119, 105, 100, 116, 104, 45, 49, 125, 44, 123, 36,
  99, 114, 111, 112, 104, 101, 105, 103, 104, 116, 45, 49, 125, 10, 45, 100,
  111, 110, 101, 10, 45, 101, 110, 100, 108, 10, 45, 105, 102, 32, 123, 36,
  52, 61, 61, 49, 125, 10, 45, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  103, 114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116, 91, 48, 44, 45,
  49, 93, 10, 45, 45, 114, 103, 98, 50, 104, 115, 118, 56, 91, 45, 49,
  93, 10, 45, 115, 112, 108, 105, 116, 91, 45, 49, 93, 32, 99, 10, 45,
  114, 101, 109, 111, 118, 101, 91, 45, 49, 44, 45, 50, 93, 10, 45, 97,
  100, 100, 91, 45, 49, 93, 32, 51, 48, 10, 45, 109, 111, 100, 91, 45,
  49, 93, 32, 50, 53, 53, 10, 45, 103, 101, 91, 45, 49, 93, 32, 32,
  52, 48, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10,
  45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 10, 45, 98,
  108, 117, 114, 91, 45, 49, 93, 32, 52, 10, 45, 45, 115, 112, 108, 105,
  116, 91, 45, 50, 93, 32, 99, 10, 45, 114, 101, 109, 111, 118, 101, 91,
  45, 49, 44, 45, 50, 93, 10, 45, 109, 111, 118, 101, 91, 45, 49, 93,
  32, 45, 50, 10, 45, 97, 112, 112, 101, 110, 100, 91, 45, 50, 44, 45,
  49, 93, 32, 99, 10, 45, 45, 99, 111, 109, 112, 111, 115, 101, 95, 97,
  108, 112, 104, 97, 91, 45, 49, 44, 45, 50, 93, 10, 45, 114, 101, 109,
  111, 118, 101, 91, 45, 50, 93, 10, 45, 109, 117, 108, 91, 45, 49, 93,
  32, 123, 36, 49, 48, 125, 10, 45, 109, 117, 108, 91, 45, 50, 93, 32,
  123, 49, 45, 36, 49, 48, 125, 10, 45, 97, 100, 100, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 50,
  93, 10, 45, 108, 91, 45, 49, 93, 10, 45, 45, 102, 102, 116, 112, 111,
  108, 97, 114, 91, 48, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 49, 44, 49, 44, 49, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91,
  45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 53, 48, 37, 44,
  53, 48, 37, 44, 48, 44, 49, 44, 36, 53, 10, 45, 101, 108, 108, 105,
  112, 115, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44,
  50, 53, 37, 44, 50, 53, 37, 44, 48, 44, 49, 44, 36, 54, 10, 45,
  101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44,
  53, 48, 37, 44, 49, 50, 37, 44, 49, 50, 37, 44, 48, 44, 49, 44,
  36, 55, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32,
  53, 48, 37, 44, 53, 48, 37, 44, 54, 37, 44, 54, 37, 44, 48, 44,
  49, 44, 36, 56, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49,
  93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 51, 37, 44, 51, 37, 44,
  48, 44, 49, 44, 36, 57, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91,
  45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 48, 46, 49, 37,
  44, 48, 46, 49, 37, 44, 48, 44, 49, 44, 49, 10, 45, 115, 101, 116,
  91, 45, 49, 93, 32, 49, 44, 53, 48, 37, 44, 53, 48, 37, 10, 45,
  109, 117, 108, 91, 49, 93, 32, 91, 45, 49, 93, 10, 45, 105, 102, 102,
  116, 112, 111, 108, 97, 114, 91, 49, 44, 50, 93, 10, 45, 107, 101, 101,
  112, 91, 49, 93, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 101,
  110, 100, 108, 10, 45, 114, 101, 109, 111, 118, 101, 91, 48, 93, 10, 45,
  105, 102, 32, 123, 36, 49, 49, 61, 61, 48, 125, 10, 45, 99, 111, 109,
  112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 91,
  45, 49, 44, 45, 50, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  108, 115, 101, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 105, 97, 105, 110,
  95, 101, 97, 115, 121, 95, 115, 107, 105, 110, 95, 114, 101, 116, 111, 117,
  99, 104, 95, 112, 114, 101, 118, 105, 101, 119, 58, 10, 45, 105, 97, 105,
  110, 95, 101, 97, 115, 121, 95, 115, 107, 105, 110, 95, 114, 101, 116, 111,
  117, 99, 104, 32, 36, 123, 49, 45, 45, 49, 125, 10, 35, 64, 103, 105,
  109, 112, 32, 69, 120, 102, 117, 115, 101, 32, 58, 32, 101, 120, 102, 117,
  115, 101, 44, 32, 101, 120, 102, 117, 115, 101, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 69, 120, 112, 111, 115, 117, 114, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 32, 40, 49, 44, 48, 44, 50, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 110, 116, 114, 97, 115, 116, 32, 98,
  105, 97, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 54, 44,
  48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 97,
  116, 117, 114, 97, 116, 105, 111, 110, 32, 98, 105, 97, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 69, 120, 112, 111, 115, 117, 114, 101, 32, 115,
  105, 103, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53,
  44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69,
  120, 112, 111, 115, 117, 114, 101, 32, 98, 105, 97, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 66, 108, 117, 114, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 53, 44, 48, 44, 53, 48, 41, 10, 101, 120, 102, 117, 115, 101,
  58, 10, 99, 114, 111, 112, 119, 105, 100, 116, 104, 61, 123, 119, 125, 10,
  99, 114, 111, 112, 104, 101, 105, 103, 104, 116, 61, 123, 104, 125, 10, 45,
  45, 109, 117, 108, 91, 48, 93, 32, 123, 50, 42, 36, 49, 125, 10, 45,
  45, 109, 117, 108, 91, 48, 93, 32, 123, 52, 42, 36, 49, 125, 10, 45,
  99, 32, 48, 44, 50, 53, 53, 10, 45, 45, 103, 105, 109, 112, 95, 69,
  120, 112, 111, 115, 117, 114, 101, 87, 101, 105, 103, 104, 116, 77, 97, 112,
  91, 48, 93, 32, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44,
  48, 10, 45, 45, 103, 105, 109, 112, 95, 69, 120, 112, 111, 115, 117, 114,
  101, 87, 101, 105, 103, 104, 116, 77, 97, 112, 91, 49, 93, 32, 36, 50,
  44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 48, 10, 45, 45, 103, 105,
  109, 112, 95, 69, 120, 112, 111, 115, 117, 114, 101, 87, 101, 105, 103, 104,
  116, 77, 97, 112, 91, 50, 93, 32, 36, 50, 44, 36, 51, 44, 36, 52,
  44, 36, 53, 44, 48, 10, 45, 112, 97, 114, 97, 108, 108, 101, 108, 32,
  34, 10, 45, 102, 114, 101, 113, 95, 112, 121, 114, 97, 109, 105, 100, 91,
  48, 93, 34, 44, 34, 10, 45, 102, 114, 101, 113, 95, 112, 121, 114, 97,
  109, 105, 100, 91, 49, 93, 34, 44, 34, 10, 45, 102, 114, 101, 113, 95,
  112, 121, 114, 97, 109, 105, 100, 91, 50, 93, 34, 44, 34, 10, 45, 100,
  117, 109, 98, 95, 112, 121, 114, 97, 109, 105, 100, 91, 51, 93, 34, 44,
  34, 10, 45, 100, 117, 109, 98, 95, 112, 121, 114, 97, 109, 105, 100, 91,
  52, 93, 34, 44, 34, 10, 45, 100, 117, 109, 98, 95, 112, 121, 114, 97,
  109, 105, 100, 91, 53, 93, 34, 10, 45, 112, 97, 114, 97, 108, 108, 101,
  108, 32, 34, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 54, 34,
  44, 34, 45, 98, 108, 117, 114, 91, 45, 50, 93, 32, 36, 54, 34, 44,
  34, 45, 98, 108, 117, 114, 91, 45, 51, 93, 32, 36, 54, 34, 10, 45,
  114, 101, 112, 108, 97, 99, 101, 91, 45, 49, 44, 45, 50, 44, 45, 51,
  93, 32, 48, 44, 48, 46, 48, 48, 48, 48, 48, 48, 48, 48, 49, 10,
  45, 45, 97, 100, 100, 91, 45, 49, 44, 45, 50, 44, 45, 51, 93, 10,
  45, 100, 105, 118, 91, 45, 50, 93, 32, 91, 45, 49, 93, 10, 45, 100,
  105, 118, 91, 45, 51, 93, 32, 91, 45, 49, 93, 10, 45, 100, 105, 118,
  91, 45, 52, 93, 32, 91, 45, 49, 93, 10, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 112, 97, 114, 97, 108, 108, 101, 108, 32, 34, 10, 45, 109,
  117, 108, 91, 48, 93, 32, 91, 51, 93, 34, 44, 34, 10, 45, 109, 117,
  108, 91, 49, 93, 32, 91, 52, 93, 34, 44, 34, 10, 45, 109, 117, 108,
  91, 50, 93, 32, 91, 53, 93, 34, 10, 45, 97, 100, 100, 91, 48, 44,
  49, 44, 50, 93, 10, 45, 107, 101, 101, 112, 91, 48, 93, 10, 45, 105,
  102, 114, 101, 113, 95, 112, 121, 114, 97, 109, 105, 100, 91, 48, 93, 10,
  45, 99, 114, 111, 112, 32, 48, 44, 48, 44, 123, 36, 99, 114, 111, 112,
  119, 105, 100, 116, 104, 45, 49, 125, 44, 123, 36, 99, 114, 111, 112, 104,
  101, 105, 103, 104, 116, 45, 49, 125, 10, 45, 99, 32, 48, 44, 50, 53,
  53, 10, 100, 117, 109, 98, 95, 112, 121, 114, 97, 109, 105, 100, 58, 10,
  99, 114, 111, 112, 119, 105, 100, 116, 104, 61, 123, 119, 125, 10, 99, 114,
  111, 112, 104, 101, 105, 103, 104, 116, 61, 123, 104, 125, 10, 45, 114, 101,
  115, 105, 122, 101, 32, 123, 119, 43, 40, 49, 48, 50, 52, 45, 119, 37,
  49, 48, 50, 52, 41, 125, 44, 123, 104, 43, 40, 49, 48, 50, 52, 45,
  104, 37, 49, 48, 50, 52, 41, 125, 44, 49, 44, 51, 44, 48, 44, 49,
  10, 110, 101, 119, 119, 105, 100, 116, 104, 61, 123, 119, 125, 10, 45, 45,
  114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53,
  48, 37, 44, 123, 100, 125, 44, 123, 115, 125, 44, 50, 10, 45, 45, 114,
  101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48,
  37, 44, 123, 100, 125, 44, 123, 115, 125, 44, 50, 10, 45, 45, 114, 101,
  115, 105, 122, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37,
  44, 123, 100, 125, 44, 123, 115, 125, 44, 50, 10, 45, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44,
  123, 100, 125, 44, 123, 115, 125, 44, 50, 10, 45, 45, 114, 101, 115, 105,
  122, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 123,
  100, 125, 44, 123, 115, 125, 44, 50, 10, 45, 97, 112, 112, 101, 110, 100,
  32, 120, 10, 45, 114, 101, 115, 105, 122, 101, 32, 123, 36, 110, 101, 119,
  119, 105, 100, 116, 104, 42, 50, 125, 44, 49, 48, 48, 37, 44, 49, 44,
  51, 44, 48, 44, 48, 10, 105, 102, 114, 101, 113, 95, 112, 121, 114, 97,
  109, 105, 100, 58, 10, 45, 115, 112, 108, 105, 116, 32, 120, 44, 50, 10,
  45, 115, 112, 108, 105, 116, 91, 49, 93, 32, 120, 44, 50, 10, 45, 115,
  112, 108, 105, 116, 91, 50, 93, 32, 120, 44, 50, 10, 45, 115, 112, 108,
  105, 116, 91, 51, 93, 32, 120, 44, 50, 10, 45, 115, 112, 108, 105, 116,
  91, 52, 93, 32, 120, 44, 50, 10, 45, 99, 114, 111, 112, 91, 49, 93,
  32, 48, 44, 48, 44, 49, 48, 48, 37, 44, 123, 64, 123, 48, 44, 104,
  47, 50, 125, 45, 49, 125, 10, 45, 99, 114, 111, 112, 91, 50, 93, 32,
  48, 44, 48, 44, 49, 48, 48, 37, 44, 123, 64, 123, 48, 44, 104, 47,
  52, 125, 45, 49, 125, 10, 45, 99, 114, 111, 112, 91, 51, 93, 32, 48,
  44, 48, 44, 49, 48, 48, 37, 44, 123, 64, 123, 48, 44, 104, 47, 56,
  125, 45, 49, 125, 10, 45, 99, 114, 111, 112, 91, 52, 93, 32, 48, 44,
  48, 44, 49, 48, 48, 37, 44, 123, 64, 123, 48, 44, 104, 47, 49, 54,
  125, 45, 49, 125, 10, 45, 99, 114, 111, 112, 91, 53, 93, 32, 48, 44,
  48, 44, 64, 123, 52, 44, 40, 119, 47, 50, 41, 45, 49, 125, 44, 123,
  64, 123, 48, 44, 104, 47, 51, 50, 125, 45, 49, 125, 10, 45, 114, 101,
  115, 105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 45, 50, 44, 119, 125,
  44, 64, 123, 45, 50, 44, 104, 125, 44, 123, 100, 125, 44, 123, 115, 125,
  44, 51, 10, 45, 97, 100, 100, 91, 45, 49, 44, 45, 50, 93, 10, 45,
  114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 45, 50, 44,
  119, 125, 44, 64, 123, 45, 50, 44, 104, 125, 44, 123, 100, 125, 44, 123,
  115, 125, 44, 51, 10, 45, 97, 100, 100, 91, 45, 49, 44, 45, 50, 93,
  10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 45,
  50, 44, 119, 125, 44, 64, 123, 45, 50, 44, 104, 125, 44, 123, 100, 125,
  44, 123, 115, 125, 44, 51, 10, 45, 97, 100, 100, 91, 45, 49, 44, 45,
  50, 93, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 64,
  123, 45, 50, 44, 119, 125, 44, 64, 123, 45, 50, 44, 104, 125, 44, 123,
  100, 125, 44, 123, 115, 125, 44, 51, 10, 45, 97, 100, 100, 91, 45, 49,
  44, 45, 50, 93, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93,
  32, 64, 123, 45, 50, 44, 119, 125, 44, 64, 123, 45, 50, 44, 104, 125,
  44, 123, 100, 125, 44, 123, 115, 125, 44, 51, 10, 45, 97, 100, 100, 91,
  45, 49, 44, 45, 50, 93, 10, 102, 114, 101, 113, 95, 112, 121, 114, 97,
  109, 105, 100, 58, 10, 99, 114, 111, 112, 119, 105, 100, 116, 104, 61, 123,
  119, 125, 10, 99, 114, 111, 112, 104, 101, 105, 103, 104, 116, 61, 123, 104,
  125, 10, 45, 114, 101, 115, 105, 122, 101, 32, 123, 119, 43, 40, 49, 48,
  50, 52, 45, 119, 37, 49, 48, 50, 52, 41, 125, 44, 123, 104, 43, 40,
  49, 48, 50, 52, 45, 104, 37, 49, 48, 50, 52, 41, 125, 44, 49, 44,
  51, 44, 48, 44, 49, 10, 110, 101, 119, 119, 105, 100, 116, 104, 61, 123,
  119, 125, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32,
  53, 48, 37, 44, 53, 48, 37, 44, 123, 100, 125, 44, 123, 115, 125, 44,
  50, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 64,
  123, 45, 50, 44, 119, 125, 44, 64, 123, 45, 50, 44, 104, 125, 44, 123,
  100, 125, 44, 123, 115, 125, 44, 51, 10, 45, 115, 117, 98, 91, 45, 51,
  44, 45, 49, 93, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49,
  93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 123, 100, 125, 44, 123, 115,
  125, 44, 50, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93,
  32, 64, 123, 45, 50, 44, 119, 125, 44, 64, 123, 45, 50, 44, 104, 125,
  44, 123, 100, 125, 44, 123, 115, 125, 44, 51, 10, 45, 115, 117, 98, 91,
  45, 51, 44, 45, 49, 93, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91,
  45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 123, 100, 125, 44,
  123, 115, 125, 44, 50, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 45,
  49, 93, 32, 64, 123, 45, 50, 44, 119, 125, 44, 64, 123, 45, 50, 44,
  104, 125, 44, 123, 100, 125, 44, 123, 115, 125, 44, 51, 10, 45, 115, 117,
  98, 91, 45, 51, 44, 45, 49, 93, 10, 45, 45, 114, 101, 115, 105, 122,
  101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 123, 100,
  125, 44, 123, 115, 125, 44, 50, 10, 45, 45, 114, 101, 115, 105, 122, 101,
  91, 45, 49, 93, 32, 64, 123, 45, 50, 44, 119, 125, 44, 64, 123, 45,
  50, 44, 104, 125, 44, 123, 100, 125, 44, 123, 115, 125, 44, 51, 10, 45,
  115, 117, 98, 91, 45, 51, 44, 45, 49, 93, 10, 45, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44,
  123, 100, 125, 44, 123, 115, 125, 44, 50, 10, 45, 45, 114, 101, 115, 105,
  122, 101, 91, 45, 49, 93, 32, 64, 123, 45, 50, 44, 119, 125, 44, 64,
  123, 45, 50, 44, 104, 125, 44, 123, 100, 125, 44, 123, 115, 125, 44, 51,
  10, 45, 115, 117, 98, 91, 45, 51, 44, 45, 49, 93, 10, 45, 97, 112,
  112, 101, 110, 100, 32, 120, 10, 45, 114, 101, 115, 105, 122, 101, 32, 123,
  36, 110, 101, 119, 119, 105, 100, 116, 104, 42, 50, 125, 44, 49, 48, 48,
  37, 44, 49, 44, 51, 44, 48, 44, 48, 10, 35, 64, 103, 105, 109, 112,
  32, 69, 120, 102, 117, 115, 105, 111, 110, 32, 58, 32, 101, 120, 102, 117,
  115, 105, 111, 110, 44, 32, 101, 120, 102, 117, 115, 105, 111, 110, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 87, 105, 100, 116, 104, 32, 61, 32,
  102, 108, 111, 97, 116, 32, 40, 50, 48, 44, 48, 44, 53, 48, 41, 10,
  101, 120, 102, 117, 115, 105, 111, 110, 58, 10, 99, 114, 111, 112, 119, 105,
  100, 116, 104, 61, 123, 119, 125, 10, 99, 114, 111, 112, 104, 101, 105, 103,
  104, 116, 61, 123, 104, 125, 10, 45, 114, 101, 115, 105, 122, 101, 32, 123,
  119, 43, 40, 49, 48, 50, 52, 45, 119, 37, 49, 48, 50, 52, 41, 125,
  44, 123, 104, 43, 40, 49, 48, 50, 52, 45, 104, 37, 49, 48, 50, 52,
  41, 125, 44, 49, 44, 51, 44, 48, 44, 49, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 49, 48, 10, 45, 108, 91, 45, 49, 45, 45, 52, 93, 10,
  45, 45, 108, 91, 48, 44, 49, 44, 50, 44, 51, 93, 10, 45, 45, 114,
  101, 115, 105, 122, 101, 91, 48, 93, 32, 53, 48, 37, 44, 53, 48, 37,
  44, 49, 44, 51, 44, 50, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91,
  45, 49, 93, 32, 50, 48, 48, 37, 44, 50, 48, 48, 37, 44, 49, 44,
  51, 44, 51, 10, 45, 115, 117, 98, 91, 48, 44, 45, 49, 93, 10, 45,
  45, 114, 101, 115, 105, 122, 101, 91, 49, 93, 32, 53, 48, 37, 44, 53,
  48, 37, 44, 49, 44, 51, 44, 50, 10, 45, 45, 114, 101, 115, 105, 122,
  101, 91, 45, 49, 93, 32, 50, 48, 48, 37, 44, 50, 48, 48, 37, 44,
  49, 44, 51, 44, 51, 10, 45, 115, 117, 98, 91, 49, 44, 45, 49, 93,
  10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 50, 93, 32, 53, 48, 37,
  44, 53, 48, 37, 44, 49, 44, 51, 44, 50, 10, 45, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 50, 48, 48, 37, 44, 50, 48, 48,
  37, 44, 49, 44, 51, 44, 51, 10, 45, 115, 117, 98, 91, 50, 44, 45,
  49, 93, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 51, 93, 32, 53,
  48, 37, 44, 53, 48, 37, 44, 49, 44, 51, 44, 50, 10, 45, 45, 114,
  101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 50, 48, 48, 37, 44, 50,
  48, 48, 37, 44, 49, 44, 51, 44, 51, 10, 45, 115, 117, 98, 91, 51,
  44, 45, 49, 93, 10, 45, 101, 110, 100, 108, 10, 45, 45, 105, 97, 105,
  110, 95, 119, 101, 105, 103, 104, 116, 109, 97, 112, 91, 48, 93, 32, 49,
  44, 36, 49, 10, 45, 45, 105, 97, 105, 110, 95, 119, 101, 105, 103, 104,
  116, 109, 97, 112, 91, 49, 93, 32, 49, 44, 36, 49, 10, 45, 45, 105,
  97, 105, 110, 95, 119, 101, 105, 103, 104, 116, 109, 97, 112, 91, 50, 93,
  32, 49, 44, 36, 49, 10, 45, 45, 105, 97, 105, 110, 95, 119, 101, 105,
  103, 104, 116, 109, 97, 112, 91, 51, 93, 32, 49, 44, 36, 49, 10, 45,
  45, 97, 100, 100, 91, 45, 49, 44, 45, 50, 44, 45, 51, 44, 45, 52,
  93, 10, 45, 114, 101, 112, 108, 97, 99, 101, 91, 45, 49, 44, 45, 50,
  44, 45, 51, 44, 45, 52, 44, 45, 53, 93, 32, 48, 44, 48, 46, 48,
  48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 49, 10, 45, 100, 105,
  118, 91, 45, 50, 93, 32, 91, 45, 49, 93, 10, 45, 100, 105, 118, 91,
  45, 51, 93, 32, 91, 45, 49, 93, 10, 45, 100, 105, 118, 91, 45, 52,
  93, 32, 91, 45, 49, 93, 10, 45, 100, 105, 118, 91, 45, 53, 93, 32,
  91, 45, 49, 93, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 109, 117,
  108, 91, 52, 44, 49, 50, 93, 10, 45, 109, 117, 108, 91, 53, 44, 49,
  50, 93, 10, 45, 109, 117, 108, 91, 54, 44, 49, 50, 93, 10, 45, 109,
  117, 108, 91, 55, 44, 49, 50, 93, 10, 45, 97, 100, 100, 91, 52, 44,
  53, 44, 54, 44, 55, 93, 10, 45, 114, 109, 91, 48, 44, 49, 44, 50,
  44, 51, 93, 10, 45, 101, 110, 100, 108, 10, 45, 100, 111, 110, 101, 10,
  45, 108, 91, 45, 49, 44, 45, 50, 44, 45, 51, 44, 45, 52, 93, 10,
  45, 112, 97, 114, 97, 108, 108, 101, 108, 32, 34, 10, 45, 45, 105, 97,
  105, 110, 95, 119, 101, 105, 103, 104, 116, 109, 97, 112, 91, 48, 93, 32,
  52, 44, 36, 49, 34, 44, 34, 10, 45, 45, 105, 97, 105, 110, 95, 119,
  101, 105, 103, 104, 116, 109, 97, 112, 91, 49, 93, 32, 52, 44, 36, 49,
  34, 44, 34, 10, 45, 45, 105, 97, 105, 110, 95, 119, 101, 105, 103, 104,
  116, 109, 97, 112, 91, 50, 93, 32, 52, 44, 36, 49, 34, 44, 34, 10,
  45, 45, 105, 97, 105, 110, 95, 119, 101, 105, 103, 104, 116, 109, 97, 112,
  91, 51, 93, 32, 52, 44, 36, 49, 34, 10, 45, 45, 97, 100, 100, 91,
  45, 49, 44, 45, 50, 44, 45, 51, 44, 45, 52, 93, 10, 45, 114, 101,
  112, 108, 97, 99, 101, 91, 45, 49, 44, 45, 50, 44, 45, 51, 44, 45,
  52, 44, 45, 53, 93, 32, 48, 44, 48, 46, 48, 48, 48, 48, 48, 48,
  48, 48, 48, 48, 48, 48, 48, 49, 10, 45, 100, 105, 118, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 10, 45, 100, 105, 118, 91, 45, 51, 93, 32,
  91, 45, 49, 93, 10, 45, 100, 105, 118, 91, 45, 52, 93, 32, 91, 45,
  49, 93, 10, 45, 100, 105, 118, 91, 45, 53, 93, 32, 91, 45, 49, 93,
  10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 109, 117, 108, 91, 48, 44,
  52, 93, 10, 45, 109, 117, 108, 91, 49, 44, 52, 93, 10, 45, 109, 117,
  108, 91, 50, 44, 52, 93, 10, 45, 109, 117, 108, 91, 51, 44, 52, 93,
  10, 45, 97, 100, 100, 10, 45, 101, 110, 100, 108, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 10, 45, 114, 101, 115, 105,
  122, 101, 91, 45, 49, 93, 32, 64, 123, 45, 50, 44, 119, 125, 44, 64,
  123, 45, 50, 44, 104, 125, 44, 49, 44, 51, 44, 51, 10, 45, 97, 100,
  100, 91, 45, 49, 44, 45, 50, 93, 10, 45, 100, 111, 110, 101, 10, 45,
  99, 114, 111, 112, 32, 48, 44, 48, 44, 123, 36, 99, 114, 111, 112, 119,
  105, 100, 116, 104, 45, 49, 125, 44, 123, 36, 99, 114, 111, 112, 104, 101,
  105, 103, 104, 116, 45, 49, 125, 10, 45, 45, 108, 91, 48, 93, 10, 45,
  114, 101, 115, 105, 122, 101, 32, 53, 37, 44, 53, 37, 44, 49, 44, 51,
  44, 50, 10, 45, 101, 110, 100, 108, 10, 109, 105, 110, 61, 64, 123, 49,
  44, 105, 109, 125, 10, 109, 97, 120, 61, 64, 123, 49, 44, 105, 77, 125,
  10, 45, 99, 91, 48, 93, 32, 36, 109, 105, 110, 44, 36, 109, 97, 120,
  10, 45, 107, 101, 101, 112, 91, 48, 93, 10, 45, 110, 32, 48, 44, 50,
  53, 53, 10, 35, 64, 103, 105, 109, 112, 32, 69, 120, 102, 117, 115, 105,
  111, 110, 51, 32, 58, 32, 101, 120, 102, 117, 115, 105, 111, 110, 51, 44,
  32, 101, 120, 102, 117, 115, 105, 111, 110, 51, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 110, 116, 114, 97, 115, 116, 32, 98, 105, 97,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 51, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 97, 116, 117,
  114, 97, 116, 105, 111, 110, 32, 98, 105, 97, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 51, 44, 48, 44, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 69, 120, 112, 111, 115, 117, 114, 101, 32, 115,
  105, 103, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 50,
  44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69,
  120, 112, 111, 115, 117, 114, 101, 32, 98, 105, 97, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 51, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 77, 97, 120, 108, 101, 118, 101, 108, 115, 32, 97, 100, 106, 117,
  115, 116, 32, 61, 32, 105, 110, 116, 40, 45, 49, 44, 45, 53, 44, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 97, 115, 101, 32,
  108, 101, 118, 101, 108, 32, 109, 101, 100, 105, 97, 110, 32, 115, 116, 97,
  99, 107, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 80, 121,
  114, 97, 109, 105, 100, 32, 108, 101, 118, 101, 108, 115, 32, 97, 114, 101,
  32, 99, 97, 108, 99, 117, 108, 97, 116, 101, 100, 32, 97, 117, 116, 111,
  109, 97, 116, 105, 99, 97, 108, 108, 121, 44, 32, 98, 117, 116, 32, 121,
  111, 117, 32, 99, 97, 110, 32, 114, 101, 100, 117, 99, 101, 32, 116, 104,
  101, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 112, 121, 114, 97,
  109, 105, 100, 32, 108, 101, 118, 101, 108, 115, 32, 116, 111, 32, 115, 97,
  118, 101, 32, 109, 101, 109, 111, 114, 121, 46, 32, 89, 111, 117, 32, 99,
  97, 110, 32, 99, 104, 111, 111, 115, 101, 32, 104, 111, 119, 32, 116, 104,
  101, 32, 98, 97, 115, 101, 32, 108, 101, 118, 101, 108, 32, 105, 115, 32,
  102, 117, 115, 101, 100, 44, 32, 98, 121, 32, 117, 115, 105, 110, 103, 32,
  119, 101, 105, 103, 104, 116, 32, 109, 97, 112, 115, 32, 108, 105, 107, 101,
  32, 110, 111, 114, 109, 97, 108, 44, 32, 111, 114, 32, 98, 121, 32, 117,
  115, 105, 110, 103, 32, 97, 32, 109, 101, 100, 105, 97, 110, 32, 111, 102,
  32, 116, 104, 101, 32, 105, 109, 97, 103, 101, 32, 115, 116, 97, 99, 107,
  34, 41, 10, 101, 120, 102, 117, 115, 105, 111, 110, 51, 58, 10, 99, 114,
  111, 112, 119, 105, 100, 116, 104, 61, 123, 119, 125, 10, 99, 114, 111, 112,
  104, 101, 105, 103, 104, 116, 61, 123, 104, 125, 10, 109, 97, 120, 108, 101,
  118, 101, 108, 115, 61, 123, 114, 111, 117, 110, 100, 40, 108, 111, 103, 50,
  40, 109, 105, 110, 40, 119, 44, 104, 41, 41, 43, 48, 46, 53, 41, 43,
  36, 53, 125, 10, 115, 105, 122, 101, 61, 123, 50, 94, 36, 109, 97, 120,
  108, 101, 118, 101, 108, 115, 125, 10, 45, 114, 101, 115, 105, 122, 101, 32,
  123, 119, 43, 40, 36, 115, 105, 122, 101, 45, 119, 37, 36, 115, 105, 122,
  101, 41, 125, 44, 123, 104, 43, 40, 36, 115, 105, 122, 101, 45, 104, 37,
  36, 115, 105, 122, 101, 41, 125, 44, 49, 44, 51, 44, 48, 44, 49, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 36, 109, 97, 120, 108, 101, 118, 101,
  108, 115, 10, 45, 108, 91, 45, 49, 45, 45, 51, 93, 10, 45, 45, 108,
  91, 48, 44, 49, 44, 50, 93, 10, 45, 45, 114, 101, 115, 105, 122, 101,
  91, 48, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 49, 44, 51, 44,
  50, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 50,
  48, 48, 37, 44, 50, 48, 48, 37, 44, 49, 44, 51, 44, 53, 10, 45,
  115, 117, 98, 91, 48, 44, 45, 49, 93, 10, 45, 45, 114, 101, 115, 105,
  122, 101, 91, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 49, 44,
  51, 44, 50, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93,
  32, 50, 48, 48, 37, 44, 50, 48, 48, 37, 44, 49, 44, 51, 44, 53,
  10, 45, 115, 117, 98, 91, 49, 44, 45, 49, 93, 10, 45, 45, 114, 101,
  115, 105, 122, 101, 91, 50, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44,
  49, 44, 51, 44, 50, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 45,
  49, 93, 32, 50, 48, 48, 37, 44, 50, 48, 48, 37, 44, 49, 44, 51,
  44, 53, 10, 45, 115, 117, 98, 91, 50, 44, 45, 49, 93, 10, 45, 101,
  110, 100, 108, 10, 91, 48, 93, 10, 45, 103, 105, 109, 112, 95, 69, 120,
  112, 111, 115, 117, 114, 101, 87, 101, 105, 103, 104, 116, 77, 97, 112, 91,
  45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44,
  48, 10, 91, 49, 93, 10, 45, 103, 105, 109, 112, 95, 69, 120, 112, 111,
  115, 117, 114, 101, 87, 101, 105, 103, 104, 116, 77, 97, 112, 91, 45, 49,
  93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 48, 10,
  91, 50, 93, 10, 45, 103, 105, 109, 112, 95, 69, 120, 112, 111, 115, 117,
  114, 101, 87, 101, 105, 103, 104, 116, 77, 97, 112, 91, 45, 49, 93, 32,
  36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 48, 10, 45, 114,
  109, 91, 48, 44, 49, 44, 50, 93, 10, 45, 45, 97, 100, 100, 91, 45,
  49, 44, 45, 50, 44, 45, 51, 93, 10, 45, 114, 101, 112, 108, 97, 99,
  101, 91, 45, 49, 44, 45, 50, 44, 45, 51, 44, 45, 52, 93, 32, 48,
  44, 48, 46, 48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 49,
  10, 45, 100, 105, 118, 91, 45, 50, 93, 32, 91, 45, 49, 93, 10, 45,
  100, 105, 118, 91, 45, 51, 93, 32, 91, 45, 49, 93, 10, 45, 100, 105,
  118, 91, 45, 52, 93, 32, 91, 45, 49, 93, 10, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 109, 117, 108, 91, 48, 44, 54, 93, 10, 45, 109, 117,
  108, 91, 49, 44, 54, 93, 10, 45, 109, 117, 108, 91, 50, 44, 54, 93,
  10, 45, 97, 100, 100, 91, 48, 44, 49, 44, 50, 93, 10, 45, 101, 110,
  100, 108, 10, 45, 100, 111, 110, 101, 10, 45, 108, 91, 45, 49, 44, 45,
  50, 44, 45, 51, 93, 10, 45, 105, 102, 32, 36, 54, 10, 45, 105, 97,
  105, 110, 95, 102, 97, 115, 116, 95, 109, 101, 100, 105, 97, 110, 95, 115,
  116, 97, 99, 107, 10, 45, 101, 108, 115, 101, 10, 91, 48, 93, 10, 91,
  49, 93, 10, 91, 50, 93, 10, 45, 112, 97, 114, 97, 108, 108, 101, 108,
  32, 34, 10, 45, 103, 105, 109, 112, 95, 69, 120, 112, 111, 115, 117, 114,
  101, 87, 101, 105, 103, 104, 116, 77, 97, 112, 91, 45, 49, 93, 32, 36,
  49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 48, 34, 44, 34, 10,
  45, 103, 105, 109, 112, 95, 69, 120, 112, 111, 115, 117, 114, 101, 87, 101,
  105, 103, 104, 116, 77, 97, 112, 91, 45, 50, 93, 32, 36, 49, 44, 36,
  50, 44, 36, 51, 44, 36, 52, 44, 48, 34, 44, 34, 10, 45, 103, 105,
  109, 112, 95, 69, 120, 112, 111, 115, 117, 114, 101, 87, 101, 105, 103, 104,
  116, 77, 97, 112, 91, 45, 51, 93, 32, 36, 49, 44, 36, 50, 44, 36,
  51, 44, 36, 52, 44, 48, 34, 10, 45, 45, 97, 100, 100, 91, 45, 49,
  44, 45, 50, 44, 45, 51, 93, 10, 45, 114, 101, 112, 108, 97, 99, 101,
  91, 45, 49, 44, 45, 50, 44, 45, 51, 44, 45, 52, 93, 32, 48, 44,
  48, 46, 48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 49, 10,
  45, 100, 105, 118, 91, 45, 50, 93, 32, 91, 45, 49, 93, 10, 45, 100,
  105, 118, 91, 45, 51, 93, 32, 91, 45, 49, 93, 10, 45, 100, 105, 118,
  91, 45, 52, 93, 32, 91, 45, 49, 93, 10, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 109, 117, 108, 91, 48, 44, 51, 93, 10, 45, 109, 117, 108,
  91, 49, 44, 51, 93, 10, 45, 109, 117, 108, 91, 50, 44, 51, 93, 10,
  45, 97, 100, 100, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  108, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125,
  10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 45,
  50, 44, 119, 125, 44, 64, 123, 45, 50, 44, 104, 125, 44, 49, 44, 51,
  44, 53, 10, 45, 97, 100, 100, 91, 45, 49, 44, 45, 50, 93, 10, 45,
  100, 111, 110, 101, 10, 45, 99, 114, 111, 112, 32, 48, 44, 48, 44, 123,
  36, 99, 114, 111, 112, 119, 105, 100, 116, 104, 45, 49, 125, 44, 123, 36,
  99, 114, 111, 112, 104, 101, 105, 103, 104, 116, 45, 49, 125, 10, 45, 45,
  108, 91, 48, 93, 10, 45, 114, 101, 115, 105, 122, 101, 32, 53, 37, 44,
  53, 37, 44, 49, 44, 51, 44, 50, 10, 45, 101, 110, 100, 108, 10, 109,
  105, 110, 61, 64, 123, 49, 44, 105, 109, 125, 10, 109, 97, 120, 61, 64,
  123, 49, 44, 105, 77, 125, 10, 45, 99, 91, 48, 93, 32, 36, 109, 105,
  110, 44, 36, 109, 97, 120, 10, 45, 107, 101, 101, 112, 91, 48, 93, 10,
  45, 110, 32, 48, 44, 50, 53, 53, 10, 35, 64, 103, 105, 109, 112, 32,
  69, 120, 102, 117, 115, 105, 111, 110, 53, 32, 58, 32, 101, 120, 102, 117,
  115, 105, 111, 110, 53, 44, 32, 101, 120, 102, 117, 115, 105, 111, 110, 53,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116, 114, 97,
  115, 116, 32, 98, 105, 97, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 32, 98, 105, 97, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 46, 50, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 120, 112, 111, 115, 117, 114,
  101, 32, 115, 105, 103, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 50, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 69, 120, 112, 111, 115, 117, 114, 101, 32, 98, 105, 97, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  80, 111, 115, 116, 32, 70, 117, 115, 105, 111, 110, 32, 79, 112, 116, 105,
  111, 110, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76,
  111, 99, 97, 108, 32, 99, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32,
  102, 108, 111, 97, 116, 32, 40, 48, 44, 48, 44, 51, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 117, 114, 118, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 32, 40, 48, 44, 45, 49, 50, 55, 44, 49, 50, 55,
  41, 10, 101, 120, 102, 117, 115, 105, 111, 110, 53, 58, 10, 105, 109, 97,
  103, 101, 115, 61, 64, 35, 10, 99, 114, 111, 112, 119, 105, 100, 116, 104,
  61, 123, 119, 125, 10, 99, 114, 111, 112, 104, 101, 105, 103, 104, 116, 61,
  123, 104, 125, 10, 109, 97, 120, 108, 101, 118, 101, 108, 115, 61, 123, 114,
  111, 117, 110, 100, 40, 108, 111, 103, 50, 40, 109, 105, 110, 40, 119, 44,
  104, 41, 41, 43, 48, 46, 53, 41, 43, 48, 125, 10, 115, 105, 122, 101,
  61, 123, 50, 94, 36, 109, 97, 120, 108, 101, 118, 101, 108, 115, 125, 10,
  45, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 10,
  45, 114, 101, 115, 105, 122, 101, 32, 123, 119, 43, 40, 36, 115, 105, 122,
  101, 45, 119, 37, 36, 115, 105, 122, 101, 41, 125, 44, 123, 104, 43, 40,
  36, 115, 105, 122, 101, 45, 104, 37, 36, 115, 105, 122, 101, 41, 125, 44,
  49, 44, 51, 44, 48, 44, 49, 44, 48, 46, 53, 44, 48, 46, 53, 10,
  45, 45, 108, 91, 48, 45, 123, 36, 105, 109, 97, 103, 101, 115, 45, 49,
  125, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  111, 99, 97, 108, 91, 64, 123, 62, 44, 45, 49, 125, 93, 10, 45, 103,
  105, 109, 112, 95, 69, 120, 112, 111, 115, 117, 114, 101, 87, 101, 105, 103,
  104, 116, 77, 97, 112, 91, 48, 93, 32, 36, 49, 44, 36, 50, 44, 36,
  51, 44, 36, 52, 44, 48, 10, 45, 101, 110, 100, 108, 111, 99, 97, 108,
  32, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 108, 10, 45, 108, 91,
  45, 49, 45, 45, 36, 105, 109, 97, 103, 101, 115, 93, 10, 45, 45, 97,
  100, 100, 10, 45, 114, 101, 112, 108, 97, 99, 101, 32, 48, 44, 48, 46,
  48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 49, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 10, 45, 100, 105,
  118, 91, 64, 123, 60, 44, 45, 49, 125, 93, 32, 91, 45, 49, 93, 10,
  45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101,
  110, 100, 108, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 109, 97, 120,
  108, 101, 118, 101, 108, 115, 10, 45, 108, 91, 45, 49, 45, 45, 123, 36,
  105, 109, 97, 103, 101, 115, 42, 50, 125, 93, 10, 45, 45, 108, 91, 48,
  45, 123, 36, 105, 109, 97, 103, 101, 115, 45, 49, 125, 93, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 111, 99, 97, 108, 91,
  64, 123, 62, 44, 45, 49, 125, 93, 10, 45, 45, 114, 101, 115, 105, 122,
  101, 91, 48, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 49, 44, 51,
  44, 50, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 50,
  48, 48, 37, 44, 50, 48, 48, 37, 44, 49, 44, 51, 44, 53, 44, 48,
  10, 45, 115, 117, 98, 91, 48, 44, 45, 49, 93, 10, 45, 101, 110, 100,
  108, 111, 99, 97, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100,
  108, 10, 45, 108, 91, 45, 49, 45, 45, 123, 36, 105, 109, 97, 103, 101,
  115, 42, 50, 125, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 105,
  109, 97, 103, 101, 115, 32, 45, 108, 111, 99, 97, 108, 91, 64, 123, 62,
  44, 45, 49, 125, 44, 123, 64, 123, 62, 44, 45, 49, 125, 43, 36, 105,
  109, 97, 103, 101, 115, 125, 93, 10, 45, 109, 117, 108, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 10, 45, 101, 110, 100, 108, 111, 99, 97, 108, 32,
  45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 108, 10, 45, 108, 91, 45,
  49, 45, 45, 36, 105, 109, 97, 103, 101, 115, 93, 10, 45, 97, 100, 100,
  10, 45, 101, 110, 100, 108, 10, 45, 109, 111, 118, 101, 91, 45, 49, 93,
  32, 48, 10, 45, 108, 91, 45, 49, 45, 45, 123, 36, 105, 109, 97, 103,
  101, 115, 42, 50, 125, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 111, 99, 97, 108, 91, 64, 123, 62, 44, 45, 49, 125,
  93, 10, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 53, 48, 37,
  44, 53, 48, 37, 44, 49, 44, 51, 44, 50, 10, 45, 101, 110, 100, 108,
  111, 99, 97, 108, 32, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 108,
  10, 45, 101, 110, 100, 108, 10, 45, 100, 111, 110, 101, 10, 45, 108, 91,
  45, 49, 45, 45, 123, 36, 105, 109, 97, 103, 101, 115, 42, 50, 125, 93,
  10, 45, 105, 102, 32, 49, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36,
  105, 109, 97, 103, 101, 115, 32, 45, 108, 111, 99, 97, 108, 91, 64, 123,
  62, 44, 45, 49, 125, 44, 123, 64, 123, 62, 44, 45, 49, 125, 43, 36,
  105, 109, 97, 103, 101, 115, 125, 93, 10, 45, 109, 117, 108, 91, 45, 49,
  93, 32, 91, 45, 50, 93, 10, 45, 101, 110, 100, 108, 111, 99, 97, 108,
  32, 45, 100, 111, 110, 101, 10, 45, 107, 101, 101, 112, 91, 45, 49, 45,
  45, 36, 105, 109, 97, 103, 101, 115, 93, 10, 45, 97, 100, 100, 10, 45,
  101, 108, 115, 101, 10, 45, 107, 101, 101, 112, 91, 48, 45, 45, 123, 36,
  105, 109, 97, 103, 101, 115, 45, 49, 125, 93, 10, 45, 97, 100, 100, 10,
  45, 100, 105, 118, 32, 36, 105, 109, 97, 103, 101, 115, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 110, 100, 108, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 64, 35, 45, 49, 125, 10, 45, 114, 101, 115, 105, 122, 101,
  91, 45, 49, 93, 32, 64, 123, 45, 50, 44, 119, 125, 44, 64, 123, 45,
  50, 44, 104, 125, 44, 49, 44, 51, 44, 53, 44, 48, 10, 45, 97, 100,
  100, 91, 45, 49, 44, 45, 50, 93, 10, 45, 100, 111, 110, 101, 10, 45,
  114, 101, 115, 105, 122, 101, 32, 36, 99, 114, 111, 112, 119, 105, 100, 116,
  104, 44, 36, 99, 114, 111, 112, 104, 101, 105, 103, 104, 116, 44, 49, 44,
  51, 44, 48, 44, 49, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 110,
  32, 48, 44, 50, 53, 53, 10, 45, 109, 117, 108, 32, 49, 48, 48, 48,
  10, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 32, 49, 44,
  48, 44, 48, 44, 49, 50, 56, 48, 48, 48, 44, 123, 40, 36, 54, 42,
  49, 48, 48, 48, 41, 43, 49, 50, 56, 48, 48, 48, 125, 44, 50, 53,
  53, 48, 48, 48, 44, 50, 53, 53, 48, 48, 48, 10, 45, 109, 117, 108,
  32, 48, 46, 48, 48, 49, 10, 45, 45, 105, 97, 105, 110, 95, 102, 97,
  115, 116, 95, 100, 101, 110, 111, 105, 115, 101, 32, 36, 53, 44, 36, 53,
  44, 49, 44, 123, 36, 53, 47, 49, 48, 48, 125, 44, 48, 10, 45, 115,
  117, 98, 91, 49, 93, 32, 91, 48, 93, 10, 45, 109, 117, 108, 91, 49,
  93, 32, 45, 49, 10, 45, 45, 97, 100, 100, 10, 45, 99, 32, 48, 44,
  50, 53, 53, 10, 45, 114, 109, 91, 49, 93, 10, 45, 114, 101, 118, 101,
  114, 115, 101, 10, 45, 114, 103, 98, 50, 108, 99, 104, 10, 45, 115, 112,
  108, 105, 116, 32, 99, 10, 45, 107, 101, 101, 112, 91, 48, 44, 52, 44,
  53, 93, 10, 45, 97, 112, 112, 101, 110, 100, 32, 99, 10, 45, 108, 99,
  104, 50, 114, 103, 98, 10, 35, 64, 103, 105, 109, 112, 32, 70, 97, 115,
  116, 32, 102, 111, 114, 109, 117, 108, 97, 32, 58, 32, 105, 97, 105, 110,
  95, 102, 97, 115, 116, 95, 102, 111, 114, 109, 117, 108, 97, 44, 32, 105,
  97, 105, 110, 95, 102, 97, 115, 116, 95, 102, 111, 114, 109, 117, 108, 97,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 112, 112, 108, 121, 32,
  102, 111, 114, 109, 117, 108, 97, 32, 61, 32, 116, 101, 120, 116, 40, 34,
  45, 97, 112, 112, 108, 121, 95, 103, 97, 109, 109, 97, 32, 50, 46, 50,
  34, 41, 10, 105, 97, 105, 110, 95, 102, 97, 115, 116, 95, 102, 111, 114,
  109, 117, 108, 97, 58, 10, 50, 53, 54, 44, 49, 10, 45, 102, 105, 108,
  108, 91, 45, 49, 93, 32, 120, 10, 45, 108, 111, 99, 97, 108, 91, 49,
  93, 10, 36, 49, 10, 45, 101, 110, 100, 108, 111, 99, 97, 108, 10, 99,
  114, 118, 48, 61, 64, 123, 49, 44, 48, 125, 10, 99, 114, 118, 49, 61,
  64, 123, 49, 44, 49, 125, 10, 99, 114, 118, 50, 61, 64, 123, 49, 44,
  50, 125, 10, 99, 114, 118, 51, 61, 64, 123, 49, 44, 51, 125, 10, 99,
  114, 118, 52, 61, 64, 123, 49, 44, 52, 125, 10, 99, 114, 118, 53, 61,
  64, 123, 49, 44, 53, 125, 10, 99, 114, 118, 54, 61, 64, 123, 49, 44,
  54, 125, 10, 99, 114, 118, 55, 61, 64, 123, 49, 44, 55, 125, 10, 99,
  114, 118, 56, 61, 64, 123, 49, 44, 56, 125, 10, 99, 114, 118, 57, 61,
  64, 123, 49, 44, 57, 125, 10, 99, 114, 118, 49, 48, 61, 64, 123, 49,
  44, 49, 48, 125, 10, 99, 114, 118, 49, 49, 61, 64, 123, 49, 44, 49,
  49, 125, 10, 99, 114, 118, 49, 50, 61, 64, 123, 49, 44, 49, 50, 125,
  10, 99, 114, 118, 49, 51, 61, 64, 123, 49, 44, 49, 51, 125, 10, 99,
  114, 118, 49, 52, 61, 64, 123, 49, 44, 49, 52, 125, 10, 99, 114, 118,
  49, 53, 61, 64, 123, 49, 44, 49, 53, 125, 10, 99, 114, 118, 49, 54,
  61, 64, 123, 49, 44, 49, 54, 125, 10, 99, 114, 118, 49, 55, 61, 64,
  123, 49, 44, 49, 55, 125, 10, 99, 114, 118, 49, 56, 61, 64, 123, 49,
  44, 49, 56, 125, 10, 99, 114, 118, 49, 57, 61, 64, 123, 49, 44, 49,
  57, 125, 10, 99, 114, 118, 50, 48, 61, 64, 123, 49, 44, 50, 48, 125,
  10, 99, 114, 118, 50, 49, 61, 64, 123, 49, 44, 50, 49, 125, 10, 99,
  114, 118, 50, 50, 61, 64, 123, 49, 44, 50, 50, 125, 10, 99, 114, 118,
  50, 51, 61, 64, 123, 49, 44, 50, 51, 125, 10, 99, 114, 118, 50, 52,
  61, 64, 123, 49, 44, 50, 52, 125, 10, 99, 114, 118, 50, 53, 61, 64,
  123, 49, 44, 50, 53, 125, 10, 99, 114, 118, 50, 54, 61, 64, 123, 49,
  44, 50, 54, 125, 10, 99, 114, 118, 50, 55, 61, 64, 123, 49, 44, 50,
  55, 125, 10, 99, 114, 118, 50, 56, 61, 64, 123, 49, 44, 50, 56, 125,
  10, 99, 114, 118, 50, 57, 61, 64, 123, 49, 44, 50, 57, 125, 10, 99,
  114, 118, 51, 48, 61, 64, 123, 49, 44, 51, 48, 125, 10, 99, 114, 118,
  51, 49, 61, 64, 123, 49, 44, 51, 49, 125, 10, 99, 114, 118, 51, 50,
  61, 64, 123, 49, 44, 51, 50, 125, 10, 99, 114, 118, 51, 51, 61, 64,
  123, 49, 44, 51, 51, 125, 10, 99, 114, 118, 51, 52, 61, 64, 123, 49,
  44, 51, 52, 125, 10, 99, 114, 118, 51, 53, 61, 64, 123, 49, 44, 51,
  53, 125, 10, 99, 114, 118, 51, 54, 61, 64, 123, 49, 44, 51, 54, 125,
  10, 99, 114, 118, 51, 55, 61, 64, 123, 49, 44, 51, 55, 125, 10, 99,
  114, 118, 51, 56, 61, 64, 123, 49, 44, 51, 56, 125, 10, 99, 114, 118,
  51, 57, 61, 64, 123, 49, 44, 51, 57, 125, 10, 99, 114, 118, 52, 48,
  61, 64, 123, 49, 44, 52, 48, 125, 10, 99, 114, 118, 52, 49, 61, 64,
  123, 49, 44, 52, 49, 125, 10, 99, 114, 118, 52, 50, 61, 64, 123, 49,
  44, 52, 50, 125, 10, 99, 114, 118, 52, 51, 61, 64, 123, 49, 44, 52,
  51, 125, 10, 99, 114, 118, 52, 52, 61, 64, 123, 49, 44, 52, 52, 125,
  10, 99, 114, 118, 52, 53, 61, 64, 123, 49, 44, 52, 53, 125, 10, 99,
  114, 118, 52, 54, 61, 64, 123, 49, 44, 52, 54, 125, 10, 99, 114, 118,
  52, 55, 61, 64, 123, 49, 44, 52, 55, 125, 10, 99, 114, 118, 52, 56,
  61, 64, 123, 49, 44, 52, 56, 125, 10, 99, 114, 118, 52, 57, 61, 64,
  123, 49, 44, 52, 57, 125, 10, 99, 114, 118, 53, 48, 61, 64, 123, 49,
  44, 53, 48, 125, 10, 99, 114, 118, 53, 49, 61, 64, 123, 49, 44, 53,
  49, 125, 10, 99, 114, 118, 53, 50, 61, 64, 123, 49, 44, 53, 50, 125,
  10, 99, 114, 118, 53, 51, 61, 64, 123, 49, 44, 53, 51, 125, 10, 99,
  114, 118, 53, 52, 61, 64, 123, 49, 44, 53, 52, 125, 10, 99, 114, 118,
  53, 53, 61, 64, 123, 49, 44, 53, 53, 125, 10, 99, 114, 118, 53, 54,
  61, 64, 123, 49, 44, 53, 54, 125, 10, 99, 114, 118, 53, 55, 61, 64,
  123, 49, 44, 53, 55, 125, 10, 99, 114, 118, 53, 56, 61, 64, 123, 49,
  44, 53, 56, 125, 10, 99, 114, 118, 53, 57, 61, 64, 123, 49, 44, 53,
  57, 125, 10, 99, 114, 118, 54, 48, 61, 64, 123, 49, 44, 54, 48, 125,
  10, 99, 114, 118, 54, 49, 61, 64, 123, 49, 44, 54, 49, 125, 10, 99,
  114, 118, 54, 50, 61, 64, 123, 49, 44, 54, 50, 125, 10, 99, 114, 118,
  54, 51, 61, 64, 123, 49, 44, 54, 51, 125, 10, 99, 114, 118, 54, 52,
  61, 64, 123, 49, 44, 54, 52, 125, 10, 99, 114, 118, 54, 53, 61, 64,
  123, 49, 44, 54, 53, 125, 10, 99, 114, 118, 54, 54, 61, 64, 123, 49,
  44, 54, 54, 125, 10, 99, 114, 118, 54, 55, 61, 64, 123, 49, 44, 54,
  55, 125, 10, 99, 114, 118, 54, 56, 61, 64, 123, 49, 44, 54, 56, 125,
  10, 99, 114, 118, 54, 57, 61, 64, 123, 49, 44, 54, 57, 125, 10, 99,
  114, 118, 55, 48, 61, 64, 123, 49, 44, 55, 48, 125, 10, 99, 114, 118,
  55, 49, 61, 64, 123, 49, 44, 55, 49, 125, 10, 99, 114, 118, 55, 50,
  61, 64, 123, 49, 44, 55, 50, 125, 10, 99, 114, 118, 55, 51, 61, 64,
  123, 49, 44, 55, 51, 125, 10, 99, 114, 118, 55, 52, 61, 64, 123, 49,
  44, 55, 52, 125, 10, 99, 114, 118, 55, 53, 61, 64, 123, 49, 44, 55,
  53, 125, 10, 99, 114, 118, 55, 54, 61, 64, 123, 49, 44, 55, 54, 125,
  10, 99, 114, 118, 55, 55, 61, 64, 123, 49, 44, 55, 55, 125, 10, 99,
  114, 118, 55, 56, 61, 64, 123, 49, 44, 55, 56, 125, 10, 99, 114, 118,
  55, 57, 61, 64, 123, 49, 44, 55, 57, 125, 10, 99, 114, 118, 56, 48,
  61, 64, 123, 49, 44, 56, 48, 125, 10, 99, 114, 118, 56, 49, 61, 64,
  123, 49, 44, 56, 49, 125, 10, 99, 114, 118, 56, 50, 61, 64, 123, 49,
  44, 56, 50, 125, 10, 99, 114, 118, 56, 51, 61, 64, 123, 49, 44, 56,
  51, 125, 10, 99, 114, 118, 56, 52, 61, 64, 123, 49, 44, 56, 52, 125,
  10, 99, 114, 118, 56, 53, 61, 64, 123, 49, 44, 56, 53, 125, 10, 99,
  114, 118, 56, 54, 61, 64, 123, 49, 44, 56, 54, 125, 10, 99, 114, 118,
  56, 55, 61, 64, 123, 49, 44, 56, 55, 125, 10, 99, 114, 118, 56, 56,
  61, 64, 123, 49, 44, 56, 56, 125, 10, 99, 114, 118, 56, 57, 61, 64,
  123, 49, 44, 56, 57, 125, 10, 99, 114, 118, 57, 48, 61, 64, 123, 49,
  44, 57, 48, 125, 10, 99, 114, 118, 57, 49, 61, 64, 123, 49, 44, 57,
  49, 125, 10, 99, 114, 118, 57, 50, 61, 64, 123, 49, 44, 57, 50, 125,
  10, 99, 114, 118, 57, 51, 61, 64, 123, 49, 44, 57, 51, 125, 10, 99,
  114, 118, 57, 52, 61, 64, 123, 49, 44, 57, 52, 125, 10, 99, 114, 118,
  57, 53, 61, 64, 123, 49, 44, 57, 53, 125, 10, 99, 114, 118, 57, 54,
  61, 64, 123, 49, 44, 57, 54, 125, 10, 99, 114, 118, 57, 55, 61, 64,
  123, 49, 44, 57, 55, 125, 10, 99, 114, 118, 57, 56, 61, 64, 123, 49,
  44, 57, 56, 125, 10, 99, 114, 118, 57, 57, 61, 64, 123, 49, 44, 57,
  57, 125, 10, 99, 114, 118, 49, 48, 48, 61, 64, 123, 49, 44, 49, 48,
  48, 125, 10, 99, 114, 118, 49, 48, 49, 61, 64, 123, 49, 44, 49, 48,
  49, 125, 10, 99, 114, 118, 49, 48, 50, 61, 64, 123, 49, 44, 49, 48,
  50, 125, 10, 99, 114, 118, 49, 48, 51, 61, 64, 123, 49, 44, 49, 48,
  51, 125, 10, 99, 114, 118, 49, 48, 52, 61, 64, 123, 49, 44, 49, 48,
  52, 125, 10, 99, 114, 118, 49, 48, 53, 61, 64, 123, 49, 44, 49, 48,
  53, 125, 10, 99, 114, 118, 49, 48, 54, 61, 64, 123, 49, 44, 49, 48,
  54, 125, 10, 99, 114, 118, 49, 48, 55, 61, 64, 123, 49, 44, 49, 48,
  55, 125, 10, 99, 114, 118, 49, 48, 56, 61, 64, 123, 49, 44, 49, 48,
  56, 125, 10, 99, 114, 118, 49, 48, 57, 61, 64, 123, 49, 44, 49, 48,
  57, 125, 10, 99, 114, 118, 49, 49, 48, 61, 64, 123, 49, 44, 49, 49,
  48, 125, 10, 99, 114, 118, 49, 49, 49, 61, 64, 123, 49, 44, 49, 49,
  49, 125, 10, 99, 114, 118, 49, 49, 50, 61, 64, 123, 49, 44, 49, 49,
  50, 125, 10, 99, 114, 118, 49, 49, 51, 61, 64, 123, 49, 44, 49, 49,
  51, 125, 10, 99, 114, 118, 49, 49, 52, 61, 64, 123, 49, 44, 49, 49,
  52, 125, 10, 99, 114, 118, 49, 49, 53, 61, 64, 123, 49, 44, 49, 49,
  53, 125, 10, 99, 114, 118, 49, 49, 54, 61, 64, 123, 49, 44, 49, 49,
  54, 125, 10, 99, 114, 118, 49, 49, 55, 61, 64, 123, 49, 44, 49, 49,
  55, 125, 10, 99, 114, 118, 49, 49, 56, 61, 64, 123, 49, 44, 49, 49,
  56, 125, 10, 99, 114, 118, 49, 49, 57, 61, 64, 123, 49, 44, 49, 49,
  57, 125, 10, 99, 114, 118, 49, 50, 48, 61, 64, 123, 49, 44, 49, 50,
  48, 125, 10, 99, 114, 118, 49, 50, 49, 61, 64, 123, 49, 44, 49, 50,
  49, 125, 10, 99, 114, 118, 49, 50, 50, 61, 64, 123, 49, 44, 49, 50,
  50, 125, 10, 99, 114, 118, 49, 50, 51, 61, 64, 123, 49, 44, 49, 50,
  51, 125, 10, 99, 114, 118, 49, 50, 52, 61, 64, 123, 49, 44, 49, 50,
  52, 125, 10, 99, 114, 118, 49, 50, 53, 61, 64, 123, 49, 44, 49, 50,
  53, 125, 10, 99, 114, 118, 49, 50, 54, 61, 64, 123, 49, 44, 49, 50,
  54, 125, 10, 99, 114, 118, 49, 50, 55, 61, 64, 123, 49, 44, 49, 50,
  55, 125, 10, 99, 114, 118, 49, 50, 56, 61, 64, 123, 49, 44, 49, 50,
  56, 125, 10, 99, 114, 118, 49, 50, 57, 61, 64, 123, 49, 44, 49, 50,
  57, 125, 10, 99, 114, 118, 49, 51, 48, 61, 64, 123, 49, 44, 49, 51,
  48, 125, 10, 99, 114, 118, 49, 51, 49, 61, 64, 123, 49, 44, 49, 51,
  49, 125, 10, 99, 114, 118, 49, 51, 50, 61, 64, 123, 49, 44, 49, 51,
  50, 125, 10, 99, 114, 118, 49, 51, 51, 61, 64, 123, 49, 44, 49, 51,
  51, 125, 10, 99, 114, 118, 49, 51, 52, 61, 64, 123, 49, 44, 49, 51,
  52, 125, 10, 99, 114, 118, 49, 51, 53, 61, 64, 123, 49, 44, 49, 51,
  53, 125, 10, 99, 114, 118, 49, 51, 54, 61, 64, 123, 49, 44, 49, 51,
  54, 125, 10, 99, 114, 118, 49, 51, 55, 61, 64, 123, 49, 44, 49, 51,
  55, 125, 10, 99, 114, 118, 49, 51, 56, 61, 64, 123, 49, 44, 49, 51,
  56, 125, 10, 99, 114, 118, 49, 51, 57, 61, 64, 123, 49, 44, 49, 51,
  57, 125, 10, 99, 114, 118, 49, 52, 48, 61, 64, 123, 49, 44, 49, 52,
  48, 125, 10, 99, 114, 118, 49, 52, 49, 61, 64, 123, 49, 44, 49, 52,
  49, 125, 10, 99, 114, 118, 49, 52, 50, 61, 64, 123, 49, 44, 49, 52,
  50, 125, 10, 99, 114, 118, 49, 52, 51, 61, 64, 123, 49, 44, 49, 52,
  51, 125, 10, 99, 114, 118, 49, 52, 52, 61, 64, 123, 49, 44, 49, 52,
  52, 125, 10, 99, 114, 118, 49, 52, 53, 61, 64, 123, 49, 44, 49, 52,
  53, 125, 10, 99, 114, 118, 49, 52, 54, 61, 64, 123, 49, 44, 49, 52,
  54, 125, 10, 99, 114, 118, 49, 52, 55, 61, 64, 123, 49, 44, 49, 52,
  55, 125, 10, 99, 114, 118, 49, 52, 56, 61, 64, 123, 49, 44, 49, 52,
  56, 125, 10, 99, 114, 118, 49, 52, 57, 61, 64, 123, 49, 44, 49, 52,
  57, 125, 10, 99, 114, 118, 49, 53, 48, 61, 64, 123, 49, 44, 49, 53,
  48, 125, 10, 99, 114, 118, 49, 53, 49, 61, 64, 123, 49, 44, 49, 53,
  49, 125, 10, 99, 114, 118, 49, 53, 50, 61, 64, 123, 49, 44, 49, 53,
  50, 125, 10, 99, 114, 118, 49, 53, 51, 61, 64, 123, 49, 44, 49, 53,
  51, 125, 10, 99, 114, 118, 49, 53, 52, 61, 64, 123, 49, 44, 49, 53,
  52, 125, 10, 99, 114, 118, 49, 53, 53, 61, 64, 123, 49, 44, 49, 53,
  53, 125, 10, 99, 114, 118, 49, 53, 54, 61, 64, 123, 49, 44, 49, 53,
  54, 125, 10, 99, 114, 118, 49, 53, 55, 61, 64, 123, 49, 44, 49, 53,
  55, 125, 10, 99, 114, 118, 49, 53, 56, 61, 64, 123, 49, 44, 49, 53,
  56, 125, 10, 99, 114, 118, 49, 53, 57, 61, 64, 123, 49, 44, 49, 53,
  57, 125, 10, 99, 114, 118, 49, 54, 48, 61, 64, 123, 49, 44, 49, 54,
  48, 125, 10, 99, 114, 118, 49, 54, 49, 61, 64, 123, 49, 44, 49, 54,
  49, 125, 10, 99, 114, 118, 49, 54, 50, 61, 64, 123, 49, 44, 49, 54,
  50, 125, 10, 99, 114, 118, 49, 54, 51, 61, 64, 123, 49, 44, 49, 54,
  51, 125, 10, 99, 114, 118, 49, 54, 52, 61, 64, 123, 49, 44, 49, 54,
  52, 125, 10, 99, 114, 118, 49, 54, 53, 61, 64, 123, 49, 44, 49, 54,
  53, 125, 10, 99, 114, 118, 49, 54, 54, 61, 64, 123, 49, 44, 49, 54,
  54, 125, 10, 99, 114, 118, 49, 54, 55, 61, 64, 123, 49, 44, 49, 54,
  55, 125, 10, 99, 114, 118, 49, 54, 56, 61, 64, 123, 49, 44, 49, 54,
  56, 125, 10, 99, 114, 118, 49, 54, 57, 61, 64, 123, 49, 44, 49, 54,
  57, 125, 10, 99, 114, 118, 49, 55, 48, 61, 64, 123, 49, 44, 49, 55,
  48, 125, 10, 99, 114, 118, 49, 55, 49, 61, 64, 123, 49, 44, 49, 55,
  49, 125, 10, 99, 114, 118, 49, 55, 50, 61, 64, 123, 49, 44, 49, 55,
  50, 125, 10, 99, 114, 118, 49, 55, 51, 61, 64, 123, 49, 44, 49, 55,
  51, 125, 10, 99, 114, 118, 49, 55, 52, 61, 64, 123, 49, 44, 49, 55,
  52, 125, 10, 99, 114, 118, 49, 55, 53, 61, 64, 123, 49, 44, 49, 55,
  53, 125, 10, 99, 114, 118, 49, 55, 54, 61, 64, 123, 49, 44, 49, 55,
  54, 125, 10, 99, 114, 118, 49, 55, 55, 61, 64, 123, 49, 44, 49, 55,
  55, 125, 10, 99, 114, 118, 49, 55, 56, 61, 64, 123, 49, 44, 49, 55,
  56, 125, 10, 99, 114, 118, 49, 55, 57, 61, 64, 123, 49, 44, 49, 55,
  57, 125, 10, 99, 114, 118, 49, 56, 48, 61, 64, 123, 49, 44, 49, 56,
  48, 125, 10, 99, 114, 118, 49, 56, 49, 61, 64, 123, 49, 44, 49, 56,
  49, 125, 10, 99, 114, 118, 49, 56, 50, 61, 64, 123, 49, 44, 49, 56,
  50, 125, 10, 99, 114, 118, 49, 56, 51, 61, 64, 123, 49, 44, 49, 56,
  51, 125, 10, 99, 114, 118, 49, 56, 52, 61, 64, 123, 49, 44, 49, 56,
  52, 125, 10, 99, 114, 118, 49, 56, 53, 61, 64, 123, 49, 44, 49, 56,
  53, 125, 10, 99, 114, 118, 49, 56, 54, 61, 64, 123, 49, 44, 49, 56,
  54, 125, 10, 99, 114, 118, 49, 56, 55, 61, 64, 123, 49, 44, 49, 56,
  55, 125, 10, 99, 114, 118, 49, 56, 56, 61, 64, 123, 49, 44, 49, 56,
  56, 125, 10, 99, 114, 118, 49, 56, 57, 61, 64, 123, 49, 44, 49, 56,
  57, 125, 10, 99, 114, 118, 49, 57, 48, 61, 64, 123, 49, 44, 49, 57,
  48, 125, 10, 99, 114, 118, 49, 57, 49, 61, 64, 123, 49, 44, 49, 57,
  49, 125, 10, 99, 114, 118, 49, 57, 50, 61, 64, 123, 49, 44, 49, 57,
  50, 125, 10, 99, 114, 118, 49, 57, 51, 61, 64, 123, 49, 44, 49, 57,
  51, 125, 10, 99, 114, 118, 49, 57, 52, 61, 64, 123, 49, 44, 49, 57,
  52, 125, 10, 99, 114, 118, 49, 57, 53, 61, 64, 123, 49, 44, 49, 57,
  53, 125, 10, 99, 114, 118, 49, 57, 54, 61, 64, 123, 49, 44, 49, 57,
  54, 125, 10, 99, 114, 118, 49, 57, 55, 61, 64, 123, 49, 44, 49, 57,
  55, 125, 10, 99, 114, 118, 49, 57, 56, 61, 64, 123, 49, 44, 49, 57,
  56, 125, 10, 99, 114, 118, 49, 57, 57, 61, 64, 123, 49, 44, 49, 57,
  57, 125, 10, 99, 114, 118, 50, 48, 48, 61, 64, 123, 49, 44, 50, 48,
  48, 125, 10, 99, 114, 118, 50, 48, 49, 61, 64, 123, 49, 44, 50, 48,
  49, 125, 10, 99, 114, 118, 50, 48, 50, 61, 64, 123, 49, 44, 50, 48,
  50, 125, 10, 99, 114, 118, 50, 48, 51, 61, 64, 123, 49, 44, 50, 48,
  51, 125, 10, 99, 114, 118, 50, 48, 52, 61, 64, 123, 49, 44, 50, 48,
  52, 125, 10, 99, 114, 118, 50, 48, 53, 61, 64, 123, 49, 44, 50, 48,
  53, 125, 10, 99, 114, 118, 50, 48, 54, 61, 64, 123, 49, 44, 50, 48,
  54, 125, 10, 99, 114, 118, 50, 48, 55, 61, 64, 123, 49, 44, 50, 48,
  55, 125, 10, 99, 114, 118, 50, 48, 56, 61, 64, 123, 49, 44, 50, 48,
  56, 125, 10, 99, 114, 118, 50, 48, 57, 61, 64, 123, 49, 44, 50, 48,
  57, 125, 10, 99, 114, 118, 50, 49, 48, 61, 64, 123, 49, 44, 50, 49,
  48, 125, 10, 99, 114, 118, 50, 49, 49, 61, 64, 123, 49, 44, 50, 49,
  49, 125, 10, 99, 114, 118, 50, 49, 50, 61, 64, 123, 49, 44, 50, 49,
  50, 125, 10, 99, 114, 118, 50, 49, 51, 61, 64, 123, 49, 44, 50, 49,
  51, 125, 10, 99, 114, 118, 50, 49, 52, 61, 64, 123, 49, 44, 50, 49,
  52, 125, 10, 99, 114, 118, 50, 49, 53, 61, 64, 123, 49, 44, 50, 49,
  53, 125, 10, 99, 114, 118, 50, 49, 54, 61, 64, 123, 49, 44, 50, 49,
  54, 125, 10, 99, 114, 118, 50, 49, 55, 61, 64, 123, 49, 44, 50, 49,
  55, 125, 10, 99, 114, 118, 50, 49, 56, 61, 64, 123, 49, 44, 50, 49,
  56, 125, 10, 99, 114, 118, 50, 49, 57, 61, 64, 123, 49, 44, 50, 49,
  57, 125, 10, 99, 114, 118, 50, 50, 48, 61, 64, 123, 49, 44, 50, 50,
  48, 125, 10, 99, 114, 118, 50, 50, 49, 61, 64, 123, 49, 44, 50, 50,
  49, 125, 10, 99, 114, 118, 50, 50, 50, 61, 64, 123, 49, 44, 50, 50,
  50, 125, 10, 99, 114, 118, 50, 50, 51, 61, 64, 123, 49, 44, 50, 50,
  51, 125, 10, 99, 114, 118, 50, 50, 52, 61, 64, 123, 49, 44, 50, 50,
  52, 125, 10, 99, 114, 118, 50, 50, 53, 61, 64, 123, 49, 44, 50, 50,
  53, 125, 10, 99, 114, 118, 50, 50, 54, 61, 64, 123, 49, 44, 50, 50,
  54, 125, 10, 99, 114, 118, 50, 50, 55, 61, 64, 123, 49, 44, 50, 50,
  55, 125, 10, 99, 114, 118, 50, 50, 56, 61, 64, 123, 49, 44, 50, 50,
  56, 125, 10, 99, 114, 118, 50, 50, 57, 61, 64, 123, 49, 44, 50, 50,
  57, 125, 10, 99, 114, 118, 50, 51, 48, 61, 64, 123, 49, 44, 50, 51,
  48, 125, 10, 99, 114, 118, 50, 51, 49, 61, 64, 123, 49, 44, 50, 51,
  49, 125, 10, 99, 114, 118, 50, 51, 50, 61, 64, 123, 49, 44, 50, 51,
  50, 125, 10, 99, 114, 118, 50, 51, 51, 61, 64, 123, 49, 44, 50, 51,
  51, 125, 10, 99, 114, 118, 50, 51, 52, 61, 64, 123, 49, 44, 50, 51,
  52, 125, 10, 99, 114, 118, 50, 51, 53, 61, 64, 123, 49, 44, 50, 51,
  53, 125, 10, 99, 114, 118, 50, 51, 54, 61, 64, 123, 49, 44, 50, 51,
  54, 125, 10, 99, 114, 118, 50, 51, 55, 61, 64, 123, 49, 44, 50, 51,
  55, 125, 10, 99, 114, 118, 50, 51, 56, 61, 64, 123, 49, 44, 50, 51,
  56, 125, 10, 99, 114, 118, 50, 51, 57, 61, 64, 123, 49, 44, 50, 51,
  57, 125, 10, 99, 114, 118, 50, 52, 48, 61, 64, 123, 49, 44, 50, 52,
  48, 125, 10, 99, 114, 118, 50, 52, 49, 61, 64, 123, 49, 44, 50, 52,
  49, 125, 10, 99, 114, 118, 50, 52, 50, 61, 64, 123, 49, 44, 50, 52,
  50, 125, 10, 99, 114, 118, 50, 52, 51, 61, 64, 123, 49, 44, 50, 52,
  51, 125, 10, 99, 114, 118, 50, 52, 52, 61, 64, 123, 49, 44, 50, 52,
  52, 125, 10, 99, 114, 118, 50, 52, 53, 61, 64, 123, 49, 44, 50, 52,
  53, 125, 10, 99, 114, 118, 50, 52, 54, 61, 64, 123, 49, 44, 50, 52,
  54, 125, 10, 99, 114, 118, 50, 52, 55, 61, 64, 123, 49, 44, 50, 52,
  55, 125, 10, 99, 114, 118, 50, 52, 56, 61, 64, 123, 49, 44, 50, 52,
  56, 125, 10, 99, 114, 118, 50, 52, 57, 61, 64, 123, 49, 44, 50, 52,
  57, 125, 10, 99, 114, 118, 50, 53, 48, 61, 64, 123, 49, 44, 50, 53,
  48, 125, 10, 99, 114, 118, 50, 53, 49, 61, 64, 123, 49, 44, 50, 53,
  49, 125, 10, 99, 114, 118, 50, 53, 50, 61, 64, 123, 49, 44, 50, 53,
  50, 125, 10, 99, 114, 118, 50, 53, 51, 61, 64, 123, 49, 44, 50, 53,
  51, 125, 10, 99, 114, 118, 50, 53, 52, 61, 64, 123, 49, 44, 50, 53,
  52, 125, 10, 99, 114, 118, 50, 53, 53, 61, 64, 123, 49, 44, 50, 53,
  53, 125, 10, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 91,
  48, 93, 32, 48, 44, 48, 44, 36, 99, 114, 118, 48, 44, 49, 44, 36,
  99, 114, 118, 49, 44, 50, 44, 36, 99, 114, 118, 50, 44, 51, 44, 36,
  99, 114, 118, 51, 44, 52, 44, 36, 99, 114, 118, 52, 44, 53, 44, 36,
  99, 114, 118, 53, 44, 54, 44, 36, 99, 114, 118, 54, 44, 55, 44, 36,
  99, 114, 118, 55, 44, 56, 44, 36, 99, 114, 118, 56, 44, 57, 44, 36,
  99, 114, 118, 57, 44, 49, 48, 44, 36, 99, 114, 118, 49, 48, 44, 49,
  49, 44, 36, 99, 114, 118, 49, 49, 44, 49, 50, 44, 36, 99, 114, 118,
  49, 50, 44, 49, 51, 44, 36, 99, 114, 118, 49, 51, 44, 49, 52, 44,
  36, 99, 114, 118, 49, 52, 44, 49, 53, 44, 36, 99, 114, 118, 49, 53,
  44, 49, 54, 44, 36, 99, 114, 118, 49, 54, 44, 49, 55, 44, 36, 99,
  114, 118, 49, 55, 44, 49, 56, 44, 36, 99, 114, 118, 49, 56, 44, 49,
  57, 44, 36, 99, 114, 118, 49, 57, 44, 50, 48, 44, 36, 99, 114, 118,
  50, 48, 44, 50, 49, 44, 36, 99, 114, 118, 50, 49, 44, 50, 50, 44,
  36, 99, 114, 118, 50, 50, 44, 50, 51, 44, 36, 99, 114, 118, 50, 51,
  44, 50, 52, 44, 36, 99, 114, 118, 50, 52, 44, 50, 53, 44, 36, 99,
  114, 118, 50, 53, 44, 50, 54, 44, 36, 99, 114, 118, 50, 54, 44, 50,
  55, 44, 36, 99, 114, 118, 50, 55, 44, 50, 56, 44, 36, 99, 114, 118,
  50, 56, 44, 50, 57, 44, 36, 99, 114, 118, 50, 57, 44, 51, 48, 44,
  36, 99, 114, 118, 51, 48, 44, 51, 49, 44, 36, 99, 114, 118, 51, 49,
  44, 51, 50, 44, 36, 99, 114, 118, 51, 50, 44, 51, 51, 44, 36, 99,
  114, 118, 51, 51, 44, 51, 52, 44, 36, 99, 114, 118, 51, 52, 44, 51,
  53, 44, 36, 99, 114, 118, 51, 53, 44, 51, 54, 44, 36, 99, 114, 118,
  51, 54, 44, 51, 55, 44, 36, 99, 114, 118, 51, 55, 44, 51, 56, 44,
  36, 99, 114, 118, 51, 56, 44, 51, 57, 44, 36, 99, 114, 118, 51, 57,
  44, 52, 48, 44, 36, 99, 114, 118, 52, 48, 44, 52, 49, 44, 36, 99,
  114, 118, 52, 49, 44, 52, 50, 44, 36, 99, 114, 118, 52, 50, 44, 52,
  51, 44, 36, 99, 114, 118, 52, 51, 44, 52, 52, 44, 36, 99, 114, 118,
  52, 52, 44, 52, 53, 44, 36, 99, 114, 118, 52, 53, 44, 52, 54, 44,
  36, 99, 114, 118, 52, 54, 44, 52, 55, 44, 36, 99, 114, 118, 52, 55,
  44, 52, 56, 44, 36, 99, 114, 118, 52, 56, 44, 52, 57, 44, 36, 99,
  114, 118, 52, 57, 44, 53, 48, 44, 36, 99, 114, 118, 53, 48, 44, 53,
  49, 44, 36, 99, 114, 118, 53, 49, 44, 53, 50, 44, 36, 99, 114, 118,
  53, 50, 44, 53, 51, 44, 36, 99, 114, 118, 53, 51, 44, 53, 52, 44,
  36, 99, 114, 118, 53, 52, 44, 53, 53, 44, 36, 99, 114, 118, 53, 53,
  44, 53, 54, 44, 36, 99, 114, 118, 53, 54, 44, 53, 55, 44, 36, 99,
  114, 118, 53, 55, 44, 53, 56, 44, 36, 99, 114, 118, 53, 56, 44, 53,
  57, 44, 36, 99, 114, 118, 53, 57, 44, 54, 48, 44, 36, 99, 114, 118,
  54, 48, 44, 54, 49, 44, 36, 99, 114, 118, 54, 49, 44, 54, 50, 44,
  36, 99, 114, 118, 54, 50, 44, 54, 51, 44, 36, 99, 114, 118, 54, 51,
  44, 54, 52, 44, 36, 99, 114, 118, 54, 52, 44, 54, 53, 44, 36, 99,
  114, 118, 54, 53, 44, 54, 54, 44, 36, 99, 114, 118, 54, 54, 44, 54,
  55, 44, 36, 99, 114, 118, 54, 55, 44, 54, 56, 44, 36, 99, 114, 118,
  54, 56, 44, 54, 57, 44, 36, 99, 114, 118, 54, 57, 44, 55, 48, 44,
  36, 99, 114, 118, 55, 48, 44, 55, 49, 44, 36, 99, 114, 118, 55, 49,
  44, 55, 50, 44, 36, 99, 114, 118, 55, 50, 44, 55, 51, 44, 36, 99,
  114, 118, 55, 51, 44, 55, 52, 44, 36, 99, 114, 118, 55, 52, 44, 55,
  53, 44, 36, 99, 114, 118, 55, 53, 44, 55, 54, 44, 36, 99, 114, 118,
  55, 54, 44, 55, 55, 44, 36, 99, 114, 118, 55, 55, 44, 55, 56, 44,
  36, 99, 114, 118, 55, 56, 44, 55, 57, 44, 36, 99, 114, 118, 55, 57,
  44, 56, 48, 44, 36, 99, 114, 118, 56, 48, 44, 56, 49, 44, 36, 99,
  114, 118, 56, 49, 44, 56, 50, 44, 36, 99, 114, 118, 56, 50, 44, 56,
  51, 44, 36, 99, 114, 118, 56, 51, 44, 56, 52, 44, 36, 99, 114, 118,
  56, 52, 44, 56, 53, 44, 36, 99, 114, 118, 56, 53, 44, 56, 54, 44,
  36, 99, 114, 118, 56, 54, 44, 56, 55, 44, 36, 99, 114, 118, 56, 55,
  44, 56, 56, 44, 36, 99, 114, 118, 56, 56, 44, 56, 57, 44, 36, 99,
  114, 118, 56, 57, 44, 57, 48, 44, 36, 99, 114, 118, 57, 48, 44, 57,
  49, 44, 36, 99, 114, 118, 57, 49, 44, 57, 50, 44, 36, 99, 114, 118,
  57, 50, 44, 57, 51, 44, 36, 99, 114, 118, 57, 51, 44, 57, 52, 44,
  36, 99, 114, 118, 57, 52, 44, 57, 53, 44, 36, 99, 114, 118, 57, 53,
  44, 57, 54, 44, 36, 99, 114, 118, 57, 54, 44, 57, 55, 44, 36, 99,
  114, 118, 57, 55, 44, 57, 56, 44, 36, 99, 114, 118, 57, 56, 44, 57,
  57, 44, 36, 99, 114, 118, 57, 57, 44, 49, 48, 48, 44, 36, 99, 114,
  118, 49, 48, 48, 44, 49, 48, 49, 44, 36, 99, 114, 118, 49, 48, 49,
  44, 49, 48, 50, 44, 36, 99, 114, 118, 49, 48, 50, 44, 49, 48, 51,
  44, 36, 99, 114, 118, 49, 48, 51, 44, 49, 48, 52, 44, 36, 99, 114,
  118, 49, 48, 52, 44, 49, 48, 53, 44, 36, 99, 114, 118, 49, 48, 53,
  44, 49, 48, 54, 44, 36, 99, 114, 118, 49, 48, 54, 44, 49, 48, 55,
  44, 36, 99, 114, 118, 49, 48, 55, 44, 49, 48, 56, 44, 36, 99, 114,
  118, 49, 48, 56, 44, 49, 48, 57, 44, 36, 99, 114, 118, 49, 48, 57,
  44, 49, 49, 48, 44, 36, 99, 114, 118, 49, 49, 48, 44, 49, 49, 49,
  44, 36, 99, 114, 118, 49, 49, 49, 44, 49, 49, 50, 44, 36, 99, 114,
  118, 49, 49, 50, 44, 49, 49, 51, 44, 36, 99, 114, 118, 49, 49, 51,
  44, 49, 49, 52, 44, 36, 99, 114, 118, 49, 49, 52, 44, 49, 49, 53,
  44, 36, 99, 114, 118, 49, 49, 53, 44, 49, 49, 54, 44, 36, 99, 114,
  118, 49, 49, 54, 44, 49, 49, 55, 44, 36, 99, 114, 118, 49, 49, 55,
  44, 49, 49, 56, 44, 36, 99, 114, 118, 49, 49, 56, 44, 49, 49, 57,
  44, 36, 99, 114, 118, 49, 49, 57, 44, 49, 50, 48, 44, 36, 99, 114,
  118, 49, 50, 48, 44, 49, 50, 49, 44, 36, 99, 114, 118, 49, 50, 49,
  44, 49, 50, 50, 44, 36, 99, 114, 118, 49, 50, 50, 44, 49, 50, 51,
  44, 36, 99, 114, 118, 49, 50, 51, 44, 49, 50, 52, 44, 36, 99, 114,
  118, 49, 50, 52, 44, 49, 50, 53, 44, 36, 99, 114, 118, 49, 50, 53,
  44, 49, 50, 54, 44, 36, 99, 114, 118, 49, 50, 54, 44, 49, 50, 55,
  44, 36, 99, 114, 118, 49, 50, 55, 44, 49, 50, 56, 44, 36, 99, 114,
  118, 49, 50, 56, 44, 49, 50, 57, 44, 36, 99, 114, 118, 49, 50, 57,
  44, 49, 51, 48, 44, 36, 99, 114, 118, 49, 51, 48, 44, 49, 51, 49,
  44, 36, 99, 114, 118, 49, 51, 49, 44, 49, 51, 50, 44, 36, 99, 114,
  118, 49, 51, 50, 44, 49, 51, 51, 44, 36, 99, 114, 118, 49, 51, 51,
  44, 49, 51, 52, 44, 36, 99, 114, 118, 49, 51, 52, 44, 49, 51, 53,
  44, 36, 99, 114, 118, 49, 51, 53, 44, 49, 51, 54, 44, 36, 99, 114,
  118, 49, 51, 54, 44, 49, 51, 55, 44, 36, 99, 114, 118, 49, 51, 55,
  44, 49, 51, 56, 44, 36, 99, 114, 118, 49, 51, 56, 44, 49, 51, 57,
  44, 36, 99, 114, 118, 49, 51, 57, 44, 49, 52, 48, 44, 36, 99, 114,
  118, 49, 52, 48, 44, 49, 52, 49, 44, 36, 99, 114, 118, 49, 52, 49,
  44, 49, 52, 50, 44, 36, 99, 114, 118, 49, 52, 50, 44, 49, 52, 51,
  44, 36, 99, 114, 118, 49, 52, 51, 44, 49, 52, 52, 44, 36, 99, 114,
  118, 49, 52, 52, 44, 49, 52, 53, 44, 36, 99, 114, 118, 49, 52, 53,
  44, 49, 52, 54, 44, 36, 99, 114, 118, 49, 52, 54, 44, 49, 52, 55,
  44, 36, 99, 114, 118, 49, 52, 55, 44, 49, 52, 56, 44, 36, 99, 114,
  118, 49, 52, 56, 44, 49, 52, 57, 44, 36, 99, 114, 118, 49, 52, 57,
  44, 49, 53, 48, 44, 36, 99, 114, 118, 49, 53, 48, 44, 49, 53, 49,
  44, 36, 99, 114, 118, 49, 53, 49, 44, 49, 53, 50, 44, 36, 99, 114,
  118, 49, 53, 50, 44, 49, 53, 51, 44, 36, 99, 114, 118, 49, 53, 51,
  44, 49, 53, 52, 44, 36, 99, 114, 118, 49, 53, 52, 44, 49, 53, 53,
  44, 36, 99, 114, 118, 49, 53, 53, 44, 49, 53, 54, 44, 36, 99, 114,
  118, 49, 53, 54, 44, 49, 53, 55, 44, 36, 99, 114, 118, 49, 53, 55,
  44, 49, 53, 56, 44, 36, 99, 114, 118, 49, 53, 56, 44, 49, 53, 57,
  44, 36, 99, 114, 118, 49, 53, 57, 44, 49, 54, 48, 44, 36, 99, 114,
  118, 49, 54, 48, 44, 49, 54, 49, 44, 36, 99, 114, 118, 49, 54, 49,
  44, 49, 54, 50, 44, 36, 99, 114, 118, 49, 54, 50, 44, 49, 54, 51,
  44, 36, 99, 114, 118, 49, 54, 51, 44, 49, 54, 52, 44, 36, 99, 114,
  118, 49, 54, 52, 44, 49, 54, 53, 44, 36, 99, 114, 118, 49, 54, 53,
  44, 49, 54, 54, 44, 36, 99, 114, 118, 49, 54, 54, 44, 49, 54, 55,
  44, 36, 99, 114, 118, 49, 54, 55, 44, 49, 54, 56, 44, 36, 99, 114,
  118, 49, 54, 56, 44, 49, 54, 57, 44, 36, 99, 114, 118, 49, 54, 57,
  44, 49, 55, 48, 44, 36, 99, 114, 118, 49, 55, 48, 44, 49, 55, 49,
  44, 36, 99, 114, 118, 49, 55, 49, 44, 49, 55, 50, 44, 36, 99, 114,
  118, 49, 55, 50, 44, 49, 55, 51, 44, 36, 99, 114, 118, 49, 55, 51,
  44, 49, 55, 52, 44, 36, 99, 114, 118, 49, 55, 52, 44, 49, 55, 53,
  44, 36, 99, 114, 118, 49, 55, 53, 44, 49, 55, 54, 44, 36, 99, 114,
  118, 49, 55, 54, 44, 49, 55, 55, 44, 36, 99, 114, 118, 49, 55, 55,
  44, 49, 55, 56, 44, 36, 99, 114, 118, 49, 55, 56, 44, 49, 55, 57,
  44, 36, 99, 114, 118, 49, 55, 57, 44, 49, 56, 48, 44, 36, 99, 114,
  118, 49, 56, 48, 44, 49, 56, 49, 44, 36, 99, 114, 118, 49, 56, 49,
  44, 49, 56, 50, 44, 36, 99, 114, 118, 49, 56, 50, 44, 49, 56, 51,
  44, 36, 99, 114, 118, 49, 56, 51, 44, 49, 56, 52, 44, 36, 99, 114,
  118, 49, 56, 52, 44, 49, 56, 53, 44, 36, 99, 114, 118, 49, 56, 53,
  44, 49, 56, 54, 44, 36, 99, 114, 118, 49, 56, 54, 44, 49, 56, 55,
  44, 36, 99, 114, 118, 49, 56, 55, 44, 49, 56, 56, 44, 36, 99, 114,
  118, 49, 56, 56, 44, 49, 56, 57, 44, 36, 99, 114, 118, 49, 56, 57,
  44, 49, 57, 48, 44, 36, 99, 114, 118, 49, 57, 48, 44, 49, 57, 49,
  44, 36, 99, 114, 118, 49, 57, 49, 44, 49, 57, 50, 44, 36, 99, 114,
  118, 49, 57, 50, 44, 49, 57, 51, 44, 36, 99, 114, 118, 49, 57, 51,
  44, 49, 57, 52, 44, 36, 99, 114, 118, 49, 57, 52, 44, 49, 57, 53,
  44, 36, 99, 114, 118, 49, 57, 53, 44, 49, 57, 54, 44, 36, 99, 114,
  118, 49, 57, 54, 44, 49, 57, 55, 44, 36, 99, 114, 118, 49, 57, 55,
  44, 49, 57, 56, 44, 36, 99, 114, 118, 49, 57, 56, 44, 49, 57, 57,
  44, 36, 99, 114, 118, 49, 57, 57, 44, 50, 48, 48, 44, 36, 99, 114,
  118, 50, 48, 48, 44, 50, 48, 49, 44, 36, 99, 114, 118, 50, 48, 49,
  44, 50, 48, 50, 44, 36, 99, 114, 118, 50, 48, 50, 44, 50, 48, 51,
  44, 36, 99, 114, 118, 50, 48, 51, 44, 50, 48, 52, 44, 36, 99, 114,
  118, 50, 48, 52, 44, 50, 48, 53, 44, 36, 99, 114, 118, 50, 48, 53,
  44, 50, 48, 54, 44, 36, 99, 114, 118, 50, 48, 54, 44, 50, 48, 55,
  44, 36, 99, 114, 118, 50, 48, 55, 44, 50, 48, 56, 44, 36, 99, 114,
  118, 50, 48, 56, 44, 50, 48, 57, 44, 36, 99, 114, 118, 50, 48, 57,
  44, 50, 49, 48, 44, 36, 99, 114, 118, 50, 49, 48, 44, 50, 49, 49,
  44, 36, 99, 114, 118, 50, 49, 49, 44, 50, 49, 50, 44, 36, 99, 114,
  118, 50, 49, 50, 44, 50, 49, 51, 44, 36, 99, 114, 118, 50, 49, 51,
  44, 50, 49, 52, 44, 36, 99, 114, 118, 50, 49, 52, 44, 50, 49, 53,
  44, 36, 99, 114, 118, 50, 49, 53, 44, 50, 49, 54, 44, 36, 99, 114,
  118, 50, 49, 54, 44, 50, 49, 55, 44, 36, 99, 114, 118, 50, 49, 55,
  44, 50, 49, 56, 44, 36, 99, 114, 118, 50, 49, 56, 44, 50, 49, 57,
  44, 36, 99, 114, 118, 50, 49, 57, 44, 50, 50, 48, 44, 36, 99, 114,
  118, 50, 50, 48, 44, 50, 50, 49, 44, 36, 99, 114, 118, 50, 50, 49,
  44, 50, 50, 50, 44, 36, 99, 114, 118, 50, 50, 50, 44, 50, 50, 51,
  44, 36, 99, 114, 118, 50, 50, 51, 44, 50, 50, 52, 44, 36, 99, 114,
  118, 50, 50, 52, 44, 50, 50, 53, 44, 36, 99, 114, 118, 50, 50, 53,
  44, 50, 50, 54, 44, 36, 99, 114, 118, 50, 50, 54, 44, 50, 50, 55,
  44, 36, 99, 114, 118, 50, 50, 55, 44, 50, 50, 56, 44, 36, 99, 114,
  118, 50, 50, 56, 44, 50, 50, 57, 44, 36, 99, 114, 118, 50, 50, 57,
  44, 50, 51, 48, 44, 36, 99, 114, 118, 50, 51, 48, 44, 50, 51, 49,
  44, 36, 99, 114, 118, 50, 51, 49, 44, 50, 51, 50, 44, 36, 99, 114,
  118, 50, 51, 50, 44, 50, 51, 51, 44, 36, 99, 114, 118, 50, 51, 51,
  44, 50, 51, 52, 44, 36, 99, 114, 118, 50, 51, 52, 44, 50, 51, 53,
  44, 36, 99, 114, 118, 50, 51, 53, 44, 50, 51, 54, 44, 36, 99, 114,
  118, 50, 51, 54, 44, 50, 51, 55, 44, 36, 99, 114, 118, 50, 51, 55,
  44, 50, 51, 56, 44, 36, 99, 114, 118, 50, 51, 56, 44, 50, 51, 57,
  44, 36, 99, 114, 118, 50, 51, 57, 44, 50, 52, 48, 44, 36, 99, 114,
  118, 50, 52, 48, 44, 50, 52, 49, 44, 36, 99, 114, 118, 50, 52, 49,
  44, 50, 52, 50, 44, 36, 99, 114, 118, 50, 52, 50, 44, 50, 52, 51,
  44, 36, 99, 114, 118, 50, 52, 51, 44, 50, 52, 52, 44, 36, 99, 114,
  118, 50, 52, 52, 44, 50, 52, 53, 44, 36, 99, 114, 118, 50, 52, 53,
  44, 50, 52, 54, 44, 36, 99, 114, 118, 50, 52, 54, 44, 50, 52, 55,
  44, 36, 99, 114, 118, 50, 52, 55, 44, 50, 52, 56, 44, 36, 99, 114,
  118, 50, 52, 56, 44, 50, 52, 57, 44, 36, 99, 114, 118, 50, 52, 57,
  44, 50, 53, 48, 44, 36, 99, 114, 118, 50, 53, 48, 44, 50, 53, 49,
  44, 36, 99, 114, 118, 50, 53, 49, 44, 50, 53, 50, 44, 36, 99, 114,
  118, 50, 53, 50, 44, 50, 53, 51, 44, 36, 99, 114, 118, 50, 53, 51,
  44, 50, 53, 52, 44, 36, 99, 114, 118, 50, 53, 52, 44, 50, 53, 53,
  44, 36, 99, 114, 118, 50, 53, 53, 10, 45, 107, 101, 101, 112, 91, 48,
  93, 10, 35, 64, 103, 105, 109, 112, 32, 70, 102, 116, 32, 116, 105, 108,
  101, 32, 58, 32, 102, 102, 116, 95, 116, 105, 108, 101, 44, 102, 102, 116,
  95, 116, 105, 108, 101, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104,
  111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 53, 48, 48,
  44, 48, 44, 53, 48, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 84, 105, 108, 101, 32, 115, 105, 122, 101, 32, 61, 32, 105,
  110, 116, 32, 40, 49, 50, 56, 44, 49, 54, 44, 50, 53, 54, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 97, 115, 116, 32, 61, 32,
  98, 111, 111, 108, 32, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 65, 117, 116, 104, 111,
  114, 32, 58, 32, 60, 105, 62, 73, 97, 105, 110, 32, 70, 101, 114, 103,
  117, 115, 115, 111, 110, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32,
  50, 48, 49, 50, 47, 48, 56, 47, 48, 56, 34, 41, 10, 102, 102, 116,
  95, 116, 105, 108, 101, 95, 102, 102, 116, 58, 10, 45, 45, 102, 102, 116,
  112, 111, 108, 97, 114, 91, 48, 93, 10, 45, 45, 116, 104, 114, 101, 115,
  104, 111, 108, 100, 91, 49, 93, 32, 36, 49, 10, 45, 115, 101, 116, 91,
  45, 49, 93, 32, 49, 44, 53, 48, 37, 44, 53, 48, 37, 10, 45, 109,
  117, 108, 91, 49, 93, 32, 91, 45, 49, 93, 10, 45, 45, 105, 102, 102,
  116, 112, 111, 108, 97, 114, 91, 49, 44, 50, 93, 10, 45, 107, 101, 101,
  112, 91, 45, 49, 93, 10, 102, 102, 116, 95, 116, 105, 108, 101, 95, 99,
  108, 101, 97, 110, 58, 10, 116, 99, 61, 123, 114, 111, 117, 110, 100, 40,
  119, 47, 36, 50, 41, 125, 32, 116, 114, 61, 123, 114, 111, 117, 110, 100,
  40, 104, 47, 36, 50, 41, 125, 10, 45, 115, 112, 108, 105, 116, 95, 116,
  105, 108, 101, 115, 32, 36, 116, 99, 44, 36, 116, 114, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 111, 99, 97, 108, 91, 64,
  123, 62, 44, 45, 49, 125, 93, 10, 45, 102, 102, 116, 95, 116, 105, 108,
  101, 95, 102, 102, 116, 91, 48, 45, 45, 49, 93, 32, 36, 49, 10, 45,
  101, 110, 100, 108, 111, 99, 97, 108, 32, 45, 100, 111, 110, 101, 10, 45,
  97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 32, 36, 116, 99,
  44, 36, 116, 114, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10, 102, 102,
  116, 95, 116, 105, 108, 101, 58, 10, 45, 45, 114, 101, 115, 105, 122, 101,
  91, 48, 93, 32, 123, 119, 43, 36, 50, 125, 44, 123, 104, 43, 36, 50,
  125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49, 10, 45, 114,
  101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 119, 43, 36, 50, 125,
  44, 123, 104, 43, 36, 50, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44,
  48, 44, 48, 10, 45, 102, 102, 116, 95, 116, 105, 108, 101, 95, 99, 108,
  101, 97, 110, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 10, 45, 99,
  114, 111, 112, 91, 45, 49, 93, 32, 36, 50, 44, 36, 50, 44, 123, 119,
  45, 36, 50, 45, 49, 125, 44, 123, 104, 45, 36, 50, 45, 49, 125, 10,
  45, 105, 102, 32, 123, 36, 51, 61, 61, 48, 125, 10, 112, 117, 115, 104,
  61, 123, 114, 111, 117, 110, 100, 40, 36, 50, 42, 49, 46, 53, 41, 125,
  10, 112, 117, 108, 108, 61, 123, 36, 50, 45, 36, 112, 117, 115, 104, 125,
  10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 123, 119, 43,
  36, 112, 117, 115, 104, 125, 44, 123, 104, 43, 36, 50, 125, 44, 49, 44,
  49, 44, 48, 44, 49, 44, 49, 44, 49, 10, 45, 114, 101, 115, 105, 122,
  101, 91, 45, 49, 93, 32, 123, 119, 43, 36, 112, 117, 108, 108, 125, 44,
  123, 104, 43, 36, 50, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 48,
  44, 48, 10, 45, 102, 102, 116, 95, 116, 105, 108, 101, 95, 99, 108, 101,
  97, 110, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 10, 45, 99, 114,
  111, 112, 91, 45, 49, 93, 32, 123, 36, 112, 117, 115, 104, 125, 44, 123,
  36, 50, 125, 44, 123, 119, 45, 36, 112, 117, 108, 108, 45, 49, 125, 44,
  123, 104, 45, 40, 36, 50, 41, 45, 49, 125, 10, 45, 45, 114, 101, 115,
  105, 122, 101, 91, 48, 93, 32, 123, 119, 43, 36, 50, 125, 44, 123, 104,
  43, 36, 112, 117, 115, 104, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44,
  49, 44, 49, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32,
  123, 119, 43, 36, 50, 125, 44, 123, 104, 43, 36, 112, 117, 108, 108, 125,
  44, 49, 44, 49, 44, 48, 44, 49, 44, 48, 44, 48, 10, 45, 102, 102,
  116, 95, 116, 105, 108, 101, 95, 99, 108, 101, 97, 110, 91, 45, 49, 93,
  32, 36, 49, 44, 36, 50, 10, 45, 99, 114, 111, 112, 91, 45, 49, 93,
  32, 36, 50, 44, 123, 36, 112, 117, 115, 104, 125, 44, 123, 119, 45, 36,
  50, 45, 49, 125, 44, 123, 104, 45, 36, 112, 117, 108, 108, 45, 49, 125,
  10, 100, 105, 97, 49, 61, 123, 114, 111, 117, 110, 100, 40, 36, 50, 47,
  51, 41, 125, 10, 100, 105, 97, 50, 61, 123, 36, 50, 45, 36, 100, 105,
  97, 49, 125, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32,
  123, 119, 43, 36, 100, 105, 97, 49, 125, 44, 123, 104, 43, 36, 100, 105,
  97, 49, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49, 10,
  45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 119, 43, 36,
  100, 105, 97, 50, 125, 44, 123, 104, 43, 36, 100, 105, 97, 50, 125, 44,
  49, 44, 49, 44, 48, 44, 49, 44, 48, 44, 48, 10, 45, 102, 102, 116,
  95, 116, 105, 108, 101, 95, 99, 108, 101, 97, 110, 91, 45, 49, 93, 32,
  36, 49, 44, 36, 50, 10, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32,
  123, 36, 100, 105, 97, 49, 125, 44, 123, 36, 100, 105, 97, 49, 125, 44,
  123, 119, 45, 36, 100, 105, 97, 50, 45, 49, 125, 44, 123, 104, 45, 36,
  100, 105, 97, 50, 45, 49, 125, 10, 45, 45, 114, 101, 115, 105, 122, 101,
  91, 48, 93, 32, 123, 119, 43, 36, 100, 105, 97, 50, 125, 44, 123, 104,
  43, 36, 100, 105, 97, 50, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44,
  49, 44, 49, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32,
  123, 119, 43, 36, 100, 105, 97, 49, 125, 44, 123, 104, 43, 36, 100, 105,
  97, 49, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 48, 44, 48, 10,
  45, 102, 102, 116, 95, 116, 105, 108, 101, 95, 99, 108, 101, 97, 110, 91,
  45, 49, 93, 32, 36, 49, 44, 36, 50, 10, 45, 99, 114, 111, 112, 91,
  45, 49, 93, 32, 123, 36, 100, 105, 97, 50, 125, 44, 123, 36, 100, 105,
  97, 50, 125, 44, 123, 119, 45, 36, 100, 105, 97, 49, 45, 49, 125, 44,
  123, 104, 45, 36, 100, 105, 97, 49, 45, 49, 125, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 114, 101, 109, 111, 118, 101, 91, 48, 93, 10, 45, 105,
  102, 32, 123, 36, 51, 61, 61, 48, 125, 10, 45, 105, 97, 105, 110, 95,
  109, 101, 100, 105, 97, 110, 95, 53, 95, 115, 116, 97, 99, 107, 10, 45,
  101, 110, 100, 105, 102, 10, 102, 102, 116, 95, 116, 105, 108, 101, 95, 112,
  114, 101, 118, 105, 101, 119, 58, 10, 45, 102, 102, 116, 95, 116, 105, 108,
  101, 32, 36, 49, 44, 36, 50, 44, 36, 51, 10, 45, 110, 32, 48, 44,
  50, 53, 53, 10, 35, 64, 103, 105, 109, 112, 32, 70, 105, 108, 108, 32,
  104, 111, 108, 101, 115, 32, 58, 32, 102, 105, 108, 108, 95, 104, 111, 108,
  101, 115, 44, 102, 105, 108, 108, 95, 104, 111, 108, 101, 115, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 77, 111, 114, 112, 104, 32, 114, 97, 100, 105, 117, 115, 32, 61,
  32, 105, 110, 116, 32, 40, 49, 49, 44, 51, 44, 53, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101, 32, 114, 97, 100,
  105, 117, 115, 32, 61, 32, 105, 110, 116, 32, 40, 50, 49, 44, 48, 44,
  53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 108, 111,
  115, 101, 32, 114, 97, 100, 105, 117, 115, 32, 61, 32, 105, 110, 116, 32,
  40, 53, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 32, 40, 48, 44, 34, 65, 108, 108, 34, 44, 34,
  82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101,
  100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44,
  34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34,
  44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34,
  44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34,
  98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117,
  101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44,
  34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 65,
  108, 112, 104, 97, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44,
  34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 105, 108, 108, 32, 108, 105,
  103, 104, 116, 32, 99, 111, 108, 111, 117, 114, 115, 32, 61, 32, 98, 111,
  111, 108, 32, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  70, 97, 115, 116, 32, 61, 32, 98, 111, 111, 108, 32, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 83, 101, 116, 32, 77, 111, 114, 112, 104, 32, 114, 97, 100, 105,
  117, 115, 32, 116, 111, 32, 99, 108, 111, 115, 101, 32, 104, 111, 108, 101,
  115, 44, 32, 115, 101, 116, 32, 69, 100, 103, 101, 32, 114, 97, 100, 105,
  117, 115, 32, 116, 111, 32, 114, 101, 115, 116, 111, 114, 101, 32, 101, 100,
  103, 101, 115, 44, 32, 115, 101, 116, 32, 67, 108, 111, 115, 101, 32, 114,
  97, 100, 105, 117, 115, 32, 116, 111, 32, 102, 105, 108, 108, 32, 115, 109,
  97, 108, 108, 32, 104, 111, 108, 101, 115, 32, 110, 101, 97, 114, 32, 116,
  104, 101, 32, 101, 100, 103, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 73, 97, 105, 110,
  32, 70, 101, 114, 103, 117, 115, 115, 111, 110, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 32, 58, 32, 50, 56, 32, 65, 117, 103, 117, 115, 116, 32, 50,
  48, 49, 50, 32, 45, 32, 97, 100, 100, 101, 100, 32, 39, 102, 97, 115,
  116, 39, 32, 111, 112, 116, 105, 111, 110, 34, 41, 10, 102, 105, 108, 108,
  95, 104, 111, 108, 101, 115, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 34, 10, 45, 105, 102, 32, 123, 36,
  53, 61, 61, 48, 125, 10, 45, 105, 102, 32, 123, 36, 54, 61, 61, 49,
  125, 10, 45, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 36,
  49, 10, 45, 101, 114, 111, 100, 101, 91, 45, 49, 93, 32, 36, 50, 10,
  45, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103, 104, 116, 101, 110,
  10, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 36, 51, 10,
  45, 101, 114, 111, 100, 101, 91, 45, 49, 93, 32, 36, 51, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 54, 61, 61, 48, 125,
  10, 45, 45, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 91, 45,
  49, 93, 32, 36, 49, 10, 45, 101, 114, 111, 100, 101, 95, 99, 105, 114,
  99, 91, 45, 49, 93, 32, 36, 50, 10, 45, 99, 111, 109, 112, 111, 115,
  101, 95, 108, 105, 103, 104, 116, 101, 110, 10, 45, 100, 105, 108, 97, 116,
  101, 95, 99, 105, 114, 99, 91, 45, 49, 93, 32, 36, 51, 10, 45, 101,
  114, 111, 100, 101, 95, 99, 105, 114, 99, 91, 45, 49, 93, 32, 36, 51,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  99, 32, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36, 53, 61,
  61, 49, 125, 10, 45, 105, 102, 32, 123, 36, 54, 61, 61, 49, 125, 10,
  45, 45, 101, 114, 111, 100, 101, 91, 45, 49, 93, 32, 36, 49, 10, 45,
  100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 36, 50, 10, 45, 99,
  111, 109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101, 110, 10, 45, 101,
  114, 111, 100, 101, 91, 45, 49, 93, 32, 36, 51, 10, 45, 100, 105, 108,
  97, 116, 101, 91, 45, 49, 93, 32, 36, 51, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 54, 61, 61, 48, 125, 10, 45, 45,
  101, 114, 111, 100, 101, 95, 99, 105, 114, 99, 91, 45, 49, 93, 32, 36,
  49, 10, 45, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 91, 45,
  49, 93, 32, 36, 50, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 100,
  97, 114, 107, 101, 110, 10, 45, 101, 114, 111, 100, 101, 95, 99, 105, 114,
  99, 91, 45, 49, 93, 32, 36, 51, 10, 45, 100, 105, 108, 97, 116, 101,
  95, 99, 105, 114, 99, 91, 45, 49, 93, 32, 36, 51, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 99, 32, 48, 44,
  50, 53, 53, 10, 34, 44, 36, 52, 10, 102, 105, 108, 108, 95, 104, 111,
  108, 101, 115, 95, 112, 114, 101, 118, 105, 101, 119, 58, 10, 45, 102, 105,
  108, 108, 95, 104, 111, 108, 101, 115, 32, 36, 49, 44, 36, 50, 44, 36,
  51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 10, 35, 64, 103, 105, 109,
  112, 32, 71, 114, 101, 121, 32, 100, 101, 115, 99, 114, 101, 101, 110, 32,
  58, 32, 105, 97, 105, 110, 95, 100, 101, 115, 99, 114, 101, 101, 110, 50,
  44, 105, 97, 105, 110, 95, 100, 101, 115, 99, 114, 101, 101, 110, 50, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 97, 108,
  121, 115, 105, 115, 32, 119, 105, 110, 100, 111, 119, 32, 61, 32, 102, 108,
  111, 97, 116, 32, 40, 51, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 116, 114, 101, 110, 103, 116, 104, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 45, 49, 48, 48, 48, 48, 44, 45, 49,
  48, 48, 48, 48, 44, 49, 48, 48, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 82, 97, 110, 103, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 32, 40, 49, 48, 44, 48, 44, 50, 48, 41, 10, 105, 97, 105,
  110, 95, 100, 101, 115, 99, 114, 101, 101, 110, 50, 58, 10, 45, 99, 104,
  97, 110, 110, 101, 108, 115, 32, 48, 10, 45, 102, 102, 116, 112, 111, 108,
  97, 114, 10, 45, 45, 98, 108, 117, 114, 91, 48, 93, 32, 36, 49, 37,
  10, 45, 115, 117, 98, 91, 45, 49, 93, 32, 91, 48, 93, 10, 45, 103,
  116, 91, 45, 49, 93, 32, 36, 50, 10, 45, 99, 105, 114, 99, 108, 101,
  91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 36, 51, 37,
  44, 49, 44, 49, 10, 45, 109, 117, 108, 91, 48, 93, 32, 91, 45, 49,
  93, 10, 45, 107, 101, 101, 112, 91, 48, 44, 49, 93, 10, 45, 105, 102,
  102, 116, 112, 111, 108, 97, 114, 10, 45, 99, 32, 48, 44, 50, 53, 53,
  10, 35, 64, 103, 105, 109, 112, 32, 72, 101, 97, 114, 116, 116, 111, 110,
  101, 32, 58, 32, 105, 97, 105, 110, 95, 104, 101, 97, 114, 116, 116, 111,
  110, 101, 44, 32, 105, 97, 105, 110, 95, 104, 101, 97, 114, 116, 116, 111,
  110, 101, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  99, 97, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 48,
  44, 49, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 69, 110, 104, 97, 110, 99, 101, 32, 100, 101, 116, 97, 105, 108,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41,
  10, 105, 97, 105, 110, 95, 104, 101, 97, 114, 116, 116, 111, 110, 101, 58,
  10, 45, 105, 102, 32, 123, 36, 50, 62, 48, 125, 10, 45, 45, 105, 97,
  105, 110, 95, 102, 97, 115, 116, 95, 100, 101, 110, 111, 105, 115, 101, 91,
  48, 93, 32, 36, 50, 44, 48, 44, 49, 44, 48, 44, 48, 10, 45, 115,
  117, 98, 91, 49, 93, 32, 91, 48, 93, 10, 45, 109, 117, 108, 91, 49,
  93, 32, 45, 49, 10, 45, 97, 100, 100, 10, 45, 110, 32, 48, 44, 50,
  53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 108, 117, 109, 105, 110,
  97, 110, 99, 101, 10, 45, 45, 108, 10, 45, 114, 109, 10, 45, 108, 10,
  49, 57, 48, 44, 49, 57, 48, 44, 49, 44, 49, 44, 48, 10, 45, 99,
  105, 114, 99, 108, 101, 32, 53, 48, 44, 53, 48, 44, 53, 48, 44, 49,
  44, 49, 48, 10, 45, 99, 105, 114, 99, 108, 101, 32, 49, 52, 48, 44,
  53, 48, 44, 53, 48, 44, 49, 44, 49, 48, 10, 45, 112, 111, 108, 121,
  103, 111, 110, 32, 53, 44, 49, 48, 44, 56, 48, 44, 53, 48, 44, 53,
  48, 44, 49, 52, 48, 44, 53, 48, 44, 49, 56, 48, 44, 56, 48, 44,
  57, 53, 44, 49, 57, 48, 44, 49, 44, 49, 48, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 48, 44, 119, 43, 50, 125,
  44, 64, 123, 48, 44, 104, 43, 50, 125, 44, 49, 44, 49, 44, 48, 44,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45, 114, 101, 115, 105,
  122, 101, 91, 48, 93, 32, 57, 53, 37, 44, 57, 53, 37, 44, 49, 44,
  49, 44, 50, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32,
  64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44,
  49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45,
  114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 57, 48, 37, 44, 57, 48,
  37, 44, 49, 44, 49, 44, 50, 10, 45, 114, 101, 115, 105, 122, 101, 91,
  45, 49, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104,
  125, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46,
  53, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 56, 53,
  37, 44, 56, 53, 37, 44, 49, 44, 49, 44, 50, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64,
  123, 48, 44, 104, 125, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48,
  93, 32, 55, 53, 37, 44, 55, 53, 37, 44, 49, 44, 49, 44, 50, 10,
  45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 48, 44,
  119, 125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 49, 44, 48, 44,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45, 114, 101, 115, 105,
  122, 101, 91, 48, 93, 32, 54, 53, 37, 44, 54, 53, 37, 44, 49, 44,
  49, 44, 50, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32,
  64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44,
  49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45,
  114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 53, 53, 37, 44, 53, 53,
  37, 44, 49, 44, 49, 44, 50, 10, 45, 114, 101, 115, 105, 122, 101, 91,
  45, 49, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104,
  125, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46,
  53, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 53, 48,
  37, 44, 53, 48, 37, 44, 49, 44, 49, 44, 50, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64,
  123, 48, 44, 104, 125, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48,
  93, 32, 52, 53, 37, 44, 52, 53, 37, 44, 49, 44, 49, 44, 50, 10,
  45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 48, 44,
  119, 125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 49, 44, 48, 44,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45, 114, 101, 115, 105,
  122, 101, 91, 48, 93, 32, 52, 48, 37, 44, 52, 48, 37, 44, 49, 44,
  49, 44, 50, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32,
  64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44,
  49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45,
  114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 51, 53, 37, 44, 51, 53,
  37, 44, 49, 44, 49, 44, 50, 10, 45, 114, 101, 115, 105, 122, 101, 91,
  45, 49, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104,
  125, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46,
  53, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 51, 48,
  37, 44, 51, 48, 37, 44, 49, 44, 49, 44, 50, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64,
  123, 48, 44, 104, 125, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48,
  93, 32, 50, 53, 37, 44, 50, 53, 37, 44, 49, 44, 49, 44, 50, 10,
  45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 48, 44,
  119, 125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 49, 44, 48, 44,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45, 114, 101, 115, 105,
  122, 101, 91, 48, 93, 32, 50, 48, 37, 44, 50, 48, 37, 44, 49, 44,
  49, 44, 50, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32,
  64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44,
  49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45,
  114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 49, 53, 37, 44, 49, 53,
  37, 44, 49, 44, 49, 44, 50, 10, 45, 114, 101, 115, 105, 122, 101, 91,
  45, 49, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104,
  125, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46,
  53, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 49, 48,
  37, 44, 49, 48, 37, 44, 49, 44, 49, 44, 50, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64,
  123, 48, 44, 104, 125, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48,
  93, 32, 53, 37, 44, 53, 37, 44, 49, 44, 49, 44, 50, 10, 45, 114,
  101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 48, 44, 119, 125,
  44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 49, 44, 48, 44, 48, 44,
  48, 46, 53, 44, 48, 46, 53, 10, 45, 97, 100, 100, 10, 45, 101, 110,
  100, 108, 10, 91, 48, 93, 10, 45, 97, 112, 112, 101, 110, 100, 32, 121,
  10, 45, 114, 101, 115, 105, 122, 101, 32, 50, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48,
  46, 53, 10, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93, 32, 49, 54,
  48, 44, 49, 48, 48, 44, 48, 44, 48, 10, 45, 45, 115, 104, 105, 102,
  116, 91, 48, 93, 32, 45, 49, 54, 48, 44, 49, 48, 48, 44, 48, 44,
  48, 10, 45, 97, 100, 100, 10, 45, 99, 114, 111, 112, 32, 51, 48, 44,
  49, 57, 48, 44, 51, 53, 48, 44, 49, 48, 48, 37, 10, 45, 110, 32,
  48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 36, 49, 44, 36, 49, 44, 49, 44,
  49, 44, 50, 10, 119, 105, 100, 116, 104, 61, 64, 123, 45, 49, 44, 119,
  125, 10, 104, 101, 105, 103, 104, 116, 61, 64, 123, 45, 49, 44, 104, 125,
  10, 119, 95, 116, 105, 108, 101, 115, 61, 123, 114, 111, 117, 110, 100, 40,
  64, 123, 48, 44, 119, 125, 47, 36, 119, 105, 100, 116, 104, 41, 125, 10,
  104, 95, 116, 105, 108, 101, 115, 61, 123, 114, 111, 117, 110, 100, 40, 64,
  123, 48, 44, 104, 125, 47, 36, 104, 101, 105, 103, 104, 116, 41, 125, 10,
  116, 111, 116, 97, 108, 95, 116, 105, 108, 101, 115, 61, 36, 104, 95, 116,
  105, 108, 101, 115, 42, 36, 119, 95, 116, 105, 108, 101, 115, 10, 91, 45,
  49, 93, 120, 123, 36, 116, 111, 116, 97, 108, 95, 116, 105, 108, 101, 115,
  45, 49, 125, 10, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101,
  115, 91, 49, 45, 45, 49, 93, 32, 36, 119, 95, 116, 105, 108, 101, 115,
  44, 36, 104, 95, 116, 105, 108, 101, 115, 10, 45, 101, 113, 117, 97, 108,
  105, 122, 101, 91, 45, 49, 93, 32, 50, 53, 54, 10, 45, 98, 108, 101,
  110, 100, 32, 97, 108, 112, 104, 97, 44, 48, 46, 53, 44, 49, 10, 45,
  103, 116, 32, 49, 50, 56, 10, 45, 109, 117, 108, 32, 50, 53, 53, 10,
  35, 64, 103, 105, 109, 112, 32, 73, 97, 105, 110, 32, 50, 120, 32, 58,
  32, 105, 97, 105, 110, 95, 50, 120, 44, 32, 105, 97, 105, 110, 95, 50,
  120, 40, 48, 41, 10, 105, 97, 105, 110, 95, 50, 120, 58, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 111, 99, 97, 108, 91,
  64, 123, 62, 44, 45, 49, 125, 93, 10, 45, 114, 101, 115, 105, 122, 101,
  91, 48, 93, 32, 50, 48, 48, 37, 44, 50, 48, 48, 37, 44, 49, 44,
  51, 44, 52, 10, 45, 115, 112, 108, 105, 116, 32, 99, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 111, 99, 97, 108, 91, 64,
  123, 62, 44, 45, 49, 125, 93, 10, 45, 45, 108, 91, 48, 93, 10, 40,
  48, 44, 48, 44, 48, 46, 53, 59, 48, 44, 49, 44, 48, 59, 48, 46,
  53, 44, 48, 44, 48, 41, 10, 45, 99, 111, 110, 118, 111, 108, 118, 101,
  91, 48, 93, 32, 91, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91,
  49, 93, 10, 45, 101, 110, 100, 108, 10, 45, 45, 108, 91, 48, 93, 10,
  40, 48, 46, 53, 44, 48, 44, 48, 59, 48, 44, 49, 44, 48, 59, 48,
  44, 48, 44, 48, 46, 53, 41, 10, 45, 99, 111, 110, 118, 111, 108, 118,
  101, 91, 48, 93, 32, 91, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101,
  91, 49, 93, 10, 45, 101, 110, 100, 108, 10, 45, 114, 101, 109, 111, 118,
  101, 91, 48, 93, 10, 45, 45, 108, 91, 48, 93, 10, 40, 48, 44, 48,
  44, 48, 46, 53, 59, 48, 44, 45, 49, 44, 48, 59, 48, 46, 53, 44,
  48, 44, 48, 41, 10, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 48,
  93, 32, 91, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 49, 93,
  10, 45, 97, 98, 115, 10, 45, 101, 110, 100, 108, 10, 45, 45, 108, 91,
  49, 93, 10, 40, 48, 46, 53, 44, 48, 44, 48, 59, 48, 44, 45, 49,
  44, 48, 59, 48, 44, 48, 44, 48, 46, 53, 41, 10, 45, 99, 111, 110,
  118, 111, 108, 118, 101, 91, 48, 93, 32, 91, 49, 93, 10, 45, 114, 101,
  109, 111, 118, 101, 91, 49, 93, 10, 45, 97, 98, 115, 10, 45, 101, 110,
  100, 108, 10, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 44, 45, 50,
  93, 32, 51, 10, 45, 115, 117, 98, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 93, 10, 45, 108,
  91, 45, 49, 93, 10, 45, 45, 108, 116, 91, 48, 93, 32, 48, 10, 45,
  45, 103, 116, 91, 48, 93, 32, 48, 10, 45, 102, 105, 108, 108, 91, 48,
  93, 32, 48, 10, 45, 115, 117, 98, 91, 48, 93, 32, 91, 49, 93, 10,
  45, 97, 100, 100, 91, 48, 93, 32, 91, 45, 49, 93, 10, 45, 107, 101,
  101, 112, 91, 48, 93, 10, 45, 97, 100, 100, 91, 48, 93, 32, 49, 10,
  45, 109, 117, 108, 91, 48, 93, 32, 49, 50, 55, 46, 53, 10, 45, 101,
  110, 100, 108, 10, 45, 97, 112, 112, 101, 110, 100, 91, 49, 44, 50, 93,
  32, 99, 10, 45, 98, 108, 101, 110, 100, 32, 97, 108, 112, 104, 97, 44,
  49, 44, 48, 10, 45, 45, 108, 91, 48, 93, 10, 40, 48, 46, 53, 44,
  49, 44, 48, 46, 53, 41, 10, 45, 99, 111, 110, 118, 111, 108, 118, 101,
  91, 48, 93, 32, 91, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91,
  49, 93, 10, 45, 101, 110, 100, 108, 10, 45, 45, 108, 91, 48, 93, 10,
  40, 48, 46, 53, 59, 49, 59, 48, 46, 53, 41, 10, 45, 99, 111, 110,
  118, 111, 108, 118, 101, 91, 48, 93, 32, 91, 49, 93, 10, 45, 114, 101,
  109, 111, 118, 101, 91, 49, 93, 10, 45, 101, 110, 100, 108, 10, 45, 114,
  101, 109, 111, 118, 101, 91, 48, 93, 10, 45, 45, 108, 91, 48, 93, 10,
  40, 48, 46, 53, 44, 45, 49, 44, 48, 46, 53, 41, 10, 45, 99, 111,
  110, 118, 111, 108, 118, 101, 91, 48, 93, 32, 91, 49, 93, 10, 45, 114,
  101, 109, 111, 118, 101, 91, 49, 93, 10, 45, 97, 98, 115, 10, 45, 101,
  110, 100, 108, 10, 45, 45, 108, 91, 49, 93, 10, 40, 48, 46, 53, 59,
  45, 49, 59, 48, 46, 53, 41, 10, 45, 99, 111, 110, 118, 111, 108, 118,
  101, 91, 48, 93, 32, 91, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101,
  91, 49, 93, 10, 45, 97, 98, 115, 10, 45, 101, 110, 100, 108, 10, 45,
  98, 108, 117, 114, 91, 45, 49, 44, 45, 50, 93, 32, 51, 10, 45, 115,
  117, 98, 91, 45, 50, 93, 32, 91, 45, 49, 93, 10, 45, 114, 101, 109,
  111, 118, 101, 91, 45, 49, 93, 10, 45, 108, 91, 45, 49, 93, 10, 45,
  45, 108, 116, 91, 48, 93, 32, 48, 10, 45, 45, 103, 116, 91, 48, 93,
  32, 48, 10, 45, 102, 105, 108, 108, 91, 48, 93, 32, 48, 10, 45, 115,
  117, 98, 91, 48, 93, 32, 91, 49, 93, 10, 45, 97, 100, 100, 91, 48,
  93, 32, 91, 45, 49, 93, 10, 45, 107, 101, 101, 112, 91, 48, 93, 10,
  45, 97, 100, 100, 91, 48, 93, 32, 49, 10, 45, 109, 117, 108, 91, 48,
  93, 32, 49, 50, 55, 46, 53, 10, 45, 101, 110, 100, 108, 10, 45, 97,
  112, 112, 101, 110, 100, 91, 49, 44, 50, 93, 32, 99, 10, 45, 98, 108,
  101, 110, 100, 32, 97, 108, 112, 104, 97, 44, 49, 44, 48, 10, 45, 101,
  110, 100, 108, 111, 99, 97, 108, 32, 45, 100, 111, 110, 101, 10, 45, 97,
  112, 112, 101, 110, 100, 32, 99, 10, 45, 101, 110, 100, 108, 111, 99, 97,
  108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 73,
  97, 105, 110, 32, 100, 101, 109, 111, 115, 105, 97, 99, 32, 58, 32, 105,
  97, 105, 110, 95, 100, 101, 109, 111, 115, 105, 97, 99, 44, 32, 105, 97,
  105, 110, 95, 100, 101, 109, 111, 115, 105, 97, 99, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 116, 97, 114, 116, 105, 110, 103,
  32, 112, 97, 116, 116, 101, 114, 110, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 48, 44, 34, 82, 101, 100, 45, 71, 114, 101, 101, 110, 34, 44,
  34, 66, 108, 117, 101, 45, 71, 114, 101, 101, 110, 34, 44, 34, 71, 114,
  101, 101, 110, 45, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 45,
  66, 108, 117, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 32,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 65, 117, 116, 104, 111, 114, 58,
  32, 73, 97, 105, 110, 32, 70, 101, 114, 103, 117, 115, 115, 111, 110, 32,
  45, 32, 114, 101, 108, 101, 97, 115, 101, 100, 32, 54, 32, 74, 117, 110,
  101, 32, 50, 48, 49, 51, 34, 41, 10, 105, 97, 105, 110, 95, 100, 101,
  109, 111, 115, 105, 97, 99, 58, 10, 45, 116, 111, 95, 114, 103, 98, 10,
  45, 97, 100, 100, 32, 49, 48, 48, 48, 10, 45, 114, 103, 98, 50, 98,
  97, 121, 101, 114, 32, 36, 49, 44, 49, 10, 45, 114, 101, 112, 108, 97,
  99, 101, 32, 48, 44, 48, 46, 48, 48, 48, 48, 48, 48, 48, 48, 48,
  49, 10, 45, 45, 108, 91, 48, 93, 10, 45, 114, 101, 112, 108, 97, 99,
  101, 32, 48, 44, 48, 46, 48, 48, 48, 48, 48, 48, 48, 48, 49, 10,
  45, 45, 108, 91, 48, 93, 10, 45, 116, 111, 95, 114, 103, 98, 10, 45,
  45, 115, 112, 108, 105, 116, 91, 48, 93, 32, 99, 10, 45, 115, 112, 108,
  105, 116, 91, 48, 93, 32, 99, 10, 45, 110, 97, 109, 101, 91, 48, 93,
  32, 114, 101, 100, 10, 45, 110, 97, 109, 101, 91, 49, 93, 32, 103, 114,
  101, 101, 110, 10, 45, 110, 97, 109, 101, 91, 50, 93, 32, 98, 108, 117,
  101, 10, 45, 110, 97, 109, 101, 91, 45, 51, 93, 32, 114, 101, 100, 98,
  108, 117, 114, 10, 45, 110, 97, 109, 101, 91, 45, 50, 93, 32, 103, 114,
  101, 101, 110, 98, 108, 117, 114, 10, 45, 110, 97, 109, 101, 91, 45, 49,
  93, 32, 98, 108, 117, 101, 98, 108, 117, 114, 10, 40, 48, 46, 50, 53,
  44, 46, 53, 44, 48, 46, 53, 44, 46, 53, 44, 48, 46, 50, 53, 41,
  10, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 114, 101, 100, 98, 108,
  117, 114, 93, 32, 91, 45, 49, 93, 10, 45, 99, 111, 110, 118, 111, 108,
  118, 101, 91, 98, 108, 117, 101, 98, 108, 117, 114, 93, 32, 91, 45, 49,
  93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 93, 10, 40, 49,
  59, 49, 41, 10, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 114, 101,
  100, 98, 108, 117, 114, 93, 32, 91, 45, 49, 93, 10, 45, 99, 111, 110,
  118, 111, 108, 118, 101, 91, 98, 108, 117, 101, 98, 108, 117, 114, 93, 32,
  91, 45, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 93,
  10, 40, 48, 46, 53, 44, 49, 44, 48, 46, 53, 41, 10, 45, 99, 111,
  110, 118, 111, 108, 118, 101, 91, 103, 114, 101, 101, 110, 98, 108, 117, 114,
  93, 32, 91, 45, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45,
  49, 93, 10, 45, 45, 100, 105, 118, 91, 103, 114, 101, 101, 110, 98, 108,
  117, 114, 93, 32, 91, 114, 101, 100, 98, 108, 117, 114, 93, 10, 45, 45,
  100, 105, 118, 91, 103, 114, 101, 101, 110, 98, 108, 117, 114, 93, 32, 91,
  98, 108, 117, 101, 98, 108, 117, 114, 93, 10, 45, 110, 97, 109, 101, 91,
  45, 49, 93, 32, 98, 108, 117, 101, 109, 117, 108, 10, 45, 110, 97, 109,
  101, 91, 45, 50, 93, 32, 114, 101, 100, 109, 117, 108, 10, 45, 114, 101,
  109, 111, 118, 101, 91, 114, 101, 100, 98, 108, 117, 114, 44, 103, 114, 101,
  101, 110, 98, 108, 117, 114, 44, 98, 108, 117, 101, 98, 108, 117, 114, 93,
  10, 45, 109, 117, 108, 91, 114, 101, 100, 93, 32, 91, 114, 101, 100, 109,
  117, 108, 93, 10, 45, 109, 117, 108, 91, 98, 108, 117, 101, 93, 32, 91,
  98, 108, 117, 101, 109, 117, 108, 93, 10, 45, 107, 101, 101, 112, 91, 114,
  101, 100, 44, 103, 114, 101, 101, 110, 44, 98, 108, 117, 101, 93, 10, 45,
  97, 100, 100, 10, 45, 99, 32, 45, 49, 48, 48, 48, 48, 48, 48, 48,
  48, 44, 49, 48, 48, 48, 48, 48, 48, 48, 48, 10, 45, 101, 110, 100,
  108, 10, 45, 108, 91, 48, 93, 10, 45, 116, 111, 95, 114, 103, 98, 10,
  45, 45, 115, 112, 108, 105, 116, 91, 48, 93, 32, 99, 10, 45, 115, 112,
  108, 105, 116, 91, 48, 93, 32, 99, 10, 45, 110, 97, 109, 101, 91, 48,
  93, 32, 114, 101, 100, 10, 45, 110, 97, 109, 101, 91, 49, 93, 32, 103,
  114, 101, 101, 110, 10, 45, 110, 97, 109, 101, 91, 50, 93, 32, 98, 108,
  117, 101, 10, 45, 110, 97, 109, 101, 91, 45, 51, 93, 32, 114, 101, 100,
  98, 108, 117, 114, 10, 45, 110, 97, 109, 101, 91, 45, 50, 93, 32, 103,
  114, 101, 101, 110, 98, 108, 117, 114, 10, 45, 110, 97, 109, 101, 91, 45,
  49, 93, 32, 98, 108, 117, 101, 98, 108, 117, 114, 10, 40, 48, 46, 50,
  53, 59, 46, 53, 59, 48, 46, 53, 59, 46, 53, 59, 48, 46, 50, 53,
  41, 10, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 114, 101, 100, 98,
  108, 117, 114, 93, 32, 91, 45, 49, 93, 10, 45, 99, 111, 110, 118, 111,
  108, 118, 101, 91, 98, 108, 117, 101, 98, 108, 117, 114, 93, 32, 91, 45,
  49, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 93, 10, 40,
  49, 44, 49, 41, 10, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 114,
  101, 100, 98, 108, 117, 114, 93, 32, 91, 45, 49, 93, 10, 45, 99, 111,
  110, 118, 111, 108, 118, 101, 91, 98, 108, 117, 101, 98, 108, 117, 114, 93,
  32, 91, 45, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49,
  93, 10, 40, 48, 46, 53, 59, 49, 59, 48, 46, 53, 41, 10, 45, 99,
  111, 110, 118, 111, 108, 118, 101, 91, 103, 114, 101, 101, 110, 98, 108, 117,
  114, 93, 32, 91, 45, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91,
  45, 49, 93, 10, 45, 45, 100, 105, 118, 91, 103, 114, 101, 101, 110, 98,
  108, 117, 114, 93, 32, 91, 114, 101, 100, 98, 108, 117, 114, 93, 10, 45,
  45, 100, 105, 118, 91, 103, 114, 101, 101, 110, 98, 108, 117, 114, 93, 32,
  91, 98, 108, 117, 101, 98, 108, 117, 114, 93, 10, 45, 110, 97, 109, 101,
  91, 45, 49, 93, 32, 98, 108, 117, 101, 109, 117, 108, 10, 45, 110, 97,
  109, 101, 91, 45, 50, 93, 32, 114, 101, 100, 109, 117, 108, 10, 45, 114,
  101, 109, 111, 118, 101, 91, 114, 101, 100, 98, 108, 117, 114, 44, 103, 114,
  101, 101, 110, 98, 108, 117, 114, 44, 98, 108, 117, 101, 98, 108, 117, 114,
  93, 10, 45, 109, 117, 108, 91, 114, 101, 100, 93, 32, 91, 114, 101, 100,
  109, 117, 108, 93, 10, 45, 109, 117, 108, 91, 98, 108, 117, 101, 93, 32,
  91, 98, 108, 117, 101, 109, 117, 108, 93, 10, 45, 107, 101, 101, 112, 91,
  114, 101, 100, 44, 103, 114, 101, 101, 110, 44, 98, 108, 117, 101, 93, 10,
  45, 97, 100, 100, 10, 45, 99, 32, 45, 49, 48, 48, 48, 48, 48, 48,
  48, 48, 44, 49, 48, 48, 48, 48, 48, 48, 48, 48, 10, 45, 101, 110,
  100, 108, 10, 35, 35, 32, 99, 104, 111, 111, 115, 101, 32, 111, 110, 101,
  32, 119, 105, 116, 104, 111, 117, 116, 32, 122, 105, 112, 112, 101, 114, 115,
  10, 40, 49, 44, 45, 50, 44, 49, 41, 10, 45, 45, 99, 111, 110, 118,
  111, 108, 118, 101, 91, 49, 93, 32, 91, 45, 49, 93, 10, 45, 97, 98,
  115, 91, 45, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 50,
  93, 10, 40, 49, 59, 45, 50, 59, 49, 41, 10, 45, 45, 99, 111, 110,
  118, 111, 108, 118, 101, 91, 48, 93, 32, 91, 45, 49, 93, 10, 45, 97,
  98, 115, 91, 45, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45,
  50, 93, 10, 45, 45, 97, 100, 100, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 10, 45, 100, 105, 118, 91, 45, 50, 93, 32, 91, 45, 49, 93, 10,
  45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 44, 45, 51, 93, 10, 45,
  108, 116, 91, 45, 49, 93, 32, 48, 46, 53, 10, 45, 109, 117, 108, 91,
  45, 49, 93, 32, 50, 53, 53, 10, 45, 98, 108, 117, 114, 91, 45, 49,
  93, 32, 49, 10, 45, 97, 112, 112, 101, 110, 100, 91, 48, 44, 45, 49,
  93, 32, 99, 10, 45, 98, 108, 101, 110, 100, 32, 97, 108, 112, 104, 97,
  44, 49, 44, 49, 10, 45, 101, 110, 100, 108, 10, 45, 115, 112, 108, 105,
  116, 91, 48, 93, 32, 99, 10, 45, 114, 101, 109, 111, 118, 101, 91, 49,
  93, 10, 45, 114, 101, 118, 101, 114, 115, 101, 91, 49, 44, 50, 93, 10,
  40, 48, 46, 50, 53, 44, 48, 46, 53, 44, 48, 46, 50, 53, 59, 48,
  46, 53, 44, 49, 44, 48, 46, 53, 59, 48, 46, 50, 53, 44, 48, 46,
  53, 44, 48, 46, 50, 53, 41, 10, 45, 99, 111, 110, 118, 111, 108, 118,
  101, 91, 48, 93, 32, 91, 45, 49, 93, 10, 45, 99, 111, 110, 118, 111,
  108, 118, 101, 91, 50, 93, 32, 91, 45, 49, 93, 10, 45, 114, 101, 109,
  111, 118, 101, 91, 45, 49, 93, 10, 45, 45, 114, 101, 115, 105, 122, 101,
  32, 53, 48, 37, 44, 53, 48, 37, 44, 123, 100, 125, 44, 123, 115, 125,
  44, 50, 10, 45, 115, 117, 98, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  10, 45, 115, 117, 98, 91, 45, 51, 93, 32, 91, 45, 50, 93, 10, 45,
  114, 101, 109, 111, 118, 101, 91, 45, 50, 93, 10, 45, 114, 101, 115, 105,
  122, 101, 91, 45, 49, 44, 45, 50, 93, 32, 64, 123, 48, 44, 119, 125,
  44, 64, 123, 48, 44, 104, 125, 44, 123, 100, 125, 44, 123, 115, 125, 44,
  51, 10, 45, 114, 101, 109, 111, 118, 101, 91, 48, 44, 50, 93, 10, 45,
  97, 100, 100, 91, 49, 93, 32, 91, 48, 93, 10, 45, 97, 100, 100, 91,
  50, 93, 32, 91, 48, 93, 10, 45, 114, 101, 118, 101, 114, 115, 101, 91,
  48, 44, 49, 93, 10, 45, 97, 112, 112, 101, 110, 100, 32, 99, 10, 45,
  115, 117, 98, 32, 49, 48, 48, 48, 10, 45, 99, 32, 48, 44, 50, 53,
  53, 10, 35, 64, 103, 105, 109, 112, 32, 73, 97, 105, 110, 32, 117, 110,
  105, 110, 100, 101, 120, 32, 58, 32, 105, 97, 105, 110, 95, 117, 110, 105,
  110, 100, 101, 120, 44, 105, 97, 105, 110, 95, 117, 110, 105, 110, 100, 101,
  120, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 32, 61, 32, 102,
  108, 111, 97, 116, 32, 40, 51, 48, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101, 32, 116, 104,
  114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 32,
  40, 50, 48, 44, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 80, 114, 101, 118, 105, 101, 119, 32, 122, 111, 111, 109, 32,
  61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 90, 111, 111, 109, 32, 99, 101, 110, 116, 101, 114, 32, 104,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 111, 111, 109,
  32, 99, 101, 110, 116, 101, 114, 32, 118, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 65, 117,
  116, 104, 111, 114, 58, 32, 73, 97, 105, 110, 32, 70, 101, 114, 103, 117,
  115, 115, 111, 110, 32, 45, 32, 114, 101, 108, 101, 97, 115, 101, 100, 32,
  49, 57, 32, 70, 101, 98, 32, 50, 48, 49, 51, 34, 41, 10, 105, 97,
  105, 110, 95, 117, 110, 105, 110, 100, 101, 120, 58, 10, 97, 109, 112, 108,
  105, 116, 117, 100, 101, 61, 36, 49, 10, 115, 104, 97, 114, 112, 110, 101,
  115, 115, 61, 46, 51, 10, 97, 110, 105, 115, 111, 116, 114, 111, 112, 121,
  61, 49, 10, 103, 114, 97, 100, 105, 101, 110, 116, 95, 115, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 61, 46, 54, 10, 116, 101, 110, 115, 111, 114,
  95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 49, 10, 115, 112,
  97, 116, 105, 97, 108, 95, 112, 114, 101, 99, 105, 115, 105, 111, 110, 61,
  48, 46, 56, 10, 97, 110, 103, 117, 108, 97, 114, 95, 112, 114, 101, 99,
  105, 115, 105, 111, 110, 61, 51, 48, 10, 118, 97, 108, 117, 101, 95, 112,
  114, 101, 99, 105, 115, 105, 111, 110, 61, 50, 10, 105, 110, 116, 101, 114,
  112, 111, 108, 97, 116, 105, 111, 110, 61, 48, 10, 102, 97, 115, 116, 95,
  97, 112, 112, 114, 111, 120, 61, 49, 10, 45, 116, 111, 95, 114, 103, 98,
  10, 45, 45, 115, 109, 111, 111, 116, 104, 91, 48, 93, 32, 36, 97, 109,
  112, 108, 105, 116, 117, 100, 101, 44, 36, 115, 104, 97, 114, 112, 110, 101,
  115, 115, 44, 36, 97, 110, 105, 115, 111, 116, 114, 111, 112, 121, 44, 36,
  103, 114, 97, 100, 105, 101, 110, 116, 95, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 44, 36, 116, 101, 110, 115, 111, 114, 95, 115, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 44, 36, 115, 112, 97, 116, 105, 97, 108, 95,
  112, 114, 101, 99, 105, 115, 105, 111, 110, 44, 36, 97, 110, 103, 117, 108,
  97, 114, 95, 112, 114, 101, 99, 105, 115, 105, 111, 110, 44, 36, 118, 97,
  108, 117, 101, 95, 112, 114, 101, 99, 105, 115, 105, 111, 110, 44, 36, 105,
  110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 44, 36, 102, 97,
  115, 116, 95, 97, 112, 112, 114, 111, 120, 10, 45, 45, 108, 117, 109, 105,
  110, 97, 110, 99, 101, 91, 45, 49, 93, 10, 45, 108, 97, 112, 108, 97,
  99, 105, 97, 110, 91, 45, 49, 93, 10, 45, 97, 98, 115, 91, 45, 49,
  93, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 46, 53, 10, 45,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 91, 45, 49, 93, 32, 36, 50,
  10, 45, 109, 117, 108, 91, 45, 49, 93, 32, 45, 49, 10, 45, 97, 100,
  100, 91, 45, 49, 93, 32, 49, 10, 45, 109, 117, 108, 91, 45, 49, 93,
  32, 50, 53, 53, 10, 45, 97, 112, 112, 101, 110, 100, 91, 49, 44, 50,
  93, 32, 99, 10, 45, 98, 108, 101, 110, 100, 32, 97, 108, 112, 104, 97,
  44, 49, 44, 48, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 105,
  97, 105, 110, 95, 117, 110, 105, 110, 100, 101, 120, 95, 112, 114, 101, 118,
  105, 101, 119, 58, 10, 45, 105, 97, 105, 110, 95, 117, 110, 105, 110, 100,
  101, 120, 32, 36, 49, 44, 36, 50, 10, 45, 105, 102, 32, 123, 36, 51,
  61, 61, 49, 125, 10, 116, 111, 112, 108, 101, 102, 116, 120, 61, 123, 36,
  52, 45, 50, 53, 125, 10, 116, 111, 112, 108, 101, 102, 116, 121, 61, 123,
  36, 53, 45, 50, 53, 125, 10, 98, 111, 116, 108, 101, 102, 116, 120, 61,
  123, 36, 52, 43, 50, 53, 125, 10, 98, 111, 116, 108, 101, 102, 116, 121,
  61, 123, 36, 53, 43, 50, 53, 125, 10, 45, 99, 114, 111, 112, 32, 36,
  116, 111, 112, 108, 101, 102, 116, 120, 37, 44, 36, 116, 111, 112, 108, 101,
  102, 116, 121, 37, 44, 36, 98, 111, 116, 108, 101, 102, 116, 120, 37, 44,
  36, 98, 111, 116, 108, 101, 102, 116, 121, 37, 10, 45, 101, 110, 100, 105,
  102, 10, 35, 64, 103, 105, 109, 112, 32, 73, 97, 105, 110, 32, 119, 101,
  105, 103, 104, 116, 109, 97, 112, 32, 58, 32, 105, 97, 105, 110, 95, 119,
  101, 105, 103, 104, 116, 109, 97, 112, 44, 32, 105, 97, 105, 110, 95, 119,
  101, 105, 103, 104, 116, 109, 97, 112, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 76, 97, 112, 32, 119, 101, 105, 103, 104, 116, 32, 61, 32, 102,
  108, 111, 97, 116, 32, 40, 49, 44, 48, 44, 52, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 66, 108, 117, 114, 32, 119, 105, 100, 116, 104,
  32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 52, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 105, 97, 105, 110, 95, 119, 101, 105, 103, 104, 116, 109,
  97, 112, 58, 10, 45, 115, 112, 108, 105, 116, 32, 99, 10, 45, 109, 97,
  120, 10, 50, 53, 53, 44, 49, 10, 45, 115, 101, 116, 91, 45, 49, 93,
  32, 50, 53, 53, 44, 49, 50, 56, 44, 48, 10, 45, 98, 108, 117, 114,
  91, 45, 49, 93, 32, 36, 50, 10, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 10, 45, 45, 109, 97, 112, 91, 48, 93, 32, 91, 49,
  93, 10, 45, 114, 109, 91, 49, 93, 10, 45, 108, 97, 112, 108, 97, 99,
  105, 97, 110, 91, 48, 93, 10, 45, 109, 117, 108, 91, 48, 93, 32, 36,
  49, 10, 45, 97, 98, 115, 91, 48, 93, 10, 45, 97, 100, 100, 10, 35,
  64, 103, 105, 109, 112, 32, 76, 117, 109, 105, 110, 97, 110, 99, 101, 32,
  110, 114, 32, 58, 32, 108, 117, 109, 105, 110, 97, 110, 99, 101, 95, 110,
  114, 44, 32, 108, 117, 109, 105, 110, 97, 110, 99, 101, 95, 110, 114, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 123, 34, 78, 111, 114, 109, 97, 108, 32,
  80, 97, 116, 99, 104, 32, 98, 97, 115, 101, 100, 32, 115, 109, 111, 111,
  116, 104, 105, 110, 103, 32, 40, 115, 99, 97, 108, 101, 32, 49, 41, 34,
  125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 116, 99, 104,
  32, 118, 97, 114, 105, 97, 110, 99, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 32, 40, 49, 48, 44, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 70, 97, 115, 116, 32, 97, 112, 112, 114, 111, 120,
  105, 109, 97, 116, 105, 111, 110, 32, 61, 32, 98, 111, 111, 108, 32, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101, 114,
  97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 32, 40, 49, 44,
  49, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 123, 34, 83, 109, 111, 111, 116, 104, 105, 110, 103,
  32, 111, 102, 32, 97, 100, 100, 105, 116, 105, 111, 110, 32, 115, 99, 97,
  108, 101, 115, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  99, 97, 108, 101, 32, 50, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40,
  54, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 99, 97, 108, 101, 32, 51, 32, 61, 32, 102, 108, 111, 97, 116,
  32, 40, 53, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 99, 97, 108, 101, 32, 52, 32, 61, 32, 102, 108, 111,
  97, 116, 32, 40, 52, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 53, 32, 61, 32, 102,
  108, 111, 97, 116, 32, 40, 51, 44, 48, 44, 50, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 54, 32, 61,
  32, 102, 108, 111, 97, 116, 32, 40, 50, 44, 48, 44, 50, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 55,
  32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 49, 44, 48, 44, 50, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 123, 34, 82, 101, 115, 116, 111, 114, 101, 32, 100, 101, 116, 97,
  105, 108, 115, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84,
  104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116,
  32, 40, 53, 48, 48, 48, 44, 48, 44, 53, 48, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 84, 105, 108, 101, 32, 115, 105, 122,
  101, 32, 61, 32, 105, 110, 116, 32, 40, 54, 52, 44, 51, 50, 44, 49,
  50, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 97, 109,
  109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 49, 46, 51, 44,
  49, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 84, 104, 105, 115, 32, 102, 105, 108, 116,
  101, 114, 32, 105, 115, 32, 60, 98, 62, 115, 108, 111, 119, 33, 60, 47,
  98, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 65, 117, 116, 104, 111,
  114, 32, 58, 32, 60, 105, 62, 73, 97, 105, 110, 32, 70, 101, 114, 103,
  117, 115, 115, 111, 110, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32,
  50, 48, 49, 50, 47, 49, 57, 47, 48, 56, 34, 41, 10, 108, 117, 109,
  105, 110, 97, 110, 99, 101, 95, 110, 114, 58, 10, 45, 97, 112, 112, 108,
  121, 95, 103, 97, 109, 109, 97, 32, 123, 49, 47, 36, 49, 50, 125, 10,
  45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  34, 10, 45, 45, 109, 115, 95, 112, 97, 116, 99, 104, 95, 115, 109, 111,
  111, 116, 104, 91, 48, 93, 32, 49, 48, 44, 36, 49, 44, 51, 44, 51,
  44, 48, 44, 36, 50, 44, 36, 51, 44, 48, 44, 36, 52, 44, 36, 53,
  44, 36, 54, 44, 36, 55, 44, 36, 56, 44, 36, 57, 44, 49, 10, 45,
  45, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 101, 120,
  116, 114, 97, 99, 116, 10, 45, 102, 102, 116, 95, 116, 105, 108, 101, 91,
  45, 49, 93, 32, 36, 49, 48, 44, 36, 49, 49, 44, 48, 10, 45, 99,
  111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 109, 101, 114, 103,
  101, 91, 49, 44, 50, 93, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93,
  10, 34, 44, 51, 10, 45, 97, 112, 112, 108, 121, 95, 103, 97, 109, 109,
  97, 32, 36, 49, 50, 10, 35, 64, 103, 105, 109, 112, 32, 76, 117, 109,
  105, 110, 97, 110, 99, 101, 32, 110, 114, 50, 32, 58, 32, 108, 117, 109,
  105, 110, 97, 110, 99, 101, 95, 110, 114, 95, 116, 119, 111, 44, 32, 108,
  117, 109, 105, 110, 97, 110, 99, 101, 95, 110, 114, 95, 116, 119, 111, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 116, 99,
  104, 32, 118, 97, 114, 105, 97, 110, 99, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 32, 40, 49, 48, 44, 48, 46, 49, 44, 50, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 70, 97, 115, 116, 32, 97, 112, 112,
  114, 111, 120, 105, 109, 97, 116, 105, 111, 110, 32, 61, 32, 98, 111, 111,
  108, 32, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73,
  116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 32,
  40, 49, 44, 49, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 65, 100, 106, 117, 115, 116,
  32, 78, 82, 32, 102, 111, 114, 32, 102, 111, 114, 32, 108, 97, 114, 103,
  101, 114, 32, 115, 99, 97, 108, 101, 115, 32, 97, 115, 32, 37, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32,
  50, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 46, 56, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 97, 108,
  101, 32, 51, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 46, 55, 44,
  48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99,
  97, 108, 101, 32, 52, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 46,
  54, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 99, 97, 108, 101, 32, 53, 32, 61, 32, 102, 108, 111, 97, 116, 32,
  40, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 99, 97, 108, 101, 32, 54, 32, 61, 32, 102, 108, 111, 97,
  116, 32, 40, 46, 52, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 55, 32, 61, 32, 102, 108,
  111, 97, 116, 32, 40, 46, 51, 44, 48, 44, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 77,
  97, 115, 116, 101, 114, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32,
  102, 111, 114, 32, 100, 101, 116, 97, 105, 108, 115, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100,
  32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 49, 50, 48, 48, 44, 48,
  44, 49, 48, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 84, 105, 108, 101, 32, 115, 105, 122, 101, 32, 61, 32, 105, 110, 116,
  32, 40, 54, 52, 44, 51, 50, 44, 49, 50, 56, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 104, 105, 110, 103, 32, 61, 32,
  102, 108, 111, 97, 116, 32, 40, 48, 44, 48, 44, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  65, 100, 106, 117, 115, 116, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100,
  32, 102, 111, 114, 32, 100, 101, 116, 105, 97, 108, 115, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 70, 105, 110, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 32, 40, 48, 44, 45, 49, 48, 48, 48, 44, 49, 48,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 101, 100,
  105, 117, 109, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 48, 44, 45,
  49, 48, 48, 48, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 117, 114, 115, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 32, 40, 48, 44, 45, 49, 48, 48, 48, 44, 49, 48, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 99, 111, 118,
  101, 114, 32, 100, 101, 116, 97, 105, 108, 32, 61, 32, 98, 111, 111, 108,
  32, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 65, 100, 106, 117, 115, 116, 32, 110, 111,
  105, 115, 101, 32, 114, 101, 100, 117, 99, 116, 105, 111, 110, 32, 98, 121,
  32, 116, 111, 110, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 66, 108, 97, 99, 107, 115, 32, 61, 32, 105, 110, 116, 32, 40, 48,
  44, 48, 44, 53, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 68, 97, 114, 107, 115, 32, 61, 32, 105, 110, 116, 32, 40, 48, 44,
  48, 44, 53, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  77, 105, 100, 116, 111, 110, 101, 115, 32, 61, 32, 105, 110, 116, 32, 40,
  48, 44, 48, 44, 53, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 76, 105, 103, 104, 116, 115, 32, 61, 32, 105, 110, 116, 32, 40,
  48, 44, 48, 44, 53, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 87, 104, 105, 116, 101, 32, 61, 32, 105, 110, 116, 32, 40, 48,
  44, 48, 44, 53, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 101, 100,
  105, 97, 110, 32, 112, 97, 115, 115, 32, 102, 105, 114, 115, 116, 32, 61,
  32, 98, 111, 111, 108, 32, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  84, 104, 105, 115, 32, 102, 105, 108, 116, 101, 114, 32, 105, 115, 32, 60,
  98, 62, 115, 108, 111, 119, 33, 60, 47, 98, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62,
  73, 97, 105, 110, 32, 70, 101, 114, 103, 117, 115, 115, 111, 110, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 32, 58, 32, 50, 53, 32, 65, 117, 103, 117,
  115, 116, 32, 50, 48, 49, 50, 34, 41, 10, 102, 102, 116, 95, 116, 105,
  108, 101, 50, 95, 102, 102, 116, 58, 10, 45, 45, 102, 102, 116, 112, 111,
  108, 97, 114, 91, 48, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 49, 44, 49, 44, 49, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91,
  45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 53, 48, 37, 44,
  53, 48, 37, 44, 48, 44, 49, 44, 36, 52, 10, 45, 101, 108, 108, 105,
  112, 115, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44,
  49, 53, 37, 44, 49, 53, 37, 44, 48, 44, 49, 44, 36, 53, 10, 45,
  101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44,
  53, 48, 37, 44, 53, 37, 44, 53, 37, 44, 48, 44, 49, 44, 36, 54,
  10, 45, 98, 111, 120, 95, 98, 108, 117, 114, 91, 45, 49, 93, 32, 123,
  36, 50, 42, 48, 46, 48, 49, 125, 10, 45, 45, 97, 100, 100, 91, 49,
  93, 32, 91, 45, 49, 93, 10, 45, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 91, 45, 49, 93, 32, 123, 36, 49, 47, 40, 49, 50, 56, 47, 36,
  50, 41, 125, 10, 45, 115, 101, 116, 91, 45, 49, 93, 32, 49, 44, 53,
  48, 37, 44, 53, 48, 37, 10, 45, 109, 117, 108, 91, 49, 93, 32, 91,
  45, 49, 93, 10, 45, 45, 105, 102, 102, 116, 112, 111, 108, 97, 114, 91,
  49, 44, 50, 93, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 102,
  102, 116, 95, 116, 105, 108, 101, 50, 95, 99, 108, 101, 97, 110, 58, 10,
  116, 99, 61, 123, 114, 111, 117, 110, 100, 40, 119, 47, 36, 50, 41, 125,
  32, 116, 114, 61, 123, 114, 111, 117, 110, 100, 40, 104, 47, 36, 50, 41,
  125, 10, 45, 115, 112, 108, 105, 116, 95, 116, 105, 108, 101, 115, 32, 36,
  116, 99, 44, 36, 116, 114, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 111, 99, 97, 108, 91, 64, 123, 62, 44, 45, 49, 125,
  93, 10, 45, 102, 102, 116, 95, 116, 105, 108, 101, 50, 95, 102, 102, 116,
  91, 48, 45, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44,
  36, 52, 44, 36, 53, 44, 36, 54, 10, 45, 101, 110, 100, 108, 111, 99,
  97, 108, 32, 45, 100, 111, 110, 101, 10, 45, 97, 112, 112, 101, 110, 100,
  95, 116, 105, 108, 101, 115, 32, 36, 116, 99, 44, 36, 116, 114, 10, 45,
  99, 32, 48, 44, 50, 53, 53, 10, 102, 102, 116, 95, 116, 105, 108, 101,
  50, 58, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 123,
  119, 43, 36, 50, 125, 44, 123, 104, 43, 36, 50, 125, 44, 49, 44, 49,
  44, 48, 44, 49, 44, 49, 44, 49, 10, 45, 114, 101, 115, 105, 122, 101,
  91, 45, 49, 93, 32, 123, 119, 43, 36, 50, 125, 44, 123, 104, 43, 36,
  50, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 48, 44, 48, 10, 45,
  102, 102, 116, 95, 116, 105, 108, 101, 50, 95, 99, 108, 101, 97, 110, 91,
  45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44,
  36, 53, 44, 36, 54, 10, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32,
  36, 50, 44, 36, 50, 44, 123, 119, 45, 36, 50, 45, 49, 125, 44, 123,
  104, 45, 36, 50, 45, 49, 125, 10, 45, 105, 102, 32, 123, 36, 51, 61,
  61, 48, 125, 10, 112, 117, 115, 104, 61, 123, 114, 111, 117, 110, 100, 40,
  36, 50, 42, 49, 46, 53, 41, 125, 10, 112, 117, 108, 108, 61, 123, 36,
  50, 45, 36, 112, 117, 115, 104, 125, 10, 45, 45, 114, 101, 115, 105, 122,
  101, 91, 48, 93, 32, 123, 119, 43, 36, 112, 117, 115, 104, 125, 44, 123,
  104, 43, 36, 50, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 49, 44,
  49, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 119,
  43, 36, 112, 117, 108, 108, 125, 44, 123, 104, 43, 36, 50, 125, 44, 49,
  44, 49, 44, 48, 44, 49, 44, 48, 44, 48, 10, 45, 102, 102, 116, 95,
  116, 105, 108, 101, 50, 95, 99, 108, 101, 97, 110, 91, 45, 49, 93, 32,
  36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36,
  54, 10, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 123, 36, 112, 117,
  115, 104, 125, 44, 123, 36, 50, 125, 44, 123, 119, 45, 36, 112, 117, 108,
  108, 45, 49, 125, 44, 123, 104, 45, 40, 36, 50, 41, 45, 49, 125, 10,
  45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 123, 119, 43, 36,
  50, 125, 44, 123, 104, 43, 36, 112, 117, 115, 104, 125, 44, 49, 44, 49,
  44, 48, 44, 49, 44, 49, 44, 49, 10, 45, 114, 101, 115, 105, 122, 101,
  91, 45, 49, 93, 32, 123, 119, 43, 36, 50, 125, 44, 123, 104, 43, 36,
  112, 117, 108, 108, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 48, 44,
  48, 10, 45, 102, 102, 116, 95, 116, 105, 108, 101, 50, 95, 99, 108, 101,
  97, 110, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44,
  36, 52, 44, 36, 53, 44, 36, 54, 10, 45, 99, 114, 111, 112, 91, 45,
  49, 93, 32, 36, 50, 44, 123, 36, 112, 117, 115, 104, 125, 44, 123, 119,
  45, 36, 50, 45, 49, 125, 44, 123, 104, 45, 36, 112, 117, 108, 108, 45,
  49, 125, 10, 100, 105, 97, 49, 61, 123, 114, 111, 117, 110, 100, 40, 36,
  50, 47, 51, 41, 125, 10, 100, 105, 97, 50, 61, 123, 36, 50, 45, 36,
  100, 105, 97, 49, 125, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48,
  93, 32, 123, 119, 43, 36, 100, 105, 97, 49, 125, 44, 123, 104, 43, 36,
  100, 105, 97, 49, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 49, 44,
  49, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 119,
  43, 36, 100, 105, 97, 50, 125, 44, 123, 104, 43, 36, 100, 105, 97, 50,
  125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 48, 44, 48, 10, 45, 102,
  102, 116, 95, 116, 105, 108, 101, 50, 95, 99, 108, 101, 97, 110, 91, 45,
  49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36,
  53, 44, 36, 54, 10, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 123,
  36, 100, 105, 97, 49, 125, 44, 123, 36, 100, 105, 97, 49, 125, 44, 123,
  119, 45, 36, 100, 105, 97, 50, 45, 49, 125, 44, 123, 104, 45, 36, 100,
  105, 97, 50, 45, 49, 125, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91,
  48, 93, 32, 123, 119, 43, 36, 100, 105, 97, 50, 125, 44, 123, 104, 43,
  36, 100, 105, 97, 50, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 49,
  44, 49, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123,
  119, 43, 36, 100, 105, 97, 49, 125, 44, 123, 104, 43, 36, 100, 105, 97,
  49, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 48, 44, 48, 10, 45,
  102, 102, 116, 95, 116, 105, 108, 101, 50, 95, 99, 108, 101, 97, 110, 91,
  45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44,
  36, 53, 44, 36, 54, 10, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32,
  123, 36, 100, 105, 97, 50, 125, 44, 123, 36, 100, 105, 97, 50, 125, 44,
  123, 119, 45, 36, 100, 105, 97, 49, 45, 49, 125, 44, 123, 104, 45, 36,
  100, 105, 97, 49, 45, 49, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 101, 109, 111, 118, 101, 91, 48, 93, 10, 45, 105, 102, 32, 123, 36,
  51, 61, 61, 48, 125, 10, 45, 105, 97, 105, 110, 95, 109, 101, 100, 105,
  97, 110, 95, 53, 95, 115, 116, 97, 99, 107, 10, 45, 101, 110, 100, 105,
  102, 10, 108, 117, 109, 105, 110, 97, 110, 99, 101, 95, 110, 114, 95, 116,
  119, 111, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 34, 10, 45, 109, 117, 108, 32, 57, 46, 57, 57, 10,
  45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 32, 48, 44, 48,
  44, 48, 44, 53, 49, 48, 44, 123, 53, 49, 48, 45, 36, 49, 55, 125,
  44, 49, 48, 50, 48, 44, 123, 49, 48, 50, 48, 45, 36, 49, 55, 45,
  36, 49, 56, 125, 44, 49, 53, 51, 48, 44, 123, 49, 53, 51, 48, 45,
  36, 49, 55, 45, 36, 49, 56, 45, 36, 49, 57, 125, 44, 50, 48, 52,
  48, 44, 123, 50, 48, 52, 48, 45, 36, 49, 55, 45, 36, 49, 56, 45,
  36, 49, 57, 45, 36, 50, 48, 125, 44, 50, 53, 53, 48, 44, 123, 50,
  53, 53, 48, 45, 36, 49, 55, 45, 36, 49, 56, 45, 36, 49, 57, 45,
  36, 50, 48, 45, 36, 50, 49, 125, 44, 50, 53, 53, 48, 44, 50, 53,
  53, 48, 10, 45, 109, 117, 108, 32, 48, 46, 49, 10, 45, 105, 102, 32,
  123, 36, 50, 50, 61, 61, 49, 125, 10, 45, 45, 109, 101, 100, 105, 97,
  110, 91, 48, 93, 32, 51, 10, 45, 109, 115, 95, 112, 97, 116, 99, 104,
  95, 115, 109, 111, 111, 116, 104, 91, 45, 49, 93, 32, 49, 48, 44, 36,
  49, 44, 51, 44, 51, 44, 48, 44, 36, 50, 44, 36, 51, 44, 48, 44,
  123, 36, 49, 42, 36, 52, 125, 44, 123, 36, 49, 42, 36, 53, 125, 44,
  123, 36, 49, 42, 36, 54, 125, 44, 123, 36, 49, 42, 36, 55, 125, 44,
  123, 36, 49, 42, 36, 56, 125, 44, 123, 36, 49, 42, 36, 57, 125, 44,
  49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 50,
  50, 61, 61, 48, 125, 10, 45, 45, 109, 115, 95, 112, 97, 116, 99, 104,
  95, 115, 109, 111, 111, 116, 104, 91, 48, 93, 32, 49, 48, 44, 36, 49,
  44, 51, 44, 51, 44, 48, 44, 36, 50, 44, 36, 51, 44, 48, 44, 123,
  36, 49, 42, 36, 52, 125, 44, 123, 36, 49, 42, 36, 53, 125, 44, 123,
  36, 49, 42, 36, 54, 125, 44, 123, 36, 49, 42, 36, 55, 125, 44, 123,
  36, 49, 42, 36, 56, 125, 44, 123, 36, 49, 42, 36, 57, 125, 44, 49,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 54,
  61, 61, 49, 125, 10, 45, 45, 99, 111, 109, 112, 111, 115, 101, 95, 103,
  114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116, 10, 45, 102, 102, 116,
  95, 116, 105, 108, 101, 50, 91, 45, 49, 93, 32, 36, 49, 48, 44, 36,
  49, 49, 44, 51, 44, 36, 49, 51, 44, 36, 49, 52, 44, 36, 49, 53,
  10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 109,
  101, 114, 103, 101, 91, 49, 44, 50, 93, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 45, 109, 117, 108, 32,
  57, 46, 57, 57, 10, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118,
  101, 32, 48, 44, 48, 44, 48, 44, 123, 53, 49, 48, 45, 36, 49, 55,
  125, 44, 53, 49, 48, 44, 123, 49, 48, 50, 48, 45, 36, 49, 55, 45,
  36, 49, 56, 125, 44, 49, 48, 50, 48, 44, 123, 49, 53, 51, 48, 45,
  36, 49, 55, 45, 36, 49, 56, 45, 36, 49, 57, 125, 44, 49, 53, 51,
  48, 44, 123, 50, 48, 52, 48, 45, 36, 49, 55, 45, 36, 49, 56, 45,
  36, 49, 57, 45, 36, 50, 48, 125, 44, 50, 48, 52, 48, 44, 123, 50,
  53, 53, 48, 45, 36, 49, 55, 45, 36, 49, 56, 45, 36, 49, 57, 45,
  36, 50, 48, 45, 36, 50, 49, 125, 44, 50, 53, 53, 48, 44, 50, 53,
  53, 48, 44, 50, 53, 53, 48, 10, 45, 109, 117, 108, 32, 48, 46, 49,
  10, 34, 44, 51, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10, 35, 64,
  103, 105, 109, 112, 32, 77, 111, 105, 114, 101, 32, 114, 101, 109, 111, 118,
  97, 108, 32, 58, 32, 105, 97, 105, 110, 95, 109, 111, 105, 114, 101, 95,
  114, 101, 109, 111, 118, 97, 108, 44, 32, 105, 97, 105, 110, 95, 109, 111,
  105, 114, 101, 95, 114, 101, 109, 111, 118, 97, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 105, 110,
  103, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 53, 44, 48, 44, 50,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 97, 114,
  116, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108,
  111, 97, 116, 32, 40, 53, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 77, 111, 105, 114, 101, 32, 114, 101, 109, 111,
  118, 97, 108, 32, 109, 101, 116, 104, 111, 100, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 48, 44, 34, 83, 109, 97, 114, 116, 34, 44, 34, 65,
  103, 103, 114, 101, 115, 105, 118, 101, 34, 44, 34, 83, 109, 111, 111, 116,
  104, 32, 111, 110, 108, 121, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 77, 111, 105, 114, 101, 32,
  114, 101, 109, 111, 118, 97, 108, 32, 99, 111, 110, 115, 105, 115, 116, 115,
  32, 111, 102, 32, 116, 119, 111, 32, 112, 97, 114, 116, 115, 44, 32, 102,
  105, 114, 115, 116, 44, 32, 97, 110, 32, 101, 100, 103, 101, 45, 112, 114,
  111, 116, 101, 99, 116, 101, 100, 32, 115, 109, 111, 111, 116, 104, 105, 110,
  103, 32, 97, 110, 100, 32, 115, 101, 99, 111, 110, 100, 32, 97, 32, 102,
  114, 101, 113, 117, 101, 110, 99, 121, 32, 97, 110, 97, 108, 121, 105, 115,
  105, 115, 32, 111, 102, 32, 116, 104, 101, 32, 100, 105, 102, 102, 101, 114,
  101, 110, 99, 101, 32, 98, 101, 116, 119, 101, 101, 110, 32, 116, 104, 101,
  32, 115, 109, 111, 111, 116, 104, 101, 100, 32, 97, 110, 100, 32, 111, 114,
  105, 103, 105, 110, 97, 108, 32, 105, 109, 97, 103, 101, 46, 32, 84, 104,
  101, 32, 105, 109, 97, 103, 101, 32, 105, 115, 32, 98, 114, 111, 107, 101,
  110, 32, 105, 110, 116, 111, 32, 116, 105, 108, 101, 115, 44, 32, 97, 110,
  100, 32, 101, 97, 99, 104, 32, 116, 105, 108, 101, 32, 112, 114, 111, 99,
  101, 115, 115, 101, 100, 46, 32, 65, 32, 116, 105, 108, 101, 32, 116, 104,
  97, 116, 32, 105, 115, 32, 97, 32, 115, 111, 108, 105, 100, 32, 99, 111,
  108, 111, 117, 114, 32, 105, 115, 32, 115, 107, 105, 112, 112, 101, 100, 46,
  34, 32, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 83, 109, 111, 111, 116, 104,
  105, 110, 103, 32, 109, 117, 115, 116, 32, 98, 101, 32, 104, 105, 103, 104,
  32, 101, 110, 111, 117, 103, 104, 32, 116, 111, 32, 114, 101, 109, 111, 118,
  101, 32, 116, 104, 101, 32, 109, 111, 105, 114, 101, 46, 32, 84, 104, 101,
  32, 60, 98, 62, 83, 109, 97, 114, 116, 32, 84, 104, 114, 101, 115, 104,
  111, 108, 100, 60, 47, 98, 62, 32, 115, 101, 116, 115, 32, 116, 104, 101,
  32, 100, 101, 116, 101, 99, 116, 105, 111, 110, 32, 111, 102, 32, 109, 111,
  105, 114, 101, 32, 102, 111, 114, 32, 101, 97, 99, 104, 32, 102, 114, 101,
  113, 117, 101, 110, 99, 121, 32, 111, 110, 32, 101, 97, 99, 104, 32, 99,
  111, 108, 111, 117, 114, 32, 99, 104, 97, 110, 110, 101, 108, 46, 32, 73,
  102, 32, 97, 32, 102, 114, 101, 113, 117, 101, 110, 99, 121, 32, 105, 110,
  32, 111, 110, 101, 32, 99, 111, 108, 111, 117, 114, 32, 99, 104, 97, 110,
  110, 101, 108, 32, 105, 115, 32, 100, 101, 116, 101, 114, 109, 105, 110, 101,
  100, 32, 116, 111, 32, 98, 101, 32, 109, 111, 105, 114, 101, 32, 105, 116,
  32, 105, 115, 32, 114, 101, 112, 108, 97, 99, 101, 100, 32, 98, 121, 32,
  116, 104, 101, 32, 99, 111, 108, 111, 117, 114, 32, 99, 104, 97, 110, 110,
  101, 108, 32, 108, 101, 97, 115, 116, 32, 108, 105, 107, 101, 108, 121, 32,
  116, 111, 32, 104, 97, 118, 101, 32, 109, 111, 105, 114, 101, 46, 34, 32,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 84, 104, 101, 32, 60, 98, 62, 65,
  103, 114, 101, 115, 115, 105, 118, 101, 60, 47, 98, 62, 32, 115, 101, 116,
  116, 105, 110, 103, 32, 115, 107, 105, 112, 115, 32, 116, 104, 101, 32, 116,
  104, 114, 101, 115, 111, 108, 100, 105, 110, 103, 32, 115, 116, 101, 112, 32,
  97, 110, 100, 32, 117, 115, 101, 115, 32, 116, 104, 101, 32, 108, 111, 119,
  101, 115, 116, 32, 102, 114, 101, 113, 117, 101, 110, 99, 121, 32, 108, 101,
  118, 101, 108, 32, 102, 114, 111, 109, 32, 116, 104, 101, 32, 99, 111, 108,
  111, 117, 114, 32, 99, 104, 97, 110, 110, 101, 108, 115, 46, 34, 32, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 84, 104, 101, 32, 102, 105, 108, 116, 101,
  114, 32, 119, 105, 108, 108, 32, 114, 101, 100, 117, 99, 101, 32, 99, 104,
  114, 111, 109, 97, 32, 100, 101, 116, 97, 105, 108, 115, 47, 110, 111, 105,
  115, 101, 34, 32, 41, 10, 105, 97, 105, 110, 95, 109, 111, 105, 114, 101,
  95, 114, 101, 109, 111, 118, 97, 108, 58, 10, 116, 105, 108, 101, 95, 115,
  105, 122, 101, 61, 50, 53, 54, 10, 111, 118, 101, 114, 108, 97, 112, 61,
  49, 54, 10, 99, 114, 111, 112, 119, 105, 100, 116, 104, 61, 123, 119, 125,
  10, 99, 114, 111, 112, 104, 101, 105, 103, 104, 116, 61, 123, 104, 125, 10,
  45, 105, 102, 32, 123, 36, 99, 114, 111, 112, 119, 105, 100, 116, 104, 37,
  36, 116, 105, 108, 101, 95, 115, 105, 122, 101, 62, 48, 125, 10, 45, 114,
  101, 115, 105, 122, 101, 91, 48, 93, 32, 123, 119, 43, 40, 36, 116, 105,
  108, 101, 95, 115, 105, 122, 101, 45, 119, 37, 36, 116, 105, 108, 101, 95,
  115, 105, 122, 101, 41, 125, 44, 49, 48, 48, 37, 44, 49, 44, 123, 115,
  125, 44, 48, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 99, 114, 111, 112, 104, 101, 105, 103, 104, 116, 37, 36, 116,
  105, 108, 101, 95, 115, 105, 122, 101, 62, 48, 125, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 48, 93, 32, 49, 48, 48, 37, 44, 123, 104, 43, 40,
  36, 116, 105, 108, 101, 95, 115, 105, 122, 101, 45, 104, 37, 36, 116, 105,
  108, 101, 95, 115, 105, 122, 101, 41, 125, 44, 49, 44, 123, 115, 125, 44,
  48, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 104, 95, 116, 105, 108,
  101, 115, 61, 123, 119, 47, 36, 116, 105, 108, 101, 95, 115, 105, 122, 101,
  125, 10, 118, 95, 116, 105, 108, 101, 115, 61, 123, 104, 47, 36, 116, 105,
  108, 101, 95, 115, 105, 122, 101, 125, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 36, 118, 95, 116, 105, 108, 101, 115, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 36, 104, 95, 116, 105, 108, 101, 115, 10, 104, 95, 99, 111, 117,
  110, 116, 61, 64, 123, 62, 44, 45, 49, 125, 10, 118, 95, 99, 111, 117,
  110, 116, 61, 64, 123, 62, 44, 45, 50, 125, 10, 45, 45, 99, 114, 111,
  112, 91, 48, 93, 32, 123, 40, 36, 104, 95, 99, 111, 117, 110, 116, 42,
  36, 116, 105, 108, 101, 95, 115, 105, 122, 101, 41, 45, 36, 111, 118, 101,
  114, 108, 97, 112, 125, 44, 123, 40, 36, 118, 95, 99, 111, 117, 110, 116,
  42, 36, 116, 105, 108, 101, 95, 115, 105, 122, 101, 41, 45, 36, 111, 118,
  101, 114, 108, 97, 112, 125, 44, 123, 40, 36, 104, 95, 99, 111, 117, 110,
  116, 42, 36, 116, 105, 108, 101, 95, 115, 105, 122, 101, 41, 43, 40, 36,
  116, 105, 108, 101, 95, 115, 105, 122, 101, 43, 36, 111, 118, 101, 114, 108,
  97, 112, 45, 49, 41, 125, 44, 123, 40, 36, 118, 95, 99, 111, 117, 110,
  116, 42, 36, 116, 105, 108, 101, 95, 115, 105, 122, 101, 41, 43, 40, 36,
  116, 105, 108, 101, 95, 115, 105, 122, 101, 43, 36, 111, 118, 101, 114, 108,
  97, 112, 45, 49, 41, 125, 44, 49, 10, 45, 100, 111, 110, 101, 10, 45,
  100, 111, 110, 101, 10, 45, 114, 109, 91, 48, 93, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 64, 123, 62, 44, 45, 49,
  125, 93, 10, 45, 105, 102, 32, 123, 105, 77, 33, 61, 105, 109, 125, 10,
  91, 48, 93, 10, 45, 97, 112, 112, 108, 121, 95, 112, 97, 114, 97, 108,
  108, 101, 108, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 49, 93, 32,
  34, 10, 45, 108, 91, 48, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  51, 10, 45, 108, 91, 45, 49, 93, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 50, 10, 45, 100, 101, 110, 111, 105, 115, 101, 91, 48, 93, 32, 49,
  48, 44, 123, 36, 49, 47, 40, 64, 123, 62, 44, 45, 49, 125, 43, 49,
  41, 125, 44, 53, 44, 53, 44, 48, 44, 123, 109, 105, 110, 40, 64, 123,
  62, 44, 45, 49, 125, 44, 49, 41, 125, 10, 45, 100, 111, 110, 101, 10,
  45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 53, 48, 37, 44,
  53, 48, 37, 44, 123, 100, 125, 44, 123, 115, 125, 44, 50, 10, 45, 45,
  114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 50, 48, 48, 37, 44,
  50, 48, 48, 37, 44, 123, 100, 125, 44, 123, 115, 125, 44, 51, 10, 45,
  115, 117, 98, 91, 48, 44, 45, 49, 93, 10, 45, 101, 110, 100, 108, 10,
  45, 100, 111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64,
  35, 45, 49, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93,
  32, 64, 123, 45, 50, 44, 119, 125, 44, 64, 123, 45, 50, 44, 104, 125,
  44, 123, 100, 125, 44, 123, 115, 125, 44, 51, 10, 45, 97, 100, 100, 91,
  45, 49, 44, 45, 50, 93, 10, 45, 100, 111, 110, 101, 10, 45, 101, 110,
  100, 108, 10, 34, 10, 45, 105, 102, 32, 123, 36, 51, 60, 50, 125, 10,
  45, 115, 117, 98, 91, 48, 93, 32, 91, 49, 93, 10, 45, 108, 91, 48,
  93, 10, 45, 102, 102, 116, 112, 111, 108, 97, 114, 91, 48, 93, 10, 45,
  105, 102, 32, 123, 36, 51, 61, 61, 49, 125, 10, 45, 97, 112, 112, 101,
  110, 100, 91, 48, 44, 49, 93, 32, 120, 10, 45, 115, 112, 108, 105, 116,
  91, 48, 93, 32, 99, 10, 45, 109, 105, 110, 10, 45, 115, 112, 108, 105,
  116, 91, 48, 93, 32, 120, 44, 50, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 51, 61, 61, 48, 125, 10, 45, 102, 105, 108, 108, 91, 49, 93, 32,
  105, 102, 40, 109, 97, 120, 40, 105, 40, 120, 44, 121, 44, 122, 44, 48,
  41, 44, 105, 40, 120, 44, 121, 44, 122, 44, 49, 41, 44, 105, 40, 120,
  44, 121, 44, 122, 44, 50, 41, 41, 45, 109, 105, 110, 40, 105, 40, 120,
  44, 121, 44, 122, 44, 48, 41, 44, 105, 40, 120, 44, 121, 44, 122, 44,
  49, 41, 44, 105, 40, 120, 44, 121, 44, 122, 44, 50, 41, 41, 60, 36,
  50, 44, 109, 105, 110, 40, 105, 40, 120, 44, 121, 44, 122, 44, 48, 41,
  44, 105, 40, 120, 44, 121, 44, 122, 44, 49, 41, 44, 105, 40, 120, 44,
  121, 44, 122, 44, 50, 41, 41, 44, 40, 105, 40, 120, 44, 121, 44, 122,
  44, 99, 41, 41, 41, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  102, 116, 112, 111, 108, 97, 114, 91, 48, 44, 49, 93, 10, 45, 107, 101,
  101, 112, 91, 48, 93, 10, 45, 101, 110, 100, 108, 10, 45, 116, 111, 95,
  114, 103, 98, 10, 45, 97, 100, 100, 10, 45, 101, 108, 115, 101, 10, 45,
  107, 101, 101, 112, 91, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  99, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 108, 10, 45, 112, 114, 111, 103, 114, 101, 115, 115, 32, 123,
  40, 64, 123, 62, 44, 45, 49, 125, 47, 64, 35, 41, 42, 49, 48, 48,
  125, 10, 45, 100, 111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 64, 123, 62, 44, 45, 49, 125, 93, 10, 45,
  99, 114, 111, 112, 32, 36, 111, 118, 101, 114, 108, 97, 112, 44, 36, 111,
  118, 101, 114, 108, 97, 112, 44, 123, 36, 116, 105, 108, 101, 95, 115, 105,
  122, 101, 43, 36, 111, 118, 101, 114, 108, 97, 112, 45, 49, 125, 44, 123,
  36, 116, 105, 108, 101, 95, 115, 105, 122, 101, 43, 36, 111, 118, 101, 114,
  108, 97, 112, 45, 49, 125, 10, 45, 101, 110, 100, 108, 10, 45, 100, 111,
  110, 101, 10, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115,
  32, 36, 104, 95, 116, 105, 108, 101, 115, 44, 36, 118, 95, 116, 105, 108,
  101, 115, 10, 45, 99, 114, 111, 112, 32, 48, 44, 48, 44, 123, 36, 99,
  114, 111, 112, 119, 105, 100, 116, 104, 45, 49, 125, 44, 123, 36, 99, 114,
  111, 112, 104, 101, 105, 103, 104, 116, 45, 49, 125, 10, 35, 64, 103, 105,
  109, 112, 32, 77, 111, 105, 114, 101, 32, 114, 101, 109, 111, 118, 97, 108,
  32, 110, 111, 116, 32, 112, 97, 114, 97, 108, 108, 101, 108, 32, 58, 32,
  105, 97, 105, 110, 95, 109, 111, 105, 114, 101, 95, 114, 101, 109, 111, 118,
  97, 108, 95, 78, 80, 44, 32, 105, 97, 105, 110, 95, 109, 111, 105, 114,
  101, 95, 114, 101, 109, 111, 118, 97, 108, 95, 78, 80, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 105,
  110, 103, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 53, 44, 48, 44,
  50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 97,
  114, 116, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102,
  108, 111, 97, 116, 32, 40, 53, 44, 48, 44, 49, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 77, 111, 105, 114, 101, 32, 114, 101, 109,
  111, 118, 97, 108, 32, 109, 101, 116, 104, 111, 100, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 48, 44, 34, 83, 109, 97, 114, 116, 34, 44, 34,
  65, 103, 103, 114, 101, 115, 105, 118, 101, 34, 44, 34, 83, 109, 111, 111,
  116, 104, 32, 111, 110, 108, 121, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 84, 104, 105, 115, 32,
  102, 105, 108, 116, 101, 114, 32, 105, 115, 32, 116, 104, 101, 32, 115, 97,
  109, 101, 32, 97, 115, 32, 116, 104, 101, 32, 111, 116, 104, 101, 114, 32,
  111, 110, 101, 32, 98, 117, 116, 32, 100, 111, 101, 32, 115, 110, 111, 116,
  32, 104, 97, 118, 101, 32, 112, 97, 114, 97, 108, 108, 101, 108, 32, 112,
  114, 111, 99, 101, 115, 115, 105, 110, 103, 34, 32, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 77, 111,
  105, 114, 101, 32, 114, 101, 109, 111, 118, 97, 108, 32, 99, 111, 110, 115,
  105, 115, 116, 115, 32, 111, 102, 32, 116, 119, 111, 32, 112, 97, 114, 116,
  115, 44, 32, 102, 105, 114, 115, 116, 44, 32, 97, 110, 32, 101, 100, 103,
  101, 45, 112, 114, 111, 116, 101, 99, 116, 101, 100, 32, 115, 109, 111, 111,
  116, 104, 105, 110, 103, 32, 97, 110, 100, 32, 115, 101, 99, 111, 110, 100,
  32, 97, 32, 102, 114, 101, 113, 117, 101, 110, 99, 121, 32, 97, 110, 97,
  108, 121, 105, 115, 105, 115, 32, 111, 102, 32, 116, 104, 101, 32, 100, 105,
  102, 102, 101, 114, 101, 110, 99, 101, 32, 98, 101, 116, 119, 101, 101, 110,
  32, 116, 104, 101, 32, 115, 109, 111, 111, 116, 104, 101, 100, 32, 97, 110,
  100, 32, 111, 114, 105, 103, 105, 110, 97, 108, 32, 105, 109, 97, 103, 101,
  46, 32, 84, 104, 101, 32, 105, 109, 97, 103, 101, 32, 105, 115, 32, 98,
  114, 111, 107, 101, 110, 32, 105, 110, 116, 111, 32, 116, 105, 108, 101, 115,
  44, 32, 97, 110, 100, 32, 101, 97, 99, 104, 32, 116, 105, 108, 101, 32,
  112, 114, 111, 99, 101, 115, 115, 101, 100, 46, 32, 65, 32, 116, 105, 108,
  101, 32, 116, 104, 97, 116, 32, 105, 115, 32, 97, 32, 115, 111, 108, 105,
  100, 32, 99, 111, 108, 111, 117, 114, 32, 105, 115, 32, 115, 107, 105, 112,
  112, 101, 100, 46, 34, 32, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 83, 109,
  111, 111, 116, 104, 105, 110, 103, 32, 109, 117, 115, 116, 32, 98, 101, 32,
  104, 105, 103, 104, 32, 101, 110, 111, 117, 103, 104, 32, 116, 111, 32, 114,
  101, 109, 111, 118, 101, 32, 116, 104, 101, 32, 109, 111, 105, 114, 101, 46,
  32, 84, 104, 101, 32, 60, 98, 62, 83, 109, 97, 114, 116, 32, 84, 104,
  114, 101, 115, 104, 111, 108, 100, 60, 47, 98, 62, 32, 115, 101, 116, 115,
  32, 116, 104, 101, 32, 100, 101, 116, 101, 99, 116, 105, 111, 110, 32, 111,
  102, 32, 109, 111, 105, 114, 101, 32, 102, 111, 114, 32, 101, 97, 99, 104,
  32, 102, 114, 101, 113, 117, 101, 110, 99, 121, 32, 111, 110, 32, 101, 97,
  99, 104, 32, 99, 111, 108, 111, 117, 114, 32, 99, 104, 97, 110, 110, 101,
  108, 46, 32, 73, 102, 32, 97, 32, 102, 114, 101, 113, 117, 101, 110, 99,
  121, 32, 105, 110, 32, 111, 110, 101, 32, 99, 111, 108, 111, 117, 114, 32,
  99, 104, 97, 110, 110, 101, 108, 32, 105, 115, 32, 100, 101, 116, 101, 114,
  109, 105, 110, 101, 100, 32, 116, 111, 32, 98, 101, 32, 109, 111, 105, 114,
  101, 32, 105, 116, 32, 105, 115, 32, 114, 101, 112, 108, 97, 99, 101, 100,
  32, 98, 121, 32, 116, 104, 101, 32, 99, 111, 108, 111, 117, 114, 32, 99,
  104, 97, 110, 110, 101, 108, 32, 108, 101, 97, 115, 116, 32, 108, 105, 107,
  101, 108, 121, 32, 116, 111, 32, 104, 97, 118, 101, 32, 109, 111, 105, 114,
  101, 46, 34, 32, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 84, 104, 101, 32,
  60, 98, 62, 65, 103, 114, 101, 115, 115, 105, 118, 101, 60, 47, 98, 62,
  32, 115, 101, 116, 116, 105, 110, 103, 32, 115, 107, 105, 112, 115, 32, 116,
  104, 101, 32, 116, 104, 114, 101, 115, 111, 108, 100, 105, 110, 103, 32, 115,
  116, 101, 112, 32, 97, 110, 100, 32, 117, 115, 101, 115, 32, 116, 104, 101,
  32, 108, 111, 119, 101, 115, 116, 32, 102, 114, 101, 113, 117, 101, 110, 99,
  121, 32, 108, 101, 118, 101, 108, 32, 102, 114, 111, 109, 32, 116, 104, 101,
  32, 99, 111, 108, 111, 117, 114, 32, 99, 104, 97, 110, 110, 101, 108, 115,
  46, 34, 32, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 84, 104, 101, 32, 102,
  105, 108, 116, 101, 114, 32, 119, 105, 108, 108, 32, 114, 101, 100, 117, 99,
  101, 32, 99, 104, 114, 111, 109, 97, 32, 100, 101, 116, 97, 105, 108, 115,
  47, 110, 111, 105, 115, 101, 34, 32, 41, 10, 105, 97, 105, 110, 95, 109,
  111, 105, 114, 101, 95, 114, 101, 109, 111, 118, 97, 108, 95, 78, 80, 58,
  10, 116, 105, 108, 101, 95, 115, 105, 122, 101, 61, 50, 53, 54, 10, 111,
  118, 101, 114, 108, 97, 112, 61, 49, 54, 10, 99, 114, 111, 112, 119, 105,
  100, 116, 104, 61, 123, 119, 125, 10, 99, 114, 111, 112, 104, 101, 105, 103,
  104, 116, 61, 123, 104, 125, 10, 45, 105, 102, 32, 123, 36, 99, 114, 111,
  112, 119, 105, 100, 116, 104, 37, 36, 116, 105, 108, 101, 95, 115, 105, 122,
  101, 62, 48, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32,
  123, 119, 43, 40, 36, 116, 105, 108, 101, 95, 115, 105, 122, 101, 45, 119,
  37, 36, 116, 105, 108, 101, 95, 115, 105, 122, 101, 41, 125, 44, 49, 48,
  48, 37, 44, 49, 44, 123, 115, 125, 44, 48, 44, 49, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 99, 114, 111, 112, 104, 101,
  105, 103, 104, 116, 37, 36, 116, 105, 108, 101, 95, 115, 105, 122, 101, 62,
  48, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 49, 48,
  48, 37, 44, 123, 104, 43, 40, 36, 116, 105, 108, 101, 95, 115, 105, 122,
  101, 45, 104, 37, 36, 116, 105, 108, 101, 95, 115, 105, 122, 101, 41, 125,
  44, 49, 44, 123, 115, 125, 44, 48, 44, 49, 10, 45, 101, 110, 100, 105,
  102, 10, 104, 95, 116, 105, 108, 101, 115, 61, 123, 119, 47, 36, 116, 105,
  108, 101, 95, 115, 105, 122, 101, 125, 10, 118, 95, 116, 105, 108, 101, 115,
  61, 123, 104, 47, 36, 116, 105, 108, 101, 95, 115, 105, 122, 101, 125, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 36, 118, 95, 116, 105, 108, 101, 115,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 104, 95, 116, 105, 108, 101,
  115, 10, 104, 95, 99, 111, 117, 110, 116, 61, 64, 123, 62, 44, 45, 49,
  125, 10, 118, 95, 99, 111, 117, 110, 116, 61, 64, 123, 62, 44, 45, 50,
  125, 10, 45, 45, 99, 114, 111, 112, 91, 48, 93, 32, 123, 40, 36, 104,
  95, 99, 111, 117, 110, 116, 42, 36, 116, 105, 108, 101, 95, 115, 105, 122,
  101, 41, 45, 36, 111, 118, 101, 114, 108, 97, 112, 125, 44, 123, 40, 36,
  118, 95, 99, 111, 117, 110, 116, 42, 36, 116, 105, 108, 101, 95, 115, 105,
  122, 101, 41, 45, 36, 111, 118, 101, 114, 108, 97, 112, 125, 44, 123, 40,
  36, 104, 95, 99, 111, 117, 110, 116, 42, 36, 116, 105, 108, 101, 95, 115,
  105, 122, 101, 41, 43, 40, 36, 116, 105, 108, 101, 95, 115, 105, 122, 101,
  43, 36, 111, 118, 101, 114, 108, 97, 112, 45, 49, 41, 125, 44, 123, 40,
  36, 118, 95, 99, 111, 117, 110, 116, 42, 36, 116, 105, 108, 101, 95, 115,
  105, 122, 101, 41, 43, 40, 36, 116, 105, 108, 101, 95, 115, 105, 122, 101,
  43, 36, 111, 118, 101, 114, 108, 97, 112, 45, 49, 41, 125, 44, 49, 10,
  45, 100, 111, 110, 101, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91,
  48, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 64, 123, 62, 44, 45, 49, 125, 93, 10, 45, 105, 102, 32, 123, 105,
  77, 33, 61, 105, 109, 125, 10, 91, 48, 93, 10, 45, 108, 91, 49, 93,
  10, 45, 108, 91, 48, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 51,
  10, 45, 108, 91, 45, 49, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  50, 10, 45, 100, 101, 110, 111, 105, 115, 101, 91, 48, 93, 32, 49, 48,
  44, 123, 36, 49, 47, 40, 64, 123, 62, 44, 45, 49, 125, 43, 49, 41,
  125, 44, 53, 44, 53, 44, 48, 44, 123, 109, 105, 110, 40, 64, 123, 62,
  44, 45, 49, 125, 44, 49, 41, 125, 10, 45, 100, 111, 110, 101, 10, 45,
  45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 53, 48, 37, 44, 53,
  48, 37, 44, 123, 100, 125, 44, 123, 115, 125, 44, 50, 10, 45, 45, 114,
  101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 50, 48, 48, 37, 44, 50,
  48, 48, 37, 44, 123, 100, 125, 44, 123, 115, 125, 44, 51, 10, 45, 115,
  117, 98, 91, 48, 44, 45, 49, 93, 10, 45, 101, 110, 100, 108, 10, 45,
  100, 111, 110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35,
  45, 49, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32,
  64, 123, 45, 50, 44, 119, 125, 44, 64, 123, 45, 50, 44, 104, 125, 44,
  123, 100, 125, 44, 123, 115, 125, 44, 51, 10, 45, 97, 100, 100, 91, 45,
  49, 44, 45, 50, 93, 10, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100,
  108, 10, 45, 101, 110, 100, 108, 10, 45, 105, 102, 32, 123, 36, 51, 60,
  50, 125, 10, 45, 115, 117, 98, 91, 48, 93, 32, 91, 49, 93, 10, 45,
  108, 91, 48, 93, 10, 45, 102, 102, 116, 112, 111, 108, 97, 114, 91, 48,
  93, 10, 45, 105, 102, 32, 123, 36, 51, 61, 61, 49, 125, 10, 45, 97,
  112, 112, 101, 110, 100, 91, 48, 44, 49, 93, 32, 120, 10, 45, 115, 112,
  108, 105, 116, 91, 48, 93, 32, 99, 10, 45, 109, 105, 110, 10, 45, 115,
  112, 108, 105, 116, 91, 48, 93, 32, 120, 44, 50, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 51, 61, 61, 48, 125, 10, 45, 102, 105, 108, 108, 91,
  49, 93, 32, 105, 102, 40, 109, 97, 120, 40, 105, 40, 120, 44, 121, 44,
  122, 44, 48, 41, 44, 105, 40, 120, 44, 121, 44, 122, 44, 49, 41, 44,
  105, 40, 120, 44, 121, 44, 122, 44, 50, 41, 41, 45, 109, 105, 110, 40,
  105, 40, 120, 44, 121, 44, 122, 44, 48, 41, 44, 105, 40, 120, 44, 121,
  44, 122, 44, 49, 41, 44, 105, 40, 120, 44, 121, 44, 122, 44, 50, 41,
  41, 60, 36, 50, 44, 109, 105, 110, 40, 105, 40, 120, 44, 121, 44, 122,
  44, 48, 41, 44, 105, 40, 120, 44, 121, 44, 122, 44, 49, 41, 44, 105,
  40, 120, 44, 121, 44, 122, 44, 50, 41, 41, 44, 40, 105, 40, 120, 44,
  121, 44, 122, 44, 99, 41, 41, 41, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 102, 116, 112, 111, 108, 97, 114, 91, 48, 44, 49, 93, 10,
  45, 107, 101, 101, 112, 91, 48, 93, 10, 45, 101, 110, 100, 108, 10, 45,
  116, 111, 95, 114, 103, 98, 10, 45, 97, 100, 100, 10, 45, 101, 108, 115,
  101, 10, 45, 107, 101, 101, 112, 91, 49, 93, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 108, 10, 45, 112, 114, 111, 103, 114, 101, 115,
  115, 32, 123, 40, 64, 123, 62, 44, 45, 49, 125, 47, 64, 35, 41, 42,
  49, 48, 48, 125, 10, 45, 100, 111, 110, 101, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 64, 123, 62, 44, 45, 49, 125,
  93, 10, 45, 99, 114, 111, 112, 32, 36, 111, 118, 101, 114, 108, 97, 112,
  44, 36, 111, 118, 101, 114, 108, 97, 112, 44, 123, 36, 116, 105, 108, 101,
  95, 115, 105, 122, 101, 43, 36, 111, 118, 101, 114, 108, 97, 112, 45, 49,
  125, 44, 123, 36, 116, 105, 108, 101, 95, 115, 105, 122, 101, 43, 36, 111,
  118, 101, 114, 108, 97, 112, 45, 49, 125, 10, 45, 101, 110, 100, 108, 10,
  45, 100, 111, 110, 101, 10, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105,
  108, 101, 115, 32, 36, 104, 95, 116, 105, 108, 101, 115, 44, 36, 118, 95,
  116, 105, 108, 101, 115, 10, 45, 99, 114, 111, 112, 32, 48, 44, 48, 44,
  123, 36, 99, 114, 111, 112, 119, 105, 100, 116, 104, 45, 49, 125, 44, 123,
  36, 99, 114, 111, 112, 104, 101, 105, 103, 104, 116, 45, 49, 125, 10, 35,
  64, 103, 105, 109, 112, 32, 77, 115, 32, 112, 97, 116, 99, 104, 32, 99,
  104, 114, 111, 109, 97, 32, 58, 32, 109, 115, 95, 112, 97, 116, 99, 104,
  95, 99, 44, 32, 109, 115, 95, 112, 97, 116, 99, 104, 95, 99, 95, 112,
  114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34,
  77, 97, 115, 116, 101, 114, 32, 80, 97, 116, 99, 104, 32, 98, 97, 115,
  101, 100, 32, 115, 109, 111, 111, 116, 104, 105, 110, 103, 32, 40, 115, 99,
  97, 108, 101, 32, 49, 41, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 80, 97, 116, 99, 104, 32, 118, 97, 114, 105, 97, 110, 99, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 53, 44, 48, 46, 49, 44,
  53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 101, 100,
  105, 97, 110, 32, 112, 97, 115, 115, 32, 61, 32, 98, 111, 111, 108, 32,
  40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 108, 111,
  98, 97, 108, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 61,
  32, 105, 110, 116, 32, 40, 49, 44, 49, 44, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 99, 97, 108, 101, 32, 50, 32, 61, 32, 102, 108, 111, 97,
  116, 32, 40, 53, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 51, 32, 61, 32, 102, 108,
  111, 97, 116, 32, 40, 52, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 52, 32, 61, 32,
  102, 108, 111, 97, 116, 32, 40, 51, 44, 48, 44, 50, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 53, 32,
  61, 32, 102, 108, 111, 97, 116, 32, 40, 50, 44, 48, 44, 50, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32,
  54, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 49, 44, 48, 44, 50,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 97, 108,
  101, 32, 55, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 49, 44, 48,
  44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 85, 110,
  100, 111, 32, 103, 97, 109, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116,
  32, 40, 49, 46, 51, 44, 49, 44, 51, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 67, 117, 115,
  116, 111, 109, 105, 115, 101, 32, 76, 117, 109, 97, 32, 119, 101, 105, 103,
  104, 116, 105, 110, 103, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 82, 101, 100, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 48, 46,
  51, 55, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 71, 114, 101, 101, 110, 32, 61, 32, 102, 108, 111, 97, 116, 32,
  40, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 66, 108, 117, 101, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40,
  48, 46, 49, 50, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 104, 111, 119, 32, 100, 105, 102, 102, 101, 114, 101, 110, 99, 101, 32,
  61, 32, 98, 111, 111, 108, 32, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 73, 97, 105,
  110, 32, 70, 101, 114, 103, 117, 115, 115, 111, 110, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 32, 58, 32, 49, 48, 32, 68, 101, 99, 101, 109, 98, 101,
  114, 32, 50, 48, 49, 50, 32, 45, 32, 97, 100, 100, 101, 100, 32, 115,
  104, 111, 119, 32, 100, 105, 102, 102, 101, 114, 101, 110, 99, 101, 32, 111,
  112, 116, 105, 111, 110, 32, 97, 110, 100, 32, 99, 104, 97, 110, 103, 101,
  100, 32, 105, 110, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 102, 114,
  111, 109, 32, 108, 111, 99, 97, 108, 32, 111, 112, 101, 114, 97, 116, 105,
  111, 110, 32, 116, 111, 32, 103, 108, 111, 98, 97, 108, 32, 111, 112, 101,
  114, 97, 116, 105, 111, 110, 46, 34, 41, 10, 99, 114, 101, 97, 116, 101,
  95, 108, 117, 109, 97, 95, 109, 105, 120, 58, 10, 45, 45, 115, 112, 108,
  105, 116, 91, 48, 93, 32, 99, 10, 45, 109, 117, 108, 91, 49, 93, 32,
  123, 36, 49, 47, 40, 36, 49, 43, 36, 50, 43, 36, 51, 41, 125, 10,
  45, 109, 117, 108, 91, 50, 93, 32, 123, 36, 50, 47, 40, 36, 49, 43,
  36, 50, 43, 36, 51, 41, 125, 10, 45, 109, 117, 108, 91, 51, 93, 32,
  123, 36, 51, 47, 40, 36, 49, 43, 36, 50, 43, 36, 51, 41, 125, 10,
  45, 97, 100, 100, 91, 49, 45, 51, 93, 10, 45, 107, 101, 101, 112, 91,
  45, 49, 93, 10, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 49, 93,
  10, 109, 115, 95, 112, 97, 116, 99, 104, 95, 99, 58, 10, 45, 116, 111,
  95, 114, 103, 98, 10, 45, 45, 99, 114, 101, 97, 116, 101, 95, 108, 117,
  109, 97, 95, 109, 105, 120, 91, 48, 93, 32, 36, 49, 49, 44, 36, 49,
  50, 44, 36, 49, 51, 10, 45, 110, 97, 109, 101, 91, 45, 49, 93, 32,
  108, 117, 109, 97, 10, 45, 105, 102, 32, 123, 36, 50, 61, 61, 49, 125,
  10, 45, 109, 101, 100, 105, 97, 110, 91, 48, 93, 32, 51, 10, 45, 109,
  101, 100, 105, 97, 110, 91, 48, 93, 32, 51, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 51, 10, 45, 109, 115,
  95, 112, 97, 116, 99, 104, 95, 115, 109, 111, 111, 116, 104, 91, 48, 93,
  32, 49, 48, 44, 36, 49, 44, 51, 44, 53, 44, 48, 44, 49, 44, 49,
  44, 48, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36,
  56, 44, 36, 57, 44, 36, 49, 48, 10, 45, 100, 111, 110, 101, 10, 45,
  45, 99, 114, 101, 97, 116, 101, 95, 108, 117, 109, 97, 95, 109, 105, 120,
  91, 48, 93, 32, 36, 49, 49, 44, 36, 49, 50, 44, 36, 49, 51, 10,
  45, 115, 117, 98, 91, 48, 93, 32, 91, 45, 49, 93, 10, 45, 97, 100,
  100, 91, 48, 93, 32, 91, 49, 93, 10, 45, 107, 101, 101, 112, 91, 48,
  93, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10, 109, 115, 95, 112, 97,
  116, 99, 104, 95, 99, 95, 112, 114, 101, 118, 105, 101, 119, 58, 10, 45,
  105, 102, 32, 123, 36, 45, 49, 61, 61, 48, 125, 10, 45, 109, 115, 95,
  112, 97, 116, 99, 104, 95, 99, 32, 36, 123, 49, 45, 45, 50, 125, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 45, 49, 61,
  61, 49, 125, 10, 45, 45, 109, 115, 95, 112, 97, 116, 99, 104, 95, 99,
  32, 36, 123, 49, 45, 45, 50, 125, 10, 45, 115, 117, 98, 91, 48, 93,
  32, 91, 49, 93, 10, 45, 107, 101, 101, 112, 91, 48, 93, 10, 45, 109,
  117, 108, 32, 50, 10, 45, 97, 100, 100, 32, 49, 50, 56, 10, 45, 101,
  110, 100, 105, 102, 10, 35, 64, 103, 105, 109, 112, 32, 77, 117, 108, 116,
  105, 32, 115, 99, 97, 108, 101, 32, 112, 97, 116, 99, 104, 32, 115, 109,
  111, 111, 116, 104, 105, 110, 103, 32, 58, 32, 109, 115, 95, 112, 97, 116,
  99, 104, 95, 115, 109, 111, 111, 116, 104, 44, 109, 115, 95, 112, 97, 116,
  99, 104, 95, 115, 109, 111, 111, 116, 104, 95, 112, 114, 101, 118, 105, 101,
  119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 78, 111, 114, 109, 97,
  108, 32, 80, 97, 116, 99, 104, 32, 98, 97, 115, 101, 100, 32, 115, 109,
  111, 111, 116, 104, 105, 110, 103, 32, 40, 115, 99, 97, 108, 101, 32, 49,
  41, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 97,
  116, 105, 97, 108, 32, 118, 97, 114, 105, 97, 110, 99, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 32, 40, 49, 48, 44, 48, 44, 50, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 116, 99, 104, 32, 118,
  97, 114, 105, 97, 110, 99, 101, 32, 61, 32, 102, 108, 111, 97, 116, 32,
  40, 53, 44, 48, 46, 49, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 80, 97, 116, 99, 104, 32, 115, 105, 122, 101, 32, 61,
  32, 105, 110, 116, 32, 40, 51, 44, 50, 44, 50, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 76, 111, 111, 107, 117, 112, 32, 115, 105,
  122, 101, 32, 61, 32, 105, 110, 116, 32, 40, 53, 44, 50, 44, 50, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 116, 99, 104,
  32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 32, 40, 48, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 70, 97, 115, 116, 32, 97, 112, 112, 114, 111, 120,
  105, 109, 97, 116, 105, 111, 110, 32, 61, 32, 98, 111, 111, 108, 32, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101, 114,
  97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 32, 40, 49, 44,
  49, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104,
  97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 32, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44,
  34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101,
  34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32,
  99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101,
  100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97,
  116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101,
  34, 44, 34, 75, 101, 121, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44,
  34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44,
  34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100,
  34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34,
  44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 80, 97, 116, 99,
  104, 32, 86, 97, 114, 105, 97, 110, 99, 101, 32, 102, 111, 114, 32, 97,
  100, 100, 105, 116, 105, 111, 110, 97, 108, 32, 115, 99, 97, 108, 101, 115,
  34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 97, 108,
  101, 32, 50, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 53, 44, 48,
  44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99,
  97, 108, 101, 32, 51, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 52,
  44, 48, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 99, 97, 108, 101, 32, 52, 32, 61, 32, 102, 108, 111, 97, 116, 32,
  40, 51, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 99, 97, 108, 101, 32, 53, 32, 61, 32, 102, 108, 111, 97,
  116, 32, 40, 50, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 54, 32, 61, 32, 102, 108,
  111, 97, 116, 32, 40, 49, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 55, 32, 61, 32,
  102, 108, 111, 97, 116, 32, 40, 49, 44, 48, 44, 50, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 85, 110, 100, 111, 32, 103, 97, 109,
  109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 49, 46, 51, 44,
  49, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 111, 119, 32, 100,
  105, 102, 102, 101, 114, 101, 110, 99, 101, 32, 61, 32, 98, 111, 111, 108,
  32, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 65, 117, 116, 104, 111, 114, 32, 58, 32,
  60, 105, 62, 73, 97, 105, 110, 32, 70, 101, 114, 103, 117, 115, 115, 111,
  110, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 50, 56, 32, 65,
  117, 103, 117, 115, 116, 32, 50, 48, 49, 50, 32, 45, 32, 109, 105, 110,
  111, 114, 32, 115, 112, 101, 101, 100, 32, 117, 112, 44, 32, 98, 117, 116,
  32, 108, 101, 118, 101, 108, 32, 55, 32, 100, 111, 101, 115, 32, 110, 111,
  116, 32, 100, 111, 32, 97, 110, 121, 116, 104, 105, 110, 103, 32, 110, 111,
  119, 46, 34, 41, 10, 109, 115, 95, 112, 97, 116, 99, 104, 95, 115, 109,
  111, 111, 116, 104, 115, 109, 111, 111, 116, 104, 105, 110, 103, 58, 10, 45,
  97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34,
  45, 114, 101, 112, 101, 97, 116, 32, 36, 55, 32, 45, 100, 101, 110, 111,
  105, 115, 101, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44,
  36, 53, 44, 36, 54, 32, 45, 100, 111, 110, 101, 34, 44, 36, 56, 44,
  48, 32, 45, 99, 32, 48, 44, 50, 53, 53, 10, 109, 115, 95, 112, 97,
  116, 99, 104, 95, 115, 109, 111, 111, 116, 104, 58, 10, 108, 118, 108, 50,
  61, 50, 10, 108, 118, 108, 51, 61, 51, 10, 108, 118, 108, 52, 61, 52,
  10, 108, 118, 108, 53, 61, 53, 10, 108, 118, 108, 54, 61, 54, 10, 108,
  118, 108, 55, 61, 56, 10, 45, 97, 112, 112, 108, 121, 95, 103, 97, 109,
  109, 97, 32, 123, 49, 47, 36, 49, 53, 125, 10, 45, 109, 115, 95, 112,
  97, 116, 99, 104, 95, 115, 109, 111, 111, 116, 104, 115, 109, 111, 111, 116,
  104, 105, 110, 103, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36,
  51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56,
  10, 45, 110, 97, 109, 101, 91, 48, 93, 32, 102, 117, 108, 108, 10, 45,
  45, 114, 101, 115, 105, 122, 101, 91, 102, 117, 108, 108, 93, 32, 64, 123,
  102, 117, 108, 108, 44, 119, 47, 36, 108, 118, 108, 50, 125, 44, 64, 123,
  102, 117, 108, 108, 44, 104, 47, 36, 108, 118, 108, 50, 125, 44, 49, 44,
  123, 115, 125, 44, 50, 32, 45, 110, 97, 109, 101, 91, 49, 93, 32, 108,
  101, 118, 101, 108, 50, 10, 45, 45, 109, 115, 95, 112, 97, 116, 99, 104,
  95, 115, 109, 111, 111, 116, 104, 115, 109, 111, 111, 116, 104, 105, 110, 103,
  91, 108, 101, 118, 101, 108, 50, 93, 32, 36, 49, 44, 36, 57, 44, 36,
  51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56,
  32, 32, 45, 110, 97, 109, 101, 91, 50, 93, 32, 108, 101, 118, 101, 108,
  50, 99, 108, 101, 97, 110, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91,
  108, 101, 118, 101, 108, 50, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64,
  123, 48, 44, 104, 125, 44, 49, 44, 123, 115, 125, 44, 53, 32, 32, 45,
  110, 97, 109, 101, 91, 51, 93, 32, 108, 111, 119, 50, 10, 45, 45, 115,
  117, 98, 91, 102, 117, 108, 108, 93, 32, 91, 108, 111, 119, 50, 93, 32,
  32, 45, 110, 97, 109, 101, 91, 52, 93, 32, 108, 101, 118, 101, 108, 50,
  104, 105, 103, 104, 10, 45, 114, 101, 109, 111, 118, 101, 91, 108, 101, 118,
  101, 108, 50, 44, 108, 111, 119, 50, 93, 10, 45, 45, 114, 101, 115, 105,
  122, 101, 91, 108, 101, 118, 101, 108, 50, 99, 108, 101, 97, 110, 93, 32,
  64, 123, 102, 117, 108, 108, 44, 119, 47, 36, 108, 118, 108, 51, 125, 44,
  64, 123, 102, 117, 108, 108, 44, 104, 47, 36, 108, 118, 108, 51, 125, 44,
  49, 44, 123, 115, 125, 44, 50, 32, 45, 110, 97, 109, 101, 91, 51, 93,
  32, 108, 101, 118, 101, 108, 51, 10, 45, 45, 109, 115, 95, 112, 97, 116,
  99, 104, 95, 115, 109, 111, 111, 116, 104, 115, 109, 111, 111, 116, 104, 105,
  110, 103, 91, 108, 101, 118, 101, 108, 51, 93, 32, 36, 49, 44, 36, 49,
  48, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55,
  44, 36, 56, 32, 32, 45, 110, 97, 109, 101, 91, 52, 93, 32, 108, 101,
  118, 101, 108, 51, 99, 108, 101, 97, 110, 10, 45, 45, 114, 101, 115, 105,
  122, 101, 91, 108, 101, 118, 101, 108, 51, 93, 32, 64, 123, 108, 101, 118,
  101, 108, 50, 99, 108, 101, 97, 110, 44, 119, 125, 44, 64, 123, 108, 101,
  118, 101, 108, 50, 99, 108, 101, 97, 110, 44, 104, 125, 44, 49, 44, 123,
  115, 125, 44, 53, 32, 32, 45, 110, 97, 109, 101, 91, 53, 93, 32, 108,
  111, 119, 51, 10, 45, 45, 115, 117, 98, 91, 108, 101, 118, 101, 108, 50,
  99, 108, 101, 97, 110, 93, 32, 91, 108, 111, 119, 51, 93, 32, 32, 45,
  110, 97, 109, 101, 91, 54, 93, 32, 108, 101, 118, 101, 108, 51, 104, 105,
  103, 104, 10, 45, 114, 101, 109, 111, 118, 101, 91, 108, 101, 118, 101, 108,
  51, 44, 108, 111, 119, 51, 93, 10, 45, 45, 114, 101, 115, 105, 122, 101,
  91, 108, 101, 118, 101, 108, 51, 99, 108, 101, 97, 110, 93, 32, 64, 123,
  102, 117, 108, 108, 44, 119, 47, 36, 108, 118, 108, 52, 125, 44, 64, 123,
  102, 117, 108, 108, 44, 104, 47, 36, 108, 118, 108, 52, 125, 44, 49, 44,
  123, 115, 125, 44, 50, 32, 45, 110, 97, 109, 101, 91, 53, 93, 32, 108,
  101, 118, 101, 108, 52, 10, 45, 45, 109, 115, 95, 112, 97, 116, 99, 104,
  95, 115, 109, 111, 111, 116, 104, 115, 109, 111, 111, 116, 104, 105, 110, 103,
  91, 108, 101, 118, 101, 108, 52, 93, 32, 36, 49, 44, 36, 49, 49, 44,
  36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36,
  56, 32, 32, 45, 110, 97, 109, 101, 91, 54, 93, 32, 108, 101, 118, 101,
  108, 52, 99, 108, 101, 97, 110, 10, 45, 45, 114, 101, 115, 105, 122, 101,
  91, 108, 101, 118, 101, 108, 52, 93, 32, 64, 123, 108, 101, 118, 101, 108,
  51, 99, 108, 101, 97, 110, 44, 119, 125, 44, 64, 123, 108, 101, 118, 101,
  108, 51, 99, 108, 101, 97, 110, 44, 104, 125, 44, 49, 44, 123, 115, 125,
  44, 53, 32, 32, 45, 110, 97, 109, 101, 91, 55, 93, 32, 108, 111, 119,
  52, 10, 45, 45, 115, 117, 98, 91, 108, 101, 118, 101, 108, 51, 99, 108,
  101, 97, 110, 93, 32, 91, 108, 111, 119, 52, 93, 32, 32, 45, 110, 97,
  109, 101, 91, 56, 93, 32, 108, 101, 118, 101, 108, 52, 104, 105, 103, 104,
  10, 45, 114, 101, 109, 111, 118, 101, 91, 108, 101, 118, 101, 108, 52, 44,
  108, 111, 119, 52, 93, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 108,
  101, 118, 101, 108, 52, 99, 108, 101, 97, 110, 93, 32, 64, 123, 102, 117,
  108, 108, 44, 119, 47, 36, 108, 118, 108, 53, 125, 44, 64, 123, 102, 117,
  108, 108, 44, 104, 47, 36, 108, 118, 108, 53, 125, 44, 49, 44, 123, 115,
  125, 44, 50, 32, 45, 110, 97, 109, 101, 91, 45, 49, 93, 32, 108, 101,
  118, 101, 108, 53, 10, 45, 45, 109, 115, 95, 112, 97, 116, 99, 104, 95,
  115, 109, 111, 111, 116, 104, 115, 109, 111, 111, 116, 104, 105, 110, 103, 91,
  108, 101, 118, 101, 108, 53, 93, 32, 36, 49, 44, 36, 49, 50, 44, 36,
  51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56,
  32, 32, 45, 110, 97, 109, 101, 91, 45, 49, 93, 32, 108, 101, 118, 101,
  108, 53, 99, 108, 101, 97, 110, 10, 45, 45, 114, 101, 115, 105, 122, 101,
  91, 108, 101, 118, 101, 108, 53, 93, 32, 64, 123, 108, 101, 118, 101, 108,
  52, 99, 108, 101, 97, 110, 44, 119, 125, 44, 64, 123, 108, 101, 118, 101,
  108, 52, 99, 108, 101, 97, 110, 44, 104, 125, 44, 49, 44, 123, 115, 125,
  44, 53, 32, 32, 45, 110, 97, 109, 101, 91, 45, 49, 93, 32, 108, 111,
  119, 53, 10, 45, 45, 115, 117, 98, 91, 108, 101, 118, 101, 108, 52, 99,
  108, 101, 97, 110, 93, 32, 91, 108, 111, 119, 53, 93, 32, 32, 45, 110,
  97, 109, 101, 91, 45, 49, 93, 32, 108, 101, 118, 101, 108, 53, 104, 105,
  103, 104, 10, 45, 114, 101, 109, 111, 118, 101, 91, 108, 101, 118, 101, 108,
  53, 44, 108, 111, 119, 53, 93, 10, 45, 45, 114, 101, 115, 105, 122, 101,
  91, 108, 101, 118, 101, 108, 53, 99, 108, 101, 97, 110, 93, 32, 64, 123,
  102, 117, 108, 108, 44, 119, 47, 36, 108, 118, 108, 54, 125, 44, 64, 123,
  102, 117, 108, 108, 44, 104, 47, 36, 108, 118, 108, 54, 125, 44, 49, 44,
  123, 115, 125, 44, 50, 32, 45, 110, 97, 109, 101, 91, 45, 49, 93, 32,
  108, 101, 118, 101, 108, 54, 10, 45, 45, 109, 115, 95, 112, 97, 116, 99,
  104, 95, 115, 109, 111, 111, 116, 104, 115, 109, 111, 111, 116, 104, 105, 110,
  103, 91, 108, 101, 118, 101, 108, 54, 93, 32, 36, 49, 44, 36, 49, 51,
  44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44,
  36, 56, 32, 32, 45, 110, 97, 109, 101, 91, 45, 49, 93, 32, 108, 101,
  118, 101, 108, 54, 99, 108, 101, 97, 110, 10, 45, 45, 114, 101, 115, 105,
  122, 101, 91, 108, 101, 118, 101, 108, 54, 93, 32, 64, 123, 108, 101, 118,
  101, 108, 53, 99, 108, 101, 97, 110, 44, 119, 125, 44, 64, 123, 108, 101,
  118, 101, 108, 53, 99, 108, 101, 97, 110, 44, 104, 125, 44, 49, 44, 123,
  115, 125, 44, 53, 32, 32, 45, 110, 97, 109, 101, 91, 45, 49, 93, 32,
  108, 111, 119, 54, 10, 45, 45, 115, 117, 98, 91, 108, 101, 118, 101, 108,
  53, 99, 108, 101, 97, 110, 93, 32, 91, 108, 111, 119, 54, 93, 32, 32,
  45, 110, 97, 109, 101, 91, 45, 49, 93, 32, 108, 101, 118, 101, 108, 54,
  104, 105, 103, 104, 10, 45, 114, 101, 109, 111, 118, 101, 91, 108, 101, 118,
  101, 108, 54, 44, 108, 111, 119, 54, 93, 10, 45, 110, 97, 109, 101, 91,
  45, 50, 93, 32, 98, 97, 115, 101, 10, 45, 114, 101, 115, 105, 122, 101,
  91, 98, 97, 115, 101, 93, 32, 64, 123, 108, 101, 118, 101, 108, 54, 104,
  105, 103, 104, 44, 119, 125, 44, 64, 123, 108, 101, 118, 101, 108, 54, 104,
  105, 103, 104, 44, 104, 125, 44, 49, 44, 123, 115, 125, 44, 53, 10, 45,
  97, 100, 100, 91, 98, 97, 115, 101, 93, 32, 91, 108, 101, 118, 101, 108,
  54, 104, 105, 103, 104, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 108,
  101, 118, 101, 108, 54, 104, 105, 103, 104, 93, 10, 45, 114, 101, 115, 105,
  122, 101, 91, 98, 97, 115, 101, 93, 32, 64, 123, 108, 101, 118, 101, 108,
  53, 104, 105, 103, 104, 44, 119, 125, 44, 64, 123, 108, 101, 118, 101, 108,
  53, 104, 105, 103, 104, 44, 104, 125, 44, 49, 44, 123, 115, 125, 44, 53,
  10, 45, 97, 100, 100, 91, 98, 97, 115, 101, 93, 32, 91, 108, 101, 118,
  101, 108, 53, 104, 105, 103, 104, 93, 10, 45, 114, 101, 109, 111, 118, 101,
  91, 108, 101, 118, 101, 108, 53, 104, 105, 103, 104, 93, 10, 45, 114, 101,
  115, 105, 122, 101, 91, 98, 97, 115, 101, 93, 32, 64, 123, 108, 101, 118,
  101, 108, 52, 104, 105, 103, 104, 44, 119, 125, 44, 64, 123, 108, 101, 118,
  101, 108, 52, 104, 105, 103, 104, 44, 104, 125, 44, 49, 44, 123, 115, 125,
  44, 53, 10, 45, 97, 100, 100, 91, 98, 97, 115, 101, 93, 32, 91, 108,
  101, 118, 101, 108, 52, 104, 105, 103, 104, 93, 10, 45, 114, 101, 109, 111,
  118, 101, 91, 108, 101, 118, 101, 108, 52, 104, 105, 103, 104, 93, 10, 45,
  114, 101, 115, 105, 122, 101, 91, 98, 97, 115, 101, 93, 32, 64, 123, 108,
  101, 118, 101, 108, 51, 104, 105, 103, 104, 44, 119, 125, 44, 64, 123, 108,
  101, 118, 101, 108, 51, 104, 105, 103, 104, 44, 104, 125, 44, 49, 44, 123,
  115, 125, 44, 53, 10, 45, 97, 100, 100, 91, 98, 97, 115, 101, 93, 32,
  91, 108, 101, 118, 101, 108, 51, 104, 105, 103, 104, 93, 10, 45, 114, 101,
  109, 111, 118, 101, 91, 108, 101, 118, 101, 108, 51, 104, 105, 103, 104, 93,
  10, 45, 114, 101, 115, 105, 122, 101, 91, 98, 97, 115, 101, 93, 32, 64,
  123, 108, 101, 118, 101, 108, 50, 104, 105, 103, 104, 44, 119, 125, 44, 64,
  123, 108, 101, 118, 101, 108, 50, 104, 105, 103, 104, 44, 104, 125, 44, 49,
  44, 123, 115, 125, 44, 53, 10, 45, 97, 100, 100, 91, 98, 97, 115, 101,
  93, 32, 91, 108, 101, 118, 101, 108, 50, 104, 105, 103, 104, 93, 10, 45,
  114, 101, 109, 111, 118, 101, 91, 108, 101, 118, 101, 108, 50, 104, 105, 103,
  104, 93, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 45, 99, 32,
  48, 44, 50, 53, 53, 10, 45, 97, 112, 112, 108, 121, 95, 103, 97, 109,
  109, 97, 32, 123, 36, 49, 53, 125, 10, 45, 99, 32, 48, 44, 50, 53,
  53, 10, 109, 115, 95, 112, 97, 116, 99, 104, 95, 115, 109, 111, 111, 116,
  104, 95, 112, 114, 101, 118, 105, 101, 119, 58, 10, 45, 105, 102, 32, 123,
  36, 45, 49, 61, 61, 48, 125, 10, 45, 109, 115, 95, 112, 97, 116, 99,
  104, 95, 115, 109, 111, 111, 116, 104, 32, 36, 123, 49, 45, 45, 50, 125,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 45, 49,
  61, 61, 49, 125, 10, 45, 45, 109, 115, 95, 112, 97, 116, 99, 104, 95,
  115, 109, 111, 111, 116, 104, 32, 36, 123, 49, 45, 45, 50, 125, 10, 45,
  115, 117, 98, 91, 48, 93, 32, 91, 49, 93, 10, 45, 107, 101, 101, 112,
  91, 48, 93, 10, 45, 109, 117, 108, 32, 50, 10, 45, 97, 100, 100, 32,
  49, 50, 56, 10, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103, 105, 109,
  112, 32, 77, 117, 108, 116, 105, 32, 115, 99, 97, 108, 101, 32, 115, 109,
  111, 111, 116, 104, 105, 110, 103, 32, 58, 32, 109, 115, 95, 115, 109, 111,
  111, 116, 104, 44, 109, 115, 95, 115, 109, 111, 111, 116, 104, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 109, 111, 111, 116, 104, 32, 115, 99, 97, 108, 101, 32, 49,
  32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111,
  116, 104, 32, 115, 99, 97, 108, 101, 32, 50, 32, 61, 32, 102, 108, 111,
  97, 116, 32, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 32, 115, 99, 97,
  108, 101, 32, 51, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 109, 111, 111, 116, 104, 32, 115, 99, 97, 108, 101, 32, 52, 32, 61,
  32, 102, 108, 111, 97, 116, 32, 40, 48, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104,
  32, 115, 99, 97, 108, 101, 32, 53, 32, 61, 32, 102, 108, 111, 97, 116,
  32, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 32, 115, 99, 97, 108, 101,
  32, 54, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 48, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  32, 40, 50, 44, 48, 44, 49, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 76, 111, 103, 32, 115, 99, 97, 108, 101, 115, 32, 61, 32,
  98, 111, 111, 108, 32, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 71, 108, 111, 98, 97, 108, 32, 114, 101, 112, 101, 97, 116, 115,
  32, 61, 32, 105, 110, 116, 32, 40, 50, 44, 48, 44, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 111, 119, 32, 100, 105, 102,
  102, 101, 114, 101, 110, 99, 101, 32, 61, 32, 98, 111, 111, 108, 32, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 65, 117, 116, 104, 111, 114, 58, 32, 73, 97, 105,
  110, 32, 70, 101, 114, 103, 117, 115, 115, 111, 110, 32, 45, 32, 117, 112,
  100, 97, 116, 101, 32, 55, 32, 68, 101, 99, 32, 50, 48, 49, 50, 34,
  41, 10, 109, 115, 95, 115, 109, 111, 111, 116, 104, 115, 109, 111, 111, 116,
  104, 105, 110, 103, 58, 10, 45, 115, 109, 111, 111, 116, 104, 32, 123, 36,
  49, 42, 53, 125, 44, 48, 46, 55, 44, 48, 46, 55, 44, 48, 46, 54,
  44, 36, 50, 44, 48, 46, 56, 44, 51, 48, 44, 50, 44, 48, 44, 49,
  10, 109, 115, 95, 115, 109, 111, 111, 116, 104, 58, 10, 45, 105, 102, 32,
  123, 36, 56, 61, 61, 48, 125, 10, 108, 118, 108, 50, 61, 50, 10, 108,
  118, 108, 51, 61, 51, 10, 108, 118, 108, 52, 61, 52, 10, 108, 118, 108,
  53, 61, 53, 10, 108, 118, 108, 54, 61, 54, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 56, 61, 61, 49, 125, 10, 108, 118,
  108, 50, 61, 50, 10, 108, 118, 108, 51, 61, 52, 10, 108, 118, 108, 52,
  61, 56, 10, 108, 118, 108, 53, 61, 49, 54, 10, 108, 118, 108, 54, 61,
  51, 50, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 36, 57, 10, 45, 105, 102, 32, 123, 36, 49, 62, 48, 125, 10,
  45, 109, 115, 95, 115, 109, 111, 111, 116, 104, 115, 109, 111, 111, 116, 104,
  105, 110, 103, 91, 45, 49, 93, 32, 36, 49, 44, 36, 55, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 110, 97, 109, 101, 91, 48, 93, 32, 102, 117,
  108, 108, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 102, 117, 108, 108,
  93, 32, 64, 123, 102, 117, 108, 108, 44, 119, 47, 36, 108, 118, 108, 50,
  125, 44, 64, 123, 102, 117, 108, 108, 44, 104, 47, 36, 108, 118, 108, 50,
  125, 44, 49, 44, 123, 115, 125, 44, 50, 32, 45, 110, 97, 109, 101, 91,
  49, 93, 32, 108, 101, 118, 101, 108, 50, 10, 45, 105, 102, 32, 123, 36,
  50, 62, 48, 125, 10, 45, 45, 109, 115, 95, 115, 109, 111, 111, 116, 104,
  115, 109, 111, 111, 116, 104, 105, 110, 103, 91, 108, 101, 118, 101, 108, 50,
  93, 32, 32, 36, 50, 44, 36, 55, 10, 45, 101, 108, 115, 101, 32, 91,
  108, 101, 118, 101, 108, 50, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  110, 97, 109, 101, 91, 50, 93, 32, 108, 101, 118, 101, 108, 50, 99, 108,
  101, 97, 110, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 108, 101, 118,
  101, 108, 50, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44,
  104, 125, 44, 49, 44, 123, 115, 125, 44, 53, 32, 32, 45, 110, 97, 109,
  101, 91, 51, 93, 32, 108, 111, 119, 50, 10, 45, 45, 115, 117, 98, 91,
  102, 117, 108, 108, 93, 32, 91, 108, 111, 119, 50, 93, 32, 32, 45, 110,
  97, 109, 101, 91, 52, 93, 32, 108, 101, 118, 101, 108, 50, 104, 105, 103,
  104, 10, 45, 114, 101, 109, 111, 118, 101, 91, 108, 101, 118, 101, 108, 50,
  44, 108, 111, 119, 50, 93, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91,
  108, 101, 118, 101, 108, 50, 99, 108, 101, 97, 110, 93, 32, 64, 123, 102,
  117, 108, 108, 44, 119, 47, 36, 108, 118, 108, 51, 125, 44, 64, 123, 102,
  117, 108, 108, 44, 104, 47, 36, 108, 118, 108, 51, 125, 44, 49, 44, 123,
  115, 125, 44, 50, 32, 45, 110, 97, 109, 101, 91, 51, 93, 32, 108, 101,
  118, 101, 108, 51, 10, 45, 105, 102, 32, 123, 36, 51, 62, 48, 125, 10,
  45, 45, 109, 115, 95, 115, 109, 111, 111, 116, 104, 115, 109, 111, 111, 116,
  104, 105, 110, 103, 91, 108, 101, 118, 101, 108, 51, 93, 32, 36, 51, 44,
  36, 55, 10, 45, 101, 108, 115, 101, 32, 91, 108, 101, 118, 101, 108, 51,
  93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 110, 97, 109, 101, 91, 52,
  93, 32, 108, 101, 118, 101, 108, 51, 99, 108, 101, 97, 110, 10, 45, 45,
  114, 101, 115, 105, 122, 101, 91, 108, 101, 118, 101, 108, 51, 93, 32, 64,
  123, 108, 101, 118, 101, 108, 50, 99, 108, 101, 97, 110, 44, 119, 125, 44,
  64, 123, 108, 101, 118, 101, 108, 50, 99, 108, 101, 97, 110, 44, 104, 125,
  44, 49, 44, 123, 115, 125, 44, 53, 32, 32, 45, 110, 97, 109, 101, 91,
  53, 93, 32, 108, 111, 119, 51, 10, 45, 45, 115, 117, 98, 91, 108, 101,
  118, 101, 108, 50, 99, 108, 101, 97, 110, 93, 32, 91, 108, 111, 119, 51,
  93, 32, 32, 45, 110, 97, 109, 101, 91, 54, 93, 32, 108, 101, 118, 101,
  108, 51, 104, 105, 103, 104, 10, 45, 114, 101, 109, 111, 118, 101, 91, 108,
  101, 118, 101, 108, 51, 44, 108, 111, 119, 51, 93, 10, 45, 45, 114, 101,
  115, 105, 122, 101, 91, 108, 101, 118, 101, 108, 51, 99, 108, 101, 97, 110,
  93, 32, 64, 123, 102, 117, 108, 108, 44, 119, 47, 36, 108, 118, 108, 52,
  125, 44, 64, 123, 102, 117, 108, 108, 44, 104, 47, 36, 108, 118, 108, 52,
  125, 44, 49, 44, 123, 115, 125, 44, 50, 32, 45, 110, 97, 109, 101, 91,
  53, 93, 32, 108, 101, 118, 101, 108, 52, 10, 45, 105, 102, 32, 123, 36,
  52, 62, 48, 125, 10, 45, 45, 109, 115, 95, 115, 109, 111, 111, 116, 104,
  115, 109, 111, 111, 116, 104, 105, 110, 103, 91, 108, 101, 118, 101, 108, 52,
  93, 32, 36, 52, 44, 36, 55, 10, 45, 101, 108, 115, 101, 32, 91, 108,
  101, 118, 101, 108, 52, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 110,
  97, 109, 101, 91, 54, 93, 32, 108, 101, 118, 101, 108, 52, 99, 108, 101,
  97, 110, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 108, 101, 118, 101,
  108, 52, 93, 32, 64, 123, 108, 101, 118, 101, 108, 51, 99, 108, 101, 97,
  110, 44, 119, 125, 44, 64, 123, 108, 101, 118, 101, 108, 51, 99, 108, 101,
  97, 110, 44, 104, 125, 44, 49, 44, 123, 115, 125, 44, 53, 32, 32, 45,
  110, 97, 109, 101, 91, 55, 93, 32, 108, 111, 119, 52, 10, 45, 45, 115,
  117, 98, 91, 108, 101, 118, 101, 108, 51, 99, 108, 101, 97, 110, 93, 32,
  91, 108, 111, 119, 52, 93, 32, 32, 45, 110, 97, 109, 101, 91, 56, 93,
  32, 108, 101, 118, 101, 108, 52, 104, 105, 103, 104, 10, 45, 114, 101, 109,
  111, 118, 101, 91, 108, 101, 118, 101, 108, 52, 44, 108, 111, 119, 52, 93,
  10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 108, 101, 118, 101, 108, 52,
  99, 108, 101, 97, 110, 93, 32, 64, 123, 102, 117, 108, 108, 44, 119, 47,
  36, 108, 118, 108, 53, 125, 44, 64, 123, 102, 117, 108, 108, 44, 104, 47,
  36, 108, 118, 108, 53, 125, 44, 49, 44, 123, 115, 125, 44, 50, 32, 45,
  110, 97, 109, 101, 91, 45, 49, 93, 32, 108, 101, 118, 101, 108, 53, 10,
  45, 105, 102, 32, 123, 36, 53, 62, 48, 125, 10, 45, 45, 109, 115, 95,
  115, 109, 111, 111, 116, 104, 115, 109, 111, 111, 116, 104, 105, 110, 103, 91,
  108, 101, 118, 101, 108, 53, 93, 32, 36, 53, 44, 36, 55, 10, 45, 101,
  108, 115, 101, 32, 91, 108, 101, 118, 101, 108, 53, 93, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 110, 97, 109, 101, 91, 45, 49, 93, 32, 108, 101,
  118, 101, 108, 53, 99, 108, 101, 97, 110, 10, 45, 45, 114, 101, 115, 105,
  122, 101, 91, 108, 101, 118, 101, 108, 53, 93, 32, 64, 123, 108, 101, 118,
  101, 108, 52, 99, 108, 101, 97, 110, 44, 119, 125, 44, 64, 123, 108, 101,
  118, 101, 108, 52, 99, 108, 101, 97, 110, 44, 104, 125, 44, 49, 44, 123,
  115, 125, 44, 53, 32, 32, 45, 110, 97, 109, 101, 91, 45, 49, 93, 32,
  108, 111, 119, 53, 10, 45, 45, 115, 117, 98, 91, 108, 101, 118, 101, 108,
  52, 99, 108, 101, 97, 110, 93, 32, 91, 108, 111, 119, 53, 93, 32, 32,
  45, 110, 97, 109, 101, 91, 45, 49, 93, 32, 108, 101, 118, 101, 108, 53,
  104, 105, 103, 104, 10, 45, 114, 101, 109, 111, 118, 101, 91, 108, 101, 118,
  101, 108, 53, 44, 108, 111, 119, 53, 93, 10, 45, 45, 114, 101, 115, 105,
  122, 101, 91, 108, 101, 118, 101, 108, 53, 99, 108, 101, 97, 110, 93, 32,
  64, 123, 102, 117, 108, 108, 44, 119, 47, 36, 108, 118, 108, 54, 125, 44,
  64, 123, 102, 117, 108, 108, 44, 104, 47, 36, 108, 118, 108, 54, 125, 44,
  49, 44, 123, 115, 125, 44, 50, 32, 45, 110, 97, 109, 101, 91, 45, 49,
  93, 32, 108, 101, 118, 101, 108, 54, 10, 45, 105, 102, 32, 123, 36, 54,
  62, 48, 125, 10, 45, 45, 109, 115, 95, 115, 109, 111, 111, 116, 104, 115,
  109, 111, 111, 116, 104, 105, 110, 103, 91, 108, 101, 118, 101, 108, 54, 93,
  32, 32, 36, 54, 44, 36, 55, 10, 45, 101, 108, 115, 101, 32, 91, 108,
  101, 118, 101, 108, 54, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 110,
  97, 109, 101, 91, 45, 49, 93, 32, 108, 101, 118, 101, 108, 54, 99, 108,
  101, 97, 110, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 108, 101, 118,
  101, 108, 54, 93, 32, 64, 123, 108, 101, 118, 101, 108, 53, 99, 108, 101,
  97, 110, 44, 119, 125, 44, 64, 123, 108, 101, 118, 101, 108, 53, 99, 108,
  101, 97, 110, 44, 104, 125, 44, 49, 44, 123, 115, 125, 44, 53, 32, 32,
  45, 110, 97, 109, 101, 91, 45, 49, 93, 32, 108, 111, 119, 54, 10, 45,
  45, 115, 117, 98, 91, 108, 101, 118, 101, 108, 53, 99, 108, 101, 97, 110,
  93, 32, 91, 108, 111, 119, 54, 93, 32, 32, 45, 110, 97, 109, 101, 91,
  45, 49, 93, 32, 108, 101, 118, 101, 108, 54, 104, 105, 103, 104, 10, 45,
  114, 101, 109, 111, 118, 101, 91, 108, 101, 118, 101, 108, 54, 44, 108, 111,
  119, 54, 93, 10, 45, 110, 97, 109, 101, 91, 45, 50, 93, 32, 98, 97,
  115, 101, 10, 45, 114, 101, 115, 105, 122, 101, 91, 98, 97, 115, 101, 93,
  32, 64, 123, 108, 101, 118, 101, 108, 54, 104, 105, 103, 104, 44, 119, 125,
  44, 64, 123, 108, 101, 118, 101, 108, 54, 104, 105, 103, 104, 44, 104, 125,
  44, 49, 44, 123, 115, 125, 44, 53, 10, 45, 97, 100, 100, 91, 98, 97,
  115, 101, 93, 32, 91, 108, 101, 118, 101, 108, 54, 104, 105, 103, 104, 93,
  10, 45, 114, 101, 109, 111, 118, 101, 91, 108, 101, 118, 101, 108, 54, 104,
  105, 103, 104, 93, 10, 45, 114, 101, 115, 105, 122, 101, 91, 98, 97, 115,
  101, 93, 32, 64, 123, 108, 101, 118, 101, 108, 53, 104, 105, 103, 104, 44,
  119, 125, 44, 64, 123, 108, 101, 118, 101, 108, 53, 104, 105, 103, 104, 44,
  104, 125, 44, 49, 44, 123, 115, 125, 44, 53, 10, 45, 97, 100, 100, 91,
  98, 97, 115, 101, 93, 32, 91, 108, 101, 118, 101, 108, 53, 104, 105, 103,
  104, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 108, 101, 118, 101, 108,
  53, 104, 105, 103, 104, 93, 10, 45, 114, 101, 115, 105, 122, 101, 91, 98,
  97, 115, 101, 93, 32, 64, 123, 108, 101, 118, 101, 108, 52, 104, 105, 103,
  104, 44, 119, 125, 44, 64, 123, 108, 101, 118, 101, 108, 52, 104, 105, 103,
  104, 44, 104, 125, 44, 49, 44, 123, 115, 125, 44, 53, 10, 45, 97, 100,
  100, 91, 98, 97, 115, 101, 93, 32, 91, 108, 101, 118, 101, 108, 52, 104,
  105, 103, 104, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 108, 101, 118,
  101, 108, 52, 104, 105, 103, 104, 93, 10, 45, 114, 101, 115, 105, 122, 101,
  91, 98, 97, 115, 101, 93, 32, 64, 123, 108, 101, 118, 101, 108, 51, 104,
  105, 103, 104, 44, 119, 125, 44, 64, 123, 108, 101, 118, 101, 108, 51, 104,
  105, 103, 104, 44, 104, 125, 44, 49, 44, 123, 115, 125, 44, 53, 10, 45,
  97, 100, 100, 91, 98, 97, 115, 101, 93, 32, 91, 108, 101, 118, 101, 108,
  51, 104, 105, 103, 104, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 108,
  101, 118, 101, 108, 51, 104, 105, 103, 104, 93, 10, 45, 114, 101, 115, 105,
  122, 101, 91, 98, 97, 115, 101, 93, 32, 64, 123, 108, 101, 118, 101, 108,
  50, 104, 105, 103, 104, 44, 119, 125, 44, 64, 123, 108, 101, 118, 101, 108,
  50, 104, 105, 103, 104, 44, 104, 125, 44, 49, 44, 123, 115, 125, 44, 53,
  10, 45, 97, 100, 100, 91, 98, 97, 115, 101, 93, 32, 91, 108, 101, 118,
  101, 108, 50, 104, 105, 103, 104, 93, 10, 45, 114, 101, 109, 111, 118, 101,
  91, 108, 101, 118, 101, 108, 50, 104, 105, 103, 104, 93, 10, 45, 107, 101,
  101, 112, 91, 45, 49, 93, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10,
  45, 99, 32, 48, 44, 50, 53, 53, 10, 45, 100, 111, 110, 101, 10, 109,
  115, 95, 115, 109, 111, 111, 116, 104, 95, 112, 114, 101, 118, 105, 101, 119,
  58, 10, 45, 105, 102, 32, 123, 36, 45, 49, 61, 61, 48, 125, 10, 45,
  109, 115, 95, 115, 109, 111, 111, 116, 104, 32, 36, 49, 44, 36, 50, 44,
  36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36,
  56, 44, 36, 57, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 45, 49, 61, 61, 49, 125, 10, 45, 45, 109, 115, 95, 115, 109,
  111, 111, 116, 104, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52,
  44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 44, 36, 57, 10,
  45, 115, 117, 98, 91, 48, 93, 32, 91, 49, 93, 10, 45, 107, 101, 101,
  112, 91, 48, 93, 10, 45, 109, 117, 108, 32, 50, 10, 45, 97, 100, 100,
  32, 49, 50, 56, 10, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103, 105,
  109, 112, 32, 78, 111, 105, 115, 101, 32, 114, 101, 100, 117, 99, 116, 105,
  111, 110, 32, 51, 32, 58, 32, 110, 114, 51, 44, 110, 114, 51, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 49, 32, 115, 116, 114,
  101, 110, 103, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 49,
  44, 46, 50, 53, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 50, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102,
  108, 111, 97, 116, 32, 40, 49, 44, 46, 48, 44, 53, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 51, 32, 109, 97, 115, 116, 101,
  114, 32, 100, 101, 116, 97, 105, 108, 32, 114, 101, 99, 111, 118, 101, 114,
  121, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 48, 44, 48, 44, 50,
  48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 52, 32,
  97, 100, 106, 117, 115, 116, 32, 102, 105, 110, 101, 32, 100, 101, 116, 97,
  105, 108, 115, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 48, 44, 45,
  53, 48, 48, 44, 53, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 53, 32, 97, 100, 106, 117, 115, 116, 32, 109, 101, 100, 105, 117,
  109, 32, 100, 101, 116, 97, 105, 108, 115, 32, 61, 32, 102, 108, 111, 97,
  116, 32, 40, 48, 44, 45, 53, 48, 48, 44, 53, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 54, 32, 97, 100, 106, 117, 115, 116,
  32, 108, 97, 114, 103, 101, 32, 100, 101, 116, 97, 105, 108, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 32, 40, 48, 44, 45, 53, 48, 48, 44, 53,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 55, 32, 101,
  110, 104, 97, 110, 99, 101, 32, 100, 101, 116, 105, 97, 108, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 32, 40, 49, 44, 48, 44, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 98, 62, 32, 115, 104, 97, 114, 112, 101, 110, 32, 101, 100, 103,
  101, 115, 60, 47, 98, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 56, 32, 114, 97, 100, 105, 117, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 32, 40, 46, 55, 53, 44, 46, 50, 53, 44, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 57, 32, 97, 109, 111, 117, 110, 116,
  32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 49, 44, 48, 44, 52, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 49, 48, 32, 116, 104, 114,
  101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40,
  48, 44, 48, 44, 53, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 98, 62, 32,
  115, 104, 97, 114, 112, 101, 110, 32, 100, 101, 116, 97, 105, 108, 115, 60,
  47, 98, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 49,
  49, 32, 114, 97, 100, 105, 117, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  32, 40, 46, 55, 53, 44, 46, 50, 53, 44, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 49, 50, 32, 97, 109, 111, 117, 110, 116, 32,
  61, 32, 102, 108, 111, 97, 116, 32, 40, 49, 44, 48, 44, 52, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 49, 51, 32, 116, 104, 114, 101,
  115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 48,
  44, 48, 44, 53, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 84, 104, 105, 115, 32,
  102, 105, 108, 116, 101, 114, 32, 105, 115, 32, 111, 110, 108, 121, 32, 105,
  110, 116, 101, 110, 116, 101, 100, 32, 102, 111, 114, 32, 97, 110, 100, 32,
  104, 97, 115, 32, 111, 110, 108, 121, 32, 98, 101, 101, 110, 32, 116, 101,
  115, 116, 101, 100, 32, 111, 110, 32, 103, 114, 101, 121, 115, 99, 97, 108,
  101, 32, 105, 109, 97, 103, 101, 115, 46, 34, 32, 125, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 123, 34, 84, 104, 105, 115, 32, 102, 105, 108, 116, 101, 114, 32, 109,
  101, 97, 115, 117, 114, 101, 115, 32, 110, 111, 105, 115, 101, 32, 105, 110,
  32, 97, 116, 32, 102, 105, 118, 101, 32, 100, 105, 102, 102, 101, 114, 101,
  110, 116, 32, 98, 114, 105, 103, 104, 116, 110, 101, 115, 115, 101, 115, 44,
  32, 105, 102, 32, 121, 111, 117, 114, 32, 112, 114, 101, 118, 105, 101, 119,
  32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 104, 97, 118, 101, 32, 97,
  32, 102, 117, 108, 108, 32, 114, 97, 110, 103, 101, 32, 111, 102, 32, 98,
  114, 105, 103, 104, 116, 110, 101, 115, 115, 32, 115, 104, 111, 119, 110, 32,
  116, 104, 101, 32, 112, 114, 101, 118, 105, 101, 119, 32, 119, 105, 108, 108,
  32, 110, 111, 116, 32, 103, 105, 118, 101, 32, 97, 110, 32, 97, 99, 99,
  117, 114, 97, 116, 101, 32, 105, 110, 100, 105, 99, 97, 116, 105, 111, 110,
  32, 111, 102, 32, 116, 104, 101, 32, 102, 105, 110, 97, 108, 32, 114, 101,
  115, 117, 108, 116, 115, 46, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 65,
  117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 73, 97, 105, 110, 32,
  70, 101, 114, 103, 117, 115, 115, 111, 110, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 32, 58, 32, 49, 49, 32, 78, 111, 118, 101, 109, 98, 101, 114, 32,
  50, 48, 49, 50, 32, 45, 32, 109, 105, 110, 111, 114, 32, 113, 117, 97,
  108, 105, 116, 121, 32, 105, 109, 112, 114, 111, 118, 101, 109, 101, 110, 116,
  115, 46, 34, 41, 10, 109, 101, 100, 51, 115, 116, 97, 99, 107, 49, 54,
  58, 10, 45, 45, 109, 97, 120, 91, 48, 44, 49, 93, 10, 45, 45, 109,
  105, 110, 91, 48, 44, 49, 93, 10, 45, 107, 101, 101, 112, 91, 50, 44,
  51, 44, 52, 93, 10, 45, 45, 109, 97, 120, 91, 48, 44, 50, 93, 10,
  45, 45, 109, 105, 110, 91, 49, 44, 51, 93, 10, 45, 107, 101, 101, 112,
  91, 45, 49, 93, 10, 109, 101, 100, 53, 115, 116, 97, 99, 107, 49, 54,
  58, 10, 45, 45, 109, 105, 110, 91, 48, 44, 49, 93, 10, 45, 45, 109,
  97, 120, 91, 48, 44, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91,
  48, 44, 49, 93, 10, 45, 45, 109, 105, 110, 91, 48, 44, 52, 93, 10,
  45, 45, 109, 97, 120, 91, 48, 44, 52, 93, 10, 45, 114, 101, 109, 111,
  118, 101, 91, 48, 44, 52, 93, 10, 45, 45, 109, 105, 110, 91, 48, 44,
  52, 93, 10, 45, 45, 109, 97, 120, 91, 48, 44, 52, 93, 10, 45, 114,
  101, 109, 111, 118, 101, 91, 48, 44, 52, 93, 10, 45, 45, 109, 105, 110,
  91, 48, 44, 52, 93, 10, 45, 45, 109, 97, 120, 91, 48, 44, 52, 93,
  10, 45, 114, 101, 109, 111, 118, 101, 91, 48, 44, 52, 93, 10, 45, 45,
  109, 105, 110, 91, 48, 44, 49, 93, 10, 45, 45, 109, 97, 120, 91, 48,
  44, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 48, 44, 49, 93,
  10, 45, 45, 109, 105, 110, 91, 48, 44, 52, 93, 10, 45, 45, 109, 97,
  120, 91, 48, 44, 52, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 48,
  44, 52, 93, 10, 45, 45, 109, 105, 110, 91, 48, 44, 52, 93, 10, 45,
  45, 109, 97, 120, 91, 48, 44, 52, 93, 10, 45, 114, 101, 109, 111, 118,
  101, 91, 48, 44, 52, 93, 10, 45, 45, 109, 105, 110, 91, 49, 44, 50,
  93, 10, 45, 45, 109, 97, 120, 91, 49, 44, 50, 93, 10, 45, 114, 101,
  109, 111, 118, 101, 91, 49, 44, 50, 93, 10, 45, 45, 109, 97, 120, 91,
  49, 44, 52, 93, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 99,
  114, 111, 115, 115, 49, 54, 58, 10, 45, 45, 115, 104, 105, 102, 116, 91,
  48, 93, 32, 48, 44, 49, 44, 48, 44, 48, 44, 50, 10, 45, 45, 115,
  104, 105, 102, 116, 91, 48, 93, 32, 48, 44, 45, 49, 44, 48, 44, 48,
  44, 50, 10, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93, 32, 49, 44,
  48, 44, 48, 44, 48, 44, 50, 10, 45, 45, 115, 104, 105, 102, 116, 91,
  48, 93, 32, 45, 49, 44, 48, 44, 48, 44, 48, 44, 50, 10, 45, 109,
  101, 100, 53, 115, 116, 97, 99, 107, 49, 54, 10, 101, 120, 49, 54, 58,
  10, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93, 32, 49, 44, 49, 44,
  48, 44, 48, 44, 50, 10, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93,
  32, 49, 44, 45, 49, 44, 48, 44, 48, 44, 50, 10, 45, 45, 115, 104,
  105, 102, 116, 91, 48, 93, 32, 45, 49, 44, 45, 49, 44, 48, 44, 48,
  44, 50, 10, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93, 32, 45, 49,
  44, 49, 44, 48, 44, 48, 44, 50, 10, 45, 109, 101, 100, 53, 115, 116,
  97, 99, 107, 49, 54, 10, 104, 121, 98, 114, 105, 100, 49, 54, 58, 10,
  45, 45, 99, 114, 111, 115, 115, 49, 54, 91, 48, 93, 10, 45, 45, 101,
  120, 49, 54, 91, 48, 93, 10, 45, 109, 101, 100, 51, 115, 116, 97, 99,
  107, 49, 54, 10, 97, 117, 116, 111, 110, 114, 50, 58, 10, 45, 45, 99,
  114, 111, 112, 32, 51, 48, 37, 44, 51, 48, 37, 44, 55, 48, 37, 44,
  55, 48, 37, 10, 110, 111, 105, 115, 101, 48, 61, 64, 123, 45, 118, 97,
  114, 105, 97, 110, 99, 101, 95, 110, 111, 105, 115, 101, 125, 10, 45, 114,
  101, 109, 111, 118, 101, 91, 45, 49, 93, 10, 99, 114, 111, 112, 119, 105,
  100, 116, 104, 61, 123, 119, 125, 10, 99, 114, 111, 112, 104, 101, 105, 103,
  104, 116, 61, 123, 104, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 48,
  93, 32, 123, 119, 43, 40, 54, 52, 45, 119, 37, 54, 52, 41, 125, 44,
  123, 104, 43, 40, 54, 52, 45, 104, 37, 54, 52, 41, 125, 44, 49, 44,
  123, 115, 125, 44, 48, 44, 49, 10, 119, 105, 100, 116, 104, 61, 123, 119,
  125, 10, 104, 101, 105, 103, 104, 116, 61, 123, 104, 125, 10, 45, 105, 102,
  32, 123, 36, 110, 111, 105, 115, 101, 48, 62, 36, 50, 125, 10, 45, 100,
  101, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 49, 48, 44, 123, 36,
  110, 111, 105, 115, 101, 48, 42, 36, 49, 125, 44, 51, 44, 53, 44, 48,
  44, 49, 10, 45, 100, 101, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32,
  49, 48, 44, 123, 36, 110, 111, 105, 115, 101, 48, 42, 36, 49, 125, 44,
  51, 44, 53, 44, 48, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 123, 36, 119, 105, 100,
  116, 104, 47, 50, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 50,
  125, 44, 49, 44, 123, 115, 125, 44, 50, 44, 49, 10, 45, 45, 114, 101,
  115, 105, 122, 101, 91, 45, 49, 93, 32, 36, 119, 105, 100, 116, 104, 44,
  36, 104, 101, 105, 103, 104, 116, 44, 49, 44, 123, 115, 125, 44, 51, 44,
  49, 10, 45, 115, 117, 98, 91, 48, 93, 32, 91, 45, 49, 93, 10, 45,
  114, 101, 109, 111, 118, 101, 91, 45, 49, 93, 10, 110, 111, 105, 115, 101,
  49, 61, 64, 123, 45, 118, 97, 114, 105, 97, 110, 99, 101, 95, 110, 111,
  105, 115, 101, 125, 10, 45, 105, 102, 32, 123, 36, 110, 111, 105, 115, 101,
  49, 62, 36, 50, 125, 10, 45, 100, 101, 110, 111, 105, 115, 101, 91, 45,
  49, 93, 32, 49, 48, 44, 123, 36, 110, 111, 105, 115, 101, 49, 42, 36,
  49, 125, 44, 51, 44, 53, 44, 48, 44, 48, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123,
  36, 119, 105, 100, 116, 104, 47, 52, 125, 44, 123, 36, 104, 101, 105, 103,
  104, 116, 47, 52, 125, 44, 49, 44, 123, 115, 125, 44, 50, 44, 49, 10,
  45, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 119,
  105, 100, 116, 104, 47, 50, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116,
  47, 50, 125, 44, 49, 44, 123, 115, 125, 44, 51, 44, 49, 10, 45, 115,
  117, 98, 91, 49, 93, 32, 91, 45, 49, 93, 10, 45, 114, 101, 109, 111,
  118, 101, 91, 45, 49, 93, 10, 110, 111, 105, 115, 101, 50, 61, 64, 123,
  45, 118, 97, 114, 105, 97, 110, 99, 101, 95, 110, 111, 105, 115, 101, 125,
  10, 45, 105, 102, 32, 123, 36, 110, 111, 105, 115, 101, 50, 62, 36, 50,
  125, 10, 45, 100, 101, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 49,
  48, 44, 123, 36, 110, 111, 105, 115, 101, 50, 42, 36, 49, 125, 44, 51,
  44, 53, 44, 48, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 45,
  114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 119, 105, 100,
  116, 104, 47, 56, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 56,
  125, 44, 49, 44, 123, 115, 125, 44, 50, 44, 49, 10, 45, 45, 114, 101,
  115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104,
  47, 52, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 52, 125, 44,
  49, 44, 123, 115, 125, 44, 51, 44, 49, 10, 45, 115, 117, 98, 91, 50,
  93, 32, 91, 45, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45,
  49, 93, 10, 110, 111, 105, 115, 101, 51, 61, 64, 123, 45, 118, 97, 114,
  105, 97, 110, 99, 101, 95, 110, 111, 105, 115, 101, 125, 10, 45, 105, 102,
  32, 123, 36, 110, 111, 105, 115, 101, 51, 62, 36, 50, 125, 10, 45, 100,
  101, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 49, 48, 44, 123, 36,
  110, 111, 105, 115, 101, 51, 42, 36, 49, 125, 44, 51, 44, 53, 44, 48,
  44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 115, 105, 122,
  101, 91, 45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 52, 125,
  44, 123, 36, 104, 101, 105, 103, 104, 116, 47, 52, 125, 44, 49, 44, 123,
  115, 125, 44, 51, 44, 49, 10, 45, 97, 100, 100, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 93,
  10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 119,
  105, 100, 116, 104, 47, 50, 125, 44, 123, 36, 104, 101, 105, 103, 104, 116,
  47, 50, 125, 44, 49, 44, 123, 115, 125, 44, 51, 44, 49, 10, 45, 97,
  100, 100, 91, 45, 50, 93, 32, 91, 45, 49, 93, 10, 45, 114, 101, 109,
  111, 118, 101, 91, 45, 49, 93, 10, 45, 114, 101, 115, 105, 122, 101, 91,
  45, 49, 93, 32, 123, 36, 119, 105, 100, 116, 104, 47, 49, 125, 44, 123,
  36, 104, 101, 105, 103, 104, 116, 47, 49, 125, 44, 49, 44, 123, 115, 125,
  44, 51, 44, 49, 10, 45, 97, 100, 100, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 93, 10, 45,
  99, 114, 111, 112, 32, 48, 44, 48, 44, 123, 36, 99, 114, 111, 112, 119,
  105, 100, 116, 104, 45, 49, 125, 44, 123, 36, 99, 114, 111, 112, 104, 101,
  105, 103, 104, 116, 45, 49, 125, 10, 102, 102, 116, 95, 116, 105, 108, 101,
  51, 95, 102, 102, 116, 58, 10, 45, 45, 102, 102, 116, 112, 111, 108, 97,
  114, 91, 48, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 49, 44, 49, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49,
  93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 53, 48, 37, 44, 53, 48,
  37, 44, 48, 44, 49, 44, 36, 52, 10, 45, 101, 108, 108, 105, 112, 115,
  101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 49, 53,
  37, 44, 49, 53, 37, 44, 48, 44, 49, 44, 36, 53, 10, 45, 101, 108,
  108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48,
  37, 44, 53, 37, 44, 53, 37, 44, 48, 44, 49, 44, 36, 54, 10, 45,
  45, 97, 100, 100, 91, 49, 93, 32, 91, 45, 49, 93, 10, 45, 116, 104,
  114, 101, 115, 104, 111, 108, 100, 91, 45, 49, 93, 32, 36, 49, 10, 45,
  115, 101, 116, 91, 45, 49, 93, 32, 49, 44, 53, 48, 37, 44, 53, 48,
  37, 10, 45, 109, 117, 108, 91, 49, 93, 32, 91, 45, 49, 93, 10, 45,
  45, 105, 102, 102, 116, 112, 111, 108, 97, 114, 91, 49, 44, 50, 93, 10,
  45, 114, 101, 109, 111, 118, 101, 91, 48, 44, 49, 44, 50, 93, 10, 45,
  107, 101, 101, 112, 91, 45, 49, 93, 10, 102, 102, 116, 95, 116, 105, 108,
  101, 51, 95, 99, 108, 101, 97, 110, 58, 10, 116, 99, 61, 123, 114, 111,
  117, 110, 100, 40, 119, 47, 36, 50, 41, 125, 32, 116, 114, 61, 123, 114,
  111, 117, 110, 100, 40, 104, 47, 36, 50, 41, 125, 10, 45, 115, 112, 108,
  105, 116, 95, 116, 105, 108, 101, 115, 32, 36, 116, 99, 44, 36, 116, 114,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 111, 99,
  97, 108, 91, 64, 123, 62, 44, 45, 49, 125, 93, 10, 45, 102, 102, 116,
  95, 116, 105, 108, 101, 51, 95, 102, 102, 116, 91, 48, 45, 45, 49, 93,
  32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44,
  36, 54, 10, 45, 101, 110, 100, 108, 111, 99, 97, 108, 32, 45, 100, 111,
  110, 101, 10, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115,
  32, 36, 116, 99, 44, 36, 116, 114, 10, 45, 99, 32, 48, 44, 50, 53,
  53, 10, 102, 102, 116, 95, 116, 105, 108, 101, 51, 58, 10, 45, 45, 114,
  101, 115, 105, 122, 101, 91, 48, 93, 32, 123, 119, 43, 36, 50, 125, 44,
  123, 104, 43, 36, 50, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 49,
  44, 49, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123,
  119, 43, 36, 50, 125, 44, 123, 104, 43, 36, 50, 125, 44, 49, 44, 49,
  44, 48, 44, 49, 44, 48, 44, 48, 10, 45, 102, 102, 116, 95, 116, 105,
  108, 101, 51, 95, 99, 108, 101, 97, 110, 91, 45, 49, 93, 32, 36, 49,
  44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 10,
  45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 36, 50, 44, 36, 50, 44,
  123, 119, 45, 36, 50, 45, 49, 125, 44, 123, 104, 45, 36, 50, 45, 49,
  125, 10, 112, 117, 115, 104, 61, 123, 114, 111, 117, 110, 100, 40, 36, 50,
  42, 49, 46, 53, 41, 125, 10, 112, 117, 108, 108, 61, 123, 36, 50, 45,
  36, 112, 117, 115, 104, 125, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91,
  48, 93, 32, 123, 119, 43, 36, 112, 117, 115, 104, 125, 44, 123, 104, 43,
  36, 50, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49, 10,
  45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 119, 43, 36,
  112, 117, 108, 108, 125, 44, 123, 104, 43, 36, 50, 125, 44, 49, 44, 49,
  44, 48, 44, 49, 44, 48, 44, 48, 10, 45, 102, 102, 116, 95, 116, 105,
  108, 101, 51, 95, 99, 108, 101, 97, 110, 91, 45, 49, 93, 32, 36, 49,
  44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 10,
  45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 123, 36, 112, 117, 115, 104,
  125, 44, 123, 36, 50, 125, 44, 123, 119, 45, 36, 112, 117, 108, 108, 45,
  49, 125, 44, 123, 104, 45, 40, 36, 50, 41, 45, 49, 125, 10, 45, 45,
  114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 123, 119, 43, 36, 50, 125,
  44, 123, 104, 43, 36, 112, 117, 115, 104, 125, 44, 49, 44, 49, 44, 48,
  44, 49, 44, 49, 44, 49, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45,
  49, 93, 32, 123, 119, 43, 36, 50, 125, 44, 123, 104, 43, 36, 112, 117,
  108, 108, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 48, 44, 48, 10,
  45, 102, 102, 116, 95, 116, 105, 108, 101, 51, 95, 99, 108, 101, 97, 110,
  91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52,
  44, 36, 53, 44, 36, 54, 10, 45, 99, 114, 111, 112, 91, 45, 49, 93,
  32, 36, 50, 44, 123, 36, 112, 117, 115, 104, 125, 44, 123, 119, 45, 36,
  50, 45, 49, 125, 44, 123, 104, 45, 36, 112, 117, 108, 108, 45, 49, 125,
  10, 100, 105, 97, 49, 61, 123, 114, 111, 117, 110, 100, 40, 36, 50, 47,
  51, 41, 125, 10, 100, 105, 97, 50, 61, 123, 36, 50, 45, 36, 100, 105,
  97, 49, 125, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32,
  123, 119, 43, 36, 100, 105, 97, 49, 125, 44, 123, 104, 43, 36, 100, 105,
  97, 49, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49, 10,
  45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 119, 43, 36,
  100, 105, 97, 50, 125, 44, 123, 104, 43, 36, 100, 105, 97, 50, 125, 44,
  49, 44, 49, 44, 48, 44, 49, 44, 48, 44, 48, 10, 45, 102, 102, 116,
  95, 116, 105, 108, 101, 51, 95, 99, 108, 101, 97, 110, 91, 45, 49, 93,
  32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44,
  36, 54, 10, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 123, 36, 100,
  105, 97, 49, 125, 44, 123, 36, 100, 105, 97, 49, 125, 44, 123, 119, 45,
  36, 100, 105, 97, 50, 45, 49, 125, 44, 123, 104, 45, 36, 100, 105, 97,
  50, 45, 49, 125, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93,
  32, 123, 119, 43, 36, 100, 105, 97, 50, 125, 44, 123, 104, 43, 36, 100,
  105, 97, 50, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49,
  10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 119, 43,
  36, 100, 105, 97, 49, 125, 44, 123, 104, 43, 36, 100, 105, 97, 49, 125,
  44, 49, 44, 49, 44, 48, 44, 49, 44, 48, 44, 48, 10, 45, 102, 102,
  116, 95, 116, 105, 108, 101, 51, 95, 99, 108, 101, 97, 110, 91, 45, 49,
  93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53,
  44, 36, 54, 10, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 123, 36,
  100, 105, 97, 50, 125, 44, 123, 36, 100, 105, 97, 50, 125, 44, 123, 119,
  45, 36, 100, 105, 97, 49, 45, 49, 125, 44, 123, 104, 45, 36, 100, 105,
  97, 49, 45, 49, 125, 10, 45, 114, 101, 109, 111, 118, 101, 91, 48, 93,
  10, 45, 109, 101, 100, 53, 115, 116, 97, 99, 107, 49, 54, 10, 110, 114,
  51, 58, 10, 45, 109, 117, 108, 32, 50, 53, 54, 10, 114, 97, 100, 105,
  117, 115, 61, 123, 48, 46, 48, 53, 42, 40, 109, 105, 110, 40, 104, 44,
  119, 41, 41, 125, 10, 91, 48, 93, 10, 45, 114, 101, 99, 116, 97, 110,
  103, 108, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 49, 48, 48, 37,
  44, 36, 114, 97, 100, 105, 117, 115, 44, 49, 44, 123, 105, 97, 125, 10,
  45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48,
  44, 48, 44, 36, 114, 97, 100, 105, 117, 115, 44, 49, 48, 48, 37, 44,
  49, 44, 123, 105, 97, 125, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108,
  101, 91, 45, 49, 93, 32, 48, 44, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 44, 123, 104, 45, 36, 114, 97, 100, 105, 117, 115, 125, 44, 49, 44,
  123, 105, 97, 125, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91,
  45, 49, 93, 32, 123, 119, 45, 36, 114, 97, 100, 105, 117, 115, 125, 44,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48, 44, 49, 44, 123, 105,
  97, 125, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 123, 36, 114,
  97, 100, 105, 117, 115, 47, 50, 125, 10, 120, 109, 105, 110, 61, 64, 123,
  45, 49, 44, 120, 109, 125, 10, 121, 109, 105, 110, 61, 64, 123, 45, 49,
  44, 121, 109, 125, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 93,
  10, 45, 45, 99, 114, 111, 112, 91, 48, 93, 32, 123, 36, 120, 109, 105,
  110, 45, 36, 114, 97, 100, 105, 117, 115, 125, 44, 123, 36, 121, 109, 105,
  110, 45, 36, 114, 97, 100, 105, 117, 115, 125, 44, 123, 36, 120, 109, 105,
  110, 43, 36, 114, 97, 100, 105, 117, 115, 125, 44, 123, 36, 121, 109, 105,
  110, 43, 36, 114, 97, 100, 105, 117, 115, 125, 10, 109, 105, 110, 110, 111,
  105, 115, 101, 61, 123, 40, 64, 123, 45, 118, 97, 114, 105, 97, 110, 99,
  101, 95, 110, 111, 105, 115, 101, 125, 41, 125, 10, 45, 114, 101, 109, 111,
  118, 101, 91, 45, 49, 93, 10, 45, 45, 115, 117, 98, 91, 48, 93, 32,
  123, 50, 53, 48, 42, 50, 53, 54, 125, 10, 45, 97, 98, 115, 91, 45,
  49, 93, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49,
  93, 32, 48, 44, 48, 44, 49, 48, 48, 37, 44, 36, 114, 97, 100, 105,
  117, 115, 44, 49, 44, 123, 105, 97, 125, 10, 45, 114, 101, 99, 116, 97,
  110, 103, 108, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 36, 114, 97,
  100, 105, 117, 115, 44, 49, 48, 48, 37, 44, 49, 44, 123, 105, 97, 125,
  10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32,
  48, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 123, 104, 45, 36,
  114, 97, 100, 105, 117, 115, 125, 44, 49, 44, 123, 105, 97, 125, 10, 45,
  114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 123, 119,
  45, 36, 114, 97, 100, 105, 117, 115, 125, 44, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 48, 44, 49, 44, 123, 105, 97, 125, 10, 45, 98, 108,
  117, 114, 91, 45, 49, 93, 32, 123, 36, 114, 97, 100, 105, 117, 115, 47,
  50, 125, 10, 120, 109, 97, 120, 61, 64, 123, 45, 49, 44, 120, 109, 125,
  10, 121, 109, 97, 120, 61, 64, 123, 45, 49, 44, 121, 109, 125, 10, 45,
  45, 99, 114, 111, 112, 91, 48, 93, 32, 123, 36, 120, 109, 97, 120, 45,
  36, 114, 97, 100, 105, 117, 115, 125, 44, 123, 36, 121, 109, 97, 120, 45,
  36, 114, 97, 100, 105, 117, 115, 125, 44, 123, 36, 120, 109, 97, 120, 43,
  36, 114, 97, 100, 105, 117, 115, 125, 44, 123, 36, 121, 109, 97, 120, 43,
  36, 114, 97, 100, 105, 117, 115, 125, 10, 109, 97, 120, 110, 111, 105, 115,
  101, 61, 123, 40, 64, 123, 45, 118, 97, 114, 105, 97, 110, 99, 101, 95,
  110, 111, 105, 115, 101, 125, 41, 125, 10, 45, 114, 101, 109, 111, 118, 101,
  91, 45, 49, 93, 10, 45, 45, 115, 117, 98, 91, 48, 93, 32, 123, 49,
  50, 56, 42, 50, 53, 54, 125, 10, 45, 97, 98, 115, 91, 45, 49, 93,
  10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32,
  48, 44, 48, 44, 49, 48, 48, 37, 44, 36, 114, 97, 100, 105, 117, 115,
  44, 49, 44, 123, 105, 97, 125, 10, 45, 114, 101, 99, 116, 97, 110, 103,
  108, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 36, 114, 97, 100, 105,
  117, 115, 44, 49, 48, 48, 37, 44, 49, 44, 123, 105, 97, 125, 10, 45,
  114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48, 44,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 123, 104, 45, 36, 114, 97,
  100, 105, 117, 115, 125, 44, 49, 44, 123, 105, 97, 125, 10, 45, 114, 101,
  99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 123, 119, 45, 36,
  114, 97, 100, 105, 117, 115, 125, 44, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 44, 48, 44, 49, 44, 123, 105, 97, 125, 10, 45, 98, 108, 117, 114,
  91, 45, 49, 93, 32, 123, 36, 114, 97, 100, 105, 117, 115, 47, 50, 125,
  10, 120, 97, 118, 101, 61, 64, 123, 45, 49, 44, 120, 109, 125, 10, 121,
  97, 118, 101, 61, 64, 123, 45, 49, 44, 121, 109, 125, 10, 45, 114, 101,
  109, 111, 118, 101, 91, 45, 49, 93, 10, 45, 45, 99, 114, 111, 112, 91,
  48, 93, 32, 123, 36, 120, 97, 118, 101, 45, 36, 114, 97, 100, 105, 117,
  115, 125, 44, 123, 36, 121, 97, 118, 101, 45, 36, 114, 97, 100, 105, 117,
  115, 125, 44, 123, 36, 120, 97, 118, 101, 43, 36, 114, 97, 100, 105, 117,
  115, 125, 44, 123, 36, 121, 97, 118, 101, 43, 36, 114, 97, 100, 105, 117,
  115, 125, 10, 109, 105, 100, 110, 111, 105, 115, 101, 61, 123, 40, 64, 123,
  45, 118, 97, 114, 105, 97, 110, 99, 101, 95, 110, 111, 105, 115, 101, 125,
  41, 125, 10, 45, 116, 101, 120, 116, 91, 45, 49, 93, 32, 36, 109, 105,
  100, 110, 111, 105, 115, 101, 44, 48, 44, 48, 44, 50, 53, 44, 49, 44,
  123, 105, 77, 125, 10, 45, 45, 115, 117, 98, 91, 48, 93, 32, 123, 54,
  52, 42, 50, 53, 54, 125, 10, 45, 97, 98, 115, 91, 45, 49, 93, 10,
  45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48,
  44, 48, 44, 49, 48, 48, 37, 44, 36, 114, 97, 100, 105, 117, 115, 44,
  49, 44, 123, 105, 97, 125, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108,
  101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 36, 114, 97, 100, 105, 117,
  115, 44, 49, 48, 48, 37, 44, 49, 44, 123, 105, 97, 125, 10, 45, 114,
  101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48, 44, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 123, 104, 45, 36, 114, 97, 100,
  105, 117, 115, 125, 44, 49, 44, 123, 105, 97, 125, 10, 45, 114, 101, 99,
  116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 123, 119, 45, 36, 114,
  97, 100, 105, 117, 115, 125, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 48, 44, 49, 44, 123, 105, 97, 125, 10, 45, 98, 108, 117, 114, 91,
  45, 49, 93, 32, 123, 36, 114, 97, 100, 105, 117, 115, 47, 50, 125, 10,
  120, 115, 104, 97, 100, 111, 119, 61, 64, 123, 45, 49, 44, 120, 109, 125,
  10, 121, 115, 104, 97, 100, 111, 119, 61, 64, 123, 45, 49, 44, 121, 109,
  125, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 93, 10, 45, 45,
  99, 114, 111, 112, 91, 48, 93, 32, 123, 36, 120, 115, 104, 97, 100, 111,
  119, 45, 36, 114, 97, 100, 105, 117, 115, 125, 44, 123, 36, 121, 115, 104,
  97, 100, 111, 119, 45, 36, 114, 97, 100, 105, 117, 115, 125, 44, 123, 36,
  120, 115, 104, 97, 100, 111, 119, 43, 36, 114, 97, 100, 105, 117, 115, 125,
  44, 123, 36, 121, 115, 104, 97, 100, 111, 119, 43, 36, 114, 97, 100, 105,
  117, 115, 125, 10, 115, 104, 97, 100, 111, 119, 110, 111, 105, 115, 101, 61,
  123, 40, 64, 123, 45, 118, 97, 114, 105, 97, 110, 99, 101, 95, 110, 111,
  105, 115, 101, 125, 41, 125, 10, 45, 45, 115, 117, 98, 91, 48, 93, 32,
  123, 49, 57, 50, 42, 50, 53, 54, 125, 10, 45, 97, 98, 115, 91, 45,
  49, 93, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49,
  93, 32, 48, 44, 48, 44, 49, 48, 48, 37, 44, 36, 114, 97, 100, 105,
  117, 115, 44, 49, 44, 123, 105, 97, 125, 10, 45, 114, 101, 99, 116, 97,
  110, 103, 108, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 36, 114, 97,
  100, 105, 117, 115, 44, 49, 48, 48, 37, 44, 49, 44, 123, 105, 97, 125,
  10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32,
  48, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 123, 104, 45, 36,
  114, 97, 100, 105, 117, 115, 125, 44, 49, 44, 123, 105, 97, 125, 10, 45,
  114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 123, 119,
  45, 36, 114, 97, 100, 105, 117, 115, 125, 44, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 48, 44, 49, 44, 123, 105, 97, 125, 10, 45, 98, 108,
  117, 114, 91, 45, 49, 93, 32, 123, 36, 114, 97, 100, 105, 117, 115, 47,
  50, 125, 10, 120, 98, 114, 105, 103, 104, 116, 61, 64, 123, 45, 49, 44,
  120, 109, 125, 10, 121, 98, 114, 105, 103, 104, 116, 61, 64, 123, 45, 49,
  44, 121, 109, 125, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 93,
  10, 45, 45, 99, 114, 111, 112, 91, 48, 93, 32, 123, 36, 120, 98, 114,
  105, 103, 104, 116, 45, 36, 114, 97, 100, 105, 117, 115, 125, 44, 123, 36,
  121, 98, 114, 105, 103, 104, 116, 45, 36, 114, 97, 100, 105, 117, 115, 125,
  44, 123, 36, 120, 98, 114, 105, 103, 104, 116, 43, 36, 114, 97, 100, 105,
  117, 115, 125, 44, 123, 36, 121, 98, 114, 105, 103, 104, 116, 43, 36, 114,
  97, 100, 105, 117, 115, 125, 10, 98, 114, 105, 103, 104, 116, 110, 111, 105,
  115, 101, 61, 123, 40, 64, 123, 45, 118, 97, 114, 105, 97, 110, 99, 101,
  95, 110, 111, 105, 115, 101, 125, 41, 125, 10, 115, 104, 97, 100, 111, 119,
  115, 61, 123, 40, 40, 36, 109, 105, 110, 110, 111, 105, 115, 101, 47, 36,
  115, 104, 97, 100, 111, 119, 110, 111, 105, 115, 101, 41, 42, 54, 52, 41,
  125, 10, 109, 105, 100, 115, 61, 123, 40, 40, 36, 109, 105, 110, 110, 111,
  105, 115, 101, 47, 36, 109, 105, 100, 110, 111, 105, 115, 101, 41, 42, 54,
  52, 41, 125, 10, 98, 114, 105, 103, 104, 116, 115, 61, 123, 40, 40, 36,
  109, 105, 110, 110, 111, 105, 115, 101, 47, 36, 98, 114, 105, 103, 104, 116,
  110, 111, 105, 115, 101, 41, 42, 54, 52, 41, 125, 10, 119, 104, 105, 116,
  101, 115, 61, 123, 40, 40, 36, 109, 105, 110, 110, 111, 105, 115, 101, 47,
  36, 109, 97, 120, 110, 111, 105, 115, 101, 41, 42, 54, 52, 41, 125, 10,
  112, 111, 105, 110, 116, 49, 61, 123, 36, 115, 104, 97, 100, 111, 119, 115,
  43, 51, 50, 125, 10, 112, 111, 105, 110, 116, 50, 61, 123, 36, 109, 105,
  100, 115, 43, 36, 115, 104, 97, 100, 111, 119, 115, 43, 51, 50, 125, 10,
  112, 111, 105, 110, 116, 51, 61, 123, 36, 98, 114, 105, 103, 104, 116, 115,
  43, 36, 109, 105, 100, 115, 43, 36, 115, 104, 97, 100, 111, 119, 115, 43,
  51, 50, 125, 10, 112, 111, 105, 110, 116, 52, 61, 123, 36, 119, 104, 105,
  116, 101, 115, 43, 36, 98, 114, 105, 103, 104, 116, 115, 43, 36, 109, 105,
  100, 115, 43, 36, 115, 104, 97, 100, 111, 119, 115, 43, 51, 50, 125, 10,
  45, 107, 101, 101, 112, 91, 48, 93, 10, 99, 114, 111, 112, 119, 105, 100,
  116, 104, 61, 123, 119, 125, 10, 99, 114, 111, 112, 104, 101, 105, 103, 104,
  116, 61, 123, 104, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93,
  32, 123, 119, 43, 40, 54, 52, 45, 119, 37, 54, 52, 41, 125, 44, 123,
  104, 43, 40, 54, 52, 45, 104, 37, 54, 52, 41, 125, 44, 49, 44, 123,
  115, 125, 44, 48, 44, 49, 10, 119, 105, 100, 116, 104, 61, 123, 119, 125,
  10, 104, 101, 105, 103, 104, 116, 61, 123, 104, 125, 10, 45, 97, 112, 112,
  108, 121, 95, 99, 117, 114, 118, 101, 91, 48, 93, 32, 48, 44, 48, 44,
  48, 44, 123, 51, 50, 42, 50, 53, 54, 125, 44, 123, 51, 50, 42, 50,
  53, 54, 125, 44, 123, 57, 54, 42, 50, 53, 54, 125, 44, 123, 36, 112,
  111, 105, 110, 116, 49, 42, 50, 53, 54, 125, 44, 123, 49, 54, 48, 42,
  50, 53, 54, 125, 44, 123, 36, 112, 111, 105, 110, 116, 50, 42, 50, 53,
  54, 125, 44, 123, 50, 50, 51, 42, 50, 53, 54, 125, 44, 123, 36, 112,
  111, 105, 110, 116, 51, 42, 50, 53, 54, 125, 44, 123, 50, 56, 55, 42,
  50, 53, 54, 125, 44, 123, 36, 112, 111, 105, 110, 116, 52, 42, 50, 53,
  54, 125, 10, 45, 115, 117, 98, 32, 123, 49, 50, 56, 42, 50, 53, 54,
  125, 32, 45, 109, 117, 108, 32, 46, 53, 32, 45, 97, 100, 100, 32, 123,
  49, 50, 56, 42, 50, 53, 54, 125, 10, 45, 45, 104, 121, 98, 114, 105,
  100, 49, 54, 91, 48, 93, 10, 45, 97, 117, 116, 111, 110, 114, 50, 91,
  45, 49, 93, 32, 36, 49, 44, 36, 50, 10, 45, 97, 117, 116, 111, 110,
  114, 50, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 10, 45, 45, 115,
  117, 98, 91, 48, 93, 32, 91, 49, 93, 10, 45, 97, 100, 100, 91, 45,
  49, 93, 32, 123, 49, 50, 56, 42, 50, 53, 54, 125, 10, 45, 114, 101,
  109, 111, 118, 101, 91, 48, 93, 10, 45, 100, 105, 118, 91, 45, 49, 93,
  32, 50, 53, 54, 10, 45, 102, 102, 116, 95, 116, 105, 108, 101, 51, 91,
  45, 49, 93, 32, 123, 50, 48, 48, 48, 45, 36, 51, 125, 44, 52, 56,
  44, 48, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 49, 10, 45, 109,
  117, 108, 91, 45, 49, 93, 32, 50, 53, 54, 10, 45, 115, 117, 98, 91,
  45, 49, 93, 32, 123, 49, 50, 56, 42, 50, 53, 54, 125, 32, 45, 109,
  117, 108, 91, 45, 49, 93, 32, 36, 55, 32, 45, 97, 100, 100, 91, 45,
  49, 93, 32, 123, 49, 50, 56, 42, 50, 53, 54, 125, 10, 45, 117, 110,
  115, 104, 97, 114, 112, 91, 48, 93, 32, 36, 56, 44, 36, 57, 44, 36,
  49, 48, 10, 45, 117, 110, 115, 104, 97, 114, 112, 91, 49, 93, 32, 36,
  49, 49, 44, 36, 49, 50, 44, 36, 49, 51, 10, 45, 115, 117, 98, 91,
  49, 93, 32, 123, 49, 50, 56, 42, 50, 53, 54, 125, 10, 45, 97, 100,
  100, 91, 48, 93, 32, 91, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101,
  91, 49, 93, 10, 45, 115, 117, 98, 32, 123, 49, 50, 56, 42, 50, 53,
  54, 125, 32, 45, 109, 117, 108, 32, 50, 32, 45, 97, 100, 100, 32, 123,
  49, 50, 56, 42, 50, 53, 54, 125, 10, 45, 97, 112, 112, 108, 121, 95,
  99, 117, 114, 118, 101, 91, 48, 93, 32, 48, 44, 48, 44, 48, 44, 123,
  51, 50, 42, 50, 53, 54, 125, 44, 123, 51, 50, 42, 50, 53, 54, 125,
  44, 123, 36, 112, 111, 105, 110, 116, 49, 42, 50, 53, 54, 125, 44, 123,
  57, 54, 42, 50, 53, 54, 125, 44, 123, 36, 112, 111, 105, 110, 116, 50,
  42, 50, 53, 54, 125, 44, 123, 49, 54, 48, 42, 50, 53, 54, 125, 44,
  123, 36, 112, 111, 105, 110, 116, 51, 42, 50, 53, 54, 125, 44, 123, 50,
  50, 51, 42, 50, 53, 54, 125, 44, 123, 36, 112, 111, 105, 110, 116, 52,
  42, 50, 53, 54, 125, 44, 123, 50, 56, 55, 42, 50, 53, 54, 125, 10,
  45, 100, 105, 118, 32, 50, 53, 54, 10, 45, 99, 32, 48, 44, 50, 53,
  53, 10, 45, 99, 114, 111, 112, 32, 48, 44, 48, 44, 123, 36, 99, 114,
  111, 112, 119, 105, 100, 116, 104, 45, 49, 125, 44, 123, 36, 99, 114, 111,
  112, 104, 101, 105, 103, 104, 116, 45, 49, 125, 10, 35, 64, 103, 105, 109,
  112, 32, 78, 111, 105, 115, 101, 32, 114, 101, 100, 117, 99, 116, 105, 111,
  110, 32, 53, 32, 58, 32, 110, 114, 53, 44, 110, 114, 53, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 49, 32, 108, 117, 109, 97, 32, 100, 101, 110, 111, 105, 115, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 49, 46, 54, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 50, 32, 99,
  111, 108, 111, 117, 114, 32, 100, 101, 110, 111, 105, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 32, 40, 53, 44, 48, 44, 50, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 51, 32, 114, 101, 99, 111, 118, 101, 114, 32, 100, 101, 116,
  97, 105, 108, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 52, 32, 97, 109, 111, 117, 110, 116,
  32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 49, 44, 48, 46, 49, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 98, 62, 32, 115, 104, 97, 114, 112, 101,
  110, 32, 100, 101, 116, 97, 105, 108, 115, 60, 47, 98, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 53, 32, 114, 97, 100, 105, 117,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 46, 55, 53, 44, 46,
  50, 53, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 54,
  32, 97, 109, 111, 117, 110, 116, 32, 61, 32, 102, 108, 111, 97, 116, 32,
  40, 51, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 55, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32,
  102, 108, 111, 97, 116, 32, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 98, 62, 32, 115, 104, 97, 114, 112, 101, 110, 32, 101, 100,
  103, 101, 115, 60, 47, 98, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 56, 32, 114, 97, 100, 105, 117, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 32, 40, 46, 55, 53, 44, 46, 50, 53, 44, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 57, 32, 97, 109, 111, 117, 110,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 46, 53, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 49, 48, 32,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97,
  116, 32, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 98,
  62, 65, 100, 118, 97, 110, 99, 101, 100, 32, 111, 112, 116, 105, 111, 110,
  115, 60, 47, 98, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 49, 49, 32, 98, 97, 115, 101, 32, 108, 117, 109, 97, 32, 109, 101,
  116, 104, 111, 100, 32, 61, 32, 99, 104, 111, 105, 99, 101, 32, 40, 49,
  44, 34, 87, 97, 118, 101, 108, 101, 116, 34, 44, 34, 77, 117, 108, 116,
  105, 45, 115, 99, 97, 108, 101, 32, 112, 97, 116, 99, 104, 32, 115, 109,
  111, 111, 116, 104, 105, 110, 103, 34, 44, 34, 83, 101, 109, 105, 45, 97,
  117, 116, 111, 32, 77, 83, 32, 112, 97, 116, 99, 104, 34, 44, 34, 77,
  101, 100, 105, 97, 110, 32, 102, 105, 114, 115, 116, 32, 77, 83, 32, 112,
  97, 116, 99, 104, 34, 44, 34, 77, 117, 108, 116, 105, 32, 83, 99, 97,
  108, 101, 32, 77, 101, 100, 105, 97, 110, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 49, 50, 32, 99, 104, 114, 111, 109, 97, 32, 109,
  101, 116, 104, 111, 100, 32, 61, 32, 99, 104, 111, 105, 99, 101, 32, 40,
  49, 44, 34, 87, 97, 118, 101, 108, 101, 116, 34, 44, 34, 77, 117, 108,
  116, 105, 45, 115, 99, 97, 108, 101, 32, 112, 97, 116, 99, 104, 32, 115,
  109, 111, 111, 116, 104, 105, 110, 103, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  49, 51, 32, 97, 100, 106, 117, 115, 116, 32, 102, 105, 110, 101, 32, 100,
  101, 116, 97, 105, 108, 115, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40,
  49, 48, 48, 44, 45, 53, 48, 48, 48, 44, 53, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 49, 52, 32, 97, 100, 106, 117, 115,
  116, 32, 109, 101, 100, 105, 117, 109, 32, 100, 101, 116, 97, 105, 108, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 48, 44, 45, 53, 48, 48,
  48, 44, 53, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  49, 53, 32, 97, 100, 106, 117, 115, 116, 32, 108, 97, 114, 103, 101, 32,
  100, 101, 116, 97, 105, 108, 115, 32, 61, 32, 102, 108, 111, 97, 116, 32,
  40, 45, 49, 48, 48, 44, 45, 53, 48, 48, 48, 44, 53, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 69, 120, 112, 101, 114, 105, 109, 101, 110, 116,
  97, 108, 32, 99, 117, 114, 118, 101, 115, 32, 61, 32, 98, 111, 111, 108,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 97, 109,
  109, 97, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 49, 46, 51, 44,
  46, 51, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  104, 111, 119, 32, 110, 111, 105, 115, 101, 32, 61, 32, 98, 111, 111, 108,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60,
  105, 62, 73, 97, 105, 110, 32, 70, 101, 114, 103, 117, 115, 115, 111, 110,
  60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 50, 56, 32, 78, 111,
  118, 101, 109, 98, 101, 114, 32, 50, 48, 49, 50, 32, 45, 32, 97, 100,
  100, 101, 100, 32, 97, 98, 105, 108, 116, 105, 116, 121, 32, 116, 111, 32,
  118, 105, 101, 119, 32, 110, 111, 105, 115, 101, 34, 41, 10, 109, 101, 100,
  51, 115, 116, 97, 99, 107, 49, 54, 58, 10, 45, 45, 109, 97, 120, 91,
  48, 44, 49, 93, 10, 45, 45, 109, 105, 110, 91, 48, 44, 49, 93, 10,
  45, 107, 101, 101, 112, 91, 50, 44, 51, 44, 52, 93, 10, 45, 45, 109,
  97, 120, 91, 48, 44, 50, 93, 10, 45, 45, 109, 105, 110, 91, 49, 44,
  51, 93, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 109, 101, 100,
  53, 115, 116, 97, 99, 107, 49, 54, 58, 10, 45, 45, 109, 105, 110, 91,
  48, 44, 49, 93, 10, 45, 45, 109, 97, 120, 91, 48, 44, 49, 93, 10,
  45, 114, 101, 109, 111, 118, 101, 91, 48, 44, 49, 93, 10, 45, 45, 109,
  105, 110, 91, 48, 44, 52, 93, 10, 45, 45, 109, 97, 120, 91, 48, 44,
  52, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 48, 44, 52, 93, 10,
  45, 45, 109, 105, 110, 91, 48, 44, 52, 93, 10, 45, 45, 109, 97, 120,
  91, 48, 44, 52, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 48, 44,
  52, 93, 10, 45, 45, 109, 105, 110, 91, 48, 44, 52, 93, 10, 45, 45,
  109, 97, 120, 91, 48, 44, 52, 93, 10, 45, 114, 101, 109, 111, 118, 101,
  91, 48, 44, 52, 93, 10, 45, 45, 109, 105, 110, 91, 48, 44, 49, 93,
  10, 45, 45, 109, 97, 120, 91, 48, 44, 49, 93, 10, 45, 114, 101, 109,
  111, 118, 101, 91, 48, 44, 49, 93, 10, 45, 45, 109, 105, 110, 91, 48,
  44, 52, 93, 10, 45, 45, 109, 97, 120, 91, 48, 44, 52, 93, 10, 45,
  114, 101, 109, 111, 118, 101, 91, 48, 44, 52, 93, 10, 45, 45, 109, 105,
  110, 91, 48, 44, 52, 93, 10, 45, 45, 109, 97, 120, 91, 48, 44, 52,
  93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 48, 44, 52, 93, 10, 45,
  45, 109, 105, 110, 91, 49, 44, 50, 93, 10, 45, 45, 109, 97, 120, 91,
  49, 44, 50, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 49, 44, 50,
  93, 10, 45, 45, 109, 97, 120, 91, 49, 44, 52, 93, 10, 45, 107, 101,
  101, 112, 91, 45, 49, 93, 10, 102, 102, 116, 95, 116, 105, 108, 101, 51,
  95, 102, 102, 116, 58, 10, 45, 45, 102, 102, 116, 112, 111, 108, 97, 114,
  91, 48, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44,
  49, 44, 49, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93,
  32, 53, 48, 37, 44, 53, 48, 37, 44, 53, 48, 37, 44, 53, 48, 37,
  44, 48, 44, 49, 44, 36, 52, 10, 45, 101, 108, 108, 105, 112, 115, 101,
  91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 49, 53, 37,
  44, 49, 53, 37, 44, 48, 44, 49, 44, 36, 53, 10, 45, 101, 108, 108,
  105, 112, 115, 101, 91, 45, 49, 93, 32, 53, 48, 37, 44, 53, 48, 37,
  44, 53, 37, 44, 53, 37, 44, 48, 44, 49, 44, 36, 54, 10, 45, 45,
  97, 100, 100, 91, 49, 93, 32, 91, 45, 49, 93, 10, 45, 116, 104, 114,
  101, 115, 104, 111, 108, 100, 91, 45, 49, 93, 32, 36, 49, 10, 45, 115,
  101, 116, 91, 45, 49, 93, 32, 49, 44, 53, 48, 37, 44, 53, 48, 37,
  10, 45, 109, 117, 108, 91, 49, 93, 32, 91, 45, 49, 93, 10, 45, 45,
  105, 102, 102, 116, 112, 111, 108, 97, 114, 91, 49, 44, 50, 93, 10, 45,
  114, 101, 109, 111, 118, 101, 91, 48, 44, 49, 44, 50, 93, 10, 45, 107,
  101, 101, 112, 91, 45, 49, 93, 10, 102, 102, 116, 95, 116, 105, 108, 101,
  51, 95, 99, 108, 101, 97, 110, 58, 10, 116, 99, 61, 123, 114, 111, 117,
  110, 100, 40, 119, 47, 36, 50, 41, 125, 32, 116, 114, 61, 123, 114, 111,
  117, 110, 100, 40, 104, 47, 36, 50, 41, 125, 10, 45, 115, 112, 108, 105,
  116, 95, 116, 105, 108, 101, 115, 32, 36, 116, 99, 44, 36, 116, 114, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 111, 99, 97,
  108, 91, 64, 123, 62, 44, 45, 49, 125, 93, 10, 45, 102, 102, 116, 95,
  116, 105, 108, 101, 51, 95, 102, 102, 116, 91, 48, 45, 45, 49, 93, 32,
  36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36,
  54, 10, 45, 101, 110, 100, 108, 111, 99, 97, 108, 32, 45, 100, 111, 110,
  101, 10, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 32,
  36, 116, 99, 44, 36, 116, 114, 10, 45, 99, 32, 48, 44, 50, 53, 53,
  10, 102, 102, 116, 95, 116, 105, 108, 101, 51, 58, 10, 45, 45, 114, 101,
  115, 105, 122, 101, 91, 48, 93, 32, 123, 119, 43, 36, 50, 125, 44, 123,
  104, 43, 36, 50, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 49, 44,
  49, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 119,
  43, 36, 50, 125, 44, 123, 104, 43, 36, 50, 125, 44, 49, 44, 49, 44,
  48, 44, 49, 44, 48, 44, 48, 10, 45, 102, 102, 116, 95, 116, 105, 108,
  101, 51, 95, 99, 108, 101, 97, 110, 91, 45, 49, 93, 32, 36, 49, 44,
  36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 10, 45,
  99, 114, 111, 112, 91, 45, 49, 93, 32, 36, 50, 44, 36, 50, 44, 123,
  119, 45, 36, 50, 45, 49, 125, 44, 123, 104, 45, 36, 50, 45, 49, 125,
  10, 45, 105, 102, 32, 123, 36, 56, 62, 50, 125, 10, 112, 117, 115, 104,
  61, 123, 114, 111, 117, 110, 100, 40, 36, 50, 42, 49, 46, 53, 41, 125,
  10, 112, 117, 108, 108, 61, 123, 36, 50, 45, 36, 112, 117, 115, 104, 125,
  10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 123, 119, 43,
  36, 112, 117, 115, 104, 125, 44, 123, 104, 43, 36, 50, 125, 44, 49, 44,
  49, 44, 48, 44, 49, 44, 49, 44, 49, 10, 45, 114, 101, 115, 105, 122,
  101, 91, 45, 49, 93, 32, 123, 119, 43, 36, 112, 117, 108, 108, 125, 44,
  123, 104, 43, 36, 50, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 48,
  44, 48, 10, 45, 102, 102, 116, 95, 116, 105, 108, 101, 51, 95, 99, 108,
  101, 97, 110, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51,
  44, 36, 52, 44, 36, 53, 44, 36, 54, 10, 45, 99, 114, 111, 112, 91,
  45, 49, 93, 32, 123, 36, 112, 117, 115, 104, 125, 44, 123, 36, 50, 125,
  44, 123, 119, 45, 36, 112, 117, 108, 108, 45, 49, 125, 44, 123, 104, 45,
  40, 36, 50, 41, 45, 49, 125, 10, 45, 45, 114, 101, 115, 105, 122, 101,
  91, 48, 93, 32, 123, 119, 43, 36, 50, 125, 44, 123, 104, 43, 36, 112,
  117, 115, 104, 125, 44, 49, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49,
  10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 119, 43,
  36, 50, 125, 44, 123, 104, 43, 36, 112, 117, 108, 108, 125, 44, 49, 44,
  49, 44, 48, 44, 49, 44, 48, 44, 48, 10, 45, 102, 102, 116, 95, 116,
  105, 108, 101, 51, 95, 99, 108, 101, 97, 110, 91, 45, 49, 93, 32, 36,
  49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54,
  10, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 36, 50, 44, 123, 36,
  112, 117, 115, 104, 125, 44, 123, 119, 45, 36, 50, 45, 49, 125, 44, 123,
  104, 45, 36, 112, 117, 108, 108, 45, 49, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 56, 62, 49, 125, 10, 100, 105, 97,
  49, 61, 123, 114, 111, 117, 110, 100, 40, 36, 50, 47, 51, 41, 125, 10,
  100, 105, 97, 50, 61, 123, 36, 50, 45, 36, 100, 105, 97, 49, 125, 10,
  45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 123, 119, 43, 36,
  100, 105, 97, 49, 125, 44, 123, 104, 43, 36, 100, 105, 97, 49, 125, 44,
  49, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 123, 119, 43, 36, 100, 105, 97, 50,
  125, 44, 123, 104, 43, 36, 100, 105, 97, 50, 125, 44, 49, 44, 49, 44,
  48, 44, 49, 44, 48, 44, 48, 10, 45, 102, 102, 116, 95, 116, 105, 108,
  101, 51, 95, 99, 108, 101, 97, 110, 91, 45, 49, 93, 32, 36, 49, 44,
  36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 10, 45,
  99, 114, 111, 112, 91, 45, 49, 93, 32, 123, 36, 100, 105, 97, 49, 125,
  44, 123, 36, 100, 105, 97, 49, 125, 44, 123, 119, 45, 36, 100, 105, 97,
  50, 45, 49, 125, 44, 123, 104, 45, 36, 100, 105, 97, 50, 45, 49, 125,
  10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 123, 119, 43,
  36, 100, 105, 97, 50, 125, 44, 123, 104, 43, 36, 100, 105, 97, 50, 125,
  44, 49, 44, 49, 44, 48, 44, 49, 44, 49, 44, 49, 10, 45, 114, 101,
  115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 119, 43, 36, 100, 105, 97,
  49, 125, 44, 123, 104, 43, 36, 100, 105, 97, 49, 125, 44, 49, 44, 49,
  44, 48, 44, 49, 44, 48, 44, 48, 10, 45, 102, 102, 116, 95, 116, 105,
  108, 101, 51, 95, 99, 108, 101, 97, 110, 91, 45, 49, 93, 32, 36, 49,
  44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 10,
  45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 123, 36, 100, 105, 97, 50,
  125, 44, 123, 36, 100, 105, 97, 50, 125, 44, 123, 119, 45, 36, 100, 105,
  97, 49, 45, 49, 125, 44, 123, 104, 45, 36, 100, 105, 97, 49, 45, 49,
  125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 109, 111, 118, 101,
  91, 48, 93, 10, 45, 105, 102, 32, 123, 36, 56, 61, 61, 51, 125, 10,
  45, 109, 101, 100, 53, 115, 116, 97, 99, 107, 49, 54, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 56, 61, 61, 50, 125, 10,
  45, 109, 101, 100, 51, 115, 116, 97, 99, 107, 49, 54, 10, 45, 101, 110,
  100, 105, 102, 10, 110, 114, 53, 58, 10, 108, 117, 109, 97, 95, 115, 116,
  114, 101, 110, 103, 116, 104, 61, 36, 49, 10, 99, 111, 108, 111, 117, 114,
  95, 115, 116, 114, 101, 110, 103, 116, 104, 61, 36, 50, 10, 114, 101, 99,
  111, 118, 101, 114, 121, 61, 36, 51, 10, 100, 101, 116, 97, 105, 108, 95,
  114, 101, 99, 111, 118, 101, 114, 121, 61, 123, 53, 48, 48, 48, 45, 40,
  36, 52, 42, 53, 48, 48, 41, 125, 10, 102, 105, 110, 101, 95, 100, 101,
  116, 105, 97, 108, 115, 61, 36, 49, 51, 10, 109, 101, 100, 105, 117, 109,
  95, 100, 101, 116, 105, 97, 108, 115, 61, 36, 49, 52, 10, 108, 97, 114,
  103, 101, 95, 100, 101, 116, 97, 105, 108, 115, 61, 36, 49, 53, 10, 100,
  101, 116, 97, 105, 108, 95, 114, 97, 100, 105, 117, 115, 61, 36, 53, 10,
  100, 101, 116, 97, 105, 108, 95, 97, 109, 111, 117, 110, 116, 61, 36, 54,
  10, 100, 101, 116, 97, 105, 108, 95, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 61, 36, 55, 10, 101, 100, 103, 101, 95, 114, 97, 100, 105, 117, 115,
  61, 36, 56, 10, 101, 100, 103, 101, 95, 97, 109, 111, 117, 110, 116, 61,
  36, 57, 10, 101, 100, 103, 101, 95, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 61, 36, 49, 48, 10, 113, 117, 97, 108, 105, 116, 121, 61, 51, 10,
  45, 105, 102, 32, 123, 36, 49, 54, 61, 61, 49, 125, 10, 45, 109, 117,
  108, 91, 48, 93, 32, 50, 53, 54, 10, 114, 97, 100, 105, 117, 115, 61,
  123, 48, 46, 48, 53, 42, 40, 109, 105, 110, 40, 104, 44, 119, 41, 41,
  125, 10, 91, 48, 93, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101,
  91, 45, 49, 93, 32, 48, 44, 48, 44, 49, 48, 48, 37, 44, 36, 114,
  97, 100, 105, 117, 115, 44, 49, 44, 123, 105, 97, 125, 10, 45, 114, 101,
  99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44,
  36, 114, 97, 100, 105, 117, 115, 44, 49, 48, 48, 37, 44, 49, 44, 123,
  105, 97, 125, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45,
  49, 93, 32, 48, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 123,
  104, 45, 36, 114, 97, 100, 105, 117, 115, 125, 44, 49, 44, 123, 105, 97,
  125, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93,
  32, 123, 119, 45, 36, 114, 97, 100, 105, 117, 115, 125, 44, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 48, 44, 49, 44, 123, 105, 97, 125, 10,
  45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 123, 36, 114, 97, 100, 105,
  117, 115, 47, 50, 125, 10, 120, 109, 105, 110, 61, 64, 123, 45, 49, 44,
  120, 109, 125, 10, 121, 109, 105, 110, 61, 64, 123, 45, 49, 44, 121, 109,
  125, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 93, 10, 45, 45,
  99, 114, 111, 112, 91, 48, 93, 32, 123, 36, 120, 109, 105, 110, 45, 36,
  114, 97, 100, 105, 117, 115, 125, 44, 123, 36, 121, 109, 105, 110, 45, 36,
  114, 97, 100, 105, 117, 115, 125, 44, 123, 36, 120, 109, 105, 110, 43, 36,
  114, 97, 100, 105, 117, 115, 125, 44, 123, 36, 121, 109, 105, 110, 43, 36,
  114, 97, 100, 105, 117, 115, 125, 10, 109, 105, 110, 110, 111, 105, 115, 101,
  61, 123, 40, 64, 123, 45, 118, 97, 114, 105, 97, 110, 99, 101, 95, 110,
  111, 105, 115, 101, 125, 41, 125, 10, 45, 114, 101, 109, 111, 118, 101, 91,
  45, 49, 93, 10, 45, 45, 115, 117, 98, 91, 48, 93, 32, 123, 50, 53,
  48, 42, 50, 53, 54, 125, 10, 45, 97, 98, 115, 91, 45, 49, 93, 10,
  45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48,
  44, 48, 44, 49, 48, 48, 37, 44, 36, 114, 97, 100, 105, 117, 115, 44,
  49, 44, 123, 105, 97, 125, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108,
  101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 36, 114, 97, 100, 105, 117,
  115, 44, 49, 48, 48, 37, 44, 49, 44, 123, 105, 97, 125, 10, 45, 114,
  101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48, 44, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 123, 104, 45, 36, 114, 97, 100,
  105, 117, 115, 125, 44, 49, 44, 123, 105, 97, 125, 10, 45, 114, 101, 99,
  116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 123, 119, 45, 36, 114,
  97, 100, 105, 117, 115, 125, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 48, 44, 49, 44, 123, 105, 97, 125, 10, 45, 98, 108, 117, 114, 91,
  45, 49, 93, 32, 123, 36, 114, 97, 100, 105, 117, 115, 47, 50, 125, 10,
  120, 109, 97, 120, 61, 64, 123, 45, 49, 44, 120, 109, 125, 10, 121, 109,
  97, 120, 61, 64, 123, 45, 49, 44, 121, 109, 125, 10, 45, 45, 99, 114,
  111, 112, 91, 48, 93, 32, 123, 36, 120, 109, 97, 120, 45, 36, 114, 97,
  100, 105, 117, 115, 125, 44, 123, 36, 121, 109, 97, 120, 45, 36, 114, 97,
  100, 105, 117, 115, 125, 44, 123, 36, 120, 109, 97, 120, 43, 36, 114, 97,
  100, 105, 117, 115, 125, 44, 123, 36, 121, 109, 97, 120, 43, 36, 114, 97,
  100, 105, 117, 115, 125, 10, 109, 97, 120, 110, 111, 105, 115, 101, 61, 123,
  40, 64, 123, 45, 118, 97, 114, 105, 97, 110, 99, 101, 95, 110, 111, 105,
  115, 101, 125, 41, 125, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49,
  93, 10, 45, 45, 115, 117, 98, 91, 48, 93, 32, 123, 49, 50, 56, 42,
  50, 53, 54, 125, 10, 45, 97, 98, 115, 91, 45, 49, 93, 10, 45, 114,
  101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48, 44, 48,
  44, 49, 48, 48, 37, 44, 36, 114, 97, 100, 105, 117, 115, 44, 49, 44,
  123, 105, 97, 125, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91,
  45, 49, 93, 32, 48, 44, 48, 44, 36, 114, 97, 100, 105, 117, 115, 44,
  49, 48, 48, 37, 44, 49, 44, 123, 105, 97, 125, 10, 45, 114, 101, 99,
  116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48, 44, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 123, 104, 45, 36, 114, 97, 100, 105, 117,
  115, 125, 44, 49, 44, 123, 105, 97, 125, 10, 45, 114, 101, 99, 116, 97,
  110, 103, 108, 101, 91, 45, 49, 93, 32, 123, 119, 45, 36, 114, 97, 100,
  105, 117, 115, 125, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48,
  44, 49, 44, 123, 105, 97, 125, 10, 45, 98, 108, 117, 114, 91, 45, 49,
  93, 32, 123, 36, 114, 97, 100, 105, 117, 115, 47, 50, 125, 10, 120, 97,
  118, 101, 61, 64, 123, 45, 49, 44, 120, 109, 125, 10, 121, 97, 118, 101,
  61, 64, 123, 45, 49, 44, 121, 109, 125, 10, 45, 114, 101, 109, 111, 118,
  101, 91, 45, 49, 93, 10, 45, 45, 99, 114, 111, 112, 91, 48, 93, 32,
  123, 36, 120, 97, 118, 101, 45, 36, 114, 97, 100, 105, 117, 115, 125, 44,
  123, 36, 121, 97, 118, 101, 45, 36, 114, 97, 100, 105, 117, 115, 125, 44,
  123, 36, 120, 97, 118, 101, 43, 36, 114, 97, 100, 105, 117, 115, 125, 44,
  123, 36, 121, 97, 118, 101, 43, 36, 114, 97, 100, 105, 117, 115, 125, 10,
  109, 105, 100, 110, 111, 105, 115, 101, 61, 123, 40, 64, 123, 45, 118, 97,
  114, 105, 97, 110, 99, 101, 95, 110, 111, 105, 115, 101, 125, 41, 125, 10,
  45, 116, 101, 120, 116, 91, 45, 49, 93, 32, 36, 109, 105, 100, 110, 111,
  105, 115, 101, 44, 48, 44, 48, 44, 50, 53, 44, 49, 44, 123, 105, 77,
  125, 10, 45, 45, 115, 117, 98, 91, 48, 93, 32, 123, 54, 52, 42, 50,
  53, 54, 125, 10, 45, 97, 98, 115, 91, 45, 49, 93, 10, 45, 114, 101,
  99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44,
  49, 48, 48, 37, 44, 36, 114, 97, 100, 105, 117, 115, 44, 49, 44, 123,
  105, 97, 125, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45,
  49, 93, 32, 48, 44, 48, 44, 36, 114, 97, 100, 105, 117, 115, 44, 49,
  48, 48, 37, 44, 49, 44, 123, 105, 97, 125, 10, 45, 114, 101, 99, 116,
  97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48, 44, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 123, 104, 45, 36, 114, 97, 100, 105, 117, 115,
  125, 44, 49, 44, 123, 105, 97, 125, 10, 45, 114, 101, 99, 116, 97, 110,
  103, 108, 101, 91, 45, 49, 93, 32, 123, 119, 45, 36, 114, 97, 100, 105,
  117, 115, 125, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 48, 44,
  49, 44, 123, 105, 97, 125, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93,
  32, 123, 36, 114, 97, 100, 105, 117, 115, 47, 50, 125, 10, 120, 115, 104,
  97, 100, 111, 119, 61, 64, 123, 45, 49, 44, 120, 109, 125, 10, 121, 115,
  104, 97, 100, 111, 119, 61, 64, 123, 45, 49, 44, 121, 109, 125, 10, 45,
  114, 101, 109, 111, 118, 101, 91, 45, 49, 93, 10, 45, 45, 99, 114, 111,
  112, 91, 48, 93, 32, 123, 36, 120, 115, 104, 97, 100, 111, 119, 45, 36,
  114, 97, 100, 105, 117, 115, 125, 44, 123, 36, 121, 115, 104, 97, 100, 111,
  119, 45, 36, 114, 97, 100, 105, 117, 115, 125, 44, 123, 36, 120, 115, 104,
  97, 100, 111, 119, 43, 36, 114, 97, 100, 105, 117, 115, 125, 44, 123, 36,
  121, 115, 104, 97, 100, 111, 119, 43, 36, 114, 97, 100, 105, 117, 115, 125,
  10, 115, 104, 97, 100, 111, 119, 110, 111, 105, 115, 101, 61, 123, 40, 64,
  123, 45, 118, 97, 114, 105, 97, 110, 99, 101, 95, 110, 111, 105, 115, 101,
  125, 41, 125, 10, 45, 45, 115, 117, 98, 91, 48, 93, 32, 123, 49, 57,
  50, 42, 50, 53, 54, 125, 10, 45, 97, 98, 115, 91, 45, 49, 93, 10,
  45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48,
  44, 48, 44, 49, 48, 48, 37, 44, 36, 114, 97, 100, 105, 117, 115, 44,
  49, 44, 123, 105, 97, 125, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108,
  101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 36, 114, 97, 100, 105, 117,
  115, 44, 49, 48, 48, 37, 44, 49, 44, 123, 105, 97, 125, 10, 45, 114,
  101, 99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48, 44, 49,
  48, 48, 37, 44, 49, 48, 48, 37, 44, 123, 104, 45, 36, 114, 97, 100,
  105, 117, 115, 125, 44, 49, 44, 123, 105, 97, 125, 10, 45, 114, 101, 99,
  116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 123, 119, 45, 36, 114,
  97, 100, 105, 117, 115, 125, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 48, 44, 49, 44, 123, 105, 97, 125, 10, 45, 98, 108, 117, 114, 91,
  45, 49, 93, 32, 123, 36, 114, 97, 100, 105, 117, 115, 47, 50, 125, 10,
  120, 98, 114, 105, 103, 104, 116, 61, 64, 123, 45, 49, 44, 120, 109, 125,
  10, 121, 98, 114, 105, 103, 104, 116, 61, 64, 123, 45, 49, 44, 121, 109,
  125, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 93, 10, 45, 45,
  99, 114, 111, 112, 91, 48, 93, 32, 123, 36, 120, 98, 114, 105, 103, 104,
  116, 45, 36, 114, 97, 100, 105, 117, 115, 125, 44, 123, 36, 121, 98, 114,
  105, 103, 104, 116, 45, 36, 114, 97, 100, 105, 117, 115, 125, 44, 123, 36,
  120, 98, 114, 105, 103, 104, 116, 43, 36, 114, 97, 100, 105, 117, 115, 125,
  44, 123, 36, 121, 98, 114, 105, 103, 104, 116, 43, 36, 114, 97, 100, 105,
  117, 115, 125, 10, 98, 114, 105, 103, 104, 116, 110, 111, 105, 115, 101, 61,
  123, 40, 64, 123, 45, 118, 97, 114, 105, 97, 110, 99, 101, 95, 110, 111,
  105, 115, 101, 125, 41, 125, 10, 115, 104, 97, 100, 111, 119, 115, 61, 123,
  40, 40, 36, 109, 105, 110, 110, 111, 105, 115, 101, 47, 36, 115, 104, 97,
  100, 111, 119, 110, 111, 105, 115, 101, 41, 42, 54, 52, 41, 125, 10, 109,
  105, 100, 115, 61, 123, 40, 40, 36, 109, 105, 110, 110, 111, 105, 115, 101,
  47, 36, 109, 105, 100, 110, 111, 105, 115, 101, 41, 42, 54, 52, 41, 125,
  10, 98, 114, 105, 103, 104, 116, 115, 61, 123, 40, 40, 36, 109, 105, 110,
  110, 111, 105, 115, 101, 47, 36, 98, 114, 105, 103, 104, 116, 110, 111, 105,
  115, 101, 41, 42, 54, 52, 41, 125, 10, 119, 104, 105, 116, 101, 115, 61,
  123, 40, 40, 36, 109, 105, 110, 110, 111, 105, 115, 101, 47, 36, 109, 97,
  120, 110, 111, 105, 115, 101, 41, 42, 54, 52, 41, 125, 10, 112, 111, 105,
  110, 116, 49, 61, 123, 36, 115, 104, 97, 100, 111, 119, 115, 43, 51, 50,
  125, 10, 112, 111, 105, 110, 116, 50, 61, 123, 36, 109, 105, 100, 115, 43,
  36, 115, 104, 97, 100, 111, 119, 115, 43, 51, 50, 125, 10, 112, 111, 105,
  110, 116, 51, 61, 123, 36, 98, 114, 105, 103, 104, 116, 115, 43, 36, 109,
  105, 100, 115, 43, 36, 115, 104, 97, 100, 111, 119, 115, 43, 51, 50, 125,
  10, 112, 111, 105, 110, 116, 52, 61, 123, 36, 119, 104, 105, 116, 101, 115,
  43, 36, 98, 114, 105, 103, 104, 116, 115, 43, 36, 109, 105, 100, 115, 43,
  36, 115, 104, 97, 100, 111, 119, 115, 43, 51, 50, 125, 10, 45, 107, 101,
  101, 112, 91, 48, 93, 10, 35, 35, 32, 99, 114, 111, 112, 119, 105, 100,
  116, 104, 61, 123, 119, 125, 10, 35, 35, 32, 99, 114, 111, 112, 104, 101,
  105, 103, 104, 116, 61, 123, 104, 125, 10, 35, 35, 32, 45, 114, 101, 115,
  105, 122, 101, 91, 48, 93, 32, 123, 119, 43, 40, 54, 52, 45, 119, 37,
  54, 52, 41, 125, 44, 123, 104, 43, 40, 54, 52, 45, 104, 37, 54, 52,
  41, 125, 44, 49, 44, 123, 115, 125, 44, 48, 44, 49, 10, 35, 35, 32,
  119, 105, 100, 116, 104, 61, 123, 119, 125, 10, 35, 35, 32, 104, 101, 105,
  103, 104, 116, 61, 123, 104, 125, 10, 45, 97, 112, 112, 108, 121, 95, 99,
  117, 114, 118, 101, 91, 48, 93, 32, 48, 44, 48, 44, 48, 44, 123, 51,
  50, 42, 50, 53, 54, 125, 44, 123, 51, 50, 42, 50, 53, 54, 125, 44,
  123, 57, 54, 42, 50, 53, 54, 125, 44, 123, 36, 112, 111, 105, 110, 116,
  49, 42, 50, 53, 54, 125, 44, 123, 49, 54, 48, 42, 50, 53, 54, 125,
  44, 123, 36, 112, 111, 105, 110, 116, 50, 42, 50, 53, 54, 125, 44, 123,
  50, 50, 51, 42, 50, 53, 54, 125, 44, 123, 36, 112, 111, 105, 110, 116,
  51, 42, 50, 53, 54, 125, 44, 123, 50, 56, 55, 42, 50, 53, 54, 125,
  44, 123, 36, 112, 111, 105, 110, 116, 52, 42, 50, 53, 54, 125, 10, 45,
  100, 105, 118, 91, 48, 93, 32, 50, 53, 54, 10, 45, 101, 108, 115, 101,
  10, 45, 97, 112, 112, 108, 121, 95, 103, 97, 109, 109, 97, 32, 123, 49,
  47, 36, 49, 55, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 103,
  98, 50, 121, 99, 98, 99, 114, 10, 45, 115, 112, 108, 105, 116, 32, 99,
  10, 45, 105, 102, 32, 123, 36, 49, 62, 48, 125, 10, 45, 105, 102, 32,
  123, 36, 49, 49, 61, 61, 48, 125, 10, 45, 45, 100, 101, 110, 111, 105,
  115, 101, 95, 104, 97, 97, 114, 91, 48, 93, 32, 36, 108, 117, 109, 97,
  95, 115, 116, 114, 101, 110, 103, 116, 104, 44, 48, 44, 123, 36, 113, 117,
  97, 108, 105, 116, 121, 42, 49, 48, 125, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 49, 49, 61, 61, 49, 125, 10, 45, 45,
  109, 115, 95, 112, 97, 116, 99, 104, 91, 48, 93, 32, 49, 48, 44, 123,
  36, 108, 117, 109, 97, 95, 115, 116, 114, 101, 110, 103, 116, 104, 42, 50,
  46, 53, 125, 44, 51, 44, 53, 44, 48, 44, 49, 44, 49, 44, 48, 44,
  123, 36, 108, 117, 109, 97, 95, 115, 116, 114, 101, 110, 103, 116, 104, 42,
  46, 55, 53, 125, 44, 123, 36, 108, 117, 109, 97, 95, 115, 116, 114, 101,
  110, 103, 116, 104, 42, 46, 53, 125, 44, 123, 36, 108, 117, 109, 97, 95,
  115, 116, 114, 101, 110, 103, 116, 104, 42, 48, 125, 44, 123, 36, 108, 117,
  109, 97, 95, 115, 116, 114, 101, 110, 103, 116, 104, 42, 48, 125, 44, 49,
  44, 49, 44, 49, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 49, 49, 61, 61, 50, 125, 10, 45, 45, 97, 117, 116,
  111, 110, 114, 50, 91, 48, 93, 32, 36, 108, 117, 109, 97, 95, 115, 116,
  114, 101, 110, 103, 116, 104, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 49, 49, 61, 61, 51, 125, 10, 45, 45, 109,
  101, 100, 105, 97, 110, 91, 48, 93, 32, 51, 10, 45, 109, 115, 95, 112,
  97, 116, 99, 104, 91, 45, 49, 93, 32, 49, 48, 44, 123, 36, 108, 117,
  109, 97, 95, 115, 116, 114, 101, 110, 103, 116, 104, 42, 50, 46, 53, 125,
  44, 51, 44, 53, 44, 48, 44, 49, 44, 49, 44, 48, 44, 123, 36, 108,
  117, 109, 97, 95, 115, 116, 114, 101, 110, 103, 116, 104, 42, 46, 55, 53,
  125, 44, 123, 36, 108, 117, 109, 97, 95, 115, 116, 114, 101, 110, 103, 116,
  104, 42, 46, 53, 125, 44, 123, 36, 108, 117, 109, 97, 95, 115, 116, 114,
  101, 110, 103, 116, 104, 42, 48, 125, 44, 123, 36, 108, 117, 109, 97, 95,
  115, 116, 114, 101, 110, 103, 116, 104, 42, 48, 125, 44, 49, 44, 49, 44,
  49, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 49, 49, 61, 61, 52, 125, 10, 45, 45, 109, 115, 109, 101, 100, 50,
  91, 48, 93, 32, 51, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49,
  10, 45, 109, 115, 109, 101, 100, 50, 91, 45, 49, 93, 32, 51, 10, 45,
  100, 111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 45, 115, 117,
  98, 91, 48, 93, 32, 91, 45, 49, 93, 10, 45, 97, 100, 100, 91, 45,
  49, 93, 32, 123, 49, 50, 56, 125, 10, 45, 114, 101, 109, 111, 118, 101,
  91, 48, 93, 10, 45, 105, 102, 32, 123, 36, 114, 101, 99, 111, 118, 101,
  114, 121, 61, 61, 49, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45,
  49, 93, 32, 123, 119, 43, 52, 56, 125, 44, 123, 104, 43, 52, 56, 125,
  44, 123, 100, 125, 44, 123, 115, 125, 44, 48, 44, 48, 44, 48, 44, 48,
  10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 119, 43,
  52, 56, 125, 44, 123, 104, 43, 52, 56, 125, 44, 123, 100, 125, 44, 123,
  115, 125, 44, 48, 44, 48, 44, 49, 44, 49, 10, 45, 114, 101, 99, 116,
  97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 49, 48,
  48, 37, 44, 52, 56, 44, 49, 44, 49, 50, 56, 10, 45, 114, 101, 99,
  116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 52,
  56, 44, 49, 48, 48, 37, 44, 49, 44, 49, 50, 56, 10, 45, 114, 101,
  99, 116, 97, 110, 103, 108, 101, 91, 45, 49, 93, 32, 48, 44, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 123, 104, 45, 52, 56, 125, 44, 49,
  44, 49, 50, 56, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 91,
  45, 49, 93, 32, 123, 119, 45, 52, 56, 125, 44, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 44, 48, 44, 49, 44, 49, 50, 56, 10, 45, 102, 102,
  116, 95, 116, 105, 108, 101, 51, 91, 45, 49, 93, 32, 123, 36, 100, 101,
  116, 97, 105, 108, 95, 114, 101, 99, 111, 118, 101, 114, 121, 125, 44, 52,
  56, 44, 48, 44, 36, 102, 105, 110, 101, 95, 100, 101, 116, 105, 97, 108,
  115, 44, 36, 109, 101, 100, 105, 117, 109, 95, 100, 101, 116, 105, 97, 108,
  115, 44, 36, 108, 97, 114, 103, 101, 95, 100, 101, 116, 97, 105, 108, 115,
  44, 49, 44, 36, 113, 117, 97, 108, 105, 116, 121, 10, 45, 99, 114, 111,
  112, 91, 45, 49, 93, 32, 52, 56, 44, 52, 56, 44, 123, 119, 45, 52,
  57, 125, 44, 123, 104, 45, 52, 57, 125, 10, 45, 101, 108, 115, 101, 10,
  45, 102, 105, 108, 108, 91, 45, 49, 93, 32, 49, 50, 56, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 117, 110, 115, 104, 97, 114, 112, 91, 45, 49,
  93, 32, 36, 100, 101, 116, 97, 105, 108, 95, 114, 97, 100, 105, 117, 115,
  44, 36, 100, 101, 116, 97, 105, 108, 95, 97, 109, 111, 117, 110, 116, 44,
  36, 100, 101, 116, 97, 105, 108, 95, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 10, 45, 117, 110, 115, 104, 97, 114, 112, 91, 50, 93, 32, 36, 101,
  100, 103, 101, 95, 114, 97, 100, 105, 117, 115, 44, 36, 101, 100, 103, 101,
  95, 97, 109, 111, 117, 110, 116, 44, 36, 101, 100, 103, 101, 95, 116, 104,
  114, 101, 115, 104, 111, 108, 100, 10, 45, 115, 117, 98, 91, 45, 49, 93,
  32, 123, 49, 50, 56, 125, 10, 45, 97, 100, 100, 91, 50, 93, 32, 91,
  45, 49, 93, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 93, 10,
  45, 101, 108, 115, 101, 10, 45, 109, 111, 118, 101, 91, 48, 93, 32, 51,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 50, 62,
  48, 125, 10, 45, 109, 101, 100, 105, 97, 110, 91, 48, 44, 49, 93, 32,
  51, 10, 45, 109, 101, 100, 105, 97, 110, 91, 48, 44, 49, 93, 32, 51,
  10, 45, 105, 102, 32, 123, 36, 49, 50, 61, 61, 49, 125, 10, 45, 109,
  115, 95, 112, 97, 116, 99, 104, 91, 48, 93, 32, 49, 48, 44, 49, 44,
  51, 44, 53, 44, 48, 44, 49, 44, 49, 44, 48, 44, 123, 36, 99, 111,
  108, 111, 117, 114, 95, 115, 116, 114, 101, 110, 103, 116, 104, 42, 49, 125,
  44, 123, 36, 99, 111, 108, 111, 117, 114, 95, 115, 116, 114, 101, 110, 103,
  116, 104, 42, 46, 53, 125, 44, 123, 36, 99, 111, 108, 111, 117, 114, 95,
  115, 116, 114, 101, 110, 103, 116, 104, 42, 46, 50, 53, 125, 44, 123, 36,
  99, 111, 108, 111, 117, 114, 95, 115, 116, 114, 101, 110, 103, 116, 104, 42,
  48, 125, 44, 48, 44, 49, 44, 49, 44, 48, 10, 45, 109, 115, 95, 112,
  97, 116, 99, 104, 91, 49, 93, 32, 49, 48, 44, 49, 44, 51, 44, 53,
  44, 48, 44, 49, 44, 49, 44, 48, 44, 123, 36, 99, 111, 108, 111, 117,
  114, 95, 115, 116, 114, 101, 110, 103, 116, 104, 42, 49, 125, 44, 123, 36,
  99, 111, 108, 111, 117, 114, 95, 115, 116, 114, 101, 110, 103, 116, 104, 42,
  46, 53, 125, 44, 123, 36, 99, 111, 108, 111, 117, 114, 95, 115, 116, 114,
  101, 110, 103, 116, 104, 42, 46, 50, 53, 125, 44, 123, 36, 99, 111, 108,
  111, 117, 114, 95, 115, 116, 114, 101, 110, 103, 116, 104, 42, 48, 125, 44,
  48, 44, 49, 44, 49, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 49, 50, 61, 61, 48, 125, 10, 45, 100, 101, 110,
  111, 105, 115, 101, 95, 104, 97, 97, 114, 91, 48, 93, 32, 36, 99, 111,
  108, 111, 117, 114, 95, 115, 116, 114, 101, 110, 103, 116, 104, 44, 48, 44,
  123, 36, 113, 117, 97, 108, 105, 116, 121, 42, 51, 125, 10, 45, 100, 101,
  110, 111, 105, 115, 101, 95, 104, 97, 97, 114, 91, 49, 93, 32, 36, 99,
  111, 108, 111, 117, 114, 95, 115, 116, 114, 101, 110, 103, 116, 104, 44, 48,
  44, 123, 36, 113, 117, 97, 108, 105, 116, 121, 42, 51, 125, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 109, 111, 118,
  101, 91, 45, 49, 93, 32, 48, 10, 45, 97, 112, 112, 101, 110, 100, 32,
  99, 10, 45, 121, 99, 98, 99, 114, 50, 114, 103, 98, 10, 45, 105, 102,
  32, 123, 49, 54, 61, 61, 49, 125, 10, 45, 109, 117, 108, 91, 48, 93,
  32, 50, 53, 54, 10, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118,
  101, 91, 48, 93, 32, 48, 44, 48, 44, 48, 44, 123, 51, 50, 42, 50,
  53, 54, 125, 44, 123, 51, 50, 42, 50, 53, 54, 125, 44, 123, 36, 112,
  111, 105, 110, 116, 49, 42, 50, 53, 54, 125, 44, 123, 57, 54, 42, 50,
  53, 54, 125, 44, 123, 36, 112, 111, 105, 110, 116, 50, 42, 50, 53, 54,
  125, 44, 123, 49, 54, 48, 42, 50, 53, 54, 125, 44, 123, 36, 112, 111,
  105, 110, 116, 51, 42, 50, 53, 54, 125, 44, 123, 50, 50, 51, 42, 50,
  53, 54, 125, 44, 123, 36, 112, 111, 105, 110, 116, 52, 42, 50, 53, 54,
  125, 44, 123, 50, 56, 55, 42, 50, 53, 54, 125, 10, 35, 35, 32, 45,
  110, 32, 48, 44, 123, 50, 53, 54, 42, 50, 53, 54, 125, 10, 45, 100,
  105, 118, 91, 48, 93, 32, 50, 53, 54, 10, 45, 101, 108, 115, 101, 10,
  45, 97, 112, 112, 108, 121, 95, 103, 97, 109, 109, 97, 32, 36, 49, 55,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 99, 32, 48, 44, 50, 53, 53,
  10, 109, 115, 95, 112, 97, 116, 99, 104, 95, 115, 109, 111, 111, 116, 104,
  105, 110, 103, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 32, 34, 45, 114, 101, 112, 101, 97, 116, 32, 36, 55,
  32, 45, 100, 101, 110, 111, 105, 115, 101, 32, 36, 49, 44, 36, 50, 44,
  36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 32, 45, 100, 111, 110,
  101, 34, 44, 36, 56, 44, 48, 32, 45, 99, 32, 48, 44, 50, 53, 53,
  10, 109, 115, 95, 112, 97, 116, 99, 104, 95, 50, 58, 10, 45, 45, 114,
  101, 115, 105, 122, 101, 91, 48, 93, 32, 53, 48, 37, 44, 53, 48, 37,
  44, 49, 44, 123, 115, 125, 44, 50, 10, 45, 45, 109, 115, 95, 112, 97,
  116, 99, 104, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 91, 45, 49,
  93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53,
  44, 36, 54, 44, 36, 55, 44, 36, 56, 10, 45, 45, 114, 101, 115, 105,
  122, 101, 91, 49, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48,
  44, 104, 125, 44, 49, 44, 123, 115, 125, 44, 53, 10, 45, 45, 115, 117,
  98, 91, 48, 93, 32, 91, 51, 93, 10, 45, 114, 101, 115, 105, 122, 101,
  91, 50, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104,
  125, 44, 49, 44, 123, 115, 125, 44, 53, 10, 45, 45, 97, 100, 100, 91,
  50, 93, 32, 91, 52, 93, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93,
  10, 45, 99, 32, 48, 44, 50, 53, 53, 10, 109, 115, 95, 112, 97, 116,
  99, 104, 95, 51, 58, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 48,
  93, 32, 50, 53, 37, 44, 50, 53, 37, 44, 49, 44, 123, 115, 125, 44,
  50, 10, 45, 45, 109, 115, 95, 112, 97, 116, 99, 104, 95, 115, 109, 111,
  111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50,
  44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44,
  36, 56, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 49, 93, 32, 64,
  123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 123,
  115, 125, 44, 53, 10, 45, 45, 115, 117, 98, 91, 48, 93, 32, 91, 51,
  93, 10, 45, 114, 101, 115, 105, 122, 101, 91, 50, 93, 32, 64, 123, 48,
  44, 119, 125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 123, 115, 125,
  44, 53, 10, 45, 45, 97, 100, 100, 91, 50, 93, 32, 91, 52, 93, 10,
  45, 107, 101, 101, 112, 91, 45, 49, 93, 10, 45, 99, 32, 48, 44, 50,
  53, 53, 10, 109, 115, 95, 112, 97, 116, 99, 104, 95, 52, 58, 10, 45,
  45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 49, 50, 46, 53, 37,
  44, 49, 50, 46, 53, 37, 44, 49, 44, 123, 115, 125, 44, 50, 10, 45,
  45, 109, 115, 95, 112, 97, 116, 99, 104, 95, 115, 109, 111, 111, 116, 104,
  105, 110, 103, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51,
  44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 10,
  45, 45, 114, 101, 115, 105, 122, 101, 91, 49, 93, 32, 64, 123, 48, 44,
  119, 125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 123, 115, 125, 44,
  53, 10, 45, 45, 115, 117, 98, 91, 48, 93, 32, 91, 51, 93, 10, 45,
  114, 101, 115, 105, 122, 101, 91, 50, 93, 32, 64, 123, 48, 44, 119, 125,
  44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 123, 115, 125, 44, 53, 10,
  45, 45, 97, 100, 100, 91, 50, 93, 32, 91, 52, 93, 10, 45, 107, 101,
  101, 112, 91, 45, 49, 93, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10,
  109, 115, 95, 112, 97, 116, 99, 104, 95, 53, 58, 10, 45, 45, 114, 101,
  115, 105, 122, 101, 91, 48, 93, 32, 54, 46, 49, 50, 53, 37, 44, 54,
  46, 49, 50, 53, 37, 44, 49, 44, 123, 115, 125, 44, 50, 10, 45, 45,
  109, 115, 95, 112, 97, 116, 99, 104, 95, 115, 109, 111, 111, 116, 104, 105,
  110, 103, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44,
  36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 10, 45,
  45, 114, 101, 115, 105, 122, 101, 91, 49, 93, 32, 64, 123, 48, 44, 119,
  125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 123, 115, 125, 44, 53,
  10, 45, 45, 115, 117, 98, 91, 48, 93, 32, 91, 51, 93, 10, 45, 114,
  101, 115, 105, 122, 101, 91, 50, 93, 32, 64, 123, 48, 44, 119, 125, 44,
  64, 123, 48, 44, 104, 125, 44, 49, 44, 123, 115, 125, 44, 53, 10, 45,
  45, 97, 100, 100, 91, 50, 93, 32, 91, 52, 93, 10, 45, 107, 101, 101,
  112, 91, 45, 49, 93, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10, 109,
  115, 95, 112, 97, 116, 99, 104, 58, 10, 45, 97, 112, 112, 108, 121, 95,
  103, 97, 109, 109, 97, 32, 123, 49, 47, 36, 49, 52, 125, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 36, 49, 53, 10, 45, 105, 102, 32, 123, 36,
  49, 51, 61, 61, 49, 125, 10, 45, 109, 115, 95, 112, 97, 116, 99, 104,
  95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 32, 36,
  49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54,
  44, 36, 55, 44, 36, 56, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 57, 62, 48, 46, 49, 125, 10, 45, 109, 115, 95, 112,
  97, 116, 99, 104, 95, 50, 32, 36, 49, 44, 36, 57, 44, 36, 51, 44,
  36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 48, 62, 48,
  46, 49, 125, 10, 45, 109, 115, 95, 112, 97, 116, 99, 104, 95, 51, 32,
  36, 49, 44, 36, 49, 48, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44,
  36, 54, 44, 36, 55, 44, 36, 56, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 49, 49, 62, 48, 46, 49, 125, 10, 45, 109,
  115, 95, 112, 97, 116, 99, 104, 95, 52, 32, 36, 49, 44, 36, 49, 49,
  44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54, 44, 36, 55, 44,
  36, 56, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  49, 50, 62, 48, 46, 49, 125, 10, 45, 109, 115, 95, 112, 97, 116, 99,
  104, 95, 53, 32, 36, 49, 44, 36, 49, 50, 44, 36, 51, 44, 36, 52,
  44, 36, 53, 44, 36, 54, 44, 36, 55, 44, 36, 56, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 97, 112, 112, 108, 121,
  95, 103, 97, 109, 109, 97, 32, 36, 49, 52, 10, 45, 99, 32, 48, 44,
  50, 53, 53, 10, 109, 115, 109, 101, 100, 50, 58, 10, 109, 101, 100, 108,
  118, 108, 50, 61, 50, 10, 109, 101, 100, 108, 118, 108, 51, 61, 51, 10,
  109, 101, 100, 108, 118, 108, 52, 61, 52, 10, 109, 101, 100, 108, 118, 108,
  53, 61, 54, 10, 109, 101, 100, 108, 118, 108, 54, 61, 54, 10, 109, 101,
  100, 108, 118, 108, 55, 61, 55, 10, 45, 109, 101, 100, 105, 97, 110, 32,
  36, 49, 10, 45, 109, 101, 100, 105, 97, 110, 32, 36, 49, 10, 45, 110,
  97, 109, 101, 91, 48, 93, 32, 102, 117, 108, 108, 10, 45, 45, 114, 101,
  115, 105, 122, 101, 91, 102, 117, 108, 108, 93, 32, 64, 123, 102, 117, 108,
  108, 44, 119, 47, 36, 109, 101, 100, 108, 118, 108, 50, 125, 44, 64, 123,
  102, 117, 108, 108, 44, 104, 47, 36, 109, 101, 100, 108, 118, 108, 50, 125,
  44, 49, 44, 123, 115, 125, 44, 50, 10, 45, 110, 97, 109, 101, 91, 45,
  49, 93, 32, 108, 101, 118, 101, 108, 50, 10, 45, 45, 114, 101, 115, 105,
  122, 101, 91, 108, 101, 118, 101, 108, 50, 93, 32, 64, 123, 48, 44, 119,
  125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 123, 115, 125, 44, 51,
  44, 49, 10, 45, 110, 97, 109, 101, 91, 45, 49, 93, 32, 108, 111, 119,
  50, 10, 45, 45, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105,
  110, 101, 120, 116, 114, 97, 99, 116, 91, 102, 117, 108, 108, 44, 108, 111,
  119, 50, 93, 10, 45, 110, 97, 109, 101, 91, 45, 49, 93, 32, 108, 101,
  118, 101, 108, 50, 104, 105, 103, 104, 10, 45, 114, 101, 109, 111, 118, 101,
  91, 108, 111, 119, 50, 93, 10, 45, 109, 101, 100, 105, 97, 110, 91, 108,
  101, 118, 101, 108, 50, 93, 32, 36, 49, 10, 45, 109, 101, 100, 105, 97,
  110, 91, 108, 101, 118, 101, 108, 50, 93, 32, 36, 49, 10, 45, 110, 97,
  109, 101, 91, 49, 93, 32, 108, 101, 118, 101, 108, 50, 10, 45, 45, 114,
  101, 115, 105, 122, 101, 91, 108, 101, 118, 101, 108, 50, 93, 32, 64, 123,
  102, 117, 108, 108, 44, 119, 47, 36, 109, 101, 100, 108, 118, 108, 51, 125,
  44, 64, 123, 102, 117, 108, 108, 44, 104, 47, 36, 109, 101, 100, 108, 118,
  108, 51, 125, 44, 49, 44, 123, 115, 125, 44, 50, 10, 45, 110, 97, 109,
  101, 91, 45, 49, 93, 32, 108, 101, 118, 101, 108, 51, 10, 45, 45, 114,
  101, 115, 105, 122, 101, 91, 108, 101, 118, 101, 108, 51, 93, 32, 64, 123,
  108, 101, 118, 101, 108, 50, 44, 119, 125, 44, 64, 123, 108, 101, 118, 101,
  108, 50, 44, 104, 125, 44, 49, 44, 123, 115, 125, 44, 51, 44, 49, 10,
  45, 110, 97, 109, 101, 91, 45, 49, 93, 32, 108, 111, 119, 51, 10, 45,
  45, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 101, 120,
  116, 114, 97, 99, 116, 91, 108, 101, 118, 101, 108, 50, 44, 108, 111, 119,
  51, 93, 10, 45, 110, 97, 109, 101, 91, 45, 49, 93, 32, 108, 101, 118,
  101, 108, 51, 104, 105, 103, 104, 10, 45, 114, 101, 109, 111, 118, 101, 91,
  49, 44, 108, 111, 119, 51, 93, 10, 45, 109, 101, 100, 105, 97, 110, 91,
  50, 93, 32, 36, 49, 10, 45, 109, 101, 100, 105, 97, 110, 91, 50, 93,
  32, 36, 49, 10, 45, 110, 97, 109, 101, 91, 50, 93, 32, 108, 101, 118,
  101, 108, 51, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 108, 101, 118,
  101, 108, 51, 93, 32, 64, 123, 102, 117, 108, 108, 44, 119, 47, 36, 109,
  101, 100, 108, 118, 108, 52, 125, 44, 64, 123, 102, 117, 108, 108, 44, 104,
  47, 36, 109, 101, 100, 108, 118, 108, 52, 125, 44, 49, 44, 123, 115, 125,
  44, 50, 10, 45, 110, 97, 109, 101, 91, 45, 49, 93, 32, 108, 101, 118,
  101, 108, 52, 10, 45, 45, 114, 101, 115, 105, 122, 101, 91, 108, 101, 118,
  101, 108, 52, 93, 32, 64, 123, 108, 101, 118, 101, 108, 51, 44, 119, 125,
  44, 64, 123, 108, 101, 118, 101, 108, 51, 44, 104, 125, 44, 49, 44, 123,
  115, 125, 44, 51, 44, 49, 10, 45, 110, 97, 109, 101, 91, 45, 49, 93,
  32, 108, 111, 119, 52, 10, 45, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  103, 114, 97, 105, 110, 101, 120, 116, 114, 97, 99, 116, 91, 108, 101, 118,
  101, 108, 51, 44, 108, 111, 119, 52, 93, 10, 45, 110, 97, 109, 101, 91,
  45, 49, 93, 32, 108, 101, 118, 101, 108, 52, 104, 105, 103, 104, 10, 45,
  114, 101, 109, 111, 118, 101, 91, 50, 44, 108, 111, 119, 52, 93, 10, 45,
  109, 101, 100, 105, 97, 110, 91, 45, 50, 93, 32, 36, 49, 10, 45, 109,
  101, 100, 105, 97, 110, 91, 45, 50, 93, 32, 36, 49, 10, 45, 110, 97,
  109, 101, 91, 45, 50, 93, 32, 98, 97, 115, 101, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 98, 97, 115, 101, 93, 32, 64, 123, 108, 101, 118, 101,
  108, 52, 104, 105, 103, 104, 44, 119, 125, 44, 64, 123, 108, 101, 118, 101,
  108, 52, 104, 105, 103, 104, 44, 104, 125, 44, 49, 44, 123, 115, 125, 44,
  51, 44, 49, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97,
  105, 110, 109, 101, 114, 103, 101, 91, 45, 49, 44, 45, 50, 93, 10, 45,
  110, 97, 109, 101, 91, 45, 49, 93, 32, 98, 97, 115, 101, 10, 45, 114,
  101, 115, 105, 122, 101, 91, 98, 97, 115, 101, 93, 32, 64, 123, 108, 101,
  118, 101, 108, 51, 104, 105, 103, 104, 44, 119, 125, 44, 64, 123, 108, 101,
  118, 101, 108, 51, 104, 105, 103, 104, 44, 104, 125, 44, 49, 44, 123, 115,
  125, 44, 51, 44, 49, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 103,
  114, 97, 105, 110, 109, 101, 114, 103, 101, 91, 45, 49, 44, 45, 50, 93,
  10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 64, 123, 102,
  117, 108, 108, 44, 119, 125, 44, 64, 123, 102, 117, 108, 108, 44, 104, 125,
  44, 49, 44, 123, 115, 125, 44, 51, 44, 49, 10, 45, 99, 111, 109, 112,
  111, 115, 101, 95, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 91, 45,
  49, 44, 45, 50, 93, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10,
  110, 114, 53, 95, 112, 114, 101, 118, 105, 101, 119, 58, 10, 45, 105, 102,
  32, 123, 36, 45, 49, 61, 61, 48, 125, 10, 45, 110, 114, 53, 32, 36,
  49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 44, 36, 54,
  44, 36, 55, 44, 36, 56, 44, 36, 57, 44, 36, 49, 48, 44, 36, 49,
  49, 44, 36, 49, 50, 44, 36, 49, 51, 44, 36, 49, 52, 44, 36, 49,
  53, 44, 36, 49, 54, 44, 36, 49, 55, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 45, 49, 61, 61, 49, 125, 10, 45, 45,
  110, 114, 53, 32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44,
  36, 53, 44, 48, 44, 36, 55, 44, 36, 56, 44, 48, 44, 36, 49, 48,
  44, 36, 49, 49, 44, 36, 49, 50, 44, 36, 49, 51, 44, 36, 49, 52,
  44, 36, 49, 53, 44, 36, 49, 54, 44, 36, 49, 55, 10, 45, 115, 117,
  98, 91, 48, 93, 32, 91, 49, 93, 10, 45, 107, 101, 101, 112, 91, 48,
  93, 10, 45, 109, 117, 108, 32, 50, 10, 45, 97, 100, 100, 32, 49, 50,
  56, 10, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103, 105, 109, 112, 32,
  83, 107, 105, 110, 32, 109, 97, 115, 107, 32, 58, 32, 105, 97, 105, 110,
  95, 103, 105, 109, 112, 95, 115, 107, 105, 110, 95, 109, 97, 115, 107, 44,
  105, 97, 105, 110, 95, 103, 105, 109, 112, 95, 115, 107, 105, 110, 95, 109,
  97, 115, 107, 95, 112, 114, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 98, 62,
  77, 97, 105, 110, 32, 67, 111, 110, 116, 114, 111, 108, 115, 60, 47, 98,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 97, 103,
  101, 110, 116, 97, 32, 114, 97, 116, 105, 111, 32, 61, 32, 102, 108, 111,
  97, 116, 32, 40, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 121, 97, 110, 32, 114, 97, 116, 105,
  111, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 50, 48, 48, 44, 50,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 98, 62, 82, 101, 102, 105, 110, 101,
  32, 72, 117, 101, 32, 82, 97, 110, 103, 101, 60, 47, 98, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 109, 111, 118, 101,
  32, 114, 101, 100, 115, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 48,
  44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 82, 101, 109, 111, 118, 101, 32, 121, 101, 108, 108, 111, 119, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 32, 40, 34, 77, 97, 115, 107, 101, 100, 32, 73, 109,
  97, 103, 101, 34, 44, 34, 74, 117, 115, 116, 32, 116, 104, 101, 32, 77,
  97, 115, 107, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80,
  114, 101, 118, 105, 101, 119, 32, 115, 104, 111, 119, 115, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 32, 40, 49, 44, 34, 79, 117, 116, 112, 117, 116,
  34, 44, 34, 72, 105, 103, 104, 108, 105, 103, 104, 116, 101, 100, 32, 77,
  97, 115, 107, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 83, 107, 105, 110, 32, 109, 97, 115, 107,
  32, 117, 115, 101, 115, 32, 67, 77, 89, 75, 32, 99, 111, 108, 111, 117,
  114, 32, 109, 111, 100, 101, 108, 32, 116, 111, 32, 115, 101, 108, 99, 116,
  32, 115, 107, 105, 110, 32, 116, 111, 110, 101, 115, 46, 32, 83, 107, 105,
  110, 32, 116, 111, 110, 101, 115, 32, 103, 101, 110, 101, 114, 97, 108, 108,
  121, 32, 104, 97, 118, 101, 32, 97, 32, 112, 114, 101, 100, 105, 99, 116,
  97, 98, 108, 101, 32, 114, 97, 116, 105, 111, 115, 32, 111, 102, 32, 67,
  121, 97, 110, 44, 32, 77, 97, 103, 101, 116, 110, 97, 32, 97, 110, 100,
  32, 89, 101, 108, 108, 111, 119, 46, 32, 68, 105, 102, 102, 101, 114, 101,
  110, 116, 32, 101, 116, 104, 110, 105, 99, 105, 101, 115, 32, 104, 97, 118,
  101, 32, 115, 108, 105, 103, 104, 116, 121, 32, 100, 105, 102, 102, 101, 114,
  101, 110, 116, 32, 114, 97, 116, 105, 111, 115, 46, 32, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 77,
  97, 103, 101, 110, 116, 97, 32, 82, 97, 116, 105, 111, 58, 60, 47, 98,
  62, 32, 84, 104, 105, 115, 32, 115, 101, 116, 115, 32, 104, 111, 119, 32,
  109, 117, 99, 104, 32, 116, 104, 101, 32, 77, 97, 103, 101, 110, 116, 97,
  32, 99, 111, 110, 116, 101, 110, 116, 32, 105, 115, 32, 97, 108, 108, 111,
  119, 101, 100, 32, 116, 111, 32, 98, 101, 32, 98, 101, 108, 111, 119, 32,
  116, 104, 101, 32, 89, 101, 108, 108, 111, 119, 32, 99, 111, 110, 116, 101,
  110, 116, 46, 32, 73, 110, 99, 114, 101, 97, 115, 101, 32, 116, 111, 32,
  105, 110, 99, 108, 117, 100, 101, 32, 100, 97, 114, 107, 32, 115, 107, 105,
  110, 32, 116, 111, 110, 101, 115, 32, 97, 110, 100, 32, 115, 104, 97, 100,
  111, 119, 115, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 67,
  121, 97, 110, 32, 82, 97, 116, 105, 111, 58, 60, 47, 98, 62, 32, 84,
  104, 105, 115, 32, 115, 101, 116, 32, 116, 104, 101, 32, 104, 111, 119, 32,
  109, 117, 99, 104, 32, 116, 104, 101, 32, 67, 121, 97, 110, 32, 99, 111,
  110, 116, 101, 110, 116, 32, 105, 115, 32, 97, 108, 108, 111, 119, 101, 100,
  32, 116, 111, 32, 98, 101, 32, 98, 101, 108, 111, 119, 32, 116, 104, 101,
  32, 89, 101, 108, 108, 111, 119, 32, 99, 111, 110, 116, 101, 110, 116, 46,
  32, 73, 110, 99, 114, 101, 97, 115, 101, 32, 116, 111, 32, 105, 110, 99,
  108, 117, 100, 101, 32, 112, 97, 108, 101, 32, 115, 107, 105, 110, 32, 116,
  111, 110, 101, 115, 32, 97, 110, 100, 32, 104, 105, 103, 104, 108, 105, 103,
  104, 116, 115, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 82,
  101, 102, 105, 110, 101, 32, 72, 117, 101, 32, 82, 97, 110, 103, 101, 58,
  60, 47, 98, 62, 32, 84, 104, 105, 115, 32, 97, 108, 108, 111, 119, 115,
  32, 121, 111, 117, 32, 116, 111, 32, 114, 101, 109, 111, 118, 101, 32, 116,
  111, 110, 101, 115, 32, 116, 104, 97, 116, 32, 112, 97, 115, 115, 32, 116,
  104, 114, 111, 117, 103, 104, 32, 116, 104, 101, 32, 109, 97, 105, 110, 32,
  99, 111, 110, 116, 114, 111, 108, 115, 32, 98, 117, 116, 32, 97, 114, 101,
  32, 110, 111, 116, 32, 112, 114, 101, 115, 101, 110, 116, 32, 105, 110, 32,
  121, 111, 117, 114, 32, 115, 117, 98, 106, 101, 99, 116, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 73, 97, 105, 110,
  32, 70, 101, 114, 103, 117, 115, 115, 111, 110, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 105, 97, 105, 110, 95, 103,
  105, 109, 112, 95, 115, 107, 105, 110, 95, 109, 97, 115, 107, 95, 112, 114,
  58, 10, 45, 105, 102, 32, 123, 36, 54, 61, 61, 48, 125, 10, 45, 105,
  97, 105, 110, 95, 115, 107, 105, 110, 95, 109, 97, 115, 107, 32, 36, 49,
  44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 54, 61, 61, 49, 125, 10, 45, 45, 105, 97, 105,
  110, 95, 115, 107, 105, 110, 95, 109, 97, 115, 107, 32, 36, 49, 44, 36,
  50, 44, 36, 51, 44, 36, 52, 44, 49, 10, 45, 110, 91, 45, 49, 93,
  32, 48, 46, 54, 44, 49, 10, 45, 109, 117, 108, 10, 45, 101, 110, 100,
  105, 102, 10, 105, 97, 105, 110, 95, 103, 105, 109, 112, 95, 115, 107, 105,
  110, 95, 109, 97, 115, 107, 58, 10, 45, 116, 105, 99, 10, 45, 97, 112,
  112, 108, 121, 95, 112, 97, 114, 97, 108, 108, 101, 108, 95, 111, 118, 101,
  114, 108, 97, 112, 91, 48, 93, 32, 34, 45, 105, 97, 105, 110, 95, 115,
  107, 105, 110, 95, 109, 97, 115, 107, 91, 48, 93, 32, 36, 123, 49, 45,
  45, 49, 125, 34, 44, 48, 44, 48, 10, 45, 116, 111, 99, 10, 105, 97,
  105, 110, 95, 115, 107, 105, 110, 95, 109, 97, 115, 107, 58, 10, 100, 97,
  114, 107, 61, 123, 36, 49, 125, 10, 112, 97, 108, 101, 61, 123, 50, 53,
  53, 45, 36, 50, 125, 10, 114, 101, 100, 61, 123, 50, 53, 53, 45, 36,
  51, 125, 10, 121, 101, 108, 108, 111, 119, 61, 123, 50, 53, 53, 45, 36,
  52, 125, 10, 45, 116, 111, 95, 114, 103, 98, 10, 91, 48, 93, 10, 91,
  48, 93, 10, 91, 48, 93, 10, 45, 108, 91, 49, 93, 10, 45, 105, 102,
  32, 123, 36, 51, 62, 48, 125, 10, 114, 101, 100, 61, 123, 50, 53, 53,
  45, 36, 51, 125, 10, 45, 102, 105, 108, 108, 32, 105, 102, 40, 105, 40,
  120, 44, 121, 44, 122, 44, 48, 41, 45, 105, 40, 120, 44, 121, 44, 122,
  44, 49, 41, 60, 123, 36, 114, 101, 100, 125, 44, 105, 44, 48, 41, 10,
  45, 103, 116, 32, 48, 10, 45, 101, 108, 115, 101, 10, 45, 102, 105, 108,
  108, 32, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108,
  10, 45, 108, 91, 50, 93, 10, 45, 114, 103, 98, 50, 99, 109, 121, 107,
  10, 100, 97, 114, 107, 61, 123, 36, 49, 125, 10, 112, 97, 108, 101, 61,
  123, 50, 53, 53, 45, 36, 50, 125, 10, 45, 102, 105, 108, 108, 32, 105,
  102, 40, 105, 40, 120, 44, 121, 44, 122, 44, 50, 41, 62, 105, 40, 120,
  44, 121, 44, 122, 44, 49, 41, 44, 105, 102, 40, 105, 40, 120, 44, 121,
  44, 122, 44, 50, 41, 45, 105, 40, 120, 44, 121, 44, 122, 44, 49, 41,
  60, 123, 36, 100, 97, 114, 107, 125, 44, 105, 102, 40, 40, 105, 40, 120,
  44, 121, 44, 122, 44, 48, 41, 43, 123, 36, 112, 97, 108, 101, 125, 41,
  60, 105, 40, 120, 44, 121, 44, 122, 44, 50, 41, 44, 105, 44, 50, 53,
  53, 41, 44, 50, 53, 53, 41, 44, 50, 53, 53, 41, 10, 45, 99, 109,
  121, 107, 50, 114, 103, 98, 10, 45, 103, 116, 32, 48, 10, 45, 101, 110,
  100, 108, 10, 45, 108, 91, 51, 93, 10, 45, 105, 102, 32, 123, 36, 52,
  62, 48, 125, 10, 121, 101, 108, 108, 111, 119, 61, 123, 50, 53, 53, 45,
  36, 52, 125, 10, 45, 114, 103, 98, 50, 104, 115, 118, 10, 45, 115, 112,
  108, 105, 116, 32, 99, 10, 45, 107, 101, 101, 112, 91, 48, 93, 10, 45,
  97, 100, 100, 91, 48, 93, 32, 49, 56, 48, 10, 45, 109, 111, 100, 91,
  48, 93, 32, 51, 54, 48, 10, 45, 108, 116, 91, 48, 93, 32, 36, 121,
  101, 108, 108, 111, 119, 10, 45, 101, 108, 115, 101, 10, 45, 102, 105, 108,
  108, 32, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108,
  10, 45, 109, 117, 108, 91, 49, 44, 50, 44, 51, 93, 10, 45, 109, 117,
  108, 91, 49, 93, 32, 50, 53, 53, 10, 45, 99, 104, 97, 110, 110, 101,
  108, 115, 91, 49, 93, 32, 48, 10, 45, 105, 102, 32, 123, 36, 53, 125,
  10, 45, 107, 101, 101, 112, 91, 49, 93, 10, 45, 101, 108, 115, 101, 10,
  45, 97, 112, 112, 101, 110, 100, 32, 99, 10, 45, 101, 110, 100, 105, 102,
  10, 35, 64, 103, 105, 109, 112, 32, 83, 112, 111, 116, 32, 109, 97, 115,
  107, 32, 58, 32, 115, 112, 111, 116, 95, 109, 97, 115, 107, 44, 115, 112,
  111, 116, 95, 109, 97, 115, 107, 95, 112, 114, 101, 118, 105, 101, 119, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 111, 116,
  32, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 52,
  44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  84, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97,
  116, 32, 40, 56, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 77, 97, 115, 107, 32, 100, 105, 108, 97, 116,
  105, 111, 110, 32, 61, 32, 105, 110, 116, 32, 40, 53, 44, 48, 44, 49,
  48, 41, 10, 115, 112, 111, 116, 95, 109, 97, 115, 107, 58, 10, 45, 116,
  111, 95, 103, 114, 97, 121, 91, 45, 49, 93, 10, 45, 45, 114, 101, 115,
  105, 122, 101, 91, 48, 93, 32, 123, 119, 47, 36, 49, 125, 44, 123, 104,
  47, 36, 49, 125, 44, 49, 44, 51, 44, 50, 10, 45, 45, 105, 97, 105,
  110, 95, 112, 105, 120, 101, 108, 95, 100, 101, 110, 111, 105, 115, 101, 91,
  45, 49, 93, 32, 49, 44, 48, 10, 45, 115, 117, 98, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 10, 45, 97, 98, 115, 91, 45, 49, 93, 10, 45,
  114, 101, 109, 111, 118, 101, 91, 49, 93, 10, 45, 116, 104, 114, 101, 115,
  104, 111, 108, 100, 91, 45, 49, 93, 32, 36, 50, 37, 10, 45, 116, 111,
  95, 103, 114, 97, 121, 91, 45, 49, 93, 10, 45, 100, 105, 108, 97, 116,
  101, 95, 99, 105, 114, 99, 91, 45, 49, 93, 32, 36, 51, 10, 45, 110,
  32, 48, 44, 50, 53, 53, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45,
  49, 93, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125,
  44, 49, 44, 51, 44, 51, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93,
  10, 115, 112, 111, 116, 95, 109, 97, 115, 107, 95, 112, 114, 101, 118, 105,
  101, 119, 58, 10, 45, 45, 115, 112, 111, 116, 95, 109, 97, 115, 107, 32,
  36, 49, 44, 36, 50, 44, 36, 51, 10, 45, 110, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 10, 45, 97, 100, 100, 91, 48, 93, 32, 91, 49,
  93, 10, 45, 107, 101, 101, 112, 91, 48, 93, 10, 45, 110, 32, 48, 44,
  50, 53, 53, 10, 35, 64, 103, 105, 109, 112, 32, 83, 116, 97, 114, 32,
  116, 111, 110, 101, 32, 58, 32, 115, 116, 97, 114, 95, 116, 111, 110, 101,
  44, 32, 115, 116, 97, 114, 95, 116, 111, 110, 101, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 48, 48, 44, 49, 48, 44, 50, 48, 48,
  41, 10, 115, 116, 97, 114, 95, 116, 111, 110, 101, 58, 10, 115, 120, 49,
  61, 53, 48, 10, 115, 120, 50, 61, 49, 57, 52, 10, 115, 120, 51, 61,
  50, 56, 49, 10, 115, 120, 52, 61, 53, 49, 49, 10, 115, 120, 53, 61,
  55, 52, 50, 10, 115, 120, 54, 61, 56, 50, 57, 10, 115, 120, 55, 61,
  57, 55, 50, 10, 115, 120, 56, 61, 56, 50, 57, 10, 115, 120, 57, 61,
  55, 52, 50, 10, 115, 120, 49, 48, 61, 53, 49, 49, 10, 115, 120, 49,
  49, 61, 50, 56, 49, 10, 115, 120, 49, 50, 61, 49, 57, 50, 10, 115,
  121, 49, 61, 52, 53, 48, 10, 115, 121, 50, 61, 54, 51, 51, 10, 115,
  121, 51, 61, 56, 52, 57, 10, 115, 121, 52, 61, 56, 49, 55, 10, 115,
  121, 53, 61, 56, 52, 57, 10, 115, 121, 54, 61, 54, 51, 51, 10, 115,
  121, 55, 61, 52, 53, 48, 10, 115, 121, 56, 61, 50, 54, 55, 10, 115,
  121, 57, 61, 53, 48, 10, 115, 121, 49, 48, 61, 56, 51, 10, 115, 121,
  49, 49, 61, 53, 48, 10, 115, 121, 49, 50, 61, 50, 54, 55, 10, 108,
  101, 118, 101, 108, 61, 49, 48, 10, 45, 108, 117, 109, 105, 110, 97, 110,
  99, 101, 10, 45, 45, 108, 10, 45, 114, 109, 10, 50, 48, 48, 48, 44,
  50, 48, 48, 48, 44, 49, 44, 49, 44, 48, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 56, 10, 45, 112, 111, 108, 121, 103, 111, 110, 32, 49, 50,
  44, 36, 115, 120, 49, 44, 36, 115, 121, 49, 44, 36, 115, 120, 50, 44,
  36, 115, 121, 50, 44, 36, 115, 120, 51, 44, 36, 115, 121, 51, 44, 36,
  115, 120, 52, 44, 36, 115, 121, 52, 44, 36, 115, 120, 53, 44, 36, 115,
  121, 53, 44, 36, 115, 120, 54, 44, 36, 115, 121, 54, 44, 36, 115, 120,
  55, 44, 36, 115, 121, 55, 44, 36, 115, 120, 56, 44, 36, 115, 121, 56,
  44, 36, 115, 120, 57, 44, 36, 115, 121, 57, 44, 36, 115, 120, 49, 48,
  44, 36, 115, 121, 49, 48, 44, 36, 115, 120, 49, 49, 44, 36, 115, 121,
  49, 49, 44, 36, 115, 120, 49, 50, 44, 36, 115, 121, 49, 50, 44, 49,
  44, 36, 108, 101, 118, 101, 108, 10, 115, 120, 50, 61, 123, 36, 115, 120,
  50, 43, 52, 48, 125, 10, 115, 120, 54, 61, 123, 36, 115, 120, 54, 45,
  52, 48, 125, 10, 115, 120, 56, 61, 123, 36, 115, 120, 56, 45, 52, 48,
  125, 10, 115, 120, 49, 50, 61, 123, 36, 115, 120, 49, 50, 43, 52, 48,
  125, 10, 115, 121, 50, 61, 123, 36, 115, 121, 50, 45, 50, 51, 125, 10,
  115, 121, 52, 61, 123, 36, 115, 121, 52, 45, 52, 55, 125, 10, 115, 121,
  54, 61, 123, 36, 115, 121, 54, 45, 50, 51, 125, 10, 115, 121, 56, 61,
  123, 36, 115, 121, 56, 43, 50, 51, 125, 10, 115, 121, 49, 48, 61, 123,
  36, 115, 121, 49, 48, 43, 52, 55, 125, 10, 115, 121, 49, 50, 61, 123,
  36, 115, 121, 49, 50, 43, 50, 51, 125, 10, 108, 101, 118, 101, 108, 61,
  123, 36, 108, 101, 118, 101, 108, 43, 50, 53, 125, 10, 45, 100, 111, 110,
  101, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 114, 101, 115, 105,
  122, 101, 32, 50, 48, 48, 44, 50, 48, 48, 44, 49, 44, 49, 44, 51,
  10, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93, 32, 45, 54, 57, 44,
  45, 52, 48, 44, 48, 44, 48, 10, 45, 45, 115, 104, 105, 102, 116, 91,
  48, 93, 32, 45, 54, 57, 44, 52, 48, 44, 48, 44, 48, 10, 45, 45,
  115, 104, 105, 102, 116, 91, 48, 93, 32, 54, 57, 44, 45, 52, 48, 44,
  48, 44, 48, 10, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93, 32, 54,
  57, 44, 52, 48, 44, 48, 44, 48, 10, 45, 97, 100, 100, 10, 45, 99,
  114, 111, 112, 32, 53, 44, 53, 44, 49, 52, 50, 44, 56, 52, 10, 45,
  101, 110, 100, 108, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93,
  32, 36, 49, 44, 36, 49, 44, 49, 44, 49, 44, 50, 10, 119, 105, 100,
  116, 104, 61, 64, 123, 45, 49, 44, 119, 125, 10, 104, 101, 105, 103, 104,
  116, 61, 64, 123, 45, 49, 44, 104, 125, 10, 119, 95, 116, 105, 108, 101,
  115, 61, 123, 114, 111, 117, 110, 100, 40, 64, 123, 48, 44, 119, 125, 47,
  36, 119, 105, 100, 116, 104, 41, 125, 10, 104, 95, 116, 105, 108, 101, 115,
  61, 123, 114, 111, 117, 110, 100, 40, 64, 123, 48, 44, 104, 125, 47, 36,
  104, 101, 105, 103, 104, 116, 41, 125, 10, 116, 111, 116, 97, 108, 95, 116,
  105, 108, 101, 115, 61, 36, 104, 95, 116, 105, 108, 101, 115, 42, 36, 119,
  95, 116, 105, 108, 101, 115, 10, 91, 45, 49, 93, 120, 123, 36, 116, 111,
  116, 97, 108, 95, 116, 105, 108, 101, 115, 45, 49, 125, 10, 45, 97, 112,
  112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 91, 49, 45, 45, 49, 93,
  32, 36, 119, 95, 116, 105, 108, 101, 115, 44, 36, 104, 95, 116, 105, 108,
  101, 115, 10, 45, 101, 113, 117, 97, 108, 105, 122, 101, 91, 45, 49, 93,
  32, 50, 53, 54, 10, 45, 98, 108, 101, 110, 100, 32, 97, 108, 112, 104,
  97, 44, 48, 46, 53, 44, 49, 10, 45, 103, 116, 32, 49, 50, 56, 10,
  45, 109, 117, 108, 32, 50, 53, 53, 10, 35, 64, 103, 105, 109, 112, 32,
  84, 117, 114, 98, 117, 108, 101, 110, 116, 32, 104, 97, 108, 102, 116, 111,
  110, 101, 32, 58, 32, 105, 97, 105, 110, 95, 116, 117, 114, 98, 117, 108,
  101, 110, 116, 95, 104, 97, 108, 102, 116, 111, 110, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 44, 32, 105, 97, 105, 110, 95, 116, 117, 114, 98, 117,
  108, 101, 110, 116, 95, 104, 97, 108, 102, 116, 111, 110, 101, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116,
  117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 53, 44, 48,
  44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 48, 44, 48, 44, 52, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 79, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 56, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 118, 105, 97, 116, 105,
  111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 105, 108, 101, 32,
  115, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 53, 49, 50, 44, 49,
  50, 56, 44, 50, 48, 52, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 66, 108, 117, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  46, 55, 53, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 111, 108, 111, 117, 114, 32, 109, 111, 100, 101, 108, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 82, 71, 66, 34, 44, 34, 67,
  77, 89, 75, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 110, 104, 97, 110,
  99, 101, 32, 100, 101, 116, 97, 105, 108, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 105, 97, 105, 110, 95, 116,
  117, 114, 98, 117, 108, 101, 110, 116, 95, 104, 97, 108, 102, 116, 111, 110,
  101, 58, 10, 45, 105, 102, 32, 123, 36, 56, 62, 48, 125, 10, 45, 45,
  105, 97, 105, 110, 95, 102, 97, 115, 116, 95, 100, 101, 110, 111, 105, 115,
  101, 32, 36, 56, 44, 48, 44, 49, 44, 48, 44, 48, 10, 45, 115, 117,
  98, 91, 49, 93, 32, 91, 48, 93, 10, 45, 109, 117, 108, 91, 49, 93,
  32, 45, 49, 10, 45, 97, 100, 100, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 55, 61, 61, 49, 125, 10, 45, 114, 103, 98,
  50, 99, 109, 121, 107, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 55, 61, 61, 50, 125, 10, 45, 108, 117, 109, 105, 110, 97,
  110, 99, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 115, 112, 108, 105,
  116, 32, 99, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 111, 99, 97, 108, 91, 64, 123, 62, 44, 45, 49, 125, 93, 10, 45,
  45, 108, 91, 48, 93, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  48, 10, 116, 115, 105, 122, 101, 61, 123, 109, 105, 110, 40, 36, 53, 44,
  119, 44, 104, 41, 125, 10, 120, 116, 105, 108, 101, 61, 123, 40, 114, 111,
  117, 110, 100, 40, 119, 47, 36, 116, 115, 105, 122, 101, 41, 41, 43, 49,
  125, 10, 121, 116, 105, 108, 101, 61, 123, 40, 114, 111, 117, 110, 100, 40,
  104, 47, 36, 116, 115, 105, 122, 101, 41, 41, 43, 49, 125, 10, 36, 116,
  115, 105, 122, 101, 44, 36, 116, 115, 105, 122, 101, 10, 45, 103, 105, 109,
  112, 95, 115, 101, 97, 109, 108, 101, 115, 115, 95, 116, 117, 114, 98, 117,
  108, 101, 110, 99, 101, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50, 44,
  36, 51, 44, 36, 52, 44, 46, 50, 53, 44, 48, 10, 91, 45, 49, 93,
  120, 123, 36, 120, 116, 105, 108, 101, 42, 36, 121, 116, 105, 108, 101, 125,
  10, 45, 97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 91, 49,
  45, 45, 49, 93, 32, 36, 120, 116, 105, 108, 101, 44, 36, 121, 116, 105,
  108, 101, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 93, 10, 45,
  99, 114, 111, 112, 91, 45, 49, 93, 32, 48, 44, 48, 44, 64, 123, 48,
  44, 119, 125, 44, 64, 123, 48, 44, 104, 125, 10, 45, 107, 101, 101, 112,
  91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 10, 45, 98, 108, 117, 114,
  91, 45, 49, 93, 32, 36, 54, 10, 45, 101, 113, 117, 97, 108, 105, 122,
  101, 91, 45, 49, 93, 32, 50, 53, 54, 10, 45, 98, 108, 101, 110, 100,
  32, 97, 108, 112, 104, 97, 44, 48, 46, 53, 44, 49, 10, 45, 103, 116,
  32, 49, 50, 56, 10, 45, 109, 117, 108, 32, 50, 53, 53, 10, 45, 101,
  110, 100, 108, 111, 99, 97, 108, 32, 45, 100, 111, 110, 101, 10, 45, 97,
  112, 112, 101, 110, 100, 32, 99, 10, 45, 105, 102, 32, 123, 36, 55, 61,
  61, 49, 125, 10, 45, 99, 109, 121, 107, 50, 114, 103, 98, 10, 45, 101,
  110, 100, 105, 102, 10, 105, 97, 105, 110, 95, 116, 117, 114, 98, 117, 108,
  101, 110, 116, 95, 104, 97, 108, 102, 116, 111, 110, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 58, 10, 45, 105, 97, 105, 110, 95, 116, 117, 114, 98,
  117, 108, 101, 110, 116, 95, 104, 97, 108, 102, 116, 111, 110, 101, 32, 36,
  49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 64, 123, 48, 44, 119,
  125, 44, 36, 54, 44, 36, 55, 44, 36, 56, 10, 35, 64, 103, 105, 109,
  112, 32, 95, 10, 35, 64, 103, 105, 109, 112, 32, 60, 105, 62, 74, 38,
  35, 50, 51, 51, 59, 106, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62,
  10, 35, 64, 103, 105, 109, 112, 32, 51, 100, 32, 114, 101, 110, 100, 101,
  114, 105, 110, 103, 32, 58, 32, 106, 101, 106, 101, 95, 114, 101, 110, 100,
  101, 114, 51, 100, 44, 32, 106, 101, 106, 101, 95, 114, 101, 110, 100, 101,
  114, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 73, 110, 112, 117, 116, 32, 105, 109, 97, 103, 101,
  32, 61, 32, 102, 105, 108, 101, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 56, 44,
  52, 44, 49, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 81,
  117, 97, 108, 105, 116, 121, 32, 61, 32, 105, 110, 116, 40, 54, 44, 50,
  44, 49, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112,
  97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  65, 110, 103, 108, 101, 32, 120, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  50, 52, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 121, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 122, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 51, 48, 44, 48, 44, 51, 54, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 111, 111, 109, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 51, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 84, 111, 112, 32, 99, 111, 108, 111, 114, 32,
  61, 32, 99, 111, 108, 111, 114, 40, 51, 50, 44, 51, 50, 44, 54, 52,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66,
  111, 116, 116, 111, 109, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111,
  108, 111, 114, 40, 54, 52, 44, 49, 50, 56, 44, 57, 54, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 110, 100,
  101, 114, 32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108, 115, 101, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 60, 98, 62, 78, 111, 116, 101,
  58, 60, 47, 98, 62, 65, 100, 106, 117, 115, 116, 32, 116, 104, 101, 32,
  51, 68, 32, 118, 105, 101, 119, 32, 102, 105, 114, 115, 116, 32, 97, 110,
  100, 32, 116, 104, 101, 110, 32, 101, 110, 97, 98, 108, 101, 32, 114, 101,
  110, 100, 101, 114, 32, 116, 111, 32, 99, 111, 109, 112, 117, 116, 101, 32,
  116, 104, 101, 32, 118, 111, 108, 117, 109, 101, 32, 114, 101, 110, 100, 101,
  114, 105, 110, 103, 46, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32,
  60, 105, 62, 74, 38, 35, 50, 51, 51, 59, 114, 38, 35, 50, 52, 52,
  59, 109, 101, 32, 66, 111, 117, 108, 97, 110, 103, 101, 114, 60, 47, 105,
  62, 46, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 53, 47, 50, 57, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 106,
  101, 106, 101, 95, 114, 101, 110, 100, 101, 114, 51, 100, 58, 10, 87, 61,
  64, 123, 48, 44, 119, 125, 10, 49, 44, 50, 44, 49, 44, 52, 32, 45,
  102, 91, 45, 49, 93, 32, 36, 57, 44, 36, 49, 51, 44, 36, 49, 48,
  44, 36, 49, 52, 44, 36, 49, 49, 44, 36, 49, 53, 44, 36, 49, 50,
  44, 36, 49, 54, 32, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93,
  32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125, 44, 49,
  44, 52, 44, 53, 10, 45, 98, 108, 101, 110, 100, 32, 97, 108, 112, 104,
  97, 10, 45, 105, 32, 36, 49, 32, 45, 97, 91, 49, 45, 45, 49, 93,
  32, 122, 10, 45, 108, 91, 45, 49, 93, 10, 45, 105, 102, 32, 36, 49,
  55, 32, 45, 100, 105, 115, 112, 108, 97, 121, 118, 111, 108, 117, 109, 101,
  32, 36, 50, 44, 36, 51, 44, 36, 52, 32, 45, 101, 108, 115, 101, 32,
  32, 45, 98, 111, 117, 110, 100, 105, 110, 103, 98, 111, 120, 51, 100, 32,
  50, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 111, 116, 97, 116,
  101, 51, 100, 32, 48, 44, 48, 44, 49, 44, 36, 55, 10, 45, 114, 111,
  116, 97, 116, 101, 51, 100, 32, 48, 44, 49, 44, 48, 44, 36, 54, 10,
  45, 114, 111, 116, 97, 116, 101, 51, 100, 32, 49, 44, 48, 44, 48, 44,
  36, 53, 10, 45, 99, 51, 100, 32, 45, 110, 51, 100, 32, 45, 42, 51,
  100, 32, 123, 51, 42, 36, 87, 42, 36, 56, 47, 52, 125, 10, 45, 101,
  110, 100, 108, 10, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 48, 93,
  32, 91, 49, 93, 44, 53, 48, 37, 44, 53, 48, 37, 44, 48, 44, 49,
  10, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 114, 109, 91, 49, 93,
  10, 106, 101, 106, 101, 95, 114, 101, 110, 100, 101, 114, 51, 100, 95, 112,
  114, 101, 118, 105, 101, 119, 58, 10, 45, 106, 101, 106, 101, 95, 114, 101,
  110, 100, 101, 114, 51, 100, 32, 36, 42, 10, 35, 64, 103, 105, 109, 112,
  32, 68, 101, 99, 111, 110, 118, 111, 108, 118, 101, 32, 58, 32, 106, 101,
  106, 101, 95, 100, 101, 99, 111, 110, 118, 111, 108, 118, 101, 44, 32, 106,
  101, 106, 101, 95, 100, 101, 99, 111, 110, 118, 111, 108, 118, 101, 95, 112,
  114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116,
  40, 50, 48, 44, 49, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 108, 103, 111, 114, 105, 116, 104, 109, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 82, 105, 99, 104, 97, 114,
  100, 115, 111, 110, 45, 76, 117, 99, 121, 34, 44, 34, 71, 111, 108, 100,
  45, 77, 101, 105, 110, 101, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 51, 44, 34, 65, 108, 108, 34, 44, 34,
  82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101,
  100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44,
  34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34,
  44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34,
  44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34,
  98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117,
  101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44,
  34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 65,
  108, 112, 104, 97, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44,
  34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 32, 58, 32, 60, 105, 62, 74, 38, 35, 50, 51, 51, 59, 114,
  38, 35, 50, 52, 52, 59, 109, 101, 32, 66, 111, 117, 108, 97, 110, 103,
  101, 114, 60, 47, 105, 62, 46, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48,
  49, 47, 50, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 106, 101, 106, 101, 95, 100, 101, 99, 111, 110, 118, 111,
  108, 118, 101, 58, 10, 45, 114, 101, 118, 101, 114, 115, 101, 10, 45, 105,
  102, 32, 123, 36, 50, 61, 61, 49, 125, 10, 45, 97, 112, 112, 108, 121,
  95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 100, 101, 99, 111,
  110, 118, 111, 108, 118, 101, 95, 103, 111, 108, 100, 109, 101, 105, 110, 101,
  108, 32, 36, 49, 32, 45, 110, 91, 48, 93, 32, 48, 44, 50, 53, 53,
  34, 44, 36, 51, 44, 48, 10, 45, 101, 108, 115, 101, 10, 45, 97, 112,
  112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 100,
  101, 99, 111, 110, 118, 111, 108, 118, 101, 95, 114, 105, 99, 104, 97, 114,
  100, 115, 111, 110, 108, 117, 99, 121, 32, 36, 49, 32, 45, 110, 91, 48,
  93, 32, 48, 44, 50, 53, 53, 34, 44, 36, 51, 44, 48, 10, 45, 101,
  110, 100, 105, 102, 10, 106, 101, 106, 101, 95, 100, 101, 99, 111, 110, 118,
  111, 108, 118, 101, 95, 112, 114, 101, 118, 105, 101, 119, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 106, 101, 106, 101, 95, 100, 101, 99, 111, 110, 118, 111,
  108, 118, 101, 32, 36, 49, 44, 36, 50, 44, 36, 51, 34, 44, 36, 52,
  10, 35, 64, 103, 105, 109, 112, 32, 95, 10, 35, 64, 103, 105, 109, 112,
  32, 60, 105, 62, 74, 97, 121, 112, 114, 105, 99, 104, 60, 47, 105, 62,
  10, 35, 64, 103, 105, 109, 112, 32, 65, 98, 111, 117, 116, 32, 58, 32,
  95, 110, 111, 110, 101, 95, 44, 32, 106, 112, 114, 95, 97, 98, 111, 117,
  116, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 123, 34, 64, 106, 97, 121, 112, 114, 105, 99,
  104, 32, 102, 105, 108, 116, 101, 114, 115, 32, 102, 111, 114, 32, 60, 98,
  62, 71, 39, 77, 73, 67, 60, 47, 98, 62, 92, 110, 97, 114, 101, 32,
  112, 114, 111, 112, 111, 115, 101, 100, 32, 116, 111, 32, 121, 111, 117, 32,
  98, 121, 32, 74, 97, 109, 101, 115, 32, 80, 114, 105, 99, 104, 97, 114,
  100, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 115, 111, 117, 114, 99, 101,
  32, 99, 111, 100, 101, 32, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119,
  46, 104, 45, 112, 115, 46, 100, 101, 109, 111, 110, 46, 99, 111, 46, 117,
  107, 47, 71, 77, 73, 67, 47, 106, 97, 121, 112, 114, 105, 99, 104, 46,
  103, 109, 105, 99, 34, 125, 10, 106, 112, 114, 95, 97, 98, 111, 117, 116,
  32, 58, 32, 45, 103, 105, 109, 112, 95, 108, 111, 103, 111, 32, 34, 64,
  106, 97, 121, 112, 114, 105, 99, 104, 32, 102, 105, 108, 116, 101, 114, 115,
  34, 10, 35, 64, 103, 105, 109, 112, 32, 74, 112, 114, 32, 99, 111, 108,
  111, 117, 114, 105, 108, 108, 117, 115, 105, 111, 110, 32, 58, 32, 106, 112,
  114, 95, 99, 111, 108, 111, 117, 114, 105, 108, 108, 117, 115, 105, 111, 110,
  44, 106, 112, 114, 95, 99, 111, 108, 111, 117, 114, 105, 108, 108, 117, 115,
  105, 111, 110, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 114, 101, 99,
  114, 101, 97, 116, 101, 100, 32, 102, 114, 111, 109, 32, 97, 32, 74, 97,
  118, 97, 32, 101, 120, 97, 109, 112, 108, 101, 32, 104, 116, 116, 112, 58,
  47, 47, 102, 105, 106, 105, 46, 115, 99, 47, 119, 105, 107, 105, 47, 32,
  115, 101, 101, 32, 83, 112, 105, 114, 97, 108, 115, 32, 77, 97, 99, 114,
  111, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 114, 109,
  115, 32, 61, 32, 105, 110, 116, 40, 50, 44, 50, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 50, 53, 44, 49, 48, 44, 53, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 85, 112, 100, 97, 116, 101,
  97, 117, 116, 104, 111, 114, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 117, 112, 100, 97, 116, 101,
  32, 50, 48, 49, 51, 45, 70, 101, 98, 45, 48, 54, 32, 97, 117, 116,
  104, 111, 114, 32, 64, 106, 97, 121, 112, 114, 105, 99, 104, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 106, 112, 114, 95, 99, 111, 108, 111,
  117, 114, 105, 108, 108, 117, 115, 105, 111, 110, 32, 58, 10, 45, 118, 32,
  45, 10, 97, 114, 109, 61, 123, 36, 49, 42, 49, 46, 53, 45, 49, 125,
  10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 49, 44, 65, 61, 49,
  48, 43, 97, 116, 97, 110, 50, 40, 120, 45, 123, 119, 47, 50, 125, 44,
  121, 45, 123, 104, 47, 50, 125, 41, 42, 36, 97, 114, 109, 47, 112, 105,
  59, 82, 61, 115, 113, 114, 116, 40, 40, 120, 45, 123, 119, 47, 50, 125,
  41, 94, 50, 43, 40, 121, 45, 123, 104, 47, 50, 125, 41, 94, 50, 41,
  47, 36, 50, 43, 65, 59, 40, 105, 110, 116, 40, 65, 43, 82, 47, 36,
  97, 114, 109, 41, 43, 105, 110, 116, 40, 82, 42, 54, 45, 65, 47, 36,
  97, 114, 109, 41, 37, 50, 41, 37, 51, 10, 40, 50, 53, 48, 44, 50,
  48, 48, 44, 48, 94, 50, 48, 44, 50, 48, 48, 44, 49, 57, 48, 94,
  49, 54, 48, 44, 49, 48, 48, 44, 49, 53, 48, 41, 10, 45, 109, 97,
  112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 10, 45, 107, 91, 45, 50,
  93, 10, 45, 118, 32, 43, 10, 35, 64, 103, 105, 109, 112, 32, 74, 112,
  114, 32, 99, 111, 108, 116, 101, 120, 105, 110, 100, 101, 120, 32, 58, 32,
  106, 112, 114, 95, 99, 111, 108, 116, 101, 120, 105, 110, 100, 101, 120, 44,
  106, 112, 114, 95, 99, 111, 108, 116, 101, 120, 105, 110, 100, 101, 120, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 123, 34, 73, 110, 100, 101, 120, 32, 116,
  104, 101, 32, 105, 109, 97, 103, 101, 32, 117, 115, 105, 110, 103, 32, 105,
  116, 115, 32, 99, 111, 108, 111, 117, 114, 32, 99, 104, 97, 110, 110, 101,
  108, 115, 32, 112, 108, 117, 115, 32, 116, 104, 101, 32, 108, 111, 99, 97,
  108, 32, 97, 110, 97, 108, 121, 115, 105, 115, 32, 111, 102, 32, 105, 116,
  115, 32, 108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 99, 104, 97, 110,
  110, 101, 108, 46, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 73, 110, 115,
  112, 105, 114, 101, 100, 32, 98, 121, 32, 113, 117, 101, 115, 116, 105, 111,
  110, 115, 32, 111, 110, 32, 109, 97, 115, 107, 105, 110, 103, 32, 102, 111,
  114, 32, 115, 105, 109, 105, 108, 97, 114, 32, 116, 101, 120, 116, 117, 114,
  101, 115, 32, 97, 110, 100, 32, 104, 111, 119, 32, 116, 111, 32, 109, 97,
  107, 101, 32, 112, 111, 115, 116, 101, 114, 32, 97, 114, 116, 32, 102, 114,
  111, 109, 32, 97, 32, 112, 104, 111, 116, 111, 46, 34, 125, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 123, 34, 87, 97, 116, 99, 104, 32, 111, 117, 116, 32, 102, 111,
  114, 32, 74, 80, 69, 71, 32, 98, 108, 111, 99, 107, 45, 97, 114, 116,
  105, 102, 97, 99, 116, 115, 32, 105, 110, 32, 99, 111, 108, 111, 117, 114,
  32, 99, 104, 97, 110, 110, 101, 108, 115, 34, 125, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 117, 109, 98, 101, 114, 32, 111, 102, 32, 116,
  121, 112, 101, 115, 32, 61, 32, 105, 110, 116, 40, 53, 44, 51, 44, 50,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 49, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 53, 53, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 49, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 53, 53, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 88, 49, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 52, 53, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 89, 50, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 52, 53, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 70, 97, 99, 116, 111, 114, 32, 40, 120, 49, 44, 121,
  49, 41, 32, 118, 115, 32, 40, 120, 50, 44, 121, 50, 41, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 105, 115, 112, 108, 97, 121, 32, 40, 120,
  44, 121, 41, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 123, 34, 60, 115, 109, 97, 108, 108, 62, 76, 117, 109, 105,
  110, 97, 110, 99, 101, 32, 89, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108,
  97, 99, 107, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 48, 53,
  44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77,
  105, 100, 116, 111, 110, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 72, 105, 103, 104, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 57, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 123, 34, 60, 115, 109, 97, 108, 108, 62, 67, 111, 108, 111, 117,
  114, 32, 38, 97, 109, 112, 59, 32, 84, 101, 120, 116, 117, 114, 101, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 111, 108, 111, 117, 114, 32, 115, 109, 111, 111, 116, 104,
  105, 110, 103, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44,
  48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 115, 109, 97,
  108, 108, 62, 76, 111, 99, 97, 108, 108, 121, 32, 65, 118, 101, 114, 97,
  103, 101, 32, 71, 114, 97, 100, 105, 101, 110, 116, 32, 78, 111, 114, 109,
  32, 111, 114, 32, 86, 97, 114, 105, 97, 110, 99, 101, 32, 102, 114, 111,
  109, 32, 76, 117, 109, 105, 110, 97, 110, 99, 101, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 85,
  115, 101, 32, 103, 114, 97, 100, 105, 101, 110, 116, 32, 110, 111, 114, 109,
  32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 76, 111, 99, 97, 108, 32, 115, 105, 122, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 50, 44, 49, 44, 57, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 87, 101, 105, 103, 104, 116, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 55, 44, 48, 46, 50, 44, 50, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 85, 112, 100, 97, 116, 101,
  97, 117, 116, 104, 111, 114, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 117, 112, 100, 97, 116, 101,
  32, 50, 48, 49, 51, 45, 77, 97, 114, 45, 49, 55, 32, 97, 117, 116,
  104, 111, 114, 32, 64, 106, 97, 121, 112, 114, 105, 99, 104, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 106, 112, 114, 95, 99, 111, 108, 116,
  101, 120, 105, 110, 100, 101, 120, 32, 58, 32, 45, 115, 107, 105, 112, 32,
  36, 123, 55, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  73, 110, 100, 101, 120, 32, 99, 111, 108, 111, 117, 114, 32, 97, 110, 100,
  32, 116, 101, 120, 116, 117, 114, 101, 32, 111, 102, 32, 105, 109, 97, 103,
  101, 36, 63, 32, 119, 105, 116, 104, 32, 36, 49, 32, 116, 121, 112, 101,
  115, 32, 40, 36, 50, 44, 36, 51, 41, 32, 118, 32, 40, 36, 52, 44,
  36, 53, 41, 32, 120, 32, 36, 54, 32, 97, 110, 100, 32, 83, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 36, 56, 32, 66, 108, 97, 99, 107,
  32, 36, 57, 32, 77, 105, 100, 32, 36, 49, 48, 32, 87, 104, 105, 116,
  101, 32, 36, 49, 49, 34, 10, 45, 118, 32, 45, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 10, 45, 108, 91, 36, 60, 93, 10, 45, 114,
  103, 98, 50, 121, 117, 118, 32, 45, 115, 32, 99, 10, 45, 45, 98, 91,
  45, 51, 93, 32, 36, 56, 10, 45, 45, 103, 101, 91, 45, 49, 93, 32,
  36, 49, 48, 10, 45, 45, 108, 101, 91, 45, 50, 93, 32, 36, 49, 49,
  10, 45, 103, 101, 91, 45, 51, 93, 32, 36, 57, 10, 45, 98, 91, 45,
  53, 44, 45, 52, 93, 32, 36, 49, 50, 10, 45, 105, 102, 32, 36, 49,
  51, 10, 45, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 54, 93, 32,
  120, 121, 44, 52, 10, 45, 97, 91, 45, 55, 44, 45, 54, 93, 32, 99,
  10, 45, 110, 111, 114, 109, 91, 45, 54, 93, 10, 45, 98, 91, 45, 54,
  93, 32, 36, 49, 52, 10, 45, 101, 108, 115, 101, 10, 45, 45, 98, 91,
  45, 54, 93, 32, 123, 36, 49, 52, 42, 48, 46, 53, 125, 10, 45, 45,
  91, 45, 55, 44, 45, 49, 93, 10, 45, 115, 113, 114, 91, 45, 54, 93,
  10, 45, 98, 91, 45, 54, 93, 32, 123, 36, 49, 52, 125, 10, 45, 115,
  113, 114, 116, 91, 45, 54, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  110, 91, 45, 54, 93, 32, 48, 44, 49, 10, 45, 42, 91, 45, 54, 93,
  32, 36, 49, 53, 10, 45, 45, 45, 91, 45, 54, 93, 32, 123, 64, 123,
  45, 54, 44, 105, 40, 48, 46, 48, 49, 42, 119, 42, 36, 50, 44, 48,
  46, 48, 49, 42, 104, 42, 36, 51, 41, 125, 125, 10, 45, 42, 91, 45,
  49, 93, 32, 123, 64, 123, 45, 49, 44, 105, 40, 48, 46, 48, 49, 42,
  119, 42, 36, 52, 44, 48, 46, 48, 49, 42, 104, 42, 36, 53, 41, 125,
  125, 10, 45, 45, 45, 91, 45, 54, 93, 32, 123, 64, 123, 45, 54, 44,
  105, 40, 48, 46, 48, 49, 42, 119, 42, 36, 50, 44, 48, 46, 48, 49,
  42, 104, 42, 36, 51, 41, 125, 125, 10, 45, 42, 91, 45, 49, 93, 32,
  123, 64, 123, 45, 49, 44, 105, 40, 48, 46, 48, 49, 42, 119, 42, 36,
  52, 44, 48, 46, 48, 49, 42, 104, 42, 36, 53, 41, 125, 125, 10, 45,
  43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 45, 45, 91, 45, 53, 93,
  32, 123, 64, 123, 45, 53, 44, 105, 40, 48, 46, 48, 49, 42, 119, 42,
  36, 50, 44, 48, 46, 48, 49, 42, 104, 42, 36, 51, 41, 125, 125, 10,
  45, 42, 91, 45, 49, 93, 32, 123, 64, 123, 45, 49, 44, 105, 40, 48,
  46, 48, 49, 42, 119, 42, 36, 52, 44, 48, 46, 48, 49, 42, 104, 42,
  36, 53, 41, 125, 125, 10, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10,
  45, 47, 91, 45, 49, 93, 32, 123, 64, 123, 45, 49, 44, 105, 40, 48,
  46, 48, 49, 42, 119, 42, 36, 52, 44, 48, 46, 48, 49, 42, 104, 42,
  36, 53, 41, 125, 43, 48, 46, 48, 48, 48, 48, 49, 125, 10, 45, 99,
  91, 45, 49, 93, 32, 48, 44, 49, 10, 45, 42, 91, 45, 49, 93, 32,
  36, 54, 10, 45, 97, 91, 45, 55, 45, 45, 53, 44, 45, 49, 93, 32,
  99, 10, 45, 45, 91, 45, 52, 93, 32, 50, 10, 45, 42, 91, 45, 52,
  44, 45, 49, 93, 10, 45, 43, 91, 45, 51, 93, 32, 50, 10, 45, 42,
  91, 45, 51, 44, 45, 50, 93, 10, 45, 45, 99, 111, 108, 111, 114, 109,
  97, 112, 91, 45, 50, 93, 32, 36, 49, 44, 49, 44, 49, 10, 45, 105,
  110, 100, 101, 120, 91, 45, 51, 93, 32, 91, 45, 49, 93, 10, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 42, 91, 45, 50, 93, 32, 50, 10, 45,
  43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 110, 32, 48, 44, 50, 53,
  53, 10, 45, 116, 111, 95, 114, 103, 98, 10, 45, 105, 102, 32, 36, 55,
  10, 45, 99, 105, 114, 99, 108, 101, 32, 36, 50, 37, 44, 36, 51, 37,
  44, 49, 37, 44, 49, 44, 44, 54, 52, 44, 49, 50, 56, 44, 50, 53,
  53, 10, 45, 99, 105, 114, 99, 108, 101, 32, 36, 52, 37, 44, 36, 53,
  37, 44, 49, 37, 44, 49, 44, 44, 50, 53, 53, 44, 54, 52, 44, 49,
  50, 56, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 10,
  45, 100, 111, 110, 101, 10, 45, 118, 32, 43, 10, 35, 64, 103, 105, 109,
  112, 32, 74, 112, 114, 32, 100, 101, 99, 105, 109, 97, 116, 101, 32, 58,
  32, 106, 112, 114, 95, 100, 101, 99, 105, 109, 97, 116, 101, 44, 106, 112,
  114, 95, 100, 101, 99, 105, 109, 97, 116, 101, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 123, 34, 82, 101, 115, 99, 97, 108, 101, 32, 105, 110, 32, 108,
  105, 110, 101, 97, 114, 32, 82, 71, 66, 32, 115, 112, 97, 99, 101, 32,
  98, 121, 32, 99, 114, 111, 112, 112, 105, 110, 103, 32, 116, 104, 101, 32,
  102, 114, 101, 113, 117, 101, 110, 99, 121, 32, 100, 111, 109, 97, 105, 110,
  32, 119, 101, 105, 103, 104, 116, 101, 100, 34, 125, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  123, 34, 116, 111, 32, 100, 101, 99, 114, 101, 97, 115, 101, 32, 104, 105,
  103, 104, 32, 102, 114, 101, 113, 117, 101, 110, 99, 121, 32, 97, 107, 105,
  110, 32, 116, 111, 32, 76, 97, 110, 99, 122, 111, 115, 32, 119, 105, 110,
  100, 111, 119, 32, 111, 110, 32, 83, 105, 110, 99, 32, 108, 111, 98, 101,
  115, 46, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 84, 104, 105, 115, 32,
  102, 105, 108, 116, 101, 114, 32, 109, 97, 121, 32, 99, 111, 114, 114, 117,
  112, 116, 32, 116, 104, 101, 32, 97, 108, 112, 104, 97, 32, 99, 104, 97,
  110, 110, 101, 108, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 72, 105, 103,
  104, 32, 115, 104, 97, 114, 112, 110, 101, 115, 115, 32, 106, 117, 115, 116,
  32, 99, 114, 111, 112, 115, 32, 102, 114, 101, 113, 117, 101, 110, 99, 121,
  32, 97, 110, 100, 32, 103, 105, 118, 101, 115, 32, 98, 97, 100, 32, 104,
  97, 108, 111, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68,
  111, 119, 110, 115, 97, 109, 112, 108, 101, 32, 115, 99, 97, 108, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 51, 55, 53, 44, 48, 46,
  49, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104,
  97, 114, 112, 110, 101, 115, 115, 32, 102, 97, 99, 116, 111, 114, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 50, 44, 49, 46, 53, 44, 52, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 85, 112, 100, 97, 116, 101, 97,
  117, 116, 104, 111, 114, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 117, 112, 100, 97, 116, 101, 32,
  50, 48, 49, 51, 45, 74, 117, 110, 45, 50, 52, 32, 97, 117, 116, 104,
  111, 114, 32, 64, 106, 97, 121, 112, 114, 105, 99, 104, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 106, 112, 114, 95, 100, 101, 99, 105, 109,
  97, 116, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  48, 46, 51, 55, 53, 125, 44, 36, 123, 50, 61, 53, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 68, 101, 99, 105, 109, 97, 116, 101, 32,
  115, 99, 97, 108, 101, 32, 36, 49, 32, 115, 104, 97, 114, 112, 110, 101,
  115, 115, 32, 36, 50, 34, 10, 45, 118, 32, 45, 10, 45, 115, 114, 103,
  98, 50, 114, 103, 98, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  10, 45, 108, 91, 36, 60, 93, 10, 110, 119, 61, 123, 114, 111, 117, 110,
  100, 40, 36, 49, 42, 119, 47, 50, 41, 125, 10, 110, 104, 61, 123, 114,
  111, 117, 110, 100, 40, 36, 49, 42, 104, 47, 50, 41, 125, 10, 115, 99,
  61, 123, 52, 42, 36, 110, 119, 47, 119, 42, 36, 110, 104, 47, 104, 125,
  10, 109, 105, 100, 61, 123, 114, 111, 117, 110, 100, 40, 48, 46, 53, 47,
  36, 49, 45, 48, 46, 53, 41, 125, 10, 45, 115, 104, 105, 102, 116, 32,
  45, 36, 109, 105, 100, 44, 45, 36, 109, 105, 100, 10, 45, 102, 102, 116,
  10, 45, 115, 104, 105, 102, 116, 32, 36, 110, 119, 44, 36, 110, 104, 44,
  48, 44, 48, 44, 50, 10, 45, 122, 32, 48, 44, 48, 44, 123, 50, 42,
  36, 110, 119, 45, 49, 125, 44, 123, 50, 42, 36, 110, 104, 45, 49, 125,
  10, 45, 115, 104, 105, 102, 116, 32, 45, 36, 110, 119, 44, 45, 36, 110,
  104, 44, 48, 44, 48, 44, 50, 10, 45, 102, 32, 105, 42, 109, 105, 110,
  40, 49, 44, 97, 98, 115, 40, 50, 42, 120, 47, 119, 45, 49, 41, 42,
  36, 50, 41, 42, 109, 105, 110, 40, 49, 44, 97, 98, 115, 40, 50, 42,
  121, 47, 104, 45, 49, 41, 42, 36, 50, 41, 10, 45, 105, 102, 102, 116,
  10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 42, 32, 36, 115, 99, 10,
  45, 101, 110, 100, 108, 10, 45, 100, 111, 110, 101, 10, 45, 114, 103, 98,
  50, 115, 114, 103, 98, 10, 45, 118, 32, 43, 10, 116, 105, 102, 102, 51,
  100, 32, 58, 32, 45, 101, 91, 94, 45, 49, 93, 32, 34, 76, 111, 97,
  100, 32, 116, 104, 101, 32, 102, 105, 108, 101, 32, 36, 49, 32, 97, 115,
  32, 97, 32, 51, 68, 32, 105, 109, 97, 103, 101, 34, 10, 45, 118, 32,
  45, 32, 110, 61, 64, 35, 10, 45, 105, 32, 36, 49, 32, 45, 97, 91,
  123, 36, 110, 125, 45, 45, 49, 93, 32, 122, 10, 45, 118, 32, 43, 10,
  116, 111, 102, 102, 51, 100, 32, 58, 32, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 83, 97, 118, 101, 32, 116, 104, 101, 32, 51, 68, 32, 105, 109,
  97, 103, 101, 32, 97, 115, 32, 97, 32, 116, 105, 102, 102, 32, 102, 105,
  108, 101, 34, 10, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 10, 45, 111, 91, 36, 62, 93, 32, 64, 123, 34, 45, 102,
  105, 108, 101, 110, 97, 109, 101, 32, 92, 34, 36, 49, 92, 34, 44, 34,
  36, 62, 125, 10, 45, 100, 111, 110, 101, 10, 45, 118, 32, 43, 10, 98,
  111, 117, 110, 100, 105, 110, 103, 98, 111, 120, 51, 100, 32, 58, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 48, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 51, 68, 32, 66, 111, 117, 110, 100, 105, 110,
  103, 32, 98, 111, 120, 34, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 98, 111, 120, 51, 100, 32,
  64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125, 44, 64, 123,
  48, 44, 100, 125, 32, 45, 112, 114, 105, 109, 105, 116, 105, 118, 101, 115,
  51, 100, 91, 45, 49, 93, 32, 49, 32, 32, 45, 111, 112, 97, 99, 105,
  116, 121, 51, 100, 91, 45, 49, 93, 32, 46, 50, 53, 10, 45, 105, 102,
  32, 123, 36, 49, 62, 48, 125, 10, 45, 112, 108, 97, 110, 101, 51, 100,
  32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48, 44, 104, 125, 44, 36,
  49, 44, 123, 114, 111, 117, 110, 100, 40, 64, 123, 48, 44, 104, 125, 47,
  64, 123, 48, 44, 119, 125, 42, 36, 49, 41, 125, 32, 45, 112, 114, 105,
  109, 105, 116, 105, 118, 101, 115, 51, 100, 91, 45, 49, 93, 32, 49, 32,
  45, 111, 112, 97, 99, 105, 116, 121, 51, 100, 91, 45, 49, 93, 32, 46,
  49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 48, 93, 10,
  45, 43, 51, 100, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 114, 101, 110, 100, 101, 114, 118, 111, 108, 117, 109, 101, 58, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 49, 61, 56, 125, 44, 36, 123, 50, 61,
  53, 125, 44, 36, 123, 51, 61, 46, 49, 125, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 80, 115, 101, 117, 100, 111, 32, 118, 111, 108, 117, 109,
  105, 99, 32, 114, 101, 110, 100, 101, 114, 105, 110, 103, 32, 111, 102, 32,
  105, 109, 97, 103, 101, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101, 32,
  36, 49, 32, 113, 117, 97, 108, 105, 116, 121, 32, 36, 50, 32, 97, 110,
  100, 32, 111, 112, 97, 99, 116, 105, 121, 32, 36, 51, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 109, 105, 114, 114, 111, 114, 32, 120, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 36, 50, 10, 45, 45, 108, 91, 48, 93,
  10, 45, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100, 50, 32, 123, 40,
  36, 62, 43, 49, 41, 47, 40, 36, 50, 43, 49, 41, 42, 40, 105, 77,
  45, 105, 109, 41, 43, 105, 109, 125, 44, 123, 40, 36, 62, 43, 50, 41,
  47, 40, 36, 50, 43, 49, 41, 42, 40, 105, 77, 45, 105, 109, 41, 43,
  105, 109, 43, 49, 125, 10, 45, 42, 91, 45, 50, 44, 45, 49, 93, 10,
  45, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 51, 100, 32, 45, 103,
  97, 117, 115, 115, 105, 97, 110, 115, 51, 100, 32, 36, 49, 44, 123, 36,
  51, 42, 40, 36, 60, 43, 49, 41, 47, 36, 50, 125, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 93, 32,
  45, 43, 51, 100, 32, 45, 109, 100, 51, 100, 32, 45, 49, 32, 32, 45,
  43, 51, 100, 32, 123, 46, 53, 125, 44, 123, 46, 53, 125, 44, 123, 46,
  53, 125, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 100, 105, 115, 112, 108, 97, 121, 118, 111, 108, 117, 109,
  101, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 56, 125, 44,
  36, 123, 50, 61, 53, 125, 44, 36, 123, 51, 61, 46, 49, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 100, 105, 115, 112, 108, 97, 121, 95,
  118, 111, 108, 117, 109, 101, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101,
  32, 36, 49, 32, 113, 117, 97, 108, 105, 116, 121, 32, 36, 50, 32, 97,
  110, 100, 32, 111, 112, 97, 99, 116, 105, 121, 32, 36, 51, 34, 10, 45,
  118, 32, 45, 10, 45, 45, 98, 111, 117, 110, 100, 105, 110, 103, 98, 111,
  120, 51, 100, 32, 50, 48, 10, 45, 114, 101, 110, 100, 101, 114, 118, 111,
  108, 117, 109, 101, 91, 48, 93, 32, 36, 49, 44, 36, 50, 44, 36, 51,
  10, 45, 43, 51, 100, 10, 45, 98, 97, 99, 107, 103, 114, 111, 117, 110,
  100, 51, 100, 32, 48, 44, 48, 44, 48, 10, 45, 118, 32, 43, 10, 118,
  105, 101, 119, 51, 100, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  49, 61, 50, 53, 125, 44, 36, 123, 50, 61, 45, 49, 50, 48, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 51,
  68, 32, 118, 105, 101, 119, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45,
  114, 111, 116, 97, 116, 101, 51, 100, 32, 48, 44, 48, 44, 49, 44, 36,
  49, 32, 45, 114, 111, 116, 97, 116, 101, 51, 100, 32, 49, 44, 48, 44,
  48, 44, 36, 50, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 99, 111, 108, 111, 114, 100, 101, 112, 116, 104,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 53, 125, 10, 45,
  101, 32, 34, 99, 111, 108, 111, 114, 100, 101, 112, 116, 104, 32, 99, 111,
  100, 105, 110, 103, 32, 119, 105, 116, 104, 32, 108, 117, 116, 32, 36, 49,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 95, 99, 111, 108, 111, 114,
  100, 101, 112, 116, 104, 95, 118, 111, 108, 117, 109, 101, 32, 36, 49, 32,
  45, 115, 32, 122, 32, 45, 43, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 95, 99, 111, 108, 111, 114, 100,
  101, 112, 116, 104, 95, 118, 111, 108, 117, 109, 101, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 49, 61, 53, 125, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 105, 32, 91, 48, 93, 32, 45, 102, 91, 45, 49, 93, 32, 39,
  122, 47, 40, 100, 45, 49, 41, 42, 50, 53, 53, 39, 32, 45, 109, 97,
  112, 91, 45, 49, 93, 32, 36, 49, 32, 45, 114, 101, 115, 105, 122, 101,
  91, 48, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 51, 32, 45, 42, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 99, 111, 108, 111, 114, 100, 101,
  112, 116, 104, 95, 115, 99, 97, 108, 101, 58, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 49, 61, 53, 125, 10, 49, 48, 44, 64, 123, 48, 44, 104,
  45, 49, 48, 125, 32, 45, 102, 91, 45, 49, 93, 32, 39, 40, 104, 45,
  121, 41, 47, 40, 104, 45, 49, 41, 42, 50, 53, 53, 39, 32, 45, 109,
  97, 112, 91, 45, 49, 93, 32, 36, 49, 32, 45, 102, 114, 97, 109, 101,
  91, 45, 49, 93, 32, 53, 44, 53, 44, 48, 44, 48, 44, 48, 10, 108,
  117, 99, 97, 115, 95, 107, 97, 110, 97, 100, 101, 58, 10, 45, 115, 116,
  114, 117, 99, 116, 117, 114, 101, 116, 101, 110, 115, 111, 114, 115, 32, 49,
  32, 45, 98, 108, 117, 114, 95, 120, 121, 32, 36, 49, 10, 45, 45, 108,
  32, 45, 115, 32, 99, 32, 45, 114, 109, 91, 48, 44, 45, 49, 93, 32,
  45, 42, 91, 49, 44, 50, 93, 32, 45, 42, 91, 48, 44, 50, 93, 32,
  45, 114, 101, 118, 101, 114, 115, 101, 32, 45, 45, 32, 45, 101, 110, 100,
  108, 10, 45, 45, 108, 91, 48, 93, 32, 45, 115, 32, 99, 32, 45, 114,
  109, 91, 51, 44, 53, 93, 32, 45, 42, 91, 48, 44, 51, 93, 32, 45,
  42, 91, 49, 44, 50, 93, 32, 45, 45, 32, 45, 101, 110, 100, 108, 10,
  45, 108, 91, 48, 93, 32, 45, 115, 32, 99, 32, 45, 114, 109, 91, 50,
  44, 52, 44, 53, 93, 32, 45, 42, 91, 48, 44, 50, 93, 32, 45, 115,
  113, 114, 91, 49, 93, 32, 45, 45, 32, 45, 101, 110, 100, 108, 10, 45,
  47, 91, 49, 44, 50, 93, 32, 91, 48, 93, 32, 32, 45, 114, 109, 91,
  48, 93, 32, 45, 97, 32, 99, 10, 100, 101, 116, 101, 99, 116, 101, 118,
  101, 110, 116, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49,
  61, 49, 125, 44, 36, 123, 50, 61, 49, 125, 44, 36, 123, 51, 61, 57,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 100, 101, 116, 101, 99,
  116, 32, 101, 118, 101, 110, 116, 115, 32, 119, 105, 116, 104, 32, 115, 99,
  97, 108, 101, 95, 120, 121, 32, 36, 49, 32, 115, 99, 97, 108, 101, 95,
  122, 32, 36, 50, 32, 97, 110, 100, 32, 116, 104, 114, 101, 115, 104, 111,
  108, 100, 32, 36, 51, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 98,
  108, 117, 114, 95, 120, 121, 32, 36, 49, 32, 45, 98, 108, 117, 114, 95,
  122, 32, 36, 50, 32, 45, 115, 116, 114, 117, 99, 116, 117, 114, 101, 116,
  101, 110, 115, 111, 114, 115, 32, 45, 98, 108, 117, 114, 95, 120, 121, 32,
  36, 49, 32, 45, 98, 108, 117, 114, 95, 122, 32, 36, 50, 10, 45, 115,
  32, 122, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 32, 45, 101, 105, 103, 101, 110, 32, 45, 107, 91, 48,
  93, 32, 45, 115, 32, 99, 32, 45, 107, 91, 50, 93, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 97, 32, 122, 10, 116, 104,
  114, 101, 115, 61, 123, 64, 123, 48, 44, 105, 97, 125, 43, 36, 51, 42,
  115, 113, 114, 116, 40, 64, 123, 48, 44, 105, 118, 125, 41, 125, 10, 45,
  45, 109, 97, 120, 95, 112, 97, 116, 99, 104, 91, 48, 93, 32, 56, 32,
  45, 116, 104, 114, 101, 115, 104, 111, 108, 100, 91, 48, 93, 32, 36, 116,
  104, 114, 101, 115, 32, 45, 42, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 100, 101, 116, 101, 99, 116, 95,
  115, 112, 111, 116, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  49, 61, 49, 125, 44, 36, 123, 50, 61, 52, 125, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 100, 101, 116, 101, 99, 116, 32, 101, 118, 101, 110,
  116, 115, 32, 119, 105, 116, 104, 32, 115, 99, 97, 108, 101, 32, 36, 49,
  32, 97, 110, 100, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 36,
  50, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 98, 108, 117, 114, 32,
  36, 49, 32, 45, 45, 98, 108, 117, 114, 32, 36, 49, 32, 45, 45, 10,
  116, 104, 114, 101, 115, 61, 123, 36, 50, 42, 64, 123, 45, 109, 97, 100,
  91, 48, 93, 125, 125, 10, 45, 45, 109, 97, 120, 95, 112, 97, 116, 99,
  104, 91, 48, 93, 32, 51, 32, 45, 45, 116, 104, 114, 101, 115, 104, 111,
  108, 100, 91, 48, 93, 32, 36, 116, 104, 114, 101, 115, 32, 45, 42, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 112, 111, 105, 110, 116, 115, 99, 111, 111, 114, 100, 105, 110, 97, 116,
  101, 115, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 114, 101,
  116, 117, 114, 110, 32, 116, 104, 101, 32, 108, 105, 115, 116, 32, 111, 102,
  32, 112, 111, 105, 110, 116, 115, 32, 105, 110, 32, 116, 104, 101, 32, 105,
  109, 97, 103, 101, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 112, 111,
  105, 110, 116, 99, 108, 111, 117, 100, 51, 100, 32, 45, 115, 51, 100, 32,
  45, 107, 91, 50, 93, 32, 45, 115, 112, 108, 105, 116, 32, 121, 44, 123,
  104, 47, 51, 125, 32, 45, 97, 32, 120, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 112, 97, 105, 114, 95,
  100, 105, 115, 116, 97, 110, 99, 101, 58, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 32, 121,
  32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 123, 49, 44, 119, 125,
  10, 45, 45, 108, 91, 48, 44, 49, 93, 10, 45, 115, 104, 105, 102, 116,
  91, 49, 93, 32, 36, 62, 44, 48, 44, 48, 44, 48, 44, 50, 10, 45,
  45, 32, 45, 110, 111, 114, 109, 10, 45, 101, 110, 100, 108, 10, 45, 100,
  111, 110, 101, 10, 45, 114, 109, 91, 48, 44, 49, 93, 10, 45, 97, 32,
  121, 10, 45, 115, 32, 120, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 115, 104, 105, 102, 116, 91, 36, 62, 93, 32, 48, 44, 36,
  62, 44, 48, 44, 48, 44, 50, 32, 45, 100, 111, 110, 101, 32, 45, 97,
  32, 120, 10, 99, 105, 114, 99, 108, 101, 115, 32, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 49, 61, 49, 48, 125, 44, 36, 123, 50, 61, 49,
  125, 44, 36, 123, 51, 61, 50, 53, 53, 125, 44, 36, 123, 52, 61, 50,
  53, 53, 125, 44, 36, 123, 53, 61, 50, 53, 53, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 100, 114, 97, 119, 32, 64, 123, 49, 44, 119,
  125, 32, 99, 105, 114, 99, 108, 101, 115, 32, 111, 110, 32, 105, 109, 97,
  103, 101, 32, 91, 48, 93, 34, 10, 45, 118, 32, 45, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 64, 123, 49, 44, 119, 125, 125, 10, 45, 105,
  102, 32, 123, 64, 123, 48, 44, 100, 125, 62, 49, 125, 10, 120, 61, 123,
  64, 123, 49, 44, 105, 40, 36, 62, 44, 48, 41, 125, 125, 32, 121, 61,
  123, 64, 123, 49, 44, 105, 40, 36, 62, 44, 49, 41, 125, 125, 32, 122,
  61, 123, 64, 123, 49, 44, 105, 40, 36, 62, 44, 50, 41, 125, 125, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 123, 48, 44, 115, 125, 32, 45,
  115, 104, 91, 48, 93, 32, 36, 122, 44, 36, 122, 44, 36, 62, 32, 45,
  101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 120, 44, 36,
  121, 44, 36, 49, 44, 36, 49, 44, 48, 44, 36, 50, 44, 48, 120, 70,
  70, 70, 70, 70, 70, 44, 36, 51, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 115, 101, 10, 120, 61, 64,
  123, 49, 44, 105, 40, 36, 62, 44, 48, 41, 125, 32, 121, 61, 64, 123,
  49, 44, 105, 40, 36, 62, 44, 49, 41, 125, 10, 45, 101, 108, 108, 105,
  112, 115, 101, 91, 48, 93, 32, 36, 120, 44, 36, 121, 44, 36, 49, 44,
  36, 49, 44, 48, 44, 36, 50, 44, 48, 120, 70, 70, 70, 70, 70, 70,
  44, 36, 51, 44, 36, 52, 44, 36, 53, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 100, 111, 110, 101, 10, 97, 100, 100, 116, 101, 120, 116, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 50, 49, 125, 44, 36,
  123, 50, 61, 49, 50, 56, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 97, 100, 100, 32, 116, 101, 120, 116, 32, 108, 97, 98, 101, 108, 115,
  32, 102, 114, 111, 109, 32, 64, 123, 49, 44, 119, 125, 32, 112, 111, 105,
  110, 116, 115, 34, 10, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 64, 123, 49, 44, 119, 125, 125, 10, 45, 105, 102, 32, 123,
  64, 123, 48, 44, 100, 125, 62, 49, 125, 10, 120, 61, 123, 64, 123, 49,
  44, 105, 40, 36, 62, 44, 48, 41, 125, 125, 32, 121, 61, 123, 64, 123,
  49, 44, 105, 40, 36, 62, 44, 49, 41, 125, 125, 32, 122, 61, 123, 64,
  123, 49, 44, 105, 40, 36, 62, 44, 50, 41, 125, 125, 32, 105, 100, 61,
  123, 36, 62, 43, 49, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  123, 48, 44, 115, 125, 32, 45, 115, 104, 91, 48, 93, 32, 36, 122, 44,
  36, 122, 44, 36, 62, 32, 45, 116, 101, 120, 116, 91, 45, 49, 93, 32,
  36, 105, 100, 44, 36, 120, 44, 36, 121, 44, 50, 49, 44, 46, 53, 44,
  36, 50, 44, 36, 50, 44, 36, 50, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 100, 111, 110, 101, 10, 45, 101, 108, 115, 101, 10, 120, 61, 64,
  123, 49, 44, 105, 40, 36, 62, 44, 48, 41, 125, 32, 121, 61, 64, 123,
  49, 44, 105, 40, 36, 62, 44, 49, 41, 125, 32, 105, 100, 61, 123, 36,
  62, 43, 49, 125, 10, 45, 116, 101, 120, 116, 91, 48, 93, 32, 36, 105,
  100, 44, 36, 120, 44, 36, 121, 44, 50, 49, 44, 46, 53, 44, 36, 50,
  44, 36, 50, 44, 36, 50, 10, 45, 101, 110, 100, 105, 102, 10, 45, 100,
  111, 110, 101, 10, 99, 114, 111, 112, 97, 114, 111, 117, 110, 100, 32, 58,
  32, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 48, 125, 44,
  36, 123, 50, 61, 49, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 99, 114, 111, 112, 32, 105, 109, 97, 103, 101, 32, 91, 48, 93, 32,
  97, 114, 111, 117, 110, 100, 32, 34, 64, 123, 49, 44, 119, 125, 34, 32,
  99, 111, 111, 114, 100, 105, 110, 97, 116, 101, 115, 32, 103, 105, 118, 101,
  110, 32, 98, 121, 32, 105, 109, 97, 103, 101, 32, 91, 49, 93, 34, 10,
  45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 123,
  49, 44, 119, 125, 125, 10, 45, 105, 102, 32, 123, 64, 123, 48, 44, 100,
  125, 62, 49, 125, 10, 120, 61, 64, 123, 49, 44, 105, 40, 36, 62, 44,
  48, 41, 125, 32, 121, 61, 64, 123, 49, 44, 105, 40, 36, 62, 44, 49,
  41, 125, 32, 122, 61, 64, 123, 49, 44, 105, 40, 36, 62, 44, 50, 41,
  125, 10, 45, 45, 99, 114, 111, 112, 91, 48, 93, 32, 123, 36, 120, 45,
  36, 49, 125, 44, 123, 36, 121, 45, 36, 49, 125, 44, 123, 36, 122, 45,
  36, 50, 125, 44, 123, 36, 120, 43, 36, 49, 125, 44, 123, 36, 121, 43,
  36, 49, 125, 44, 123, 36, 122, 43, 36, 50, 125, 10, 45, 101, 108, 115,
  101, 10, 120, 61, 64, 123, 49, 44, 105, 40, 36, 62, 44, 48, 41, 125,
  32, 121, 61, 64, 123, 49, 44, 105, 40, 36, 62, 44, 49, 41, 125, 10,
  45, 45, 99, 114, 111, 112, 91, 48, 93, 32, 123, 36, 120, 45, 36, 49,
  125, 44, 123, 36, 121, 45, 36, 49, 125, 44, 123, 36, 120, 43, 36, 49,
  125, 44, 123, 36, 121, 43, 36, 49, 125, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 44, 49, 93, 32,
  45, 118, 32, 43, 10, 114, 97, 110, 100, 111, 109, 95, 119, 97, 108, 107,
  115, 32, 58, 10, 110, 117, 109, 98, 101, 114, 61, 36, 52, 32, 119, 105,
  100, 116, 104, 61, 36, 49, 32, 104, 101, 105, 103, 104, 116, 61, 36, 50,
  32, 108, 101, 110, 103, 116, 104, 61, 36, 51, 32, 115, 112, 101, 101, 100,
  61, 36, 53, 10, 36, 110, 117, 109, 98, 101, 114, 44, 51, 10, 45, 108,
  91, 45, 49, 93, 10, 45, 110, 111, 105, 115, 101, 32, 49, 44, 49, 10,
  45, 115, 104, 32, 48, 44, 48, 44, 48, 44, 48, 32, 45, 110, 91, 45,
  49, 93, 32, 49, 44, 123, 36, 119, 105, 100, 116, 104, 45, 49, 125, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 32, 49, 44, 49, 44,
  48, 44, 48, 32, 45, 110, 91, 45, 49, 93, 32, 49, 44, 123, 36, 104,
  101, 105, 103, 104, 116, 45, 49, 125, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 115, 104, 32, 50, 44, 50, 44, 48, 44, 48, 32, 45, 102, 91,
  45, 49, 93, 32, 48, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 123, 36, 108, 101, 110, 103, 116, 104, 45, 49,
  125, 32, 45, 45, 108, 91, 45, 49, 93, 10, 45, 110, 111, 105, 115, 101,
  32, 49, 10, 45, 115, 104, 32, 48, 44, 48, 44, 48, 44, 48, 32, 45,
  99, 91, 45, 49, 93, 32, 49, 44, 123, 36, 119, 105, 100, 116, 104, 45,
  50, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 32, 49,
  44, 49, 44, 48, 44, 48, 32, 45, 99, 91, 45, 49, 93, 32, 49, 44,
  123, 36, 104, 101, 105, 103, 104, 116, 45, 50, 125, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 115, 104, 32, 50, 44, 50, 44, 48, 44, 48, 32,
  45, 102, 91, 45, 49, 93, 32, 39, 36, 62, 43, 49, 39, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 97, 32, 120, 10, 45, 101, 110, 100, 108, 10, 109, 111, 118,
  97, 118, 103, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49,
  62, 61, 49, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 109, 111,
  118, 105, 110, 103, 32, 97, 118, 101, 114, 97, 103, 101, 32, 119, 105, 116,
  104, 32, 115, 105, 122, 101, 32, 34, 36, 49, 32, 45, 118, 32, 45, 10,
  110, 61, 123, 36, 49, 45, 49, 125, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 36, 110, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 123, 64, 35,
  125, 45, 49, 125, 32, 45, 45, 43, 91, 123, 36, 62, 125, 44, 123, 36,
  62, 43, 49, 125, 93, 32, 45, 42, 91, 45, 49, 93, 32, 46, 53, 32,
  45, 114, 109, 91, 36, 62, 93, 32, 45, 109, 118, 91, 45, 49, 93, 32,
  36, 62, 32, 45, 100, 111, 110, 101, 10, 45, 114, 101, 118, 101, 114, 115,
  101, 10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 110, 37,
  50, 33, 61, 48, 125, 32, 45, 114, 101, 118, 101, 114, 115, 101, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 118, 32, 43, 10, 102, 102, 116, 115, 104,
  105, 102, 116, 32, 58, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 115, 104,
  105, 102, 116, 32, 123, 45, 105, 110, 116, 40, 119, 47, 50, 41, 125, 44,
  123, 45, 105, 110, 116, 40, 104, 47, 50, 41, 125, 44, 123, 45, 105, 110,
  116, 40, 100, 47, 50, 41, 125, 44, 48, 44, 50, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 119, 104, 105,
  116, 101, 110, 95, 102, 114, 101, 113, 117, 101, 110, 99, 121, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 46, 50, 53, 125,
  62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 87, 104,
  105, 116, 101, 110, 32, 116, 104, 101, 32, 102, 114, 101, 113, 117, 101, 110,
  99, 121, 32, 119, 105, 116, 104, 32, 112, 97, 114, 97, 109, 101, 116, 101,
  114, 32, 34, 36, 49, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 102, 102,
  116, 32, 45, 45, 97, 32, 99, 32, 45, 110, 111, 114, 109, 91, 45, 49,
  93, 32, 45, 112, 111, 119, 91, 45, 49, 93, 32, 36, 49, 32, 45, 109,
  97, 120, 91, 45, 49, 93, 32, 49, 101, 45, 49, 50, 32, 45, 47, 91,
  45, 49, 93, 32, 123, 105, 97, 125, 32, 45, 47, 91, 48, 45, 49, 93,
  32, 91, 50, 93, 32, 45, 114, 109, 91, 50, 93, 32, 45, 105, 102, 102,
  116, 32, 45, 107, 91, 48, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 100, 101, 98, 108, 117, 114, 95,
  103, 111, 108, 100, 109, 101, 105, 110, 101, 108, 50, 32, 58, 32, 45, 99,
  104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48, 32, 38, 38, 32, 36,
  123, 50, 61, 56, 125, 62, 61, 48, 32, 38, 38, 32, 36, 123, 51, 61,
  49, 125, 62, 61, 48, 34, 32, 45, 115, 107, 105, 112, 32, 36, 123, 52,
  61, 49, 125, 32, 45, 115, 107, 105, 112, 32, 36, 123, 53, 61, 49, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 101, 98, 108, 117, 114,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 117, 115, 105, 110, 103, 32, 71,
  111, 108, 100, 45, 77, 101, 105, 110, 101, 108, 32, 97, 108, 103, 111, 114,
  105, 116, 104, 109, 44, 32, 119, 105, 116, 104, 32, 115, 105, 103, 109, 97,
  32, 36, 49, 44, 32, 36, 50, 32, 105, 116, 101, 114, 97, 116, 105, 111,
  110, 115, 44, 32, 97, 99, 99, 101, 108, 101, 114, 97, 116, 105, 111, 110,
  32, 36, 51, 32, 97, 110, 100, 32, 34, 64, 123, 45, 97, 114, 103, 92,
  32, 49, 43, 33, 36, 52, 44, 34, 34, 44, 113, 117, 97, 115, 105, 45,
  125, 34, 103, 97, 117, 115, 115, 105, 97, 110, 32, 107, 101, 114, 110, 101,
  108, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 91, 48, 93, 32, 45,
  114, 91, 45, 49, 93, 32, 50, 48, 48, 37, 44, 50, 48, 48, 37, 44,
  50, 48, 48, 37, 44, 49, 48, 48, 37, 44, 53, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 36, 50, 10, 45, 45, 98, 91, 45, 49, 93, 32, 36,
  49, 44, 49, 44, 36, 52, 32, 45, 114, 91, 45, 49, 93, 32, 53, 48,
  37, 44, 53, 48, 37, 44, 53, 48, 37, 32, 45, 45, 47, 91, 48, 44,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45, 94, 91, 45,
  49, 93, 32, 36, 51, 32, 45, 114, 91, 45, 49, 93, 32, 50, 48, 48,
  37, 44, 50, 48, 48, 37, 44, 50, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 53, 32, 45, 42, 91, 45, 49, 44, 45, 50, 93, 10, 45, 100, 111,
  110, 101, 32, 45, 114, 109, 91, 48, 93, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 100, 101, 98, 108, 117,
  114, 95, 114, 105, 99, 104, 97, 114, 100, 115, 111, 110, 108, 117, 99, 121,
  50, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61,
  48, 32, 38, 38, 32, 36, 123, 50, 61, 53, 48, 125, 62, 61, 48, 34,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 49, 125, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 52, 61, 49, 125, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 68, 101, 98, 108, 117, 114, 32, 105, 109, 97, 103, 101,
  36, 63, 32, 117, 115, 105, 110, 103, 32, 82, 105, 99, 104, 97, 114, 100,
  115, 111, 110, 45, 76, 117, 99, 121, 32, 97, 108, 103, 111, 114, 105, 116,
  104, 109, 44, 32, 119, 105, 116, 104, 32, 115, 105, 103, 109, 97, 32, 36,
  49, 44, 32, 36, 50, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115,
  32, 97, 110, 100, 32, 34, 64, 123, 45, 97, 114, 103, 92, 32, 49, 43,
  33, 36, 51, 44, 34, 34, 44, 113, 117, 97, 115, 105, 45, 125, 34, 103,
  97, 117, 115, 115, 105, 97, 110, 32, 107, 101, 114, 110, 101, 108, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 91, 48, 93, 32, 45, 114, 91, 45,
  49, 93, 32, 50, 48, 48, 37, 44, 50, 48, 48, 37, 44, 50, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 53, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 36, 50, 10, 45, 45, 98, 91, 45, 49, 93, 32, 36, 49, 44, 49,
  44, 123, 36, 51, 33, 61, 48, 125, 32, 45, 114, 91, 45, 49, 93, 32,
  53, 48, 37, 44, 53, 48, 37, 44, 53, 48, 37, 44, 49, 48, 48, 37,
  44, 53, 32, 45, 45, 47, 91, 48, 44, 45, 49, 93, 32, 45, 114, 109,
  91, 45, 50, 93, 32, 45, 114, 91, 45, 49, 93, 32, 50, 48, 48, 37,
  44, 50, 48, 48, 37, 44, 50, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  53, 32, 45, 98, 91, 45, 49, 93, 32, 36, 49, 44, 49, 44, 123, 36,
  51, 33, 61, 48, 125, 32, 32, 45, 42, 91, 45, 49, 44, 45, 50, 93,
  10, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 93, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 99,
  111, 114, 114, 101, 108, 97, 116, 101, 95, 102, 102, 116, 32, 58, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 114, 114, 101, 108, 97, 116,
  101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121,
  45, 116, 119, 111, 32, 116, 104, 114, 111, 117, 103, 104, 32, 102, 111, 117,
  114, 105, 101, 114, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 115, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62,
  44, 123, 36, 62, 43, 49, 125, 93, 10, 119, 50, 61, 123, 105, 110, 116,
  40, 64, 123, 48, 44, 119, 125, 47, 50, 41, 125, 32, 104, 50, 61, 123,
  105, 110, 116, 40, 64, 123, 48, 44, 104, 125, 47, 50, 41, 125, 32, 100,
  50, 61, 123, 105, 110, 116, 40, 64, 123, 48, 44, 100, 125, 47, 50, 41,
  125, 10, 45, 114, 91, 49, 93, 32, 91, 48, 93, 44, 91, 48, 93, 44,
  91, 48, 93, 44, 49, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46,
  53, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 115, 104, 105, 102, 116,
  91, 49, 93, 32, 45, 36, 119, 50, 44, 45, 36, 104, 50, 44, 45, 36,
  100, 50, 44, 48, 44, 50, 10, 45, 102, 102, 116, 91, 48, 93, 32, 45,
  102, 102, 116, 91, 50, 93, 32, 45, 42, 91, 49, 93, 32, 45, 49, 10,
  45, 45, 42, 91, 45, 52, 93, 32, 91, 45, 49, 93, 32, 45, 45, 42,
  91, 45, 52, 93, 32, 91, 45, 51, 93, 32, 45, 43, 91, 45, 50, 44,
  45, 49, 93, 10, 45, 42, 91, 45, 53, 44, 45, 51, 93, 32, 45, 42,
  91, 45, 51, 44, 45, 50, 93, 32, 45, 45, 91, 45, 51, 44, 45, 50,
  93, 10, 45, 105, 102, 102, 116, 32, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 100, 101, 99, 111, 110, 118, 111, 108, 118, 101, 95, 114, 105, 99, 104,
  97, 114, 100, 115, 111, 110, 108, 117, 99, 121, 32, 58, 32, 32, 45, 99,
  104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 53, 125, 62, 61, 49, 34,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 101, 98, 108, 117, 114,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 117, 115, 105, 110, 103, 32, 82,
  105, 99, 104, 97, 114, 100, 115, 111, 110, 45, 76, 117, 99, 121, 32, 97,
  108, 103, 111, 114, 105, 116, 104, 109, 32, 119, 105, 116, 104, 32, 97, 32,
  99, 117, 115, 116, 111, 109, 32, 102, 105, 108, 116, 101, 114, 46, 34, 10,
  45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35,
  45, 49, 125, 32, 45, 108, 91, 48, 44, 123, 36, 62, 43, 49, 125, 93,
  10, 45, 114, 91, 48, 93, 32, 64, 123, 49, 44, 119, 125, 44, 64, 123,
  49, 44, 104, 125, 44, 64, 123, 49, 44, 100, 125, 44, 49, 48, 48, 37,
  44, 48, 44, 48, 44, 46, 53, 44, 46, 53, 44, 46, 53, 32, 45, 110,
  111, 114, 109, 97, 108, 105, 122, 101, 95, 115, 117, 109, 91, 48, 93, 10,
  91, 49, 93, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 10, 45,
  45, 99, 111, 110, 118, 111, 108, 118, 101, 95, 102, 102, 116, 91, 48, 44,
  45, 49, 93, 32, 45, 45, 47, 91, 49, 44, 45, 49, 93, 32, 45, 114,
  109, 91, 45, 50, 93, 32, 45, 45, 99, 111, 114, 114, 101, 108, 97, 116,
  101, 95, 102, 102, 116, 91, 48, 44, 45, 49, 93, 32, 45, 114, 109, 91,
  45, 50, 93, 32, 45, 42, 91, 45, 49, 44, 45, 50, 93, 10, 45, 100,
  111, 110, 101, 32, 45, 114, 109, 91, 48, 44, 49, 93, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 100, 101,
  99, 111, 110, 118, 111, 108, 118, 101, 95, 103, 111, 108, 100, 109, 101, 105,
  110, 101, 108, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123,
  49, 61, 53, 125, 62, 61, 49, 38, 38, 36, 123, 50, 61, 49, 125, 62,
  61, 49, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 101, 98,
  108, 117, 114, 32, 105, 109, 97, 103, 101, 36, 63, 32, 117, 115, 105, 110,
  103, 32, 71, 111, 108, 100, 45, 77, 101, 105, 110, 101, 108, 32, 97, 108,
  103, 111, 114, 105, 116, 104, 109, 44, 32, 119, 105, 116, 104, 32, 36, 49,
  32, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 44, 32, 97, 99, 99,
  101, 108, 101, 114, 97, 116, 105, 111, 110, 32, 36, 50, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45,
  49, 125, 32, 45, 108, 91, 48, 44, 123, 36, 62, 43, 49, 125, 93, 10,
  45, 114, 91, 48, 93, 32, 64, 123, 49, 44, 119, 125, 44, 64, 123, 49,
  44, 104, 125, 44, 64, 123, 49, 44, 100, 125, 44, 49, 48, 48, 37, 44,
  48, 44, 48, 44, 46, 53, 44, 46, 53, 44, 46, 53, 32, 45, 110, 111,
  114, 109, 97, 108, 105, 122, 101, 95, 115, 117, 109, 91, 48, 93, 10, 91,
  49, 93, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 50, 10, 45, 45,
  99, 111, 110, 118, 111, 108, 118, 101, 95, 102, 102, 116, 91, 48, 44, 45,
  49, 93, 32, 32, 45, 45, 47, 91, 49, 44, 45, 49, 93, 32, 45, 114,
  109, 91, 45, 50, 93, 32, 45, 94, 91, 45, 49, 93, 32, 36, 50, 32,
  45, 42, 91, 45, 49, 44, 45, 50, 93, 10, 45, 100, 111, 110, 101, 32,
  45, 114, 109, 91, 48, 44, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 110, 111, 114, 109, 97, 108,
  105, 122, 101, 95, 115, 117, 109, 32, 58, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 42, 32, 123, 49, 47, 40, 105, 97, 42, 119, 42, 104, 42, 100,
  42, 115, 41, 125, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 118, 32, 43, 10, 108, 111, 99, 97, 108, 95, 118, 97, 114, 105,
  97, 110, 99, 101, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  50, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 76, 111, 99, 97,
  108, 32, 86, 97, 114, 105, 97, 110, 99, 101, 32, 102, 105, 108, 116, 101,
  114, 32, 119, 105, 116, 104, 32, 115, 99, 97, 108, 101, 32, 34, 36, 49,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 98, 108, 117, 114, 32, 36,
  49, 44, 49, 44, 49, 32, 45, 45, 32, 45, 115, 113, 114, 32, 45, 98,
  108, 117, 114, 32, 36, 49, 44, 49, 44, 49, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 110, 111, 114, 109,
  97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 95, 118, 97, 114, 105,
  97, 110, 99, 101, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  53, 48, 125, 44, 36, 123, 50, 61, 50, 125, 44, 36, 123, 51, 61, 50,
  53, 125, 44, 36, 123, 52, 61, 49, 125, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 78, 111, 114, 109, 97, 108, 105, 122, 101, 32, 108, 111, 99,
  97, 108, 32, 118, 97, 114, 105, 97, 110, 99, 101, 32, 119, 105, 116, 104,
  32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 36, 49, 44, 32, 115,
  99, 97, 108, 101, 32, 36, 50, 44, 32, 116, 104, 114, 101, 115, 104, 111,
  108, 100, 32, 36, 51, 32, 40, 120, 36, 52, 32, 116, 105, 109, 101, 115,
  41, 46, 34, 10, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 36, 52, 10, 45, 45, 108, 111, 99, 97, 108, 95, 118, 97, 114, 105,
  97, 110, 99, 101, 32, 36, 50, 32, 45, 115, 113, 114, 116, 91, 45, 49,
  93, 32, 45, 109, 97, 120, 91, 45, 49, 93, 32, 36, 51, 10, 45, 45,
  98, 108, 117, 114, 91, 48, 93, 32, 36, 50, 44, 49, 44, 49, 32, 45,
  45, 45, 91, 48, 44, 45, 49, 93, 32, 45, 47, 91, 45, 49, 93, 32,
  91, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 36, 49, 32, 45, 43,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 107, 91, 45, 49, 93, 10, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 108, 111, 99, 97, 108, 95,
  119, 105, 101, 110, 101, 114, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 49, 61, 50, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 76,
  111, 99, 97, 108, 32, 87, 105, 101, 110, 101, 114, 32, 102, 105, 108, 116,
  101, 114, 105, 110, 103, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 115, 105,
  103, 109, 97, 61, 64, 123, 45, 110, 111, 105, 115, 101, 95, 115, 116, 100,
  125, 10, 45, 45, 98, 108, 117, 114, 32, 36, 49, 10, 45, 45, 108, 111,
  99, 97, 108, 95, 118, 97, 114, 105, 97, 110, 99, 101, 91, 48, 93, 32,
  123, 50, 42, 36, 49, 125, 32, 45, 45, 45, 91, 45, 49, 93, 32, 123,
  36, 115, 105, 103, 109, 97, 42, 36, 115, 105, 103, 109, 97, 125, 32, 45,
  114, 101, 118, 101, 114, 115, 101, 91, 45, 49, 44, 45, 50, 93, 32, 45,
  47, 91, 45, 49, 44, 45, 50, 93, 10, 45, 45, 45, 91, 48, 44, 49,
  93, 10, 45, 42, 91, 45, 49, 44, 45, 50, 93, 32, 45, 43, 91, 45,
  49, 44, 45, 50, 93, 32, 45, 107, 91, 45, 49, 93, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 112, 101,
  114, 105, 111, 100, 105, 122, 101, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 112, 101, 114, 105, 111, 100, 105, 122, 101, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 119, 62, 49, 125, 32, 45,
  45, 109, 105, 114, 114, 111, 114, 32, 120, 32, 45, 97, 32, 120, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 104, 62, 49, 125, 32,
  45, 45, 109, 105, 114, 114, 111, 114, 32, 121, 32, 45, 97, 32, 121, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 100, 62, 49, 125,
  32, 45, 45, 109, 105, 114, 114, 111, 114, 32, 122, 32, 45, 97, 32, 122,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 116, 97, 112, 101, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 97, 112, 112, 108, 121, 32, 97,
  32, 72, 97, 110, 110, 32, 116, 97, 112, 101, 114, 105, 110, 103, 32, 119,
  105, 110, 100, 111, 119, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105,
  102, 32, 123, 119, 62, 49, 125, 32, 45, 102, 32, 39, 105, 42, 115, 105,
  110, 40, 112, 105, 42, 120, 47, 40, 119, 45, 49, 41, 41, 94, 50, 39,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 104, 62, 49,
  125, 32, 45, 102, 32, 39, 105, 42, 115, 105, 110, 40, 112, 105, 42, 121,
  47, 40, 104, 45, 49, 41, 41, 94, 50, 39, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 100, 62, 49, 125, 32, 45, 102, 32, 39,
  105, 42, 115, 105, 110, 40, 112, 105, 42, 122, 47, 40, 100, 45, 49, 41,
  41, 94, 50, 39, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 112, 111, 119,
  101, 114, 115, 112, 101, 99, 116, 114, 117, 109, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 112, 111,
  119, 101, 114, 32, 115, 112, 101, 99, 116, 114, 117, 109, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 100, 105, 115, 112, 108, 97, 121, 95, 102, 102,
  116, 32, 45, 107, 91, 48, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 102, 111, 117, 114, 105, 101, 114,
  109, 105, 120, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  53, 48, 37, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 102, 111,
  117, 114, 105, 101, 114, 32, 109, 105, 120, 32, 105, 109, 97, 103, 101, 115,
  46, 34, 10, 45, 102, 102, 116, 91, 48, 93, 32, 45, 102, 102, 116, 91,
  50, 93, 32, 45, 102, 102, 116, 115, 104, 105, 102, 116, 10, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 32, 45, 99, 105, 114, 99, 108, 101, 91, 45,
  49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 36, 49, 44, 49, 44,
  49, 32, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 49, 48, 37, 44,
  49, 44, 49, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 49, 10, 45,
  42, 91, 48, 44, 49, 93, 32, 91, 45, 49, 93, 32, 45, 110, 101, 103,
  97, 116, 105, 118, 101, 91, 45, 49, 93, 32, 45, 42, 91, 50, 44, 51,
  93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  43, 91, 48, 44, 50, 93, 32, 45, 43, 91, 49, 44, 50, 93, 32, 45,
  102, 102, 116, 115, 104, 105, 102, 116, 10, 45, 105, 102, 102, 116, 32, 32,
  45, 107, 91, 48, 93, 10, 102, 111, 117, 114, 105, 101, 114, 99, 117, 116,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 84, 104, 114, 101, 115, 104, 111,
  108, 100, 32, 70, 111, 117, 114, 105, 101, 114, 32, 99, 111, 101, 102, 102,
  105, 99, 105, 101, 110, 116, 115, 32, 119, 105, 116, 104, 32, 116, 104, 114,
  101, 115, 104, 111, 108, 100, 32, 34, 36, 49, 34, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 45, 108, 91, 45, 49, 93, 32, 45, 112, 111,
  119, 101, 114, 115, 112, 101, 99, 116, 114, 117, 109, 32, 45, 116, 104, 114,
  101, 115, 104, 111, 108, 100, 32, 36, 49, 32, 45, 102, 102, 116, 115, 104,
  105, 102, 116, 32, 45, 101, 110, 100, 108, 10, 45, 102, 102, 116, 91, 48,
  93, 32, 45, 42, 91, 48, 93, 32, 91, 45, 49, 93, 32, 45, 42, 91,
  49, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 105, 102, 102, 116, 32, 45, 107, 91, 48, 93, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 117, 110, 115,
  116, 114, 105, 112, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49,
  61, 50, 53, 125, 44, 36, 123, 50, 61, 50, 48, 125, 44, 36, 123, 51,
  61, 52, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 82, 101, 109,
  111, 118, 101, 32, 115, 116, 114, 105, 112, 101, 115, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 45, 108, 91, 45, 49, 93, 10, 45, 116, 97, 112,
  101, 32, 45, 112, 111, 119, 101, 114, 115, 112, 101, 99, 116, 114, 117, 109,
  32, 45, 110, 111, 114, 109, 32, 45, 100, 101, 116, 101, 99, 116, 95, 115,
  112, 111, 116, 115, 32, 49, 44, 36, 51, 32, 45, 100, 105, 108, 97, 116,
  101, 95, 99, 105, 114, 99, 32, 36, 50, 32, 45, 103, 116, 32, 48, 10,
  45, 110, 32, 48, 44, 49, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101,
  32, 45, 99, 105, 114, 99, 108, 101, 32, 53, 48, 37, 44, 53, 48, 37,
  44, 36, 50, 44, 49, 44, 49, 10, 45, 105, 102, 32, 123, 64, 123, 45,
  49, 44, 105, 109, 125, 60, 46, 57, 125, 10, 97, 99, 116, 105, 118, 101,
  61, 49, 32, 45, 98, 108, 117, 114, 32, 36, 49, 32, 45, 110, 32, 48,
  44, 49, 32, 45, 102, 102, 116, 115, 104, 105, 102, 116, 32, 45, 105, 102,
  32, 123, 105, 77, 61, 61, 48, 125, 32, 45, 102, 32, 49, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 108, 115, 101, 10, 97, 99, 116, 105, 118,
  101, 61, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108,
  10, 45, 105, 102, 32, 123, 36, 97, 99, 116, 105, 118, 101, 61, 61, 49,
  125, 10, 45, 102, 102, 116, 91, 48, 93, 32, 45, 42, 91, 48, 93, 32,
  91, 45, 49, 93, 32, 45, 42, 91, 49, 93, 32, 91, 45, 49, 93, 32,
  45, 114, 109, 91, 45, 49, 93, 32, 45, 105, 102, 102, 116, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 107, 91, 48, 93, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 97, 117, 116, 111,
  99, 111, 114, 114, 101, 108, 97, 116, 101, 32, 58, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 97, 117, 116,
  111, 99, 111, 114, 114, 101, 108, 97, 116, 105, 111, 110, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 102, 102, 116, 32, 45, 115, 113, 114, 32, 45,
  43, 32, 45, 115, 113, 114, 116, 32, 45, 105, 102, 102, 116, 32, 45, 107,
  91, 48, 93, 32, 45, 102, 102, 116, 115, 104, 105, 102, 116, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 112,
  115, 102, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49,
  46, 52, 48, 125, 44, 36, 123, 50, 61, 49, 46, 51, 51, 125, 44, 36,
  123, 51, 61, 52, 56, 56, 125, 44, 36, 123, 52, 61, 49, 54, 48, 125,
  44, 36, 123, 53, 61, 50, 48, 48, 125, 10, 67, 61, 123, 50, 42, 112,
  105, 47, 36, 51, 42, 36, 49, 47, 36, 50, 42, 53, 48, 125, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 102, 32, 39, 100, 120, 61, 120, 45, 119,
  47, 50, 59, 100, 121, 61, 121, 45, 104, 47, 50, 59, 100, 122, 61, 122,
  45, 100, 47, 50, 59, 105, 102, 40, 36, 67, 42, 115, 113, 114, 116, 40,
  100, 120, 42, 100, 120, 43, 100, 121, 42, 100, 121, 41, 60, 40, 100, 45,
  97, 98, 115, 40, 100, 122, 41, 41, 44, 49, 44, 48, 41, 39, 10, 45,
  98, 108, 117, 114, 32, 49, 10, 45, 115, 32, 122, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 102,
  102, 116, 112, 111, 108, 97, 114, 32, 45, 107, 91, 48, 93, 32, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 97, 32, 122, 10, 45,
  115, 113, 114, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 98, 101, 97, 100, 115, 50, 112, 115, 102, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 53, 125, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 97,
  32, 80, 83, 70, 32, 102, 114, 111, 109, 32, 97, 110, 32, 105, 109, 97,
  103, 101, 32, 98, 101, 97, 100, 32, 117, 115, 105, 110, 103, 32, 97, 117,
  116, 111, 99, 111, 114, 114, 101, 108, 97, 116, 105, 111, 110, 32, 109, 101,
  116, 104, 111, 100, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 116, 97,
  112, 101, 32, 45, 97, 117, 116, 111, 99, 111, 114, 114, 101, 108, 97, 116,
  101, 32, 45, 45, 32, 123, 115, 113, 114, 116, 40, 64, 123, 48, 44, 105,
  118, 125, 41, 125, 32, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32,
  48, 44, 49, 10, 45, 102, 32, 39, 100, 120, 61, 120, 45, 119, 47, 50,
  59, 100, 121, 61, 121, 45, 104, 47, 50, 59, 100, 122, 61, 122, 45, 100,
  47, 50, 59, 115, 105, 103, 109, 97, 61, 57, 43, 36, 49, 42, 100, 122,
  42, 100, 122, 59, 105, 42, 101, 120, 112, 40, 45, 46, 53, 42, 40, 100,
  120, 42, 100, 120, 43, 100, 121, 42, 100, 121, 41, 47, 40, 115, 105, 103,
  109, 97, 41, 41, 47, 115, 113, 114, 116, 40, 50, 42, 112, 105, 42, 115,
  105, 103, 109, 97, 41, 39, 10, 45, 115, 113, 114, 32, 45, 42, 32, 123,
  49, 47, 40, 105, 97, 42, 119, 42, 104, 42, 100, 42, 115, 41, 125, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43,
  10, 115, 105, 109, 109, 111, 100, 32, 58, 10, 45, 45, 43, 32, 45, 42,
  91, 45, 49, 93, 32, 123, 49, 47, 40, 64, 35, 45, 49, 41, 125, 32,
  45, 47, 91, 48, 45, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 115, 112, 111, 116, 105, 102, 121, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 49, 125, 62, 48,
  32, 38, 38, 32, 36, 123, 50, 61, 49, 125, 62, 48, 34, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 83, 112, 111, 116, 105, 102, 121, 32, 119,
  105, 116, 104, 32, 115, 99, 97, 108, 101, 32, 36, 49, 32, 119, 105, 116,
  104, 32, 36, 50, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 115, 61, 64, 123, 48, 44, 97, 125,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 36, 50, 32, 45, 98, 108, 117,
  114, 32, 36, 49, 32, 45, 45, 98, 108, 117, 114, 32, 123, 50, 42, 36,
  49, 125, 32, 45, 45, 32, 45, 99, 117, 116, 32, 48, 44, 49, 48, 48,
  37, 32, 45, 102, 32, 39, 105, 42, 123, 36, 115, 125, 47, 105, 97, 39,
  32, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 116, 117, 98, 101, 110, 101, 115, 115,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 49,
  125, 62, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 84, 117,
  98, 101, 110, 101, 115, 115, 32, 119, 105, 116, 104, 32, 115, 99, 97, 108,
  101, 32, 36, 49, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 98,
  108, 117, 114, 32, 36, 49, 10, 45, 115, 32, 99, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 104,
  101, 115, 115, 105, 97, 110, 32, 45, 97, 32, 99, 32, 45, 101, 105, 103,
  101, 110, 32, 45, 107, 91, 48, 93, 32, 45, 115, 32, 99, 32, 45, 107,
  91, 49, 93, 32, 45, 42, 32, 45, 49, 32, 45, 99, 117, 116, 32, 48,
  44, 49, 48, 48, 37, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 98, 103, 115, 117, 98, 115, 116, 114,
  97, 99, 116, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 84, 101,
  109, 112, 111, 114, 97, 108, 32, 98, 97, 99, 107, 103, 114, 111, 117, 110,
  100, 32, 115, 117, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 32, 119,
  105, 116, 104, 32, 108, 101, 110, 103, 116, 104, 32, 36, 49, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 49, 44, 49, 44, 36, 49, 32, 45, 102,
  91, 45, 49, 93, 32, 49, 32, 45, 45, 101, 114, 111, 100, 101, 91, 48,
  93, 32, 91, 49, 93, 32, 45, 45, 91, 48, 93, 32, 91, 45, 49, 93,
  32, 45, 114, 109, 91, 49, 44, 45, 49, 93, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 115, 99, 104, 105,
  122, 111, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49,
  48, 48, 125, 44, 36, 123, 50, 61, 45, 53, 48, 125, 44, 36, 123, 51,
  61, 53, 125, 44, 36, 123, 52, 61, 46, 55, 53, 125, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 83, 99, 104, 105, 122, 111, 32, 102, 105, 108,
  116, 101, 114, 32, 115, 109, 111, 111, 116, 104, 105, 110, 103, 32, 119, 105,
  116, 104, 32, 47, 47, 32, 36, 49, 32, 97, 110, 100, 32, 84, 32, 36,
  50, 32, 97, 110, 100, 32, 36, 51, 32, 105, 116, 101, 114, 97, 116, 105,
  111, 110, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 91, 48, 93,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 51, 10, 45, 108, 91, 45,
  49, 93, 10, 45, 45, 105, 101, 101, 32, 45, 42, 91, 45, 49, 93, 32,
  123, 36, 49, 47, 40, 48, 46, 48, 48, 48, 49, 43, 109, 97, 120, 40,
  97, 98, 115, 40, 64, 123, 45, 49, 44, 109, 125, 41, 44, 97, 98, 115,
  40, 64, 123, 45, 49, 44, 77, 125, 41, 41, 41, 125, 10, 45, 45, 105,
  110, 110, 91, 48, 93, 32, 45, 42, 91, 45, 49, 93, 32, 123, 36, 50,
  47, 40, 48, 46, 48, 48, 48, 49, 43, 109, 97, 120, 40, 97, 98, 115,
  40, 64, 123, 45, 49, 44, 109, 125, 41, 44, 97, 98, 115, 40, 64, 123,
  45, 49, 44, 77, 125, 41, 41, 41, 125, 10, 45, 43, 10, 45, 101, 110,
  100, 108, 10, 45, 42, 91, 45, 49, 93, 32, 36, 52, 32, 32, 45, 45,
  42, 91, 48, 93, 32, 123, 49, 45, 36, 52, 125, 32, 45, 43, 91, 45,
  49, 44, 45, 50, 93, 10, 45, 100, 111, 110, 101, 32, 45, 114, 109, 91,
  48, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 115, 99, 97, 110, 100, 111, 99, 58, 32, 45, 115, 107,
  105, 112, 32, 36, 123, 49, 61, 51, 125, 44, 36, 123, 50, 61, 49, 48,
  48, 125, 44, 36, 123, 51, 61, 49, 48, 37, 125, 44, 36, 123, 52, 61,
  57, 48, 37, 125, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108,
  105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45, 108, 91, 48, 93,
  10, 45, 109, 101, 100, 105, 97, 110, 32, 36, 49, 32, 45, 45, 98, 108,
  117, 114, 32, 36, 50, 32, 45, 45, 32, 45, 109, 105, 110, 32, 48, 10,
  45, 115, 32, 99, 32, 45, 110, 32, 48, 44, 49, 32, 45, 97, 32, 99,
  32, 45, 99, 32, 36, 51, 44, 36, 52, 32, 45, 110, 32, 48, 44, 50,
  53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 111,
  98, 108, 117, 114, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  49, 125, 44, 36, 123, 50, 61, 54, 125, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 32, 115, 61, 123, 50,
  94, 40, 36, 62, 43, 50, 41, 125, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 36, 50, 32, 97, 61, 123, 36, 62, 47, 64, 35, 42, 49, 56, 48,
  125, 10, 45, 101, 99, 104, 111, 95, 115, 116, 100, 111, 117, 116, 32, 36,
  115, 34, 44, 32, 34, 36, 97, 10, 45, 45, 108, 91, 48, 93, 32, 45,
  98, 108, 117, 114, 95, 108, 105, 110, 101, 97, 114, 32, 36, 115, 44, 49,
  44, 36, 97, 32, 32, 45, 45, 98, 108, 117, 114, 32, 49, 32, 45, 45,
  32, 45, 101, 110, 100, 108, 10, 45, 105, 102, 32, 123, 64, 35, 61, 61,
  51, 125, 32, 32, 45, 109, 97, 120, 91, 49, 44, 50, 93, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 32, 45, 100, 111, 110, 101,
  10, 45, 114, 109, 91, 48, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 118, 32, 43, 10, 111, 104, 101, 97, 116, 58, 32,
  45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 125, 44, 36, 123, 50,
  61, 54, 125, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 36, 49, 32, 32, 45, 114, 101, 112, 101, 97, 116, 32, 36,
  50, 32, 97, 61, 123, 36, 62, 47, 64, 35, 42, 49, 56, 48, 125, 10,
  45, 45, 108, 91, 48, 93, 32, 45, 98, 108, 117, 114, 95, 108, 105, 110,
  101, 97, 114, 32, 50, 44, 46, 53, 44, 36, 97, 32, 32, 45, 45, 98,
  108, 117, 114, 32, 49, 32, 45, 45, 32, 45, 101, 110, 100, 108, 10, 45,
  100, 111, 110, 101, 10, 45, 109, 97, 120, 91, 49, 45, 45, 49, 93, 32,
  45, 43, 10, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 119, 97, 114, 112, 95, 97,
  102, 102, 105, 110, 101, 32, 58, 10, 45, 45, 108, 91, 48, 44, 49, 93,
  10, 112, 97, 114, 97, 109, 115, 61, 40, 64, 123, 49, 44, 105, 40, 48,
  44, 48, 41, 125, 44, 64, 123, 49, 44, 105, 40, 49, 44, 48, 41, 125,
  44, 64, 123, 49, 44, 105, 40, 50, 44, 48, 41, 125, 59, 92, 10, 64,
  123, 49, 44, 105, 40, 48, 44, 49, 41, 125, 44, 64, 123, 49, 44, 105,
  40, 49, 44, 49, 41, 125, 44, 64, 123, 49, 44, 105, 40, 50, 44, 49,
  41, 125, 59, 92, 10, 64, 123, 49, 44, 105, 40, 48, 44, 50, 41, 125,
  44, 64, 123, 49, 44, 105, 40, 49, 44, 50, 41, 125, 44, 64, 123, 49,
  44, 105, 40, 50, 44, 50, 41, 125, 41, 10, 64, 123, 48, 44, 119, 125,
  44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 49, 44, 49, 32, 45, 45,
  102, 91, 45, 49, 93, 32, 120, 32, 45, 45, 102, 91, 45, 49, 93, 32,
  121, 32, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 99, 10, 45, 109,
  105, 120, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32,
  36, 112, 97, 114, 97, 109, 115, 10, 45, 99, 104, 97, 110, 110, 101, 108,
  115, 91, 45, 49, 93, 32, 49, 44, 50, 10, 45, 119, 97, 114, 112, 91,
  48, 93, 32, 91, 45, 49, 93, 44, 48, 44, 49, 44, 48, 32, 45, 114,
  109, 91, 45, 49, 44, 45, 50, 93, 10, 45, 101, 110, 100, 108, 10, 45,
  114, 109, 91, 48, 44, 49, 93, 10, 109, 105, 100, 119, 97, 121, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 45, 45, 108, 91, 48, 93, 10, 45, 114, 101, 115, 105, 122,
  101, 32, 50, 48, 37, 44, 50, 48, 37, 10, 45, 115, 32, 99, 32, 45,
  117, 110, 114, 111, 108, 108, 32, 121, 32, 45, 108, 91, 48, 93, 32, 49,
  44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 49, 44, 49, 32, 45, 97,
  32, 120, 32, 45, 101, 110, 100, 108, 32, 32, 45, 116, 114, 97, 110, 115,
  112, 111, 115, 101, 91, 48, 93, 10, 45, 108, 91, 48, 93, 32, 45, 115,
  118, 100, 32, 45, 102, 91, 45, 50, 93, 32, 39, 105, 102, 40, 105, 62,
  49, 101, 45, 54, 44, 49, 47, 105, 44, 48, 41, 39, 32, 45, 100, 105,
  97, 103, 111, 110, 97, 108, 91, 45, 50, 93, 32, 45, 116, 114, 97, 110,
  115, 112, 111, 115, 101, 91, 45, 49, 93, 32, 45, 109, 109, 117, 108, 32,
  45, 101, 110, 100, 108, 32, 45, 109, 109, 117, 108, 10, 97, 61, 64, 123,
  48, 44, 48, 125, 32, 98, 61, 64, 123, 48, 44, 49, 125, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 10, 45, 115, 32, 99,
  10, 45, 43, 91, 45, 49, 93, 32, 123, 36, 98, 125, 32, 45, 42, 91,
  45, 49, 93, 32, 123, 49, 47, 36, 97, 125, 32, 45, 97, 32, 99, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 118, 111, 98, 115,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49, 61, 49,
  125, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 51, 125, 62, 48, 34,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 77, 111, 116, 105, 111, 110,
  32, 113, 117, 97, 110, 116, 105, 116, 121, 32, 119, 105, 116, 104, 32, 115,
  99, 97, 108, 101, 32, 36, 49, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  45, 103, 114, 97, 100, 105, 101, 110, 116, 32, 45, 97, 91, 48, 44, 49,
  93, 32, 99, 32, 45, 110, 111, 114, 109, 91, 48, 93, 32, 45, 97, 98,
  115, 91, 49, 93, 32, 45, 42, 91, 49, 93, 32, 91, 48, 93, 32, 45,
  115, 113, 114, 91, 48, 93, 32, 45, 98, 108, 117, 114, 32, 36, 49, 44,
  49, 44, 49, 32, 45, 114, 101, 118, 101, 114, 115, 101, 32, 45, 109, 97,
  120, 91, 49, 93, 32, 53, 37, 32, 45, 47, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 100, 105, 115, 112,
  108, 97, 121, 95, 118, 111, 98, 115, 32, 58, 10, 45, 45, 118, 111, 98,
  115, 32, 49, 32, 65, 61, 123, 114, 111, 117, 110, 100, 40, 64, 123, 45,
  49, 44, 105, 109, 125, 44, 48, 46, 48, 48, 49, 41, 125, 32, 66, 61,
  123, 114, 111, 117, 110, 100, 40, 64, 123, 45, 49, 44, 105, 77, 125, 44,
  48, 46, 48, 48, 49, 41, 125, 32, 45, 42, 91, 45, 49, 93, 32, 39,
  123, 49, 50, 56, 47, 109, 97, 120, 40, 105, 109, 44, 105, 77, 41, 125,
  39, 32, 45, 43, 91, 45, 49, 93, 32, 49, 50, 56, 32, 32, 45, 109,
  97, 112, 91, 45, 49, 93, 32, 53, 10, 45, 114, 101, 115, 105, 122, 101,
  91, 48, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 51, 44, 49, 32, 45, 97, 112, 112, 108, 121, 95, 103, 97,
  109, 109, 97, 91, 48, 93, 32, 49, 46, 53, 32, 45, 110, 91, 48, 93,
  32, 48, 44, 50, 53, 53, 10, 45, 108, 91, 48, 93, 32, 45, 115, 32,
  122, 32, 45, 102, 114, 97, 109, 101, 32, 53, 44, 49, 50, 44, 54, 52,
  32, 45, 115, 104, 105, 102, 116, 32, 48, 44, 53, 44, 48, 44, 48, 44,
  50, 32, 45, 116, 101, 120, 116, 32, 34, 79, 114, 105, 103, 105, 110, 97,
  108, 32, 115, 101, 113, 117, 101, 110, 99, 101, 34, 44, 53, 44, 48, 44,
  49, 51, 44, 49, 44, 50, 53, 53, 32, 45, 97, 32, 122, 32, 45, 101,
  110, 100, 108, 10, 45, 108, 91, 49, 93, 32, 45, 115, 32, 122, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  32, 49, 44, 49, 48, 48, 37, 32, 45, 102, 91, 45, 49, 93, 32, 39,
  104, 45, 121, 39, 32, 45, 110, 32, 48, 44, 50, 53, 53, 32, 32, 45,
  109, 97, 112, 91, 45, 49, 93, 32, 53, 32, 45, 114, 101, 115, 105, 122,
  101, 91, 45, 49, 93, 32, 53, 44, 64, 123, 48, 44, 104, 125, 44, 49,
  44, 51, 44, 53, 32, 45, 102, 114, 97, 109, 101, 91, 45, 49, 93, 32,
  51, 44, 48, 44, 54, 52, 32, 32, 45, 114, 101, 115, 105, 122, 101, 91,
  45, 49, 93, 32, 49, 48, 48, 37, 44, 64, 123, 48, 44, 104, 125, 44,
  49, 44, 51, 44, 53, 32, 45, 97, 32, 120, 10, 45, 102, 114, 97, 109,
  101, 32, 53, 44, 49, 50, 44, 54, 52, 32, 45, 115, 104, 105, 102, 116,
  32, 48, 44, 53, 44, 48, 44, 48, 44, 50, 10, 45, 116, 101, 120, 116,
  32, 34, 86, 111, 98, 115, 32, 91, 34, 36, 65, 34, 58, 34, 36, 66,
  34, 93, 34, 44, 53, 44, 48, 44, 49, 51, 44, 49, 44, 50, 53, 53,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 97, 32,
  122, 32, 45, 101, 110, 100, 108, 10, 45, 97, 32, 120, 10, 100, 105, 115,
  112, 108, 97, 121, 95, 112, 115, 101, 117, 100, 111, 99, 111, 108, 111, 114,
  32, 58, 10, 65, 61, 123, 114, 111, 117, 110, 100, 40, 64, 123, 45, 49,
  44, 105, 109, 125, 44, 48, 46, 48, 48, 48, 49, 41, 125, 32, 66, 61,
  123, 114, 111, 117, 110, 100, 40, 64, 123, 45, 49, 44, 105, 77, 125, 44,
  48, 46, 48, 48, 48, 49, 41, 125, 32, 45, 110, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 32, 45, 109, 97, 112, 91, 45, 49, 93, 32, 53,
  10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 32, 123, 119, 45, 53,
  48, 45, 53, 125, 44, 123, 104, 47, 52, 45, 53, 125, 44, 123, 119, 45,
  53, 125, 44, 123, 104, 45, 104, 47, 52, 43, 53, 125, 44, 46, 53, 44,
  48, 44, 48, 44, 48, 10, 45, 97, 100, 100, 95, 99, 111, 108, 111, 114,
  98, 97, 114, 91, 45, 49, 93, 32, 123, 119, 45, 53, 48, 125, 44, 123,
  104, 47, 52, 125, 44, 123, 119, 45, 52, 48, 125, 44, 123, 104, 45, 104,
  47, 52, 125, 44, 36, 65, 44, 36, 66, 44, 54, 44, 50, 53, 53, 10,
  100, 105, 115, 112, 108, 97, 121, 95, 99, 111, 108, 111, 114, 100, 101, 112,
  116, 104, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 100, 105,
  115, 112, 108, 97, 121, 32, 116, 104, 101, 32, 51, 68, 32, 105, 109, 97,
  103, 101, 32, 119, 105, 116, 104, 32, 97, 32, 100, 101, 112, 116, 104, 32,
  99, 111, 108, 111, 114, 32, 99, 111, 100, 101, 100, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 72, 61, 123, 100, 42, 36, 49, 125, 32, 45, 99,
  111, 108, 111, 114, 100, 101, 112, 116, 104, 32, 44, 32, 45, 97, 32, 122,
  32, 45, 109, 105, 110, 32, 123, 105, 97, 43, 49, 48, 42, 115, 113, 114,
  116, 40, 105, 118, 41, 125, 32, 45, 110, 32, 48, 44, 50, 53, 53, 32,
  45, 115, 32, 122, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 32,
  123, 119, 45, 53, 48, 45, 53, 125, 44, 123, 104, 47, 52, 45, 53, 125,
  44, 123, 119, 45, 53, 125, 44, 123, 104, 45, 104, 47, 52, 43, 53, 125,
  44, 46, 53, 44, 48, 44, 48, 44, 48, 10, 45, 97, 100, 100, 95, 99,
  111, 108, 111, 114, 98, 97, 114, 91, 45, 49, 93, 32, 123, 119, 45, 53,
  48, 125, 44, 123, 104, 47, 52, 125, 44, 123, 119, 45, 52, 48, 125, 44,
  123, 104, 45, 104, 47, 52, 125, 44, 48, 44, 36, 72, 44, 54, 44, 50,
  53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 97, 100, 100, 95, 99, 111, 108, 111, 114, 98, 97, 114,
  32, 58, 10, 45, 115, 107, 105, 112, 32, 36, 123, 53, 61, 48, 125, 44,
  36, 123, 54, 61, 50, 53, 53, 125, 44, 36, 123, 55, 61, 54, 125, 44,
  36, 123, 56, 61, 50, 53, 53, 125, 44, 36, 123, 57, 61, 34, 34, 125,
  44, 36, 123, 49, 48, 61, 53, 125, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 123, 36, 51, 45, 36,
  49, 125, 44, 123, 36, 52, 45, 36, 50, 125, 32, 45, 108, 91, 45, 49,
  93, 32, 45, 102, 32, 39, 104, 45, 121, 39, 32, 45, 110, 32, 48, 44,
  50, 53, 53, 32, 45, 109, 97, 112, 32, 36, 49, 48, 32, 45, 101, 110,
  100, 108, 10, 45, 102, 114, 97, 109, 101, 91, 49, 93, 32, 49, 44, 49,
  44, 36, 56, 32, 45, 105, 109, 97, 103, 101, 91, 48, 93, 32, 91, 49,
  93, 44, 36, 49, 44, 36, 50, 44, 48, 44, 48, 44, 49, 32, 45, 107,
  91, 48, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 55, 10, 118,
  97, 108, 61, 123, 114, 111, 117, 110, 100, 40, 36, 53, 43, 36, 62, 47,
  40, 36, 55, 45, 49, 41, 42, 40, 36, 54, 45, 36, 53, 41, 44, 46,
  48, 48, 49, 41, 125, 10, 45, 116, 101, 120, 116, 32, 34, 45, 32, 34,
  36, 118, 97, 108, 34, 32, 34, 36, 57, 44, 123, 36, 51, 43, 49, 125,
  44, 123, 36, 52, 45, 36, 62, 42, 40, 36, 52, 45, 36, 50, 45, 53,
  41, 47, 40, 36, 55, 45, 49, 41, 45, 49, 48, 125, 44, 49, 51, 44,
  49, 44, 36, 56, 10, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 108, 111, 99, 97, 108, 95, 100, 105, 102,
  102, 117, 115, 105, 111, 110, 95, 99, 111, 101, 102, 102, 105, 99, 105, 101,
  110, 116, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49,
  61, 50, 125, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 46, 53, 125,
  62, 61, 48, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 76, 111,
  99, 97, 108, 32, 100, 105, 102, 102, 117, 115, 105, 111, 110, 32, 99, 111,
  101, 102, 102, 105, 99, 105, 101, 110, 116, 32, 101, 115, 116, 105, 109, 97,
  116, 105, 111, 110, 32, 117, 115, 105, 110, 103, 32, 115, 99, 97, 108, 101,
  32, 36, 49, 32, 97, 110, 100, 32, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 32, 36, 50, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 108,
  91, 48, 93, 32, 45, 115, 32, 122, 32, 45, 108, 97, 112, 108, 97, 99,
  105, 97, 110, 32, 45, 97, 32, 122, 32, 45, 101, 110, 100, 108, 10, 45,
  45, 108, 91, 48, 93, 32, 45, 115, 32, 122, 32, 45, 103, 114, 97, 100,
  105, 101, 110, 116, 95, 110, 111, 114, 109, 32, 45, 97, 32, 122, 32, 45,
  115, 113, 114, 32, 45, 101, 110, 100, 108, 10, 45, 103, 114, 97, 100, 105,
  101, 110, 116, 91, 48, 93, 32, 122, 44, 49, 10, 45, 108, 91, 48, 44,
  49, 93, 10, 82, 61, 123, 64, 123, 49, 44, 105, 97, 125, 43, 36, 50,
  42, 115, 113, 114, 116, 40, 64, 123, 49, 44, 118, 125, 41, 125, 10, 45,
  97, 32, 99, 32, 45, 102, 32, 39, 98, 61, 105, 40, 120, 44, 121, 44,
  122, 44, 48, 41, 59, 97, 61, 105, 40, 120, 44, 121, 44, 122, 44, 49,
  41, 59, 105, 102, 40, 97, 98, 115, 40, 97, 41, 62, 97, 98, 115, 40,
  98, 41, 44, 98, 47, 97, 44, 105, 102, 40, 97, 98, 115, 40, 98, 41,
  62, 36, 82, 44, 49, 47, 40, 98, 47, 97, 41, 44, 48, 41, 41, 39,
  10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48, 10, 45, 101, 110,
  100, 108, 10, 45, 42, 91, 48, 93, 32, 91, 49, 93, 32, 45, 98, 108,
  117, 114, 32, 36, 49, 44, 49, 44, 49, 32, 45, 109, 97, 120, 91, 49,
  93, 32, 123, 64, 123, 49, 44, 105, 97, 125, 43, 36, 50, 42, 115, 113,
  114, 116, 40, 64, 123, 49, 44, 118, 125, 41, 125, 32, 32, 45, 47, 10,
  45, 99, 104, 97, 110, 110, 101, 108, 115, 32, 48, 10, 45, 118, 32, 43,
  32, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 108, 100, 99,
  32, 58, 10, 45, 108, 111, 99, 97, 108, 95, 100, 105, 102, 102, 117, 115,
  105, 111, 110, 95, 99, 111, 101, 102, 102, 105, 99, 105, 101, 110, 116, 32,
  36, 42, 10, 100, 105, 115, 112, 108, 97, 121, 95, 108, 100, 99, 32, 58,
  10, 45, 45, 108, 100, 99, 32, 53, 44, 51, 32, 65, 61, 123, 114, 111,
  117, 110, 100, 40, 64, 123, 45, 49, 44, 105, 109, 125, 44, 48, 46, 48,
  48, 49, 41, 125, 32, 66, 61, 123, 114, 111, 117, 110, 100, 40, 64, 123,
  45, 49, 44, 105, 77, 125, 44, 48, 46, 48, 48, 49, 41, 125, 32, 45,
  42, 91, 45, 49, 93, 32, 39, 123, 49, 50, 56, 47, 109, 97, 120, 40,
  105, 109, 44, 105, 77, 41, 125, 39, 32, 45, 43, 91, 45, 49, 93, 32,
  49, 50, 56, 32, 32, 45, 109, 97, 112, 91, 45, 49, 93, 32, 53, 10,
  45, 114, 101, 115, 105, 122, 101, 91, 48, 93, 32, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 51, 44, 49, 32, 45, 97,
  112, 112, 108, 121, 95, 103, 97, 109, 109, 97, 91, 48, 93, 32, 49, 46,
  53, 32, 45, 110, 91, 48, 93, 32, 48, 44, 50, 53, 53, 10, 45, 108,
  91, 48, 93, 32, 45, 115, 32, 122, 32, 45, 102, 114, 97, 109, 101, 32,
  53, 44, 49, 50, 44, 54, 52, 32, 45, 115, 104, 105, 102, 116, 32, 48,
  44, 53, 44, 48, 44, 48, 44, 50, 32, 45, 116, 101, 120, 116, 32, 34,
  79, 114, 105, 103, 105, 110, 97, 108, 32, 115, 101, 113, 117, 101, 110, 99,
  101, 34, 44, 53, 44, 48, 44, 49, 51, 44, 49, 44, 50, 53, 53, 32,
  45, 97, 32, 122, 32, 45, 101, 110, 100, 108, 10, 45, 108, 91, 49, 93,
  32, 45, 115, 32, 122, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 49, 44, 49, 48, 48, 37, 32, 45,
  102, 91, 45, 49, 93, 32, 39, 104, 45, 121, 39, 32, 45, 110, 32, 48,
  44, 50, 53, 53, 32, 32, 45, 109, 97, 112, 91, 45, 49, 93, 32, 53,
  32, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 53, 44, 64,
  123, 48, 44, 104, 125, 44, 49, 44, 51, 44, 53, 32, 45, 102, 114, 97,
  109, 101, 91, 45, 49, 93, 32, 51, 44, 48, 44, 54, 52, 32, 32, 45,
  114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44,
  64, 123, 48, 44, 104, 125, 44, 49, 44, 51, 44, 53, 32, 45, 97, 32,
  120, 10, 45, 102, 114, 97, 109, 101, 32, 53, 44, 49, 50, 44, 54, 52,
  32, 45, 115, 104, 105, 102, 116, 32, 48, 44, 53, 44, 48, 44, 48, 44,
  50, 10, 45, 116, 101, 120, 116, 32, 34, 76, 111, 99, 97, 108, 32, 100,
  105, 102, 102, 117, 115, 105, 111, 110, 32, 99, 111, 101, 102, 102, 105, 99,
  105, 101, 110, 116, 32, 91, 34, 36, 65, 34, 58, 34, 36, 66, 34, 93,
  34, 44, 53, 44, 48, 44, 49, 51, 44, 49, 44, 50, 53, 53, 32, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 97, 32, 122, 32,
  45, 101, 110, 100, 108, 10, 45, 97, 32, 120, 10, 112, 114, 105, 110, 116,
  95, 112, 115, 110, 114, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  49, 61, 50, 53, 53, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  67, 111, 109, 112, 117, 116, 101, 32, 80, 83, 78, 82, 32, 119, 105, 116,
  104, 32, 105, 109, 97, 103, 101, 32, 48, 32, 97, 110, 100, 32, 112, 114,
  105, 110, 116, 32, 105, 116, 32, 111, 110, 32, 116, 104, 101, 32, 111, 116,
  104, 101, 114, 32, 105, 109, 97, 103, 101, 115, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 45, 112, 115, 110, 114, 32, 36, 49, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 64, 35, 45, 50, 125, 32, 45, 116, 101, 120, 116,
  95, 111, 117, 116, 108, 105, 110, 101, 91, 123, 36, 62, 43, 49, 125, 93,
  32, 34, 80, 83, 78, 82, 58, 34, 123, 114, 111, 117, 110, 100, 40, 64,
  123, 45, 49, 44, 105, 40, 48, 44, 36, 62, 43, 49, 41, 125, 44, 46,
  48, 49, 41, 125, 34, 100, 66, 34, 44, 53, 44, 53, 44, 51, 48, 44,
  49, 32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 118, 32, 43, 10, 110, 111, 105, 115, 101, 95, 115, 116, 100, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 117, 116,
  101, 32, 110, 111, 105, 115, 101, 32, 118, 97, 114, 105, 97, 110, 99, 101,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 45, 108, 97, 112, 108, 97, 99,
  105, 97, 110, 32, 45, 105, 102, 32, 123, 64, 123, 48, 44, 100, 125, 61,
  61, 49, 125, 32, 32, 45, 117, 32, 123, 64, 123, 45, 109, 97, 100, 91,
  45, 49, 93, 125, 47, 115, 113, 114, 116, 40, 50, 48, 46, 48, 41, 125,
  32, 45, 101, 108, 115, 101, 32, 45, 117, 32, 123, 64, 123, 45, 109, 97,
  100, 91, 45, 49, 93, 125, 47, 115, 113, 114, 116, 40, 52, 50, 46, 48,
  41, 125, 32, 45, 101, 110, 100, 105, 102, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 118, 32, 43, 10, 100, 101, 110, 111, 105, 115, 101, 95, 112,
  97, 116, 99, 104, 95, 100, 105, 99, 116, 58, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 49, 61, 56, 125, 44, 36, 123, 50, 61, 56, 125, 44, 36,
  123, 51, 61, 49, 46, 49, 125, 44, 36, 123, 52, 61, 49, 46, 49, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 101, 110, 111, 105, 115,
  105, 110, 103, 32, 117, 115, 105, 110, 103, 32, 97, 32, 100, 105, 99, 116,
  105, 111, 110, 110, 97, 114, 121, 32, 111, 102, 32, 34, 36, 49, 34, 120,
  34, 36, 49, 34, 32, 112, 97, 116, 99, 104, 101, 115, 32, 119, 105, 116,
  104, 32, 34, 36, 50, 34, 32, 115, 104, 105, 102, 116, 115, 44, 32, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 32, 36, 51, 120, 40, 110, 111, 105,
  115, 101, 32, 115, 116, 100, 41, 32, 102, 111, 114, 32, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 115, 32, 97, 110, 100, 32, 36, 52, 120, 40, 115,
  116, 100, 41, 32, 102, 111, 114, 32, 99, 111, 101, 102, 102, 105, 99, 105,
  101, 110, 116, 115, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 83, 105,
  103, 109, 97, 61, 64, 123, 45, 110, 111, 105, 115, 101, 95, 115, 116, 100,
  91, 48, 93, 125, 10, 45, 45, 99, 114, 111, 112, 32, 48, 44, 48, 44,
  36, 49, 44, 49, 48, 48, 37, 32, 45, 109, 105, 114, 114, 111, 114, 91,
  45, 49, 93, 32, 120, 32, 45, 114, 101, 118, 101, 114, 115, 101, 32, 45,
  45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 123, 119, 45, 36, 49, 45,
  49, 125, 44, 48, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45,
  109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 120, 32, 45, 97, 32,
  120, 10, 45, 45, 99, 114, 111, 112, 32, 48, 44, 48, 44, 49, 48, 48,
  37, 44, 36, 49, 32, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93,
  32, 121, 32, 45, 114, 101, 118, 101, 114, 115, 101, 32, 45, 45, 99, 114,
  111, 112, 91, 45, 49, 93, 32, 48, 44, 123, 104, 45, 36, 49, 45, 49,
  125, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 109, 105, 114,
  114, 111, 114, 91, 45, 49, 93, 32, 121, 32, 45, 97, 32, 121, 10, 111,
  87, 61, 64, 123, 48, 44, 119, 125, 32, 111, 72, 61, 64, 123, 48, 44,
  104, 125, 32, 111, 83, 61, 64, 123, 48, 44, 115, 125, 32, 110, 87, 61,
  123, 36, 49, 42, 114, 111, 117, 110, 100, 40, 36, 111, 87, 47, 36, 49,
  44, 49, 44, 49, 41, 125, 32, 110, 72, 61, 123, 36, 49, 42, 114, 111,
  117, 110, 100, 40, 36, 111, 72, 47, 36, 49, 44, 49, 44, 49, 41, 125,
  10, 45, 45, 99, 114, 111, 112, 32, 123, 50, 42, 36, 111, 87, 45, 36,
  110, 87, 125, 44, 48, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32,
  45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 120, 32, 45, 97,
  32, 120, 10, 45, 45, 99, 114, 111, 112, 32, 48, 44, 123, 50, 42, 36,
  111, 72, 45, 36, 110, 72, 125, 44, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 32, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 121, 32,
  45, 97, 32, 121, 10, 78, 116, 105, 108, 101, 88, 61, 123, 114, 111, 117,
  110, 100, 40, 36, 110, 87, 47, 36, 49, 41, 125, 32, 32, 78, 116, 105,
  108, 101, 89, 61, 123, 114, 111, 117, 110, 100, 40, 36, 110, 72, 47, 36,
  49, 41, 125, 10, 45, 45, 108, 91, 45, 49, 93, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 36, 50, 10, 45, 105, 102, 32, 123, 36, 50, 62, 49,
  125, 32, 100, 120, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44,
  36, 49, 41, 41, 125, 32, 100, 121, 61, 123, 114, 111, 117, 110, 100, 40,
  63, 40, 48, 44, 36, 49, 41, 41, 125, 32, 45, 101, 108, 115, 101, 32,
  100, 120, 61, 48, 32, 100, 121, 61, 48, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93, 32, 36, 100, 120, 44,
  36, 100, 121, 44, 48, 44, 48, 44, 50, 10, 45, 115, 112, 108, 105, 116,
  95, 116, 105, 108, 101, 115, 91, 45, 49, 93, 32, 36, 78, 116, 105, 108,
  101, 88, 44, 36, 78, 116, 105, 108, 101, 89, 32, 112, 87, 61, 64, 123,
  49, 44, 119, 125, 32, 112, 72, 61, 64, 123, 49, 44, 104, 125, 10, 45,
  100, 111, 110, 101, 32, 45, 114, 109, 91, 48, 93, 10, 45, 117, 110, 114,
  111, 108, 108, 32, 121, 32, 45, 97, 32, 120, 32, 110, 61, 64, 123, 45,
  49, 44, 119, 125, 32, 45, 45, 32, 39, 105, 97, 39, 32, 45, 45, 116,
  114, 97, 110, 115, 112, 111, 115, 101, 91, 45, 49, 93, 32, 45, 42, 42,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 47, 32, 36, 110, 32, 45, 101,
  105, 103, 101, 110, 10, 45, 108, 91, 45, 50, 93, 32, 45, 117, 110, 114,
  111, 108, 108, 32, 120, 32, 45, 115, 113, 114, 116, 32, 45, 103, 116, 32,
  123, 36, 51, 42, 36, 83, 105, 103, 109, 97, 125, 32, 45, 102, 32, 39,
  97, 98, 115, 40, 105, 40, 120, 43, 49, 41, 45, 105, 40, 120, 41, 41,
  39, 10, 84, 61, 64, 123, 45, 49, 44, 67, 125, 32, 52, 32, 45, 102,
  91, 45, 49, 93, 32, 36, 84, 32, 84, 61, 64, 123, 45, 49, 44, 105,
  40, 48, 41, 125, 32, 45, 101, 110, 100, 108, 10, 45, 105, 102, 32, 123,
  36, 84, 61, 61, 48, 125, 32, 84, 61, 49, 48, 48, 37, 32, 45, 101,
  110, 100, 105, 102, 32, 45, 107, 91, 45, 49, 93, 32, 45, 99, 111, 108,
  117, 109, 110, 115, 32, 48, 44, 36, 84, 10, 45, 101, 110, 100, 108, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 36, 50, 10, 45, 105, 102, 32, 123,
  36, 50, 62, 49, 125, 32, 100, 120, 61, 123, 114, 111, 117, 110, 100, 40,
  63, 40, 48, 44, 36, 49, 41, 41, 125, 32, 100, 121, 61, 123, 114, 111,
  117, 110, 100, 40, 63, 40, 48, 44, 36, 49, 41, 41, 125, 32, 45, 101,
  108, 115, 101, 32, 100, 120, 61, 48, 32, 100, 121, 61, 48, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 45, 115, 104, 105, 102, 116, 91, 48, 93, 32,
  36, 100, 120, 44, 36, 100, 121, 44, 48, 44, 48, 44, 50, 10, 45, 108,
  91, 49, 44, 45, 49, 93, 10, 45, 108, 91, 49, 93, 32, 45, 115, 112,
  108, 105, 116, 95, 116, 105, 108, 101, 115, 32, 36, 78, 116, 105, 108, 101,
  88, 44, 36, 78, 116, 105, 108, 101, 89, 32, 45, 117, 110, 114, 111, 108,
  108, 32, 121, 32, 45, 97, 32, 120, 32, 45, 101, 110, 100, 108, 10, 45,
  116, 114, 97, 110, 115, 112, 111, 115, 101, 91, 48, 93, 32, 45, 45, 42,
  42, 10, 116, 61, 64, 123, 45, 109, 97, 100, 91, 45, 49, 93, 125, 10,
  45, 102, 91, 45, 49, 93, 32, 39, 105, 102, 40, 97, 98, 115, 40, 105,
  41, 60, 36, 52, 42, 36, 116, 44, 48, 44, 105, 41, 39, 10, 45, 114,
  109, 91, 49, 93, 32, 45, 116, 114, 97, 110, 115, 112, 111, 115, 101, 91,
  48, 93, 32, 45, 45, 42, 42, 32, 45, 114, 109, 91, 45, 50, 93, 10,
  45, 101, 110, 100, 108, 10, 45, 108, 91, 45, 49, 93, 10, 45, 115, 32,
  120, 32, 45, 114, 101, 115, 105, 122, 101, 32, 36, 112, 87, 44, 36, 112,
  72, 44, 49, 44, 36, 111, 83, 44, 45, 49, 10, 45, 97, 112, 112, 101,
  110, 100, 95, 116, 105, 108, 101, 115, 32, 36, 78, 116, 105, 108, 101, 88,
  44, 36, 78, 116, 105, 108, 101, 89, 10, 45, 115, 104, 105, 102, 116, 32,
  123, 45, 36, 100, 120, 125, 44, 123, 45, 36, 100, 121, 125, 44, 48, 44,
  48, 44, 50, 10, 45, 101, 110, 100, 108, 10, 45, 100, 111, 110, 101, 10,
  45, 114, 109, 91, 48, 44, 49, 93, 10, 45, 43, 32, 45, 47, 32, 36,
  50, 10, 45, 99, 114, 111, 112, 32, 123, 36, 49, 43, 49, 125, 44, 123,
  36, 49, 43, 49, 125, 44, 123, 36, 111, 87, 45, 36, 49, 45, 50, 125,
  44, 123, 36, 111, 72, 45, 36, 49, 45, 50, 125, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 105, 117, 119,
  116, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 51, 125, 44,
  36, 123, 50, 61, 51, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  67, 111, 109, 112, 117, 116, 101, 32, 105, 115, 111, 116, 114, 111, 112, 105,
  99, 32, 117, 110, 100, 101, 99, 105, 109, 97, 116, 101, 100, 32, 119, 97,
  118, 101, 108, 101, 116, 32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 60, 93, 10, 53, 48, 10, 45, 108, 91, 45, 49,
  93, 10, 45, 102, 32, 39, 105, 102, 40, 120, 61, 61, 119, 47, 50, 124,
  120, 61, 61, 119, 47, 50, 45, 49, 44, 49, 44, 48, 41, 39, 32, 45,
  105, 32, 91, 48, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 50,
  32, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 45, 49, 93, 32, 91,
  48, 93, 32, 45, 100, 111, 110, 101, 10, 45, 107, 91, 45, 49, 93, 32,
  45, 97, 117, 116, 111, 99, 114, 111, 112, 32, 48, 32, 45, 47, 32, 123,
  105, 97, 42, 119, 125, 10, 45, 101, 110, 100, 108, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 36, 49, 45, 49, 125, 10, 45, 108, 91, 45, 49,
  44, 45, 50, 93, 10, 45, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91,
  48, 93, 32, 91, 49, 93, 10, 45, 121, 91, 49, 93, 32, 121, 32, 45,
  99, 111, 110, 118, 111, 108, 118, 101, 91, 45, 49, 93, 32, 91, 49, 93,
  10, 45, 45, 45, 91, 48, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109,
  91, 48, 93, 32, 45, 114, 101, 118, 101, 114, 115, 101, 10, 45, 101, 110,
  100, 108, 10, 45, 108, 91, 45, 49, 93, 32, 45, 121, 32, 121, 32, 49,
  48, 48, 37, 32, 45, 97, 32, 120, 32, 45, 115, 32, 121, 32, 45, 115,
  32, 120, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 97, 32, 120, 32,
  45, 101, 110, 100, 108, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 114, 101, 118, 101, 114, 115, 101, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 105, 117,
  119, 116, 95, 115, 116, 100, 58, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 115,
  105, 103, 109, 97, 61, 64, 123, 45, 110, 111, 105, 115, 101, 95, 115, 116,
  100, 125, 10, 45, 102, 32, 48, 32, 45, 110, 111, 105, 115, 101, 32, 36,
  115, 105, 103, 109, 97, 32, 45, 105, 117, 119, 116, 32, 36, 49, 44, 36,
  50, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 32, 120, 61, 123, 115, 113, 114, 116, 40, 105, 118, 41, 125,
  32, 45, 114, 109, 32, 49, 32, 45, 102, 32, 36, 120, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 97, 32, 120, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 100,
  101, 110, 111, 105, 115, 101, 95, 105, 117, 119, 116, 58, 32, 45, 99, 104,
  101, 99, 107, 32, 34, 36, 123, 49, 61, 49, 46, 52, 125, 62, 48, 38,
  38, 36, 123, 50, 61, 52, 125, 62, 50, 38, 38, 36, 123, 51, 61, 51,
  125, 62, 49, 34, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 101,
  110, 111, 105, 115, 101, 32, 117, 115, 105, 110, 103, 32, 116, 104, 101, 32,
  105, 115, 111, 116, 114, 111, 112, 105, 99, 32, 117, 110, 100, 101, 99, 105,
  109, 97, 116, 101, 100, 32, 66, 34, 36, 51, 34, 32, 115, 112, 108, 105,
  110, 101, 32, 119, 97, 118, 101, 108, 101, 116, 32, 116, 114, 97, 110, 115,
  102, 111, 114, 109, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 105,
  117, 119, 116, 95, 115, 116, 100, 91, 48, 93, 32, 36, 50, 44, 36, 51,
  32, 45, 114, 101, 118, 101, 114, 115, 101, 10, 45, 105, 117, 119, 116, 91,
  45, 49, 93, 32, 36, 50, 44, 36, 51, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 64, 35, 45, 50, 125, 32, 45, 116, 104, 114, 101, 115, 104,
  111, 108, 100, 91, 123, 36, 62, 43, 50, 125, 93, 32, 123, 36, 49, 42,
  64, 123, 48, 44, 105, 40, 36, 62, 41, 125, 125, 44, 49, 32, 45, 100,
  111, 110, 101, 10, 45, 43, 91, 49, 45, 45, 49, 93, 10, 45, 114, 109,
  91, 48, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  32, 45, 118, 32, 43, 10, 99, 111, 110, 116, 111, 117, 114, 50, 100, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 46, 49, 125, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 102, 32, 39, 105, 102, 40, 97, 98, 115,
  40, 105, 40, 120, 44, 121, 41, 45, 105, 40, 120, 43, 49, 44, 121, 43,
  49, 41, 41, 62, 36, 49, 124, 124, 97, 98, 115, 40, 105, 40, 120, 44,
  121, 41, 45, 105, 40, 120, 43, 49, 44, 121, 41, 41, 62, 36, 49, 44,
  49, 44, 48, 41, 39, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 115, 101, 103, 109, 101, 110, 116, 95, 115,
  110, 97, 107, 101, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  49, 48, 125, 44, 36, 123, 50, 61, 49, 125, 44, 36, 123, 51, 61, 49,
  48, 48, 125, 44, 36, 123, 52, 61, 53, 48, 37, 125, 44, 36, 123, 53,
  61, 49, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 83, 101, 103,
  109, 101, 110, 116, 32, 116, 104, 101, 32, 105, 109, 97, 103, 101, 32, 117,
  115, 105, 110, 103, 32, 97, 99, 116, 105, 118, 101, 32, 99, 111, 110, 116,
  111, 117, 114, 115, 32, 119, 105, 116, 104, 111, 117, 116, 32, 101, 100, 103,
  101, 115, 32, 117, 115, 105, 110, 103, 32, 36, 49, 32, 105, 116, 101, 114,
  97, 116, 105, 111, 110, 115, 32, 97, 110, 100, 32, 116, 105, 109, 101, 32,
  115, 116, 101, 112, 32, 36, 50, 44, 32, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 36, 51, 32, 97, 110, 100, 32, 105, 110, 105, 116, 105,
  97, 108, 105, 122, 101, 32, 119, 105, 116, 104, 32, 116, 104, 114, 101, 115,
  104, 111, 108, 100, 32, 111, 102, 32, 36, 52, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 10, 45,
  45, 98, 108, 117, 114, 32, 36, 53, 32, 45, 103, 116, 91, 45, 49, 93,
  32, 36, 52, 10, 45, 108, 91, 45, 49, 93, 32, 45, 45, 100, 105, 115,
  116, 97, 110, 99, 101, 32, 48, 32, 45, 110, 101, 103, 97, 116, 105, 118,
  101, 91, 48, 93, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 48,
  93, 32, 48, 32, 45, 42, 91, 48, 93, 32, 45, 49, 32, 45, 43, 32,
  45, 101, 110, 100, 108, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49,
  10, 45, 45, 108, 116, 91, 45, 49, 93, 32, 48, 32, 45, 98, 108, 117,
  114, 91, 45, 49, 93, 32, 36, 53, 32, 45, 45, 42, 91, 48, 44, 45,
  49, 93, 32, 115, 119, 120, 61, 64, 123, 45, 49, 44, 105, 97, 125, 32,
  115, 119, 61, 64, 123, 45, 50, 44, 105, 97, 125, 32, 77, 49, 61, 123,
  36, 115, 119, 120, 47, 36, 115, 119, 125, 10, 45, 115, 113, 114, 91, 45,
  49, 93, 32, 115, 119, 120, 50, 61, 64, 123, 45, 49, 44, 105, 97, 125,
  32, 32, 83, 49, 61, 123, 109, 97, 120, 40, 49, 101, 45, 51, 44, 36,
  115, 119, 120, 50, 47, 36, 115, 119, 94, 50, 45, 36, 77, 49, 94, 50,
  41, 125, 32, 45, 114, 109, 91, 45, 49, 44, 45, 50, 93, 10, 45, 45,
  103, 116, 91, 45, 49, 93, 32, 48, 32, 45, 98, 108, 117, 114, 91, 45,
  49, 93, 32, 36, 53, 32, 45, 45, 42, 91, 48, 44, 45, 49, 93, 32,
  115, 119, 120, 61, 64, 123, 45, 49, 44, 105, 97, 125, 32, 115, 119, 61,
  64, 123, 45, 50, 44, 105, 97, 125, 32, 77, 50, 61, 123, 36, 115, 119,
  120, 47, 36, 115, 119, 125, 10, 45, 115, 113, 114, 91, 45, 49, 93, 32,
  115, 119, 120, 50, 61, 64, 123, 45, 49, 44, 105, 97, 125, 32, 32, 83,
  50, 61, 123, 109, 97, 120, 40, 49, 101, 45, 51, 44, 36, 115, 119, 120,
  50, 47, 36, 115, 119, 94, 50, 45, 36, 77, 50, 94, 50, 41, 125, 32,
  45, 114, 109, 91, 45, 49, 44, 45, 50, 93, 10, 45, 45, 105, 101, 101,
  91, 45, 49, 93, 10, 45, 45, 102, 91, 48, 93, 32, 39, 40, 49, 46,
  48, 47, 36, 51, 41, 42, 40, 40, 40, 105, 40, 120, 44, 121, 41, 45,
  36, 77, 49, 41, 94, 50, 41, 47, 36, 83, 49, 45, 40, 40, 105, 40,
  120, 44, 121, 41, 45, 36, 77, 50, 41, 94, 50, 41, 47, 36, 83, 50,
  41, 39, 10, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 42, 91,
  45, 49, 93, 32, 123, 36, 50, 47, 40, 48, 46, 48, 48, 48, 49, 43,
  109, 97, 120, 40, 97, 98, 115, 40, 64, 123, 45, 49, 44, 109, 125, 41,
  44, 97, 98, 115, 40, 64, 123, 45, 49, 44, 77, 125, 41, 41, 41, 125,
  10, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 100, 111, 110, 101,
  10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 53, 32, 45, 103,
  116, 91, 45, 49, 93, 32, 48, 32, 45, 114, 109, 91, 48, 93, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  115, 101, 103, 109, 101, 110, 116, 95, 99, 101, 108, 108, 115, 58, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 49, 61, 53, 125, 44, 36, 123, 50, 61,
  49, 48, 37, 125, 10, 45, 98, 108, 117, 114, 32, 36, 49, 10, 45, 45,
  108, 91, 48, 93, 10, 45, 45, 109, 97, 120, 95, 112, 97, 116, 99, 104,
  32, 44, 32, 45, 103, 116, 91, 48, 93, 32, 36, 50, 32, 45, 42, 32,
  45, 45, 100, 105, 115, 116, 97, 110, 99, 101, 32, 49, 32, 45, 109, 117,
  108, 91, 45, 49, 93, 32, 45, 49, 32, 45, 108, 97, 98, 101, 108, 91,
  45, 50, 93, 32, 48, 10, 45, 119, 97, 116, 101, 114, 115, 104, 101, 100,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 49, 93,
  10, 45, 101, 110, 100, 108, 10, 45, 103, 116, 91, 48, 93, 32, 36, 50,
  10, 45, 42, 10, 95, 99, 104, 97, 108, 108, 101, 110, 103, 101, 58, 10,
  49, 48, 56, 44, 56, 54, 44, 49, 44, 51, 32, 45, 108, 91, 45, 49,
  93, 32, 45, 102, 114, 97, 99, 116, 105, 111, 110, 97, 108, 95, 98, 114,
  111, 119, 110, 105, 97, 110, 95, 109, 111, 116, 105, 111, 110, 32, 46, 50,
  53, 32, 32, 45, 110, 32, 48, 44, 49, 50, 56, 32, 45, 45, 110, 111,
  114, 109, 32, 45, 103, 116, 91, 45, 49, 93, 32, 54, 48, 37, 32, 45,
  42, 32, 45, 114, 101, 115, 105, 122, 101, 32, 49, 48, 56, 48, 44, 56,
  54, 48, 44, 49, 44, 51, 44, 49, 32, 32, 45, 45, 108, 91, 45, 49,
  93, 32, 45, 98, 108, 117, 114, 32, 49, 48, 32, 45, 115, 104, 105, 102,
  116, 91, 45, 49, 93, 32, 49, 48, 44, 49, 48, 32, 45, 101, 110, 100,
  108, 32, 45, 109, 97, 120, 32, 45, 99, 114, 111, 112, 32, 49, 48, 44,
  49, 48, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 110, 101,
  103, 97, 116, 105, 118, 101, 32, 45, 101, 110, 100, 108, 32, 45, 110, 32,
  48, 44, 50, 53, 53, 10, 112, 101, 114, 105, 111, 100, 105, 99, 95, 100,
  111, 116, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61,
  54, 125, 44, 36, 123, 50, 61, 52, 125, 44, 36, 123, 51, 61, 46, 53,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 71, 101, 110, 101, 114,
  97, 116, 101, 32, 97, 32, 112, 101, 114, 105, 111, 100, 105, 99, 32, 100,
  111, 116, 32, 112, 97, 116, 116, 101, 114, 110, 32, 119, 105, 116, 104, 32,
  34, 36, 49, 34, 32, 97, 110, 103, 108, 101, 115, 44, 32, 115, 99, 97,
  108, 101, 32, 34, 36, 50, 34, 44, 32, 97, 110, 100, 32, 111, 114, 105,
  101, 110, 116, 97, 116, 105, 111, 110, 32, 34, 36, 51, 34, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 115, 32, 99, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45,
  114, 101, 115, 105, 122, 101, 32, 123, 109, 97, 120, 40, 119, 44, 104, 41,
  125, 44, 123, 109, 97, 120, 40, 119, 44, 104, 41, 125, 44, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 48, 10, 45, 108, 91, 45, 49, 93, 10,
  45, 102, 32, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 10,
  45, 99, 105, 114, 99, 108, 101, 32, 123, 119, 42, 40, 46, 53, 43, 46,
  53, 47, 36, 50, 42, 99, 111, 115, 40, 50, 42, 112, 105, 42, 40, 36,
  62, 43, 36, 51, 47, 49, 56, 48, 42, 112, 105, 41, 47, 36, 49, 41,
  41, 125, 44, 123, 119, 42, 40, 46, 53, 43, 46, 53, 47, 36, 50, 42,
  115, 105, 110, 40, 50, 42, 112, 105, 42, 40, 36, 62, 43, 36, 51, 47,
  49, 56, 48, 42, 112, 105, 41, 47, 36, 49, 41, 41, 125, 44, 48, 44,
  49, 44, 50, 53, 53, 10, 45, 100, 111, 110, 101, 10, 45, 102, 102, 116,
  32, 45, 97, 32, 99, 32, 45, 110, 111, 114, 109, 32, 45, 102, 102, 116,
  115, 104, 105, 102, 116, 32, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45,
  101, 110, 100, 108, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93,
  32, 91, 48, 93, 44, 48, 10, 45, 107, 91, 45, 49, 93, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 97, 32, 99, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  114, 97, 121, 115, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  71, 101, 110, 101, 114, 97, 116, 101, 32, 97, 32, 114, 97, 121, 32, 112,
  97, 116, 116, 101, 114, 110, 32, 99, 101, 110, 116, 101, 114, 101, 100, 32,
  105, 110, 32, 40, 36, 49, 44, 36, 50, 41, 34, 10, 45, 102, 32, 39,
  116, 61, 97, 116, 97, 110, 50, 40, 121, 45, 36, 50, 44, 120, 45, 36,
  49, 41, 59, 115, 105, 110, 40, 36, 51, 42, 116, 43, 36, 52, 41, 39,
  10, 102, 114, 97, 99, 116, 105, 111, 110, 97, 108, 95, 98, 114, 111, 119,
  110, 105, 97, 110, 95, 109, 111, 116, 105, 111, 110, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 36, 123, 49, 61, 46, 53, 125, 44, 36, 123, 50, 61,
  49, 125, 32, 45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48,
  38, 38, 36, 49, 60, 61, 49, 34, 32, 45, 99, 104, 101, 99, 107, 32,
  34, 36, 50, 62, 48, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 102,
  32, 48, 32, 45, 110, 111, 105, 115, 101, 32, 49, 10, 45, 102, 102, 116,
  32, 45, 102, 102, 116, 115, 104, 105, 102, 116, 10, 45, 105, 102, 32, 123,
  64, 123, 48, 44, 100, 125, 61, 61, 49, 125, 10, 45, 102, 32, 39, 114,
  120, 61, 120, 45, 119, 47, 50, 59, 114, 121, 61, 121, 45, 104, 47, 50,
  59, 105, 42, 40, 36, 50, 43, 115, 113, 114, 116, 40, 114, 120, 42, 114,
  120, 43, 114, 121, 42, 114, 121, 41, 41, 94, 40, 45, 50, 42, 36, 49,
  45, 49, 41, 39, 10, 45, 101, 108, 115, 101, 10, 45, 102, 32, 39, 114,
  120, 61, 120, 45, 119, 47, 50, 59, 114, 121, 61, 121, 45, 104, 47, 50,
  59, 114, 122, 61, 122, 45, 100, 47, 50, 59, 105, 42, 40, 36, 50, 43,
  115, 113, 114, 116, 40, 114, 120, 42, 114, 120, 43, 114, 121, 42, 114, 121,
  43, 114, 122, 42, 114, 122, 41, 41, 94, 40, 45, 50, 42, 36, 49, 45,
  49, 41, 39, 10, 45, 101, 110, 100, 105, 102, 10, 45, 102, 102, 116, 115,
  104, 105, 102, 116, 32, 45, 105, 102, 102, 116, 10, 45, 107, 91, 48, 93,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 99, 108, 111, 117, 100, 115, 32, 58, 32, 45, 115, 107, 105, 112,
  32, 36, 123, 49, 61, 53, 48, 37, 125, 44, 36, 123, 50, 61, 49, 125,
  44, 36, 123, 51, 61, 46, 53, 125, 44, 36, 123, 52, 61, 49, 125, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 48, 10, 45, 102, 114, 97, 99, 116, 105, 111, 110, 97, 108, 95, 98,
  114, 111, 119, 110, 105, 97, 110, 95, 109, 111, 116, 105, 111, 110, 32, 36,
  51, 44, 36, 52, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 32, 45,
  109, 105, 110, 32, 36, 49, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101,
  32, 45, 114, 101, 115, 105, 122, 101, 32, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 44, 52, 10, 45, 110, 32, 48, 44, 50, 53, 53, 32,
  45, 115, 32, 99, 32, 45, 110, 91, 48, 45, 50, 93, 32, 49, 57, 48,
  44, 50, 53, 53, 32, 32, 45, 110, 91, 51, 93, 32, 48, 44, 50, 53,
  53, 32, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 99, 108, 101, 97, 114, 98, 108, 117,
  101, 115, 107, 121, 32, 58, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 49, 44,
  50, 44, 49, 44, 51, 32, 45, 102, 91, 45, 49, 93, 32, 39, 54, 51,
  44, 55, 48, 44, 49, 50, 48, 44, 49, 52, 52, 44, 49, 57, 48, 44,
  50, 49, 53, 39, 32, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93,
  32, 91, 48, 93, 44, 53, 32, 45, 107, 91, 45, 49, 93, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 119,
  97, 118, 101, 108, 101, 110, 103, 116, 104, 95, 99, 111, 108, 111, 114, 58,
  10, 45, 118, 32, 45, 10, 45, 105, 102, 32, 123, 36, 49, 62, 61, 51,
  56, 48, 38, 36, 49, 60, 52, 52, 48, 125, 10, 82, 61, 123, 45, 49,
  42, 40, 36, 49, 45, 52, 52, 48, 41, 47, 40, 52, 52, 48, 45, 51,
  56, 48, 41, 125, 10, 71, 61, 48, 10, 66, 61, 49, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 62, 61, 52, 52, 48, 38, 36, 49, 60, 52,
  57, 48, 125, 10, 82, 61, 48, 10, 71, 61, 123, 40, 36, 49, 45, 52,
  52, 48, 41, 47, 40, 52, 57, 48, 45, 52, 52, 48, 41, 125, 10, 66,
  61, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 62, 61, 52, 57,
  48, 38, 36, 49, 60, 53, 49, 48, 125, 10, 82, 61, 48, 10, 71, 61,
  49, 10, 66, 61, 123, 45, 49, 42, 40, 36, 49, 45, 53, 49, 48, 41,
  47, 40, 53, 49, 48, 45, 52, 57, 48, 41, 125, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 62, 61, 53, 49, 48, 38, 36, 49, 60, 53, 56,
  48, 125, 10, 82, 61, 123, 40, 36, 49, 45, 53, 49, 48, 41, 47, 40,
  53, 56, 48, 45, 53, 49, 48, 41, 125, 10, 71, 61, 49, 10, 66, 61,
  48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 62, 61, 53, 56, 48,
  38, 36, 49, 60, 54, 52, 53, 125, 10, 82, 61, 49, 10, 71, 61, 123,
  45, 49, 42, 40, 36, 49, 45, 54, 52, 53, 41, 47, 40, 54, 52, 53,
  45, 53, 56, 48, 41, 125, 10, 66, 61, 48, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 62, 61, 54, 52, 53, 38, 36, 49, 60, 55, 56, 48,
  125, 10, 82, 61, 49, 10, 71, 61, 48, 10, 66, 61, 48, 10, 45, 101,
  108, 115, 101, 10, 82, 61, 48, 10, 71, 61, 48, 10, 66, 61, 48, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 109, 105, 120, 95, 99, 104,
  97, 110, 110, 101, 108, 115, 32, 40, 36, 82, 59, 36, 71, 59, 36, 66,
  41, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64,
  103, 105, 109, 112, 32, 74, 112, 114, 32, 103, 114, 97, 100, 105, 101, 110,
  116, 32, 115, 109, 111, 111, 116, 104, 32, 58, 32, 106, 112, 114, 95, 103,
  114, 97, 100, 105, 101, 110, 116, 95, 115, 109, 111, 111, 116, 104, 44, 106,
  112, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 95, 115, 109, 111, 111,
  116, 104, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 105, 109, 97, 103,
  101, 32, 97, 110, 100, 32, 105, 116, 115, 32, 103, 114, 97, 100, 105, 101,
  110, 116, 32, 105, 110, 32, 120, 32, 121, 32, 97, 114, 101, 32, 116, 114,
  101, 97, 116, 101, 100, 32, 97, 115, 32, 115, 111, 108, 105, 100, 32, 97,
  110, 103, 108, 101, 115, 32, 97, 110, 100, 32, 115, 109, 111, 111, 116, 104,
  101, 100, 32, 111, 110, 32, 116, 104, 101, 32, 116, 111, 112, 111, 108, 111,
  103, 121, 32, 111, 102, 32, 116, 104, 101, 32, 115, 117, 114, 102, 97, 99,
  101, 32, 111, 102, 32, 97, 32, 115, 112, 104, 101, 114, 101, 92, 110, 116,
  104, 105, 115, 32, 109, 101, 97, 110, 115, 32, 97, 32, 108, 111, 111, 112,
  32, 98, 114, 105, 103, 104, 116, 47, 100, 97, 114, 107, 47, 98, 114, 105,
  103, 104, 116, 32, 99, 97, 110, 110, 111, 116, 32, 99, 111, 110, 116, 114,
  97, 99, 116, 32, 116, 104, 114, 111, 117, 103, 104, 32, 116, 104, 101, 32,
  99, 101, 110, 116, 114, 101, 32, 111, 102, 32, 116, 104, 101, 32, 115, 112,
  104, 101, 114, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  79, 102, 102, 115, 101, 116, 32, 98, 114, 105, 103, 104, 116, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 48, 46, 57,
  44, 48, 46, 57, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  109, 111, 111, 116, 104, 105, 110, 103, 32, 97, 109, 111, 117, 110, 116, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 53, 44, 48, 46, 56, 44,
  50, 46, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 85, 112,
  100, 97, 116, 101, 97, 117, 116, 104, 111, 114, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 117, 112,
  100, 97, 116, 101, 32, 50, 48, 49, 51, 45, 70, 101, 98, 45, 48, 51,
  32, 97, 117, 116, 104, 111, 114, 32, 64, 106, 97, 121, 112, 114, 105, 99,
  104, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 106, 112, 114, 95,
  103, 114, 97, 100, 105, 101, 110, 116, 95, 115, 109, 111, 111, 116, 104, 58,
  10, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  10, 45, 108, 91, 36, 62, 93, 10, 45, 110, 111, 114, 109, 10, 45, 45,
  103, 32, 120, 121, 44, 48, 10, 45, 110, 91, 48, 93, 32, 123, 36, 49,
  45, 49, 125, 44, 123, 36, 49, 43, 49, 125, 10, 45, 97, 32, 99, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 50, 53, 10, 45, 45, 110, 111, 114,
  109, 10, 45, 47, 91, 48, 44, 49, 93, 10, 45, 98, 32, 123, 119, 42,
  36, 50, 47, 53, 48, 48, 125, 10, 45, 100, 111, 110, 101, 10, 45, 102,
  32, 97, 116, 97, 110, 50, 40, 105, 44, 97, 98, 115, 40, 105, 40, 120,
  44, 121, 44, 48, 44, 48, 41, 41, 41, 10, 45, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 49, 44, 50, 10, 45, 101, 110, 100, 108, 10, 45, 114,
  32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 51, 44, 48,
  44, 49, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 100, 111, 110,
  101, 10, 45, 118, 32, 43, 10, 35, 64, 103, 105, 109, 112, 32, 74, 112,
  114, 32, 108, 105, 110, 101, 32, 101, 100, 103, 101, 115, 32, 58, 32, 106,
  112, 114, 95, 108, 105, 110, 101, 95, 101, 100, 103, 101, 115, 44, 106, 112,
  114, 95, 108, 105, 110, 101, 95, 101, 100, 103, 101, 115, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 123, 34, 99, 111, 109, 98, 105, 110, 101, 115, 32, 116,
  104, 101, 32, 114, 101, 115, 117, 108, 116, 115, 32, 105, 110, 32, 115, 101,
  118, 101, 114, 97, 108, 32, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111,
  110, 115, 44, 32, 101, 97, 99, 104, 32, 111, 110, 101, 32, 98, 108, 117,
  114, 115, 32, 111, 110, 101, 32, 119, 97, 121, 32, 97, 110, 100, 32, 108,
  111, 111, 107, 115, 32, 102, 111, 114, 32, 112, 111, 105, 110, 116, 115, 32,
  111, 102, 32, 109, 97, 120, 32, 103, 114, 97, 100, 105, 101, 110, 116, 32,
  97, 116, 32, 57, 48, 32, 100, 101, 103, 114, 101, 101, 115, 32, 116, 111,
  32, 116, 104, 101, 32, 98, 108, 117, 114, 34, 125, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  123, 34, 119, 111, 114, 107, 115, 32, 98, 101, 115, 116, 32, 111, 110, 32,
  112, 104, 111, 116, 111, 103, 114, 97, 112, 104, 115, 32, 110, 111, 116, 32,
  108, 105, 110, 101, 45, 97, 114, 116, 34, 125, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 110, 103, 108, 101, 115, 32, 112, 101, 114, 32, 113,
  117, 97, 100, 114, 97, 110, 116, 32, 61, 32, 105, 110, 116, 40, 50, 44,
  49, 44, 57, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108,
  117, 114, 114, 105, 110, 103, 32, 61, 32, 105, 110, 116, 40, 50, 44, 50,
  44, 50, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114,
  97, 100, 105, 101, 110, 116, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 44, 48, 44, 51, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 116, 105, 32, 97,
  108, 105, 97, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 85, 112, 100, 97, 116, 101, 97, 117,
  116, 104, 111, 114, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 117, 112, 100, 97, 116, 101, 32, 50,
  48, 49, 51, 45, 74, 97, 110, 45, 50, 50, 32, 97, 117, 116, 104, 111,
  114, 32, 64, 106, 97, 121, 112, 114, 105, 99, 104, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 106, 112, 114, 95, 108, 105, 110, 101, 95, 101,
  100, 103, 101, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49,
  61, 53, 125, 44, 36, 123, 50, 61, 53, 125, 44, 36, 123, 51, 61, 49,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 70, 105, 110, 100, 32,
  101, 100, 103, 101, 115, 32, 105, 110, 32, 105, 109, 97, 103, 101, 36, 63,
  32, 117, 115, 105, 110, 103, 32, 36, 49, 32, 97, 110, 103, 108, 101, 115,
  32, 112, 101, 114, 32, 113, 117, 97, 100, 114, 97, 110, 116, 32, 119, 105,
  116, 104, 32, 36, 50, 32, 98, 108, 117, 114, 114, 105, 110, 103, 32, 97,
  110, 100, 32, 36, 51, 32, 97, 110, 116, 105, 45, 97, 108, 105, 97, 115,
  34, 10, 45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 110, 111, 114, 109, 10, 45,
  102, 102, 116, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44,
  49, 44, 120, 45, 119, 47, 50, 10, 49, 48, 48, 37, 44, 49, 48, 48,
  37, 44, 49, 44, 49, 44, 121, 45, 104, 47, 50, 10, 45, 115, 104, 105,
  102, 116, 91, 50, 44, 51, 93, 32, 123, 45, 119, 47, 50, 125, 44, 123,
  45, 104, 47, 50, 125, 44, 48, 44, 48, 44, 50, 10, 49, 48, 48, 37,
  44, 49, 48, 48, 37, 44, 49, 44, 49, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 36, 49, 125, 10, 97, 99, 61, 123, 51, 42, 99, 111, 115,
  40, 40, 36, 62, 43, 48, 46, 53, 41, 42, 112, 105, 47, 36, 49, 47,
  50, 41, 47, 115, 113, 114, 116, 40, 112, 105, 41, 42, 36, 50, 47, 119,
  125, 10, 97, 115, 61, 123, 51, 42, 115, 105, 110, 40, 40, 36, 62, 43,
  48, 46, 53, 41, 42, 112, 105, 47, 36, 49, 47, 50, 41, 47, 115, 113,
  114, 116, 40, 112, 105, 41, 42, 36, 50, 47, 119, 125, 10, 45, 45, 42,
  91, 50, 93, 32, 36, 97, 99, 10, 45, 45, 42, 91, 51, 93, 32, 36,
  97, 115, 10, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 45, 115,
  113, 114, 91, 45, 49, 93, 10, 45, 42, 91, 45, 49, 93, 32, 45, 49,
  10, 45, 101, 120, 112, 91, 45, 49, 93, 10, 45, 42, 91, 45, 50, 44,
  45, 49, 93, 10, 45, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93,
  32, 120, 10, 45, 42, 91, 45, 49, 93, 32, 45, 49, 10, 91, 49, 93,
  120, 49, 10, 45, 42, 91, 45, 49, 93, 32, 45, 49, 10, 91, 48, 93,
  120, 49, 10, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 91, 45, 52,
  93, 10, 45, 114, 109, 91, 45, 52, 93, 10, 45, 105, 102, 102, 116, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 114, 109, 91, 45, 49, 93, 10, 91,
  49, 93, 120, 49, 10, 45, 42, 91, 45, 49, 93, 32, 45, 49, 10, 91,
  48, 93, 120, 49, 10, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 91,
  45, 52, 93, 10, 45, 114, 109, 91, 45, 52, 93, 10, 45, 105, 102, 102,
  116, 91, 45, 50, 44, 45, 49, 93, 10, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 97, 98, 115, 91, 45, 50, 44, 45, 49, 93, 10, 45, 109, 97,
  120, 91, 45, 50, 44, 45, 49, 93, 32, 36, 51, 10, 97, 99, 61, 123,
  49, 46, 52, 53, 42, 99, 111, 115, 40, 40, 36, 62, 43, 48, 46, 53,
  41, 42, 112, 105, 47, 36, 49, 47, 50, 41, 125, 10, 97, 115, 61, 123,
  49, 46, 52, 53, 42, 115, 105, 110, 40, 40, 36, 62, 43, 48, 46, 53,
  41, 42, 112, 105, 47, 36, 49, 47, 50, 41, 125, 10, 45, 45, 115, 104,
  105, 102, 116, 91, 45, 50, 93, 32, 123, 45, 36, 97, 99, 125, 44, 123,
  45, 36, 97, 115, 125, 10, 45, 45, 115, 104, 105, 102, 116, 91, 45, 51,
  93, 32, 123, 36, 97, 99, 125, 44, 123, 36, 97, 115, 125, 10, 45, 45,
  115, 104, 105, 102, 116, 91, 45, 51, 93, 32, 123, 36, 97, 99, 125, 44,
  123, 45, 36, 97, 115, 125, 10, 45, 45, 115, 104, 105, 102, 116, 91, 45,
  52, 93, 32, 123, 45, 36, 97, 99, 125, 44, 123, 36, 97, 115, 125, 10,
  45, 105, 102, 32, 36, 52, 10, 45, 45, 109, 97, 120, 91, 45, 54, 44,
  45, 52, 44, 45, 51, 93, 10, 45, 45, 109, 105, 110, 91, 45, 55, 44,
  45, 53, 44, 45, 52, 93, 10, 45, 45, 91, 45, 50, 44, 45, 49, 93,
  10, 45, 43, 91, 45, 53, 44, 45, 52, 93, 10, 45, 42, 91, 45, 52,
  93, 32, 48, 46, 53, 10, 45, 45, 91, 45, 54, 44, 45, 52, 93, 10,
  45, 47, 91, 45, 53, 44, 45, 49, 93, 10, 45, 45, 91, 45, 52, 93,
  32, 48, 46, 49, 10, 45, 109, 97, 120, 91, 45, 52, 93, 32, 48, 10,
  45, 42, 91, 45, 52, 93, 32, 50, 10, 45, 45, 91, 52, 44, 45, 52,
  93, 10, 45, 45, 109, 97, 120, 91, 45, 51, 44, 45, 50, 44, 45, 49,
  93, 10, 45, 45, 109, 105, 110, 91, 45, 52, 44, 45, 51, 44, 45, 50,
  93, 10, 45, 45, 91, 45, 50, 44, 45, 49, 93, 10, 45, 43, 91, 45,
  51, 44, 45, 50, 93, 10, 45, 42, 91, 45, 50, 93, 32, 48, 46, 53,
  10, 45, 45, 91, 45, 51, 44, 45, 50, 93, 10, 45, 47, 91, 45, 50,
  44, 45, 49, 93, 10, 45, 45, 91, 45, 49, 93, 32, 48, 46, 49, 10,
  45, 109, 97, 120, 91, 45, 49, 93, 32, 48, 10, 45, 42, 91, 45, 49,
  93, 32, 50, 10, 45, 45, 91, 52, 44, 45, 49, 93, 10, 45, 101, 108,
  115, 101, 10, 45, 109, 97, 120, 91, 45, 52, 44, 45, 51, 93, 10, 45,
  103, 116, 91, 45, 53, 44, 45, 51, 93, 10, 45, 45, 91, 52, 44, 45,
  52, 93, 10, 45, 109, 97, 120, 91, 45, 50, 44, 45, 49, 93, 10, 45,
  103, 116, 91, 45, 50, 44, 45, 49, 93, 10, 45, 45, 91, 52, 44, 45,
  49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 10,
  45, 114, 109, 91, 48, 44, 49, 44, 50, 44, 51, 93, 10, 45, 110, 32,
  48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 45, 118, 32, 43, 10, 35, 64, 103, 105, 109, 112, 32, 74, 112,
  114, 32, 111, 114, 105, 101, 110, 116, 101, 100, 116, 104, 105, 110, 110, 105,
  110, 103, 32, 58, 32, 106, 112, 114, 95, 111, 114, 105, 101, 110, 116, 101,
  100, 116, 104, 105, 110, 110, 105, 110, 103, 44, 106, 112, 114, 95, 111, 114,
  105, 101, 110, 116, 101, 100, 116, 104, 105, 110, 110, 105, 110, 103, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 123, 34, 83, 107, 101, 108, 101, 116, 111, 110,
  32, 111, 102, 32, 97, 32, 115, 104, 97, 112, 101, 32, 97, 103, 97, 105,
  110, 115, 116, 32, 97, 32, 122, 101, 114, 111, 45, 118, 97, 108, 117, 101,
  32, 40, 112, 117, 114, 101, 45, 98, 108, 97, 99, 107, 41, 32, 98, 97,
  99, 107, 103, 114, 111, 117, 110, 100, 32, 117, 115, 105, 110, 103, 32, 108,
  111, 99, 97, 108, 108, 121, 32, 111, 114, 105, 101, 110, 116, 101, 100, 32,
  108, 111, 99, 97, 108, 32, 109, 97, 120, 105, 109, 97, 32, 116, 111, 32,
  102, 105, 110, 100, 32, 111, 110, 108, 121, 32, 114, 101, 108, 101, 118, 97,
  110, 116, 32, 114, 105, 100, 103, 101, 115, 32, 45, 32, 110, 111, 116, 32,
  109, 105, 99, 114, 111, 32, 114, 105, 100, 103, 101, 115, 32, 102, 114, 111,
  109, 32, 97, 32, 110, 111, 105, 115, 121, 32, 98, 111, 117, 110, 100, 97,
  114, 121, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114,
  101, 32, 115, 109, 111, 111, 116, 104, 32, 98, 111, 114, 100, 101, 114, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 49, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 111, 112, 97, 103,
  97, 116, 101, 32, 100, 105, 114, 101, 99, 116, 105, 111, 110, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 53, 44, 51, 44, 53, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108,
  100, 32, 119, 105, 100, 116, 104, 32, 61, 32, 105, 110, 116, 40, 49, 44,
  49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80,
  114, 101, 118, 105, 101, 119, 32, 111, 114, 105, 101, 110, 116, 97, 116, 105,
  111, 110, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 105, 115, 116, 97, 110, 99, 101, 32, 109,
  101, 116, 114, 105, 99, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 109,
  97, 120, 32, 124, 120, 124, 32, 124, 121, 124, 32, 99, 104, 101, 98, 121,
  115, 104, 101, 118, 44, 124, 120, 124, 43, 124, 121, 124, 32, 109, 97, 110,
  104, 97, 116, 116, 97, 110, 44, 124, 120, 32, 121, 124, 32, 101, 117, 99,
  108, 105, 100, 101, 97, 110, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 85, 112, 100, 97, 116, 101, 97, 117, 116, 104, 111, 114, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 117, 112, 100, 97, 116, 101, 32, 50, 48, 49, 51, 45, 65, 112, 114,
  45, 49, 52, 32, 97, 117, 116, 104, 111, 114, 32, 64, 106, 97, 121, 112,
  114, 105, 99, 104, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 106,
  112, 114, 95, 111, 114, 105, 101, 110, 116, 101, 100, 116, 104, 105, 110, 110,
  105, 110, 103, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 79,
  114, 105, 101, 110, 116, 101, 100, 32, 84, 104, 105, 110, 110, 105, 110, 103,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 119, 105, 116, 104, 32, 80, 114,
  101, 45, 83, 109, 111, 111, 116, 104, 32, 36, 49, 44, 32, 80, 114, 111,
  112, 97, 103, 97, 116, 101, 32, 68, 105, 114, 101, 99, 116, 105, 111, 110,
  32, 36, 50, 44, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32, 87,
  105, 100, 116, 104, 32, 36, 51, 34, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 10, 45, 108, 91, 36, 60, 93, 10, 45, 110, 111, 114, 109,
  10, 45, 45, 98, 32, 36, 49, 10, 45, 115, 116, 114, 117, 99, 116, 117,
  114, 101, 116, 101, 110, 115, 111, 114, 115, 91, 45, 49, 93, 32, 48, 10,
  45, 109, 105, 120, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49,
  93, 32, 40, 49, 44, 48, 44, 45, 49, 41, 10, 45, 98, 91, 45, 49,
  93, 32, 36, 50, 10, 45, 108, 101, 91, 45, 49, 93, 32, 48, 10, 45,
  105, 102, 32, 36, 52, 10, 45, 114, 109, 91, 45, 50, 93, 10, 45, 42,
  32, 50, 53, 53, 10, 45, 101, 108, 115, 101, 10, 40, 49, 46, 49, 44,
  48, 94, 48, 44, 49, 46, 49, 41, 10, 45, 109, 97, 112, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 50, 93, 32, 48, 44, 36,
  53, 10, 45, 109, 97, 120, 91, 45, 50, 93, 32, 36, 51, 10, 45, 45,
  119, 97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49, 10,
  45, 42, 91, 45, 50, 93, 32, 45, 49, 10, 45, 45, 119, 97, 114, 112,
  91, 45, 51, 93, 32, 91, 45, 50, 93, 44, 49, 10, 45, 114, 109, 91,
  45, 51, 93, 10, 45, 109, 97, 120, 91, 45, 50, 44, 45, 49, 93, 10,
  45, 103, 116, 91, 45, 50, 44, 45, 49, 93, 10, 45, 42, 32, 50, 53,
  53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 10, 45,
  100, 111, 110, 101, 10, 45, 118, 32, 43, 10, 35, 64, 103, 105, 109, 112,
  32, 74, 112, 114, 32, 112, 104, 97, 115, 101, 99, 111, 110, 103, 114, 117,
  101, 110, 99, 101, 32, 58, 32, 106, 112, 114, 95, 112, 104, 97, 115, 101,
  99, 111, 110, 103, 114, 117, 101, 110, 99, 101, 44, 106, 112, 114, 95, 112,
  104, 97, 115, 101, 99, 111, 110, 103, 114, 117, 101, 110, 99, 101, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 123, 34, 69, 100, 103, 101, 32, 100, 101, 116,
  101, 99, 116, 32, 119, 105, 116, 104, 32, 100, 105, 114, 101, 99, 116, 105,
  111, 110, 97, 108, 32, 80, 104, 97, 115, 101, 32, 67, 111, 110, 103, 114,
  117, 101, 110, 99, 101, 32, 117, 115, 105, 110, 103, 32, 112, 114, 111, 112,
  111, 114, 116, 105, 111, 110, 97, 108, 105, 116, 121, 32, 116, 111, 32, 76,
  111, 99, 97, 108, 32, 69, 110, 101, 114, 103, 121, 46, 34, 125, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 116, 97, 114, 116, 32, 97, 110,
  103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 53, 44, 48,
  44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68,
  105, 114, 101, 99, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40,
  49, 44, 49, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 69, 110, 101, 114, 103, 121, 32, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 53,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 111, 99,
  97, 108, 32, 109, 97, 120, 105, 109, 97, 32, 61, 32, 98, 111, 111, 108,
  40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 85, 112, 100,
  97, 116, 101, 97, 117, 116, 104, 111, 114, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 117, 112, 100,
  97, 116, 101, 32, 50, 48, 49, 51, 45, 77, 97, 114, 45, 51, 49, 32,
  97, 117, 116, 104, 111, 114, 32, 64, 106, 97, 121, 112, 114, 105, 99, 104,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 106, 112, 114, 95, 112,
  104, 97, 115, 101, 99, 111, 110, 103, 114, 117, 101, 110, 99, 101, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 80, 104, 97, 115, 101, 32,
  67, 111, 110, 103, 114, 117, 101, 110, 99, 101, 32, 105, 109, 97, 103, 101,
  36, 63, 32, 119, 105, 116, 104, 32, 83, 116, 97, 114, 116, 65, 110, 103,
  108, 101, 32, 36, 49, 44, 32, 68, 105, 114, 101, 99, 116, 105, 111, 110,
  115, 32, 36, 50, 44, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32,
  36, 51, 44, 32, 73, 115, 76, 105, 110, 101, 115, 32, 36, 52, 34, 10,
  45, 118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10,
  45, 108, 91, 36, 60, 93, 10, 45, 110, 111, 114, 109, 10, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 48, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 36, 50, 10, 91, 48, 93, 120, 49, 10, 116, 61,
  123, 40, 36, 49, 47, 49, 56, 48, 43, 36, 60, 47, 36, 50, 41, 42,
  112, 105, 125, 10, 97, 61, 123, 99, 111, 115, 40, 36, 116, 41, 125, 10,
  98, 61, 123, 115, 105, 110, 40, 36, 116, 41, 125, 10, 45, 102, 102, 116,
  91, 50, 93, 10, 45, 109, 118, 91, 51, 93, 32, 50, 10, 49, 48, 48,
  37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 115, 120, 61, 105, 102,
  40, 120, 62, 119, 47, 50, 44, 120, 45, 119, 44, 120, 41, 59, 115, 121,
  61, 105, 102, 40, 121, 62, 104, 47, 50, 44, 121, 45, 104, 44, 121, 41,
  59, 105, 102, 40, 97, 98, 115, 40, 36, 97, 42, 115, 120, 43, 36, 98,
  42, 115, 121, 41, 62, 48, 46, 55, 44, 115, 105, 103, 110, 40, 36, 97,
  42, 115, 120, 43, 36, 98, 42, 115, 121, 41, 44, 48, 41, 10, 45, 42,
  91, 51, 93, 32, 45, 49, 10, 45, 42, 91, 50, 44, 51, 93, 32, 91,
  52, 93, 10, 45, 114, 109, 91, 52, 93, 10, 45, 105, 102, 102, 116, 91,
  50, 44, 51, 93, 10, 45, 114, 109, 91, 51, 93, 10, 99, 61, 123, 109,
  97, 120, 40, 97, 98, 115, 40, 36, 97, 41, 44, 97, 98, 115, 40, 36,
  98, 41, 41, 42, 46, 56, 125, 10, 45, 97, 98, 115, 91, 50, 93, 10,
  45, 109, 97, 120, 91, 50, 93, 32, 36, 51, 10, 45, 105, 102, 32, 36,
  52, 10, 97, 61, 123, 36, 97, 47, 36, 99, 125, 10, 98, 61, 123, 36,
  98, 47, 36, 99, 125, 10, 45, 102, 91, 50, 93, 32, 105, 62, 105, 40,
  120, 43, 36, 97, 44, 121, 43, 36, 98, 41, 38, 105, 62, 105, 40, 120,
  45, 36, 97, 44, 121, 45, 36, 98, 41, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 43, 91, 49, 44, 50, 93, 10, 45, 100, 111, 110, 101, 10, 45,
  114, 109, 91, 48, 93, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45,
  101, 110, 100, 108, 10, 45, 100, 111, 110, 101, 10, 45, 118, 32, 43, 10,
  35, 64, 103, 105, 109, 112, 32, 74, 112, 114, 32, 114, 101, 109, 111, 118,
  101, 32, 98, 108, 111, 99, 107, 115, 49, 32, 58, 32, 106, 112, 114, 95,
  114, 101, 109, 111, 118, 101, 95, 98, 108, 111, 99, 107, 115, 49, 44, 106,
  112, 114, 95, 114, 101, 109, 111, 118, 101, 95, 98, 108, 111, 99, 107, 115,
  49, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 115, 117, 98, 116, 114, 97, 99, 116, 115, 32,
  115, 113, 117, 97, 114, 101, 32, 101, 100, 103, 101, 100, 32, 98, 108, 111,
  99, 107, 115, 32, 119, 105, 116, 104, 32, 108, 105, 109, 105, 116, 101, 100,
  45, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 119, 104, 105, 108, 101,
  32, 109, 97, 115, 107, 105, 110, 103, 32, 108, 101, 115, 115, 45, 115, 109,
  111, 111, 116, 104, 32, 97, 114, 101, 97, 115, 32, 111, 102, 32, 97, 110,
  32, 105, 109, 97, 103, 101, 92, 110, 92, 110, 116, 104, 105, 115, 32, 99,
  97, 110, 32, 114, 101, 100, 117, 99, 101, 32, 108, 111, 119, 32, 113, 117,
  97, 108, 105, 116, 121, 32, 106, 112, 101, 103, 32, 97, 114, 116, 105, 102,
  97, 99, 116, 115, 32, 105, 110, 32, 118, 101, 114, 121, 32, 115, 109, 111,
  111, 116, 104, 32, 112, 97, 114, 116, 115, 32, 111, 102, 32, 97, 110, 32,
  105, 109, 97, 103, 101, 92, 110, 49, 46, 32, 99, 104, 111, 111, 115, 101,
  32, 97, 32, 98, 108, 111, 99, 107, 32, 115, 105, 122, 101, 32, 105, 110,
  32, 112, 105, 120, 101, 108, 115, 32, 116, 111, 32, 102, 105, 116, 92, 110,
  50, 46, 32, 115, 101, 116, 32, 115, 109, 97, 108, 108, 101, 115, 116, 32,
  97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 116, 104, 97, 116, 32, 99,
  97, 116, 99, 104, 101, 115, 32, 98, 108, 111, 99, 107, 32, 110, 111, 105,
  115, 101, 32, 105, 110, 32, 115, 109, 111, 111, 116, 104, 32, 97, 114, 101,
  97, 115, 32, 98, 117, 116, 32, 109, 97, 115, 107, 115, 32, 114, 101, 97,
  108, 32, 101, 100, 103, 101, 115, 32, 105, 110, 32, 116, 104, 101, 32, 105,
  109, 97, 103, 101, 92, 110, 51, 46, 32, 102, 105, 110, 101, 32, 116, 117,
  110, 101, 32, 116, 104, 101, 32, 115, 116, 114, 101, 110, 103, 116, 104, 32,
  97, 114, 111, 117, 110, 100, 32, 55, 48, 44, 32, 116, 104, 101, 32, 97,
  109, 111, 117, 110, 116, 32, 111, 102, 32, 101, 115, 116, 105, 109, 97, 116,
  101, 100, 32, 98, 108, 111, 99, 107, 45, 110, 111, 105, 115, 101, 32, 116,
  111, 32, 115, 117, 98, 116, 114, 97, 99, 116, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 112, 97, 116, 105, 97, 108, 32, 98, 108,
  111, 99, 107, 32, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 52, 44, 50, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 51, 44, 49, 44, 54, 52, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 116, 114, 101, 110, 103, 116, 104, 32, 102, 105,
  110, 101, 45, 116, 117, 110, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  55, 48, 44, 50, 48, 44, 51, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 85, 112, 100, 97, 116, 101, 97, 117, 116, 104, 111, 114,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 117, 112, 100, 97, 116, 101, 32, 50, 48, 49, 50, 45,
  78, 111, 118, 45, 51, 48, 32, 97, 117, 116, 104, 111, 114, 32, 64, 106,
  97, 121, 112, 114, 105, 99, 104, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 106, 112, 114, 95, 114, 101, 109, 111, 118, 101, 95, 98, 108, 111,
  99, 107, 115, 49, 32, 58, 10, 45, 118, 32, 45, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 60, 93, 10, 45, 107,
  101, 101, 112, 91, 48, 93, 10, 115, 112, 97, 116, 105, 97, 108, 61, 36,
  49, 10, 97, 109, 112, 108, 105, 116, 117, 100, 101, 61, 36, 50, 10, 115,
  116, 114, 101, 110, 103, 116, 104, 61, 36, 51, 10, 45, 45, 98, 91, 48,
  93, 32, 123, 36, 115, 112, 97, 116, 105, 97, 108, 42, 49, 46, 50, 125,
  32, 45, 45, 98, 91, 48, 93, 32, 123, 36, 115, 112, 97, 116, 105, 97,
  108, 42, 48, 46, 56, 125, 32, 45, 45, 91, 49, 44, 50, 93, 32, 91,
  48, 93, 10, 45, 99, 91, 49, 44, 50, 93, 32, 123, 45, 36, 97, 109,
  112, 108, 105, 116, 117, 100, 101, 125, 44, 123, 36, 97, 109, 112, 108, 105,
  116, 117, 100, 101, 125, 10, 45, 45, 61, 61, 91, 49, 44, 50, 93, 32,
  123, 45, 36, 97, 109, 112, 108, 105, 116, 117, 100, 101, 125, 10, 45, 45,
  61, 61, 91, 49, 44, 50, 93, 32, 123, 36, 97, 109, 112, 108, 105, 116,
  117, 100, 101, 125, 32, 45, 111, 114, 91, 51, 44, 52, 44, 53, 44, 54,
  93, 10, 119, 104, 61, 123, 119, 125, 44, 123, 104, 125, 10, 45, 115, 104,
  105, 102, 116, 91, 49, 93, 32, 50, 44, 50, 10, 45, 114, 91, 49, 44,
  50, 93, 32, 123, 119, 47, 36, 115, 112, 97, 116, 105, 97, 108, 125, 44,
  123, 104, 47, 36, 115, 112, 97, 116, 105, 97, 108, 125, 44, 49, 44, 51,
  44, 50, 10, 45, 114, 91, 49, 44, 50, 93, 32, 36, 119, 104, 10, 45,
  115, 104, 105, 102, 116, 91, 49, 93, 32, 45, 50, 44, 45, 50, 10, 45,
  99, 91, 49, 44, 50, 93, 32, 123, 45, 36, 97, 109, 112, 108, 105, 116,
  117, 100, 101, 47, 50, 125, 44, 123, 36, 97, 109, 112, 108, 105, 116, 117,
  100, 101, 47, 50, 125, 10, 45, 45, 61, 61, 91, 49, 44, 50, 93, 32,
  123, 45, 36, 97, 109, 112, 108, 105, 116, 117, 100, 101, 47, 50, 125, 10,
  45, 45, 61, 61, 91, 49, 44, 50, 93, 32, 123, 36, 97, 109, 112, 108,
  105, 116, 117, 100, 101, 47, 50, 125, 32, 45, 111, 114, 91, 51, 44, 52,
  44, 53, 44, 54, 44, 55, 93, 10, 45, 99, 111, 109, 112, 111, 115, 101,
  95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 51, 93, 32, 111, 114, 10,
  45, 98, 108, 117, 114, 91, 51, 93, 32, 123, 50, 42, 36, 115, 112, 97,
  116, 105, 97, 108, 125, 32, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100,
  91, 51, 93, 32, 48, 46, 49, 10, 45, 98, 108, 117, 114, 91, 51, 93,
  32, 123, 50, 42, 36, 115, 112, 97, 116, 105, 97, 108, 125, 10, 45, 45,
  91, 51, 93, 32, 49, 10, 45, 43, 91, 49, 93, 32, 91, 50, 93, 32,
  45, 114, 109, 91, 50, 93, 10, 45, 42, 91, 49, 93, 32, 91, 50, 93,
  32, 45, 114, 109, 91, 50, 93, 10, 45, 42, 91, 49, 93, 32, 123, 48,
  46, 48, 49, 42, 36, 115, 116, 114, 101, 110, 103, 116, 104, 125, 10, 45,
  45, 91, 48, 93, 32, 91, 49, 93, 32, 45, 114, 109, 91, 49, 93, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 118, 32, 43,
  10, 35, 64, 103, 105, 109, 112, 32, 74, 112, 114, 32, 115, 104, 97, 112,
  101, 115, 32, 103, 114, 97, 100, 105, 101, 110, 116, 32, 58, 32, 106, 112,
  114, 95, 115, 104, 97, 112, 101, 115, 95, 103, 114, 97, 100, 105, 101, 110,
  116, 44, 106, 112, 114, 95, 115, 104, 97, 112, 101, 115, 95, 103, 114, 97,
  100, 105, 101, 110, 116, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 108,
  111, 116, 115, 32, 111, 102, 32, 108, 111, 99, 97, 108, 32, 114, 101, 103,
  114, 101, 115, 115, 105, 111, 110, 115, 32, 117, 115, 105, 110, 103, 32, 115,
  104, 97, 112, 101, 97, 118, 101, 114, 97, 103, 101, 32, 115, 117, 112, 112,
  114, 101, 115, 115, 32, 110, 111, 105, 115, 101, 32, 105, 110, 32, 116, 104,
  101, 32, 103, 114, 97, 100, 105, 101, 110, 116, 115, 32, 111, 102, 32, 115,
  109, 97, 108, 108, 32, 97, 114, 101, 97, 115, 32, 114, 97, 110, 100, 111,
  109, 32, 97, 114, 101, 97, 115, 32, 99, 104, 111, 115, 101, 110, 32, 98,
  121, 32, 119, 97, 116, 101, 114, 115, 104, 101, 100, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 32, 98, 108, 117, 114, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 52, 46, 53, 44, 48, 44, 49, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 87, 97, 116, 101, 114,
  115, 104, 101, 100, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 50, 53, 44, 48, 46, 48, 53,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 97,
  100, 105, 101, 110, 116, 32, 102, 108, 97, 116, 116, 101, 110, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 48, 49, 44, 48, 46, 48, 49, 44,
  51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 97, 100,
  105, 101, 110, 116, 32, 99, 97, 112, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 55, 44, 48, 46, 53, 44, 49, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 85, 112, 100, 97, 116, 101, 97, 117, 116, 104, 111, 114,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 117, 112, 100, 97, 116, 101, 32, 50, 48, 49, 51, 45,
  74, 97, 110, 45, 51, 49, 32, 97, 117, 116, 104, 111, 114, 32, 64, 106,
  97, 121, 112, 114, 105, 99, 104, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 106, 112, 114, 95, 115, 104, 97, 112, 101, 115, 95, 103, 114, 97,
  100, 105, 101, 110, 116, 58, 10, 45, 118, 32, 45, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 60, 93, 10, 49, 48,
  48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 48, 46, 49, 42,
  40, 120, 45, 119, 47, 50, 41, 10, 45, 45, 110, 111, 114, 109, 91, 48,
  93, 10, 45, 98, 91, 45, 49, 93, 32, 36, 49, 10, 45, 115, 101, 103,
  109, 101, 110, 116, 95, 119, 97, 116, 101, 114, 115, 104, 101, 100, 91, 45,
  49, 93, 32, 36, 50, 44, 48, 10, 45, 103, 116, 91, 45, 49, 93, 32,
  48, 10, 45, 42, 91, 49, 93, 32, 91, 45, 49, 93, 10, 45, 45, 98,
  108, 101, 110, 100, 95, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97, 103,
  101, 91, 49, 44, 45, 49, 93, 10, 45, 45, 91, 49, 44, 45, 49, 93,
  10, 45, 45, 115, 113, 114, 91, 49, 93, 10, 91, 45, 50, 93, 120, 49,
  10, 45, 98, 108, 101, 110, 100, 95, 115, 104, 97, 112, 101, 97, 118, 101,
  114, 97, 103, 101, 91, 45, 50, 44, 45, 49, 93, 10, 45, 43, 91, 45,
  49, 93, 32, 36, 51, 10, 45, 115, 113, 114, 116, 91, 45, 49, 93, 10,
  45, 47, 91, 49, 44, 45, 49, 93, 10, 45, 45, 98, 108, 101, 110, 100,
  95, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97, 103, 101, 91, 48, 44,
  45, 49, 93, 10, 45, 42, 91, 48, 93, 32, 91, 45, 51, 93, 10, 45,
  98, 108, 101, 110, 100, 95, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97,
  103, 101, 91, 48, 44, 45, 50, 93, 10, 45, 99, 91, 48, 93, 32, 45,
  36, 52, 44, 36, 52, 10, 45, 42, 91, 48, 44, 49, 93, 10, 45, 43,
  91, 48, 44, 49, 93, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 118, 32, 43, 10,
  35, 64, 103, 105, 109, 112, 32, 74, 112, 114, 32, 115, 112, 101, 99, 117,
  108, 97, 114, 98, 117, 109, 112, 115, 32, 58, 32, 106, 112, 114, 95, 115,
  112, 101, 99, 117, 108, 97, 114, 98, 117, 109, 112, 115, 44, 106, 112, 114,
  95, 115, 112, 101, 99, 117, 108, 97, 114, 98, 117, 109, 112, 115, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 123, 34, 65, 100, 100, 32, 104, 105, 103, 104,
  108, 105, 103, 104, 116, 115, 32, 117, 115, 105, 110, 103, 32, 98, 114, 105,
  103, 104, 116, 110, 101, 115, 115, 32, 103, 114, 97, 100, 105, 101, 110, 116,
  46, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 97,
  100, 105, 101, 110, 116, 32, 105, 108, 108, 117, 109, 105, 110, 97, 116, 101,
  32, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50,
  55, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 80, 114, 101, 32, 115, 109, 111, 111, 116, 104, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 71, 114, 97, 100, 105, 101, 110, 116, 32, 114,
  97, 110, 103, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 51, 44,
  48, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73,
  108, 108, 117, 109, 105, 110, 97, 116, 105, 111, 110, 32, 97, 100, 106, 117,
  115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 52, 53,
  44, 52, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 108,
  108, 117, 109, 105, 110, 97, 116, 105, 111, 110, 32, 111, 102, 102, 115, 101,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 56, 48, 44, 48, 44, 57,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 105, 103, 104,
  108, 105, 103, 104, 116, 32, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 49, 44, 48, 44, 48, 46, 50, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 82, 111, 117, 103, 104, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 49, 44, 48, 46,
  48, 53, 44, 48, 46, 51, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 79, 117, 116, 112, 117, 116, 32, 116, 121, 112, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 98, 108, 97, 99, 107, 32, 97, 110,
  100, 32, 119, 104, 105, 116, 101, 34, 44, 34, 119, 104, 105, 116, 101, 32,
  119, 105, 116, 104, 32, 97, 108, 112, 104, 97, 34, 44, 34, 99, 111, 109,
  112, 111, 115, 101, 32, 116, 111, 32, 105, 109, 97, 103, 101, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 85, 112, 100, 97, 116, 101, 97,
  117, 116, 104, 111, 114, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 117, 112, 100, 97, 116, 101, 32,
  50, 48, 49, 51, 45, 77, 97, 114, 45, 51, 49, 32, 97, 117, 116, 104,
  111, 114, 32, 64, 106, 97, 121, 112, 114, 105, 99, 104, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 106, 112, 114, 95, 115, 112, 101, 99, 117,
  108, 97, 114, 98, 117, 109, 112, 115, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 83, 112, 101, 99, 117, 108, 97, 114, 32, 104, 105, 103,
  104, 108, 105, 103, 104, 116, 115, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  119, 105, 116, 104, 32, 71, 114, 97, 100, 105, 101, 110, 116, 65, 110, 103,
  108, 101, 32, 36, 49, 44, 32, 80, 114, 101, 45, 83, 109, 111, 111, 116,
  104, 32, 36, 50, 44, 32, 71, 114, 97, 100, 105, 101, 110, 116, 82, 97,
  110, 103, 101, 32, 36, 51, 44, 32, 65, 100, 106, 117, 115, 116, 65, 110,
  103, 108, 101, 32, 36, 52, 44, 32, 73, 108, 108, 117, 109, 105, 110, 97,
  116, 105, 111, 110, 79, 102, 102, 115, 101, 116, 32, 36, 53, 44, 32, 72,
  105, 103, 104, 108, 105, 103, 104, 116, 83, 105, 122, 101, 32, 36, 54, 44,
  32, 82, 111, 117, 103, 104, 110, 101, 115, 115, 32, 36, 55, 44, 32, 79,
  117, 116, 112, 117, 116, 84, 121, 112, 101, 32, 36, 56, 34, 10, 45, 118,
  32, 45, 10, 116, 61, 123, 36, 49, 42, 112, 105, 47, 49, 56, 48, 125,
  10, 97, 61, 123, 99, 111, 115, 40, 36, 116, 41, 125, 10, 98, 61, 123,
  115, 105, 110, 40, 36, 116, 41, 125, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 10, 45, 108, 91, 36, 60, 93, 10, 45, 116, 111, 95, 114,
  103, 98, 10, 45, 45, 98, 32, 36, 50, 10, 45, 108, 91, 45, 49, 93,
  10, 45, 110, 111, 114, 109, 10, 45, 103, 114, 97, 100, 105, 101, 110, 116,
  32, 120, 121, 10, 45, 97, 32, 99, 10, 45, 109, 105, 120, 95, 99, 104,
  97, 110, 110, 101, 108, 115, 32, 40, 36, 97, 44, 36, 98, 59, 123, 45,
  36, 98, 125, 44, 36, 97, 41, 10, 45, 100, 105, 118, 32, 36, 51, 10,
  45, 99, 32, 48, 44, 49, 10, 45, 45, 110, 111, 114, 109, 10, 45, 102,
  91, 45, 49, 93, 32, 34, 48, 46, 49, 47, 40, 48, 46, 49, 43, 105,
  41, 34, 10, 45, 97, 32, 99, 10, 45, 45, 110, 111, 114, 109, 10, 45,
  100, 105, 118, 91, 45, 50, 44, 45, 49, 93, 10, 45, 98, 32, 50, 10,
  45, 45, 110, 111, 114, 109, 10, 45, 100, 105, 118, 91, 45, 50, 44, 45,
  49, 93, 10, 119, 104, 61, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44,
  51, 10, 40, 123, 99, 111, 115, 40, 40, 52, 53, 43, 36, 52, 41, 42,
  112, 105, 47, 49, 56, 48, 41, 42, 115, 105, 110, 40, 36, 53, 42, 112,
  105, 47, 49, 56, 48, 41, 125, 94, 123, 115, 105, 110, 40, 40, 52, 53,
  43, 36, 52, 41, 42, 112, 105, 47, 49, 56, 48, 41, 42, 115, 105, 110,
  40, 36, 53, 42, 112, 105, 47, 49, 56, 48, 41, 125, 94, 123, 99, 111,
  115, 40, 36, 53, 42, 112, 105, 47, 49, 56, 48, 41, 125, 41, 10, 45,
  114, 32, 36, 119, 104, 10, 45, 45, 10, 45, 110, 111, 114, 109, 10, 45,
  99, 32, 36, 54, 44, 123, 36, 54, 43, 36, 55, 125, 10, 45, 42, 32,
  45, 49, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100,
  108, 10, 45, 105, 102, 32, 123, 36, 56, 61, 61, 48, 125, 10, 45, 114,
  109, 91, 45, 50, 93, 10, 45, 101, 108, 115, 101, 10, 45, 105, 102, 32,
  123, 36, 56, 61, 61, 49, 125, 10, 45, 114, 109, 91, 45, 50, 93, 10,
  49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 51, 44, 50, 53,
  53, 10, 45, 109, 118, 91, 45, 49, 93, 32, 45, 50, 10, 45, 97, 91,
  45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 101, 108, 115, 101, 10, 45,
  98, 108, 101, 110, 100, 32, 100, 111, 100, 103, 101, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 10,
  45, 100, 111, 110, 101, 10, 45, 118, 32, 43, 10, 35, 64, 103, 105, 109,
  112, 32, 74, 112, 114, 32, 119, 97, 114, 112, 102, 114, 111, 109, 116, 104,
  114, 101, 115, 104, 111, 108, 100, 32, 58, 32, 106, 112, 114, 95, 119, 97,
  114, 112, 102, 114, 111, 109, 116, 104, 114, 101, 115, 104, 111, 108, 100, 44,
  106, 112, 114, 95, 119, 97, 114, 112, 102, 114, 111, 109, 116, 104, 114, 101,
  115, 104, 111, 108, 100, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 97,
  32, 100, 117, 109, 109, 121, 32, 49, 48, 48, 120, 49, 48, 48, 32, 103,
  114, 105, 100, 32, 105, 115, 32, 119, 97, 114, 112, 101, 100, 32, 117, 115,
  105, 110, 103, 32, 115, 109, 111, 111, 116, 104, 101, 100, 32, 111, 114, 105,
  101, 110, 116, 97, 116, 105, 111, 110, 32, 97, 115, 32, 97, 32, 109, 97,
  112, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 114, 105,
  103, 104, 116, 110, 101, 115, 115, 32, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 55, 48, 44, 49, 48,
  44, 50, 52, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  105, 109, 112, 108, 105, 102, 121, 32, 114, 101, 103, 105, 111, 110, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 44, 54, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 117, 114, 32, 38, 32, 114,
  101, 110, 111, 114, 109, 97, 108, 105, 115, 101, 32, 108, 111, 111, 112, 32,
  61, 32, 105, 110, 116, 40, 49, 48, 44, 51, 44, 53, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 117, 114, 32, 97, 109, 111,
  117, 110, 116, 32, 112, 101, 114, 32, 115, 116, 101, 112, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 50, 44, 49, 44, 49, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 85, 112, 100, 97, 116, 101, 97, 117, 116, 104,
  111, 114, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 117, 112, 100, 97, 116, 101, 32, 50, 48, 49,
  51, 45, 70, 101, 98, 45, 48, 51, 32, 97, 117, 116, 104, 111, 114, 32,
  64, 106, 97, 121, 112, 114, 105, 99, 104, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 106, 112, 114, 95, 119, 97, 114, 112, 102, 114, 111, 109,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 58, 10, 45, 118, 32, 45, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 108, 91, 36, 62,
  93, 10, 45, 110, 111, 114, 109, 10, 45, 45, 103, 32, 120, 121, 10, 45,
  97, 91, 49, 44, 50, 93, 32, 99, 10, 45, 103, 101, 91, 48, 93, 32,
  36, 49, 10, 45, 98, 91, 48, 93, 32, 36, 50, 10, 45, 103, 101, 91,
  48, 93, 32, 48, 46, 53, 10, 45, 102, 91, 48, 93, 32, 105, 33, 61,
  105, 40, 120, 43, 49, 44, 121, 41, 124, 105, 33, 61, 105, 40, 120, 44,
  121, 43, 49, 41, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 51, 10,
  45, 45, 110, 111, 114, 109, 91, 49, 93, 10, 45, 42, 91, 50, 93, 32,
  91, 48, 93, 10, 45, 97, 91, 49, 44, 50, 93, 32, 99, 10, 45, 102,
  91, 49, 93, 32, 105, 102, 40, 105, 40, 120, 44, 121, 44, 48, 44, 50,
  41, 61, 61, 48, 44, 105, 44, 105, 47, 105, 40, 120, 44, 121, 44, 48,
  44, 50, 41, 41, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 49,
  93, 32, 48, 44, 49, 10, 45, 98, 91, 49, 93, 32, 36, 52, 10, 45,
  100, 111, 110, 101, 10, 45, 114, 109, 91, 48, 93, 10, 45, 115, 32, 99,
  10, 45, 110, 32, 48, 44, 49, 48, 48, 10, 45, 97, 32, 99, 10, 49,
  48, 48, 44, 49, 48, 48, 44, 49, 44, 51, 44, 40, 40, 120, 47, 50,
  41, 37, 52, 41, 61, 61, 48, 124, 40, 99, 61, 61, 50, 38, 40, 40,
  121, 47, 50, 41, 37, 52, 41, 61, 61, 48, 41, 10, 45, 119, 97, 114,
  112, 91, 49, 93, 32, 91, 48, 93, 10, 45, 114, 109, 91, 48, 93, 10,
  45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 10, 45,
  100, 111, 110, 101, 10, 45, 118, 32, 43, 10, 35, 64, 103, 105, 109, 112,
  32, 95, 10, 35, 64, 103, 105, 109, 112, 32, 60, 105, 62, 75, 97, 114,
  111, 39, 115, 32, 116, 101, 115, 116, 115, 60, 47, 105, 62, 10, 35, 64,
  103, 105, 109, 112, 32, 65, 98, 111, 117, 116, 32, 58, 32, 95, 110, 111,
  110, 101, 95, 44, 32, 107, 97, 114, 111, 115, 95, 97, 98, 111, 117, 116,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 123, 34, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 75, 97, 82, 111, 39, 115, 32, 116, 101, 115, 116, 32, 102, 105, 108,
  101, 115, 32, 102, 111, 114, 32, 60, 98, 62, 71, 39, 77, 73, 67, 60,
  47, 98, 62, 92, 110, 92, 119, 114, 105, 116, 116, 101, 110, 32, 98, 121,
  34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 108, 105, 110, 107, 40, 34, 75, 97, 114, 115, 116, 101, 110,
  32, 82, 111, 100, 101, 110, 97, 99, 107, 101, 114, 34, 44, 34, 104, 116,
  116, 112, 58, 47, 47, 75, 46, 82, 111, 100, 101, 110, 97, 99, 107, 101,
  114, 46, 100, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 92, 110, 34,
  125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 123, 34, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 84, 104, 101, 32, 115, 111, 117, 114, 99, 101, 32, 99, 111, 100,
  101, 32, 111, 102, 32, 116, 104, 105, 115, 32, 115, 101, 116, 32, 111, 102,
  32, 102, 105, 108, 116, 101, 114, 115, 32, 105, 115, 32, 97, 118, 97, 105,
  108, 97, 98, 108, 101, 32, 97, 116, 32, 58, 34, 125, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110,
  107, 40, 34, 104, 116, 116, 112, 58, 47, 47, 107, 97, 114, 111, 48, 51,
  46, 98, 112, 108, 97, 99, 101, 100, 46, 110, 101, 116, 47, 103, 109, 105,
  99, 47, 107, 97, 114, 111, 115, 46, 103, 109, 105, 99, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 34, 125, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 83, 101, 118, 101,
  114, 97, 108, 32, 111, 112, 101, 114, 97, 116, 105, 111, 110, 115, 32, 104,
  101, 114, 101, 32, 114, 101, 108, 121, 32, 111, 110, 32, 101, 120, 101, 99,
  117, 116, 97, 98, 108, 101, 115, 32, 101, 120, 105, 115, 116, 105, 110, 103,
  32, 60, 105, 62, 105, 110, 32, 115, 101, 97, 114, 99, 104, 32, 80, 65,
  84, 72, 60, 47, 105, 62, 32, 40, 36, 80, 65, 84, 72, 32, 117, 110,
  116, 101, 114, 32, 77, 97, 99, 47, 85, 110, 105, 120, 41, 46, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 105, 115, 32, 109, 101, 97,
  110, 115, 32, 116, 104, 97, 116, 32, 116, 104, 101, 32, 101, 120, 101, 99,
  117, 116, 97, 98, 108, 101, 32, 105, 115, 32, 100, 111, 119, 110, 108, 111,
  97, 100, 101, 100, 32, 111, 114, 32, 98, 117, 105, 108, 116, 32, 97, 110,
  100, 32, 112, 114, 111, 112, 101, 114, 108, 121, 32, 108, 111, 99, 97, 116,
  101, 100, 46, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 46, 32,
  103, 46, 32, 67, 73, 109, 103, 32, 101, 120, 97, 109, 112, 108, 101, 115,
  32, 104, 97, 118, 101, 32, 116, 111, 32, 98, 101, 32, 98, 117, 105, 108,
  116, 32, 97, 110, 100, 32, 99, 111, 112, 105, 101, 100, 32, 116, 111, 32,
  97, 32, 108, 111, 99, 97, 116, 105, 111, 110, 32, 105, 110, 32, 116, 104,
  101, 32, 115, 101, 97, 114, 99, 104, 32, 112, 97, 116, 104, 44, 32, 101,
  46, 103, 46, 32, 117, 110, 100, 101, 114, 32, 117, 110, 105, 120, 32, 60,
  105, 62, 47, 117, 115, 114, 47, 108, 111, 99, 97, 108, 47, 98, 105, 110,
  60, 47, 105, 62, 46, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  105, 109, 105, 108, 97, 114, 32, 119, 105, 116, 104, 32, 80, 73, 78, 75,
  32, 101, 120, 101, 99, 117, 116, 97, 98, 108, 101, 115, 46, 32, 70, 111,
  114, 32, 77, 97, 99, 32, 116, 104, 101, 121, 32, 104, 97, 118, 101, 32,
  116, 111, 32, 98, 101, 32, 98, 117, 105, 108, 116, 32, 97, 99, 99, 111,
  114, 100, 105, 110, 103, 32, 116, 104, 101, 32, 82, 69, 65, 68, 77, 69,
  32, 119, 105, 116, 104, 32, 60, 105, 62, 46, 47, 109, 97, 107, 101, 108,
  105, 110, 60, 47, 105, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  97, 110, 100, 32, 80, 65, 84, 72, 32, 97, 115, 32, 116, 111, 32, 98,
  101, 32, 101, 120, 116, 101, 110, 100, 101, 100, 32, 98, 121, 32, 60, 105,
  62, 46, 46, 112, 105, 110, 107, 32, 108, 111, 99, 97, 116, 105, 111, 110,
  46, 46, 47, 108, 105, 110, 117, 120, 47, 98, 105, 110, 60, 47, 105, 62,
  46, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 123, 34, 32, 32, 67, 73, 109, 103, 32, 83, 107, 101, 108,
  101, 116, 111, 110, 58, 32, 60, 105, 62, 117, 115, 101, 95, 115, 107, 101,
  108, 101, 116, 111, 110, 60, 47, 105, 62, 32, 105, 110, 32, 115, 101, 97,
  114, 99, 104, 32, 80, 65, 84, 72, 34, 125, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 108, 105, 110, 107, 40, 34,
  104, 116, 116, 112, 58, 47, 47, 99, 105, 109, 103, 46, 99, 118, 115, 46,
  115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47,
  118, 105, 101, 119, 118, 99, 47, 99, 105, 109, 103, 47, 67, 73, 109, 103,
  47, 101, 120, 97, 109, 112, 108, 101, 115, 47, 117, 115, 101, 95, 115, 107,
  101, 108, 101, 116, 111, 110, 46, 99, 112, 112, 63, 118, 105, 101, 119, 61,
  108, 111, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 32, 32, 67, 73,
  109, 103, 32, 110, 108, 109, 101, 97, 110, 115, 58, 32, 60, 105, 62, 117,
  115, 101, 95, 110, 108, 109, 101, 97, 110, 115, 60, 47, 105, 62, 32, 105,
  110, 32, 115, 101, 97, 114, 99, 104, 32, 80, 65, 84, 72, 34, 125, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 108,
  105, 110, 107, 40, 34, 104, 116, 116, 112, 58, 47, 47, 99, 105, 109, 103,
  46, 99, 118, 115, 46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101,
  46, 110, 101, 116, 47, 118, 105, 101, 119, 118, 99, 47, 99, 105, 109, 103,
  47, 67, 73, 109, 103, 47, 101, 120, 97, 109, 112, 108, 101, 115, 47, 117,
  115, 101, 95, 110, 108, 109, 101, 97, 110, 115, 46, 99, 112, 112, 63, 118,
  105, 101, 119, 61, 108, 111, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34,
  32, 32, 109, 77, 32, 68, 105, 102, 102, 101, 114, 101, 110, 99, 101, 115,
  58, 32, 92, 110, 109, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108,
  32, 109, 111, 114, 112, 104, 111, 108, 111, 103, 121, 32, 111, 112, 101, 114,
  97, 116, 105, 111, 110, 32, 100, 105, 102, 102, 101, 114, 101, 110, 99, 101,
  115, 92, 110, 109, 77, 32, 111, 112, 101, 114, 97, 116, 105, 111, 110, 32,
  115, 105, 122, 101, 32, 45, 32, 109, 77, 32, 111, 112, 101, 114, 97, 116,
  105, 111, 110, 32, 115, 105, 122, 101, 50, 34, 125, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  123, 34, 32, 32, 111, 67, 32, 68, 105, 102, 102, 101, 114, 101, 110, 99,
  101, 115, 58, 32, 92, 110, 109, 97, 116, 104, 101, 109, 97, 116, 105, 99,
  97, 108, 32, 109, 111, 114, 112, 104, 111, 108, 111, 103, 121, 32, 111, 112,
  101, 110, 47, 99, 108, 111, 115, 101, 32, 100, 105, 102, 102, 101, 114, 101,
  110, 99, 101, 115, 92, 110, 109, 77, 32, 111, 112, 101, 110, 32, 115, 105,
  122, 101, 32, 45, 32, 109, 77, 32, 99, 108, 111, 115, 101, 32, 115, 105,
  122, 101, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 32, 32, 80, 105, 110,
  107, 32, 111, 112, 101, 114, 97, 116, 105, 111, 110, 115, 32, 98, 105, 110,
  97, 114, 121, 58, 32, 60, 105, 62, 80, 105, 110, 107, 32, 97, 112, 112,
  108, 105, 99, 97, 116, 105, 111, 110, 115, 60, 47, 105, 62, 32, 105, 110,
  32, 115, 101, 97, 114, 99, 104, 32, 80, 65, 84, 72, 34, 125, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 108, 105,
  110, 107, 40, 34, 104, 116, 116, 112, 58, 47, 47, 112, 105, 110, 107, 104,
  113, 46, 99, 111, 109, 47, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 92, 110, 84, 104, 101, 32,
  102, 117, 110, 99, 116, 105, 111, 110, 115, 32, 100, 101, 102, 105, 110, 101,
  100, 32, 97, 114, 101, 32, 113, 117, 105, 116, 101, 32, 60, 105, 62, 101,
  120, 112, 101, 114, 105, 109, 101, 110, 116, 97, 108, 60, 47, 105, 62, 32,
  97, 110, 100, 32, 115, 117, 98, 106, 101, 99, 116, 32, 116, 111, 32, 99,
  104, 97, 110, 103, 101, 115, 46, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 80, 108, 101, 97, 115, 101, 32, 100, 111, 32, 110, 111, 116, 32, 114,
  101, 108, 121, 32, 111, 110, 32, 116, 104, 101, 32, 102, 97, 99, 116, 32,
  116, 104, 97, 116, 32, 116, 104, 101, 121, 32, 119, 105, 108, 108, 32, 112,
  101, 114, 102, 111, 114, 109, 32, 101, 113, 117, 97, 108, 108, 121, 32, 102,
  111, 114, 101, 118, 101, 114, 46, 34, 125, 10, 107, 97, 114, 111, 115, 95,
  97, 98, 111, 117, 116, 32, 58, 10, 45, 103, 105, 109, 112, 95, 108, 111,
  103, 111, 32, 34, 32, 34, 32, 91, 48, 93, 32, 45, 42, 91, 45, 49,
  93, 32, 48, 32, 45, 116, 101, 120, 116, 91, 45, 49, 93, 32, 34, 75,
  97, 82, 111, 39, 115, 34, 44, 49, 48, 37, 44, 50, 50, 37, 44, 53,
  55, 44, 49, 44, 50, 53, 53, 32, 45, 116, 101, 120, 116, 91, 45, 49,
  93, 32, 34, 84, 101, 115, 116, 115, 34, 44, 52, 48, 37, 44, 54, 48,
  37, 44, 53, 55, 44, 49, 44, 50, 48, 48, 32, 45, 45, 116, 111, 95,
  103, 114, 97, 121, 91, 45, 49, 93, 32, 45, 115, 107, 101, 108, 101, 116,
  111, 110, 91, 45, 49, 93, 32, 44, 32, 45, 110, 91, 45, 49, 45, 45,
  50, 93, 32, 48, 44, 50, 53, 53, 32, 45, 100, 105, 108, 97, 116, 101,
  91, 45, 50, 93, 32, 50, 32, 45, 45, 91, 45, 49, 45, 45, 50, 93,
  32, 45, 43, 32, 45, 110, 32, 48, 44, 50, 53, 53, 10, 112, 115, 101,
  117, 100, 111, 95, 99, 32, 58, 32, 45, 118, 32, 45, 32, 64, 123, 45,
  49, 44, 77, 125, 44, 49, 44, 49, 44, 51, 44, 63, 40, 50, 53, 53,
  41, 32, 45, 114, 111, 117, 110, 100, 91, 45, 49, 93, 32, 45, 109, 97,
  112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45,
  49, 93, 32, 45, 118, 32, 43, 10, 95, 117, 112, 95, 101, 115, 32, 58,
  32, 45, 118, 32, 45, 32, 118, 101, 114, 61, 64, 46, 32, 45, 115, 107,
  105, 112, 32, 34, 36, 123, 49, 61, 36, 118, 101, 114, 125, 34, 44, 34,
  36, 123, 50, 61, 48, 125, 34, 10, 45, 118, 32, 43, 32, 45, 101, 91,
  94, 49, 93, 32, 34, 85, 112, 100, 97, 116, 101, 32, 101, 120, 116, 101,
  114, 110, 97, 108, 32, 115, 111, 117, 114, 99, 101, 102, 105, 108, 101, 115,
  32, 97, 110, 100, 32, 46, 103, 109, 105, 99, 95, 100, 101, 102, 46, 34,
  36, 49, 32, 45, 118, 32, 45, 10, 45, 105, 32, 114, 97, 119, 58, 104,
  116, 116, 112, 58, 47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99,
  101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 103, 109, 105, 99, 95,
  100, 101, 102, 46, 36, 49, 44, 117, 99, 104, 97, 114, 32, 45, 111, 91,
  45, 49, 93, 32, 114, 97, 119, 58, 36, 123, 72, 79, 77, 69, 125, 47,
  46, 103, 109, 105, 99, 95, 100, 101, 102, 46, 36, 49, 44, 117, 99, 104,
  97, 114, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 105, 102, 32, 36,
  50, 32, 45, 105, 32, 64, 123, 45, 112, 97, 116, 104, 95, 117, 115, 101,
  114, 125, 64, 123, 45, 102, 105, 108, 101, 95, 115, 108, 97, 115, 104, 125,
  46, 103, 109, 105, 99, 95, 115, 111, 117, 114, 99, 101, 115, 46, 99, 105,
  109, 103, 122, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 45, 64, 123, 60, 44, 45, 49, 125, 93, 32, 45, 105, 102, 32,
  123, 119, 62, 53, 125, 10, 102, 110, 61, 64, 123, 45, 49, 44, 116, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 118, 32, 43, 32, 45, 101,
  32, 36, 123, 102, 110, 125, 32, 45, 118, 32, 45, 10, 45, 105, 32, 114,
  97, 119, 58, 36, 123, 102, 110, 125, 44, 117, 99, 104, 97, 114, 32, 45,
  111, 91, 45, 49, 93, 32, 114, 97, 119, 58, 36, 123, 72, 79, 77, 69,
  125, 47, 46, 64, 123, 45, 49, 44, 98, 125, 46, 103, 109, 105, 99, 44,
  117, 99, 104, 97, 114, 32, 45, 101, 110, 100, 105, 102, 32, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 45, 101, 110, 100, 105, 102, 32, 45, 118, 32, 43, 10, 107, 97, 114,
  111, 95, 99, 108, 111, 115, 101, 32, 58, 10, 45, 101, 32, 34, 67, 111,
  109, 112, 117, 116, 101, 32, 99, 108, 111, 115, 105, 110, 103, 32, 105, 109,
  97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 115, 105, 122, 101,
  32, 36, 49, 32, 40, 111, 110, 108, 121, 32, 50, 100, 41, 46, 34, 10,
  45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 53, 125, 44, 36, 123, 50,
  61, 48, 125, 44, 36, 123, 51, 61, 48, 125, 44, 36, 123, 52, 61, 48,
  125, 44, 36, 123, 53, 61, 48, 125, 10, 45, 103, 105, 109, 112, 95, 109,
  111, 114, 112, 104, 111, 32, 51, 44, 36, 49, 44, 36, 51, 44, 36, 50,
  44, 36, 53, 44, 36, 52, 10, 107, 97, 114, 111, 95, 111, 112, 101, 110,
  32, 58, 10, 45, 101, 32, 34, 67, 111, 109, 112, 117, 116, 101, 32, 111,
  112, 101, 110, 105, 110, 103, 32, 105, 109, 97, 103, 101, 36, 63, 44, 32,
  119, 105, 116, 104, 32, 115, 105, 122, 101, 32, 36, 49, 32, 40, 111, 110,
  108, 121, 32, 50, 100, 41, 46, 34, 10, 45, 115, 107, 105, 112, 32, 36,
  123, 49, 61, 53, 125, 44, 36, 123, 50, 61, 48, 125, 44, 36, 123, 51,
  61, 48, 125, 44, 36, 123, 52, 61, 48, 125, 44, 36, 123, 53, 61, 48,
  125, 10, 45, 103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111, 32, 50,
  44, 36, 49, 44, 36, 51, 44, 36, 50, 44, 36, 53, 44, 36, 52, 10,
  107, 97, 114, 111, 95, 100, 111, 99, 32, 58, 10, 45, 101, 32, 34, 67,
  111, 109, 112, 117, 116, 101, 32, 100, 105, 102, 102, 101, 114, 101, 110, 99,
  101, 32, 111, 102, 32, 111, 112, 101, 110, 47, 99, 108, 111, 115, 101, 32,
  97, 110, 100, 32, 111, 114, 105, 103, 105, 110, 97, 108, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 119, 105, 110, 100, 111,
  119, 32, 115, 105, 122, 101, 32, 36, 49, 32, 40, 111, 110, 108, 121, 32,
  50, 100, 41, 46, 34, 32, 45, 118, 32, 45, 10, 45, 115, 107, 105, 112,
  32, 36, 123, 49, 61, 53, 125, 44, 36, 123, 50, 61, 49, 125, 44, 36,
  123, 51, 61, 48, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 64, 123, 60, 44, 45, 49, 125, 93, 10, 45, 45, 107,
  97, 114, 111, 95, 111, 112, 101, 110, 91, 48, 93, 32, 36, 49, 44, 36,
  50, 44, 48, 44, 48, 44, 36, 51, 32, 45, 45, 107, 97, 114, 111, 95,
  99, 108, 111, 115, 101, 91, 48, 93, 32, 36, 49, 44, 36, 50, 44, 48,
  44, 48, 44, 36, 51, 10, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 47, 91, 45, 49, 93, 32, 50, 32, 45, 45, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 107, 97, 114,
  111, 95, 100, 111, 111, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  49, 61, 53, 125, 44, 36, 123, 50, 61, 55, 125, 44, 36, 123, 51, 61,
  50, 125, 44, 36, 123, 52, 61, 49, 125, 44, 36, 123, 53, 61, 48, 125,
  44, 36, 123, 54, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 67, 111, 109, 112, 117, 116, 101, 32, 100, 105, 102, 102, 101, 114, 101,
  110, 99, 101, 32, 111, 102, 32, 109, 109, 32, 111, 112, 32, 111, 110, 32,
  105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 115, 105,
  122, 101, 115, 32, 36, 49, 32, 97, 110, 100, 32, 36, 50, 32, 40, 111,
  110, 108, 121, 32, 50, 100, 41, 46, 34, 32, 45, 118, 32, 45, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 64, 123, 60,
  44, 45, 49, 125, 93, 10, 45, 45, 103, 105, 109, 112, 95, 109, 111, 114,
  112, 104, 111, 91, 45, 49, 93, 32, 36, 51, 44, 36, 49, 44, 48, 44,
  36, 52, 44, 36, 54, 44, 48, 10, 45, 103, 105, 109, 112, 95, 109, 111,
  114, 112, 104, 111, 91, 45, 50, 93, 32, 36, 51, 44, 36, 50, 44, 48,
  44, 36, 52, 44, 36, 54, 44, 48, 10, 45, 105, 102, 32, 123, 123, 36,
  123, 51, 125, 38, 49, 125, 61, 61, 48, 125, 32, 45, 114, 118, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 45, 91,
  45, 50, 44, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 53, 61, 61,
  49, 125, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 107, 97, 114, 111, 95, 108, 97, 98,
  101, 108, 95, 115, 111, 114, 116, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 83, 111, 114, 116, 32, 108, 97, 98, 101, 108, 108, 101, 100,
  32, 105, 109, 97, 103, 101, 32, 91, 49, 93, 32, 98, 121, 32, 114, 101,
  103, 105, 111, 110, 32, 115, 105, 122, 101, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 110, 98, 61, 123, 49, 43, 105, 77, 125, 32, 109, 110, 61,
  64, 123, 45, 49, 44, 109, 125, 32, 45, 45, 104, 105, 115, 116, 111, 103,
  114, 97, 109, 91, 45, 49, 93, 32, 36, 110, 98, 44, 48, 44, 123, 36,
  110, 98, 45, 49, 125, 10, 49, 48, 48, 37, 44, 49, 44, 49, 44, 49,
  44, 120, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 32, 45,
  115, 111, 114, 116, 91, 45, 49, 93, 32, 45, 44, 120, 32, 45, 114, 111,
  119, 115, 91, 45, 49, 93, 32, 49, 10, 49, 48, 48, 37, 44, 49, 44,
  49, 44, 49, 44, 120, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32,
  121, 32, 45, 115, 111, 114, 116, 91, 45, 49, 93, 32, 43, 44, 120, 32,
  45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 49, 10, 45, 109, 97, 112,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 107, 97, 114, 111, 95, 108, 97, 98, 101, 108, 32, 58, 32,
  45, 99, 104, 101, 99, 107, 32, 34, 36, 49, 62, 61, 48, 34, 32, 45,
  115, 107, 105, 112, 32, 36, 123, 50, 61, 48, 125, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 51, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 76, 97, 98, 101, 108, 32, 99, 111, 110, 110, 101, 99, 116, 101,
  100, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 32, 111, 110, 32,
  105, 109, 97, 103, 101, 32, 91, 49, 93, 44, 32, 119, 105, 116, 104, 32,
  116, 111, 108, 101, 114, 97, 110, 99, 101, 32, 36, 49, 44, 32, 34, 64,
  123, 45, 97, 114, 103, 92, 32, 49, 43, 33, 36, 50, 44, 104, 105, 103,
  104, 44, 108, 111, 119, 125, 34, 32, 99, 111, 110, 110, 101, 99, 116, 105,
  118, 105, 116, 121, 32, 97, 110, 100, 32, 34, 64, 123, 45, 97, 114, 103,
  92, 32, 49, 43, 33, 36, 51, 44, 115, 111, 114, 116, 101, 100, 44, 117,
  110, 115, 111, 114, 116, 101, 100, 125, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  45, 108, 97, 98, 101, 108, 91, 45, 49, 93, 32, 36, 49, 44, 36, 50,
  10, 45, 105, 102, 32, 123, 36, 51, 125, 10, 110, 98, 61, 123, 49, 43,
  64, 123, 45, 49, 44, 77, 125, 125, 32, 45, 45, 104, 105, 115, 116, 111,
  103, 114, 97, 109, 91, 45, 49, 93, 32, 36, 110, 98, 44, 48, 44, 64,
  123, 45, 49, 44, 77, 125, 10, 49, 48, 48, 37, 44, 49, 44, 49, 44,
  49, 44, 120, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 121, 32,
  45, 115, 111, 114, 116, 91, 45, 49, 93, 32, 45, 44, 120, 32, 45, 114,
  111, 119, 115, 91, 45, 49, 93, 32, 49, 10, 49, 48, 48, 37, 44, 49,
  44, 49, 44, 49, 44, 120, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93,
  32, 121, 32, 45, 115, 111, 114, 116, 91, 45, 49, 93, 32, 43, 44, 120,
  32, 45, 114, 111, 119, 115, 91, 45, 49, 93, 32, 49, 10, 45, 109, 97,
  112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 107, 97, 114, 111, 95,
  109, 120, 32, 58, 10, 45, 99, 104, 101, 99, 107, 32, 34, 36, 123, 49,
  61, 45, 50, 125, 62, 61, 45, 50, 32, 38, 38, 32, 36, 49, 60, 61,
  53, 32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 50, 61, 48,
  125, 41, 32, 38, 38, 32, 36, 50, 62, 61, 48, 34, 10, 45, 115, 107,
  105, 112, 32, 36, 123, 51, 61, 48, 125, 10, 45, 118, 32, 45, 32, 45,
  105, 102, 32, 123, 36, 49, 60, 45, 49, 124, 124, 36, 49, 62, 53, 125,
  32, 118, 97, 114, 61, 34, 109, 100, 44, 109, 48, 44, 109, 49, 44, 109,
  50, 44, 109, 105, 110, 44, 109, 97, 120, 44, 109, 101, 100, 34, 10, 45,
  101, 108, 115, 101, 32, 118, 97, 114, 61, 64, 123, 45, 97, 114, 103, 92,
  32, 123, 36, 49, 43, 50, 125, 44, 34, 109, 100, 44, 109, 48, 44, 109,
  49, 44, 109, 50, 44, 109, 105, 110, 44, 109, 97, 120, 44, 109, 101, 100,
  34, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  50, 62, 49, 125, 32, 118, 97, 114, 49, 61, 34, 49, 100, 32, 115, 109,
  111, 111, 116, 104, 101, 100, 32, 40, 119, 105, 100, 116, 104, 61, 34, 36,
  50, 34, 41, 34, 32, 32, 45, 101, 108, 115, 101, 32, 118, 97, 114, 49,
  61, 34, 49, 100, 34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32,
  43, 10, 45, 101, 32, 34, 67, 97, 108, 99, 117, 108, 97, 116, 101, 32,
  102, 101, 97, 116, 117, 114, 101, 32, 34, 36, 118, 97, 114, 34, 32, 102,
  114, 111, 109, 32, 34, 36, 118, 97, 114, 49, 34, 32, 104, 105, 115, 116,
  111, 103, 114, 97, 109, 46, 34, 10, 45, 105, 102, 32, 123, 104, 62, 49,
  124, 124, 100, 62, 49, 124, 124, 115, 62, 49, 125, 32, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 73, 109, 97, 103, 101, 36, 63, 32, 115, 101, 101,
  109, 105, 110, 103, 108, 121, 32, 110, 111, 116, 32, 49, 100, 33, 34, 32,
  45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  118, 32, 45, 32, 45, 108, 91, 45, 49, 93, 10, 45, 105, 102, 32, 36,
  51, 32, 45, 112, 111, 105, 110, 116, 91, 45, 49, 93, 32, 48, 44, 48,
  44, 48, 44, 49, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 50, 62, 49, 125, 32, 32, 36, 50, 44, 49, 44, 49,
  44, 49, 32, 45, 43, 91, 45, 49, 93, 32, 123, 49, 47, 36, 50, 125,
  32, 45, 99, 111, 110, 118, 111, 108, 118, 101, 91, 45, 50, 93, 32, 91,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 114, 111, 117,
  110, 100, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 109, 100,
  61, 123, 120, 77, 125, 10, 109, 48, 61, 64, 123, 45, 49, 44, 43, 125,
  10, 99, 99, 61, 64, 123, 45, 97, 117, 116, 111, 99, 114, 111, 112, 95,
  99, 111, 111, 114, 100, 115, 91, 45, 49, 93, 92, 32, 48, 125, 32, 109,
  110, 61, 64, 123, 45, 97, 114, 103, 92, 32, 49, 44, 36, 99, 99, 125,
  32, 109, 120, 61, 64, 123, 45, 97, 114, 103, 92, 32, 52, 44, 36, 99,
  99, 125, 10, 45, 45, 102, 105, 108, 108, 91, 45, 49, 93, 32, 120, 32,
  45, 45, 42, 91, 45, 49, 44, 45, 50, 93, 32, 109, 49, 61, 123, 64,
  123, 45, 49, 44, 43, 125, 47, 36, 109, 48, 125, 32, 45, 114, 109, 91,
  45, 49, 44, 45, 50, 93, 10, 45, 45, 102, 105, 108, 108, 91, 45, 49,
  93, 32, 120, 94, 50, 32, 45, 45, 42, 91, 45, 49, 44, 45, 50, 93,
  32, 109, 50, 61, 123, 115, 113, 114, 116, 40, 64, 123, 45, 49, 44, 43,
  125, 47, 36, 109, 48, 45, 36, 109, 49, 94, 50, 41, 125, 32, 45, 114,
  109, 91, 45, 49, 44, 45, 50, 93, 10, 45, 45, 99, 117, 109, 117, 108,
  91, 45, 49, 93, 10, 45, 45, 103, 101, 91, 45, 49, 93, 32, 123, 64,
  123, 45, 49, 44, 77, 125, 47, 50, 125, 32, 109, 101, 100, 49, 61, 64,
  123, 45, 97, 114, 103, 92, 32, 49, 44, 64, 123, 45, 49, 44, 67, 125,
  125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 45, 108, 101, 91, 45,
  49, 93, 32, 123, 64, 123, 45, 49, 44, 77, 125, 47, 50, 125, 32, 109,
  101, 100, 50, 61, 64, 123, 45, 97, 114, 103, 92, 32, 49, 44, 64, 123,
  45, 49, 44, 99, 125, 125, 32, 45, 114, 109, 91, 45, 49, 44, 45, 50,
  93, 10, 109, 101, 100, 61, 123, 40, 36, 109, 101, 100, 49, 43, 36, 109,
  101, 100, 50, 41, 47, 50, 125, 10, 45, 114, 109, 91, 45, 49, 93, 10,
  45, 105, 102, 32, 123, 36, 49, 61, 61, 45, 49, 125, 32, 45, 117, 32,
  36, 109, 100, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 48,
  125, 32, 45, 117, 32, 36, 109, 48, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 61, 61, 49, 125, 32, 45, 117, 32, 36, 109, 49, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 49, 61, 61, 50, 125, 32, 45, 117, 32, 36,
  109, 50, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 51, 125,
  32, 45, 117, 32, 36, 109, 110, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  49, 61, 61, 52, 125, 32, 45, 117, 32, 36, 109, 120, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 61, 61, 53, 125, 32, 45, 117, 32, 36, 109,
  101, 100, 10, 45, 101, 108, 115, 101, 32, 45, 117, 32, 36, 109, 100, 44,
  36, 109, 48, 44, 36, 109, 49, 44, 36, 109, 50, 44, 36, 109, 110, 44,
  36, 109, 120, 44, 36, 109, 101, 100, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 108, 32, 45, 118, 32, 43, 10, 107, 97, 114, 111, 95,
  109, 120, 49, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67,
  97, 108, 99, 117, 108, 97, 116, 101, 32, 109, 100, 44, 109, 48, 44, 109,
  49, 44, 109, 50, 44, 109, 105, 110, 44, 109, 97, 120, 44, 109, 101, 100,
  32, 102, 114, 111, 109, 32, 49, 100, 32, 101, 118, 116, 108, 46, 32, 115,
  109, 111, 111, 116, 104, 101, 100, 32, 104, 105, 115, 116, 111, 103, 114, 97,
  109, 46, 34, 10, 45, 118, 32, 45, 32, 45, 107, 97, 114, 111, 95, 109,
  120, 32, 36, 123, 49, 61, 45, 50, 125, 44, 36, 123, 50, 61, 48, 125,
  44, 49, 32, 45, 118, 32, 43, 10, 104, 105, 115, 116, 95, 102, 101, 97,
  116, 117, 114, 101, 32, 58, 10, 45, 99, 104, 101, 99, 107, 32, 34, 36,
  123, 49, 61, 45, 50, 125, 62, 61, 45, 50, 38, 38, 36, 49, 60, 61,
  52, 38, 38, 105, 115, 105, 110, 116, 40, 36, 49, 41, 38, 38, 105, 115,
  105, 110, 116, 40, 36, 123, 50, 61, 48, 125, 41, 38, 38, 36, 50, 62,
  61, 48, 34, 10, 45, 115, 107, 105, 112, 32, 36, 123, 51, 61, 48, 125,
  44, 36, 123, 52, 61, 48, 125, 44, 36, 123, 53, 61, 49, 125, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 67, 97, 108, 99, 117, 108, 97, 116,
  101, 32, 109, 100, 44, 109, 48, 44, 109, 49, 44, 109, 50, 44, 109, 105,
  110, 44, 109, 97, 120, 32, 102, 114, 111, 109, 32, 49, 100, 32, 104, 105,
  115, 116, 111, 103, 114, 97, 109, 46, 34, 10, 45, 118, 32, 45, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 108, 91, 64, 123, 62,
  44, 45, 49, 125, 93, 10, 45, 105, 102, 32, 123, 104, 62, 49, 124, 124,
  100, 62, 49, 124, 124, 115, 62, 49, 125, 32, 45, 118, 32, 43, 32, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 73, 109, 97, 103, 101, 32, 34, 64,
  123, 62, 44, 45, 49, 125, 34, 32, 115, 101, 101, 109, 105, 110, 103, 108,
  121, 32, 110, 111, 116, 32, 49, 100, 33, 34, 32, 45, 118, 32, 45, 32,
  45, 99, 111, 110, 116, 105, 110, 117, 101, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 51, 33, 61, 48, 125, 32, 45, 112, 111,
  105, 110, 116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 49, 44,
  48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 50,
  62, 61, 49, 125, 32, 32, 36, 50, 44, 49, 44, 49, 44, 49, 32, 45,
  43, 91, 45, 49, 93, 32, 123, 49, 47, 36, 50, 125, 32, 45, 99, 111,
  110, 118, 111, 108, 118, 101, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32,
  45, 114, 109, 91, 45, 49, 93, 32, 45, 114, 111, 117, 110, 100, 91, 45,
  49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 109, 100, 61, 123, 120, 77,
  42, 36, 53, 43, 36, 52, 125, 10, 109, 48, 61, 64, 123, 45, 49, 44,
  43, 125, 10, 99, 99, 61, 64, 123, 45, 97, 117, 116, 111, 99, 114, 111,
  112, 95, 99, 111, 111, 114, 100, 115, 91, 45, 49, 93, 125, 10, 109, 110,
  61, 123, 64, 123, 45, 97, 114, 103, 92, 32, 49, 44, 36, 99, 99, 125,
  42, 36, 53, 43, 36, 52, 125, 32, 109, 120, 61, 123, 64, 123, 45, 97,
  114, 103, 92, 32, 52, 44, 36, 99, 99, 125, 42, 36, 53, 43, 36, 52,
  125, 10, 45, 45, 42, 91, 45, 49, 93, 32, 39, 120, 42, 36, 53, 43,
  36, 52, 39, 32, 109, 49, 61, 123, 64, 123, 45, 49, 44, 43, 125, 47,
  36, 109, 48, 125, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 45, 42,
  91, 45, 49, 93, 32, 39, 40, 120, 42, 36, 53, 43, 36, 52, 41, 94,
  50, 39, 32, 109, 50, 61, 123, 115, 113, 114, 116, 40, 64, 123, 45, 49,
  44, 43, 125, 47, 36, 109, 48, 45, 36, 109, 49, 94, 50, 41, 125, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 114, 101, 115, 61, 36, 109, 100, 92,
  44, 36, 109, 48, 92, 44, 36, 109, 49, 92, 44, 36, 109, 50, 92, 44,
  36, 109, 110, 92, 44, 36, 109, 120, 10, 45, 105, 102, 32, 123, 36, 49,
  62, 45, 50, 125, 32, 114, 101, 115, 61, 64, 123, 45, 97, 114, 103, 92,
  32, 123, 36, 49, 43, 50, 125, 44, 36, 114, 101, 115, 125, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 64, 123, 62, 44, 45, 49,
  125, 61, 61, 48, 125, 32, 115, 114, 101, 115, 61, 36, 114, 101, 115, 32,
  45, 101, 108, 115, 101, 32, 115, 114, 101, 115, 61, 36, 115, 114, 101, 115,
  92, 44, 36, 114, 101, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  110, 100, 108, 10, 45, 100, 111, 110, 101, 32, 45, 117, 32, 36, 115, 114,
  101, 115, 32, 45, 118, 32, 43, 10, 107, 97, 114, 111, 95, 120, 99, 105,
  109, 103, 32, 58, 10, 102, 105, 108, 101, 110, 97, 109, 101, 61, 64, 123,
  45, 102, 105, 108, 101, 95, 114, 97, 110, 100, 125, 10, 45, 105, 102, 32,
  123, 33, 64, 123, 45, 105, 115, 95, 119, 105, 110, 100, 111, 119, 115, 125,
  125, 10, 45, 120, 32, 34, 119, 104, 105, 99, 104, 32, 34, 36, 49, 34,
  32, 62, 47, 100, 101, 118, 47, 110, 117, 108, 108, 32, 50, 62, 38, 49,
  34, 10, 45, 105, 102, 32, 64, 123, 125, 32, 45, 118, 32, 43, 32, 45,
  101, 32, 34, 101, 120, 101, 99, 117, 116, 97, 98, 108, 101, 32, 92, 34,
  36, 49, 92, 34, 32, 110, 111, 116, 32, 102, 111, 117, 110, 100, 32, 105,
  110, 32, 80, 65, 84, 72, 44, 32, 115, 116, 97, 116, 117, 115, 32, 61,
  32, 34, 64, 123, 125, 34, 33, 33, 32, 82, 101, 116, 117, 114, 110, 105,
  110, 103, 33, 33, 92, 110, 34, 32, 45, 118, 32, 45, 10, 123, 119, 125,
  44, 123, 104, 125, 32, 45, 103, 105, 109, 112, 95, 108, 111, 103, 111, 32,
  34, 101, 120, 101, 99, 32, 69, 114, 114, 111, 114, 32, 33, 33, 34, 32,
  45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 111, 32, 36, 123, 102, 105, 108, 101, 110,
  97, 109, 101, 125, 46, 99, 105, 109, 103, 10, 45, 120, 32, 34, 36, 49,
  32, 45, 105, 32, 34, 36, 123, 102, 105, 108, 101, 110, 97, 109, 101, 125,
  34, 46, 99, 105, 109, 103, 32, 36, 50, 32, 45, 111, 32, 34, 36, 123,
  102, 105, 108, 101, 110, 97, 109, 101, 125, 34, 46, 99, 105, 109, 103, 34,
  10, 45, 105, 102, 32, 64, 123, 125, 32, 45, 118, 32, 43, 32, 45, 101,
  32, 34, 83, 116, 97, 116, 117, 115, 32, 105, 115, 32, 34, 64, 123, 125,
  34, 46, 34, 32, 45, 118, 32, 45, 32, 123, 119, 125, 44, 123, 104, 125,
  32, 45, 103, 105, 109, 112, 95, 108, 111, 103, 111, 32, 34, 101, 120, 101,
  99, 32, 69, 114, 114, 111, 114, 32, 33, 33, 34, 10, 45, 101, 108, 115,
  101, 32, 45, 105, 32, 36, 123, 102, 105, 108, 101, 110, 97, 109, 101, 125,
  46, 99, 105, 109, 103, 32, 45, 101, 110, 100, 105, 102, 10, 45, 102, 105,
  108, 101, 95, 114, 109, 32, 36, 123, 102, 105, 108, 101, 110, 97, 109, 101,
  125, 46, 99, 105, 109, 103, 10, 107, 97, 114, 111, 95, 108, 105, 50, 115,
  116, 32, 58, 10, 45, 118, 32, 45, 32, 45, 117, 32, 34, 34, 32, 45,
  105, 102, 32, 123, 36, 35, 62, 61, 49, 125, 32, 40, 123, 34, 39, 36,
  123, 49, 45, 45, 49, 125, 39, 34, 125, 41, 32, 45, 114, 101, 112, 108,
  97, 99, 101, 91, 45, 49, 93, 32, 123, 39, 44, 39, 125, 44, 123, 34,
  39, 32, 39, 34, 125, 32, 45, 117, 32, 64, 123, 45, 49, 44, 116, 125,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 32,
  45, 118, 32, 43, 10, 107, 97, 114, 111, 95, 115, 107, 101, 108, 101, 116,
  111, 110, 32, 58, 32, 45, 118, 32, 45, 32, 45, 105, 102, 32, 123, 36,
  35, 62, 48, 125, 32, 45, 107, 97, 114, 111, 95, 108, 105, 50, 115, 116,
  32, 36, 123, 49, 45, 45, 49, 125, 32, 112, 61, 64, 123, 125, 32, 45,
  101, 108, 115, 101, 32, 112, 61, 34, 34, 32, 45, 101, 110, 100, 105, 102,
  32, 45, 118, 32, 43, 10, 45, 101, 32, 34, 67, 111, 109, 112, 117, 116,
  101, 32, 117, 115, 101, 95, 115, 107, 101, 108, 101, 116, 111, 110, 32, 101,
  120, 101, 99, 32, 119, 105, 116, 104, 32, 111, 112, 116, 105, 111, 110, 115,
  32, 34, 36, 112, 34, 32, 111, 110, 36, 63, 34, 32, 45, 118, 32, 45,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 64,
  123, 62, 44, 45, 49, 125, 93, 10, 115, 61, 64, 123, 45, 49, 44, 115,
  125, 32, 45, 105, 102, 32, 123, 36, 115, 62, 49, 125, 32, 45, 115, 91,
  45, 49, 93, 32, 99, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 64, 123, 62, 44, 45,
  49, 125, 93, 32, 45, 107, 97, 114, 111, 95, 120, 99, 105, 109, 103, 32,
  117, 115, 101, 95, 115, 107, 101, 108, 101, 116, 111, 110, 44, 36, 123, 112,
  125, 34, 32, 45, 118, 105, 115, 117, 32, 48, 34, 32, 45, 109, 118, 91,
  45, 49, 93, 32, 48, 32, 45, 107, 91, 48, 93, 32, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 115, 62,
  49, 125, 32, 45, 97, 91, 45, 36, 115, 45, 45, 49, 93, 32, 99, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 107, 97, 114, 111, 95, 110, 108, 109,
  101, 97, 110, 115, 32, 58, 32, 45, 118, 32, 45, 32, 45, 105, 102, 32,
  123, 36, 35, 62, 48, 125, 32, 45, 107, 97, 114, 111, 95, 108, 105, 50,
  115, 116, 32, 36, 123, 49, 45, 45, 49, 125, 32, 112, 61, 64, 123, 125,
  32, 45, 101, 108, 115, 101, 32, 112, 61, 34, 34, 32, 45, 101, 110, 100,
  105, 102, 32, 45, 118, 32, 43, 10, 45, 101, 32, 34, 67, 111, 109, 112,
  117, 116, 101, 32, 117, 115, 101, 95, 110, 108, 109, 101, 97, 110, 115, 32,
  101, 120, 101, 99, 32, 119, 105, 116, 104, 32, 111, 112, 116, 105, 111, 110,
  115, 32, 34, 36, 123, 112, 125, 34, 32, 111, 110, 36, 63, 34, 32, 45,
  118, 32, 45, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 64, 123, 62, 44, 45, 49, 125, 93, 10, 115, 61, 64, 123, 45,
  49, 44, 115, 125, 32, 45, 105, 102, 32, 123, 36, 115, 62, 49, 125, 32,
  45, 115, 91, 45, 49, 93, 32, 99, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 64, 123,
  62, 44, 45, 49, 125, 93, 32, 45, 107, 97, 114, 111, 95, 120, 99, 105,
  109, 103, 32, 117, 115, 101, 95, 110, 108, 109, 101, 97, 110, 115, 44, 36,
  123, 112, 125, 34, 32, 45, 118, 105, 115, 117, 32, 48, 34, 32, 45, 109,
  118, 91, 45, 49, 93, 32, 48, 32, 45, 107, 91, 48, 93, 32, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36,
  115, 62, 49, 125, 32, 45, 97, 91, 45, 36, 115, 45, 45, 49, 93, 32,
  99, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 105, 109, 112,
  32, 67, 105, 109, 103, 32, 110, 108, 109, 101, 97, 110, 115, 32, 58, 32,
  103, 105, 109, 112, 95, 107, 97, 114, 111, 95, 99, 105, 109, 103, 95, 110,
  108, 109, 101, 97, 110, 115, 44, 32, 103, 105, 109, 112, 95, 107, 97, 114,
  111, 95, 99, 105, 109, 103, 95, 110, 108, 109, 101, 97, 110, 115, 95, 112,
  114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 100, 100, 32, 103, 97, 117, 115, 115, 32, 110, 111, 105,
  115, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 48, 44, 48,
  46, 48, 44, 51, 48, 46, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 65, 100, 100, 32, 117, 110, 105, 102, 111, 114, 109, 32, 110, 111,
  105, 115, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 48, 44,
  48, 46, 48, 44, 51, 48, 46, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 100, 100, 32, 115, 97, 108, 116, 32, 38, 32, 112, 101,
  112, 112, 101, 114, 32, 110, 111, 105, 115, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 48, 44, 48, 46, 48, 44, 51, 48, 46, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 97, 108, 102, 32, 115,
  105, 122, 101, 32, 111, 102, 32, 112, 97, 116, 99, 104, 32, 61, 32, 105,
  110, 116, 40, 49, 44, 49, 44, 49, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 66, 97, 110, 100, 32, 119, 105, 100, 116, 104, 32, 108,
  97, 109, 98, 100, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 45, 49,
  44, 45, 49, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 105, 115, 101, 32, 115, 100, 32, 115, 105, 103, 109, 97, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 45, 49, 44, 45, 49, 44, 50, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 101, 105, 103, 104,
  98, 111, 114, 104, 111, 111, 100, 32, 115, 105, 122, 101, 32, 97, 108, 112,
  104, 97, 32, 61, 32, 105, 110, 116, 40, 51, 44, 49, 44, 49, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 97, 109, 112, 108, 105,
  110, 103, 32, 115, 116, 101, 112, 32, 115, 105, 122, 101, 32, 61, 32, 105,
  110, 116, 40, 50, 44, 49, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121,
  112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 70,
  117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  83, 109, 111, 111, 116, 104, 105, 110, 103, 32, 117, 115, 105, 110, 103, 32,
  67, 73, 109, 103, 32, 101, 120, 97, 109, 112, 108, 101, 32, 112, 108, 117,
  103, 105, 110, 32, 117, 115, 101, 95, 110, 108, 109, 101, 97, 110, 115, 46,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 123, 34, 67, 73, 109, 103, 32, 110, 108, 109,
  101, 97, 110, 115, 58, 32, 60, 105, 62, 117, 115, 101, 95, 110, 108, 109,
  101, 97, 110, 115, 60, 47, 105, 62, 32, 105, 110, 32, 115, 101, 97, 114,
  99, 104, 32, 80, 65, 84, 72, 34, 125, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  32, 58, 32, 60, 105, 62, 75, 97, 82, 111, 60, 47, 105, 62, 46, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32,
  60, 105, 62, 50, 48, 49, 50, 47, 49, 48, 47, 50, 54, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 107, 97, 114, 111, 95, 99, 105, 109, 103, 95, 110, 108, 109, 101,
  97, 110, 115, 32, 58, 10, 45, 115, 107, 105, 112, 32, 34, 36, 123, 49,
  61, 48, 125, 34, 44, 34, 36, 123, 50, 61, 48, 125, 34, 44, 34, 36,
  123, 51, 61, 48, 125, 34, 44, 34, 36, 123, 52, 61, 49, 125, 34, 44,
  34, 36, 123, 53, 61, 45, 49, 125, 34, 44, 34, 36, 123, 54, 61, 45,
  49, 125, 34, 44, 34, 36, 123, 55, 61, 50, 125, 34, 10, 45, 107, 97,
  114, 111, 95, 110, 108, 109, 101, 97, 110, 115, 32, 45, 110, 103, 44, 36,
  49, 44, 45, 110, 117, 44, 36, 50, 44, 45, 110, 115, 44, 36, 51, 44,
  45, 112, 44, 36, 52, 44, 45, 108, 97, 109, 98, 100, 97, 44, 36, 53,
  44, 45, 115, 105, 103, 109, 97, 44, 36, 54, 44, 45, 97, 108, 112, 104,
  97, 44, 36, 55, 44, 45, 115, 97, 109, 112, 108, 105, 110, 103, 44, 36,
  56, 10, 103, 105, 109, 112, 95, 107, 97, 114, 111, 95, 99, 105, 109, 103,
  95, 110, 108, 109, 101, 97, 110, 115, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 107, 97,
  114, 111, 95, 99, 105, 109, 103, 95, 110, 108, 109, 101, 97, 110, 115, 32,
  36, 123, 49, 45, 56, 125, 34, 44, 36, 57, 10, 35, 64, 103, 105, 109,
  112, 32, 67, 105, 109, 103, 32, 115, 107, 101, 108, 101, 116, 111, 110, 32,
  58, 32, 103, 105, 109, 112, 95, 107, 97, 114, 111, 95, 99, 105, 109, 103,
  95, 115, 107, 101, 108, 44, 32, 103, 105, 109, 112, 95, 107, 97, 114, 111,
  95, 99, 105, 109, 103, 95, 115, 107, 101, 108, 95, 112, 114, 101, 118, 105,
  101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  117, 116, 111, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32,
  98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32, 92, 37, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 105, 122, 101, 32, 109, 101,
  100, 105, 97, 110, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 49,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 118, 101,
  114, 116, 32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108, 115, 101, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104,
  111, 108, 100, 32, 111, 110, 32, 102, 108, 117, 120, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 45, 48, 46, 51, 44, 45, 53, 44, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 77, 101, 100, 105, 97, 108, 32, 99,
  117, 114, 118, 101, 32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108, 115,
  101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 111, 114, 115,
  101, 108, 108, 111, 32, 99, 111, 114, 114, 101, 99, 116, 105, 111, 110, 32,
  61, 98, 111, 111, 108, 40, 102, 97, 108, 115, 101, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 105, 115, 99, 114, 101, 116, 101, 32, 115,
  116, 101, 112, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49, 44, 49, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 49, 44, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 83, 107, 101, 108, 101, 116, 111, 110,
  32, 117, 115, 105, 110, 103, 32, 67, 73, 109, 103, 32, 101, 120, 97, 109,
  112, 108, 101, 32, 112, 108, 117, 103, 105, 110, 32, 117, 115, 101, 95, 115,
  107, 101, 108, 101, 116, 111, 110, 46, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34,
  67, 73, 109, 103, 32, 83, 107, 101, 108, 101, 116, 111, 110, 58, 32, 60,
  105, 62, 117, 115, 101, 95, 115, 107, 101, 108, 101, 116, 111, 110, 60, 47,
  105, 62, 32, 105, 110, 32, 115, 101, 97, 114, 99, 104, 32, 80, 65, 84,
  72, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62,
  75, 97, 82, 111, 60, 47, 105, 62, 46, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49,
  50, 47, 49, 48, 47, 50, 54, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 107, 97, 114, 111,
  95, 99, 105, 109, 103, 95, 115, 107, 101, 108, 32, 58, 10, 45, 105, 102,
  32, 36, 49, 32, 45, 111, 116, 115, 117, 32, 50, 53, 54, 32, 45, 101,
  108, 115, 101, 32, 45, 116, 32, 36, 123, 50, 125, 37, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 107, 97, 114, 111, 95, 115, 107, 101, 108, 101, 116,
  111, 110, 32, 45, 109, 101, 100, 105, 97, 110, 44, 36, 51, 44, 45, 105,
  110, 118, 44, 36, 52, 44, 45, 116, 44, 36, 53, 44, 45, 99, 117, 114,
  118, 101, 44, 36, 54, 44, 45, 99, 111, 114, 114, 44, 36, 55, 44, 45,
  100, 108, 116, 44, 36, 56, 32, 45, 110, 32, 48, 44, 50, 53, 53, 10,
  103, 105, 109, 112, 95, 107, 97, 114, 111, 95, 99, 105, 109, 103, 95, 115,
  107, 101, 108, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 103, 105, 109, 112, 95, 107, 97, 114, 111, 95, 99, 105,
  109, 103, 95, 115, 107, 101, 108, 32, 36, 123, 49, 45, 56, 125, 34, 44,
  36, 57, 10, 35, 64, 103, 105, 109, 112, 32, 77, 109, 32, 100, 105, 102,
  102, 101, 114, 101, 110, 99, 101, 115, 32, 58, 32, 103, 105, 109, 112, 95,
  107, 97, 114, 111, 95, 109, 109, 95, 100, 105, 102, 102, 44, 32, 103, 105,
  109, 112, 95, 107, 97, 114, 111, 95, 109, 109, 95, 100, 105, 102, 102, 95,
  112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 53,
  44, 49, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 105, 122, 101, 50, 32, 61, 32, 105, 110, 116, 40, 55, 44, 49, 44,
  50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 101,
  114, 97, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  50, 44, 34, 69, 114, 111, 115, 105, 111, 110, 34, 44, 34, 68, 105, 108,
  97, 116, 105, 111, 110, 34, 44, 34, 79, 112, 101, 110, 34, 44, 34, 67,
  108, 111, 115, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 104, 97, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49,
  44, 34, 83, 113, 117, 97, 114, 101, 34, 44, 34, 79, 99, 116, 97, 103,
  111, 110, 34, 44, 34, 67, 105, 114, 99, 108, 101, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115,
  41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 65, 108,
  108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44,
  34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117,
  101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105,
  110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110,
  101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105,
  111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121,
  34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44,
  34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 61,
  32, 98, 111, 111, 108, 40, 116, 114, 117, 101, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32,
  116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44,
  34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 66, 101, 115, 116, 32, 119, 105, 116, 104, 32, 111, 100, 100,
  32, 115, 105, 122, 101, 115, 33, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 65, 114, 105, 116, 104, 109, 101, 116, 105, 99, 97, 108, 32, 100, 105,
  102, 102, 101, 114, 101, 110, 99, 101, 32, 111, 102, 32, 97, 32, 109, 111,
  114, 112, 104, 111, 108, 111, 103, 105, 99, 97, 108, 32, 111, 112, 101, 114,
  97, 116, 105, 111, 110, 32, 111, 102, 32, 60, 105, 62, 115, 105, 122, 101,
  60, 47, 105, 62, 32, 97, 110, 100, 32, 60, 105, 62, 115, 105, 122, 101,
  50, 60, 47, 105, 62, 46, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32,
  58, 32, 60, 105, 62, 75, 97, 82, 111, 60, 47, 105, 62, 46, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60,
  105, 62, 50, 48, 49, 50, 47, 49, 48, 47, 50, 54, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112,
  95, 107, 97, 114, 111, 95, 109, 109, 95, 100, 105, 102, 102, 32, 58, 10,
  45, 115, 107, 105, 112, 32, 34, 36, 123, 49, 61, 53, 125, 34, 44, 34,
  36, 123, 50, 61, 55, 125, 34, 44, 34, 36, 123, 51, 61, 50, 125, 34,
  44, 34, 36, 123, 52, 61, 49, 125, 34, 44, 34, 36, 123, 53, 61, 48,
  125, 34, 44, 34, 36, 123, 54, 61, 49, 125, 34, 10, 45, 105, 102, 32,
  123, 36, 50, 60, 61, 36, 49, 125, 32, 115, 50, 61, 123, 36, 49, 43,
  50, 125, 32, 45, 101, 108, 115, 101, 32, 115, 50, 61, 36, 50, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 107, 97, 114, 111, 95, 100, 111, 111, 32,
  36, 49, 44, 36, 123, 115, 50, 125, 44, 36, 51, 44, 36, 52, 44, 36,
  54, 44, 36, 53, 10, 103, 105, 109, 112, 95, 107, 97, 114, 111, 95, 109,
  109, 95, 100, 105, 102, 102, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 107, 97, 114, 111,
  95, 109, 109, 95, 100, 105, 102, 102, 32, 36, 123, 49, 45, 54, 125, 34,
  44, 36, 55, 10, 35, 64, 103, 105, 109, 112, 32, 79, 99, 32, 100, 105,
  102, 102, 101, 114, 101, 110, 99, 101, 115, 32, 58, 32, 103, 105, 109, 112,
  95, 107, 97, 114, 111, 95, 111, 99, 95, 100, 105, 102, 102, 44, 32, 103,
  105, 109, 112, 95, 107, 97, 114, 111, 95, 111, 99, 95, 100, 105, 102, 102,
  95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 53, 44, 50,
  44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104,
  97, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34,
  83, 113, 117, 97, 114, 101, 34, 44, 34, 79, 99, 116, 97, 103, 111, 110,
  34, 44, 34, 67, 105, 114, 99, 108, 101, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 65, 108, 108, 34,
  44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76,
  117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47,
  114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115,
  34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105,
  110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115,
  115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34,
  72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110,
  34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44,
  34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66,
  108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 61, 98, 111,
  111, 108, 40, 116, 114, 117, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 70, 117,
  108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  66, 101, 115, 116, 32, 119, 105, 116, 104, 32, 111, 100, 100, 32, 115, 105,
  122, 101, 115, 33, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 68, 105,
  102, 102, 101, 114, 101, 110, 99, 101, 32, 111, 102, 32, 109, 101, 97, 110,
  32, 111, 102, 32, 109, 111, 114, 112, 104, 111, 108, 111, 103, 105, 99, 97,
  108, 32, 111, 112, 101, 110, 105, 110, 103, 32, 97, 110, 100, 32, 99, 108,
  111, 115, 105, 110, 103, 32, 119, 105, 116, 104, 32, 111, 114, 105, 103, 105,
  110, 97, 108, 46, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32,
  60, 105, 62, 75, 97, 82, 111, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48,
  55, 47, 48, 52, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 107, 97, 114, 111, 95, 111, 99,
  95, 100, 105, 102, 102, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 107, 97, 114, 111, 95, 100,
  111, 99, 32, 36, 49, 44, 36, 50, 44, 48, 34, 44, 36, 51, 44, 36,
  52, 10, 103, 105, 109, 112, 95, 107, 97, 114, 111, 95, 111, 99, 95, 100,
  105, 102, 102, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 103, 105, 109, 112, 95, 107, 97, 114, 111, 95, 111, 99,
  95, 100, 105, 102, 102, 32, 36, 123, 49, 45, 52, 125, 34, 44, 36, 53,
  10, 35, 64, 103, 105, 109, 112, 32, 80, 105, 110, 107, 32, 111, 112, 101,
  114, 97, 116, 111, 114, 32, 58, 32, 103, 105, 109, 112, 95, 112, 105, 110,
  107, 44, 32, 103, 105, 109, 112, 95, 112, 105, 110, 107, 95, 112, 114, 101,
  118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 80, 105, 110, 107, 32, 111, 112, 101, 114, 97, 116, 111, 114, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 119, 115, 104, 101, 100, 116, 111,
  112, 111, 34, 44, 34, 119, 115, 104, 101, 100, 116, 111, 112, 111, 32, 105,
  110, 118, 34, 44, 34, 109, 105, 110, 105, 109, 97, 34, 44, 34, 109, 97,
  120, 105, 109, 97, 34, 44, 34, 104, 101, 105, 103, 104, 116, 109, 105, 110,
  105, 109, 97, 34, 44, 34, 104, 101, 105, 103, 104, 116, 109, 97, 120, 105,
  109, 97, 34, 44, 34, 103, 114, 97, 121, 115, 107, 101, 108, 34, 44, 34,
  104, 116, 107, 101, 114, 110, 34, 44, 34, 104, 116, 107, 101, 114, 110, 117,
  34, 44, 34, 108, 118, 107, 101, 114, 110, 34, 44, 34, 108, 118, 107, 101,
  114, 110, 117, 34, 44, 34, 97, 115, 102, 34, 44, 34, 97, 115, 102, 108,
  105, 110, 34, 44, 34, 97, 115, 102, 114, 34, 44, 34, 97, 115, 102, 116,
  34, 44, 34, 97, 115, 102, 116, 109, 101, 100, 34, 44, 34, 97, 115, 102,
  116, 110, 100, 103, 34, 44, 34, 100, 105, 108, 97, 116, 98, 97, 108, 108,
  110, 117, 109, 34, 44, 34, 101, 114, 111, 115, 98, 97, 108, 108, 110, 117,
  109, 34, 44, 34, 108, 105, 110, 116, 111, 112, 104, 97, 116, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 110, 101, 99, 116,
  105, 118, 105, 116, 121, 32, 47, 32, 100, 105, 114, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 70, 111, 117, 114, 47, 120, 34, 44, 34, 69,
  105, 103, 104, 116, 47, 121, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 72, 101, 105, 103, 104, 116, 47, 114, 101, 112, 32,
  61, 32, 105, 110, 116, 40, 53, 44, 48, 44, 50, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115,
  41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 65, 108,
  108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44,
  34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117,
  101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105,
  110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110,
  101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105,
  111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121,
  34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44,
  34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107,
  40, 34, 104, 116, 116, 112, 58, 47, 47, 112, 105, 110, 107, 104, 113, 46,
  99, 111, 109, 47, 34, 41, 10, 103, 105, 109, 112, 95, 112, 105, 110, 107,
  32, 58, 10, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 49, 125,
  44, 36, 123, 50, 61, 48, 125, 44, 36, 123, 51, 61, 48, 125, 44, 36,
  123, 52, 61, 53, 125, 44, 36, 123, 53, 61, 48, 125, 10, 45, 105, 102,
  32, 32, 32, 123, 36, 49, 61, 61, 48, 125, 32, 32, 45, 97, 112, 112,
  108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 98, 32,
  36, 51, 32, 45, 112, 105, 110, 107, 32, 104, 101, 105, 103, 104, 116, 109,
  105, 110, 105, 109, 97, 44, 123, 40, 36, 50, 43, 49, 41, 42, 52, 125,
  44, 36, 52, 32, 45, 112, 105, 110, 107, 32, 119, 115, 104, 101, 100, 116,
  111, 112, 111, 44, 123, 40, 36, 50, 43, 49, 41, 42, 52, 125, 34, 44,
  36, 53, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61,
  49, 125, 32, 32, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 34, 45, 98, 32, 36, 51, 32, 45, 112, 105, 110, 107,
  32, 104, 101, 105, 103, 104, 116, 109, 97, 120, 105, 109, 97, 44, 123, 40,
  36, 50, 43, 49, 41, 42, 52, 125, 44, 36, 52, 32, 45, 112, 105, 110,
  107, 32, 119, 115, 104, 101, 100, 116, 111, 112, 111, 44, 123, 40, 36, 50,
  43, 49, 41, 42, 52, 125, 44, 105, 34, 44, 36, 53, 44, 48, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 50, 125, 32, 32, 45, 97,
  112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45,
  98, 32, 36, 51, 32, 45, 112, 105, 110, 107, 32, 109, 105, 110, 105, 109,
  97, 44, 123, 40, 36, 50, 43, 49, 41, 42, 52, 125, 34, 44, 36, 53,
  44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 51, 125,
  32, 32, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 34, 45, 98, 32, 36, 51, 32, 45, 112, 105, 110, 107, 32, 109,
  97, 120, 105, 109, 97, 44, 123, 40, 36, 50, 43, 49, 41, 42, 52, 125,
  34, 44, 36, 53, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49,
  61, 61, 52, 125, 32, 32, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 34, 45, 98, 32, 36, 51, 32, 45, 112, 105,
  110, 107, 32, 104, 101, 105, 103, 104, 116, 109, 105, 110, 105, 109, 97, 44,
  123, 40, 36, 50, 43, 49, 41, 42, 52, 125, 44, 36, 52, 34, 44, 36,
  53, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 53,
  125, 32, 32, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101,
  108, 115, 32, 34, 45, 98, 32, 36, 51, 32, 45, 112, 105, 110, 107, 32,
  104, 101, 105, 103, 104, 116, 109, 97, 120, 105, 109, 97, 44, 123, 40, 36,
  50, 43, 49, 41, 42, 52, 125, 44, 36, 52, 34, 44, 36, 53, 44, 48,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 54, 125, 32, 32,
  45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  34, 45, 98, 32, 36, 51, 32, 45, 112, 105, 110, 107, 32, 103, 114, 97,
  121, 115, 107, 101, 108, 44, 110, 117, 108, 108, 44, 52, 44, 36, 52, 34,
  44, 36, 53, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61,
  61, 55, 125, 32, 32, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 32, 34, 45, 98, 32, 36, 51, 32, 45, 112, 105, 110,
  107, 32, 104, 116, 107, 101, 114, 110, 44, 110, 117, 108, 108, 44, 123, 40,
  36, 50, 43, 49, 41, 42, 52, 125, 34, 44, 36, 53, 44, 48, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 56, 125, 32, 32, 45, 97,
  112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45,
  98, 32, 36, 51, 32, 45, 112, 105, 110, 107, 32, 104, 116, 107, 101, 114,
  110, 117, 44, 110, 117, 108, 108, 44, 123, 40, 36, 50, 43, 49, 41, 42,
  52, 125, 34, 44, 36, 53, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 61, 61, 57, 125, 32, 32, 45, 97, 112, 112, 108, 121, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 98, 32, 36, 51, 32, 45,
  112, 105, 110, 107, 32, 108, 118, 107, 101, 114, 110, 44, 110, 117, 108, 108,
  44, 123, 40, 36, 50, 43, 49, 41, 42, 52, 125, 34, 44, 36, 53, 44,
  48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 48, 125,
  32, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 34, 45, 98, 32, 36, 51, 32, 45, 112, 105, 110, 107, 32, 108, 118,
  107, 101, 114, 110, 117, 44, 110, 117, 108, 108, 44, 123, 40, 36, 50, 43,
  49, 41, 42, 52, 125, 34, 44, 36, 53, 44, 48, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 61, 61, 49, 49, 125, 32, 45, 97, 112, 112, 108,
  121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 98, 32, 36,
  51, 32, 45, 112, 105, 110, 107, 32, 97, 115, 102, 44, 36, 52, 34, 44,
  36, 53, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61,
  49, 50, 125, 10, 45, 105, 102, 32, 123, 36, 50, 61, 61, 48, 125, 32,
  45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  34, 45, 98, 32, 36, 51, 32, 91, 48, 93, 120, 50, 32, 45, 97, 32,
  122, 32, 45, 112, 105, 110, 107, 32, 97, 115, 102, 108, 105, 110, 44, 120,
  44, 36, 52, 32, 45, 115, 32, 122, 32, 45, 107, 91, 45, 49, 93, 34,
  44, 36, 53, 44, 48, 10, 45, 101, 108, 115, 101, 32, 45, 97, 112, 112,
  108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 98, 32,
  36, 51, 32, 91, 48, 93, 120, 50, 32, 45, 97, 32, 122, 32, 45, 112,
  105, 110, 107, 32, 97, 115, 102, 108, 105, 110, 44, 121, 44, 36, 52, 32,
  45, 115, 32, 122, 32, 45, 107, 91, 45, 49, 93, 34, 44, 36, 53, 44,
  48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 61, 61, 49, 51, 125, 32, 45, 97, 112, 112, 108, 121, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 98, 32, 36, 51, 32, 45,
  112, 105, 110, 107, 32, 97, 115, 102, 114, 44, 36, 52, 34, 44, 36, 53,
  44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 52,
  125, 32, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 34, 45, 98, 32, 36, 51, 32, 45, 112, 105, 110, 107, 32, 97,
  115, 102, 116, 44, 110, 117, 108, 108, 44, 110, 117, 108, 108, 44, 123, 40,
  36, 50, 43, 49, 41, 42, 52, 125, 44, 36, 52, 34, 44, 36, 53, 44,
  48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 53, 125,
  32, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 34, 45, 98, 32, 36, 51, 32, 45, 112, 105, 110, 107, 32, 97, 115,
  102, 116, 109, 101, 100, 44, 123, 40, 36, 50, 43, 49, 41, 42, 52, 125,
  44, 36, 52, 34, 44, 36, 53, 44, 48, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 49, 61, 61, 49, 54, 125, 32, 45, 97, 112, 112, 108, 121, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 98, 32, 36, 51, 32,
  45, 112, 105, 110, 107, 32, 97, 115, 102, 116, 110, 100, 103, 44, 110, 117,
  108, 108, 44, 110, 117, 108, 108, 44, 123, 40, 36, 50, 43, 49, 41, 42,
  52, 125, 44, 36, 52, 34, 44, 36, 53, 44, 48, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 61, 61, 49, 55, 125, 32, 45, 97, 112, 112, 108,
  121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 98, 32, 36,
  51, 32, 45, 112, 105, 110, 107, 32, 100, 105, 108, 97, 116, 98, 97, 108,
  108, 110, 117, 109, 44, 36, 52, 34, 44, 36, 53, 44, 48, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 56, 125, 32, 45, 97, 112,
  112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 98,
  32, 36, 51, 32, 45, 112, 105, 110, 107, 32, 101, 114, 111, 115, 98, 97,
  108, 108, 110, 117, 109, 44, 36, 52, 34, 44, 36, 53, 44, 48, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 57, 125, 32, 45, 97,
  112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45,
  98, 32, 36, 51, 32, 45, 112, 105, 110, 107, 32, 108, 105, 110, 116, 111,
  112, 104, 97, 116, 44, 36, 52, 34, 44, 36, 53, 44, 48, 10, 45, 101,
  108, 115, 101, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 45, 97, 112,
  112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 98,
  32, 36, 51, 32, 45, 112, 105, 110, 107, 32, 104, 101, 105, 103, 104, 116,
  109, 105, 110, 105, 109, 97, 44, 123, 40, 36, 50, 43, 49, 41, 42, 52,
  125, 44, 36, 52, 32, 45, 112, 105, 110, 107, 32, 119, 115, 104, 101, 100,
  116, 111, 112, 111, 44, 123, 40, 36, 50, 43, 49, 41, 42, 52, 125, 34,
  44, 36, 53, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109,
  112, 95, 112, 105, 110, 107, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 112, 105, 110, 107,
  32, 36, 123, 49, 45, 53, 125, 34, 44, 36, 54, 10, 35, 64, 103, 105,
  109, 112, 32, 80, 105, 110, 107, 32, 111, 112, 101, 114, 97, 116, 111, 114,
  32, 98, 105, 110, 97, 114, 121, 32, 58, 32, 103, 105, 109, 112, 95, 107,
  97, 114, 111, 95, 112, 105, 110, 107, 95, 98, 105, 110, 44, 32, 103, 105,
  109, 112, 95, 107, 97, 114, 111, 95, 112, 105, 110, 107, 95, 98, 105, 110,
  95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 117, 116, 111, 45, 116, 104, 114, 101, 115, 104,
  111, 108, 100, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100,
  32, 92, 37, 32, 61, 32, 105, 110, 116, 40, 53, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 105, 110,
  107, 32, 111, 112, 101, 114, 97, 116, 111, 114, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 51, 44, 34, 115, 107, 101, 108, 112, 97, 114, 34, 44,
  34, 115, 107, 101, 108, 101, 110, 100, 34, 44, 34, 115, 107, 101, 108, 99,
  117, 114, 118, 34, 44, 34, 115, 107, 101, 108, 101, 116, 111, 110, 34, 44,
  34, 98, 97, 114, 121, 99, 101, 110, 116, 114, 101, 34, 44, 34, 98, 111,
  114, 100, 101, 114, 34, 44, 34, 99, 108, 111, 115, 101, 98, 97, 108, 108,
  34, 44, 34, 111, 112, 101, 110, 98, 97, 108, 108, 34, 44, 34, 99, 111,
  110, 118, 101, 120, 104, 117, 108, 108, 34, 44, 34, 100, 105, 115, 116, 34,
  44, 34, 100, 105, 115, 116, 99, 34, 44, 34, 108, 97, 98, 101, 108, 32,
  112, 108, 97, 34, 44, 34, 76, 97, 110, 116, 117, 101, 106, 111, 117, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 110,
  101, 99, 116, 105, 118, 105, 116, 121, 32, 47, 32, 100, 105, 114, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 111, 117, 114, 47, 120, 34,
  44, 34, 69, 105, 103, 104, 116, 47, 121, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 72, 101, 105, 103, 104, 116, 47, 114, 101, 112, 32,
  61, 32, 105, 110, 116, 40, 53, 44, 45, 49, 44, 50, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 108, 103, 111, 114, 105, 116, 104,
  109, 32, 61, 32, 105, 110, 116, 40, 52, 44, 48, 44, 50, 57, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108,
  40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34,
  65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66,
  34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66,
  108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104,
  116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97,
  116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75,
  101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110,
  34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 66, 105, 110, 97, 114, 121, 32, 111, 112, 101,
  114, 97, 116, 105, 111, 110, 115, 32, 119, 105, 116, 104, 32, 80, 105, 110,
  107, 32, 101, 120, 116, 101, 114, 110, 97, 108, 115, 46, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 123, 34, 68, 105, 118, 101, 114, 115, 101, 32, 80, 105, 110, 107,
  32, 101, 120, 101, 99, 117, 116, 97, 98, 108, 101, 115, 32, 105, 110, 32,
  115, 101, 97, 114, 99, 104, 32, 80, 65, 84, 72, 34, 125, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 75, 97, 82, 111, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105,
  62, 50, 48, 49, 52, 47, 48, 50, 47, 48, 53, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40,
  34, 104, 116, 116, 112, 58, 47, 47, 112, 105, 110, 107, 104, 113, 46, 99,
  111, 109, 47, 34, 41, 10, 103, 105, 109, 112, 95, 107, 97, 114, 111, 95,
  112, 105, 110, 107, 95, 98, 105, 110, 32, 58, 10, 45, 105, 102, 32, 32,
  32, 123, 36, 51, 61, 61, 48, 125, 32, 32, 45, 97, 112, 112, 108, 121,
  95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 105, 102, 32, 36,
  49, 32, 45, 111, 116, 115, 117, 32, 50, 53, 54, 32, 45, 101, 108, 115,
  101, 32, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 36, 123, 50,
  125, 37, 32, 45, 101, 110, 100, 105, 102, 32, 45, 112, 105, 110, 107, 95,
  115, 107, 101, 108, 112, 97, 114, 32, 36, 54, 44, 36, 53, 32, 45, 110,
  32, 48, 44, 50, 53, 53, 34, 44, 36, 55, 44, 48, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 51, 61, 61, 49, 125, 32, 32, 45, 97, 112, 112,
  108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 105, 102,
  32, 36, 49, 32, 45, 111, 116, 115, 117, 32, 50, 53, 54, 32, 45, 101,
  108, 115, 101, 32, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 36,
  123, 50, 125, 37, 32, 45, 101, 110, 100, 105, 102, 32, 45, 112, 105, 110,
  107, 95, 115, 107, 101, 108, 101, 110, 100, 32, 123, 40, 36, 52, 43, 49,
  41, 42, 52, 125, 44, 36, 53, 32, 45, 110, 32, 48, 44, 50, 53, 53,
  34, 44, 36, 55, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 51,
  61, 61, 50, 125, 32, 32, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 34, 45, 105, 102, 32, 36, 49, 32, 45, 111,
  116, 115, 117, 32, 50, 53, 54, 32, 45, 101, 108, 115, 101, 32, 45, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 32, 36, 123, 50, 125, 37, 32, 45,
  101, 110, 100, 105, 102, 32, 45, 112, 105, 110, 107, 95, 115, 107, 101, 108,
  99, 117, 114, 118, 32, 36, 54, 44, 123, 40, 36, 52, 43, 49, 41, 42,
  52, 125, 32, 45, 110, 32, 48, 44, 50, 53, 53, 34, 44, 36, 55, 44,
  48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 51, 61, 61, 51, 125, 32,
  32, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 34, 45, 105, 102, 32, 36, 49, 32, 45, 111, 116, 115, 117, 32, 50,
  53, 54, 32, 45, 101, 108, 115, 101, 32, 45, 116, 104, 114, 101, 115, 104,
  111, 108, 100, 32, 36, 123, 50, 125, 37, 32, 45, 101, 110, 100, 105, 102,
  32, 45, 112, 105, 110, 107, 95, 115, 107, 101, 108, 101, 116, 111, 110, 32,
  36, 54, 44, 123, 40, 36, 52, 43, 49, 41, 42, 52, 125, 32, 45, 110,
  32, 48, 44, 50, 53, 53, 34, 44, 36, 55, 44, 48, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 51, 61, 61, 52, 125, 32, 32, 45, 97, 112, 112,
  108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 105, 102,
  32, 36, 49, 32, 45, 111, 116, 115, 117, 32, 50, 53, 54, 32, 45, 101,
  108, 115, 101, 32, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 36,
  123, 50, 125, 37, 32, 45, 101, 110, 100, 105, 102, 32, 45, 112, 105, 110,
  107, 32, 98, 97, 114, 121, 99, 101, 110, 116, 114, 101, 44, 123, 40, 36,
  52, 43, 49, 41, 42, 52, 125, 32, 45, 110, 32, 48, 44, 50, 53, 53,
  34, 44, 36, 55, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 51,
  61, 61, 53, 125, 32, 32, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97,
  110, 110, 101, 108, 115, 32, 34, 45, 105, 102, 32, 36, 49, 32, 45, 111,
  116, 115, 117, 32, 50, 53, 54, 32, 45, 101, 108, 115, 101, 32, 45, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 32, 36, 123, 50, 125, 37, 32, 45,
  101, 110, 100, 105, 102, 32, 45, 112, 105, 110, 107, 32, 98, 111, 114, 100,
  101, 114, 44, 123, 40, 36, 52, 43, 49, 41, 42, 52, 125, 32, 45, 110,
  32, 48, 44, 50, 53, 53, 34, 44, 36, 55, 44, 48, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 51, 61, 61, 54, 125, 32, 32, 45, 97, 112, 112,
  108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34, 45, 105, 102,
  32, 36, 49, 32, 45, 111, 116, 115, 117, 32, 50, 53, 54, 32, 45, 101,
  108, 115, 101, 32, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 36,
  123, 50, 125, 37, 32, 45, 101, 110, 100, 105, 102, 32, 45, 112, 105, 110,
  107, 32, 99, 108, 111, 115, 101, 98, 97, 108, 108, 44, 36, 53, 44, 36,
  54, 32, 45, 110, 32, 48, 44, 50, 53, 53, 34, 44, 36, 55, 44, 48,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 51, 61, 61, 55, 125, 32, 32,
  45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  34, 45, 105, 102, 32, 36, 49, 32, 45, 111, 116, 115, 117, 32, 50, 53,
  54, 32, 45, 101, 108, 115, 101, 32, 45, 116, 104, 114, 101, 115, 104, 111,
  108, 100, 32, 36, 123, 50, 125, 37, 32, 45, 101, 110, 100, 105, 102, 32,
  45, 112, 105, 110, 107, 32, 111, 112, 101, 110, 98, 97, 108, 108, 44, 36,
  53, 44, 36, 54, 32, 45, 110, 32, 48, 44, 50, 53, 53, 34, 44, 36,
  55, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 51, 61, 61, 56,
  125, 32, 32, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101,
  108, 115, 32, 34, 45, 105, 102, 32, 36, 49, 32, 45, 111, 116, 115, 117,
  32, 50, 53, 54, 32, 45, 101, 108, 115, 101, 32, 45, 116, 104, 114, 101,
  115, 104, 111, 108, 100, 32, 36, 123, 50, 125, 37, 32, 45, 101, 110, 100,
  105, 102, 32, 45, 112, 105, 110, 107, 32, 99, 111, 110, 118, 101, 120, 104,
  117, 108, 108, 44, 51, 32, 45, 110, 32, 48, 44, 50, 53, 53, 34, 44,
  36, 55, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 51, 61, 61,
  57, 125, 32, 32, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 34, 45, 105, 102, 32, 36, 49, 32, 45, 111, 116, 115,
  117, 32, 50, 53, 54, 32, 45, 101, 108, 115, 101, 32, 45, 116, 104, 114,
  101, 115, 104, 111, 108, 100, 32, 36, 123, 50, 125, 37, 32, 45, 101, 110,
  100, 105, 102, 32, 45, 112, 105, 110, 107, 32, 100, 105, 115, 116, 44, 36,
  54, 32, 45, 110, 32, 48, 44, 50, 53, 53, 34, 44, 36, 55, 44, 48,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 51, 61, 61, 49, 48, 125, 32,
  32, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  32, 34, 45, 105, 102, 32, 36, 49, 32, 45, 111, 116, 115, 117, 32, 50,
  53, 54, 32, 45, 101, 108, 115, 101, 32, 45, 116, 104, 114, 101, 115, 104,
  111, 108, 100, 32, 36, 123, 50, 125, 37, 32, 45, 101, 110, 100, 105, 102,
  32, 45, 112, 105, 110, 107, 32, 100, 105, 115, 116, 99, 44, 36, 54, 32,
  45, 110, 32, 48, 44, 50, 53, 53, 34, 44, 36, 55, 44, 48, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 51, 61, 61, 49, 49, 125, 32, 32, 45,
  97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 34,
  45, 105, 102, 32, 36, 49, 32, 45, 111, 116, 115, 117, 32, 50, 53, 54,
  32, 45, 101, 108, 115, 101, 32, 45, 116, 104, 114, 101, 115, 104, 111, 108,
  100, 32, 36, 123, 50, 125, 37, 32, 45, 101, 110, 100, 105, 102, 32, 45,
  112, 105, 110, 107, 32, 108, 97, 98, 101, 108, 44, 123, 40, 36, 52, 43,
  49, 41, 42, 52, 125, 44, 112, 108, 97, 34, 44, 36, 55, 44, 48, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 51, 61, 61, 49, 50, 125, 32, 32,
  45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  34, 45, 105, 102, 32, 36, 49, 32, 45, 111, 116, 115, 117, 32, 50, 53,
  54, 32, 45, 101, 108, 115, 101, 32, 45, 116, 104, 114, 101, 115, 104, 111,
  108, 100, 32, 36, 123, 50, 125, 37, 32, 45, 101, 110, 100, 105, 102, 32,
  45, 112, 105, 110, 107, 32, 108, 97, 110, 116, 117, 101, 106, 111, 117, 108,
  44, 36, 54, 32, 45, 110, 32, 48, 44, 50, 53, 53, 34, 44, 36, 55,
  44, 48, 10, 45, 101, 108, 115, 101, 10, 45, 101, 110, 100, 105, 102, 10,
  103, 105, 109, 112, 95, 107, 97, 114, 111, 95, 112, 105, 110, 107, 95, 98,
  105, 110, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 107, 97, 114, 111, 95, 112, 105, 110,
  107, 95, 98, 105, 110, 32, 36, 123, 49, 45, 55, 125, 34, 44, 36, 56,
  10, 35, 64, 103, 105, 109, 112, 32, 80, 105, 110, 107, 32, 116, 101, 115,
  116, 32, 111, 112, 101, 114, 97, 116, 111, 114, 32, 98, 105, 97, 110, 99,
  97, 32, 58, 32, 103, 105, 109, 112, 95, 107, 97, 114, 111, 95, 112, 105,
  110, 107, 95, 98, 105, 97, 110, 99, 97, 44, 32, 103, 105, 109, 112, 95,
  107, 97, 114, 111, 95, 112, 105, 110, 107, 95, 98, 105, 97, 110, 99, 97,
  95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 115, 102, 32, 115, 109, 111, 111, 116, 104, 32,
  115, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 53, 44, 49, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101,
  115, 104, 111, 108, 100, 32, 92, 37, 32, 61, 32, 105, 110, 116, 40, 54,
  48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 87, 97, 116, 101, 114, 115, 104, 101, 100, 32, 104, 101, 105, 103,
  104, 116, 32, 109, 105, 110, 32, 61, 32, 105, 110, 116, 40, 53, 44, 48,
  44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112,
  101, 110, 105, 110, 103, 32, 114, 97, 100, 105, 117, 115, 32, 61, 32, 105,
  110, 116, 40, 49, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 73, 110, 118, 101, 114, 116, 32, 61, 32, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 85, 115,
  101, 32, 103, 32, 105, 110, 115, 116, 101, 97, 100, 32, 111, 102, 32, 98,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117,
  108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 80,
  105, 110, 107, 32, 116, 101, 115, 116, 32, 111, 112, 101, 114, 97, 116, 111,
  114, 32, 66, 105, 97, 110, 99, 97, 32, 102, 111, 114, 32, 82, 71, 66,
  32, 105, 109, 97, 103, 101, 59, 32, 111, 110, 108, 121, 32, 66, 32, 117,
  115, 101, 100, 46, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 80, 105, 110, 107,
  32, 101, 120, 101, 99, 117, 116, 97, 98, 108, 101, 115, 32, 105, 110, 32,
  115, 101, 97, 114, 99, 104, 32, 80, 65, 84, 72, 32, 111, 114, 32, 67,
  58, 92, 92, 80, 105, 110, 107, 92, 92, 98, 105, 110, 92, 92, 32, 102,
  111, 114, 32, 87, 105, 110, 100, 111, 119, 115, 34, 125, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 32, 58, 32, 60, 105, 62, 75, 97, 82, 111, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62,
  50, 48, 49, 50, 47, 49, 48, 47, 50, 54, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34,
  104, 116, 116, 112, 58, 47, 47, 112, 105, 110, 107, 104, 113, 46, 99, 111,
  109, 47, 34, 41, 10, 103, 105, 109, 112, 95, 107, 97, 114, 111, 95, 112,
  105, 110, 107, 95, 98, 105, 97, 110, 99, 97, 32, 58, 10, 45, 115, 107,
  105, 112, 32, 34, 36, 123, 49, 61, 53, 125, 34, 44, 34, 36, 123, 50,
  61, 54, 48, 125, 34, 44, 34, 36, 123, 51, 61, 53, 125, 34, 44, 34,
  36, 123, 52, 61, 49, 125, 34, 44, 34, 36, 123, 53, 61, 48, 125, 34,
  44, 34, 36, 123, 54, 61, 48, 125, 34, 10, 45, 105, 102, 32, 36, 53,
  32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 33, 64, 123, 45, 105, 115, 95, 119, 105,
  110, 100, 111, 119, 115, 125, 125, 32, 101, 120, 101, 61, 34, 108, 97, 98,
  101, 108, 34, 32, 45, 101, 108, 115, 101, 32, 101, 120, 101, 61, 34, 67,
  58, 92, 80, 105, 110, 107, 92, 98, 105, 110, 92, 108, 97, 98, 101, 108,
  34, 32, 45, 101, 110, 100, 105, 102, 10, 45, 115, 32, 99, 32, 45, 105,
  102, 32, 36, 54, 32, 45, 107, 91, 45, 50, 93, 32, 45, 101, 108, 115,
  101, 32, 45, 107, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 45, 112, 105, 110, 107, 32, 97, 115, 102, 44, 36, 49, 32, 45, 45,
  45, 32, 45, 107, 91, 45, 49, 44, 45, 51, 93, 32, 45, 116, 91, 45,
  49, 93, 32, 36, 123, 50, 125, 37, 10, 45, 45, 112, 105, 110, 107, 95,
  119, 115, 104, 101, 100, 91, 45, 50, 93, 32, 44, 49, 44, 36, 51, 10,
  45, 112, 105, 110, 107, 91, 45, 49, 93, 32, 36, 101, 120, 101, 44, 52,
  44, 109, 97, 120, 32, 45, 116, 91, 45, 49, 93, 32, 49, 10, 45, 101,
  114, 111, 100, 101, 95, 111, 99, 116, 91, 45, 50, 93, 32, 123, 36, 52,
  42, 50, 43, 49, 125, 32, 45, 100, 105, 108, 97, 116, 101, 95, 111, 99,
  116, 91, 45, 50, 93, 32, 123, 36, 52, 42, 50, 43, 49, 125, 10, 45,
  45, 42, 91, 45, 49, 44, 45, 50, 93, 32, 45, 110, 101, 103, 97, 116,
  105, 118, 101, 91, 45, 50, 93, 32, 45, 110, 91, 45, 49, 44, 45, 50,
  93, 32, 48, 44, 50, 53, 53, 32, 45, 97, 91, 45, 49, 44, 45, 50,
  44, 45, 52, 93, 32, 99, 32, 45, 107, 91, 48, 93, 10, 103, 105, 109,
  112, 95, 107, 97, 114, 111, 95, 112, 105, 110, 107, 95, 98, 105, 97, 110,
  99, 97, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 107, 97, 114, 111, 95, 112, 105, 110,
  107, 95, 98, 105, 97, 110, 99, 97, 32, 36, 123, 49, 45, 54, 125, 34,
  44, 36, 55, 10, 35, 64, 103, 105, 109, 112, 32, 95, 10, 35, 64, 103,
  105, 109, 112, 32, 60, 105, 62, 76, 121, 108, 101, 106, 107, 60, 47, 105,
  62, 10, 35, 64, 103, 105, 109, 112, 32, 66, 108, 101, 110, 100, 32, 91,
  115, 104, 97, 112, 101, 32, 97, 118, 101, 114, 97, 103, 101, 93, 32, 58,
  32, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 95, 115, 104, 97, 112,
  101, 97, 118, 101, 114, 97, 103, 101, 44, 32, 103, 105, 109, 112, 95, 98,
  108, 101, 110, 100, 95, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97, 103,
  101, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114,
  101, 115, 101, 114, 118, 101, 32, 115, 104, 97, 100, 105, 110, 103, 32, 61,
  32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 121, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121, 101, 114, 115, 32,
  61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34,
  60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 78, 111, 116, 101, 58, 60,
  47, 98, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 105,
  115, 32, 102, 105, 108, 116, 101, 114, 32, 110, 101, 101, 100, 115, 32, 116,
  119, 111, 32, 108, 97, 121, 101, 114, 115, 32, 116, 111, 32, 119, 111, 114,
  107, 32, 112, 114, 111, 112, 101, 114, 108, 121, 46, 32, 83, 101, 116, 32,
  116, 104, 101, 32, 60, 105, 62, 73, 110, 112, 117, 116, 32, 108, 97, 121,
  101, 114, 115, 60, 47, 105, 62, 32, 111, 112, 116, 105, 111, 110, 32, 116,
  111, 32, 104, 97, 110, 100, 108, 101, 32, 109, 117, 108, 116, 105, 112, 108,
  101, 32, 105, 110, 112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 46, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68,
  97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38,
  35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60,
  105, 62, 50, 48, 49, 49, 47, 49, 48, 47, 49, 57, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112,
  95, 98, 108, 101, 110, 100, 95, 115, 104, 97, 112, 101, 97, 118, 101, 114,
  97, 103, 101, 32, 58, 10, 45, 105, 102, 32, 36, 123, 51, 61, 48, 125,
  32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108,
  97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111,
  95, 114, 103, 98, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110,
  116, 40, 64, 35, 47, 50, 41, 125, 10, 45, 114, 118, 91, 45, 50, 44,
  45, 49, 93, 10, 45, 105, 102, 32, 36, 49, 32, 45, 105, 91, 48, 93,
  32, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 98, 108,
  101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 115, 104, 97, 112, 101,
  97, 118, 101, 114, 97, 103, 101, 48, 10, 45, 105, 102, 32, 36, 49, 32,
  45, 42, 91, 48, 44, 45, 49, 93, 32, 45, 47, 91, 48, 93, 32, 50,
  53, 53, 32, 45, 109, 118, 91, 48, 93, 32, 64, 35, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 36, 50, 32, 45, 116, 111, 95, 114,
  103, 98, 97, 91, 45, 49, 93, 32, 45, 114, 101, 112, 108, 97, 99, 101,
  95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 48,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 109, 118, 91, 45, 49, 93, 32,
  48, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 76,
  121, 108, 101, 106, 107, 39, 115, 32, 115, 116, 101, 110, 99, 105, 108, 32,
  58, 32, 103, 105, 109, 112, 95, 108, 121, 108, 101, 106, 107, 95, 115, 116,
  101, 110, 99, 105, 108, 44, 32, 103, 105, 109, 112, 95, 108, 121, 108, 101,
  106, 107, 95, 115, 116, 101, 110, 99, 105, 108, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  32, 61, 32, 105, 110, 116, 40, 53, 44, 49, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 114, 112, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 100,
  105, 117, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97,
  110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82,
  71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105,
  110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32,
  99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105,
  103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117,
  114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44,
  34, 75, 101, 121, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34, 99,
  104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44,
  34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34,
  65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 115, 58,
  32, 60, 105, 62, 76, 121, 108, 101, 32, 75, 114, 111, 108, 108, 44, 32,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 108, 121, 108, 101, 106, 107, 95, 115, 116, 101, 110, 99, 105, 108,
  32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101,
  108, 115, 32, 34, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 32, 45,
  98, 32, 36, 51, 32, 45, 117, 110, 115, 104, 97, 114, 112, 32, 36, 51,
  44, 36, 50, 32, 45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 109, 118,
  91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 34, 44, 36, 52,
  44, 48, 10, 35, 64, 103, 105, 109, 112, 32, 95, 10, 35, 64, 103, 105,
  109, 112, 32, 60, 105, 62, 78, 97, 103, 103, 111, 98, 111, 116, 60, 47,
  105, 62, 10, 35, 64, 103, 105, 109, 112, 32, 65, 98, 115, 116, 114, 97,
  99, 116, 32, 102, 108, 111, 111, 100, 32, 58, 32, 103, 105, 109, 112, 95,
  65, 98, 115, 116, 114, 97, 99, 116, 70, 108, 111, 111, 100, 44, 32, 103,
  105, 109, 112, 95, 65, 98, 115, 116, 114, 97, 99, 116, 70, 108, 111, 111,
  100, 95, 80, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 87, 97,
  114, 110, 105, 110, 103, 58, 32, 82, 101, 97, 108, 108, 121, 32, 114, 101,
  97, 108, 108, 121, 32, 115, 108, 111, 119, 32, 102, 105, 108, 116, 101, 114,
  32, 101, 115, 112, 101, 99, 105, 97, 108, 108, 121, 32, 119, 105, 116, 104,
  32, 67, 117, 98, 105, 115, 109, 32, 101, 110, 97, 98, 108, 101, 100, 46,
  32, 85, 115, 101, 32, 97, 32, 109, 97, 120, 105, 109, 117, 109, 32, 111,
  102, 32, 49, 32, 109, 101, 103, 97, 112, 105, 120, 101, 108, 32, 105, 109,
  97, 103, 101, 46, 32, 82, 97, 110, 100, 111, 109, 32, 119, 97, 108, 107,
  32, 97, 108, 103, 111, 114, 105, 104, 109, 32, 105, 115, 32, 117, 115, 101,
  100, 32, 116, 111, 32, 115, 101, 108, 101, 99, 116, 32, 110, 101, 119, 32,
  97, 114, 101, 97, 115, 32, 116, 111, 32, 102, 108, 111, 111, 100, 46, 32,
  73, 102, 32, 67, 117, 98, 105, 115, 109, 32, 105, 115, 32, 101, 110, 97,
  98, 108, 101, 100, 32, 116, 104, 101, 32, 102, 105, 108, 116, 101, 114, 32,
  104, 97, 115, 32, 116, 111, 32, 114, 117, 110, 32, 99, 117, 98, 105, 109,
  115, 32, 102, 111, 114, 32, 101, 118, 101, 114, 121, 32, 115, 117, 99, 99,
  101, 115, 102, 117, 108, 32, 114, 101, 112, 101, 97, 116, 32, 100, 101, 102,
  105, 110, 101, 100, 32, 105, 110, 32, 116, 104, 101, 32, 102, 108, 111, 111,
  100, 32, 115, 101, 116, 116, 105, 110, 103, 115, 32, 115, 101, 99, 116, 105,
  111, 110, 46, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80,
  114, 101, 112, 114, 111, 99, 101, 115, 115, 32, 119, 105, 116, 104, 32, 98,
  105, 108, 97, 116, 101, 114, 97, 108, 32, 102, 105, 108, 116, 101, 114, 105,
  110, 103, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 112, 97, 116, 105, 97, 108, 32, 118, 97,
  114, 105, 97, 110, 99, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 86, 97, 108, 117, 101, 32, 118, 97, 114, 105, 97, 110, 99, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 55, 44, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101, 114, 97,
  116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 50, 44, 49, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 70, 108, 111, 111, 100, 32, 115, 101, 116, 116, 105,
  110, 103, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  99, 116, 105, 118, 97, 116, 101, 32, 102, 108, 111, 111, 100, 32, 61, 32,
  98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 82, 101, 112, 101, 97, 116, 115, 32, 61, 32, 105, 110, 116, 40, 49,
  48, 44, 49, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 70, 108, 111, 111, 100, 32, 116, 111, 108, 101, 114, 97, 110,
  99, 101, 32, 61, 32, 105, 110, 116, 40, 53, 44, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 108, 111, 111, 100,
  32, 98, 97, 115, 101, 32, 115, 116, 101, 112, 32, 61, 32, 105, 110, 116,
  40, 51, 44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 97, 110, 118, 97, 115, 32, 99, 111, 108, 111, 114, 32, 61,
  32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 65, 98, 115, 116, 114, 97, 99,
  116, 105, 111, 110, 32, 115, 101, 116, 116, 105, 110, 103, 44, 32, 67, 111,
  110, 115, 105, 100, 101, 114, 32, 100, 105, 115, 97, 98, 108, 105, 110, 103,
  32, 112, 114, 101, 118, 105, 101, 119, 32, 105, 102, 32, 117, 115, 105, 110,
  103, 32, 104, 105, 103, 104, 32, 102, 108, 111, 111, 100, 32, 114, 101, 112,
  101, 97, 116, 115, 33, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 65, 99, 116, 105, 118, 97, 116, 101, 32, 99, 117, 98, 105, 115, 109,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 117, 98, 105, 115, 109, 32, 105, 116, 101, 114, 97,
  116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 51, 48, 48, 44,
  49, 44, 50, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 66, 108, 111, 99, 32, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 48, 44, 48, 44, 52, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 57, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 55, 44, 48, 46, 48, 49, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 79, 112, 97, 99, 105,
  116, 121, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 117, 115, 101,
  100, 32, 116, 111, 32, 109, 97, 107, 101, 32, 100, 101, 99, 105, 115, 105,
  111, 110, 32, 97, 98, 111, 117, 116, 32, 102, 108, 111, 111, 100, 105, 110,
  103, 46, 32, 85, 115, 101, 32, 48, 32, 105, 102, 32, 67, 117, 98, 105,
  115, 109, 32, 105, 115, 32, 110, 111, 116, 32, 101, 110, 97, 98, 108, 101,
  100, 46, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112,
  97, 99, 105, 116, 121, 32, 116, 111, 108, 101, 114, 97, 110, 99, 101, 32,
  61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 50, 53, 52, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 32, 58, 32, 60, 105, 62, 65, 114, 116, 111, 32, 72, 117, 111, 116,
  97, 114, 105, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105,
  62, 50, 48, 49, 51, 47, 48, 57, 47, 50, 56, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40,
  34, 70, 105, 108, 116, 101, 114, 32, 69, 120, 112, 108, 97, 105, 110, 101,
  100, 32, 104, 101, 114, 101, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47,
  119, 119, 119, 46, 102, 108, 105, 99, 107, 114, 46, 99, 111, 109, 47, 112,
  104, 111, 116, 111, 115, 47, 110, 97, 103, 103, 111, 98, 111, 116, 47, 54,
  50, 52, 51, 55, 49, 53, 54, 54, 54, 34, 41, 10, 103, 105, 109, 112,
  95, 65, 98, 115, 116, 114, 97, 99, 116, 70, 108, 111, 111, 100, 32, 58,
  10, 80, 114, 101, 112, 61, 36, 49, 10, 83, 112, 97, 116, 105, 97, 108,
  86, 97, 114, 105, 97, 110, 99, 101, 61, 36, 50, 10, 86, 97, 108, 117,
  101, 86, 97, 114, 105, 97, 110, 99, 101, 61, 36, 51, 10, 73, 116, 101,
  114, 97, 116, 105, 111, 110, 115, 61, 36, 52, 10, 65, 99, 116, 105, 118,
  97, 116, 101, 70, 108, 111, 111, 100, 61, 36, 53, 10, 82, 101, 112, 101,
  97, 116, 115, 61, 36, 54, 10, 84, 111, 108, 101, 114, 97, 110, 99, 101,
  61, 36, 55, 10, 70, 108, 111, 111, 100, 66, 97, 115, 101, 83, 116, 101,
  112, 61, 36, 56, 10, 67, 97, 110, 118, 97, 115, 82, 61, 36, 57, 10,
  67, 97, 110, 118, 97, 115, 71, 61, 36, 49, 48, 10, 67, 97, 110, 118,
  97, 115, 66, 61, 36, 49, 49, 10, 79, 112, 97, 99, 105, 116, 121, 61,
  36, 49, 50, 10, 65, 99, 116, 105, 118, 97, 116, 101, 67, 117, 98, 105,
  115, 109, 61, 36, 49, 51, 10, 67, 117, 98, 105, 115, 109, 73, 116, 101,
  114, 97, 116, 105, 111, 110, 115, 61, 36, 49, 52, 10, 66, 108, 111, 99,
  115, 105, 122, 101, 61, 36, 49, 53, 10, 65, 110, 103, 108, 101, 61, 36,
  49, 54, 10, 67, 117, 98, 105, 115, 109, 79, 112, 97, 99, 105, 116, 121,
  61, 36, 49, 55, 10, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61,
  36, 49, 56, 10, 83, 116, 101, 112, 84, 104, 114, 101, 115, 104, 111, 108,
  100, 61, 123, 36, 49, 57, 43, 48, 46, 49, 125, 10, 83, 116, 101, 112,
  61, 36, 70, 108, 111, 111, 100, 66, 97, 115, 101, 83, 116, 101, 112, 10,
  68, 101, 108, 116, 97, 61, 49, 10, 68, 101, 108, 116, 97, 79, 114, 103,
  61, 36, 68, 101, 108, 116, 97, 10, 45, 116, 111, 95, 114, 103, 98, 97,
  91, 48, 93, 10, 45, 105, 102, 32, 123, 36, 80, 114, 101, 112, 61, 61,
  49, 125, 10, 45, 103, 105, 109, 112, 95, 98, 105, 108, 97, 116, 101, 114,
  97, 108, 91, 48, 93, 32, 36, 83, 112, 97, 116, 105, 97, 108, 86, 97,
  114, 105, 97, 110, 99, 101, 44, 36, 86, 97, 108, 117, 101, 86, 97, 114,
  105, 97, 110, 99, 101, 44, 36, 73, 116, 101, 114, 97, 116, 105, 111, 110,
  115, 44, 48, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 40, 123, 36,
  67, 97, 110, 118, 97, 115, 82, 125, 94, 123, 36, 67, 97, 110, 118, 97,
  115, 71, 125, 94, 123, 36, 67, 97, 110, 118, 97, 115, 66, 125, 94, 48,
  41, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 49, 93, 10, 45, 114,
  91, 49, 93, 32, 91, 48, 93, 10, 88, 61, 123, 40, 119, 41, 47, 50,
  125, 10, 89, 61, 123, 40, 104, 41, 47, 50, 125, 10, 73, 109, 97, 103,
  101, 72, 61, 123, 40, 104, 41, 125, 10, 73, 109, 97, 103, 101, 87, 61,
  123, 40, 119, 41, 125, 10, 68, 111, 76, 111, 111, 112, 61, 48, 10, 73,
  115, 71, 111, 111, 100, 61, 48, 10, 45, 105, 102, 32, 123, 36, 65, 99,
  116, 105, 118, 97, 116, 101, 70, 108, 111, 111, 100, 61, 61, 49, 125, 10,
  35, 65, 32, 99, 111, 109, 109, 101, 110, 116, 32, 104, 101, 114, 101, 32,
  105, 115, 32, 110, 101, 101, 100, 101, 100, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 36, 82, 101, 112, 101, 97, 116, 115, 10, 45, 102, 108, 111, 111,
  100, 91, 48, 93, 32, 123, 49, 48, 48, 42, 36, 88, 47, 119, 125, 37,
  44, 123, 49, 48, 48, 42, 36, 89, 47, 104, 125, 37, 44, 48, 44, 36,
  84, 111, 108, 101, 114, 97, 110, 99, 101, 44, 48, 44, 49, 44, 64, 123,
  48, 44, 40, 36, 88, 44, 36, 89, 44, 48, 44, 48, 41, 125, 44, 64,
  123, 48, 44, 40, 36, 88, 44, 36, 89, 44, 48, 44, 49, 41, 125, 44,
  64, 123, 48, 44, 40, 36, 88, 44, 36, 89, 44, 48, 44, 50, 41, 125,
  44, 64, 123, 48, 44, 40, 36, 88, 44, 36, 89, 44, 48, 44, 51, 41,
  125, 10, 45, 45, 103, 105, 109, 112, 95, 115, 101, 108, 101, 99, 116, 95,
  99, 111, 108, 111, 114, 91, 48, 93, 32, 48, 44, 49, 44, 48, 44, 64,
  123, 48, 44, 40, 36, 88, 44, 36, 89, 44, 48, 44, 48, 41, 125, 44,
  64, 123, 48, 44, 40, 36, 88, 44, 36, 89, 44, 48, 44, 49, 41, 125,
  44, 64, 123, 48, 44, 40, 36, 88, 44, 36, 89, 44, 48, 44, 50, 41,
  125, 44, 64, 123, 48, 44, 40, 36, 88, 44, 36, 89, 44, 48, 44, 51,
  41, 125, 44, 48, 44, 48, 10, 45, 105, 102, 32, 123, 36, 65, 99, 116,
  105, 118, 97, 116, 101, 67, 117, 98, 105, 115, 109, 61, 61, 49, 125, 10,
  45, 99, 117, 98, 105, 115, 109, 91, 50, 93, 32, 36, 67, 117, 98, 105,
  115, 109, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 44, 36, 66, 108,
  111, 99, 115, 105, 122, 101, 44, 36, 65, 110, 103, 108, 101, 44, 36, 67,
  117, 98, 105, 115, 109, 79, 112, 97, 99, 105, 116, 121, 44, 36, 83, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 98, 108, 101, 110, 100, 91, 49, 44, 50, 93, 32, 97, 108, 112, 104,
  97, 10, 45, 100, 111, 10, 82, 115, 116, 101, 112, 61, 123, 36, 83, 116,
  101, 112, 43, 36, 68, 101, 108, 116, 97, 125, 10, 116, 104, 101, 116, 97,
  61, 123, 63, 40, 51, 54, 48, 41, 125, 10, 88, 110, 101, 119, 61, 123,
  105, 110, 116, 40, 36, 88, 43, 36, 82, 115, 116, 101, 112, 42, 99, 111,
  115, 40, 36, 116, 104, 101, 116, 97, 41, 41, 125, 10, 89, 110, 101, 119,
  61, 123, 105, 110, 116, 40, 36, 89, 43, 36, 82, 115, 116, 101, 112, 42,
  115, 105, 110, 40, 36, 116, 104, 101, 116, 97, 41, 41, 125, 10, 45, 105,
  102, 32, 123, 123, 36, 88, 110, 101, 119, 62, 48, 125, 34, 32, 38, 38,
  32, 34, 123, 36, 88, 110, 101, 119, 60, 36, 73, 109, 97, 103, 101, 87,
  125, 34, 32, 38, 38, 32, 34, 123, 36, 89, 110, 101, 119, 62, 48, 125,
  34, 32, 38, 38, 32, 34, 123, 36, 89, 110, 101, 119, 60, 36, 73, 109,
  97, 103, 101, 72, 125, 125, 10, 88, 61, 36, 88, 110, 101, 119, 10, 89,
  61, 36, 89, 110, 101, 119, 10, 45, 105, 102, 32, 123, 64, 123, 49, 44,
  40, 36, 88, 44, 36, 89, 44, 48, 44, 51, 41, 125, 62, 36, 83, 116,
  101, 112, 84, 104, 114, 101, 115, 104, 111, 108, 100, 125, 10, 68, 101, 108,
  116, 97, 61, 123, 109, 105, 110, 40, 123, 36, 68, 101, 108, 116, 97, 43,
  36, 68, 101, 108, 116, 97, 42, 50, 125, 44, 123, 109, 97, 120, 40, 36,
  73, 109, 97, 103, 101, 87, 44, 36, 73, 109, 97, 103, 101, 72, 41, 47,
  53, 125, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 64, 123, 49, 44, 40, 36, 88, 44, 36, 89, 44, 48, 44, 51, 41,
  125, 60, 36, 83, 116, 101, 112, 84, 104, 114, 101, 115, 104, 111, 108, 100,
  125, 10, 73, 115, 71, 111, 111, 100, 61, 49, 48, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 68, 111, 76, 111, 111, 112, 62,
  49, 48, 48, 125, 10, 73, 115, 71, 111, 111, 100, 61, 49, 48, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 68, 111, 76,
  111, 111, 112, 61, 36, 68, 111, 76, 111, 111, 112, 43, 49, 10, 45, 119,
  104, 105, 108, 101, 32, 123, 36, 73, 115, 71, 111, 111, 100, 60, 49, 125,
  10, 73, 115, 71, 111, 111, 100, 61, 48, 10, 68, 111, 76, 111, 111, 112,
  61, 48, 10, 68, 101, 108, 116, 97, 61, 36, 68, 101, 108, 116, 97, 79,
  114, 103, 10, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10,
  40, 123, 36, 67, 97, 110, 118, 97, 115, 82, 125, 94, 123, 36, 67, 97,
  110, 118, 97, 115, 71, 125, 94, 123, 36, 67, 97, 110, 118, 97, 115, 66,
  125, 94, 123, 36, 79, 112, 97, 99, 105, 116, 121, 125, 41, 10, 45, 114,
  91, 50, 93, 32, 91, 48, 93, 10, 45, 114, 101, 118, 101, 114, 115, 101,
  91, 49, 44, 50, 93, 10, 45, 98, 108, 101, 110, 100, 91, 49, 44, 50,
  93, 32, 97, 108, 112, 104, 97, 10, 45, 105, 102, 32, 123, 36, 65, 99,
  116, 105, 118, 97, 116, 101, 70, 108, 111, 111, 100, 61, 61, 49, 125, 10,
  45, 107, 101, 101, 112, 91, 49, 93, 10, 45, 101, 108, 105, 102, 32, 32,
  123, 36, 65, 99, 116, 105, 118, 97, 116, 101, 70, 108, 111, 111, 100, 61,
  61, 48, 125, 10, 45, 107, 101, 101, 112, 91, 48, 93, 10, 45, 101, 110,
  100, 105, 102, 10, 103, 105, 109, 112, 95, 65, 98, 115, 116, 114, 97, 99,
  116, 70, 108, 111, 111, 100, 95, 80, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 65, 98, 115, 116,
  114, 97, 99, 116, 70, 108, 111, 111, 100, 32, 36, 123, 49, 45, 45, 50,
  125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 66, 108,
  97, 99, 107, 32, 38, 97, 109, 112, 59, 32, 119, 104, 105, 116, 101, 32,
  102, 105, 108, 109, 32, 58, 32, 103, 105, 109, 112, 95, 98, 119, 102, 105,
  108, 109, 115, 105, 109, 117, 108, 97, 116, 101, 44, 32, 103, 105, 109, 112,
  95, 98, 119, 102, 105, 108, 109, 115, 105, 109, 117, 108, 97, 116, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 70, 105, 108, 109, 32, 116, 121, 112, 101, 32, 47, 32,
  82, 71, 66, 32, 98, 97, 108, 97, 110, 99, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 48, 44, 34, 77, 97, 110, 117, 97, 108, 34, 44,
  34, 65, 103, 102, 97, 32, 50, 48, 48, 88, 34, 44, 34, 65, 103, 102,
  97, 112, 97, 110, 32, 50, 53, 34, 44, 34, 65, 103, 102, 97, 112, 97,
  110, 32, 49, 48, 48, 34, 44, 34, 65, 103, 102, 97, 112, 97, 110, 32,
  52, 48, 48, 34, 44, 34, 73, 102, 111, 114, 100, 32, 68, 101, 108, 116,
  97, 32, 49, 48, 48, 34, 44, 34, 73, 102, 111, 114, 100, 32, 68, 101,
  108, 116, 97, 32, 52, 48, 48, 34, 44, 34, 73, 102, 111, 114, 100, 32,
  68, 101, 108, 116, 97, 32, 52, 48, 48, 32, 112, 114, 111, 32, 38, 32,
  51, 50, 48, 48, 34, 44, 34, 73, 108, 102, 111, 114, 100, 32, 70, 80,
  52, 34, 44, 34, 73, 108, 102, 111, 114, 100, 32, 72, 80, 52, 34, 44,
  34, 73, 108, 102, 111, 114, 100, 32, 80, 97, 110, 32, 70, 34, 44, 34,
  73, 108, 102, 111, 114, 100, 32, 83, 70, 88, 34, 44, 34, 73, 108, 102,
  111, 114, 100, 32, 88, 80, 50, 32, 83, 117, 112, 101, 114, 34, 44, 34,
  75, 111, 100, 97, 107, 32, 84, 109, 97, 120, 32, 49, 48, 48, 34, 44,
  34, 75, 111, 100, 97, 107, 32, 84, 109, 97, 120, 32, 52, 48, 48, 34,
  44, 34, 75, 111, 100, 97, 107, 32, 84, 114, 105, 45, 88, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 83, 105, 109, 112, 108, 101, 114, 32, 118, 101,
  114, 115, 105, 111, 110, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 32,
  105, 110, 32, 109, 97, 105, 110, 32, 116, 114, 101, 101, 46, 32, 84, 104,
  105, 115, 32, 102, 105, 108, 116, 101, 114, 32, 119, 105, 108, 108, 32, 98,
  101, 32, 114, 101, 109, 111, 118, 101, 100, 32, 105, 110, 32, 102, 117, 116,
  117, 114, 101, 32, 102, 114, 111, 109, 32, 116, 101, 115, 116, 105, 110, 103,
  46, 32, 80, 77, 32, 109, 101, 32, 105, 102, 32, 121, 111, 117, 32, 110,
  101, 101, 100, 32, 116, 104, 105, 115, 32, 102, 111, 114, 32, 115, 111, 109,
  101, 32, 114, 101, 97, 115, 111, 110, 46, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 82, 71, 66, 32, 115, 108, 105, 100, 101, 114, 115, 32, 119, 111,
  114, 107, 32, 111, 110, 108, 121, 32, 119, 105, 116, 104, 32, 109, 97, 110,
  117, 97, 108, 32, 115, 101, 108, 101, 99, 116, 105, 111, 110, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 100, 32, 108, 101, 118,
  101, 108, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 50, 57, 57,
  44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  101, 100, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 71, 114, 101, 101, 110, 32, 108, 101, 118,
  101, 108, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 56, 55,
  44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71,
  114, 101, 101, 110, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 117, 101, 32, 108, 101,
  118, 101, 108, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 49, 49,
  52, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  66, 108, 117, 101, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 71, 97, 109, 109, 97, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 44, 48, 46, 48, 49, 44, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 111, 110, 116, 114, 97, 115, 116, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 66, 114, 105, 103, 104, 116, 110, 101, 115, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 53, 53, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 117,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 51, 54,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 97, 116, 117,
  114, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 97, 105, 110, 32,
  40, 115, 104, 97, 100, 111, 119, 115, 41, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 71, 114, 97, 105, 110, 32, 40, 109, 105, 100, 116, 111,
  110, 101, 115, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71,
  114, 97, 105, 110, 32, 40, 104, 105, 103, 104, 108, 105, 103, 104, 116, 115,
  41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 50, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 97, 105,
  110, 32, 116, 111, 110, 101, 32, 102, 97, 100, 105, 110, 103, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 50, 44, 48, 44, 49, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 71, 114, 97, 105, 110, 32, 115, 99, 97,
  108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 51,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 97, 105, 110,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  71, 97, 117, 115, 115, 105, 97, 110, 34, 44, 34, 85, 110, 105, 102, 111,
  114, 109, 34, 44, 34, 83, 97, 108, 116, 32, 97, 110, 100, 32, 112, 101,
  112, 112, 101, 114, 34, 44, 34, 80, 111, 105, 115, 115, 111, 110, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 76, 111, 99, 97, 108, 32, 99, 111, 110, 116, 114,
  97, 115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 100,
  105, 117, 115, 32, 61, 32, 105, 110, 116, 40, 49, 54, 44, 49, 44, 53,
  49, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110,
  116, 114, 97, 115, 116, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 44, 48, 44, 49, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101,
  118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 32, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84,
  115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 44, 32,
  65, 114, 116, 111, 32, 72, 117, 111, 116, 97, 114, 105, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 57, 47,
  48, 57, 47, 50, 56, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 98, 119, 102, 105, 108, 109,
  115, 105, 109, 117, 108, 97, 116, 101, 32, 58, 10, 67, 104, 111, 105, 99,
  101, 61, 36, 49, 10, 80, 49, 61, 36, 50, 10, 80, 50, 61, 36, 51,
  10, 80, 51, 61, 36, 52, 10, 80, 52, 61, 36, 53, 10, 80, 53, 61,
  36, 54, 10, 80, 54, 61, 36, 55, 10, 80, 55, 61, 36, 56, 10, 80,
  56, 61, 36, 57, 10, 80, 57, 61, 36, 49, 48, 10, 80, 49, 48, 61,
  36, 49, 49, 10, 80, 49, 49, 61, 36, 49, 50, 10, 80, 49, 50, 61,
  36, 49, 51, 10, 80, 49, 51, 61, 36, 49, 52, 10, 80, 49, 52, 61,
  36, 49, 53, 10, 80, 49, 53, 61, 36, 49, 54, 10, 80, 49, 54, 61,
  36, 49, 55, 10, 80, 49, 55, 61, 36, 49, 56, 10, 80, 49, 56, 61,
  36, 49, 57, 10, 80, 49, 57, 61, 36, 50, 48, 10, 80, 50, 48, 61,
  36, 50, 49, 10, 45, 105, 102, 32, 123, 36, 67, 104, 111, 105, 99, 101,
  61, 61, 49, 125, 32, 80, 49, 61, 123, 49, 56, 47, 50, 53, 53, 125,
  32, 80, 51, 61, 123, 52, 49, 47, 50, 53, 53, 125, 32, 80, 53, 61,
  123, 52, 49, 47, 50, 53, 53, 125, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 67, 104, 111, 105, 99, 101, 61, 61, 50, 125,
  32, 80, 49, 61, 123, 50, 53, 47, 50, 53, 53, 125, 32, 80, 51, 61,
  123, 51, 57, 47, 50, 53, 53, 125, 32, 80, 53, 61, 123, 51, 54, 47,
  50, 53, 53, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 67, 104, 111, 105, 99, 101, 61, 61, 51, 125, 32, 80, 49, 61,
  123, 50, 49, 47, 50, 53, 53, 125, 32, 80, 51, 61, 123, 52, 48, 47,
  50, 53, 53, 125, 32, 80, 53, 61, 123, 51, 57, 47, 50, 53, 53, 125,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 67, 104,
  111, 105, 99, 101, 61, 61, 52, 125, 32, 80, 49, 61, 123, 50, 48, 47,
  50, 53, 53, 125, 32, 80, 51, 61, 123, 52, 49, 47, 50, 53, 53, 125,
  32, 80, 53, 61, 123, 51, 57, 47, 50, 53, 53, 125, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 67, 104, 111, 105, 99, 101,
  61, 61, 53, 125, 32, 80, 49, 61, 123, 50, 49, 47, 50, 53, 53, 125,
  32, 80, 51, 61, 123, 52, 50, 47, 50, 53, 53, 125, 32, 80, 53, 61,
  123, 51, 55, 47, 50, 53, 53, 125, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 67, 104, 111, 105, 99, 101, 61, 61, 54, 125,
  32, 80, 49, 61, 123, 50, 50, 47, 50, 53, 53, 125, 32, 80, 51, 61,
  123, 52, 50, 47, 50, 53, 53, 125, 32, 80, 53, 61, 123, 51, 54, 47,
  50, 53, 53, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 67, 104, 111, 105, 99, 101, 61, 61, 55, 125, 32, 80, 49, 61,
  123, 51, 49, 47, 50, 53, 53, 125, 32, 80, 51, 61, 123, 51, 54, 47,
  50, 53, 53, 125, 32, 80, 53, 61, 123, 51, 51, 47, 50, 53, 53, 125,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 67, 104,
  111, 105, 99, 101, 61, 61, 56, 125, 32, 80, 49, 61, 123, 50, 56, 47,
  50, 53, 53, 125, 32, 80, 51, 61, 123, 52, 49, 47, 50, 53, 53, 125,
  32, 80, 53, 61, 123, 51, 49, 47, 50, 53, 53, 125, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 67, 104, 111, 105, 99, 101,
  61, 61, 57, 125, 32, 80, 49, 61, 123, 50, 51, 47, 50, 53, 53, 125,
  32, 80, 51, 61, 123, 51, 55, 47, 50, 53, 53, 125, 32, 80, 53, 61,
  123, 52, 48, 47, 50, 53, 53, 125, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 67, 104, 111, 105, 99, 101, 61, 61, 49, 48,
  125, 32, 80, 49, 61, 123, 51, 51, 47, 50, 53, 53, 125, 32, 80, 51,
  61, 123, 51, 54, 47, 50, 53, 53, 125, 32, 80, 53, 61, 123, 51, 49,
  47, 50, 53, 53, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 67, 104, 111, 105, 99, 101, 61, 61, 49, 49, 125, 32, 80,
  49, 61, 123, 51, 54, 47, 50, 53, 53, 125, 32, 80, 51, 61, 123, 51,
  49, 47, 50, 53, 53, 125, 32, 80, 53, 61, 123, 51, 51, 47, 50, 53,
  53, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  67, 104, 111, 105, 99, 101, 61, 61, 49, 50, 125, 32, 80, 49, 61, 123,
  50, 49, 47, 50, 53, 53, 125, 32, 80, 51, 61, 123, 52, 50, 47, 50,
  53, 53, 125, 32, 80, 53, 61, 123, 51, 55, 47, 50, 53, 53, 125, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 67, 104, 111,
  105, 99, 101, 61, 61, 49, 51, 125, 32, 80, 49, 61, 123, 50, 52, 47,
  50, 53, 53, 125, 32, 80, 51, 61, 123, 51, 55, 47, 50, 53, 53, 125,
  32, 80, 53, 61, 123, 51, 57, 47, 50, 53, 53, 125, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 67, 104, 111, 105, 99, 101,
  61, 61, 49, 52, 125, 32, 80, 49, 61, 123, 51, 55, 47, 50, 53, 53,
  125, 32, 80, 51, 61, 123, 51, 54, 47, 50, 53, 53, 125, 32, 80, 53,
  61, 123, 51, 55, 47, 50, 53, 53, 125, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 67, 104, 111, 105, 99, 101, 61, 61, 49,
  53, 125, 32, 80, 49, 61, 123, 50, 53, 47, 50, 53, 53, 125, 32, 80,
  51, 61, 123, 51, 53, 47, 50, 53, 53, 125, 32, 80, 53, 61, 123, 52,
  48, 47, 50, 53, 53, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 108, 91, 45, 49, 93, 32,
  45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 32, 45,
  114, 118, 32, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 32, 45,
  115, 91, 45, 49, 93, 32, 99, 10, 45, 42, 91, 45, 51, 93, 32, 36,
  80, 49, 32, 45, 98, 91, 45, 51, 93, 32, 36, 80, 50, 37, 10, 45,
  42, 91, 45, 50, 93, 32, 36, 80, 51, 32, 45, 98, 91, 45, 50, 93,
  32, 36, 80, 52, 37, 10, 45, 42, 91, 45, 49, 93, 32, 36, 80, 53,
  32, 45, 98, 91, 45, 49, 93, 32, 36, 80, 54, 37, 10, 45, 43, 91,
  45, 51, 45, 45, 49, 93, 32, 45, 47, 91, 45, 49, 93, 32, 123, 36,
  80, 49, 43, 36, 80, 51, 43, 36, 80, 53, 125, 32, 45, 99, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 97, 112, 112, 108, 121, 95,
  103, 97, 109, 109, 97, 91, 45, 49, 93, 32, 36, 80, 55, 10, 45, 45,
  91, 45, 49, 93, 32, 49, 50, 56, 32, 45, 42, 91, 45, 49, 93, 32,
  36, 80, 56, 32, 45, 43, 91, 45, 49, 93, 32, 49, 50, 56, 32, 45,
  43, 91, 45, 49, 93, 32, 36, 80, 57, 32, 45, 99, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  32, 91, 45, 49, 93, 120, 50, 10, 45, 110, 111, 105, 115, 101, 91, 45,
  51, 93, 32, 49, 48, 48, 44, 36, 80, 49, 55, 32, 45, 98, 91, 45,
  51, 93, 32, 36, 80, 49, 54, 37, 32, 45, 110, 91, 45, 51, 93, 32,
  45, 36, 80, 49, 50, 44, 36, 80, 49, 50, 10, 45, 110, 111, 105, 115,
  101, 91, 45, 50, 93, 32, 49, 48, 48, 44, 36, 80, 49, 55, 32, 45,
  98, 91, 45, 50, 93, 32, 36, 80, 49, 54, 37, 32, 45, 110, 91, 45,
  50, 93, 32, 45, 36, 80, 49, 51, 44, 36, 80, 49, 51, 10, 45, 110,
  111, 105, 115, 101, 91, 45, 49, 93, 32, 49, 48, 48, 44, 36, 80, 49,
  55, 32, 45, 98, 91, 45, 49, 93, 32, 36, 80, 49, 54, 37, 32, 45,
  110, 91, 45, 49, 93, 32, 45, 36, 80, 49, 52, 44, 36, 80, 49, 52,
  10, 45, 45, 116, 111, 110, 101, 115, 91, 45, 52, 93, 32, 51, 32, 45,
  98, 91, 45, 51, 45, 45, 49, 93, 32, 36, 80, 49, 53, 37, 10, 45,
  42, 91, 45, 54, 44, 45, 51, 93, 32, 45, 42, 91, 45, 52, 44, 45,
  50, 93, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 10, 45, 43, 91,
  45, 52, 45, 45, 49, 93, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 10, 45, 105, 102, 32, 123, 36, 80, 49, 48, 124, 124, 36,
  80, 49, 49, 125, 10, 45, 47, 91, 45, 49, 93, 32, 50, 53, 53, 10,
  45, 105, 91, 45, 50, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 49, 44, 49, 44, 36, 80, 49, 49, 10, 45, 105, 91, 45, 51, 93,
  32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 44, 49, 44, 36,
  80, 49, 48, 10, 45, 97, 91, 45, 51, 45, 45, 49, 93, 32, 99, 32,
  45, 104, 115, 118, 50, 114, 103, 98, 91, 45, 49, 93, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 114, 118, 32, 45, 97, 32, 99, 32, 45, 101, 110,
  100, 108, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111,
  110, 101, 10, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 108, 111,
  99, 97, 108, 32, 36, 80, 49, 56, 44, 36, 80, 49, 57, 44, 36, 80,
  50, 48, 44, 50, 37, 44, 49, 44, 48, 44, 50, 53, 53, 10, 103, 105,
  109, 112, 95, 98, 119, 102, 105, 108, 109, 115, 105, 109, 117, 108, 97, 116,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 98, 119, 102, 105, 108, 109, 115, 105, 109,
  117, 108, 97, 116, 101, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36,
  45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 67, 111, 109, 112, 111, 115,
  105, 116, 111, 110, 32, 97, 110, 97, 108, 121, 115, 105, 115, 32, 58, 32,
  103, 105, 109, 112, 95, 67, 111, 109, 112, 111, 115, 105, 116, 111, 110, 65,
  110, 97, 108, 121, 115, 105, 115, 44, 32, 103, 105, 109, 112, 95, 67, 111,
  109, 112, 111, 115, 105, 116, 111, 110, 65, 110, 97, 108, 121, 115, 105, 115,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 65, 32, 116, 111, 111, 108, 32, 116, 111,
  32, 97, 98, 115, 116, 114, 97, 99, 116, 32, 116, 104, 101, 32, 105, 109,
  97, 103, 101, 32, 102, 111, 114, 32, 115, 117, 98, 106, 101, 99, 116, 105,
  118, 101, 32, 99, 111, 109, 112, 111, 115, 105, 116, 105, 111, 110, 32, 97,
  110, 97, 108, 121, 115, 105, 115, 46, 32, 66, 111, 116, 104, 32, 76, 117,
  109, 105, 110, 97, 110, 99, 101, 32, 97, 110, 100, 32, 115, 104, 97, 112,
  101, 32, 111, 102, 32, 116, 104, 101, 32, 105, 109, 97, 103, 101, 32, 97,
  114, 101, 32, 97, 98, 115, 116, 114, 97, 99, 116, 101, 100, 46, 32, 70,
  111, 114, 32, 97, 99, 116, 117, 97, 108, 32, 97, 110, 97, 108, 121, 115,
  105, 115, 32, 116, 104, 101, 32, 97, 101, 115, 116, 104, 101, 116, 105, 99,
  32, 115, 101, 110, 115, 101, 32, 111, 102, 32, 116, 104, 101, 32, 97, 114,
  116, 105, 115, 116, 32, 105, 115, 32, 114, 101, 113, 117, 105, 114, 101, 100,
  46, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62,
  65, 114, 116, 111, 32, 72, 117, 111, 116, 97, 114, 105, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48,
  49, 47, 50, 56, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 67, 111, 109, 112, 111, 115, 105,
  116, 111, 110, 65, 110, 97, 108, 121, 115, 105, 115, 32, 58, 10, 45, 116,
  111, 95, 114, 103, 98, 91, 48, 93, 10, 73, 87, 105, 100, 116, 104, 61,
  64, 123, 48, 44, 119, 125, 10, 73, 72, 101, 105, 103, 104, 116, 61, 64,
  123, 48, 44, 119, 125, 10, 45, 105, 102, 32, 123, 36, 73, 87, 105, 100,
  116, 104, 62, 61, 36, 73, 72, 101, 105, 103, 104, 116, 125, 10, 83, 99,
  97, 108, 101, 66, 121, 87, 105, 100, 116, 104, 61, 49, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 83, 99, 97, 108, 101, 66,
  121, 87, 105, 100, 116, 104, 61, 61, 49, 125, 10, 45, 45, 114, 101, 115,
  105, 122, 101, 50, 100, 120, 91, 48, 93, 32, 50, 48, 48, 44, 53, 10,
  45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 50, 10, 35, 82, 101, 115,
  105, 122, 101, 32, 116, 111, 32, 49, 48, 50, 52, 32, 112, 120, 10, 45,
  114, 101, 115, 105, 122, 101, 50, 100, 120, 91, 45, 49, 93, 32, 49, 48,
  50, 52, 44, 53, 10, 35, 83, 101, 103, 109, 101, 110, 116, 97, 116, 105,
  111, 110, 10, 45, 103, 105, 109, 112, 95, 115, 101, 103, 109, 101, 110, 116,
  95, 119, 97, 116, 101, 114, 115, 104, 101, 100, 91, 45, 49, 93, 32, 48,
  46, 53, 44, 53, 44, 48, 44, 48, 10, 45, 101, 108, 105, 102, 10, 45,
  45, 114, 101, 115, 105, 122, 101, 50, 100, 121, 91, 48, 93, 32, 50, 48,
  48, 44, 53, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 50, 10,
  35, 82, 101, 115, 105, 122, 101, 32, 116, 111, 32, 49, 48, 50, 52, 32,
  112, 120, 10, 45, 114, 101, 115, 105, 122, 101, 50, 100, 121, 91, 45, 49,
  93, 32, 49, 48, 50, 52, 44, 53, 10, 35, 83, 101, 103, 109, 101, 110,
  116, 97, 116, 105, 111, 110, 10, 45, 103, 105, 109, 112, 95, 115, 101, 103,
  109, 101, 110, 116, 95, 119, 97, 116, 101, 114, 115, 104, 101, 100, 91, 45,
  49, 93, 32, 48, 46, 53, 44, 53, 44, 48, 44, 48, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32,
  91, 48, 93, 10, 45, 45, 114, 103, 98, 50, 108, 97, 98, 91, 48, 93,
  10, 45, 115, 112, 108, 105, 116, 91, 45, 49, 93, 32, 99, 10, 45, 114,
  109, 91, 45, 49, 44, 45, 50, 93, 10, 45, 98, 108, 117, 114, 91, 45,
  49, 93, 32, 49, 48, 37, 10, 45, 110, 111, 114, 109, 97, 108, 105, 122,
  101, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 98, 108, 101,
  110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 104, 97, 114, 100, 108, 105,
  103, 104, 116, 44, 49, 44, 49, 10, 45, 107, 101, 101, 112, 91, 45, 49,
  93, 10, 35, 64, 103, 105, 109, 112, 32, 68, 111, 100, 103, 101, 32, 115,
  107, 101, 116, 99, 104, 32, 58, 32, 103, 105, 109, 112, 95, 100, 111, 100,
  103, 101, 115, 107, 101, 116, 99, 104, 44, 32, 103, 105, 109, 112, 95, 100,
  111, 100, 103, 101, 115, 107, 101, 116, 99, 104, 112, 114, 101, 118, 105, 101,
  119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 83, 105, 109, 112, 108,
  101, 32, 66, 87, 32, 115, 107, 101, 116, 99, 104, 34, 41, 44, 110, 111,
  116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 77, 101, 116, 104, 111,
  100, 32, 105, 115, 32, 100, 101, 115, 99, 114, 105, 98, 101, 100, 32, 104,
  101, 114, 101, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119,
  46, 103, 105, 109, 112, 117, 115, 101, 114, 115, 46, 99, 111, 109, 47, 116,
  117, 116, 111, 114, 105, 97, 108, 115, 47, 109, 97, 107, 105, 110, 103, 45,
  97, 45, 112, 101, 110, 99, 105, 108, 45, 100, 114, 97, 119, 105, 110, 103,
  45, 102, 114, 111, 109, 45, 97, 45, 112, 104, 111, 116, 111, 46, 104, 116,
  109, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 105, 110, 32, 97, 100,
  100, 105, 116, 105, 111, 110, 32, 97, 110, 32, 111, 112, 116, 105, 111, 110,
  32, 116, 111, 32, 99, 111, 108, 111, 114, 32, 116, 104, 101, 32, 115, 107,
  101, 116, 99, 104, 32, 105, 115, 32, 105, 110, 99, 108, 117, 100, 101, 100,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 80, 111, 119, 101,
  114, 32, 115, 101, 116, 116, 105, 110, 103, 32, 102, 111, 114, 32, 115, 107,
  101, 116, 99, 104, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  80, 111, 119, 101, 114, 32, 61, 32, 105, 110, 116, 40, 51, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 80, 114, 101,
  115, 109, 111, 111, 116, 104, 105, 110, 103, 32, 115, 101, 116, 116, 105, 110,
  115, 32, 111, 102, 32, 98, 105, 108, 97, 116, 101, 114, 97, 108, 32, 102,
  105, 108, 116, 101, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 112, 97, 116, 105, 97, 108, 32, 118, 97, 114, 105, 97, 110, 99,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108,
  117, 101, 32, 118, 97, 114, 105, 97, 110, 99, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 55, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115,
  32, 61, 32, 105, 110, 116, 40, 50, 44, 49, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 111, 108, 111, 114, 101, 100, 63, 32, 61, 32, 98, 111,
  111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 65, 114,
  116, 111, 32, 72, 117, 111, 116, 97, 114, 105, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 57, 47,
  50, 56, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 100, 111, 100, 103, 101, 115, 107, 101, 116,
  99, 104, 58, 10, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 10, 80,
  111, 119, 101, 114, 61, 36, 49, 10, 83, 112, 97, 116, 105, 97, 108, 86,
  97, 114, 105, 97, 110, 99, 101, 61, 36, 50, 10, 86, 97, 108, 117, 101,
  86, 97, 114, 105, 97, 110, 99, 101, 61, 36, 51, 10, 73, 116, 101, 114,
  97, 116, 105, 111, 110, 115, 61, 36, 52, 10, 67, 111, 108, 111, 114, 101,
  100, 61, 36, 53, 10, 45, 45, 103, 105, 109, 112, 95, 109, 105, 120, 95,
  104, 115, 118, 91, 48, 93, 32, 49, 44, 48, 44, 48, 44, 48, 44, 45,
  49, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 10,
  45, 45, 103, 105, 109, 112, 95, 98, 105, 108, 97, 116, 101, 114, 97, 108,
  91, 45, 49, 93, 32, 36, 83, 112, 97, 116, 105, 97, 108, 86, 97, 114,
  105, 97, 110, 99, 101, 44, 36, 86, 97, 108, 117, 101, 86, 97, 114, 105,
  97, 110, 99, 101, 44, 36, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115,
  44, 48, 44, 48, 10, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45,
  49, 93, 10, 45, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93,
  32, 97, 108, 112, 104, 97, 44, 48, 46, 53, 44, 48, 10, 91, 45, 49,
  93, 10, 45, 45, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93,
  32, 100, 111, 100, 103, 101, 44, 49, 44, 48, 10, 45, 107, 101, 101, 112,
  91, 48, 44, 45, 49, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36,
  80, 111, 119, 101, 114, 10, 91, 45, 49, 93, 10, 45, 98, 108, 101, 110,
  100, 91, 45, 49, 44, 45, 50, 93, 32, 109, 117, 108, 116, 105, 112, 108,
  121, 10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 67, 111,
  108, 111, 114, 101, 100, 61, 61, 49, 125, 10, 45, 45, 98, 108, 101, 110,
  100, 91, 45, 49, 44, 45, 50, 93, 32, 104, 97, 114, 100, 108, 105, 103,
  104, 116, 10, 45, 114, 101, 109, 111, 118, 101, 91, 45, 50, 93, 10, 45,
  103, 105, 109, 112, 95, 116, 114, 97, 110, 115, 102, 101, 114, 95, 99, 111,
  108, 111, 114, 115, 91, 45, 49, 44, 45, 50, 93, 32, 48, 44, 48, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93,
  10, 103, 105, 109, 112, 95, 100, 111, 100, 103, 101, 115, 107, 101, 116, 99,
  104, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 103, 105, 109, 112, 95, 100, 111, 100, 103, 101, 115, 107, 101, 116, 99,
  104, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35,
  64, 103, 105, 109, 112, 32, 69, 120, 112, 111, 115, 117, 114, 101, 32, 102,
  117, 115, 105, 111, 110, 32, 119, 101, 105, 103, 104, 116, 32, 109, 97, 112,
  32, 58, 32, 103, 105, 109, 112, 95, 69, 120, 112, 111, 115, 117, 114, 101,
  87, 101, 105, 103, 104, 116, 77, 97, 112, 44, 32, 103, 105, 109, 112, 95,
  69, 120, 112, 111, 115, 117, 114, 101, 87, 101, 105, 103, 104, 116, 77, 97,
  112, 80, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 67, 114, 101,
  97, 116, 101, 32, 101, 120, 112, 111, 115, 117, 114, 101, 32, 102, 117, 115,
  105, 111, 110, 32, 119, 101, 105, 103, 104, 116, 32, 109, 97, 112, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 65, 116, 32, 108, 101, 97, 115, 116, 32, 116, 119, 111, 32, 97,
  108, 105, 103, 110, 101, 100, 32, 111, 114, 32, 105, 109, 97, 103, 101, 115,
  32, 97, 114, 101, 32, 110, 101, 101, 100, 101, 100, 32, 102, 111, 114, 32,
  102, 105, 108, 116, 101, 114, 46, 32, 65, 114, 114, 97, 110, 103, 101, 32,
  116, 104, 101, 32, 108, 97, 121, 101, 114, 115, 32, 102, 114, 111, 109, 32,
  98, 114, 105, 103, 104, 116, 101, 115, 116, 32, 116, 111, 32, 100, 97, 114,
  107, 101, 115, 116, 46, 32, 83, 101, 116, 32, 102, 105, 108, 116, 101, 114,
  32, 111, 117, 116, 112, 117, 116, 32, 116, 111, 32, 34, 78, 101, 119, 32,
  108, 97, 121, 101, 114, 115, 34, 46, 32, 67, 111, 112, 121, 32, 102, 105,
  108, 116, 101, 114, 32, 111, 117, 116, 112, 117, 116, 32, 116, 111, 32, 99,
  111, 114, 114, 101, 115, 112, 111, 110, 100, 105, 110, 103, 32, 108, 97, 121,
  101, 114, 32, 109, 97, 115, 107, 46, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  111, 110, 116, 114, 97, 115, 116, 32, 98, 105, 97, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 51, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 97, 116, 117, 114, 97, 116, 105, 111,
  110, 32, 98, 105, 97, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  46, 51, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 69, 120, 112, 111, 115, 117, 114, 101, 32, 115, 105, 103, 109, 97, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 50, 44, 48, 44, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 120, 112, 111, 115, 117,
  114, 101, 32, 98, 105, 97, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 51, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 66, 108, 117, 114, 109, 97, 112, 32, 61, 32, 98, 111, 111, 108,
  40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  32, 65, 117, 116, 104, 111, 114, 58, 32, 65, 114, 116, 111, 32, 72, 117,
  111, 116, 97, 114, 105, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 49, 49,
  47, 50, 54, 32, 118, 50, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 66, 97, 115, 101,
  100, 32, 111, 110, 32, 97, 114, 116, 105, 99, 108, 101, 34, 44, 34, 104,
  116, 116, 112, 58, 47, 47, 114, 101, 115, 101, 97, 114, 99, 104, 46, 101,
  100, 109, 46, 117, 104, 97, 115, 115, 101, 108, 116, 46, 98, 101, 47, 116,
  109, 101, 114, 116, 101, 110, 115, 47, 112, 97, 112, 101, 114, 115, 47, 101,
  120, 112, 111, 115, 117, 114, 101, 95, 102, 117, 115, 105, 111, 110, 95, 114,
  101, 100, 117, 99, 101, 100, 46, 112, 100, 102, 34, 41, 10, 83, 117, 98,
  95, 67, 111, 110, 116, 114, 97, 115, 116, 95, 66, 105, 97, 115, 58, 10,
  45, 100, 105, 118, 91, 45, 49, 93, 32, 50, 53, 53, 10, 45, 116, 111,
  95, 103, 114, 97, 121, 91, 45, 49, 93, 10, 45, 108, 97, 112, 108, 97,
  99, 105, 97, 110, 91, 45, 49, 93, 10, 45, 97, 98, 115, 91, 45, 49,
  93, 10, 83, 117, 98, 95, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110,
  95, 66, 105, 97, 115, 58, 10, 45, 100, 105, 118, 91, 45, 49, 93, 32,
  50, 53, 53, 10, 45, 45, 115, 112, 108, 105, 116, 91, 48, 93, 32, 99,
  10, 45, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 44, 45, 51,
  93, 32, 97, 118, 101, 114, 97, 103, 101, 10, 45, 115, 112, 108, 105, 116,
  91, 48, 93, 32, 99, 10, 45, 114, 109, 91, 48, 93, 10, 45, 45, 115,
  117, 98, 91, 48, 93, 32, 91, 49, 93, 10, 45, 114, 109, 91, 49, 93,
  10, 45, 45, 115, 117, 98, 91, 48, 93, 32, 91, 49, 93, 10, 45, 114,
  109, 91, 49, 93, 10, 45, 45, 115, 117, 98, 91, 48, 93, 32, 91, 49,
  93, 10, 45, 114, 109, 91, 49, 93, 10, 45, 114, 109, 91, 48, 93, 10,
  45, 112, 111, 119, 91, 48, 93, 32, 50, 10, 45, 112, 111, 119, 91, 49,
  93, 32, 50, 10, 45, 112, 111, 119, 91, 50, 93, 32, 50, 10, 45, 97,
  100, 100, 91, 49, 93, 32, 91, 50, 93, 10, 45, 114, 109, 91, 50, 93,
  10, 45, 97, 100, 100, 91, 48, 93, 32, 91, 49, 93, 10, 45, 114, 109,
  91, 49, 93, 10, 45, 115, 113, 114, 116, 91, 48, 93, 10, 83, 117, 98,
  95, 69, 120, 112, 111, 115, 117, 114, 101, 95, 66, 105, 97, 115, 32, 58,
  10, 45, 100, 105, 118, 91, 48, 93, 32, 50, 53, 53, 10, 45, 115, 117,
  98, 91, 48, 93, 32, 48, 46, 53, 10, 45, 112, 111, 119, 91, 48, 93,
  32, 50, 10, 45, 100, 105, 118, 91, 48, 93, 32, 123, 50, 42, 36, 49,
  42, 36, 49, 125, 10, 45, 109, 117, 108, 91, 48, 93, 32, 45, 49, 10,
  45, 101, 120, 112, 91, 48, 93, 10, 45, 115, 112, 108, 105, 116, 91, 48,
  93, 32, 99, 10, 45, 109, 117, 108, 91, 48, 93, 32, 91, 50, 93, 10,
  45, 114, 109, 91, 50, 93, 10, 45, 109, 117, 108, 91, 48, 93, 32, 91,
  49, 93, 10, 45, 114, 109, 91, 49, 93, 10, 83, 117, 98, 95, 66, 108,
  117, 114, 80, 121, 114, 97, 109, 105, 100, 32, 58, 10, 115, 105, 122, 101,
  61, 123, 109, 105, 110, 40, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48,
  44, 104, 125, 41, 125, 10, 108, 101, 118, 101, 108, 115, 61, 123, 114, 111,
  117, 110, 100, 40, 108, 111, 103, 40, 36, 115, 105, 122, 101, 41, 47, 108,
  111, 103, 40, 53, 41, 41, 125, 10, 68, 101, 118, 105, 97, 116, 105, 111,
  110, 61, 49, 10, 45, 98, 108, 117, 114, 91, 48, 93, 32, 36, 68, 101,
  118, 105, 97, 116, 105, 111, 110, 44, 49, 44, 49, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 36, 108, 101, 118, 101, 108, 115, 45, 49, 125, 10,
  45, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 53, 48, 37,
  44, 53, 48, 37, 44, 53, 44, 49, 10, 45, 98, 108, 117, 114, 91, 45,
  49, 93, 32, 36, 68, 101, 118, 105, 97, 116, 105, 111, 110, 44, 49, 44,
  49, 10, 45, 100, 111, 110, 101, 10, 98, 108, 110, 100, 97, 108, 112, 104,
  97, 61, 48, 46, 53, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36,
  108, 101, 118, 101, 108, 115, 45, 49, 125, 10, 105, 110, 100, 101, 120, 61,
  123, 45, 49, 42, 40, 64, 123, 60, 44, 48, 125, 43, 49, 41, 125, 10,
  45, 114, 101, 115, 105, 122, 101, 91, 36, 105, 110, 100, 101, 120, 93, 32,
  91, 48, 93, 44, 53, 44, 49, 10, 45, 98, 108, 101, 110, 100, 91, 48,
  44, 36, 105, 110, 100, 101, 120, 93, 32, 97, 108, 112, 104, 97, 44, 36,
  98, 108, 110, 100, 97, 108, 112, 104, 97, 44, 48, 10, 98, 108, 110, 100,
  97, 108, 112, 104, 97, 61, 123, 36, 98, 108, 110, 100, 97, 108, 112, 104,
  97, 47, 50, 125, 10, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95,
  69, 120, 112, 111, 115, 117, 114, 101, 87, 101, 105, 103, 104, 116, 77, 97,
  112, 32, 58, 10, 119, 99, 61, 36, 49, 10, 119, 115, 61, 36, 50, 10,
  115, 105, 103, 109, 97, 61, 36, 51, 10, 119, 101, 61, 36, 52, 10, 66,
  108, 117, 114, 77, 97, 112, 61, 36, 53, 10, 45, 116, 111, 95, 114, 103,
  98, 91, 48, 93, 10, 45, 45, 83, 117, 98, 95, 67, 111, 110, 116, 114,
  97, 115, 116, 95, 66, 105, 97, 115, 91, 48, 93, 10, 45, 45, 83, 117,
  98, 95, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 95, 66, 105, 97,
  115, 91, 48, 93, 10, 45, 45, 83, 117, 98, 95, 69, 120, 112, 111, 115,
  117, 114, 101, 95, 66, 105, 97, 115, 91, 48, 93, 32, 36, 115, 105, 103,
  109, 97, 10, 45, 114, 109, 91, 48, 93, 10, 45, 112, 111, 119, 91, 48,
  93, 32, 36, 119, 99, 10, 45, 112, 111, 119, 91, 49, 93, 32, 36, 119,
  115, 10, 45, 112, 111, 119, 91, 50, 93, 32, 36, 119, 101, 10, 45, 97,
  100, 100, 91, 48, 93, 32, 91, 49, 93, 10, 45, 97, 100, 100, 91, 48,
  93, 32, 91, 50, 93, 10, 45, 107, 101, 101, 112, 91, 48, 93, 10, 45,
  110, 111, 114, 109, 97, 108, 105, 122, 101, 91, 48, 93, 32, 48, 44, 50,
  53, 53, 10, 45, 105, 102, 32, 123, 36, 66, 108, 117, 114, 77, 97, 112,
  61, 61, 49, 125, 10, 45, 83, 117, 98, 95, 66, 108, 117, 114, 80, 121,
  114, 97, 109, 105, 100, 91, 48, 93, 10, 45, 101, 110, 100, 105, 102, 10,
  103, 105, 109, 112, 95, 69, 120, 112, 111, 115, 117, 114, 101, 87, 101, 105,
  103, 104, 116, 77, 97, 112, 80, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 69, 120, 112, 111, 115,
  117, 114, 101, 87, 101, 105, 103, 104, 116, 77, 97, 112, 32, 36, 123, 49,
  45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112,
  32, 71, 109, 105, 99, 32, 115, 116, 114, 117, 99, 116, 117, 114, 101, 32,
  116, 101, 110, 115, 111, 114, 115, 32, 58, 32, 103, 105, 109, 112, 95, 83,
  116, 114, 117, 99, 116, 117, 114, 101, 84, 101, 110, 115, 111, 114, 115, 44,
  32, 103, 105, 109, 112, 95, 83, 116, 114, 117, 99, 116, 117, 114, 101, 84,
  101, 110, 115, 111, 114, 115, 80, 114, 101, 118, 105, 101, 119, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 83, 116, 114, 117, 99, 116, 117, 114, 101, 32, 116, 101, 110, 115,
  111, 114, 115, 32, 99, 97, 108, 99, 117, 108, 97, 116, 105, 111, 110, 32,
  102, 111, 114, 32, 71, 105, 109, 112, 32, 112, 108, 117, 103, 105, 110, 46,
  32, 84, 104, 105, 115, 32, 105, 115, 32, 106, 117, 115, 116, 32, 97, 110,
  32, 105, 110, 116, 101, 114, 102, 97, 99, 101, 32, 116, 111, 32, 98, 117,
  105, 108, 116, 32, 105, 110, 32, 71, 77, 105, 99, 32, 83, 116, 114, 117,
  99, 116, 117, 114, 101, 32, 116, 101, 110, 115, 111, 114, 115, 32, 99, 111,
  109, 109, 97, 110, 100, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 80, 111, 119, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  46, 49, 44, 48, 46, 49, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121,
  112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60,
  105, 62, 65, 114, 116, 111, 32, 72, 117, 111, 116, 97, 114, 105, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 49,
  47, 49, 50, 47, 48, 54, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 70, 105, 108, 116,
  101, 114, 32, 69, 120, 112, 108, 97, 105, 110, 101, 100, 32, 104, 101, 114,
  101, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 103, 109, 105, 99, 46,
  115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116, 47,
  114, 101, 102, 101, 114, 101, 110, 99, 101, 46, 115, 104, 116, 109, 108, 34,
  41, 10, 103, 105, 109, 112, 95, 83, 116, 114, 117, 99, 116, 117, 114, 101,
  84, 101, 110, 115, 111, 114, 115, 58, 10, 45, 115, 116, 114, 117, 99, 116,
  117, 114, 101, 116, 101, 110, 115, 111, 114, 115, 32, 45, 97, 98, 115, 32,
  45, 112, 111, 119, 32, 36, 49, 10, 45, 110, 111, 114, 109, 97, 108, 105,
  122, 101, 32, 48, 44, 50, 53, 53, 10, 103, 105, 109, 112, 95, 83, 116,
  114, 117, 99, 116, 117, 114, 101, 84, 101, 110, 115, 111, 114, 115, 80, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112,
  108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105,
  109, 112, 95, 83, 116, 114, 117, 99, 116, 117, 114, 101, 84, 101, 110, 115,
  111, 114, 115, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 73, 109, 112, 111, 114, 116, 32, 49,
  54, 98, 105, 116, 32, 105, 109, 97, 103, 101, 32, 58, 32, 103, 105, 109,
  112, 95, 105, 109, 112, 111, 114, 116, 95, 105, 109, 97, 103, 101, 95, 49,
  54, 44, 32, 103, 105, 109, 112, 95, 105, 109, 112, 111, 114, 116, 95, 105,
  109, 97, 103, 101, 95, 49, 54, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 70, 105,
  108, 116, 101, 114, 32, 99, 97, 110, 32, 98, 101, 32, 117, 115, 101, 100,
  32, 116, 111, 32, 105, 109, 112, 111, 114, 116, 32, 97, 110, 100, 32, 97,
  100, 106, 117, 115, 116, 32, 49, 54, 32, 98, 105, 116, 32, 105, 109, 97,
  103, 101, 115, 32, 116, 111, 32, 71, 105, 109, 112, 46, 32, 84, 104, 105,
  115, 32, 102, 105, 108, 116, 101, 114, 32, 114, 101, 112, 108, 97, 99, 101,
  115, 32, 116, 104, 101, 32, 112, 114, 101, 118, 105, 111, 117, 115, 32, 49,
  54, 32, 98, 105, 116, 32, 99, 104, 97, 110, 110, 101, 108, 32, 112, 114,
  111, 99, 101, 115, 115, 105, 110, 103, 32, 112, 114, 111, 116, 111, 116, 121,
  112, 101, 46, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 49, 46, 32, 67,
  114, 101, 97, 116, 101, 32, 110, 101, 119, 32, 101, 109, 112, 116, 121, 32,
  105, 109, 97, 103, 101, 32, 116, 111, 32, 71, 105, 109, 112, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 50, 46, 32, 79, 112, 101, 110, 32, 71, 39,
  77, 105, 99, 32, 102, 114, 111, 109, 32, 102, 105, 108, 116, 101, 114, 115,
  32, 109, 101, 110, 117, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 51, 46,
  32, 83, 101, 116, 32, 71, 39, 77, 105, 99, 32, 111, 117, 116, 112, 117,
  116, 32, 116, 111, 32, 34, 110, 101, 119, 32, 108, 97, 121, 101, 114, 115,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 52, 46, 32, 83, 101, 108, 101,
  99, 116, 32, 49, 54, 32, 98, 105, 116, 32, 116, 105, 102, 102, 32, 105,
  109, 97, 103, 101, 32, 102, 114, 111, 109, 32, 102, 111, 108, 100, 101, 114,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 53, 46, 32, 77, 97, 107, 101,
  32, 97, 100, 106, 117, 115, 116, 109, 101, 110, 116, 115, 32, 117, 115, 105,
  110, 103, 32, 115, 108, 105, 100, 101, 114, 115, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 54, 46, 32, 73, 109, 97, 103, 101, 32, 119, 105, 108, 108,
  32, 98, 101, 32, 111, 117, 116, 112, 117, 116, 116, 101, 100, 32, 116, 111,
  32, 71, 105, 109, 112, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 80, 114,
  101, 118, 105, 101, 119, 32, 111, 110, 108, 121, 32, 112, 114, 111, 99, 101,
  115, 115, 101, 115, 32, 115, 99, 97, 108, 101, 100, 32, 100, 111, 119, 110,
  32, 105, 109, 97, 103, 101, 46, 32, 66, 101, 102, 111, 114, 101, 32, 112,
  114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 102, 117, 108, 108, 32, 115,
  105, 122, 101, 32, 100, 105, 115, 97, 98, 108, 101, 32, 112, 114, 101, 118,
  105, 101, 119, 32, 119, 105, 110, 100, 111, 119, 32, 102, 114, 111, 109, 32,
  103, 117, 105, 46, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 85, 115, 101,
  32, 103, 97, 109, 109, 97, 32, 116, 111, 32, 97, 100, 106, 117, 115, 116,
  32, 112, 101, 114, 99, 101, 105, 118, 101, 100, 32, 98, 114, 105, 103, 104,
  116, 110, 101, 115, 115, 32, 97, 110, 100, 32, 98, 114, 105, 103, 104, 116,
  110, 101, 115, 115, 32, 116, 111, 32, 97, 100, 106, 117, 115, 116, 32, 114,
  101, 108, 97, 116, 105, 118, 101, 32, 115, 116, 97, 114, 116, 32, 112, 111,
  105, 110, 116, 32, 111, 102, 32, 104, 105, 115, 116, 111, 103, 114, 97, 109,
  46, 32, 67, 111, 110, 116, 114, 97, 115, 116, 32, 97, 100, 106, 117, 115,
  116, 115, 32, 102, 111, 114, 32, 119, 105, 100, 116, 104, 32, 111, 102, 32,
  104, 105, 115, 116, 111, 114, 103, 114, 97, 109, 46, 32, 78, 111, 116, 101,
  32, 115, 108, 105, 100, 101, 114, 115, 32, 119, 105, 108, 108, 32, 110, 111,
  116, 32, 104, 97, 118, 101, 32, 97, 110, 121, 32, 101, 102, 102, 101, 99,
  116, 32, 105, 102, 32, 116, 104, 101, 32, 105, 109, 97, 103, 101, 32, 100,
  111, 101, 115, 32, 110, 111, 116, 32, 104, 97, 118, 101, 32, 112, 105, 120,
  101, 108, 32, 118, 97, 108, 117, 101, 115, 32, 111, 118, 101, 114, 32, 50,
  53, 54, 46, 32, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 32, 98,
  111, 111, 115, 116, 115, 32, 98, 111, 116, 104, 32, 65, 45, 66, 32, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 97, 110, 100, 32, 65, 44, 32, 66,
  32, 115, 108, 105, 100, 101, 114, 115, 32, 98, 111, 111, 115, 116, 32, 105,
  110, 100, 105, 118, 105, 100, 117, 97, 108, 32, 65, 47, 66, 32, 99, 104,
  97, 110, 110, 101, 108, 115, 46, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 73, 110, 112, 117, 116, 32, 105, 109, 97, 103, 101, 32, 61,
  32, 102, 105, 108, 101, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 80, 114, 101, 118, 105, 101, 119, 32, 111, 110, 108, 121, 32, 61, 32,
  98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 104, 111, 119, 32, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32,
  61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 71, 97, 109, 109, 97, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 46, 50, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 66, 114, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116, 114, 97, 115, 116, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 51, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 97, 116, 117, 114, 97, 116, 105,
  111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 40, 114,
  45, 103, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 40, 121,
  45, 98, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 113, 117,
  97, 108, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  65, 114, 116, 111, 32, 72, 117, 111, 116, 97, 114, 105, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48,
  50, 47, 49, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 103, 105, 109, 112, 95, 105, 109, 112, 111, 114, 116, 95,
  105, 109, 97, 103, 101, 95, 49, 54, 32, 58, 10, 80, 114, 101, 118, 105,
  101, 119, 79, 110, 108, 121, 61, 36, 50, 10, 83, 104, 111, 119, 72, 105,
  115, 116, 111, 103, 114, 97, 109, 61, 36, 51, 10, 71, 97, 109, 109, 97,
  61, 36, 52, 10, 66, 114, 105, 103, 104, 116, 110, 101, 115, 115, 61, 36,
  53, 10, 67, 111, 110, 116, 114, 97, 115, 116, 61, 36, 54, 10, 65, 66,
  61, 36, 55, 10, 65, 61, 36, 56, 10, 66, 61, 36, 57, 10, 69, 113,
  117, 97, 108, 105, 122, 101, 61, 36, 49, 48, 10, 45, 114, 109, 32, 45,
  105, 10, 36, 49, 10, 45, 116, 111, 95, 114, 103, 98, 10, 45, 105, 102,
  32, 36, 80, 114, 101, 118, 105, 101, 119, 79, 110, 108, 121, 10, 45, 114,
  101, 115, 105, 122, 101, 50, 100, 120, 32, 53, 50, 48, 44, 49, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 97, 112, 112, 108, 121, 95, 103, 97, 109,
  109, 97, 32, 36, 71, 97, 109, 109, 97, 10, 45, 105, 102, 32, 123, 64,
  123, 48, 44, 77, 125, 62, 50, 53, 54, 125, 10, 45, 105, 102, 32, 36,
  69, 113, 117, 97, 108, 105, 122, 101, 10, 45, 45, 101, 113, 117, 97, 108,
  105, 122, 101, 32, 54, 53, 53, 51, 53, 10, 45, 98, 108, 101, 110, 100,
  32, 97, 108, 112, 104, 97, 44, 123, 36, 69, 113, 117, 97, 108, 105, 122,
  101, 47, 50, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 100, 105, 118,
  32, 54, 53, 53, 51, 53, 10, 45, 114, 103, 98, 50, 108, 97, 98, 10,
  45, 115, 112, 108, 105, 116, 32, 99, 10, 45, 105, 102, 32, 36, 66, 114,
  105, 103, 104, 116, 110, 101, 115, 115, 10, 45, 97, 100, 100, 91, 45, 51,
  93, 32, 36, 66, 114, 105, 103, 104, 116, 110, 101, 115, 115, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 67, 111, 110, 116, 114,
  97, 115, 116, 33, 61, 49, 125, 10, 45, 109, 117, 108, 91, 45, 51, 93,
  32, 36, 67, 111, 110, 116, 114, 97, 115, 116, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 36, 65, 66, 10, 45, 109, 117, 108, 91, 45,
  50, 93, 32, 36, 65, 66, 10, 45, 109, 117, 108, 91, 45, 49, 93, 32,
  36, 65, 66, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36,
  65, 10, 45, 109, 117, 108, 91, 45, 50, 93, 32, 123, 49, 43, 36, 65,
  125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 66, 10,
  45, 109, 117, 108, 91, 45, 49, 93, 32, 123, 49, 43, 36, 66, 125, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 97, 112, 112, 101, 110, 100, 32, 99,
  10, 45, 108, 97, 98, 50, 114, 103, 98, 10, 45, 109, 117, 108, 32, 50,
  53, 53, 10, 45, 99, 117, 116, 32, 48, 44, 50, 53, 53, 10, 45, 105,
  102, 32, 36, 80, 114, 101, 118, 105, 101, 119, 79, 110, 108, 121, 10, 45,
  105, 102, 32, 36, 83, 104, 111, 119, 72, 105, 115, 116, 111, 103, 114, 97,
  109, 10, 45, 45, 100, 105, 115, 112, 108, 97, 121, 95, 104, 105, 115, 116,
  111, 103, 114, 97, 109, 32, 64, 123, 48, 44, 119, 125, 44, 64, 123, 48,
  44, 104, 125, 44, 50, 53, 53, 44, 48, 44, 50, 53, 52, 44, 48, 10,
  45, 98, 108, 101, 110, 100, 32, 108, 105, 103, 104, 116, 101, 110, 44, 48,
  46, 55, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103, 105, 109, 112, 32, 77,
  97, 107, 101, 32, 111, 108, 100, 32, 115, 113, 117, 105, 103, 103, 108, 121,
  32, 58, 32, 103, 105, 109, 112, 95, 79, 108, 100, 83, 113, 117, 105, 103,
  103, 108, 121, 44, 32, 103, 105, 109, 112, 95, 79, 108, 100, 83, 113, 117,
  105, 103, 103, 108, 121, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 68, 101, 118, 101,
  108, 111, 112, 109, 101, 110, 116, 32, 118, 101, 114, 115, 105, 111, 110, 46,
  32, 84, 104, 105, 115, 32, 118, 101, 114, 115, 105, 111, 110, 32, 119, 105,
  108, 108, 32, 98, 101, 32, 114, 101, 109, 111, 118, 101, 100, 32, 105, 110,
  32, 102, 117, 116, 117, 114, 101, 32, 102, 114, 111, 109, 32, 115, 111, 117,
  114, 99, 101, 115, 32, 115, 111, 32, 105, 102, 32, 121, 111, 117, 32, 112,
  114, 101, 102, 101, 114, 32, 116, 104, 105, 115, 32, 116, 104, 101, 110, 32,
  99, 111, 112, 121, 32, 97, 110, 100, 32, 115, 97, 118, 101, 32, 116, 104,
  101, 32, 115, 111, 117, 114, 99, 101, 32, 116, 111, 32, 121, 111, 117, 114,
  32, 108, 111, 99, 97, 108, 32, 46, 103, 109, 105, 99, 32, 102, 105, 108,
  101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 114,
  101, 97, 100, 32, 110, 111, 105, 115, 101, 32, 97, 109, 111, 117, 110, 116,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 44, 50, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 103, 109, 101, 110,
  116, 97, 116, 105, 111, 110, 32, 101, 100, 103, 101, 32, 116, 104, 114, 101,
  115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 50,
  44, 48, 44, 49, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111, 110, 32, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 56, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 71, 114, 97, 100, 105, 101, 110, 110, 111, 114, 109, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 71, 114, 97, 100, 105, 101, 110, 110, 111, 114, 109, 108, 105, 110, 101,
  97, 114, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  53, 44, 48, 44, 49, 46, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 73, 110, 99, 114, 101, 97, 115, 101, 99, 104, 114, 111, 109, 97,
  49, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44, 49, 44, 52, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 111, 110, 101, 32, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 50, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 84, 111, 110, 101, 32, 103, 97, 109, 109, 97, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 52, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 112, 101, 114, 32, 103, 114,
  97, 121, 110, 101, 115, 115, 32, 61, 32, 105, 110, 116, 40, 53, 48, 44,
  48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  80, 97, 112, 101, 114, 32, 119, 104, 105, 116, 101, 110, 101, 115, 115, 32,
  61, 32, 105, 110, 116, 40, 50, 52, 53, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 113, 117, 105, 103, 103,
  108, 101, 32, 103, 97, 109, 109, 97, 32, 61, 32, 105, 110, 116, 40, 52,
  53, 44, 49, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 113, 117, 105, 103, 103, 108, 101, 32, 109, 117, 108, 116, 105,
  112, 108, 105, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  53, 44, 48, 44, 49, 41, 10, 103, 105, 109, 112, 95, 79, 108, 100, 83,
  113, 117, 105, 103, 103, 108, 121, 32, 58, 10, 45, 45, 103, 105, 109, 112,
  95, 115, 112, 114, 101, 97, 100, 91, 48, 93, 32, 36, 49, 44, 36, 49,
  44, 48, 44, 48, 10, 45, 103, 105, 109, 112, 95, 115, 101, 103, 109, 101,
  110, 116, 95, 119, 97, 116, 101, 114, 115, 104, 101, 100, 91, 49, 93, 32,
  36, 50, 44, 36, 51, 44, 48, 44, 48, 10, 45, 45, 103, 105, 109, 112,
  95, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 91, 49,
  93, 32, 36, 52, 44, 36, 53, 44, 48, 44, 49, 48, 48, 44, 48, 44,
  48, 10, 45, 45, 98, 108, 101, 110, 100, 91, 50, 44, 49, 93, 32, 109,
  117, 108, 116, 105, 112, 108, 121, 10, 45, 103, 105, 109, 112, 95, 109, 105,
  120, 95, 121, 99, 98, 99, 114, 91, 51, 93, 32, 49, 44, 48, 44, 48,
  44, 36, 54, 44, 48, 44, 48, 44, 36, 54, 44, 48, 44, 48, 44, 48,
  44, 50, 44, 48, 10, 45, 103, 105, 109, 112, 95, 109, 97, 112, 95, 116,
  111, 110, 101, 115, 91, 48, 93, 32, 36, 55, 44, 36, 56, 44, 48, 46,
  49, 44, 51, 48, 44, 48, 44, 48, 10, 45, 98, 108, 101, 110, 100, 91,
  48, 44, 51, 93, 32, 100, 97, 114, 107, 101, 110, 10, 45, 114, 101, 109,
  111, 118, 101, 91, 49, 44, 50, 93, 10, 45, 45, 103, 105, 109, 112, 95,
  112, 108, 97, 115, 109, 97, 32, 48, 46, 53, 44, 49, 48, 44, 56, 44,
  48, 10, 45, 103, 105, 109, 112, 95, 98, 108, 97, 99, 107, 97, 110, 100,
  119, 104, 105, 116, 101, 91, 49, 93, 32, 48, 46, 50, 57, 57, 44, 48,
  44, 48, 46, 53, 56, 55, 44, 48, 44, 48, 46, 49, 49, 52, 44, 48,
  44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 50, 44, 48, 44, 48, 44, 48, 44, 49, 54, 44, 52, 44, 48, 44,
  48, 44, 48, 10, 45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95,
  99, 117, 114, 118, 101, 91, 49, 93, 32, 36, 57, 44, 45, 49, 44, 49,
  50, 56, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50, 56,
  44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50, 56, 44, 36,
  49, 48, 44, 49, 44, 51, 44, 48, 44, 48, 44, 48, 10, 45, 103, 105,
  109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 48,
  93, 32, 48, 44, 36, 49, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49,
  50, 56, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50, 56,
  44, 45, 49, 44, 49, 50, 56, 44, 50, 53, 53, 44, 49, 44, 51, 44,
  48, 44, 48, 44, 48, 10, 45, 109, 117, 108, 91, 48, 93, 32, 123, 48,
  46, 53, 42, 40, 49, 43, 36, 49, 50, 41, 125, 10, 45, 109, 117, 108,
  91, 49, 93, 32, 123, 48, 46, 53, 42, 40, 49, 45, 36, 49, 50, 41,
  125, 10, 45, 45, 97, 100, 100, 91, 48, 93, 32, 91, 49, 93, 10, 45,
  45, 98, 108, 101, 110, 100, 91, 48, 44, 50, 93, 32, 115, 111, 102, 116,
  108, 105, 103, 104, 116, 10, 45, 114, 101, 109, 111, 118, 101, 91, 48, 44,
  49, 44, 50, 93, 10, 35, 64, 103, 105, 109, 112, 32, 77, 97, 112, 112,
  101, 100, 32, 115, 109, 111, 111, 116, 104, 105, 110, 103, 32, 58, 32, 103,
  105, 109, 112, 95, 77, 97, 112, 112, 101, 100, 83, 109, 111, 111, 116, 104,
  44, 32, 103, 105, 109, 112, 95, 77, 97, 112, 112, 101, 100, 83, 109, 111,
  111, 116, 104, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 110, 111,
  116, 101, 40, 34, 84, 119, 111, 32, 108, 97, 121, 101, 114, 115, 32, 114,
  101, 113, 117, 105, 114, 101, 100, 32, 105, 102, 32, 97, 117, 116, 111, 109,
  97, 112, 32, 105, 115, 32, 110, 111, 116, 32, 117, 115, 101, 100, 46, 32,
  60, 98, 62, 83, 101, 116, 32, 105, 110, 112, 117, 116, 32, 116, 111, 32,
  97, 99, 116, 105, 118, 101, 32, 97, 110, 100, 32, 98, 101, 108, 111, 119,
  60, 47, 98, 62, 46, 32, 70, 105, 108, 116, 101, 114, 32, 83, 109, 111,
  111, 116, 104, 115, 32, 105, 109, 97, 103, 101, 32, 119, 105, 116, 104, 32,
  97, 32, 118, 101, 99, 116, 111, 114, 32, 102, 105, 101, 108, 100, 32, 109,
  97, 112, 46, 32, 77, 97, 112, 32, 105, 115, 32, 99, 114, 101, 97, 116,
  101, 100, 32, 102, 114, 111, 109, 32, 82, 32, 97, 110, 100, 32, 71, 32,
  99, 104, 97, 110, 110, 101, 108, 115, 32, 115, 111, 32, 116, 104, 97, 116,
  32, 82, 49, 50, 56, 44, 71, 49, 50, 56, 32, 98, 101, 99, 111, 109,
  101, 115, 32, 91, 48, 32, 48, 93, 46, 32, 69, 120, 112, 101, 114, 105,
  109, 101, 110, 116, 32, 119, 105, 116, 104, 32, 115, 111, 108, 105, 100, 32,
  49, 50, 56, 44, 49, 50, 56, 44, 48, 32, 99, 111, 108, 111, 114, 32,
  108, 97, 121, 101, 114, 32, 97, 110, 100, 32, 97, 100, 100, 32, 104, 117,
  101, 115, 32, 111, 102, 32, 114, 101, 100, 32, 97, 110, 100, 32, 103, 114,
  101, 101, 110, 46, 32, 65, 110, 103, 108, 101, 32, 115, 104, 105, 102, 116,
  32, 114, 111, 116, 97, 116, 101, 115, 32, 116, 104, 101, 32, 118, 101, 99,
  116, 111, 114, 32, 102, 105, 101, 108, 100, 32, 97, 110, 100, 32, 90, 101,
  114, 111, 32, 112, 111, 105, 110, 116, 32, 111, 102, 102, 115, 101, 116, 32,
  109, 111, 118, 101, 115, 32, 116, 104, 101, 32, 100, 101, 102, 97, 117, 108,
  116, 32, 48, 32, 48, 32, 112, 111, 105, 110, 116, 46, 32, 84, 104, 105,
  115, 32, 105, 115, 32, 115, 111, 109, 101, 119, 104, 97, 116, 32, 97, 32,
  100, 101, 118, 101, 108, 111, 112, 109, 101, 110, 116, 32, 118, 101, 114, 115,
  105, 111, 110, 44, 32, 115, 97, 109, 112, 108, 101, 32, 97, 114, 116, 32,
  105, 115, 32, 115, 116, 105, 108, 108, 32, 109, 105, 115, 115, 105, 110, 103,
  46, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 77, 97, 112, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 117, 116, 111, 109,
  97, 112, 34, 44, 34, 76, 97, 121, 101, 114, 32, 77, 97, 112, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32,
  115, 104, 105, 102, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  45, 49, 56, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 90, 101, 114, 111, 32, 112, 111, 105, 110, 116, 32, 111, 102,
  102, 115, 101, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45,
  49, 50, 56, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 51, 48, 48, 44, 49, 48, 44, 49, 48, 48, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 101, 99, 116, 111,
  114, 32, 108, 101, 110, 103, 116, 104, 32, 109, 117, 108, 116, 105, 112, 108,
  101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 46, 49,
  44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 79, 112, 116, 105, 111, 110, 97, 108, 32, 118, 105,
  101, 119, 105, 110, 103, 32, 111, 102, 32, 118, 101, 99, 116, 111, 114, 32,
  102, 105, 101, 108, 100, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 104, 111, 119, 32, 113, 117, 105, 118, 101, 114, 32, 61, 32, 98,
  111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32,
  60, 105, 62, 65, 114, 116, 111, 32, 72, 117, 111, 116, 97, 114, 105, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49,
  50, 47, 48, 50, 47, 50, 53, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 77, 97, 112, 112,
  101, 100, 83, 109, 111, 111, 116, 104, 32, 58, 10, 77, 97, 112, 84, 121,
  112, 101, 61, 36, 49, 10, 102, 105, 61, 123, 36, 50, 42, 51, 46, 49,
  52, 49, 53, 47, 49, 56, 48, 125, 10, 90, 101, 114, 111, 79, 102, 102,
  115, 101, 116, 61, 36, 51, 10, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  61, 36, 52, 10, 76, 77, 117, 108, 116, 61, 36, 53, 10, 83, 104, 111,
  119, 81, 117, 105, 118, 101, 114, 61, 36, 54, 10, 45, 105, 102, 32, 123,
  36, 77, 97, 112, 84, 121, 112, 101, 61, 61, 48, 125, 10, 45, 45, 103,
  105, 109, 112, 95, 108, 111, 99, 97, 108, 95, 111, 114, 105, 101, 110, 116,
  97, 116, 105, 111, 110, 32, 48, 46, 53, 44, 48, 44, 49, 48, 48, 44,
  48, 44, 52, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 99, 111, 115,
  102, 105, 61, 123, 99, 111, 115, 40, 36, 102, 105, 41, 125, 10, 115, 105,
  110, 102, 105, 61, 123, 115, 105, 110, 40, 36, 102, 105, 41, 125, 10, 45,
  116, 111, 95, 114, 103, 98, 91, 45, 50, 44, 45, 49, 93, 10, 45, 45,
  91, 45, 49, 93, 32, 123, 49, 50, 56, 43, 36, 90, 101, 114, 111, 79,
  102, 102, 115, 101, 116, 125, 10, 45, 115, 112, 108, 105, 116, 91, 45, 49,
  93, 32, 99, 10, 45, 109, 117, 108, 91, 51, 93, 32, 48, 10, 45, 45,
  109, 117, 108, 91, 49, 93, 32, 36, 99, 111, 115, 102, 105, 10, 45, 45,
  109, 117, 108, 91, 50, 93, 32, 36, 115, 105, 110, 102, 105, 10, 45, 115,
  117, 98, 91, 52, 93, 32, 91, 53, 93, 10, 45, 114, 109, 91, 53, 93,
  10, 45, 45, 109, 117, 108, 91, 49, 93, 32, 36, 115, 105, 110, 102, 105,
  10, 45, 45, 109, 117, 108, 91, 50, 93, 32, 36, 99, 111, 115, 102, 105,
  10, 45, 97, 100, 100, 91, 53, 93, 32, 91, 54, 93, 10, 45, 114, 109,
  91, 54, 93, 10, 45, 114, 109, 91, 49, 44, 50, 93, 10, 45, 114, 109,
  91, 49, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48,
  48, 37, 44, 49, 44, 48, 10, 45, 97, 112, 112, 101, 110, 100, 91, 49,
  44, 50, 44, 51, 93, 32, 99, 10, 45, 47, 91, 45, 49, 93, 32, 123,
  49, 50, 56, 47, 36, 76, 77, 117, 108, 116, 125, 10, 45, 99, 104, 97,
  110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 44, 49, 10, 45, 105,
  102, 32, 123, 36, 83, 104, 111, 119, 81, 117, 105, 118, 101, 114, 61, 61,
  48, 125, 10, 45, 118, 101, 99, 116, 111, 114, 50, 116, 101, 110, 115, 111,
  114, 91, 45, 49, 93, 10, 45, 115, 109, 111, 111, 116, 104, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 44, 36, 65, 109, 112, 108, 105, 116, 117, 100,
  101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 83,
  104, 111, 119, 81, 117, 105, 118, 101, 114, 61, 61, 49, 125, 10, 45, 113,
  117, 105, 118, 101, 114, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 49,
  48, 44, 123, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 47, 50, 48,
  125, 44, 49, 44, 48, 46, 56, 44, 50, 53, 53, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 114, 109, 91, 45, 49, 93, 10, 35, 64, 103, 105, 109,
  112, 32, 78, 105, 103, 104, 116, 32, 104, 100, 114, 32, 105, 109, 97, 103,
  101, 32, 98, 108, 97, 99, 107, 32, 110, 111, 105, 115, 101, 32, 99, 111,
  114, 114, 101, 99, 116, 105, 111, 110, 32, 58, 32, 103, 105, 109, 112, 95,
  102, 105, 120, 95, 72, 68, 82, 95, 98, 108, 97, 99, 107, 44, 32, 103,
  105, 109, 112, 95, 102, 105, 120, 95, 72, 68, 82, 95, 98, 108, 97, 99,
  107, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 110, 111, 116, 101,
  40, 34, 70, 105, 108, 116, 101, 114, 32, 116, 111, 32, 114, 101, 109, 111,
  118, 101, 32, 98, 108, 117, 101, 44, 32, 109, 97, 103, 101, 110, 116, 97,
  32, 97, 110, 100, 32, 114, 101, 100, 32, 110, 111, 105, 115, 101, 32, 102,
  114, 111, 109, 32, 116, 104, 101, 32, 98, 108, 97, 99, 107, 32, 97, 114,
  101, 97, 115, 32, 111, 102, 32, 72, 68, 82, 32, 105, 109, 97, 103, 101,
  115, 46, 32, 70, 105, 108, 116, 101, 114, 32, 105, 115, 32, 100, 101, 115,
  105, 103, 110, 101, 100, 32, 115, 112, 101, 99, 105, 102, 105, 99, 97, 108,
  108, 121, 32, 102, 111, 114, 32, 72, 68, 82, 32, 110, 105, 103, 104, 116,
  32, 115, 104, 111, 116, 115, 32, 98, 117, 116, 32, 109, 97, 121, 32, 119,
  111, 114, 107, 32, 111, 110, 32, 111, 116, 104, 101, 114, 32, 105, 109, 97,
  103, 101, 115, 32, 97, 115, 32, 119, 101, 108, 108, 46, 32, 66, 105, 108,
  97, 116, 101, 114, 97, 108, 32, 102, 105, 108, 116, 101, 114, 105, 110, 103,
  32, 97, 110, 100, 32, 72, 97, 97, 114, 32, 87, 97, 118, 101, 108, 101,
  116, 115, 32, 97, 114, 101, 32, 117, 115, 101, 100, 32, 116, 111, 32, 102,
  105, 108, 116, 101, 114, 32, 116, 104, 101, 32, 110, 111, 105, 115, 101, 32,
  102, 114, 111, 109, 32, 116, 104, 101, 32, 105, 109, 97, 103, 101, 32, 97,
  110, 100, 32, 109, 97, 115, 107, 32, 105, 115, 32, 117, 115, 101, 100, 32,
  116, 111, 32, 97, 112, 112, 108, 121, 32, 116, 104, 101, 32, 110, 111, 105,
  115, 101, 32, 114, 101, 109, 111, 118, 97, 108, 32, 111, 110, 108, 121, 32,
  116, 111, 32, 100, 97, 114, 107, 32, 97, 114, 101, 97, 115, 46, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 61, 110, 111, 116, 101, 40, 34, 77, 97, 115, 107, 32, 111, 112, 97,
  99, 105, 116, 121, 32, 115, 101, 116, 116, 105, 110, 103, 115, 44, 32, 66,
  108, 97, 99, 107, 32, 118, 97, 108, 117, 101, 115, 32, 109, 117, 115, 116,
  32, 98, 101, 32, 108, 111, 119, 101, 114, 32, 116, 104, 97, 110, 32, 72,
  105, 103, 104, 108, 105, 103, 104, 116, 32, 118, 97, 108, 117, 101, 115, 46,
  32, 84, 105, 99, 107, 32, 83, 104, 111, 119, 32, 109, 97, 115, 107, 32,
  116, 111, 32, 118, 105, 101, 119, 32, 109, 97, 115, 107, 32, 97, 110, 100,
  32, 116, 111, 32, 115, 101, 101, 32, 116, 104, 101, 32, 101, 102, 102, 101,
  99, 116, 32, 111, 102, 32, 116, 104, 101, 32, 115, 108, 105, 100, 101, 114,
  115, 46, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 110, 111, 116, 101, 40, 34, 66, 108, 97, 99, 107, 32,
  99, 117, 116, 111, 102, 102, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 45, 99, 111, 111, 114, 100, 40, 49, 41, 32, 61, 32, 105,
  110, 116, 40, 50, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100, 40, 49, 41,
  32, 61, 32, 105, 110, 116, 40, 50, 53, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  110, 111, 116, 101, 40, 34, 72, 105, 103, 104, 108, 105, 103, 104, 116, 32,
  114, 97, 105, 115, 105, 110, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 88, 45, 99, 111, 111, 114, 100, 40, 50, 41, 32, 61, 32,
  105, 110, 116, 40, 53, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 111, 111, 114, 100, 40, 50,
  41, 32, 61, 32, 105, 110, 116, 40, 50, 48, 48, 44, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 111, 119,
  32, 109, 97, 115, 107, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 32, 65, 117, 116,
  104, 111, 114, 58, 32, 65, 114, 116, 111, 32, 72, 117, 111, 116, 97, 114,
  105, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32,
  58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 49, 49, 47, 48, 50, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103,
  105, 109, 112, 95, 102, 105, 120, 95, 72, 68, 82, 95, 98, 108, 97, 99,
  107, 58, 10, 45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 10, 88, 49,
  61, 36, 49, 10, 89, 49, 61, 36, 50, 10, 88, 50, 61, 36, 51, 10,
  89, 50, 61, 36, 52, 10, 83, 104, 111, 119, 77, 97, 115, 107, 61, 36,
  53, 10, 45, 45, 103, 105, 109, 112, 95, 98, 105, 108, 97, 116, 101, 114,
  97, 108, 91, 45, 49, 93, 32, 52, 44, 56, 44, 54, 44, 52, 44, 48,
  10, 45, 103, 105, 109, 112, 95, 104, 97, 97, 114, 95, 115, 109, 111, 111,
  116, 104, 105, 110, 103, 91, 45, 49, 93, 32, 48, 46, 54, 44, 53, 44,
  50, 44, 51, 44, 49, 44, 50, 52, 10, 45, 45, 114, 103, 98, 50, 108,
  97, 98, 91, 45, 49, 93, 10, 45, 115, 112, 108, 105, 116, 91, 45, 49,
  93, 32, 99, 10, 45, 114, 109, 91, 45, 49, 44, 45, 50, 93, 10, 45,
  103, 105, 109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101,
  91, 45, 49, 93, 32, 48, 44, 36, 88, 49, 44, 36, 89, 49, 44, 36,
  88, 50, 44, 36, 89, 50, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49,
  44, 49, 50, 56, 44, 45, 49, 44, 49, 50, 56, 44, 50, 53, 53, 44,
  49, 44, 48, 44, 48, 44, 50, 49, 44, 48, 10, 45, 105, 102, 32, 123,
  36, 83, 104, 111, 119, 77, 97, 115, 107, 61, 61, 48, 125, 10, 45, 110,
  101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 10, 45, 97, 112, 112,
  101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 116, 111,
  95, 114, 103, 98, 97, 91, 45, 49, 93, 10, 45, 98, 108, 101, 110, 100,
  91, 48, 44, 45, 49, 93, 32, 97, 108, 112, 104, 97, 10, 45, 107, 101,
  101, 112, 91, 48, 93, 10, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109,
  112, 95, 102, 105, 120, 95, 72, 68, 82, 95, 98, 108, 97, 99, 107, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  103, 105, 109, 112, 95, 102, 105, 120, 95, 72, 68, 82, 95, 98, 108, 97,
  99, 107, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10,
  35, 64, 103, 105, 109, 112, 32, 78, 111, 105, 115, 101, 32, 112, 97, 105,
  110, 116, 105, 110, 103, 32, 58, 32, 103, 105, 109, 112, 95, 110, 111, 105,
  115, 101, 112, 97, 105, 110, 116, 105, 110, 103, 44, 32, 103, 105, 109, 112,
  95, 110, 111, 105, 115, 101, 112, 97, 105, 110, 116, 105, 110, 103, 95, 112,
  114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  65, 32, 112, 114, 101, 112, 114, 111, 99, 101, 115, 115, 32, 115, 117, 103,
  103, 101, 115, 116, 105, 111, 110, 32, 102, 111, 114, 32, 116, 104, 101, 32,
  112, 97, 105, 110, 116, 105, 110, 103, 32, 102, 105, 108, 116, 101, 114, 46,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 80, 114, 101, 32,
  112, 114, 111, 99, 101, 115, 115, 32, 102, 111, 114, 32, 112, 97, 105, 110,
  116, 105, 110, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 112, 114, 101, 97, 100, 32, 110, 111, 105, 115, 101, 32, 61, 32, 105,
  110, 116, 40, 48, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 100, 100, 105, 116, 105, 118, 101, 32, 110, 111, 105,
  115, 101, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 51, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 117, 109, 105, 110, 97,
  110, 99, 101, 32, 111, 110, 108, 121, 32, 61, 32, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 80, 97, 105, 110,
  116, 105, 110, 103, 32, 97, 98, 115, 116, 114, 97, 116, 105, 111, 110, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 98, 115, 116, 114,
  97, 99, 116, 105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 53, 44, 49,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101,
  116, 97, 105, 108, 115, 32, 115, 99, 97, 108, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 50, 46, 53, 44, 48, 44, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 46, 53, 44, 48, 44, 52, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97,
  114, 112, 101, 110, 32, 115, 104, 97, 100, 101, 115, 32, 61, 32, 98, 111,
  111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 32, 65, 117, 116, 104, 111, 114, 58, 32, 65, 114, 116, 111, 32,
  72, 117, 111, 116, 97, 114, 105, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 50, 47,
  48, 55, 47, 49, 50, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 110, 111, 105, 115, 101, 112,
  97, 105, 110, 116, 105, 110, 103, 32, 58, 10, 68, 101, 103, 114, 76, 97,
  114, 103, 101, 61, 36, 49, 10, 68, 101, 103, 114, 83, 109, 97, 108, 108,
  61, 36, 50, 10, 67, 104, 97, 110, 110, 101, 108, 61, 36, 51, 10, 65,
  98, 115, 116, 114, 61, 36, 52, 10, 68, 101, 116, 97, 105, 108, 115, 61,
  36, 53, 10, 67, 111, 108, 111, 114, 61, 36, 54, 10, 83, 109, 111, 111,
  116, 104, 61, 36, 55, 10, 83, 104, 97, 114, 112, 61, 36, 56, 10, 45,
  116, 111, 95, 114, 103, 98, 91, 48, 93, 10, 45, 105, 102, 32, 123, 36,
  67, 104, 97, 110, 110, 101, 108, 125, 32, 67, 104, 97, 110, 110, 101, 108,
  61, 51, 32, 45, 101, 108, 105, 102, 32, 67, 104, 97, 110, 110, 101, 108,
  61, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 80,
  114, 101, 80, 114, 111, 99, 101, 115, 115, 32, 45, 103, 105, 109, 112, 95,
  115, 101, 103, 109, 101, 110, 116, 95, 119, 97, 116, 101, 114, 115, 104, 101,
  100, 32, 36, 69, 100, 103, 101, 84, 104, 114, 101, 115, 104, 44, 36, 87,
  97, 116, 101, 114, 83, 109, 111, 111, 116, 104, 44, 48, 44, 48, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 68, 101, 103, 114,
  76, 97, 114, 103, 101, 33, 61, 48, 125, 32, 45, 103, 105, 109, 112, 95,
  115, 112, 114, 101, 97, 100, 32, 36, 68, 101, 103, 114, 76, 97, 114, 103,
  101, 44, 36, 68, 101, 103, 114, 76, 97, 114, 103, 101, 44, 48, 44, 48,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 68, 101,
  103, 114, 83, 109, 97, 108, 108, 33, 61, 48, 125, 32, 45, 103, 105, 109,
  112, 95, 110, 111, 105, 115, 101, 32, 36, 68, 101, 103, 114, 83, 109, 97,
  108, 108, 44, 50, 44, 36, 67, 104, 97, 110, 110, 101, 108, 44, 48, 44,
  48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 112,
  97, 105, 110, 116, 105, 110, 103, 32, 36, 65, 98, 115, 116, 114, 44, 36,
  68, 101, 116, 97, 105, 108, 115, 44, 36, 67, 111, 108, 111, 114, 44, 36,
  83, 109, 111, 111, 116, 104, 44, 36, 83, 104, 97, 114, 112, 44, 48, 10,
  103, 105, 109, 112, 95, 110, 111, 105, 115, 101, 112, 97, 105, 110, 116, 105,
  110, 103, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 110, 111, 105, 115, 101, 112, 97, 105,
  110, 116, 105, 110, 103, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36,
  45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 83, 109, 111, 111, 116, 104,
  32, 115, 107, 101, 116, 99, 104, 32, 58, 32, 103, 105, 109, 112, 95, 83,
  109, 111, 111, 116, 104, 83, 107, 101, 116, 99, 104, 44, 32, 103, 105, 109,
  112, 95, 83, 109, 111, 111, 116, 104, 83, 107, 101, 116, 99, 104, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 67, 111, 110, 118, 101, 114, 116, 32,
  105, 109, 97, 103, 101, 32, 116, 111, 32, 98, 108, 97, 99, 107, 32, 97,
  110, 100, 32, 119, 104, 105, 116, 101, 32, 115, 107, 101, 116, 99, 104, 46,
  32, 66, 121, 32, 100, 101, 102, 97, 117, 108, 116, 32, 103, 114, 97, 100,
  105, 101, 110, 116, 32, 101, 100, 103, 101, 115, 32, 97, 114, 101, 32, 117,
  115, 101, 100, 32, 98, 117, 116, 32, 105, 102, 32, 102, 105, 108, 116, 101,
  114, 32, 105, 110, 112, 117, 116, 32, 115, 101, 116, 32, 116, 111, 32, 65,
  99, 116, 105, 118, 101, 32, 97, 110, 100, 32, 66, 101, 108, 111, 119, 32,
  97, 32, 112, 114, 101, 109, 97, 100, 101, 32, 101, 100, 103, 101, 32, 108,
  97, 121, 101, 114, 32, 99, 97, 110, 32, 98, 101, 32, 117, 115, 101, 100,
  32, 102, 114, 111, 109, 32, 116, 104, 101, 32, 108, 97, 121, 101, 114, 32,
  98, 101, 108, 111, 119, 46, 32, 83, 107, 101, 116, 99, 104, 32, 115, 116,
  114, 101, 110, 103, 116, 104, 32, 115, 108, 105, 100, 101, 114, 32, 119, 105,
  108, 108, 32, 110, 111, 116, 32, 104, 97, 118, 101, 32, 97, 110, 121, 32,
  101, 102, 102, 101, 99, 116, 32, 105, 102, 32, 112, 114, 101, 109, 97, 100,
  101, 32, 101, 100, 103, 101, 115, 32, 108, 97, 121, 101, 114, 32, 105, 115,
  32, 117, 115, 101, 100, 46, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 83, 107, 101, 116, 99, 104,
  32, 97, 110, 100, 32, 101, 100, 103, 101, 115, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 107, 101, 116, 99, 104, 32, 115, 116, 114,
  101, 110, 103, 116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40, 54, 44,
  48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  104, 97, 114, 112, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 56, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 109, 111, 111, 116, 104, 101, 114, 32, 115, 99, 97, 108,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 46, 53, 44,
  50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111,
  111, 116, 104, 101, 114, 32, 97, 99, 99, 117, 114, 97, 99, 121, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 105, 110, 103,
  32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 48, 48, 48, 44, 49, 44, 51, 48, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 117, 100, 103, 101, 32,
  97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  45, 49, 56, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 69, 109, 112, 116, 121,
  32, 97, 114, 101, 97, 32, 99, 111, 108, 111, 114, 105, 110, 103, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 105,
  110, 103, 32, 100, 101, 110, 115, 105, 116, 121, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 53, 48, 44, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 105, 110, 103, 32, 115,
  116, 114, 111, 107, 101, 32, 108, 101, 110, 103, 116, 104, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 105, 110, 103,
  32, 115, 116, 121, 108, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  50, 44, 34, 76, 105, 110, 101, 97, 114, 34, 44, 34, 65, 110, 103, 117,
  108, 97, 114, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 119, 97, 118,
  121, 34, 44, 34, 65, 110, 103, 117, 108, 97, 114, 32, 119, 97, 118, 121,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111,
  114, 105, 110, 103, 32, 111, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 54, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 80,
  111, 115, 116, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 112,
  97, 114, 97, 109, 101, 116, 101, 114, 115, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 80, 111, 115, 116, 32, 103, 97, 109, 109, 97, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 53, 44, 48, 46, 49,
  44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62,
  65, 114, 116, 111, 32, 72, 117, 111, 116, 97, 114, 105, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48,
  57, 47, 50, 56, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 70, 105, 108, 116, 101, 114,
  32, 69, 120, 112, 108, 97, 105, 110, 101, 100, 32, 104, 101, 114, 101, 34,
  44, 34, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 102, 108, 105,
  99, 107, 114, 46, 99, 111, 109, 47, 103, 114, 111, 117, 112, 115, 47, 103,
  109, 105, 99, 47, 100, 105, 115, 99, 117, 115, 115, 47, 55, 50, 49, 53,
  55, 54, 50, 56, 51, 48, 55, 50, 50, 53, 55, 52, 55, 34, 41, 10,
  103, 105, 109, 112, 95, 83, 109, 111, 111, 116, 104, 83, 107, 101, 116, 99,
  104, 32, 58, 10, 85, 115, 109, 82, 97, 100, 105, 117, 115, 61, 53, 10,
  85, 115, 109, 65, 109, 111, 117, 110, 116, 61, 36, 49, 10, 83, 104, 97,
  114, 112, 110, 101, 115, 115, 61, 36, 50, 10, 83, 109, 83, 99, 97, 108,
  101, 61, 36, 51, 10, 83, 109, 65, 99, 99, 117, 114, 97, 99, 121, 61,
  123, 49, 45, 36, 52, 125, 10, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  61, 36, 53, 10, 102, 105, 61, 36, 54, 10, 68, 101, 110, 115, 105, 116,
  121, 61, 36, 55, 10, 66, 108, 117, 114, 76, 101, 110, 103, 116, 104, 61,
  36, 56, 10, 83, 116, 121, 108, 101, 61, 36, 57, 10, 66, 103, 79, 112,
  97, 99, 105, 116, 121, 61, 36, 49, 48, 10, 80, 111, 115, 116, 71, 97,
  109, 109, 97, 61, 36, 49, 49, 10, 83, 116, 97, 99, 107, 83, 105, 122,
  101, 61, 64, 35, 10, 45, 105, 102, 32, 123, 36, 83, 116, 97, 99, 107,
  83, 105, 122, 101, 61, 61, 49, 125, 10, 35, 85, 110, 115, 104, 97, 114,
  112, 32, 116, 111, 32, 101, 110, 104, 97, 110, 99, 101, 32, 101, 100, 103,
  101, 115, 32, 97, 110, 100, 32, 100, 101, 116, 97, 105, 108, 10, 35, 45,
  117, 110, 115, 104, 97, 114, 112, 91, 45, 49, 93, 32, 36, 85, 115, 109,
  82, 97, 100, 105, 117, 115, 44, 36, 85, 115, 109, 65, 109, 111, 117, 110,
  116, 10, 45, 103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112, 91,
  45, 49, 93, 32, 48, 44, 36, 85, 115, 109, 82, 97, 100, 105, 117, 115,
  44, 51, 48, 44, 36, 85, 115, 109, 65, 109, 111, 117, 110, 116, 44, 48,
  44, 49, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 10, 35, 71, 114,
  97, 100, 105, 101, 110, 116, 32, 110, 111, 114, 109, 32, 102, 111, 114, 32,
  108, 105, 110, 101, 115, 10, 45, 45, 103, 114, 97, 100, 105, 101, 110, 116,
  95, 110, 111, 114, 109, 91, 45, 49, 93, 10, 35, 73, 110, 118, 101, 114,
  116, 32, 102, 111, 114, 32, 119, 104, 105, 116, 101, 32, 98, 103, 10, 45,
  110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 10, 35, 78, 111,
  114, 109, 97, 108, 105, 122, 101, 32, 102, 111, 114, 32, 109, 97, 120, 32,
  114, 97, 110, 103, 101, 10, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101,
  91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105,
  102, 10, 40, 50, 53, 53, 59, 50, 53, 53, 59, 50, 53, 53, 41, 10,
  45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 10, 45, 103, 105, 109,
  112, 95, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 36, 68, 101, 110,
  115, 105, 116, 121, 44, 48, 44, 51, 44, 48, 44, 48, 10, 45, 105, 102,
  32, 123, 36, 83, 116, 121, 108, 101, 61, 61, 48, 125, 10, 45, 103, 105,
  109, 112, 95, 98, 108, 117, 114, 95, 108, 105, 110, 101, 97, 114, 91, 45,
  49, 93, 32, 36, 66, 108, 117, 114, 76, 101, 110, 103, 116, 104, 44, 48,
  44, 49, 51, 53, 44, 53, 48, 48, 44, 49, 44, 51, 44, 48, 44, 48,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 83, 116,
  121, 108, 101, 61, 61, 49, 125, 10, 45, 103, 105, 109, 112, 95, 98, 108,
  117, 114, 95, 97, 110, 103, 117, 108, 97, 114, 91, 45, 49, 93, 32, 36,
  66, 108, 117, 114, 76, 101, 110, 103, 116, 104, 44, 49, 46, 50, 44, 49,
  46, 50, 44, 48, 44, 48, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 83, 116, 121, 108, 101, 61, 61, 50, 125, 10,
  45, 103, 105, 109, 112, 95, 98, 108, 117, 114, 95, 108, 105, 110, 101, 97,
  114, 91, 45, 49, 93, 32, 36, 66, 108, 117, 114, 76, 101, 110, 103, 116,
  104, 44, 48, 44, 49, 51, 53, 44, 53, 48, 48, 44, 49, 44, 51, 44,
  48, 44, 48, 10, 45, 100, 101, 102, 111, 114, 109, 91, 45, 49, 93, 32,
  123, 36, 68, 101, 110, 115, 105, 116, 121, 47, 53, 125, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 83, 116, 121, 108, 101, 61,
  61, 51, 125, 10, 45, 103, 105, 109, 112, 95, 98, 108, 117, 114, 95, 97,
  110, 103, 117, 108, 97, 114, 91, 45, 49, 93, 32, 36, 66, 108, 117, 114,
  76, 101, 110, 103, 116, 104, 44, 49, 46, 50, 44, 49, 46, 50, 44, 48,
  44, 48, 44, 48, 10, 45, 100, 101, 102, 111, 114, 109, 91, 45, 49, 93,
  32, 123, 36, 68, 101, 110, 115, 105, 116, 121, 47, 53, 125, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45,
  50, 93, 32, 109, 117, 108, 116, 105, 112, 108, 121, 44, 36, 66, 103, 79,
  112, 97, 99, 105, 116, 121, 44, 48, 10, 45, 110, 111, 114, 109, 97, 108,
  105, 122, 101, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 45,
  100, 105, 102, 102, 117, 115, 105, 111, 110, 116, 101, 110, 115, 111, 114, 115,
  91, 48, 93, 32, 36, 83, 104, 97, 114, 112, 110, 101, 115, 115, 44, 48,
  46, 51, 44, 48, 46, 54, 44, 49, 46, 49, 44, 48, 10, 45, 114, 111,
  116, 97, 116, 105, 111, 110, 51, 100, 32, 48, 44, 48, 44, 49, 44, 123,
  36, 102, 105, 125, 10, 45, 109, 105, 120, 95, 99, 104, 97, 110, 110, 101,
  108, 115, 91, 45, 50, 93, 32, 40, 64, 123, 45, 49, 44, 48, 45, 50,
  125, 59, 64, 123, 45, 49, 44, 51, 45, 53, 125, 59, 64, 123, 45, 49,
  44, 54, 45, 56, 125, 41, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  109, 117, 108, 91, 45, 49, 93, 32, 123, 36, 83, 109, 83, 99, 97, 108,
  101, 47, 109, 97, 120, 40, 97, 98, 115, 40, 64, 123, 45, 49, 44, 77,
  125, 41, 44, 97, 98, 115, 40, 64, 123, 45, 49, 44, 109, 125, 41, 41,
  125, 10, 45, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 123, 36, 83,
  109, 65, 99, 99, 117, 114, 97, 99, 121, 42, 109, 97, 120, 40, 97, 98,
  115, 40, 64, 123, 45, 49, 44, 77, 125, 41, 44, 97, 98, 115, 40, 64,
  123, 45, 49, 44, 109, 125, 41, 41, 125, 10, 45, 114, 101, 118, 101, 114,
  115, 101, 91, 45, 49, 44, 45, 50, 93, 10, 45, 115, 109, 111, 111, 116,
  104, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 36, 65, 109, 112, 108,
  105, 116, 117, 100, 101, 10, 45, 107, 101, 101, 112, 91, 45, 49, 93, 10,
  45, 97, 112, 112, 108, 121, 95, 103, 97, 109, 109, 97, 91, 45, 49, 93,
  32, 36, 80, 111, 115, 116, 71, 97, 109, 109, 97, 10, 35, 64, 103, 105,
  109, 112, 32, 86, 101, 99, 116, 111, 114, 32, 102, 105, 101, 108, 100, 32,
  114, 111, 116, 97, 116, 105, 111, 110, 32, 100, 101, 109, 111, 32, 58, 32,
  103, 105, 109, 112, 95, 68, 101, 109, 111, 86, 101, 99, 82, 111, 116, 44,
  32, 103, 105, 109, 112, 95, 68, 101, 109, 111, 86, 101, 99, 82, 111, 116,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  110, 111, 116, 101, 40, 34, 86, 101, 99, 116, 111, 114, 32, 102, 105, 101,
  108, 100, 32, 114, 111, 116, 97, 116, 105, 111, 110, 32, 97, 110, 100, 32,
  113, 117, 105, 118, 101, 114, 32, 115, 97, 109, 112, 108, 101, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 115,
  104, 105, 102, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45,
  49, 56, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32,
  58, 32, 60, 105, 62, 65, 114, 116, 111, 32, 72, 117, 111, 116, 97, 114,
  105, 60, 47, 105, 62, 32, 119, 105, 116, 104, 32, 104, 101, 108, 112, 32,
  102, 114, 111, 109, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115,
  99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 50, 47,
  48, 50, 47, 50, 53, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 68, 101, 109, 111, 86, 101,
  99, 82, 111, 116, 32, 58, 10, 97, 110, 103, 108, 101, 61, 36, 49, 10,
  45, 116, 111, 95, 114, 103, 98, 91, 48, 93, 10, 91, 48, 93, 10, 45,
  116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10, 45, 115, 112, 108, 105,
  116, 91, 45, 49, 93, 32, 99, 10, 45, 45, 91, 45, 50, 93, 32, 49,
  50, 56, 10, 45, 45, 91, 45, 51, 93, 32, 49, 50, 56, 10, 45, 97,
  112, 112, 101, 110, 100, 91, 45, 51, 44, 45, 50, 44, 45, 49, 93, 32,
  99, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32,
  48, 44, 49, 10, 45, 47, 91, 45, 49, 93, 32, 49, 50, 56, 10, 35,
  50, 48, 48, 44, 50, 48, 48, 44, 49, 44, 50, 32, 50, 48, 48, 120,
  50, 48, 48, 120, 49, 32, 112, 120, 32, 111, 110, 108, 121, 32, 116, 119,
  111, 32, 99, 104, 97, 110, 110, 101, 108, 115, 10, 45, 114, 111, 116, 97,
  116, 105, 111, 110, 51, 100, 32, 48, 44, 48, 44, 49, 44, 36, 97, 110,
  103, 108, 101, 10, 45, 122, 91, 45, 49, 93, 32, 48, 44, 48, 44, 49,
  44, 49, 10, 45, 109, 105, 120, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  91, 45, 50, 93, 32, 40, 64, 123, 45, 49, 44, 48, 45, 49, 125, 59,
  64, 123, 45, 49, 44, 50, 45, 51, 125, 41, 10, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 113, 117, 105, 118, 101, 114, 91, 45, 50, 93, 32, 91,
  45, 49, 93, 44, 49, 48, 44, 49, 48, 44, 49, 44, 48, 46, 56, 44,
  50, 53, 53, 10, 45, 107, 101, 101, 112, 91, 45, 50, 93, 10, 35, 64,
  103, 105, 109, 112, 32, 87, 97, 114, 112, 32, 116, 101, 115, 116, 32, 58,
  32, 103, 105, 109, 112, 95, 87, 97, 114, 112, 84, 101, 115, 116, 44, 32,
  103, 105, 109, 112, 95, 87, 97, 114, 112, 84, 101, 115, 116, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 110, 111, 116, 101, 40, 34, 84, 119,
  111, 32, 108, 97, 121, 101, 114, 115, 32, 114, 101, 113, 117, 105, 114, 101,
  100, 32, 105, 102, 32, 97, 117, 116, 111, 109, 97, 112, 32, 105, 115, 32,
  110, 111, 116, 32, 117, 115, 101, 100, 46, 32, 60, 98, 62, 83, 101, 116,
  32, 105, 110, 112, 117, 116, 32, 116, 111, 32, 97, 99, 116, 105, 118, 101,
  32, 97, 110, 100, 32, 98, 101, 108, 111, 119, 60, 47, 98, 62, 46, 32,
  70, 105, 108, 116, 101, 114, 32, 111, 102, 102, 115, 101, 116, 116, 115, 32,
  105, 109, 97, 103, 101, 32, 119, 105, 116, 104, 32, 97, 32, 118, 101, 99,
  116, 111, 114, 32, 102, 105, 101, 108, 100, 32, 109, 97, 112, 46, 32, 77,
  97, 112, 32, 105, 115, 32, 99, 114, 101, 97, 116, 101, 100, 32, 102, 114,
  111, 109, 32, 82, 32, 97, 110, 100, 32, 71, 32, 99, 104, 97, 110, 110,
  101, 108, 115, 32, 115, 111, 32, 116, 104, 97, 116, 32, 82, 49, 50, 56,
  44, 71, 49, 50, 56, 32, 98, 101, 99, 111, 109, 101, 115, 32, 91, 48,
  32, 48, 93, 46, 32, 69, 120, 112, 101, 114, 105, 109, 101, 110, 116, 32,
  119, 105, 116, 104, 32, 115, 111, 108, 105, 100, 32, 49, 50, 56, 44, 49,
  50, 56, 44, 48, 32, 99, 111, 108, 111, 114, 32, 108, 97, 121, 101, 114,
  32, 97, 110, 100, 32, 97, 100, 100, 32, 104, 117, 101, 115, 32, 111, 102,
  32, 114, 101, 100, 32, 97, 110, 100, 32, 103, 114, 101, 101, 110, 46, 32,
  65, 110, 103, 108, 101, 32, 115, 104, 105, 102, 116, 32, 114, 111, 116, 97,
  116, 101, 115, 32, 116, 104, 101, 32, 118, 101, 99, 116, 111, 114, 32, 102,
  105, 101, 108, 100, 32, 97, 110, 100, 32, 90, 101, 114, 111, 32, 112, 111,
  105, 110, 116, 32, 111, 102, 102, 115, 101, 116, 32, 109, 111, 118, 101, 115,
  32, 116, 104, 101, 32, 100, 101, 102, 97, 117, 108, 116, 32, 48, 32, 48,
  32, 112, 111, 105, 110, 116, 46, 32, 84, 104, 105, 115, 32, 105, 115, 32,
  109, 97, 105, 110, 108, 121, 32, 102, 111, 114, 32, 102, 117, 110, 32, 97,
  110, 100, 32, 116, 101, 115, 116, 105, 110, 103, 46, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 77, 97, 112, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 65, 117, 116, 111, 109, 97, 112, 34, 44, 34, 76,
  97, 121, 101, 114, 32, 77, 97, 112, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 115, 104, 105, 102, 116, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 56, 48, 44, 49,
  56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 101, 114,
  111, 32, 112, 111, 105, 110, 116, 32, 111, 102, 102, 115, 101, 116, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 50, 56, 44, 49, 50,
  56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 101, 99, 116,
  111, 114, 32, 108, 101, 110, 103, 116, 104, 32, 109, 117, 108, 116, 105, 112,
  108, 101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 46,
  49, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 79, 112, 116, 105, 111, 110, 97, 108,
  32, 118, 105, 101, 119, 105, 110, 103, 32, 111, 102, 32, 118, 101, 99, 116,
  111, 114, 32, 102, 105, 101, 108, 100, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 104, 111, 119, 32, 113, 117, 105, 118, 101, 114, 32,
  61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  32, 58, 32, 60, 105, 62, 65, 114, 116, 111, 32, 72, 117, 111, 116, 97,
  114, 105, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62,
  50, 48, 49, 50, 47, 48, 50, 47, 50, 56, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 87,
  97, 114, 112, 84, 101, 115, 116, 32, 58, 10, 77, 97, 112, 84, 121, 112,
  101, 61, 36, 49, 10, 102, 105, 61, 123, 36, 50, 42, 51, 46, 49, 52,
  49, 53, 47, 49, 56, 48, 125, 10, 90, 101, 114, 111, 79, 102, 102, 115,
  101, 116, 61, 36, 51, 10, 76, 77, 117, 108, 116, 61, 36, 52, 10, 83,
  104, 111, 119, 81, 117, 105, 118, 101, 114, 61, 36, 53, 10, 45, 105, 102,
  32, 123, 36, 77, 97, 112, 84, 121, 112, 101, 61, 61, 48, 125, 10, 45,
  45, 103, 105, 109, 112, 95, 108, 111, 99, 97, 108, 95, 111, 114, 105, 101,
  110, 116, 97, 116, 105, 111, 110, 32, 48, 46, 53, 44, 48, 44, 49, 48,
  48, 44, 48, 44, 52, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 99,
  111, 115, 102, 105, 61, 123, 99, 111, 115, 40, 36, 102, 105, 41, 125, 10,
  115, 105, 110, 102, 105, 61, 123, 115, 105, 110, 40, 36, 102, 105, 41, 125,
  10, 45, 116, 111, 95, 114, 103, 98, 91, 45, 50, 44, 45, 49, 93, 10,
  45, 45, 91, 45, 49, 93, 32, 123, 49, 50, 56, 43, 36, 90, 101, 114,
  111, 79, 102, 102, 115, 101, 116, 125, 10, 45, 115, 112, 108, 105, 116, 91,
  45, 49, 93, 32, 99, 10, 45, 109, 117, 108, 91, 51, 93, 32, 48, 10,
  45, 45, 109, 117, 108, 91, 49, 93, 32, 36, 99, 111, 115, 102, 105, 10,
  45, 45, 109, 117, 108, 91, 50, 93, 32, 36, 115, 105, 110, 102, 105, 10,
  45, 115, 117, 98, 91, 52, 93, 32, 91, 53, 93, 10, 45, 114, 109, 91,
  53, 93, 10, 45, 45, 109, 117, 108, 91, 49, 93, 32, 36, 115, 105, 110,
  102, 105, 10, 45, 45, 109, 117, 108, 91, 50, 93, 32, 36, 99, 111, 115,
  102, 105, 10, 45, 97, 100, 100, 91, 53, 93, 32, 91, 54, 93, 10, 45,
  114, 109, 91, 54, 93, 10, 45, 114, 109, 91, 49, 44, 50, 93, 10, 45,
  114, 109, 91, 49, 93, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44,
  49, 48, 48, 37, 44, 49, 44, 48, 10, 45, 97, 112, 112, 101, 110, 100,
  91, 49, 44, 50, 44, 51, 93, 32, 99, 10, 45, 47, 91, 45, 49, 93,
  32, 123, 49, 50, 56, 47, 36, 76, 77, 117, 108, 116, 125, 10, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 44, 49, 10,
  45, 105, 102, 32, 123, 36, 83, 104, 111, 119, 81, 117, 105, 118, 101, 114,
  61, 61, 48, 125, 10, 45, 119, 97, 114, 112, 91, 45, 50, 93, 32, 91,
  45, 49, 93, 44, 49, 44, 49, 44, 48, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 83, 104, 111, 119, 81, 117, 105, 118, 101,
  114, 61, 61, 49, 125, 10, 45, 113, 117, 105, 118, 101, 114, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 44, 49, 48, 44, 123, 36, 76, 77, 117, 108,
  116, 47, 49, 48, 48, 125, 44, 49, 44, 48, 46, 56, 44, 50, 53, 53,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 49, 93, 10,
  35, 64, 103, 105, 109, 112, 32, 95, 10, 35, 64, 103, 105, 109, 112, 32,
  60, 105, 62, 79, 107, 121, 108, 49, 54, 56, 60, 47, 105, 62, 10, 35,
  64, 103, 105, 109, 112, 32, 74, 111, 98, 115, 32, 99, 111, 108, 111, 114,
  115, 32, 58, 32, 103, 105, 109, 112, 95, 106, 111, 98, 115, 95, 99, 111,
  108, 111, 114, 115, 44, 32, 103, 105, 109, 112, 95, 106, 111, 98, 115, 95,
  99, 111, 108, 111, 114, 115, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 71, 97, 109, 109, 97, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 44, 50, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 69, 113, 117, 97, 108, 105, 122, 101, 32,
  61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121,
  112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 68, 117, 112,
  108, 105, 99, 97, 116, 101, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 79, 98, 101,
  114, 111, 110, 32, 76, 101, 117, 110, 103, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 50, 53,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  103, 105, 109, 112, 95, 106, 111, 98, 115, 95, 99, 111, 108, 111, 114, 115,
  32, 58, 10, 45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 105, 102, 32,
  36, 50, 32, 45, 101, 113, 117, 97, 108, 105, 122, 101, 32, 50, 53, 54,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 108, 117, 109, 105, 110, 97, 110,
  99, 101, 32, 45, 97, 112, 112, 108, 121, 95, 103, 97, 109, 109, 97, 32,
  123, 49, 48, 94, 36, 49, 125, 32, 45, 110, 32, 48, 44, 57, 32, 45,
  114, 111, 117, 110, 100, 10, 40, 50, 50, 44, 49, 56, 55, 44, 50, 48,
  44, 51, 54, 44, 50, 51, 53, 44, 50, 52, 48, 44, 50, 52, 53, 44,
  50, 52, 51, 44, 50, 52, 55, 44, 50, 48, 57, 94, 49, 56, 44, 57,
  55, 44, 49, 52, 55, 44, 49, 53, 55, 44, 55, 57, 44, 49, 49, 48,
  44, 49, 50, 49, 44, 49, 52, 50, 44, 49, 55, 48, 44, 50, 48, 48,
  94, 49, 57, 44, 49, 53, 56, 44, 49, 57, 50, 44, 54, 48, 44, 54,
  55, 44, 54, 53, 44, 54, 52, 44, 54, 52, 44, 54, 52, 44, 49, 56,
  53, 41, 10, 45, 109, 97, 112, 91, 94, 45, 49, 93, 32, 91, 45, 49,
  93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 103, 105, 109, 112, 95, 106,
  111, 98, 115, 95, 99, 111, 108, 111, 114, 115, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95,
  106, 111, 98, 115, 95, 99, 111, 108, 111, 114, 115, 32, 36, 42, 34, 44,
  36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 95, 10, 35, 64, 103,
  105, 109, 112, 32, 60, 105, 62, 80, 104, 111, 116, 111, 99, 111, 109, 105,
  120, 60, 47, 105, 62, 10, 35, 64, 103, 105, 109, 112, 32, 66, 111, 111,
  115, 116, 32, 115, 99, 114, 101, 101, 110, 32, 58, 32, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 98, 111, 111, 115, 116, 115, 99,
  114, 101, 101, 110, 44, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 98, 111, 111, 115, 116, 115, 99, 114, 101, 101, 110, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32,
  108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116,
  121, 32, 50, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 44,
  48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 32, 40, 34, 84, 104, 105, 115,
  32, 102, 105, 108, 116, 101, 114, 32, 110, 101, 101, 100, 115, 32, 116, 119,
  111, 32, 108, 97, 121, 101, 114, 115, 32, 116, 111, 32, 119, 111, 114, 107,
  32, 112, 114, 111, 112, 101, 114, 108, 121, 46, 32, 83, 101, 116, 32, 116,
  104, 101, 32, 60, 105, 62, 73, 110, 112, 117, 116, 32, 108, 97, 121, 101,
  114, 115, 60, 47, 105, 62, 32, 111, 112, 116, 105, 111, 110, 32, 116, 111,
  32, 104, 97, 110, 100, 108, 101, 32, 109, 117, 108, 116, 105, 112, 108, 101,
  32, 105, 110, 112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 46, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 80, 104, 111, 116,
  111, 67, 111, 109, 105, 88, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58,
  32, 60, 105, 62, 50, 48, 49, 49, 47, 49, 49, 47, 49, 51, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 98, 111, 111, 115, 116,
  115, 99, 114, 101, 101, 110, 32, 58, 10, 45, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 115, 99, 114, 101, 101, 110, 32, 36, 49,
  44, 36, 50, 32, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111,
  116, 104, 105, 110, 103, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 32, 36,
  51, 44, 48, 10, 35, 64, 103, 105, 109, 112, 32, 67, 111, 108, 111, 114,
  32, 100, 111, 112, 105, 110, 103, 32, 58, 32, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 99, 111, 108, 111, 114, 100, 111, 112, 105,
  110, 103, 32, 44, 32, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 99, 111, 108, 111, 114, 100, 111, 112, 105, 110, 103, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97,
  121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 32, 40, 34, 84, 104, 105, 115, 32, 102, 105, 108, 116, 101,
  114, 32, 110, 101, 101, 100, 115, 32, 116, 119, 111, 32, 108, 97, 121, 101,
  114, 115, 32, 116, 111, 32, 119, 111, 114, 107, 32, 112, 114, 111, 112, 101,
  114, 108, 121, 46, 32, 83, 101, 116, 32, 116, 104, 101, 32, 60, 105, 62,
  73, 110, 112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 60, 47, 105, 62,
  32, 111, 112, 116, 105, 111, 110, 32, 116, 111, 32, 104, 97, 110, 100, 108,
  101, 32, 109, 117, 108, 116, 105, 112, 108, 101, 32, 105, 110, 112, 117, 116,
  32, 108, 97, 121, 101, 114, 115, 46, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 58, 32, 60, 105, 62, 80, 104, 111, 116, 111, 67, 111, 109, 105, 88,
  60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48,
  49, 49, 47, 49, 49, 47, 49, 51, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 99, 111, 108, 111, 114, 100, 111, 112, 105, 110, 103,
  32, 58, 10, 45, 114, 101, 118, 101, 114, 115, 101, 32, 45, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103, 104, 116, 110,
  101, 115, 115, 32, 49, 44, 36, 50, 32, 45, 45, 103, 105, 109, 112, 95,
  100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 32, 45, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108, 116, 105, 112, 108,
  121, 32, 36, 49, 44, 48, 10, 35, 64, 103, 105, 109, 112, 32, 67, 111,
  109, 105, 120, 32, 99, 111, 108, 111, 114, 115, 32, 58, 32, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 99, 111, 109, 105, 120, 95,
  99, 111, 108, 111, 114, 44, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 99, 111, 109, 105, 120, 95, 99, 111, 108, 111, 114, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108,
  97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121,
  32, 50, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 32, 40, 34, 84, 104, 105, 115, 32, 102, 105,
  108, 116, 101, 114, 32, 110, 101, 101, 100, 115, 32, 116, 119, 111, 32, 108,
  97, 121, 101, 114, 115, 32, 116, 111, 32, 119, 111, 114, 107, 32, 112, 114,
  111, 112, 101, 114, 108, 121, 46, 32, 83, 101, 116, 32, 116, 104, 101, 32,
  60, 105, 62, 73, 110, 112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 60,
  47, 105, 62, 32, 111, 112, 116, 105, 111, 110, 32, 116, 111, 32, 104, 97,
  110, 100, 108, 101, 32, 109, 117, 108, 116, 105, 112, 108, 101, 32, 105, 110,
  112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 46, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 58, 32, 60, 105, 62, 80, 104, 111, 116, 111, 67, 111,
  109, 105, 88, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105,
  62, 50, 48, 49, 49, 47, 49, 49, 47, 49, 51, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  99, 111, 109, 112, 111, 115, 101, 95, 99, 111, 109, 105, 120, 95, 99, 111,
  108, 111, 114, 32, 58, 10, 45, 114, 101, 118, 101, 114, 115, 101, 32, 45,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103,
  104, 116, 110, 101, 115, 115, 32, 36, 49, 44, 36, 50, 32, 45, 45, 103,
  105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 32, 45,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97,
  105, 110, 109, 101, 114, 103, 101, 32, 36, 51, 44, 48, 10, 35, 64, 103,
  105, 109, 112, 32, 68, 97, 114, 107, 32, 101, 100, 103, 101, 115, 32, 58,
  32, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 100, 97,
  114, 107, 101, 100, 103, 101, 115, 44, 32, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101, 100, 103, 101, 115, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99,
  105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101,
  115, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97,
  121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32,
  50, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 80, 104,
  111, 116, 111, 67, 111, 109, 105, 88, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  32, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 49, 49, 47, 49, 51,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 100, 97, 114,
  107, 101, 100, 103, 101, 115, 32, 58, 10, 45, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 101, 100, 103, 101, 115, 32, 36, 49, 44,
  36, 50, 44, 36, 51, 32, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95,
  110, 111, 116, 104, 105, 110, 103, 32, 45, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 109, 117, 108, 116, 105, 112, 108, 121, 32, 36,
  52, 44, 48, 10, 35, 64, 103, 105, 109, 112, 32, 68, 97, 114, 107, 32,
  115, 99, 114, 101, 101, 110, 32, 58, 32, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 115, 99, 114, 101, 101, 110,
  44, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 100, 97,
  114, 107, 115, 99, 114, 101, 101, 110, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 55, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121, 101, 114,
  115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 50, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 32, 40, 34, 84, 104, 105, 115, 32, 102, 105, 108, 116,
  101, 114, 32, 110, 101, 101, 100, 115, 32, 116, 119, 111, 32, 108, 97, 121,
  101, 114, 115, 32, 116, 111, 32, 119, 111, 114, 107, 32, 112, 114, 111, 112,
  101, 114, 108, 121, 46, 32, 83, 101, 116, 32, 116, 104, 101, 32, 60, 105,
  62, 73, 110, 112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 60, 47, 105,
  62, 32, 111, 112, 116, 105, 111, 110, 32, 116, 111, 32, 104, 97, 110, 100,
  108, 101, 32, 109, 117, 108, 116, 105, 112, 108, 101, 32, 105, 110, 112, 117,
  116, 32, 108, 97, 121, 101, 114, 115, 46, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 80, 104, 111, 116, 111, 67, 111, 109, 105,
  88, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50,
  48, 49, 49, 47, 49, 49, 47, 49, 51, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 115, 99, 114, 101, 101, 110,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 115, 99, 114, 101, 101, 110, 32, 36, 49, 44, 36, 50, 32, 45, 45,
  103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 32,
  45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117,
  108, 116, 105, 112, 108, 121, 32, 36, 51, 44, 48, 10, 35, 64, 103, 105,
  109, 112, 32, 71, 114, 97, 112, 104, 105, 99, 32, 99, 111, 108, 111, 114,
  115, 32, 58, 32, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 103, 114, 97, 112, 104, 105, 99, 111, 108, 111, 114, 44, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 112, 104, 105,
  99, 111, 108, 111, 114, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79,
  112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  46, 54, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121, 101, 114, 115, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 50, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 56, 44, 48, 44, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 32, 40, 34, 84, 104, 105, 115, 32, 102, 105, 108, 116, 101, 114, 32,
  110, 101, 101, 100, 115, 32, 116, 119, 111, 32, 108, 97, 121, 101, 114, 115,
  32, 116, 111, 32, 119, 111, 114, 107, 32, 112, 114, 111, 112, 101, 114, 108,
  121, 46, 32, 83, 101, 116, 32, 116, 104, 101, 32, 60, 105, 62, 73, 110,
  112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 60, 47, 105, 62, 32, 111,
  112, 116, 105, 111, 110, 32, 116, 111, 32, 104, 97, 110, 100, 108, 101, 32,
  109, 117, 108, 116, 105, 112, 108, 101, 32, 105, 110, 112, 117, 116, 32, 108,
  97, 121, 101, 114, 115, 46, 32, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 80, 104, 111, 116, 111, 67, 111, 109, 105, 88, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49,
  49, 47, 49, 49, 47, 49, 51, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 103, 114, 97, 112, 104, 105, 99, 111, 108, 111, 114, 32,
  58, 10, 45, 114, 101, 118, 101, 114, 115, 101, 32, 45, 45, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 108, 117, 109, 105, 110, 97,
  110, 99, 101, 32, 36, 49, 44, 36, 50, 44, 32, 45, 114, 109, 91, 45,
  50, 93, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 115, 111, 102, 116, 108, 105, 103, 104, 116, 32, 36, 51, 44, 48, 10,
  35, 64, 103, 105, 109, 112, 32, 71, 114, 97, 112, 104, 105, 99, 32, 110,
  111, 118, 101, 108, 45, 111, 108, 100, 32, 58, 32, 103, 105, 109, 112, 95,
  110, 111, 118, 101, 108, 102, 120, 44, 32, 103, 105, 109, 112, 95, 110, 111,
  118, 101, 108, 102, 120, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 65, 112, 112, 108, 121, 32, 76, 111, 99, 97, 108, 32, 78,
  111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 107, 105, 112, 32, 116, 104, 105,
  115, 32, 115, 116, 101, 112, 32, 61, 32, 98, 111, 111, 108, 40, 102, 97,
  108, 115, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 32, 76, 111, 99, 97, 108, 32, 78, 111,
  114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110, 32, 67, 111, 110, 116,
  114, 111, 108, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  76, 110, 32, 97, 109, 112, 108, 105, 116, 105, 116, 117, 100, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 44, 54, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 76, 110, 32, 115, 105, 122, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 54, 44, 48, 44, 54, 52, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 110, 32, 110, 101, 105, 103,
  104, 116, 98, 111, 114, 104, 111, 111, 100, 45, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48,
  44, 52, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 110,
  32, 97, 118, 101, 114, 97, 103, 101, 45, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 48,
  44, 52, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 107, 105, 112, 32, 97, 108,
  108, 32, 111, 116, 104, 101, 114, 32, 115, 116, 101, 112, 115, 32, 61, 32,
  98, 111, 111, 108, 40, 102, 97, 108, 115, 101, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 32, 80, 101, 110, 99, 105, 108, 32,
  79, 112, 116, 105, 111, 110, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 80, 101, 110, 99, 105, 108, 32, 115, 105, 122, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 54, 50, 44, 48, 44, 52, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 101, 110, 99, 105, 108,
  32, 97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 52, 44, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 107, 105, 112, 32, 97, 108, 108, 32, 111, 116, 104, 101, 114, 32,
  115, 116, 101, 112, 115, 32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108,
  115, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 99, 116, 105, 118, 97, 116, 101, 32, 34, 112, 101, 110,
  99, 105, 108, 32, 115, 109, 111, 111, 116, 104, 101, 114, 34, 32, 61, 32,
  98, 111, 111, 108, 40, 116, 114, 117, 101, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 32, 73, 102, 32, 117, 110, 99, 104, 101, 99, 107, 101, 100, 32, 116,
  104, 101, 32, 51, 32, 115, 108, 105, 100, 101, 114, 115, 32, 98, 101, 108,
  111, 119, 32, 97, 114, 101, 32, 100, 105, 115, 97, 98, 108, 101, 100, 32,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 80, 101, 110, 99, 105, 108, 32, 115, 109,
  111, 111, 116, 104, 101, 114, 32, 115, 104, 97, 114, 112, 110, 101, 115, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 50,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 101, 110, 99, 105,
  108, 32, 115, 109, 111, 111, 116, 104, 101, 114, 32, 101, 100, 103, 101, 32,
  112, 114, 111, 116, 101, 99, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 55, 56, 44, 48, 44, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 80, 101, 110, 99, 105, 108, 32, 115, 109, 111,
  111, 116, 104, 101, 114, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 57, 50, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 107, 105, 112, 32, 97, 108, 108,
  32, 111, 116, 104, 101, 114, 32, 115, 116, 101, 112, 115, 32, 61, 32, 98,
  111, 111, 108, 40, 102, 97, 108, 115, 101, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 32, 40, 34, 66, 111, 111, 115, 116, 32, 77,
  101, 114, 103, 105, 110, 103, 32, 79, 112, 116, 105, 111, 110, 115, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 119, 97, 112, 32, 108,
  97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 32, 40, 102, 97,
  108, 115, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 111,
  111, 115, 116, 32, 109, 101, 114, 103, 105, 110, 103, 32, 111, 112, 116, 105,
  111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 79, 118, 101,
  114, 108, 97, 121, 34, 44, 34, 77, 117, 108, 116, 105, 112, 108, 121, 34,
  44, 34, 83, 111, 102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 67,
  111, 108, 111, 114, 32, 66, 117, 114, 110, 34, 44, 34, 68, 97, 114, 107,
  101, 110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34, 72, 97, 114,
  100, 32, 76, 105, 103, 104, 116, 34, 44, 34, 86, 97, 108, 117, 101, 34,
  44, 34, 71, 114, 97, 105, 110, 32, 77, 101, 114, 103, 101, 34, 44, 34,
  70, 114, 101, 101, 122, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 100,
  100, 32, 112, 97, 105, 110, 116, 101, 114, 39, 115, 32, 116, 111, 117, 99,
  104, 32, 61, 32, 98, 111, 111, 108, 40, 116, 114, 117, 101, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 80, 97, 105, 110, 116, 101, 114, 39, 115, 32, 116, 111,
  117, 99, 104, 32, 115, 104, 97, 114, 112, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 50, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 105, 110, 116, 101, 114, 39,
  115, 32, 101, 100, 103, 101, 32, 112, 114, 111, 116, 101, 99, 116, 105, 111,
  110, 32, 102, 108, 111, 119, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  46, 56, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 80, 97, 105, 110, 116, 101, 114, 39, 115, 32, 115, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 61, 102, 108, 111, 97, 116, 40, 49, 46, 50,
  56, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 80,
  104, 111, 116, 111, 67, 111, 109, 105, 88, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48, 52, 47, 50,
  52, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 108, 105, 110, 107, 40, 34, 70, 105, 108, 116, 101, 114, 32, 101, 120,
  112, 108, 97, 105, 110, 101, 100, 32, 104, 101, 114, 101, 34, 44, 34, 104,
  116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 103, 105, 109, 112, 99, 104,
  97, 116, 46, 99, 111, 109, 47, 118, 105, 101, 119, 116, 111, 112, 105, 99,
  46, 112, 104, 112, 63, 102, 61, 57, 38, 116, 61, 49, 53, 56, 50, 34,
  41, 10, 103, 105, 109, 112, 95, 110, 111, 118, 101, 108, 102, 120, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116,
  121, 32, 45, 108, 91, 48, 93, 10, 45, 105, 102, 32, 123, 36, 49, 61,
  61, 48, 125, 32, 45, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97, 108,
  105, 122, 101, 95, 108, 111, 99, 97, 108, 32, 36, 50, 44, 36, 51, 44,
  36, 52, 44, 36, 53, 44, 49, 44, 51, 44, 48, 32, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 61, 61, 49, 125, 32, 45, 103, 105, 109, 112, 95,
  100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 54, 61, 61, 48, 125, 32, 45, 45,
  103, 105, 109, 112, 95, 112, 101, 110, 99, 105, 108, 98, 119, 32, 36, 55,
  44, 36, 56, 44, 48, 44, 48, 44, 48, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 57, 61, 61, 49, 125, 32, 45, 107, 101,
  101, 112, 91, 45, 49, 93, 32, 45, 98, 114, 101, 97, 107, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 48, 61, 61, 49,
  125, 32, 45, 103, 105, 109, 112, 95, 97, 110, 105, 115, 111, 116, 114, 111,
  112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 91, 45, 49,
  93, 32, 54, 48, 44, 36, 49, 49, 44, 36, 49, 50, 44, 36, 49, 51,
  44, 49, 46, 49, 44, 48, 46, 56, 44, 51, 48, 44, 50, 44, 48, 44,
  49, 44, 49, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 49, 52, 61, 61, 49, 125, 32, 45, 107, 101, 101, 112, 91,
  45, 49, 93, 32, 45, 98, 114, 101, 97, 107, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 49, 53, 61, 61, 49, 125, 32, 45,
  114, 101, 118, 101, 114, 115, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 49, 54, 61, 61, 48, 125, 32, 45, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 111, 118, 101, 114, 108, 97,
  121, 91, 45, 49, 44, 48, 93, 32, 36, 49, 55, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 54, 61, 61, 49, 125, 32, 45, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108, 116, 105, 112, 108,
  121, 91, 45, 49, 44, 48, 93, 32, 36, 49, 55, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 54, 61, 61, 50, 125, 32, 45, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 115, 111, 102, 116, 108, 105, 103,
  104, 116, 91, 45, 49, 44, 48, 93, 32, 36, 49, 55, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 54, 61, 61, 51, 125, 32, 45, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 99, 111, 108, 111, 114, 98,
  117, 114, 110, 91, 45, 49, 44, 48, 93, 32, 36, 49, 55, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 49, 54, 61, 61, 52, 125, 32, 45, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 100, 97, 114, 107, 101,
  110, 91, 45, 49, 44, 48, 93, 32, 36, 49, 55, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 54, 61, 61, 53, 125, 32, 45, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 115, 116, 97, 109, 112, 91, 45,
  49, 44, 48, 93, 32, 36, 49, 55, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 54, 61, 61, 54, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 104, 97, 114, 100, 108, 105, 103, 104, 116, 91,
  45, 49, 44, 48, 93, 32, 36, 49, 55, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 49, 54, 61, 61, 55, 125, 32, 45, 114, 101, 118, 101, 114, 115,
  101, 91, 49, 44, 48, 93, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 118, 97, 108, 117, 101, 91, 45, 49, 44, 48, 93,
  32, 36, 49, 55, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49,
  54, 61, 61, 56, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 91, 45,
  49, 44, 48, 93, 32, 36, 49, 55, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 49, 54, 61, 61, 56, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 102, 114, 101, 101, 122, 101, 91, 45, 49, 44,
  48, 93, 32, 36, 49, 55, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 49, 56, 61, 61, 49, 125, 32, 45, 103, 105, 109, 112,
  95, 97, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111,
  111, 116, 104, 105, 110, 103, 32, 54, 48, 44, 36, 49, 57, 44, 36, 50,
  48, 44, 36, 50, 49, 44, 49, 46, 49, 44, 48, 46, 56, 44, 51, 48,
  44, 50, 44, 48, 44, 49, 44, 49, 44, 48, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 110, 111,
  118, 101, 108, 102, 120, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 110, 111, 118, 101, 108,
  102, 120, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10,
  35, 64, 103, 105, 109, 112, 32, 71, 114, 97, 112, 104, 105, 120, 32, 99,
  111, 108, 111, 114, 115, 32, 58, 32, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 103, 114, 97, 112, 104, 105, 120, 99, 111, 108, 111,
  114, 44, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 103,
  114, 97, 112, 104, 105, 120, 99, 111, 108, 111, 114, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121, 101,
  114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 32, 40, 34, 84, 104, 105, 115, 32, 102, 105, 108, 116, 101, 114, 32,
  110, 101, 101, 100, 115, 32, 116, 119, 111, 32, 108, 97, 121, 101, 114, 115,
  32, 116, 111, 32, 119, 111, 114, 107, 32, 112, 114, 111, 112, 101, 114, 108,
  121, 46, 32, 83, 101, 116, 32, 116, 104, 101, 32, 60, 105, 62, 73, 110,
  112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 60, 47, 105, 62, 32, 111,
  112, 116, 105, 111, 110, 32, 116, 111, 32, 104, 97, 110, 100, 108, 101, 32,
  109, 117, 108, 116, 105, 112, 108, 101, 32, 105, 110, 112, 117, 116, 32, 108,
  97, 121, 101, 114, 115, 46, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 80, 104, 111, 116, 111, 67, 111, 109, 105, 88, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 49,
  47, 49, 49, 47, 49, 51, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 103, 114, 97, 112, 104, 105, 120, 99, 111, 108, 111, 114, 32,
  58, 10, 45, 114, 101, 118, 101, 114, 115, 101, 32, 45, 45, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 118, 97, 108, 117, 101, 32,
  49, 44, 36, 50, 32, 45, 107, 101, 101, 112, 91, 45, 49, 44, 45, 51,
  93, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95,
  103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 32, 36, 49, 44, 48, 10,
  64, 103, 105, 109, 112, 32, 71, 114, 97, 112, 104, 105, 99, 32, 98, 111,
  111, 115, 116, 45, 111, 108, 100, 32, 58, 32, 103, 105, 109, 112, 95, 103,
  114, 97, 112, 104, 105, 99, 95, 98, 111, 111, 115, 116, 44, 32, 103, 105,
  109, 112, 95, 103, 114, 97, 112, 104, 105, 99, 95, 98, 111, 111, 115, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 85, 110,
  115, 104, 97, 114, 112, 32, 77, 97, 115, 107, 32, 99, 111, 110, 116, 114,
  111, 108, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  97, 100, 105, 117, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46,
  50, 53, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 68, 97, 114, 107, 101, 110, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 107, 105,
  112, 32, 111, 116, 104, 101, 114, 115, 32, 115, 116, 101, 112, 115, 32, 61,
  32, 98, 111, 111, 108, 40, 102, 97, 108, 115, 101, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 67, 104, 101, 99, 107, 32, 102, 111, 114, 32, 118, 105, 115,
  117, 97, 108, 32, 99, 111, 110, 116, 114, 111, 108, 44, 32, 85, 78, 99,
  104, 101, 99, 107, 32, 116, 111, 32, 114, 101, 97, 99, 116, 105, 118, 97,
  116, 101, 32, 116, 104, 101, 32, 111, 116, 104, 101, 114, 32, 99, 111, 110,
  116, 114, 111, 108, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 66, 87, 95, 80, 101, 110, 99, 105, 108, 32, 67, 111,
  110, 116, 114, 111, 108, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 80, 101, 110, 99, 105, 108, 32, 115, 105, 122, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 49, 53, 44, 48, 44, 52, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 101, 110, 99, 105, 108, 32,
  97, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 52, 44, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 107, 105, 112, 32, 111, 116, 104, 101, 114, 115, 32, 115, 116, 101, 112,
  115, 32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108, 115, 101, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 65, 99, 116, 105, 118, 97, 116, 101, 32, 34, 112, 101, 110, 99, 105,
  108, 32, 115, 109, 111, 111, 116, 104, 101, 114, 34, 32, 61, 32, 98, 111,
  111, 108, 40, 116, 114, 117, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 32,
  73, 102, 32, 117, 110, 99, 104, 101, 99, 107, 101, 100, 32, 116, 104, 101,
  32, 51, 32, 115, 108, 105, 100, 101, 114, 115, 32, 98, 101, 108, 111, 119,
  32, 97, 114, 101, 32, 100, 105, 115, 97, 98, 108, 101, 100, 32, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 101, 110, 99, 105, 108,
  32, 115, 109, 111, 111, 116, 104, 101, 114, 32, 115, 104, 97, 114, 112, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44,
  48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 101,
  110, 99, 105, 108, 32, 115, 109, 111, 111, 116, 104, 101, 114, 32, 101, 100,
  103, 101, 32, 112, 114, 111, 116, 101, 99, 116, 105, 111, 110, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 52, 53, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 101, 110, 99, 105, 108, 32,
  115, 109, 111, 111, 116, 104, 101, 114, 32, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 32, 40, 50, 44, 48,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 107, 105, 112, 32, 111, 116,
  104, 101, 114, 115, 32, 115, 116, 101, 112, 115, 32, 61, 32, 98, 111, 111,
  108, 40, 102, 97, 108, 115, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 32, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 77, 101, 114, 103, 105, 110, 103, 32, 79,
  112, 116, 105, 111, 110, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 119, 97, 112, 32, 108, 97, 121, 101, 114, 115, 32, 61, 32,
  98, 111, 111, 108, 32, 40, 84, 114, 117, 101, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  32, 40, 34, 34, 83, 119, 97, 112, 34, 32, 99, 104, 97, 110, 103, 101,
  32, 116, 104, 101, 32, 101, 102, 102, 101, 99, 116, 32, 111, 102, 32, 77,
  101, 114, 103, 105, 110, 103, 32, 97, 110, 100, 32, 73, 110, 116, 101, 115,
  105, 116, 121, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77,
  101, 114, 103, 105, 110, 103, 32, 111, 112, 116, 105, 111, 110, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 32, 34, 72, 97, 114, 100, 32, 76, 105,
  103, 104, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 77, 101, 114, 103,
  101, 34, 44, 34, 77, 117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 67,
  111, 108, 111, 114, 32, 66, 117, 114, 110, 34, 44, 34, 79, 118, 101, 114,
  108, 97, 121, 34, 32, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 68,
  97, 114, 107, 101, 110, 34, 32, 44, 34, 83, 116, 97, 109, 112, 34, 32,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 116, 101, 110,
  115, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 100, 100, 32, 112, 97, 105,
  110, 116, 101, 114, 39, 115, 32, 116, 111, 117, 99, 104, 32, 61, 32, 98,
  111, 111, 108, 40, 116, 114, 117, 101, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  73, 102, 32, 117, 110, 99, 104, 101, 99, 107, 101, 100, 32, 116, 104, 101,
  32, 51, 32, 115, 108, 105, 100, 101, 114, 115, 32, 98, 101, 108, 111, 119,
  32, 97, 114, 101, 32, 100, 105, 115, 97, 98, 108, 101, 100, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 32, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 80, 97, 105, 110, 116, 101, 114, 39, 115, 32, 116,
  111, 117, 99, 104, 32, 115, 104, 97, 114, 112, 110, 101, 115, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 50, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 105, 110, 116, 101, 114,
  39, 115, 32, 101, 100, 103, 101, 32, 112, 114, 111, 116, 101, 99, 116, 105,
  111, 110, 32, 102, 108, 111, 119, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 52, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 80, 97, 105, 110, 116, 101, 114, 39, 115, 32, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 61, 102, 108, 111, 97, 116, 40, 49,
  44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 80, 104,
  111, 116, 111, 67, 111, 109, 105, 88, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  32, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48, 49, 47, 49, 48,
  32, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 108, 105, 110, 107, 40, 34, 70, 105, 108, 116, 101, 114, 32, 101, 120,
  112, 108, 97, 105, 110, 101, 100, 32, 104, 101, 114, 101, 34, 44, 34, 104,
  116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 103, 105, 109, 112, 99, 104,
  97, 116, 46, 99, 111, 109, 47, 118, 105, 101, 119, 116, 111, 112, 105, 99,
  46, 112, 104, 112, 63, 102, 61, 57, 38, 116, 61, 55, 55, 53, 34, 41,
  10, 103, 105, 109, 112, 95, 103, 114, 97, 112, 104, 105, 99, 95, 98, 111,
  111, 115, 116, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111,
  112, 97, 99, 105, 116, 121, 32, 45, 108, 91, 48, 93, 10, 45, 103, 105,
  109, 112, 95, 117, 110, 115, 104, 97, 114, 112, 32, 49, 44, 36, 49, 44,
  51, 48, 44, 51, 44, 48, 44, 36, 50, 44, 48, 46, 52, 48, 44, 49,
  44, 48, 44, 48, 44, 48, 10, 45, 105, 102, 32, 123, 36, 51, 61, 61,
  49, 125, 32, 45, 98, 114, 101, 97, 107, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 45, 103, 105, 109, 112, 95, 112, 101, 110, 99, 105, 108, 98, 119,
  32, 36, 52, 44, 36, 53, 44, 48, 44, 48, 44, 48, 10, 45, 105, 102,
  32, 123, 36, 54, 61, 61, 49, 125, 32, 45, 107, 101, 101, 112, 91, 45,
  49, 93, 32, 45, 98, 114, 101, 97, 107, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 55, 61, 61, 49, 125, 32, 45, 103, 105,
  109, 112, 95, 97, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115,
  109, 111, 111, 116, 104, 105, 110, 103, 91, 49, 93, 32, 54, 48, 44, 36,
  56, 44, 36, 57, 44, 36, 49, 48, 44, 49, 46, 49, 44, 48, 46, 56,
  44, 51, 48, 44, 50, 44, 48, 44, 49, 44, 49, 44, 48, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 49, 61, 61, 49,
  125, 32, 45, 107, 101, 101, 112, 91, 45, 49, 93, 32, 45, 98, 114, 101,
  97, 107, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  49, 50, 61, 61, 49, 125, 32, 32, 45, 114, 101, 118, 101, 114, 115, 101,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 49, 51,
  61, 61, 48, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 104, 97, 114, 100, 108, 105, 103, 104, 116, 32, 36, 49, 52,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 51, 61, 61, 49, 125, 32,
  45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114,
  97, 105, 110, 109, 101, 114, 103, 101, 32, 36, 49, 52, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 51, 61, 61, 50, 125, 32, 45, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108, 116, 105, 112,
  108, 121, 32, 36, 49, 52, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49,
  51, 61, 61, 51, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 99, 111, 108, 111, 114, 98, 117, 114, 110, 32, 36, 49,
  52, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 51, 61, 61, 52, 125,
  32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 111,
  118, 101, 114, 108, 97, 121, 32, 36, 49, 52, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 51, 61, 61, 53, 125, 32, 45, 103, 105, 109, 112, 95,
  99, 111, 109, 112, 111, 115, 101, 95, 118, 97, 108, 117, 101, 32, 36, 49,
  52, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 51, 61, 61,
  54, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 100, 97, 114, 107, 101, 110, 32, 36, 49, 52, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 51, 61, 61, 55, 125, 32, 45, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 115, 116, 97, 109, 112, 32, 36,
  49, 52, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  49, 53, 61, 61, 49, 125, 32, 45, 103, 105, 109, 112, 95, 97, 110, 105,
  115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105,
  110, 103, 32, 54, 48, 44, 36, 49, 54, 44, 36, 49, 55, 44, 36, 49,
  56, 44, 49, 46, 49, 44, 48, 46, 56, 44, 51, 48, 44, 50, 44, 48,
  44, 49, 44, 49, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 103, 114, 97, 112, 104, 105,
  99, 95, 98, 111, 111, 115, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 103, 114, 97,
  112, 104, 105, 99, 95, 98, 111, 111, 115, 116, 32, 36, 123, 49, 45, 45,
  50, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 72,
  101, 97, 118, 121, 32, 115, 99, 114, 101, 101, 110, 32, 58, 32, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 104, 101, 97, 118, 121,
  115, 99, 114, 101, 101, 110, 44, 32, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 104, 101, 97, 118, 121, 115, 99, 114, 101, 101, 110,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116,
  121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 54, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101,
  114, 116, 32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97,
  99, 105, 116, 121, 32, 50, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  46, 55, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 32, 40, 34, 84,
  104, 105, 115, 32, 102, 105, 108, 116, 101, 114, 32, 110, 101, 101, 100, 115,
  32, 116, 119, 111, 32, 108, 97, 121, 101, 114, 115, 32, 116, 111, 32, 119,
  111, 114, 107, 32, 112, 114, 111, 112, 101, 114, 108, 121, 46, 32, 83, 101,
  116, 32, 116, 104, 101, 32, 60, 105, 62, 73, 110, 112, 117, 116, 32, 108,
  97, 121, 101, 114, 115, 60, 47, 105, 62, 32, 111, 112, 116, 105, 111, 110,
  32, 116, 111, 32, 104, 97, 110, 100, 108, 101, 32, 109, 117, 108, 116, 105,
  112, 108, 101, 32, 105, 110, 112, 117, 116, 32, 108, 97, 121, 101, 114, 115,
  32, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 80,
  104, 111, 116, 111, 67, 111, 109, 105, 88, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 49, 49, 47, 49,
  51, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 104, 101,
  97, 118, 121, 115, 99, 114, 101, 101, 110, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 115, 99, 114, 101, 101, 110,
  32, 36, 49, 44, 36, 50, 32, 45, 45, 103, 105, 109, 112, 95, 100, 111,
  95, 110, 111, 116, 104, 105, 110, 103, 32, 45, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 99, 111, 108, 111, 114, 98, 117, 114, 110,
  32, 36, 51, 44, 48, 10, 35, 64, 103, 105, 109, 112, 32, 77, 101, 116,
  97, 108, 108, 105, 99, 32, 103, 114, 97, 105, 110, 32, 58, 32, 103, 105,
  109, 112, 95, 109, 101, 116, 97, 108, 103, 114, 97, 105, 110, 44, 32, 103,
  105, 109, 112, 95, 109, 101, 116, 97, 108, 103, 114, 97, 105, 110, 95, 112,
  114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 97, 100, 100,
  32, 97, 32, 109, 101, 116, 97, 108, 108, 105, 99, 32, 103, 114, 97, 105,
  110, 32, 97, 100, 97, 112, 116, 32, 116, 111, 32, 112, 105, 99, 116, 111,
  114, 105, 97, 108, 32, 97, 110, 100, 32, 115, 112, 101, 99, 105, 97, 108,
  32, 101, 102, 102, 101, 99, 116, 115, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 100, 101, 112, 101,
  110, 100, 101, 110, 116, 32, 102, 114, 111, 109, 32, 34, 67, 111, 117, 108,
  101, 117, 114, 115, 32, 77, 101, 116, 97, 108, 108, 105, 113, 117, 101, 115,
  34, 32, 98, 121, 32, 83, 97, 109, 106, 32, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 73, 110, 116, 101, 110, 115, 105, 116, 121, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 53, 44, 48, 46, 49, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 119, 97, 112, 32, 108, 97, 121, 101,
  114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108, 115, 101, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 118, 105, 101,
  119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  58, 32, 60, 105, 62, 80, 104, 111, 116, 111, 67, 111, 109, 105, 120, 44,
  97, 32, 104, 97, 99, 107, 32, 111, 102, 32, 97, 32, 83, 97, 109, 106,
  32, 102, 105, 108, 116, 101, 114, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32,
  58, 32, 60, 105, 62, 50, 48, 49, 50, 47, 48, 50, 47, 50, 57, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103,
  105, 109, 112, 95, 109, 101, 116, 97, 108, 103, 114, 97, 105, 110, 32, 58,
  10, 45, 45, 67, 111, 117, 108, 101, 117, 114, 115, 95, 77, 101, 116, 97,
  108, 108, 105, 113, 117, 101, 115, 32, 49, 44, 49, 44, 49, 57, 46, 56,
  54, 44, 48, 44, 48, 44, 48, 44, 55, 46, 52, 44, 49, 49, 44, 51,
  46, 57, 54, 44, 50, 48, 44, 49, 44, 48, 44, 48, 44, 49, 44, 49,
  46, 57, 44, 49, 48, 46, 50, 44, 49, 44, 48, 44, 48, 10, 45, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 111, 118, 101, 114,
  108, 97, 121, 32, 32, 36, 49, 44, 36, 50, 10, 103, 105, 109, 112, 95,
  109, 101, 116, 97, 108, 103, 114, 97, 105, 110, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95,
  109, 101, 116, 97, 108, 103, 114, 97, 105, 110, 32, 36, 123, 49, 45, 45,
  50, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 77,
  101, 116, 97, 108, 108, 105, 99, 32, 115, 116, 101, 110, 99, 105, 108, 115,
  32, 58, 32, 103, 105, 109, 112, 95, 109, 101, 116, 97, 108, 108, 105, 99,
  115, 116, 101, 110, 99, 105, 108, 115, 32, 44, 32, 103, 105, 109, 112, 95,
  109, 101, 116, 97, 108, 108, 105, 99, 115, 116, 101, 110, 99, 105, 108, 115,
  95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 116, 32, 109, 111, 100, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 76, 105,
  103, 104, 116, 101, 110, 34, 44, 34, 79, 118, 101, 114, 108, 97, 121, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 58, 32, 60, 105, 62, 80, 104, 111, 116, 111, 67, 111, 109, 105, 120,
  44, 97, 32, 104, 97, 99, 107, 32, 111, 102, 32, 97, 32, 83, 97, 109,
  106, 32, 102, 105, 108, 116, 101, 114, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  32, 58, 32, 60, 105, 62, 50, 48, 49, 50, 47, 49, 48, 47, 48, 51,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  103, 105, 109, 112, 95, 109, 101, 116, 97, 108, 108, 105, 99, 115, 116, 101,
  110, 99, 105, 108, 115, 32, 58, 10, 45, 45, 67, 111, 117, 108, 101, 117,
  114, 115, 95, 77, 101, 116, 97, 108, 108, 105, 113, 117, 101, 115, 32, 48,
  44, 49, 44, 50, 50, 44, 48, 44, 48, 44, 49, 44, 55, 46, 56, 44,
  57, 44, 55, 46, 54, 44, 49, 54, 46, 54, 44, 49, 44, 48, 44, 48,
  44, 49, 44, 50, 46, 52, 44, 56, 46, 50, 44, 49, 44, 48, 10, 45,
  45, 103, 105, 109, 112, 95, 108, 121, 108, 101, 106, 107, 95, 115, 116, 101,
  110, 99, 105, 108, 91, 48, 93, 32, 52, 44, 50, 54, 46, 55, 48, 52,
  53, 44, 50, 46, 52, 49, 52, 55, 55, 44, 48, 10, 45, 114, 109, 91,
  48, 93, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 125, 32, 45,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 100, 97, 114,
  107, 101, 110, 32, 49, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  49, 61, 61, 49, 125, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 108, 105, 103, 104, 116, 101, 110, 32, 49, 44, 48, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 50, 125, 32, 45, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 111, 118, 101, 114,
  108, 97, 121, 32, 49, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 103,
  105, 109, 112, 95, 109, 101, 116, 97, 108, 108, 105, 99, 115, 116, 101, 110,
  99, 105, 108, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 109, 101, 116, 97, 108, 108,
  105, 99, 115, 116, 101, 110, 99, 105, 108, 115, 32, 36, 123, 49, 45, 45,
  50, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 10, 106,
  108, 95, 104, 115, 118, 95, 116, 111, 95, 114, 103, 98, 32, 58, 10, 40,
  123, 51, 54, 48, 42, 36, 49, 125, 94, 36, 50, 94, 36, 51, 41, 32,
  45, 104, 115, 118, 50, 114, 103, 98, 91, 45, 49, 93, 32, 45, 117, 32,
  64, 45, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 108, 101, 118, 101,
  108, 115, 32, 58, 10, 95, 105, 110, 112, 108, 111, 119, 61, 123, 105, 110,
  116, 40, 36, 49, 41, 125, 10, 95, 105, 110, 112, 104, 105, 103, 104, 61,
  123, 105, 110, 116, 40, 36, 50, 41, 125, 10, 95, 103, 97, 109, 109, 97,
  61, 36, 51, 10, 95, 111, 117, 116, 108, 111, 119, 61, 123, 105, 110, 116,
  40, 36, 52, 41, 125, 10, 95, 111, 117, 116, 104, 105, 103, 104, 61, 123,
  105, 110, 116, 40, 36, 53, 41, 125, 10, 95, 116, 109, 112, 50, 61, 34,
  34, 10, 45, 105, 102, 32, 123, 36, 95, 103, 97, 109, 109, 97, 33, 61,
  49, 125, 10, 95, 116, 109, 112, 50, 61, 34, 45, 97, 112, 112, 108, 121,
  95, 103, 97, 109, 109, 97, 32, 34, 36, 95, 103, 97, 109, 109, 97, 10,
  45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  36, 95, 116, 109, 112, 50, 44, 36, 54, 44, 48, 10, 45, 101, 110, 100,
  105, 102, 10, 95, 99, 117, 114, 118, 101, 49, 61, 34, 48, 44, 34, 10,
  45, 105, 102, 32, 123, 36, 95, 105, 110, 112, 108, 111, 119, 62, 48, 125,
  10, 95, 116, 109, 112, 49, 61, 34, 48, 44, 34, 10, 95, 99, 117, 114,
  118, 101, 49, 61, 36, 95, 99, 117, 114, 118, 101, 49, 36, 95, 116, 109,
  112, 49, 36, 95, 111, 117, 116, 108, 111, 119, 34, 44, 34, 10, 45, 101,
  110, 100, 105, 102, 10, 95, 99, 117, 114, 118, 101, 49, 61, 36, 95, 99,
  117, 114, 118, 101, 49, 36, 95, 105, 110, 112, 108, 111, 119, 34, 44, 34,
  36, 95, 111, 117, 116, 108, 111, 119, 34, 44, 34, 36, 95, 105, 110, 112,
  104, 105, 103, 104, 34, 44, 34, 36, 95, 111, 117, 116, 104, 105, 103, 104,
  10, 45, 105, 102, 32, 123, 36, 95, 105, 110, 112, 104, 105, 103, 104, 60,
  50, 53, 53, 125, 10, 95, 99, 117, 114, 118, 101, 49, 61, 36, 95, 99,
  117, 114, 118, 101, 49, 34, 44, 50, 53, 53, 44, 34, 36, 95, 111, 117,
  116, 104, 105, 103, 104, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 95, 99, 117, 114, 118, 101, 49, 39, 33, 61, 39, 34, 48,
  44, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 34, 125, 10, 95,
  116, 109, 112, 50, 61, 34, 45, 97, 112, 112, 108, 121, 95, 99, 117, 114,
  118, 101, 32, 34, 36, 95, 99, 117, 114, 118, 101, 49, 10, 45, 97, 112,
  112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 36, 95, 116,
  109, 112, 50, 44, 36, 54, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10,
  103, 105, 109, 112, 95, 101, 113, 117, 97, 108, 105, 122, 101, 95, 115, 32,
  58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105,
  116, 121, 32, 45, 108, 91, 48, 93, 32, 45, 116, 111, 95, 114, 103, 98,
  10, 45, 114, 103, 98, 50, 104, 115, 118, 32, 45, 115, 104, 32, 49, 44,
  49, 32, 45, 42, 91, 45, 49, 93, 32, 36, 49, 32, 45, 43, 91, 45,
  49, 93, 32, 36, 50, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 49,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 104, 115, 118, 50, 114, 103,
  98, 10, 45, 101, 110, 100, 108, 32, 45, 97, 32, 99, 32, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32,
  80, 104, 111, 116, 111, 99, 111, 109, 105, 120, 32, 115, 109, 111, 111, 116,
  104, 105, 110, 103, 32, 58, 32, 103, 105, 109, 112, 95, 97, 110, 105, 115,
  111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105, 110,
  103, 44, 32, 103, 105, 109, 112, 95, 97, 110, 105, 115, 111, 116, 114, 111,
  112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116,
  117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 54, 48, 44, 48,
  44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 104, 97, 114, 112, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 49, 54, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 110, 105, 115, 111, 116, 114, 111, 112, 121, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 54, 51, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 97, 100, 105,
  101, 110, 116, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 54, 44, 48, 44, 49, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 101, 110, 115, 111, 114,
  32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 50, 46, 51, 53, 44, 48, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 97, 116, 105, 97, 108, 32,
  112, 114, 101, 99, 105, 115, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 56, 44, 48, 46, 49, 44, 50, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 65, 110, 103, 117, 108, 97, 114, 32, 112, 114,
  101, 99, 105, 115, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  51, 48, 44, 49, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 86, 97, 108, 117, 101, 32, 112, 114, 101, 99, 105, 115, 105,
  111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 46, 49,
  44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 116,
  101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 48, 44, 34, 78, 101, 97, 114, 101, 115, 116, 32, 110,
  101, 105, 103, 104, 98, 111, 114, 34, 44, 34, 76, 105, 110, 101, 97, 114,
  34, 44, 34, 82, 117, 110, 103, 101, 45, 75, 117, 116, 116, 97, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 97, 115, 116, 32, 97,
  112, 112, 114, 111, 120, 105, 109, 97, 116, 105, 111, 110, 32, 61, 32, 98,
  111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116,
  40, 49, 44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 32, 38, 32,
  82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115,
  34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105,
  110, 97, 110, 99, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 84, 105, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 92, 110, 60, 115, 109,
  97, 108, 108, 62, 60, 98, 62, 78, 111, 116, 101, 32, 58, 32, 60, 47,
  98, 62, 84, 104, 105, 115, 32, 115, 101, 116, 32, 111, 102, 32, 97, 110,
  105, 115, 111, 116, 114, 111, 112, 105, 99, 32, 115, 109, 111, 111, 116, 104,
  105, 110, 103, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 104,
  97, 115, 32, 98, 101, 101, 110, 32, 115, 117, 103, 103, 101, 115, 116, 101,
  100, 32, 98, 121, 32, 80, 104, 111, 116, 111, 67, 111, 109, 105, 88, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 125, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 58, 32, 60, 105, 62, 80, 104, 111, 116, 111, 67, 111, 109, 105, 88,
  60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48,
  49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 83,
  99, 97, 108, 101, 32, 100, 111, 119, 110, 32, 110, 101, 97, 116, 32, 58,
  32, 103, 105, 109, 112, 95, 115, 99, 97, 108, 101, 100, 111, 119, 110, 51,
  44, 32, 103, 105, 109, 112, 95, 115, 99, 97, 108, 101, 100, 111, 119, 110,
  51, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 40, 34, 32, 84, 111, 32, 115, 99,
  97, 108, 101, 32, 100, 111, 119, 110, 32, 112, 114, 101, 115, 101, 114, 118,
  105, 110, 103, 32, 99, 108, 101, 97, 110, 32, 101, 100, 103, 101, 115, 32,
  97, 110, 100, 32, 115, 109, 111, 111, 116, 104, 108, 121, 32, 115, 104, 97,
  114, 112, 101, 110, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 117, 116, 111, 109,
  97, 116, 105, 99, 32, 112, 114, 101, 45, 98, 108, 117, 114, 32, 61, 32,
  98, 111, 111, 108, 40, 102, 97, 108, 115, 101, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 32, 32, 34, 65,
  117, 116, 111, 109, 97, 116, 105, 99, 32, 112, 114, 101, 45, 98, 108, 117,
  114, 34, 32, 100, 105, 115, 97, 98, 108, 101, 32, 116, 104, 101, 32, 50,
  32, 115, 108, 105, 100, 101, 114, 115, 32, 98, 101, 108, 111, 119, 34, 32,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 66, 108, 117, 114, 32, 120, 32, 61, 32, 102,
  108, 111, 97, 116, 32, 40, 49, 44, 48, 46, 50, 44, 52, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 117, 114, 32, 121, 32, 61,
  32, 102, 108, 111, 97, 116, 32, 40, 49, 44, 48, 46, 50, 44, 52, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 99, 97, 108, 101, 32, 100, 111, 119, 110, 32,
  116, 111, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 32,
  78, 101, 119, 32, 87, 105, 100, 116, 104, 32, 97, 110, 100, 32, 72, 101,
  105, 103, 104, 116, 32, 32, 34, 44, 32, 34, 32, 112, 114, 101, 115, 101,
  114, 118, 101, 95, 105, 109, 97, 103, 101, 95, 114, 97, 116, 105, 111, 32,
  83, 101, 116, 32, 110, 101, 119, 32, 87, 105, 100, 116, 104, 32, 34, 32,
  44, 32, 34, 112, 114, 101, 115, 101, 114, 118, 101, 95, 105, 109, 97, 103,
  101, 95, 114, 97, 116, 105, 111, 32, 83, 101, 116, 32, 110, 101, 119, 32,
  72, 101, 105, 103, 104, 116, 34, 44, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 101, 119, 32, 119, 105, 100, 116, 104, 32, 61, 32, 105,
  110, 116, 40, 49, 54, 48, 48, 44, 49, 54, 44, 51, 50, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 101, 119, 32, 104, 101,
  105, 103, 104, 116, 32, 61, 32, 105, 110, 116, 40, 49, 54, 48, 48, 44,
  49, 54, 44, 51, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 107, 105,
  112, 32, 112, 111, 115, 116, 32, 115, 104, 97, 114, 112, 101, 110, 105, 110,
  103, 32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108, 115, 101, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  32, 34, 34, 83, 107, 105, 112, 32, 80, 111, 115, 116, 32, 83, 104, 97,
  114, 112, 101, 110, 105, 110, 103, 34, 58, 32, 105, 102, 32, 99, 104, 111,
  115, 101, 110, 32, 119, 105, 108, 108, 32, 100, 101, 97, 99, 116, 105, 118,
  97, 116, 101, 32, 97, 108, 108, 32, 99, 111, 110, 116, 114, 111, 108, 115,
  32, 98, 101, 108, 111, 119, 32, 34, 32, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  109, 111, 117, 110, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 46,
  51, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 68, 97, 114, 107, 110, 101, 115, 115, 47, 108, 105, 103, 104, 116, 110,
  101, 115, 115, 32, 108, 101, 118, 101, 108, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 51, 44, 34, 65, 108, 108, 34, 44, 34, 82,
  71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105,
  110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100,
  32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34,
  66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44,
  34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44,
  34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101,
  34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34,
  86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 65, 108,
  112, 104, 97, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34,
  66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105,
  62, 80, 104, 111, 116, 111, 67, 111, 109, 105, 120, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 50, 47, 57, 47,
  50, 53, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 103, 105, 109, 112, 95, 115, 99, 97, 108, 101, 100, 111, 119, 110,
  51, 32, 58, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 32, 38,
  38, 32, 36, 52, 61, 61, 48, 125, 32, 45, 98, 108, 117, 114, 95, 120,
  121, 32, 123, 119, 47, 36, 53, 125, 44, 123, 104, 47, 36, 54, 125, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 48, 32, 38, 38, 32,
  36, 52, 61, 61, 49, 125, 32, 45, 98, 108, 117, 114, 95, 120, 121, 32,
  123, 119, 47, 36, 53, 125, 44, 123, 119, 47, 36, 54, 125, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 49, 61, 61, 48, 32, 38, 38, 32, 36, 52,
  61, 61, 50, 125, 32, 45, 98, 108, 117, 114, 95, 120, 121, 32, 123, 104,
  47, 36, 53, 125, 44, 123, 119, 47, 36, 54, 125, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 61, 61, 49, 32, 38, 38, 32, 36, 52, 61, 61,
  48, 125, 32, 45, 98, 108, 117, 114, 95, 120, 121, 32, 36, 50, 32, 44,
  36, 51, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 32,
  38, 38, 32, 36, 52, 61, 61, 49, 125, 32, 45, 98, 108, 117, 114, 95,
  120, 121, 32, 36, 50, 32, 44, 36, 51, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 49, 61, 61, 49, 32, 38, 38, 32, 36, 52, 61, 61, 50, 125,
  32, 45, 98, 108, 117, 114, 95, 120, 121, 32, 36, 50, 32, 44, 36, 51,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 52, 61,
  61, 48, 125, 10, 45, 114, 101, 115, 105, 122, 101, 32, 36, 53, 44, 36,
  54, 44, 50, 10, 45, 101, 108, 105, 102, 32, 123, 36, 52, 61, 61, 49,
  125, 10, 45, 114, 101, 115, 105, 122, 101, 50, 100, 120, 32, 36, 53, 44,
  50, 10, 45, 101, 108, 105, 102, 32, 123, 36, 52, 61, 61, 50, 125, 10,
  45, 114, 101, 115, 105, 122, 101, 50, 100, 121, 32, 36, 54, 44, 50, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 55, 61, 61,
  48, 125, 10, 45, 103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112,
  32, 48, 44, 49, 46, 50, 53, 44, 51, 48, 44, 36, 56, 44, 48, 44,
  36, 57, 44, 123, 36, 57, 47, 51, 125, 44, 49, 44, 48, 44, 36, 49,
  48, 10, 45, 101, 110, 100, 105, 102, 10, 103, 105, 109, 112, 95, 115, 99,
  97, 108, 101, 100, 111, 119, 110, 51, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105, 109, 112, 95, 115, 99,
  97, 108, 101, 100, 111, 119, 110, 51, 32, 36, 123, 49, 45, 45, 50, 125,
  34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 86, 105, 118,
  105, 100, 32, 99, 111, 108, 111, 114, 115, 32, 58, 32, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 118, 105, 118, 105, 100, 95, 99,
  111, 108, 111, 114, 44, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 118, 105, 118, 105, 100, 95, 99, 111, 108, 111, 114, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97,
  121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32,
  50, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 32, 40, 34, 84, 104, 105, 115, 32, 102, 105, 108,
  116, 101, 114, 32, 110, 101, 101, 100, 115, 32, 116, 119, 111, 32, 108, 97,
  121, 101, 114, 115, 32, 116, 111, 32, 119, 111, 114, 107, 32, 112, 114, 111,
  112, 101, 114, 108, 121, 46, 32, 83, 101, 116, 32, 116, 104, 101, 32, 60,
  105, 62, 73, 110, 112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 60, 47,
  105, 62, 32, 111, 112, 116, 105, 111, 110, 32, 116, 111, 32, 104, 97, 110,
  100, 108, 101, 32, 109, 117, 108, 116, 105, 112, 108, 101, 32, 105, 110, 112,
  117, 116, 32, 108, 97, 121, 101, 114, 115, 46, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 58, 32, 60, 105, 62, 80, 104, 111, 116, 111, 67, 111, 109,
  105, 88, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62,
  50, 48, 49, 49, 47, 49, 49, 47, 49, 51, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 118, 105, 118, 105, 100, 95, 99, 111, 108,
  111, 114, 32, 58, 10, 45, 114, 101, 118, 101, 114, 115, 101, 32, 45, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103, 104,
  116, 110, 101, 115, 115, 32, 36, 49, 44, 36, 50, 32, 45, 45, 103, 105,
  109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 32, 45, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 115, 111, 102, 116,
  108, 105, 103, 104, 116, 32, 36, 51, 44, 48, 10, 35, 64, 103, 105, 109,
  112, 32, 86, 105, 118, 105, 100, 32, 101, 100, 103, 101, 115, 32, 58, 32,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 118, 105, 118,
  105, 100, 101, 100, 103, 101, 115, 44, 32, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 118, 105, 118, 105, 100, 101, 100, 103, 101, 115,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116,
  121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101, 115, 32,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 53, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121, 101,
  114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 50, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 44, 48, 44, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 32, 40, 34, 84, 104, 105, 115, 32, 102, 105, 108,
  116, 101, 114, 32, 110, 101, 101, 100, 115, 32, 116, 119, 111, 32, 108, 97,
  121, 101, 114, 115, 32, 116, 111, 32, 119, 111, 114, 107, 32, 112, 114, 111,
  112, 101, 114, 108, 121, 46, 32, 83, 101, 116, 32, 116, 104, 101, 32, 60,
  105, 62, 73, 110, 112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 60, 47,
  105, 62, 32, 111, 112, 116, 105, 111, 110, 32, 116, 111, 32, 104, 97, 110,
  100, 108, 101, 32, 109, 117, 108, 116, 105, 112, 108, 101, 32, 105, 110, 112,
  117, 116, 32, 108, 97, 121, 101, 114, 115, 46, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 58, 32, 60, 105, 62, 80, 104, 111, 116, 111, 67, 111, 109,
  105, 88, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62,
  50, 48, 49, 49, 47, 49, 49, 47, 49, 51, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 118, 105, 118, 105, 100, 101, 100, 103, 101,
  115, 32, 58, 10, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 101, 100, 103, 101, 115, 32, 36, 49, 44, 36, 50, 44, 36, 51,
  32, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105,
  110, 103, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 111, 118, 101, 114, 108, 97, 121, 32, 36, 52, 44, 48, 10, 35, 64,
  103, 105, 109, 112, 32, 86, 105, 118, 105, 100, 32, 115, 99, 114, 101, 101,
  110, 32, 58, 32, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 118, 105, 118, 105, 100, 115, 99, 114, 101, 101, 110, 32, 44, 32, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 118, 105, 118, 105,
  100, 115, 99, 114, 101, 101, 110, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 54, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121, 101, 114, 115,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 50, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 55, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 32, 40, 34, 84, 104, 105, 115, 32, 102, 105, 108, 116, 101,
  114, 32, 110, 101, 101, 100, 115, 32, 116, 119, 111, 32, 108, 97, 121, 101,
  114, 115, 32, 116, 111, 32, 119, 111, 114, 107, 32, 112, 114, 111, 112, 101,
  114, 108, 121, 46, 32, 83, 101, 116, 32, 116, 104, 101, 32, 60, 105, 62,
  73, 110, 112, 117, 116, 32, 108, 97, 121, 101, 114, 115, 60, 47, 105, 62,
  32, 111, 112, 116, 105, 111, 110, 32, 116, 111, 32, 104, 97, 110, 100, 108,
  101, 32, 109, 117, 108, 116, 105, 112, 108, 101, 32, 105, 110, 112, 117, 116,
  32, 108, 97, 121, 101, 114, 115, 46, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 58, 32, 60, 105, 62, 80, 104, 111, 116, 111, 67, 111, 109, 105, 88,
  60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48,
  49, 49, 47, 49, 49, 47, 49, 51, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 118, 105, 118, 105, 100, 115, 99, 114, 101, 101, 110,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 115, 99, 114, 101, 101, 110, 32, 36, 49, 44, 36, 50, 32, 45, 45,
  103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 32,
  45, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 111, 118,
  101, 114, 108, 97, 121, 32, 36, 51, 44, 48, 10, 35, 64, 103, 105, 109,
  112, 32, 95, 10, 35, 64, 103, 105, 109, 112, 32, 60, 105, 62, 82, 108,
  60, 47, 105, 62, 10, 35, 64, 103, 105, 109, 112, 32, 80, 108, 97, 115,
  109, 97, 32, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 32, 58, 32,
  112, 108, 97, 115, 109, 97, 95, 116, 114, 97, 110, 115, 105, 116, 105, 111,
  110, 44, 32, 112, 108, 97, 115, 109, 97, 95, 116, 114, 97, 110, 115, 105,
  116, 105, 111, 110, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 97,
  108, 97, 110, 99, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 99, 97, 108, 101, 32, 61, 32, 105, 110, 116, 40, 53, 44, 48, 44,
  53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 82, 97, 110, 100, 111, 109, 32, 105, 110, 105, 116, 105, 97, 108, 105,
  122, 97, 116, 105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 52, 50, 44,
  49, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 115, 58, 32,
  60, 105, 62, 74, 101, 97, 110, 45, 66, 97, 112, 116, 105, 115, 116, 101,
  32, 82, 111, 108, 108, 97, 110, 100, 44, 32, 74, 117, 108, 105, 101, 110,
  32, 76, 101, 118, 105, 108, 108, 97, 105, 110, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 51, 47, 50,
  56, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 112, 108, 97, 115, 109, 97, 95, 116, 114, 97, 110, 115, 105, 116, 105,
  111, 110, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34, 105, 115, 105, 110,
  116, 40, 36, 123, 52, 61, 52, 50, 125, 41, 32, 38, 38, 32, 105, 115,
  105, 110, 116, 40, 36, 123, 50, 61, 53, 125, 41, 32, 38, 38, 32, 36,
  123, 49, 61, 48, 46, 53, 125, 62, 61, 48, 32, 32, 38, 38, 32, 36,
  49, 60, 61, 49, 32, 38, 38, 32, 36, 50, 62, 61, 48, 32, 38, 38,
  32, 36, 123, 51, 61, 49, 125, 62, 61, 48, 34, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 46, 48, 41,
  125, 10, 45, 108, 111, 99, 97, 108, 91, 123, 36, 62, 125, 44, 123, 36,
  62, 43, 49, 125, 93, 10, 45, 105, 102, 32, 123, 64, 35, 60, 50, 125,
  32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 114, 32, 64, 123, 45, 109, 97, 120, 95, 119, 104, 100, 115, 125, 44,
  51, 10, 49, 48, 48, 37, 44, 49, 48, 48, 37, 32, 45, 115, 114, 97,
  110, 100, 32, 36, 52, 32, 45, 112, 108, 97, 115, 109, 97, 91, 45, 49,
  93, 32, 49, 44, 48, 44, 36, 50, 32, 45, 110, 91, 45, 49, 93, 32,
  48, 44, 49, 10, 45, 45, 108, 101, 91, 45, 49, 93, 32, 36, 49, 32,
  45, 98, 91, 45, 49, 93, 32, 36, 51, 10, 45, 114, 109, 91, 45, 50,
  93, 10, 45, 106, 91, 45, 51, 93, 32, 91, 45, 50, 93, 44, 48, 44,
  48, 44, 48, 44, 48, 44, 49, 44, 91, 45, 49, 93, 10, 45, 107, 101,
  101, 112, 91, 45, 51, 93, 10, 45, 101, 110, 100, 108, 111, 99, 97, 108,
  10, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 82, 97,
  110, 100, 111, 109, 119, 97, 118, 101, 115, 32, 58, 32, 114, 97, 110, 100,
  111, 109, 119, 97, 118, 101, 115, 44, 32, 114, 97, 110, 100, 111, 109, 119,
  97, 118, 101, 115, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 116,
  101, 112, 115, 32, 110, 117, 109, 98, 101, 114, 32, 61, 32, 105, 110, 116,
  40, 56, 52, 44, 49, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 80, 114, 111, 98, 97, 98, 105, 108, 105, 116, 121,
  32, 111, 102, 32, 105, 109, 112, 117, 108, 115, 101, 32, 40, 37, 32, 47,
  32, 115, 116, 101, 112, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 56,
  48, 46, 44, 49, 46, 44, 49, 48, 48, 46, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 76, 101, 115, 115, 101, 110, 105, 110, 103, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 46, 50, 44, 48, 46, 48, 49, 44,
  49, 48, 46, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97,
  110, 100, 111, 109, 32, 105, 110, 105, 116, 105, 97, 108, 105, 122, 97, 116,
  105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 52, 50, 44, 49, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 115, 58, 32, 60, 105, 62,
  74, 101, 97, 110, 45, 66, 97, 112, 116, 105, 115, 116, 101, 32, 82, 111,
  108, 108, 97, 110, 100, 44, 32, 74, 117, 108, 105, 101, 110, 32, 76, 101,
  118, 105, 108, 108, 97, 105, 110, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 51, 47, 50, 56, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 114, 97,
  110, 100, 111, 109, 119, 97, 118, 101, 115, 58, 32, 32, 45, 99, 104, 101,
  99, 107, 32, 32, 34, 105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 56,
  52, 125, 41, 32, 32, 38, 38, 32, 32, 36, 123, 50, 61, 56, 48, 125,
  62, 61, 48, 32, 32, 38, 38, 32, 32, 36, 50, 60, 61, 49, 48, 48,
  32, 32, 38, 38, 32, 36, 123, 51, 61, 49, 46, 50, 125, 62, 48, 46,
  32, 38, 38, 32, 105, 115, 105, 110, 116, 40, 36, 123, 52, 61, 52, 50,
  125, 41, 34, 10, 45, 115, 114, 97, 110, 100, 32, 36, 52, 10, 40, 48,
  44, 49, 44, 48, 59, 49, 44, 48, 44, 49, 59, 48, 44, 49, 44, 48,
  41, 32, 45, 47, 91, 45, 49, 93, 32, 50, 10, 45, 110, 109, 91, 45,
  49, 93, 32, 109, 97, 116, 99, 111, 110, 118, 10, 64, 123, 48, 44, 119,
  125, 44, 64, 123, 48, 44, 104, 125, 44, 49, 44, 49, 32, 45, 115, 101,
  116, 91, 45, 49, 93, 32, 50, 53, 53, 44, 123, 63, 40, 49, 48, 48,
  41, 125, 37, 44, 123, 63, 40, 49, 48, 48, 41, 125, 37, 10, 91, 45,
  49, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 49, 10, 91, 45,
  49, 93, 10, 45, 105, 102, 32, 123, 36, 123, 50, 125, 62, 61, 63, 40,
  49, 48, 48, 41, 125, 10, 45, 99, 105, 114, 99, 108, 101, 91, 45, 49,
  93, 32, 123, 63, 40, 49, 48, 48, 41, 125, 37, 44, 123, 63, 40, 49,
  48, 48, 41, 125, 37, 44, 123, 63, 40, 51, 41, 125, 44, 44, 50, 53,
  53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 99, 111, 110, 118, 111, 108,
  118, 101, 91, 45, 49, 93, 32, 91, 109, 97, 116, 99, 111, 110, 118, 93,
  32, 45, 100, 105, 118, 91, 45, 49, 93, 32, 36, 51, 32, 45, 115, 117,
  98, 91, 45, 49, 93, 32, 91, 45, 51, 93, 10, 45, 114, 109, 91, 45,
  51, 93, 10, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 45, 50, 44,
  109, 97, 116, 99, 111, 110, 118, 93, 10, 45, 103, 91, 45, 49, 93, 32,
  45, 97, 91, 45, 49, 44, 45, 50, 93, 32, 99, 32, 45, 119, 97, 114,
  112, 91, 48, 93, 32, 91, 45, 49, 93, 44, 49, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 35, 64, 103, 105, 109, 112, 32, 95, 10, 35, 64, 103,
  105, 109, 112, 32, 60, 105, 62, 82, 111, 110, 111, 117, 110, 111, 117, 114,
  115, 60, 47, 105, 62, 10, 35, 64, 103, 105, 109, 112, 32, 65, 117, 116,
  111, 45, 97, 100, 106, 117, 115, 116, 32, 111, 114, 105, 101, 110, 116, 97,
  116, 105, 111, 110, 32, 58, 32, 103, 105, 109, 112, 95, 97, 100, 106, 117,
  115, 116, 95, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 44, 32,
  103, 105, 109, 112, 95, 97, 100, 106, 117, 115, 116, 95, 111, 114, 105, 101,
  110, 116, 97, 116, 105, 111, 110, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 49, 48, 48, 41, 10, 103,
  105, 109, 112, 95, 97, 100, 106, 117, 115, 116, 95, 111, 114, 105, 101, 110,
  116, 97, 116, 105, 111, 110, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 10, 77, 61, 123, 109, 97, 120, 40, 119, 44, 104, 41, 125,
  10, 45, 45, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109,
  91, 45, 49, 93, 32, 45, 103, 101, 91, 45, 49, 93, 32, 36, 49, 37,
  10, 45, 45, 42, 91, 45, 49, 93, 32, 39, 49, 43, 121, 39, 32, 45,
  42, 91, 45, 50, 93, 32, 39, 49, 43, 120, 39, 32, 45, 97, 91, 45,
  50, 44, 45, 49, 93, 32, 99, 10, 45, 114, 91, 45, 49, 93, 32, 123,
  119, 42, 104, 125, 44, 50, 44, 49, 44, 49, 44, 45, 49, 32, 45, 115,
  111, 114, 116, 91, 45, 49, 93, 32, 43, 44, 120, 32, 45, 97, 117, 116,
  111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 48, 10, 45, 47, 91, 45,
  49, 93, 32, 36, 77, 32, 45, 45, 114, 91, 45, 49, 93, 32, 49, 44,
  50, 44, 49, 44, 49, 44, 50, 32, 45, 114, 91, 45, 49, 93, 32, 91,
  45, 50, 93, 32, 45, 45, 91, 45, 50, 44, 45, 49, 93, 10, 45, 45,
  116, 114, 97, 110, 115, 112, 111, 115, 101, 91, 45, 49, 93, 32, 45, 42,
  42, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 105, 103, 101, 110, 91,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45, 122, 91, 45,
  49, 93, 32, 48, 44, 48, 10, 45, 105, 102, 32, 123, 105, 60, 48, 125,
  32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 101, 110, 100, 105,
  102, 10, 116, 104, 101, 116, 97, 61, 123, 49, 56, 48, 42, 97, 116, 97,
  110, 50, 40, 105, 40, 48, 44, 49, 41, 44, 105, 41, 47, 112, 105, 125,
  10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 119, 62,
  104, 125, 32, 45, 114, 111, 116, 97, 116, 101, 91, 45, 49, 93, 32, 123,
  45, 36, 116, 104, 101, 116, 97, 125, 44, 49, 44, 48, 44, 53, 48, 37,
  44, 53, 48, 37, 10, 45, 101, 108, 115, 101, 32, 45, 114, 111, 116, 97,
  116, 101, 91, 45, 49, 93, 32, 123, 45, 36, 116, 104, 101, 116, 97, 43,
  57, 48, 125, 44, 49, 44, 48, 44, 53, 48, 37, 44, 53, 48, 37, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48,
  32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 67, 105,
  114, 99, 108, 105, 115, 109, 32, 58, 32, 103, 105, 109, 112, 95, 99, 105,
  114, 99, 108, 105, 115, 109, 44, 32, 103, 105, 109, 112, 95, 110, 111, 95,
  112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 77, 105, 110, 32, 114, 97, 100, 105, 117, 115, 32, 61, 32, 105, 110,
  116, 40, 50, 44, 49, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 77, 97, 120, 32, 114, 97, 100, 105, 117, 115, 32, 61,
  32, 105, 110, 116, 40, 49, 48, 44, 49, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101,
  32, 108, 105, 110, 101, 97, 114, 105, 116, 121, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 52, 44, 48, 46, 48, 49, 44, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 76, 111, 99, 97, 116, 105, 111, 110,
  32, 108, 105, 110, 101, 97, 114, 105, 116, 121, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 51, 44, 48, 46, 48, 49, 44, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 104, 97, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 50, 44, 34, 68, 105, 97, 109, 111, 110, 100, 115,
  34, 44, 34, 83, 113, 117, 97, 114, 101, 115, 34, 44, 34, 67, 105, 114,
  99, 108, 101, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 121, 32, 61, 32, 98,
  111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60,
  105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101,
  114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 49, 48, 47, 49, 54, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103,
  105, 109, 112, 95, 99, 105, 114, 99, 108, 105, 115, 109, 32, 58, 10, 45,
  116, 111, 95, 114, 103, 98, 32, 45, 99, 105, 114, 99, 108, 105, 115, 109,
  32, 36, 123, 49, 45, 54, 125, 10, 45, 105, 102, 32, 36, 55, 32, 45,
  116, 111, 95, 114, 103, 98, 97, 32, 45, 114, 101, 112, 108, 97, 99, 101,
  95, 99, 111, 108, 111, 114, 32, 48, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 48, 32, 45, 101, 110,
  100, 105, 102, 10, 35, 64, 103, 105, 109, 112, 32, 70, 97, 100, 101, 100,
  32, 109, 105, 114, 114, 111, 114, 32, 58, 32, 103, 105, 109, 112, 95, 102,
  97, 100, 101, 100, 95, 109, 105, 114, 114, 111, 114, 44, 32, 103, 105, 109,
  112, 95, 102, 97, 100, 101, 100, 95, 109, 105, 114, 114, 111, 114, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 120, 105, 115, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 120, 45, 97, 120, 105, 115,
  34, 44, 34, 121, 45, 97, 120, 105, 115, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 70, 97, 100, 105, 110, 103, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 79, 118, 101, 114, 108, 97, 112, 112, 105,
  110, 103, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 51, 47, 48, 53, 47, 50, 57, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 102, 97, 100, 101, 100, 95, 109, 105, 114, 114, 111, 114, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 125, 10, 49,
  48, 48, 37, 44, 49, 44, 49, 44, 49, 44, 34, 97, 61, 49, 47, 40,
  49, 45, 119, 42, 36, 50, 37, 41, 59, 98, 61, 45, 97, 42, 40, 119,
  45, 49, 41, 59, 97, 42, 120, 43, 98, 34, 32, 45, 99, 91, 45, 49,
  93, 32, 48, 46, 48, 49, 44, 49, 32, 45, 42, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 10, 45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37,
  44, 91, 45, 50, 93, 32, 45, 97, 32, 99, 32, 45, 114, 32, 123, 50,
  42, 119, 45, 119, 42, 36, 51, 37, 125, 44, 49, 48, 48, 37, 44, 49,
  44, 49, 48, 48, 37, 44, 48, 32, 45, 45, 109, 105, 114, 114, 111, 114,
  32, 120, 10, 45, 101, 108, 115, 101, 10, 49, 44, 49, 48, 48, 37, 44,
  49, 44, 49, 44, 34, 97, 61, 49, 47, 40, 49, 45, 104, 42, 36, 50,
  37, 41, 59, 98, 61, 45, 97, 42, 40, 104, 45, 49, 41, 59, 97, 42,
  121, 43, 98, 34, 32, 45, 99, 91, 45, 49, 93, 32, 48, 46, 48, 49,
  44, 49, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 49,
  48, 48, 37, 32, 45, 42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 10,
  45, 97, 32, 99, 32, 45, 114, 32, 49, 48, 48, 37, 44, 123, 50, 42,
  104, 45, 104, 42, 36, 51, 37, 125, 44, 49, 44, 49, 48, 48, 37, 44,
  48, 32, 45, 45, 109, 105, 114, 114, 111, 114, 32, 121, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 43, 32, 45, 115, 91, 45, 49, 93, 32, 99, 44,
  45, 123, 115, 45, 49, 125, 32, 45, 47, 91, 45, 50, 44, 45, 49, 93,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103,
  105, 109, 112, 32, 79, 108, 100, 32, 99, 117, 98, 105, 115, 109, 32, 58,
  32, 103, 105, 109, 112, 95, 111, 108, 100, 95, 99, 117, 98, 105, 115, 109,
  44, 32, 103, 105, 109, 112, 95, 111, 108, 100, 95, 99, 117, 98, 105, 115,
  109, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116,
  101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 51,
  48, 48, 44, 49, 44, 52, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 66, 108, 111, 99, 32, 115, 105, 122, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 52, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 57, 48, 44, 48, 44, 51, 54, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 44, 48, 46, 48,
  49, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32,
  60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112,
  101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 58, 32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  103, 105, 109, 112, 95, 111, 108, 100, 95, 99, 117, 98, 105, 115, 109, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 49, 54, 48, 125,
  44, 36, 123, 50, 61, 49, 48, 125, 44, 36, 123, 51, 61, 55, 53, 125,
  44, 36, 123, 52, 61, 48, 46, 55, 125, 44, 36, 123, 53, 61, 48, 125,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32,
  99, 117, 98, 105, 115, 109, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110,
  32, 105, 109, 97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 36,
  49, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 44, 32, 98, 108,
  111, 99, 32, 115, 105, 122, 101, 32, 36, 50, 37, 44, 32, 109, 97, 120,
  105, 109, 117, 109, 32, 97, 110, 103, 108, 101, 32, 36, 51, -62, -80, 44,
  32, 111, 112, 97, 99, 105, 116, 121, 32, 36, 52, 32, 97, 110, 100, 32,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 36, 53, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 77, 61, 123, 36, 50, 42, 109, 97, 120,
  40, 119, 44, 104, 41, 47, 50, 48, 48, 125, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 36, 49, 10, 40, 123, 63, 40, 48, 44, 119, 41, 125, 44,
  123, 63, 40, 48, 44, 104, 41, 125, 41, 10, 45, 45, 122, 91, 45, 50,
  93, 32, 123, 64, 123, 45, 49, 44, 48, 125, 45, 36, 77, 125, 44, 123,
  64, 123, 45, 49, 44, 49, 125, 45, 36, 77, 125, 44, 123, 64, 123, 45,
  49, 44, 48, 125, 43, 36, 77, 125, 44, 123, 64, 123, 45, 49, 44, 49,
  125, 43, 36, 77, 125, 44, 49, 10, 45, 98, 91, 45, 49, 93, 32, 36,
  53, 32, 45, 45, 102, 91, 45, 49, 93, 32, 49, 32, 45, 114, 111, 116,
  97, 116, 101, 91, 45, 50, 44, 45, 49, 93, 32, 123, 63, 40, 45, 36,
  51, 44, 36, 51, 41, 125, 44, 48, 44, 48, 10, 45, 106, 91, 45, 52,
  93, 32, 91, 45, 50, 93, 44, 123, 64, 123, 45, 51, 44, 48, 125, 45,
  36, 77, 125, 44, 123, 64, 123, 45, 51, 44, 49, 125, 45, 36, 77, 125,
  44, 48, 44, 48, 44, 36, 52, 44, 91, 45, 49, 93, 32, 45, 107, 91,
  48, 93, 10, 45, 100, 111, 110, 101, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 35, 64, 103, 105, 109, 112,
  32, 80, 101, 114, 115, 112, 101, 99, 116, 105, 118, 101, 32, 115, 99, 97,
  108, 101, 32, 58, 32, 103, 105, 109, 112, 95, 112, 101, 114, 115, 112, 101,
  99, 116, 105, 118, 101, 95, 115, 99, 97, 108, 101, 44, 32, 103, 105, 109,
  112, 95, 112, 101, 114, 115, 112, 101, 99, 116, 105, 118, 101, 95, 115, 99,
  97, 108, 101, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101, 114, 97, 116, 105, 111,
  110, 115, 32, 61, 32, 105, 110, 116, 40, 50, 44, 50, 44, 49, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 97, 99, 116, 111, 114,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 55, 53, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 111, 102,
  102, 115, 101, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45,
  49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 89, 45, 111, 102, 102, 115, 101, 116, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 109,
  111, 100, 101, 32, 61, 32, 95, 99, 104, 111, 105, 99, 101, 40, 34, 83,
  105, 110, 103, 108, 101, 32, 108, 97, 121, 101, 114, 34, 44, 34, 77, 117,
  108, 116, 105, 112, 108, 101, 32, 108, 97, 121, 101, 114, 115, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 51, 47, 48, 50, 47, 48, 56, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 112, 101, 114,
  115, 112, 101, 99, 116, 105, 118, 101, 95, 115, 99, 97, 108, 101, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  60, 93, 32, 45, 116, 111, 95, 114, 103, 98, 97, 10, 119, 61, 123, 119,
  125, 32, 104, 61, 123, 104, 125, 10, 102, 61, 49, 48, 48, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 123, 36, 49, 45, 49, 125, 32, 102, 61, 123,
  36, 102, 42, 36, 50, 37, 125, 32, 45, 45, 114, 91, 48, 93, 32, 36,
  102, 37, 44, 36, 102, 37, 44, 49, 44, 52, 44, 50, 32, 45, 100, 111,
  110, 101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49,
  125, 32, 45, 108, 91, 123, 36, 62, 43, 49, 125, 93, 10, 115, 120, 61,
  123, 40, 36, 62, 43, 49, 41, 42, 36, 119, 42, 36, 51, 37, 47, 40,
  36, 49, 45, 49, 41, 125, 10, 115, 121, 61, 123, 40, 36, 62, 43, 49,
  41, 42, 36, 104, 42, 36, 52, 37, 47, 40, 36, 49, 45, 49, 41, 125,
  10, 45, 114, 32, 36, 119, 44, 36, 104, 44, 49, 44, 52, 44, 48, 44,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 115, 104, 105, 102, 116,
  91, 45, 49, 93, 32, 36, 115, 120, 44, 36, 115, 121, 44, 48, 44, 48,
  44, 48, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 45,
  105, 102, 32, 123, 33, 36, 53, 125, 32, 45, 114, 101, 112, 101, 97, 116,
  32, 123, 64, 35, 45, 49, 125, 32, 45, 98, 108, 101, 110, 100, 91, 48,
  44, 49, 93, 32, 97, 108, 112, 104, 97, 44, 49, 44, 49, 32, 45, 100,
  111, 110, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 112, 101, 114, 115,
  112, 101, 99, 116, 105, 118, 101, 95, 115, 99, 97, 108, 101, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 112, 101,
  114, 115, 112, 101, 99, 116, 105, 118, 101, 95, 115, 99, 97, 108, 101, 32,
  36, 123, 49, 45, 52, 125, 44, 48, 10, 35, 64, 103, 105, 109, 112, 32,
  83, 104, 97, 100, 101, 100, 32, 115, 101, 103, 109, 101, 110, 116, 97, 116,
  105, 111, 110, 32, 58, 32, 100, 116, 95, 115, 101, 103, 109, 101, 110, 116,
  95, 115, 104, 97, 100, 101, 100, 44, 100, 116, 95, 115, 101, 103, 109, 101,
  110, 116, 95, 115, 104, 97, 100, 101, 100, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 101, 110, 115, 105, 116, 121, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 51, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 104, 97, 100, 105, 110, 103, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 55, 44, 48, 44, 50, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 51, 47, 48, 50, 47, 48, 49, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 100, 116, 95, 115, 101,
  103, 109, 101, 110, 116, 95, 115, 104, 97, 100, 101, 100, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 98, 32, 36, 51, 32, 45, 115, 101, 103, 109, 101, 110, 116, 95,
  119, 97, 116, 101, 114, 115, 104, 101, 100, 32, 36, 49, 44, 49, 10, 45,
  45, 103, 32, 120, 121, 44, 49, 32, 45, 97, 91, 45, 50, 44, 45, 49,
  93, 32, 99, 32, 45, 110, 111, 114, 109, 91, 45, 49, 93, 32, 45, 110,
  101, 113, 91, 45, 49, 93, 32, 48, 32, 45, 100, 105, 115, 116, 97, 110,
  99, 101, 91, 49, 93, 32, 49, 32, 45, 110, 111, 114, 109, 97, 108, 105,
  122, 101, 95, 108, 111, 99, 97, 108, 91, 45, 49, 93, 32, 49, 48, 48,
  48, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 49, 32, 45, 94, 91,
  45, 49, 93, 32, 123, 109, 97, 120, 40, 49, 101, 45, 53, 44, 36, 50,
  41, 125, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10,
  45, 98, 108, 101, 110, 100, 32, 118, 97, 108, 117, 101, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32,
  83, 104, 97, 114, 112, 101, 110, 32, 91, 117, 110, 115, 104, 97, 114, 112,
  32, 109, 97, 115, 107, 59, 32, 49, 54, 98, 105, 116, 115, 93, 32, 58,
  32, 103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112, 49, 54, 44,
  32, 103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112, 49, 54, 95,
  112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 73, 110, 112, 117, 116, 32, 105, 109, 97, 103, 101, 32,
  61, 32, 102, 105, 108, 101, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 79, 117, 116, 112, 117, 116, 32, 105, 109, 97, 103, 101, 32, 61,
  32, 116, 101, 120, 116, 40, 34, 103, 109, 105, 99, 95, 117, 110, 115, 104,
  97, 114, 112, 49, 54, 46, 112, 110, 103, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 92, 110, 60, 98, 62, 70, 105, 108, 116, 101, 114, 32, 112, 97,
  114, 97, 109, 101, 116, 101, 114, 115, 32, 58, 60, 47, 98, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 114, 112, 101,
  110, 105, 110, 103, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 48, 44, 34, 71, 97, 117, 115, 115, 105, 97, 110, 34, 44,
  34, 66, 105, 108, 97, 116, 101, 114, 97, 108, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 112, 97, 116, 105, 97, 108, 32, 114, 97,
  100, 105, 117, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 50,
  53, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 66, 105, 108, 97, 116, 101, 114, 97, 108, 32, 114, 97, 100, 105, 117,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 48, 44, 48, 44, 54,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 111, 117,
  110, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44, 48, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101,
  115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68,
  97, 114, 107, 110, 101, 115, 115, 32, 108, 101, 118, 101, 108, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 52, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 76, 105, 103, 104, 116, 110, 101, 115, 115, 32,
  108, 101, 118, 101, 108, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44,
  48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116,
  101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 49,
  44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 101, 103, 97, 116, 105, 118, 101, 32, 101, 102, 102, 101, 99, 116, 32,
  61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71,
  66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32,
  99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66,
  108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34,
  44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34,
  97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34,
  97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34,
  44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86,
  97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 65, 108, 112,
  104, 97, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66,
  108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 123, 34, 92, 110, 92, 110, 60, 115, 109, 97, 108, 108, 62, 60,
  98, 62, 78, 111, 116, 101, 58, 32, 60, 47, 98, 62, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 84, 104, 105, 115, 32, 102, 105, 108, 116, 101,
  114, 32, 105, 115, 32, 105, 110, 115, 112, 105, 114, 101, 100, 32, 98, 121,
  32, 116, 104, 101, 32, 111, 114, 105, 103, 105, 110, 97, 108, 32, 60, 105,
  62, 85, 110, 115, 104, 97, 114, 112, 32, 77, 97, 115, 107, 60, 47, 105,
  62, 32, 102, 105, 108, 116, 101, 114, 32, 105, 110, 32, 71, 73, 77, 80,
  44, 32, 119, 105, 116, 104, 32, 97, 100, 100, 105, 116, 105, 111, 110, 97,
  108, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 46, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118,
  105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50,
  51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62,
  50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 117,
  110, 115, 104, 97, 114, 112, 49, 54, 32, 58, 10, 45, 114, 109, 32, 45,
  105, 32, 36, 49, 32, 45, 47, 32, 50, 53, 54, 10, 45, 103, 105, 109,
  112, 95, 117, 110, 115, 104, 97, 114, 112, 32, 36, 123, 51, 45, 45, 49,
  125, 10, 45, 42, 32, 50, 53, 54, 32, 45, 105, 102, 32, 123, 110, 97,
  114, 103, 40, 36, 50, 41, 125, 32, 45, 111, 32, 36, 50, 32, 45, 101,
  110, 100, 105, 102, 32, 45, 47, 32, 50, 53, 54, 10, 103, 105, 109, 112,
  95, 117, 110, 115, 104, 97, 114, 112, 49, 54, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 105, 32, 36, 49, 32, 45, 122, 91, 45, 49,
  93, 32, 123, 109, 97, 120, 40, 48, 44, 40, 119, 45, 64, 123, 45, 50,
  44, 119, 125, 41, 47, 50, 41, 125, 44, 123, 109, 97, 120, 40, 48, 44,
  40, 104, 45, 64, 123, 45, 50, 44, 104, 125, 41, 47, 50, 41, 125, 44,
  123, 109, 105, 110, 40, 119, 45, 49, 44, 40, 119, 43, 64, 123, 45, 50,
  44, 119, 125, 41, 47, 50, 41, 125, 44, 123, 109, 105, 110, 40, 104, 45,
  49, 44, 40, 104, 43, 64, 123, 45, 50, 44, 104, 125, 41, 47, 50, 41,
  125, 32, 45, 107, 91, 45, 49, 93, 32, 45, 47, 32, 50, 53, 54, 10,
  45, 103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112, 32, 36, 123,
  51, 45, 45, 49, 125, 10, 35, 64, 103, 105, 109, 112, 32, 83, 109, 111,
  111, 116, 104, 32, 91, 97, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99,
  59, 32, 49, 54, 98, 105, 116, 115, 93, 32, 58, 32, 103, 105, 109, 112,
  95, 97, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111,
  111, 116, 104, 105, 110, 103, 49, 54, 44, 32, 103, 105, 109, 112, 95, 97,
  110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116,
  104, 105, 110, 103, 49, 54, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 112, 117, 116,
  32, 105, 109, 97, 103, 101, 32, 61, 32, 102, 105, 108, 101, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32,
  105, 109, 97, 103, 101, 32, 61, 32, 116, 101, 120, 116, 40, 34, 103, 109,
  105, 99, 95, 97, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 49, 54,
  46, 112, 110, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 92, 110, 60,
  98, 62, 70, 105, 108, 116, 101, 114, 32, 112, 97, 114, 97, 109, 101, 116,
  101, 114, 115, 32, 58, 60, 47, 98, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 54, 48, 44, 48, 44, 49, 48, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 114, 112,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55,
  44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  110, 105, 115, 111, 116, 114, 111, 112, 121, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 51, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 71, 114, 97, 100, 105, 101, 110, 116, 32, 115, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 54, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 84, 101, 110, 115, 111, 114, 32, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 49,
  44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 112, 97, 116, 105, 97, 108, 32, 112, 114, 101, 99, 105, 115, 105, 111,
  110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 56, 44, 48, 46,
  49, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110,
  103, 117, 108, 97, 114, 32, 112, 114, 101, 99, 105, 115, 105, 111, 110, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 51, 48, 44, 49, 44, 49, 56, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108, 117, 101,
  32, 112, 114, 101, 99, 105, 115, 105, 111, 110, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 50, 44, 48, 46, 49, 44, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105,
  111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 78,
  101, 97, 114, 101, 115, 116, 32, 110, 101, 105, 103, 104, 98, 111, 114, 34,
  44, 34, 76, 105, 110, 101, 97, 114, 34, 44, 34, 82, 117, 110, 103, 101,
  45, 75, 117, 116, 116, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 70, 97, 115, 116, 32, 97, 112, 112, 114, 111, 120, 105, 109, 97,
  116, 105, 111, 110, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101, 114, 97, 116, 105, 111,
  110, 115, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49, 44, 49, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101,
  108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65,
  108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34,
  44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108,
  117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110,
  99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114,
  111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116,
  110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116,
  105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101,
  121, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34, 99, 104, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114,
  101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112,
  104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 105,
  108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49, 44, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118,
  105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50,
  51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62,
  50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 97,
  110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116,
  104, 105, 110, 103, 49, 54, 32, 58, 10, 45, 114, 109, 32, 45, 105, 32,
  36, 49, 32, 45, 47, 32, 50, 53, 54, 10, 45, 103, 105, 109, 112, 95,
  97, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111,
  116, 104, 105, 110, 103, 32, 36, 123, 51, 45, 45, 49, 125, 10, 45, 42,
  32, 50, 53, 54, 32, 45, 105, 102, 32, 123, 110, 97, 114, 103, 40, 36,
  50, 41, 125, 32, 45, 111, 32, 36, 50, 32, 45, 101, 110, 100, 105, 102,
  32, 45, 47, 32, 50, 53, 54, 10, 103, 105, 109, 112, 95, 97, 110, 105,
  115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105,
  110, 103, 49, 54, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  105, 32, 36, 49, 32, 45, 122, 91, 45, 49, 93, 32, 123, 109, 97, 120,
  40, 48, 44, 40, 119, 45, 64, 123, 45, 50, 44, 119, 125, 41, 47, 50,
  41, 125, 44, 123, 109, 97, 120, 40, 48, 44, 40, 104, 45, 64, 123, 45,
  50, 44, 104, 125, 41, 47, 50, 41, 125, 44, 123, 109, 105, 110, 40, 119,
  45, 49, 44, 40, 119, 43, 64, 123, 45, 50, 44, 119, 125, 41, 47, 50,
  41, 125, 44, 123, 109, 105, 110, 40, 104, 45, 49, 44, 40, 104, 43, 64,
  123, 45, 50, 44, 104, 125, 41, 47, 50, 41, 125, 32, 45, 107, 91, 45,
  49, 93, 32, 45, 47, 32, 50, 53, 54, 10, 45, 103, 105, 109, 112, 95,
  97, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111,
  116, 104, 105, 110, 103, 32, 36, 123, 51, 45, 45, 49, 125, 10, 35, 64,
  103, 105, 109, 112, 32, 83, 109, 111, 111, 116, 104, 32, 91, 112, 97, 116,
  99, 104, 45, 98, 97, 115, 101, 100, 59, 32, 49, 54, 98, 105, 116, 115,
  93, 32, 58, 32, 103, 105, 109, 112, 95, 112, 97, 116, 99, 104, 95, 115,
  109, 111, 111, 116, 104, 105, 110, 103, 49, 54, 44, 32, 103, 105, 109, 112,
  95, 112, 97, 116, 99, 104, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103,
  49, 54, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 73, 110, 112, 117, 116, 32, 105, 109, 97,
  103, 101, 32, 61, 32, 102, 105, 108, 101, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 105, 109, 97, 103,
  101, 32, 61, 32, 116, 101, 120, 116, 40, 34, 103, 109, 105, 99, 95, 112,
  97, 116, 99, 104, 49, 54, 46, 112, 110, 103, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 92, 110, 60, 98, 62, 70, 105, 108, 116, 101, 114, 32, 112,
  97, 114, 97, 109, 101, 116, 101, 114, 115, 32, 58, 60, 47, 98, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 97, 116, 105,
  97, 108, 32, 118, 97, 114, 105, 97, 110, 99, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 48, 44, 48, 46, 49, 44, 50, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 116, 99, 104, 32, 118,
  97, 114, 105, 97, 110, 99, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 48, 44, 48, 46, 49, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 80, 97, 116, 99, 104, 32, 115, 105, 122, 101, 32,
  61, 32, 105, 110, 116, 40, 51, 44, 50, 44, 50, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 76, 111, 111, 107, 117, 112, 32, 115, 105,
  122, 101, 32, 61, 32, 105, 110, 116, 40, 53, 44, 50, 44, 50, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 116, 99, 104, 32,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 70, 97, 115, 116, 32, 97, 112, 112, 114, 111, 120, 105, 109,
  97, 116, 105, 111, 110, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101, 114, 97, 116, 105,
  111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49, 44, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110,
  101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66,
  34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66,
  108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104,
  116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97,
  116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75,
  101, 121, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34, 99, 104, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71,
  114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108,
  112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105,
  62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114,
  108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 112, 97, 116, 99, 104, 95, 115, 109, 111, 111, 116, 104, 105,
  110, 103, 49, 54, 32, 58, 10, 45, 114, 109, 32, 45, 105, 32, 36, 49,
  32, 45, 47, 32, 50, 53, 54, 10, 45, 103, 105, 109, 112, 95, 112, 97,
  116, 99, 104, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 32, 36, 123,
  51, 45, 45, 49, 125, 10, 45, 42, 32, 50, 53, 54, 32, 45, 105, 102,
  32, 123, 110, 97, 114, 103, 40, 36, 50, 41, 125, 32, 45, 111, 32, 36,
  50, 32, 45, 101, 110, 100, 105, 102, 32, 45, 47, 32, 50, 53, 54, 10,
  103, 105, 109, 112, 95, 112, 97, 116, 99, 104, 95, 115, 109, 111, 111, 116,
  104, 105, 110, 103, 49, 54, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 105, 32, 36, 49, 32, 45, 122, 91, 45, 49, 93, 32, 123, 109,
  97, 120, 40, 48, 44, 40, 119, 45, 64, 123, 45, 50, 44, 119, 125, 41,
  47, 50, 41, 125, 44, 123, 109, 97, 120, 40, 48, 44, 40, 104, 45, 64,
  123, 45, 50, 44, 104, 125, 41, 47, 50, 41, 125, 44, 123, 109, 105, 110,
  40, 119, 45, 49, 44, 40, 119, 43, 64, 123, 45, 50, 44, 119, 125, 41,
  47, 50, 41, 125, 44, 123, 109, 105, 110, 40, 104, 45, 49, 44, 40, 104,
  43, 64, 123, 45, 50, 44, 104, 125, 41, 47, 50, 41, 125, 32, 45, 107,
  91, 45, 49, 93, 32, 45, 47, 32, 50, 53, 54, 10, 45, 103, 105, 109,
  112, 95, 112, 97, 116, 99, 104, 95, 115, 109, 111, 111, 116, 104, 105, 110,
  103, 32, 36, 123, 51, 45, 45, 49, 125, 10, 35, 64, 103, 105, 109, 112,
  32, 95, 10, 35, 64, 103, 105, 109, 112, 32, 60, 105, 62, 83, 97, 109,
  106, 60, 47, 105, 62, 10, 35, 64, 103, 105, 109, 112, 32, 65, 98, 111,
  117, 116, 32, 58, 32, 95, 110, 111, 110, 101, 95, 44, 32, 115, 97, 109,
  106, 95, 97, 98, 111, 117, 116, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 60, 98, 62,
  73, 110, 102, 111, 114, 109, 97, 116, 105, 111, 110, 115, 32, 45, 32, 67,
  111, 109, 112, 105, 108, 97, 116, 105, 111, 110, 115, 32, 58, 60, 47, 98,
  62, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 108, 105, 110, 107, 40, 34, 104, 116, 116, 112, 58, 47, 47,
  119, 119, 119, 46, 97, 108, 106, 97, 99, 111, 109, 46, 99, 111, 109, 47,
  126, 103, 109, 105, 99, 47, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47,
  119, 119, 119, 46, 97, 108, 106, 97, 99, 111, 109, 46, 99, 111, 109, 47,
  126, 103, 109, 105, 99, 47, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 104,
  116, 116, 112, 58, 47, 47, 115, 97, 109, 106, 99, 114, 101, 97, 116, 105,
  111, 110, 115, 46, 98, 108, 111, 103, 115, 112, 111, 116, 46, 99, 97, 47,
  34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 115, 97, 109, 106, 99, 114,
  101, 97, 116, 105, 111, 110, 115, 46, 98, 108, 111, 103, 115, 112, 111, 116,
  46, 99, 97, 47, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 60, 98, 62, 70,
  105, 108, 116, 114, 101, 115, 32, 45, 32, 70, 105, 108, 116, 101, 114, 115,
  32, 58, 60, 47, 98, 62, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 76, 101,
  115, 32, 102, 105, 108, 116, 114, 101, 115, 32, 99, 111, 110, 116, 101, 110,
  117, 115, 32, 100, 97, 110, 115, 32, 99, 101, 32, 114, 92, 51, 48, 51,
  92, 50, 53, 49, 112, 101, 114, 116, 111, 105, 114, 101, 32, 115, 111, 110,
  116, 32, 101, 110, 32, 99, 111, 117, 114, 115, 32, 100, 101, 32, 100, 92,
  51, 48, 51, 92, 50, 53, 49, 118, 101, 108, 111, 112, 112, 101, 109, 101,
  110, 116, 46, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 84, 104, 101, 32,
  102, 105, 108, 116, 101, 114, 115, 32, 100, 101, 102, 105, 110, 101, 100, 32,
  105, 110, 32, 116, 104, 105, 115, 32, 102, 111, 108, 100, 101, 114, 32, 97,
  114, 101, 32, 113, 117, 105, 116, 101, 32, 60, 105, 62, 101, 120, 112, 101,
  114, 105, 109, 101, 110, 116, 97, 108, 60, 47, 105, 62, 32, 97, 110, 100,
  32, 115, 117, 98, 106, 101, 99, 116, 32, 116, 111, 32, 104, 105, 103, 104,
  32, 99, 104, 97, 110, 103, 101, 115, 46, 34, 41, 10, 115, 97, 109, 106,
  95, 97, 98, 111, 117, 116, 32, 58, 10, 45, 116, 101, 120, 116, 32, 66,
  111, 110, 106, 111, 117, 114, 33, 44, 50, 48, 44, 57, 48, 44, 49, 48,
  48, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 48, 48, 10, 115, 97, 109, 106, 95, 114, 105, 101, 110, 95, 97, 114,
  114, 97, 121, 115, 95, 97, 110, 100, 95, 116, 105, 108, 101, 115, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110,
  103, 91, 45, 49, 93, 10, 35, 64, 103, 105, 109, 112, 32, 60, 105, 62,
  65, 114, 114, 97, 121, 115, 32, 38, 97, 109, 112, 59, 32, 116, 105, 108,
  101, 115, 60, 47, 105, 62, 10, 35, 64, 103, 105, 109, 112, 32, 67, 97,
  114, 114, 101, 108, 97, 103, 101, 32, 115, 97, 109, 106, 32, 58, 32, 67,
  97, 114, 114, 101, 108, 97, 103, 101, 95, 115, 97, 109, 106, 44, 32, 67,
  97, 114, 114, 101, 108, 97, 103, 101, 95, 115, 97, 109, 106, 95, 112, 114,
  101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 67, 97, 114, 114, 101, 108, 97, 103, 101, 32,
  47, 32, 84, 105, 108, 101, 115, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 105, 109, 101, 110,
  115, 105, 111, 110, 32, 40, 112, 105, 120, 101, 108, 115, 41, 32, 61, 32,
  105, 110, 116, 40, 56, 44, 54, 44, 51, 50, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 82, 97, 112, 112, 111, 114, 116, 32, 40, 37, 41,
  32, 61, 32, 105, 110, 116, 40, 49, 48, 48, 44, 50, 53, 44, 52, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 67, 111, 117, 108, 101, 117, 114, 115, 32, 47, 32, 67, 111,
  108, 111, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 82, 32, 115, 101, 108, 101, 99, 116,
  105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 50, 53, 53, 44, 48, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 47,
  103, 32, 115, 101, 108, 101, 99, 116, 105, 111, 110, 32, 61, 32, 105, 110,
  116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 66, 32, 115, 101, 108, 101, 99, 116, 105, 111,
  110, 32, 61, 32, 105, 110, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 83, 104, 97, 114, 112, 101, 110, 32, 91, 111, 99, 116, 97,
  118, 101, 32, 115, 104, 97, 114, 112, 101, 110, 105, 110, 103, 93, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 99, 97, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 52,
  44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  77, 97, 120, 105, 109, 97, 108, 32, 114, 97, 100, 105, 117, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 50, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 111, 117, 110, 116, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 51, 44, 48, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108,
  100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110,
  110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71,
  66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114,
  111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103,
  104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114,
  97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34,
  75, 101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101,
  110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 114, 97,
  108, 108, 101, 108, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 117, 116, 111, 34, 44,
  34, 79, 110, 101, 32, 116, 104, 114, 101, 97, 100, 34, 44, 34, 84, 119,
  111, 32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 70, 111, 117, 114,
  32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 69, 105, 103, 104, 116,
  32, 116, 104, 114, 101, 97, 100, 115, 34, 44, 34, 83, 105, 120, 116, 101,
  101, 110, 32, 116, 104, 114, 101, 97, 100, 115, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 112, 97, 116, 105, 97, 108, 32, 111, 118,
  101, 114, 108, 97, 112, 32, 61, 32, 105, 110, 116, 40, 50, 52, 44, 48,
  44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73,
  116, 92, 51, 48, 51, 92, 50, 53, 49, 114, 97, 116, 105, 111, 110, 115,
  32, 61, 32, 105, 110, 116, 40, 51, 44, 49, 44, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 66, 108,
  101, 110, 100, 32, 58, 32, 115, 111, 102, 116, 108, 105, 103, 104, 32, 109,
  117, 108, 116, 105, 112, 108, 121, 32, 111, 118, 101, 114, 108, 97, 121, 32,
  114, 101, 102, 108, 101, 99, 116, 32, 115, 99, 114, 101, 101, 110, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  51, 54, 44, 34, 65, 100, 100, 34, 44, 34, 65, 108, 112, 104, 97, 34,
  44, 34, 65, 110, 100, 34, 44, 34, 65, 118, 101, 114, 97, 103, 101, 34,
  44, 34, 66, 108, 117, 101, 34, 44, 34, 66, 117, 114, 110, 34, 44, 34,
  68, 97, 114, 107, 101, 110, 34, 44, 34, 68, 105, 102, 102, 101, 114, 101,
  110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34,
  68, 105, 118, 105, 100, 101, 34, 44, 34, 68, 111, 100, 103, 101, 34, 44,
  34, 69, 120, 99, 108, 117, 115, 105, 111, 110, 34, 44, 34, 70, 114, 101,
  101, 122, 101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 101, 120, 116, 114,
  97, 99, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 109, 101, 114, 103,
  101, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 72, 97, 114, 100,
  32, 108, 105, 103, 104, 116, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44, 34, 72, 117,
  101, 34, 44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111,
  110, 34, 44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44, 34, 76, 105,
  103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110, 101, 97, 114,
  32, 98, 117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 108,
  105, 103, 104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101,
  34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 77, 117, 108,
  116, 105, 112, 108, 121, 34, 44, 34, 78, 101, 103, 97, 116, 105, 111, 110,
  34, 44, 34, 79, 114, 34, 44, 34, 79, 118, 101, 114, 108, 97, 121, 34,
  44, 34, 80, 105, 110, 32, 108, 105, 103, 104, 116, 34, 44, 34, 82, 101,
  100, 34, 44, 34, 82, 101, 102, 108, 101, 99, 116, 34, 44, 34, 83, 97,
  116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97,
  103, 101, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97,
  103, 101, 48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117, 114, 110, 34,
  44, 34, 83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34, 44, 34, 83,
  111, 102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83, 99, 114, 101,
  101, 110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34, 83, 117, 98,
  116, 114, 97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 86, 105, 118, 105, 100, 32,
  108, 105, 103, 104, 116, 34, 44, 34, 88, 111, 114, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97,
  121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 82,
  101, 110, 100, 117, 32, 47, 32, 82, 101, 110, 100, 101, 114, 105, 110, 103,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 76, 117, 109, 105, 110, 111, 115, 105, 116, 92, 51, 48,
  51, 92, 50, 53, 49, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44,
  52, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68,
  101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 101, 117, 114, 115, 32, 47, 32, 65, 117, 116, 104, 111,
  114, 115, 32, 58, 32, 60, 105, 62, 83, 97, 109, 106, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48,
  49, 47, 49, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 67, 97, 114, 114, 101, 108, 97, 103, 101, 95, 115, 97,
  109, 106, 32, 58, 10, 68, 105, 109, 101, 110, 115, 105, 111, 110, 61, 36,
  49, 10, 82, 97, 112, 112, 111, 114, 116, 61, 36, 50, 10, 82, 95, 115,
  101, 108, 101, 99, 116, 105, 111, 110, 61, 36, 51, 10, 86, 95, 115, 101,
  108, 101, 99, 116, 105, 111, 110, 61, 36, 52, 10, 66, 95, 115, 101, 108,
  101, 99, 116, 105, 111, 110, 61, 36, 53, 10, 83, 79, 95, 83, 99, 97,
  108, 101, 115, 61, 36, 54, 10, 83, 79, 95, 77, 97, 120, 105, 109, 97,
  108, 95, 114, 97, 100, 105, 117, 115, 61, 36, 55, 10, 83, 79, 95, 65,
  109, 111, 117, 110, 116, 61, 36, 56, 10, 83, 79, 95, 84, 104, 114, 101,
  115, 104, 111, 108, 100, 61, 36, 57, 10, 83, 79, 95, 67, 104, 97, 110,
  110, 101, 108, 115, 61, 36, 49, 48, 10, 83, 79, 95, 80, 97, 114, 97,
  108, 108, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 61,
  36, 49, 49, 10, 83, 79, 95, 83, 112, 97, 116, 105, 97, 108, 95, 111,
  118, 101, 114, 108, 97, 112, 61, 36, 49, 50, 10, 83, 79, 95, 73, 116,
  101, 114, 97, 116, 105, 111, 110, 115, 61, 36, 49, 51, 10, 98, 108, 101,
  110, 100, 61, 36, 49, 52, 10, 111, 112, 97, 99, 105, 116, 101, 61, 36,
  49, 53, 10, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115,
  61, 36, 49, 54, 10, 76, 117, 109, 105, 110, 111, 115, 105, 116, 101, 61,
  36, 49, 55, 10, 68, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 61,
  36, 49, 56, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 36, 68, 105, 109, 101,
  110, 115, 105, 111, 110, 61, 61, 48, 125, 10, 68, 105, 109, 101, 110, 115,
  105, 111, 110, 61, 49, 10, 45, 101, 110, 100, 105, 102, 10, 107, 95, 119,
  61, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 10, 107, 95, 104, 61,
  123, 114, 111, 117, 110, 100, 40, 123, 36, 68, 105, 109, 101, 110, 115, 105,
  111, 110, 42, 36, 82, 97, 112, 112, 111, 114, 116, 47, 49, 48, 48, 125,
  41, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123,
  123, 119, 125, 47, 36, 107, 95, 119, 125, 44, 123, 123, 104, 125, 47, 36,
  107, 95, 104, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93,
  32, 123, 123, 119, 125, 42, 36, 107, 95, 119, 125, 44, 123, 123, 104, 125,
  42, 36, 107, 95, 104, 125, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111,
  95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 71, 114,
  105, 122, 111, 117, 95, 115, 97, 109, 106, 91, 45, 49, 93, 32, 48, 44,
  48, 44, 36, 82, 95, 115, 101, 108, 101, 99, 116, 105, 111, 110, 44, 50,
  53, 53, 44, 48, 44, 36, 86, 95, 115, 101, 108, 101, 99, 116, 105, 111,
  110, 44, 50, 53, 53, 44, 48, 44, 36, 66, 95, 115, 101, 108, 101, 99,
  116, 105, 111, 110, 44, 50, 53, 53, 44, 48, 44, 55, 54, 53, 44, 50,
  53, 53, 44, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 83, 79,
  95, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 10, 45, 103, 105, 109,
  112, 95, 117, 110, 115, 104, 97, 114, 112, 95, 111, 99, 116, 97, 118, 101,
  91, 45, 49, 93, 32, 36, 83, 79, 95, 83, 99, 97, 108, 101, 115, 44,
  36, 83, 79, 95, 77, 97, 120, 105, 109, 97, 108, 95, 114, 97, 100, 105,
  117, 115, 44, 36, 83, 79, 95, 65, 109, 111, 117, 110, 116, 44, 36, 83,
  79, 95, 84, 104, 114, 101, 115, 104, 111, 108, 100, 44, 36, 83, 79, 95,
  67, 104, 97, 110, 110, 101, 108, 115, 44, 36, 83, 79, 95, 80, 97, 114,
  97, 108, 108, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103,
  44, 36, 83, 79, 95, 83, 112, 97, 116, 105, 97, 108, 95, 111, 118, 101,
  114, 108, 97, 112, 10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123,
  36, 76, 117, 109, 105, 110, 111, 115, 105, 116, 101, 62, 49, 125, 32, 45,
  115, 104, 97, 114, 112, 101, 110, 91, 45, 49, 44, 45, 50, 93, 32, 36,
  76, 117, 109, 105, 110, 111, 115, 105, 116, 101, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 68, 101, 102, 111, 114, 109, 97, 116,
  105, 111, 110, 62, 48, 125, 32, 45, 100, 101, 102, 111, 114, 109, 91, 45,
  49, 93, 32, 36, 68, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101,
  110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 36, 98, 108, 101, 110, 100,
  44, 36, 111, 112, 97, 99, 105, 116, 101, 44, 36, 82, 101, 118, 101, 114,
  116, 95, 108, 97, 121, 101, 114, 115, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 67, 97, 114, 114, 101, 108, 97, 103, 101, 95, 115,
  97, 109, 106, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 67, 97, 114, 114, 101, 108, 97, 103, 101, 95, 115, 97,
  109, 106, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10,
  35, 64, 103, 105, 109, 112, 32, 67, 101, 107, 111, 97, 115, 97, 32, 48,
  48, 53, 32, 58, 32, 115, 97, 109, 106, 95, 67, 101, 75, 111, 97, 83,
  97, 95, 48, 48, 53, 44, 32, 115, 97, 109, 106, 95, 67, 101, 75, 111,
  97, 83, 97, 95, 48, 48, 53, 95, 112, 114, 101, 118, 105, 101, 119, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97,
  110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114,
  97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62,
  71, 114, 105, 108, 108, 101, 32, 47, 32, 71, 114, 105, 100, 60, 47, 115,
  109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 105, 108, 108, 101, 32, 47,
  32, 103, 114, 105, 100, 32, 120, 32, 61, 32, 105, 110, 116, 40, 49, 54,
  44, 50, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 71, 114, 105, 108, 108, 101, 32, 47, 32, 103, 114, 105, 100, 32, 121,
  32, 61, 32, 105, 110, 116, 40, 49, 54, 44, 50, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 105, 108, 108, 101,
  32, 99, 97, 114, 114, 92, 51, 48, 51, 92, 50, 53, 49, 101, 32, 120,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 71, 114, 105, 108, 108, 101, 32, 99, 97, 114, 114, 92,
  51, 48, 51, 92, 50, 53, 49, 101, 32, 121, 32, 61, 32, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34,
  111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108,
  108, 62, 67, 111, 117, 108, 101, 117, 114, 115, 32, 47, 32, 67, 111, 108,
  111, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97,
  110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110,
  116, 101, 110, 115, 105, 116, 92, 51, 48, 51, 92, 50, 53, 49, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 50, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 100, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 52, 49, 44, 34, 65, 100, 100, 34, 44,
  34, 65, 108, 112, 104, 97, 34, 44, 34, 65, 110, 100, 34, 44, 34, 65,
  118, 101, 114, 97, 103, 101, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34,
  66, 117, 114, 110, 34, 44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34,
  68, 105, 102, 102, 101, 114, 101, 110, 99, 101, 34, 44, 34, 68, 105, 118,
  105, 100, 101, 34, 44, 34, 68, 111, 100, 103, 101, 34, 44, 34, 69, 120,
  99, 108, 117, 115, 105, 111, 110, 34, 44, 34, 70, 114, 101, 101, 122, 101,
  34, 44, 34, 71, 114, 97, 105, 110, 32, 101, 120, 116, 114, 97, 99, 116,
  34, 44, 34, 71, 114, 97, 105, 110, 32, 109, 101, 114, 103, 101, 34, 44,
  34, 71, 114, 101, 101, 110, 34, 44, 34, 72, 97, 114, 100, 32, 108, 105,
  103, 104, 116, 34, 44, 34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44,
  34, 72, 117, 101, 34, 44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97,
  116, 105, 111, 110, 34, 44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44,
  34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110,
  101, 97, 114, 32, 98, 117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97,
  114, 32, 108, 105, 103, 104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 77, 117, 108, 116, 105, 112, 108, 121, 34, 44,
  34, 78, 101, 103, 97, 116, 105, 111, 110, 34, 44, 34, 79, 114, 34, 44,
  34, 79, 118, 101, 114, 108, 97, 121, 34, 44, 34, 80, 105, 110, 32, 108,
  105, 103, 104, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 82, 101, 102,
  108, 101, 99, 116, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111,
  110, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103,
  101, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103,
  101, 48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117, 114, 110, 34, 44,
  34, 83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34, 44, 34, 83, 111,
  102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83, 99, 114, 101, 101,
  110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34, 83, 117, 98, 116,
  114, 97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 86,
  105, 118, 105, 100, 32, 108, 105, 103, 104, 116, 34, 44, 34, 88, 111, 114,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99,
  105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101,
  114, 116, 32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 114,
  109, 97, 108, 105, 115, 101, 114, 32, 61, 32, 98, 111, 111, 108, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97,
  109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47,
  49, 52, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 115, 97, 109, 106, 95, 67, 101, 75, 111, 97, 83, 97, 95, 48,
  48, 53, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 71, 114, 105, 108, 108, 101, 95, 88, 61,
  36, 49, 10, 71, 114, 105, 108, 108, 101, 95, 89, 61, 36, 50, 10, 71,
  114, 105, 108, 108, 101, 95, 67, 97, 114, 114, 101, 101, 95, 88, 61, 36,
  51, 10, 71, 114, 105, 108, 108, 101, 95, 67, 97, 114, 114, 101, 101, 95,
  89, 61, 36, 52, 10, 73, 110, 116, 101, 110, 115, 105, 116, 101, 61, 36,
  53, 10, 77, 111, 100, 101, 95, 77, 101, 108, 97, 110, 103, 101, 61, 36,
  54, 10, 79, 112, 97, 99, 105, 116, 121, 95, 77, 101, 108, 97, 110, 103,
  101, 61, 36, 55, 10, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101,
  114, 115, 95, 77, 101, 108, 97, 110, 103, 101, 61, 36, 56, 10, 78, 111,
  114, 109, 97, 108, 105, 115, 101, 114, 61, 36, 57, 10, 45, 45, 103, 105,
  109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49,
  93, 10, 45, 105, 102, 32, 123, 36, 71, 114, 105, 108, 108, 101, 95, 67,
  97, 114, 114, 101, 101, 95, 88, 61, 61, 49, 125, 10, 71, 114, 105, 108,
  108, 101, 95, 89, 61, 36, 71, 114, 105, 108, 108, 101, 95, 88, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 71, 114, 105, 108,
  108, 101, 95, 67, 97, 114, 114, 101, 101, 95, 89, 61, 61, 49, 125, 10,
  71, 114, 105, 108, 108, 101, 95, 88, 61, 36, 71, 114, 105, 108, 108, 101,
  95, 89, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 97, 110, 100, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 105, 109, 97, 103, 101,
  103, 114, 105, 100, 91, 45, 49, 44, 45, 50, 93, 32, 36, 71, 114, 105,
  108, 108, 101, 95, 88, 44, 36, 71, 114, 105, 108, 108, 101, 95, 89, 10,
  45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110,
  103, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110,
  100, 91, 45, 49, 44, 45, 50, 93, 32, 49, 54, 44, 36, 73, 110, 116,
  101, 110, 115, 105, 116, 101, 44, 48, 10, 45, 103, 105, 109, 112, 95, 98,
  108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 32, 36, 77, 111,
  100, 101, 95, 77, 101, 108, 97, 110, 103, 101, 44, 36, 79, 112, 97, 99,
  105, 116, 121, 95, 77, 101, 108, 97, 110, 103, 101, 44, 36, 82, 101, 118,
  101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 95, 77, 101, 108, 97, 110,
  103, 101, 10, 45, 105, 102, 32, 123, 36, 78, 111, 114, 109, 97, 108, 105,
  115, 101, 114, 61, 61, 49, 125, 10, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95,
  99, 111, 108, 111, 114, 109, 111, 100, 101, 91, 45, 49, 93, 32, 52, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115, 97, 109, 106,
  95, 67, 101, 75, 111, 97, 83, 97, 95, 48, 48, 53, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109,
  106, 95, 67, 101, 75, 111, 97, 83, 97, 95, 48, 48, 53, 32, 36, 42,
  34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 67, 111, 101,
  117, 114, 115, 32, 104, 101, 97, 114, 116, 115, 32, 48, 48, 49, 32, 58,
  32, 115, 97, 109, 106, 95, 67, 111, 101, 117, 114, 115, 95, 72, 101, 97,
  114, 116, 115, 95, 48, 48, 49, 44, 32, 115, 97, 109, 106, 95, 67, 111,
  101, 117, 114, 115, 95, 72, 101, 97, 114, 116, 115, 95, 48, 48, 49, 95,
  112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114,
  111, 117, 110, 100, 61, 34, 114, 101, 100, 34, 62, 68, 101, 115, 32, 99,
  38, 35, 51, 51, 57, 59, 117, 114, 115, 32, 97, 117, 120, 32, 99, 111,
  117, 108, 101, 117, 114, 115, 32, 100, 101, 32, 108, 39, 105, 109, 97, 103,
  101, 46, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103,
  114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100,
  34, 62, 60, 115, 109, 97, 108, 108, 62, 67, 38, 35, 51, 51, 57, 59,
  117, 114, 115, 32, 47, 32, 72, 101, 97, 114, 116, 115, 60, 47, 115, 109,
  97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 101, 115, 111, 108, 117, 116, 105, 111,
  110, 32, 61, 32, 105, 110, 116, 40, 49, 54, 44, 52, 44, 49, 50, 56,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 109, 112, 108,
  105, 115, 115, 97, 103, 101, 32, 37, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 48, 48, 44, 50, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 114, 111, 116, 97,
  116, 105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 51,
  54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 108, 111,
  117, 32, 47, 32, 98, 108, 117, 114, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 111, 101, 117, 114, 115, 32, 47, 32, 104, 101, 97, 114, 116, 115,
  32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114,
  111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34,
  62, 60, 115, 109, 97, 108, 108, 62, 73, 109, 97, 103, 101, 32, 67, 111,
  117, 108, 101, 117, 114, 115, 32, 47, 32, 67, 111, 108, 111, 114, 115, 60,
  47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 48, 44,
  48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114,
  105, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 115, 32, 98, 111, 111,
  115, 116, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 70, 111, 110, 100, 32, 99, 111, 108, 111, 114,
  92, 51, 48, 51, 92, 50, 53, 49, 32, 61, 32, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108,
  101, 117, 114, 32, 102, 111, 110, 100, 32, 47, 32, 98, 97, 99, 107, 103,
  114, 111, 117, 110, 100, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111,
  108, 111, 114, 40, 48, 44, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97, 109, 106, 32,
  45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32,
  58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 49, 54, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 115,
  97, 109, 106, 95, 67, 111, 101, 117, 114, 115, 95, 72, 101, 97, 114, 116,
  115, 95, 48, 48, 49, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 82, 101, 115, 111, 108, 117,
  116, 105, 111, 110, 61, 36, 49, 10, 82, 101, 109, 112, 108, 105, 115, 115,
  97, 103, 101, 61, 36, 50, 10, 65, 110, 103, 108, 101, 95, 82, 111, 116,
  97, 116, 105, 111, 110, 95, 77, 111, 116, 105, 102, 61, 36, 51, 10, 102,
  108, 111, 117, 61, 36, 52, 10, 67, 111, 101, 117, 114, 115, 95, 72, 101,
  97, 114, 116, 115, 61, 36, 53, 10, 73, 110, 116, 101, 114, 112, 111, 108,
  97, 116, 105, 111, 110, 61, 36, 54, 10, 71, 114, 105, 115, 61, 36, 55,
  10, 66, 111, 111, 115, 116, 61, 36, 56, 10, 70, 111, 110, 100, 95, 67,
  111, 108, 111, 114, 101, 61, 36, 57, 10, 82, 95, 67, 111, 117, 108, 101,
  117, 114, 61, 36, 49, 48, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  61, 36, 49, 49, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36,
  49, 50, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 49, 51,
  10, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 10, 45,
  105, 102, 32, 123, 36, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105,
  111, 110, 61, 61, 48, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45,
  49, 93, 32, 123, 123, 119, 125, 47, 36, 82, 101, 115, 111, 108, 117, 116,
  105, 111, 110, 125, 44, 123, 123, 104, 125, 47, 36, 82, 101, 115, 111, 108,
  117, 116, 105, 111, 110, 125, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 10, 45, 101, 108, 105, 102, 32, 123, 36, 73, 110, 116, 101,
  114, 112, 111, 108, 97, 116, 105, 111, 110, 61, 61, 49, 125, 10, 45, 114,
  101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 123, 119, 125, 47, 36,
  82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 125, 44, 123, 123, 104, 125,
  47, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 125, 44, 49, 44,
  51, 44, 51, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 73, 110, 116, 101, 114, 112, 111,
  108, 97, 116, 105, 111, 110, 61, 61, 50, 125, 10, 45, 114, 101, 115, 105,
  122, 101, 91, 45, 49, 93, 32, 123, 123, 119, 125, 47, 36, 82, 101, 115,
  111, 108, 117, 116, 105, 111, 110, 125, 44, 123, 123, 104, 125, 47, 36, 82,
  101, 115, 111, 108, 117, 116, 105, 111, 110, 125, 10, 45, 110, 91, 45, 49,
  93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 61, 61, 51,
  125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 123,
  119, 125, 47, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 125, 44,
  123, 123, 104, 125, 47, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110,
  125, 44, 49, 44, 51, 44, 51, 10, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 71, 114, 105, 115, 61, 61, 49, 125, 10, 45, 116, 111, 95, 103,
  114, 97, 121, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 123, 119, 125, 42,
  36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 125, 44, 123, 123, 104,
  125, 42, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 125, 10, 45,
  99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32,
  123, 36, 66, 111, 111, 115, 116, 61, 61, 49, 125, 10, 45, 103, 105, 109,
  112, 95, 98, 97, 108, 97, 110, 99, 101, 95, 103, 97, 109, 109, 97, 91,
  45, 49, 93, 32, 49, 50, 56, 44, 49, 50, 56, 44, 49, 50, 56, 44,
  49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 110, 101, 103, 97, 116, 105,
  118, 101, 91, 45, 49, 93, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91,
  45, 49, 93, 10, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 44,
  36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 44, 49, 44, 52, 10,
  45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32,
  48, 44, 48, 44, 48, 44, 48, 10, 45, 105, 102, 32, 123, 36, 67, 111,
  101, 117, 114, 115, 95, 72, 101, 97, 114, 116, 115, 61, 61, 49, 125, 10,
  40, 48, 44, 48, 44, 48, 44, 49, 44, 49, 44, 49, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 49, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48,
  59, 48, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 48,
  44, 48, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 48,
  59, 48, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 48,
  59, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  59, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  59, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  59, 48, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 48,
  59, 48, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 48,
  59, 48, 44, 48, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 48, 44, 48,
  59, 48, 44, 48, 44, 48, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48,
  59, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 44, 48,
  59, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 44, 48,
  59, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48,
  59, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48,
  59, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49,
  44, 49, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48,
  59, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49,
  44, 49, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48,
  41, 10, 45, 101, 108, 115, 101, 10, 40, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 48, 59, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 48, 44, 48, 44, 48, 44, 48, 59, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 48, 44, 48, 59, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 48, 44, 48, 59, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 48, 59, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 48, 59, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 48, 59, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 48, 59, 48, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 59, 48, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 59, 48, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 59, 48, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 59, 48, 44, 48, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 59, 48, 44, 48, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 59, 48, 44, 48, 44, 48, 44, 48,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 59, 48, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 41, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 65, 110, 103, 108, 101, 95, 82, 111, 116,
  97, 116, 105, 111, 110, 95, 77, 111, 116, 105, 102, 62, 48, 125, 10, 45,
  114, 111, 116, 97, 116, 101, 91, 45, 49, 93, 32, 36, 65, 110, 103, 108,
  101, 95, 82, 111, 116, 97, 116, 105, 111, 110, 95, 77, 111, 116, 105, 102,
  44, 48, 44, 48, 10, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45,
  49, 93, 32, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 82, 101, 115, 111, 108, 117,
  116, 105, 111, 110, 42, 36, 82, 101, 109, 112, 108, 105, 115, 115, 97, 103,
  101, 47, 49, 48, 48, 125, 44, 123, 36, 82, 101, 115, 111, 108, 117, 116,
  105, 111, 110, 42, 36, 82, 101, 109, 112, 108, 105, 115, 115, 97, 103, 101,
  47, 49, 48, 48, 125, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 97,
  108, 112, 104, 97, 91, 45, 49, 44, 45, 50, 93, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50,
  93, 44, 49, 44, 49, 44, 48, 44, 50, 10, 45, 116, 111, 95, 114, 103,
  98, 97, 91, 45, 49, 93, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95,
  99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48,
  44, 48, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45,
  50, 44, 45, 49, 93, 32, 52, 50, 44, 49, 44, 48, 10, 45, 105, 102,
  32, 123, 36, 102, 108, 111, 117, 62, 48, 125, 10, 45, 98, 108, 117, 114,
  91, 45, 49, 93, 32, 36, 102, 108, 111, 117, 44, 48, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 70, 111, 110, 100, 95, 67,
  111, 108, 111, 114, 101, 61, 61, 49, 125, 10, 123, 119, 125, 44, 123, 104,
  125, 44, 49, 44, 52, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111,
  114, 91, 45, 49, 93, 32, 123, 50, 53, 53, 45, 36, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 125, 44, 123, 50, 53, 53, 45, 36, 86, 95, 67,
  111, 117, 108, 101, 117, 114, 125, 44, 123, 50, 53, 53, 45, 36, 66, 95,
  67, 111, 117, 108, 101, 117, 114, 125, 44, 36, 65, 95, 67, 111, 117, 108,
  101, 117, 114, 10, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 44,
  36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 44, 49, 44, 52, 10,
  45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32,
  48, 44, 48, 44, 48, 44, 48, 10, 45, 105, 102, 32, 123, 36, 67, 111,
  101, 117, 114, 115, 95, 72, 101, 97, 114, 116, 115, 61, 61, 49, 125, 10,
  40, 48, 44, 48, 44, 48, 44, 49, 44, 49, 44, 49, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 49, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48,
  59, 48, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 48,
  44, 48, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 48,
  59, 48, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 48,
  59, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  59, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  59, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  59, 48, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 48,
  59, 48, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 48,
  59, 48, 44, 48, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 48, 44, 48,
  59, 48, 44, 48, 44, 48, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48,
  59, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 44, 48,
  59, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 44, 48,
  59, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48,
  59, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48,
  59, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49,
  44, 49, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48,
  59, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49,
  44, 49, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48,
  41, 10, 45, 101, 108, 115, 101, 10, 40, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 48, 59, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 48, 44, 48, 44, 48, 44, 48, 59, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 48, 44, 48, 59, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 48, 44, 48, 59, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 48, 59, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 48, 59, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 48, 59, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 48, 59, 48, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 59, 48, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 59, 48, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 59, 48, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 59, 48, 44, 48, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 59, 48, 44, 48, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 59, 48, 44, 48, 44, 48, 44, 48,
  44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 59, 48, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 49, 44, 49, 44, 49,
  44, 49, 44, 49, 44, 49, 44, 49, 41, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 65, 110, 103, 108, 101, 95, 82, 111, 116,
  97, 116, 105, 111, 110, 95, 77, 111, 116, 105, 102, 62, 48, 125, 10, 45,
  114, 111, 116, 97, 116, 101, 91, 45, 49, 93, 32, 36, 65, 110, 103, 108,
  101, 95, 82, 111, 116, 97, 116, 105, 111, 110, 95, 77, 111, 116, 105, 102,
  44, 48, 44, 48, 10, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45,
  49, 93, 32, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 82, 101, 115, 111, 108, 117,
  116, 105, 111, 110, 42, 36, 82, 101, 109, 112, 108, 105, 115, 115, 97, 103,
  101, 47, 49, 48, 48, 125, 44, 123, 36, 82, 101, 115, 111, 108, 117, 116,
  105, 111, 110, 42, 36, 82, 101, 109, 112, 108, 105, 115, 115, 97, 103, 101,
  47, 49, 48, 48, 125, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 97,
  108, 112, 104, 97, 91, 45, 49, 44, 45, 50, 93, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 36, 82, 101, 115, 111, 108, 117, 116,
  105, 111, 110, 44, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 10,
  45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 10, 45, 114, 101,
  112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32,
  49, 48, 48, 37, 44, 48, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91,
  45, 49, 93, 32, 49, 48, 48, 37, 44, 48, 44, 49, 44, 49, 44, 49,
  44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 48, 10, 45, 114, 101,
  115, 105, 122, 101, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45,
  50, 93, 44, 49, 44, 49, 44, 48, 44, 50, 10, 45, 116, 111, 95, 114,
  103, 98, 97, 91, 45, 49, 93, 10, 45, 114, 101, 112, 108, 97, 99, 101,
  95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44,
  48, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 48, 44, 48, 44,
  48, 44, 48, 10, 45, 105, 102, 32, 123, 36, 102, 108, 111, 117, 62, 48,
  125, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 102, 108, 111,
  117, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112,
  95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 52, 50,
  44, 49, 44, 48, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 97, 108,
  112, 104, 97, 91, 45, 49, 44, 45, 50, 93, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115, 97,
  109, 106, 95, 67, 111, 101, 117, 114, 115, 95, 72, 101, 97, 114, 116, 115,
  95, 48, 48, 49, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 67, 111, 101, 117, 114, 115,
  95, 72, 101, 97, 114, 116, 115, 95, 48, 48, 49, 32, 36, 42, 34, 44,
  36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 71, 114, 105, 108, 108,
  101, 32, 103, 114, 105, 100, 32, 48, 48, 49, 32, 58, 32, 115, 97, 109,
  106, 95, 71, 114, 105, 108, 108, 101, 95, 71, 114, 105, 100, 95, 48, 48,
  49, 44, 32, 115, 97, 109, 106, 95, 71, 114, 105, 108, 108, 101, 95, 71,
  114, 105, 100, 95, 48, 48, 49, 95, 112, 114, 101, 118, 105, 101, 119, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97,
  110, 32, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 61, 34, 119, 104,
  105, 116, 101, 34, 62, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103,
  114, 111, 117, 110, 100, 61, 34, 114, 101, 100, 34, 62, 76, 101, 32, 114,
  101, 110, 100, 117, 32, 112, 101, 117, 116, 32, 118, 97, 114, 105, 101, 114,
  32, 97, 118, 101, 99, 32, 117, 110, 32, 99, 97, 108, 113, 117, 101, 32,
  97, 121, 97, 110, 116, 32, 117, 110, 32, 99, 97, 110, 97, 108, 32, 97,
  108, 112, 104, 97, 60, 47, 115, 112, 97, 110, 62, 60, 47, 115, 112, 97,
  110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34,
  111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108,
  108, 62, 71, 114, 105, 108, 108, 101, 32, 47, 32, 71, 114, 105, 100, 60,
  47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 105, 108, 108, 101,
  32, 47, 32, 103, 114, 105, 100, 32, 120, 32, 61, 32, 105, 110, 116, 40,
  49, 54, 44, 50, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 71, 114, 105, 108, 108, 101, 32, 47, 32, 103, 114, 105, 100,
  32, 121, 32, 61, 32, 105, 110, 116, 40, 49, 54, 44, 50, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 105, 108,
  108, 101, 32, 99, 97, 114, 114, 92, 51, 48, 51, 92, 50, 53, 49, 101,
  32, 120, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 71, 114, 105, 108, 108, 101, 32, 99, 97, 114,
  114, 92, 51, 48, 51, 92, 50, 53, 49, 101, 32, 121, 32, 61, 32, 98,
  111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100,
  61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109,
  97, 108, 108, 62, 67, 111, 117, 108, 101, 117, 114, 115, 32, 47, 32, 67,
  111, 108, 111, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115,
  112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  77, 111, 100, 117, 108, 111, 32, 61, 32, 105, 110, 116, 40, 51, 50, 44,
  49, 54, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 113, 117, 97, 114, 101, 32, 114, 111, 111, 116, 32, 61, 32, 98,
  111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  79, 112, 97, 99, 105, 116, 92, 51, 48, 51, 92, 50, 53, 49, 32, 47,
  32, 111, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 44, 45, 49, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50,
  48, 49, 52, 47, 48, 49, 47, 49, 51, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 71, 114,
  105, 108, 108, 101, 95, 71, 114, 105, 100, 95, 48, 48, 49, 32, 58, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 71, 114, 105, 108, 108, 101, 95, 88, 61, 36, 49, 10, 71, 114,
  105, 108, 108, 101, 95, 89, 61, 36, 50, 10, 71, 114, 105, 108, 108, 101,
  95, 67, 97, 114, 114, 101, 101, 95, 88, 61, 36, 51, 10, 71, 114, 105,
  108, 108, 101, 95, 67, 97, 114, 114, 101, 101, 95, 89, 61, 36, 52, 10,
  77, 111, 100, 117, 108, 111, 61, 36, 53, 10, 83, 113, 117, 97, 114, 101,
  95, 82, 111, 111, 116, 61, 36, 54, 10, 79, 112, 97, 99, 105, 116, 101,
  61, 36, 55, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111,
  116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 108, 117, 109, 105, 110,
  97, 110, 99, 101, 91, 45, 49, 93, 10, 45, 109, 111, 100, 91, 45, 49,
  93, 32, 36, 77, 111, 100, 117, 108, 111, 10, 45, 105, 102, 32, 123, 36,
  83, 113, 117, 97, 114, 101, 95, 82, 111, 111, 116, 61, 61, 49, 125, 10,
  45, 115, 113, 114, 116, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 71, 114, 105, 108, 108, 101, 95, 67, 97,
  114, 114, 101, 101, 95, 88, 61, 61, 49, 125, 10, 71, 114, 105, 108, 108,
  101, 95, 89, 61, 36, 71, 114, 105, 108, 108, 101, 95, 88, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 71, 114, 105, 108, 108,
  101, 95, 67, 97, 114, 114, 101, 101, 95, 89, 61, 61, 49, 125, 10, 71,
  114, 105, 108, 108, 101, 95, 88, 61, 36, 71, 114, 105, 108, 108, 101, 95,
  89, 10, 45, 101, 110, 100, 105, 102, 10, 45, 110, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 10, 45, 105, 109, 97, 103, 101, 103, 114, 105, 100,
  91, 45, 49, 44, 45, 50, 93, 32, 36, 71, 114, 105, 108, 108, 101, 95,
  88, 44, 36, 71, 114, 105, 108, 108, 101, 95, 89, 10, 45, 105, 102, 32,
  123, 36, 79, 112, 97, 99, 105, 116, 101, 62, 61, 48, 125, 10, 45, 103,
  105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93,
  32, 50, 50, 44, 36, 79, 112, 97, 99, 105, 116, 101, 44, 48, 10, 45,
  101, 108, 115, 101, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100,
  91, 45, 49, 44, 45, 50, 93, 32, 50, 50, 44, 40, 49, 43, 36, 79,
  112, 97, 99, 105, 116, 101, 41, 44, 49, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 91, 45,
  49, 93, 32, 52, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 115, 97, 109, 106, 95, 71, 114, 105, 108, 108, 101, 95, 71, 114, 105,
  100, 95, 48, 48, 49, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 71, 114, 105, 108, 108,
  101, 95, 71, 114, 105, 100, 95, 48, 48, 49, 32, 36, 42, 34, 44, 36,
  45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 71, 114, 105, 108, 108, 101,
  32, 103, 114, 105, 100, 32, 48, 48, 50, 32, 58, 32, 115, 97, 109, 106,
  95, 71, 114, 105, 108, 108, 101, 95, 71, 114, 105, 100, 95, 48, 48, 50,
  44, 32, 115, 97, 109, 106, 95, 71, 114, 105, 108, 108, 101, 95, 71, 114,
  105, 100, 95, 48, 48, 50, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110,
  32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 114, 101, 100,
  34, 62, 85, 110, 101, 32, 103, 114, 105, 108, 108, 101, 32, 115, 117, 114,
  32, 108, 39, 105, 109, 97, 103, 101, 32, 112, 105, 120, 92, 51, 48, 51,
  92, 50, 53, 49, 108, 105, 115, 92, 51, 48, 51, 92, 50, 53, 49, 101,
  46, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114,
  111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34,
  62, 60, 115, 109, 97, 108, 108, 62, 71, 114, 105, 108, 108, 101, 32, 47,
  32, 71, 114, 105, 100, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115,
  112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  88, 32, 61, 32, 105, 110, 116, 40, 49, 54, 44, 52, 44, 52, 56, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 32, 61, 32, 105, 110,
  116, 40, 49, 54, 44, 52, 44, 52, 56, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 47, 32, 99, 111,
  108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 54, 52, 44, 49,
  50, 56, 44, 49, 57, 50, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 68, 105, 108, 97, 116, 97, 116, 105, 111, 110, 32,
  40, 92, 51, 48, 51, 92, 50, 53, 49, 112, 97, 105, 115, 115, 101, 117,
  114, 41, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49, 44, 52, 56, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32,
  102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110,
  103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 73, 109,
  97, 103, 101, 32, 67, 111, 117, 108, 101, 117, 114, 115, 32, 47, 32, 67,
  111, 108, 111, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115,
  112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 32, 61, 32,
  105, 110, 116, 40, 48, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 71, 114, 105, 115, 32, 61, 32, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111,
  114, 115, 32, 98, 111, 111, 115, 116, 32, 61, 32, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80,
  114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115,
  97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49,
  47, 49, 53, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 115, 97, 109, 106, 95, 71, 114, 105, 108, 108, 101, 95, 71,
  114, 105, 100, 95, 48, 48, 50, 32, 58, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 82, 101, 115, 111,
  108, 117, 116, 105, 111, 110, 95, 88, 61, 36, 49, 10, 82, 101, 115, 111,
  108, 117, 116, 105, 111, 110, 95, 89, 61, 36, 50, 10, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 61, 36, 51, 10, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 61, 36, 52, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 61,
  36, 53, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 54, 10,
  86, 97, 108, 101, 117, 114, 95, 100, 105, 108, 97, 116, 101, 95, 99, 105,
  114, 99, 61, 36, 55, 10, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116,
  105, 111, 110, 61, 36, 56, 10, 71, 114, 105, 115, 61, 36, 57, 10, 66,
  111, 111, 115, 116, 61, 36, 49, 48, 10, 45, 105, 102, 32, 123, 36, 73,
  110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 61, 61, 48, 125,
  10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 123, 119,
  125, 47, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 95, 88, 125,
  44, 123, 123, 104, 125, 47, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111,
  110, 95, 89, 125, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 10, 45, 101, 108, 105, 102, 32, 123, 36, 73, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 105, 111, 110, 61, 61, 49, 125, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 123, 123, 119, 125, 47, 36, 82, 101,
  115, 111, 108, 117, 116, 105, 111, 110, 95, 88, 125, 44, 123, 123, 104, 125,
  47, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 95, 89, 125, 44,
  49, 44, 51, 44, 51, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 10, 45, 101, 108, 105, 102, 32, 123, 36, 73, 110, 116, 101, 114,
  112, 111, 108, 97, 116, 105, 111, 110, 61, 61, 50, 125, 10, 45, 114, 101,
  115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 123, 119, 125, 47, 36, 82,
  101, 115, 111, 108, 117, 116, 105, 111, 110, 95, 88, 125, 44, 123, 123, 104,
  125, 47, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 95, 89, 125,
  10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116,
  105, 111, 110, 61, 61, 51, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91,
  45, 49, 93, 32, 123, 123, 119, 125, 47, 36, 82, 101, 115, 111, 108, 117,
  116, 105, 111, 110, 95, 88, 125, 44, 123, 123, 104, 125, 47, 36, 82, 101,
  115, 111, 108, 117, 116, 105, 111, 110, 95, 89, 125, 44, 49, 44, 51, 44,
  51, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 71, 114, 105, 115,
  61, 61, 49, 125, 10, 45, 116, 111, 95, 103, 114, 97, 121, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93,
  32, 123, 123, 119, 125, 42, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111,
  110, 95, 88, 125, 44, 123, 123, 104, 125, 42, 36, 82, 101, 115, 111, 108,
  117, 116, 105, 111, 110, 95, 89, 125, 10, 45, 99, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36, 66, 111, 111, 115,
  116, 61, 61, 49, 125, 10, 45, 103, 105, 109, 112, 95, 98, 97, 108, 97,
  110, 99, 101, 95, 103, 97, 109, 109, 97, 91, 45, 49, 93, 32, 49, 50,
  56, 44, 49, 50, 56, 44, 49, 50, 56, 44, 49, 10, 45, 101, 110, 100,
  105, 102, 10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 52, 10, 45,
  102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 123,
  50, 53, 53, 45, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 125, 44,
  123, 50, 53, 53, 45, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 125,
  44, 123, 50, 53, 53, 45, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114,
  125, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 123, 119, 125,
  44, 123, 104, 125, 44, 49, 44, 52, 10, 45, 102, 105, 108, 108, 91, 45,
  49, 93, 32, 105, 102, 40, 120, 37, 123, 36, 82, 101, 115, 111, 108, 117,
  116, 105, 111, 110, 95, 88, 125, 61, 61, 48, 44, 50, 53, 53, 44, 105,
  41, 10, 45, 102, 105, 108, 108, 91, 45, 49, 93, 32, 105, 102, 40, 121,
  37, 123, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 95, 89, 125,
  61, 61, 48, 44, 50, 53, 53, 44, 105, 41, 10, 45, 105, 102, 32, 123,
  36, 86, 97, 108, 101, 117, 114, 95, 100, 105, 108, 97, 116, 101, 95, 99,
  105, 114, 99, 62, 49, 125, 10, 45, 100, 105, 108, 97, 116, 101, 95, 99,
  105, 114, 99, 91, 45, 49, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95,
  100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45,
  49, 44, 45, 50, 93, 32, 52, 50, 44, 49, 44, 48, 10, 45, 99, 111,
  109, 112, 111, 115, 101, 95, 97, 108, 112, 104, 97, 91, 45, 49, 44, 45,
  50, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101,
  91, 45, 49, 93, 32, 52, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 115, 97, 109, 106, 95, 71, 114, 105, 108, 108, 101, 95, 71,
  114, 105, 100, 95, 48, 48, 50, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 71, 114, 105,
  108, 108, 101, 95, 71, 114, 105, 100, 95, 48, 48, 50, 32, 36, 42, 34,
  44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 71, 114, 105, 108,
  108, 101, 32, 103, 114, 105, 100, 32, 48, 48, 51, 32, 58, 32, 115, 97,
  109, 106, 95, 71, 114, 105, 108, 108, 101, 95, 71, 114, 105, 100, 95, 48,
  48, 51, 44, 32, 115, 97, 109, 106, 95, 71, 114, 105, 108, 108, 101, 95,
  71, 114, 105, 100, 95, 48, 48, 51, 95, 112, 114, 101, 118, 105, 101, 119,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112,
  97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 114,
  101, 100, 34, 62, 85, 110, 101, 32, 103, 114, 105, 108, 108, 101, 32, 115,
  117, 114, 32, 102, 111, 110, 100, 32, 116, 114, 97, 110, 115, 112, 97, 114,
  101, 110, 116, 46, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114,
  101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114,
  101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 71, 114, 105, 108, 108,
  101, 32, 47, 32, 71, 114, 105, 100, 60, 47, 115, 109, 97, 108, 108, 62,
  60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 88, 32, 61, 32, 105, 110, 116, 40, 49, 54, 44, 52, 44,
  52, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 32, 61,
  32, 105, 110, 116, 40, 49, 54, 44, 52, 44, 52, 56, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 47,
  32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 54,
  52, 44, 49, 50, 56, 44, 49, 57, 50, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 105, 108, 97, 116, 97, 116, 105,
  111, 110, 32, 40, 92, 51, 48, 51, 92, 50, 53, 49, 112, 97, 105, 115,
  115, 101, 117, 114, 41, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49, 44,
  52, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48,
  49, 47, 49, 53, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 115, 97, 109, 106, 95, 71, 114, 105, 108, 108, 101, 95,
  71, 114, 105, 100, 95, 48, 48, 51, 32, 58, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 82, 101, 115,
  111, 108, 117, 116, 105, 111, 110, 95, 88, 61, 36, 49, 10, 82, 101, 115,
  111, 108, 117, 116, 105, 111, 110, 95, 89, 61, 36, 50, 10, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 61, 36, 51, 10, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 61, 36, 52, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114,
  61, 36, 53, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 54,
  10, 86, 97, 108, 101, 117, 114, 95, 100, 105, 108, 97, 116, 101, 95, 99,
  105, 114, 99, 61, 36, 55, 10, 123, 119, 125, 44, 123, 104, 125, 44, 49,
  44, 52, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45,
  49, 93, 32, 123, 50, 53, 53, 45, 36, 82, 95, 67, 111, 117, 108, 101,
  117, 114, 125, 44, 123, 50, 53, 53, 45, 36, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 125, 44, 123, 50, 53, 53, 45, 36, 66, 95, 67, 111, 117,
  108, 101, 117, 114, 125, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114,
  10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 52, 10, 45, 102, 105,
  108, 108, 91, 45, 49, 93, 32, 105, 102, 40, 120, 37, 123, 36, 82, 101,
  115, 111, 108, 117, 116, 105, 111, 110, 95, 88, 125, 61, 61, 48, 44, 50,
  53, 53, 44, 105, 41, 10, 45, 102, 105, 108, 108, 91, 45, 49, 93, 32,
  105, 102, 40, 121, 37, 123, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111,
  110, 95, 89, 125, 61, 61, 48, 44, 50, 53, 53, 44, 105, 41, 10, 45,
  105, 102, 32, 123, 36, 86, 97, 108, 101, 117, 114, 95, 100, 105, 108, 97,
  116, 101, 95, 99, 105, 114, 99, 62, 49, 125, 10, 45, 100, 105, 108, 97,
  116, 101, 95, 99, 105, 114, 99, 91, 45, 49, 93, 32, 36, 86, 97, 108,
  101, 117, 114, 95, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101,
  110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 52, 50, 44, 49, 44, 48,
  10, 45, 114, 109, 91, 45, 50, 93, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 115, 97, 109, 106, 95, 71, 114, 105, 108, 108, 101,
  95, 71, 114, 105, 100, 95, 48, 48, 51, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 71,
  114, 105, 108, 108, 101, 95, 71, 114, 105, 100, 95, 48, 48, 51, 32, 36,
  42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 71, 114,
  105, 108, 108, 101, 32, 103, 114, 105, 100, 32, 48, 48, 52, 32, 58, 32,
  115, 97, 109, 106, 95, 71, 114, 105, 108, 108, 101, 95, 71, 114, 105, 100,
  95, 48, 48, 52, 44, 32, 115, 97, 109, 106, 95, 71, 114, 105, 108, 108,
  101, 95, 71, 114, 105, 100, 95, 48, 48, 52, 95, 112, 114, 101, 118, 105,
  101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61,
  34, 114, 101, 100, 34, 62, 85, 110, 101, 32, 103, 114, 105, 108, 108, 101,
  32, 115, 117, 114, 32, 108, 39, 105, 109, 97, 103, 101, 46, 60, 47, 115,
  112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100,
  61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109,
  97, 108, 108, 62, 71, 114, 105, 108, 108, 101, 32, 47, 32, 71, 114, 105,
  100, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 32, 61, 32,
  105, 110, 116, 40, 49, 54, 44, 52, 44, 52, 56, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 89, 32, 61, 32, 105, 110, 116, 40, 49, 54,
  44, 52, 44, 52, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 117, 108, 101, 117, 114, 32, 47, 32, 99, 111, 108, 111, 114, 32,
  61, 32, 99, 111, 108, 111, 114, 40, 54, 52, 44, 49, 50, 56, 44, 49,
  57, 50, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 68, 105, 108, 97, 116, 97, 116, 105, 111, 110, 32, 40, 92, 51, 48,
  51, 92, 50, 53, 49, 112, 97, 105, 115, 115, 101, 117, 114, 41, 32, 61,
  32, 105, 110, 116, 40, 49, 44, 49, 44, 52, 56, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97, 109, 106, 32, 45, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32,
  60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 49, 53, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109,
  106, 95, 71, 114, 105, 108, 108, 101, 95, 71, 114, 105, 100, 95, 48, 48,
  52, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110,
  95, 88, 61, 36, 49, 10, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110,
  95, 89, 61, 36, 50, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61,
  36, 51, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 52, 10,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 53, 10, 65, 95, 67,
  111, 117, 108, 101, 117, 114, 61, 36, 54, 10, 86, 97, 108, 101, 117, 114,
  95, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 61, 36, 55, 10,
  123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 52, 10, 45, 102, 105, 108,
  108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 123, 50, 53, 53,
  45, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 125, 44, 123, 50, 53,
  53, 45, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 125, 44, 123, 50,
  53, 53, 45, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 125, 44, 36,
  65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 123, 119, 125, 44, 123, 104,
  125, 44, 49, 44, 52, 10, 45, 102, 105, 108, 108, 91, 45, 49, 93, 32,
  105, 102, 40, 120, 37, 123, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111,
  110, 95, 88, 125, 61, 61, 48, 44, 50, 53, 53, 44, 105, 41, 10, 45,
  102, 105, 108, 108, 91, 45, 49, 93, 32, 105, 102, 40, 121, 37, 123, 36,
  82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 95, 89, 125, 61, 61, 48,
  44, 50, 53, 53, 44, 105, 41, 10, 45, 105, 102, 32, 123, 36, 86, 97,
  108, 101, 117, 114, 95, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99,
  62, 49, 125, 10, 45, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99,
  91, 45, 49, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 100, 105, 108,
  97, 116, 101, 95, 99, 105, 114, 99, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45,
  50, 93, 32, 52, 50, 44, 49, 44, 48, 10, 45, 99, 111, 109, 112, 111,
  115, 101, 95, 97, 108, 112, 104, 97, 91, 45, 49, 44, 45, 50, 93, 10,
  45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 91, 45, 49,
  93, 32, 52, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  115, 97, 109, 106, 95, 71, 114, 105, 108, 108, 101, 95, 71, 114, 105, 100,
  95, 48, 48, 52, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 71, 114, 105, 108, 108, 101,
  95, 71, 114, 105, 100, 95, 48, 48, 52, 32, 36, 42, 34, 44, 36, 45,
  49, 10, 35, 64, 103, 105, 109, 112, 32, 71, 114, 105, 108, 108, 101, 32,
  103, 114, 105, 100, 32, 48, 48, 53, 32, 58, 32, 115, 97, 109, 106, 95,
  71, 114, 105, 108, 108, 101, 95, 71, 114, 105, 100, 95, 48, 48, 53, 44,
  32, 115, 97, 109, 106, 95, 71, 114, 105, 108, 108, 101, 95, 71, 114, 105,
  100, 95, 48, 48, 53, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32,
  102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 114, 101, 100, 34,
  62, 68, 105, 102, 102, 92, 51, 48, 51, 92, 50, 53, 49, 114, 101, 110,
  116, 101, 115, 32, 71, 114, 105, 108, 108, 101, 115, 46, 60, 47, 115, 112,
  97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61,
  34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97,
  108, 108, 62, 84, 121, 112, 101, 115, 32, 100, 101, 32, 114, 101, 110, 100,
  117, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 110, 100,
  117, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 49, 32,
  71, 114, 105, 108, 108, 101, 32, 115, 117, 114, 32, 105, 109, 97, 103, 101,
  32, 112, 105, 120, 101, 108, 105, 115, 101, 101, 34, 44, 34, 50, 32, 71,
  114, 105, 108, 108, 101, 32, 115, 117, 114, 32, 105, 109, 97, 103, 101, 34,
  44, 34, 51, 32, 71, 114, 105, 108, 108, 101, 32, 115, 117, 114, 32, 102,
  111, 110, 100, 32, 116, 114, 97, 110, 115, 112, 97, 114, 101, 110, 116, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110,
  32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97,
  110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 71,
  114, 105, 108, 108, 101, 32, 47, 32, 71, 114, 105, 100, 60, 47, 115, 109,
  97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 88, 32, 61, 32, 105, 110, 116, 40, 49,
  54, 44, 52, 44, 52, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 89, 32, 61, 32, 105, 110, 116, 40, 49, 54, 44, 52, 44, 52, 56,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101,
  117, 114, 32, 47, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108,
  111, 114, 40, 54, 52, 44, 49, 50, 56, 44, 49, 57, 50, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 105, 108, 97,
  116, 97, 116, 105, 111, 110, 32, 40, 92, 51, 48, 51, 92, 50, 53, 49,
  112, 97, 105, 115, 115, 101, 117, 114, 41, 32, 61, 32, 105, 110, 116, 40,
  49, 44, 49, 44, 52, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110,
  100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 73, 109,
  97, 103, 101, 32, 112, 105, 120, 92, 51, 48, 51, 92, 50, 53, 49, 108,
  105, 115, 92, 51, 48, 51, 92, 50, 53, 49, 101, 32, 58, 32, 60, 115,
  109, 97, 108, 108, 62, 67, 111, 117, 108, 101, 117, 114, 115, 32, 47, 32,
  67, 111, 108, 111, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47,
  115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 32, 61,
  32, 105, 110, 116, 40, 48, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 71, 114, 105, 115, 32, 61, 32, 98, 111, 111, 108,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108,
  111, 114, 115, 32, 98, 111, 111, 115, 116, 32, 61, 32, 98, 111, 111, 108,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48,
  49, 47, 49, 53, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 115, 97, 109, 106, 95, 71, 114, 105, 108, 108, 101, 95,
  71, 114, 105, 100, 95, 48, 48, 53, 32, 58, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 84, 121, 112,
  101, 95, 100, 101, 95, 114, 101, 110, 100, 117, 61, 36, 49, 10, 82, 101,
  115, 111, 108, 117, 116, 105, 111, 110, 95, 88, 61, 36, 50, 10, 82, 101,
  115, 111, 108, 117, 116, 105, 111, 110, 95, 89, 61, 36, 51, 10, 82, 95,
  67, 111, 117, 108, 101, 117, 114, 61, 36, 52, 10, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 61, 36, 53, 10, 66, 95, 67, 111, 117, 108, 101, 117,
  114, 61, 36, 54, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36,
  55, 10, 86, 97, 108, 101, 117, 114, 95, 100, 105, 108, 97, 116, 101, 95,
  99, 105, 114, 99, 61, 36, 56, 10, 73, 110, 116, 101, 114, 112, 111, 108,
  97, 116, 105, 111, 110, 61, 36, 57, 10, 71, 114, 105, 115, 61, 36, 49,
  48, 10, 66, 111, 111, 115, 116, 61, 36, 49, 49, 10, 45, 105, 102, 32,
  123, 36, 84, 121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100, 117, 61,
  61, 48, 125, 10, 45, 105, 102, 32, 123, 36, 73, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 105, 111, 110, 61, 61, 48, 125, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 123, 123, 119, 125, 47, 36, 82, 101,
  115, 111, 108, 117, 116, 105, 111, 110, 95, 88, 125, 44, 123, 123, 104, 125,
  47, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 95, 89, 125, 10,
  45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105,
  111, 110, 61, 61, 49, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45,
  49, 93, 32, 123, 123, 119, 125, 47, 36, 82, 101, 115, 111, 108, 117, 116,
  105, 111, 110, 95, 88, 125, 44, 123, 123, 104, 125, 47, 36, 82, 101, 115,
  111, 108, 117, 116, 105, 111, 110, 95, 89, 125, 44, 49, 44, 51, 44, 51,
  10, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116,
  105, 111, 110, 61, 61, 50, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91,
  45, 49, 93, 32, 123, 123, 119, 125, 47, 36, 82, 101, 115, 111, 108, 117,
  116, 105, 111, 110, 95, 88, 125, 44, 123, 123, 104, 125, 47, 36, 82, 101,
  115, 111, 108, 117, 116, 105, 111, 110, 95, 89, 125, 10, 45, 110, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 61, 61,
  51, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123,
  123, 119, 125, 47, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 95,
  88, 125, 44, 123, 123, 104, 125, 47, 36, 82, 101, 115, 111, 108, 117, 116,
  105, 111, 110, 95, 89, 125, 44, 49, 44, 51, 44, 51, 10, 45, 110, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 71, 114, 105, 115, 61, 61, 49, 125, 10,
  45, 116, 111, 95, 103, 114, 97, 121, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 123, 119, 125,
  42, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 95, 88, 125, 44,
  123, 123, 104, 125, 42, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110,
  95, 89, 125, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  10, 45, 105, 102, 32, 123, 36, 66, 111, 111, 115, 116, 61, 61, 49, 125,
  10, 45, 103, 105, 109, 112, 95, 98, 97, 108, 97, 110, 99, 101, 95, 103,
  97, 109, 109, 97, 91, 45, 49, 93, 32, 49, 50, 56, 44, 49, 50, 56,
  44, 49, 50, 56, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 123, 119,
  125, 44, 123, 104, 125, 44, 49, 44, 52, 10, 45, 102, 105, 108, 108, 95,
  99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 123, 50, 53, 53, 45, 36,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 125, 44, 123, 50, 53, 53, 45,
  36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 125, 44, 123, 50, 53, 53,
  45, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 125, 44, 36, 65, 95,
  67, 111, 117, 108, 101, 117, 114, 10, 123, 119, 125, 44, 123, 104, 125, 44,
  49, 44, 52, 10, 45, 102, 105, 108, 108, 91, 45, 49, 93, 32, 105, 102,
  40, 120, 37, 123, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 95,
  88, 125, 61, 61, 48, 44, 50, 53, 53, 44, 105, 41, 10, 45, 102, 105,
  108, 108, 91, 45, 49, 93, 32, 105, 102, 40, 121, 37, 123, 36, 82, 101,
  115, 111, 108, 117, 116, 105, 111, 110, 95, 89, 125, 61, 61, 48, 44, 50,
  53, 53, 44, 105, 41, 10, 45, 105, 102, 32, 123, 36, 86, 97, 108, 101,
  117, 114, 95, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 62, 49,
  125, 10, 45, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 91, 45,
  49, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 100, 105, 108, 97, 116,
  101, 95, 99, 105, 114, 99, 10, 45, 101, 110, 100, 105, 102, 10, 45, 103,
  105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93,
  32, 52, 50, 44, 49, 44, 48, 10, 45, 99, 111, 109, 112, 111, 115, 101,
  95, 97, 108, 112, 104, 97, 91, 45, 49, 44, 45, 50, 93, 10, 45, 116,
  111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 91, 45, 49, 93, 32,
  52, 10, 45, 101, 108, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95, 100,
  101, 95, 114, 101, 110, 100, 117, 61, 61, 49, 125, 10, 123, 119, 125, 44,
  123, 104, 125, 44, 49, 44, 52, 10, 45, 102, 105, 108, 108, 95, 99, 111,
  108, 111, 114, 91, 45, 49, 93, 32, 123, 50, 53, 53, 45, 36, 82, 95,
  67, 111, 117, 108, 101, 117, 114, 125, 44, 123, 50, 53, 53, 45, 36, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 125, 44, 123, 50, 53, 53, 45, 36,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 125, 44, 36, 65, 95, 67, 111,
  117, 108, 101, 117, 114, 10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44,
  52, 10, 45, 102, 105, 108, 108, 91, 45, 49, 93, 32, 105, 102, 40, 120,
  37, 123, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 95, 88, 125,
  61, 61, 48, 44, 50, 53, 53, 44, 105, 41, 10, 45, 102, 105, 108, 108,
  91, 45, 49, 93, 32, 105, 102, 40, 121, 37, 123, 36, 82, 101, 115, 111,
  108, 117, 116, 105, 111, 110, 95, 89, 125, 61, 61, 48, 44, 50, 53, 53,
  44, 105, 41, 10, 45, 105, 102, 32, 123, 36, 86, 97, 108, 101, 117, 114,
  95, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 62, 49, 125, 10,
  45, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 91, 45, 49, 93,
  32, 36, 86, 97, 108, 101, 117, 114, 95, 100, 105, 108, 97, 116, 101, 95,
  99, 105, 114, 99, 10, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109,
  112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 52,
  50, 44, 49, 44, 48, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 97,
  108, 112, 104, 97, 91, 45, 49, 44, 45, 50, 93, 10, 45, 116, 111, 95,
  99, 111, 108, 111, 114, 109, 111, 100, 101, 91, 45, 49, 93, 32, 52, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95, 100, 101, 95,
  114, 101, 110, 100, 117, 61, 61, 50, 125, 10, 123, 119, 125, 44, 123, 104,
  125, 44, 49, 44, 52, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111,
  114, 91, 45, 49, 93, 32, 123, 50, 53, 53, 45, 36, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 125, 44, 123, 50, 53, 53, 45, 36, 86, 95, 67,
  111, 117, 108, 101, 117, 114, 125, 44, 123, 50, 53, 53, 45, 36, 66, 95,
  67, 111, 117, 108, 101, 117, 114, 125, 44, 36, 65, 95, 67, 111, 117, 108,
  101, 117, 114, 10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 52, 10,
  45, 102, 105, 108, 108, 91, 45, 49, 93, 32, 105, 102, 40, 120, 37, 123,
  36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 95, 88, 125, 61, 61,
  48, 44, 50, 53, 53, 44, 105, 41, 10, 45, 102, 105, 108, 108, 91, 45,
  49, 93, 32, 105, 102, 40, 121, 37, 123, 36, 82, 101, 115, 111, 108, 117,
  116, 105, 111, 110, 95, 89, 125, 61, 61, 48, 44, 50, 53, 53, 44, 105,
  41, 10, 45, 105, 102, 32, 123, 36, 86, 97, 108, 101, 117, 114, 95, 100,
  105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 62, 49, 125, 10, 45, 100,
  105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 91, 45, 49, 93, 32, 36,
  86, 97, 108, 101, 117, 114, 95, 100, 105, 108, 97, 116, 101, 95, 99, 105,
  114, 99, 10, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95,
  98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 52, 50, 44,
  49, 44, 48, 10, 45, 114, 109, 91, 45, 50, 93, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115,
  97, 109, 106, 95, 71, 114, 105, 108, 108, 101, 95, 71, 114, 105, 100, 95,
  48, 48, 53, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 115, 97, 109, 106, 95, 71, 114, 105, 108, 108, 101, 95,
  71, 114, 105, 100, 95, 48, 48, 53, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 77, 111, 115, 97, 105, 113, 117, 101,
  32, 49, 32, 58, 32, 109, 111, 115, 97, 105, 113, 117, 101, 95, 49, 95,
  98, 97, 108, 108, 101, 115, 95, 115, 97, 109, 106, 44, 32, 109, 111, 115,
  97, 105, 113, 117, 101, 95, 49, 95, 98, 97, 108, 108, 101, 115, 95, 115,
  97, 109, 106, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 82, 101, 115, 111, 108, 117, 116, 105, 111,
  110, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 32,
  61, 32, 105, 110, 116, 40, 49, 50, 48, 44, 56, 48, 44, 52, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 115, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 67, 101, 114, 99, 108, 101, 115, 32, 47, 32, 67,
  105, 114, 99, 108, 101, 115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 105, 109, 101, 110, 115,
  105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 51, 48, 44, 49, 50, 44,
  54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117,
  108, 101, 117, 114, 32, 47, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99,
  111, 108, 111, 114, 40, 50, 49, 48, 44, 50, 49, 48, 44, 50, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 32, 108, 105, 103,
  104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 51, 48, 44,
  48, 46, 50, 48, 44, 48, 46, 56, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 89, 32, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 54, 55, 44, 48, 46, 50, 48, 44, 48, 46,
  56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 32, 114,
  97, 100, 105, 117, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  49, 48, 44, 48, 46, 48, 49, 44, 48, 46, 50, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 89, 32, 114, 97, 100, 105, 117, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 48, 56, 44, 48, 46, 48,
  49, 44, 48, 46, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 76, 105, 103, 104, 116, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99,
  111, 108, 111, 114, 40, 49, 56, 48, 44, 49, 56, 48, 44, 49, 56, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 108, 111, 117, 32,
  47, 32, 98, 108, 117, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  65, 110, 103, 108, 101, 32, 114, 111, 116, 97, 116, 105, 111, 110, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 56, 48, 46, 48, 48, 44, 48, 46,
  48, 48, 44, 51, 54, 48, 46, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 110, 116, 111, 117, 114, 32, 61, 32, 105, 110,
  116, 40, 53, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 68, 92, 51, 48, 51, 92, 50, 53, 49, 99, 97, 108, 97,
  103, 101, 32, 120, 32, 99, 111, 110, 116, 111, 117, 114, 32, 61, 32, 105,
  110, 116, 40, 45, 49, 44, 45, 53, 44, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 68, 92, 51, 48, 51, 92, 50, 53, 49, 99, 97,
  108, 97, 103, 101, 32, 121, 32, 99, 111, 110, 116, 111, 117, 114, 32, 61,
  32, 105, 110, 116, 40, 48, 44, 45, 53, 44, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 42, 42, 42, 32, 112, 114, 92, 51, 48, 51,
  92, 50, 53, 49, 118, 105, 115, 117, 97, 108, 105, 115, 97, 116, 105, 111,
  110, 32, 97, 106, 117, 115, 116, 101, 114, 32, 114, 92, 51, 48, 51, 92,
  50, 53, 49, 103, 108, 97, 103, 101, 115, 32, 47, 32, 112, 114, 101, 118,
  105, 101, 119, 32, 97, 100, 106, 117, 115, 116, 32, 115, 101, 116, 116, 105,
  110, 103, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 115, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 70, 111, 110, 100, 32, 47, 32, 66, 97, 99, 107, 103, 114, 111, 117,
  110, 100, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 61, 32, 99, 111,
  108, 111, 114, 40, 48, 44, 48, 44, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 111, 114, 109, 97, 108, 105, 122, 101, 32, 108, 32,
  61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 116, 32, 108, 32,
  61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 82, 92, 51, 48, 51, 92, 50, 53, 49, 115, 117, 108, 116, 97, 116,
  32, 102, 105, 110, 97, 108, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 101, 116, 116, 101, 116,
  92, 51, 48, 51, 92, 50, 53, 49, 32, 47, 32, 115, 104, 97, 114, 112,
  101, 110, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 52, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 114, 109, 97,
  108, 105, 122, 101, 32, 108, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56,
  44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 117, 116, 32, 108, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56,
  44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 73, 116, 92, 51, 48, 51, 92, 50, 53, 49, 114, 97, 116, 105, 111,
  110, 115, 32, 97, 99, 99, 101, 110, 116, 117, 97, 116, 105, 111, 110, 32,
  61, 32, 105, 110, 116, 40, 49, 44, 48, 44, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 66, 108, 101,
  110, 100, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 49, 49, 44, 34, 65, 100, 100, 34, 44, 34, 65, 108,
  112, 104, 97, 34, 44, 34, 65, 110, 100, 34, 44, 34, 65, 118, 101, 114,
  97, 103, 101, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 66, 117, 114,
  110, 34, 44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 68, 105, 102,
  102, 101, 114, 101, 110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 34, 68, 105, 118, 105, 100, 101, 34, 44, 34, 68, 111, 100,
  103, 101, 34, 44, 34, 69, 120, 99, 108, 117, 115, 105, 111, 110, 34, 44,
  34, 70, 114, 101, 101, 122, 101, 34, 44, 34, 71, 114, 97, 105, 110, 32,
  101, 120, 116, 114, 97, 99, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32,
  109, 101, 114, 103, 101, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34,
  72, 97, 114, 100, 32, 108, 105, 103, 104, 116, 34, 44, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 34, 72, 97, 114, 100, 32, 109, 105, 120, 34,
  44, 34, 72, 117, 101, 34, 44, 34, 73, 110, 116, 101, 114, 112, 111, 108,
  97, 116, 105, 111, 110, 34, 44, 34, 76, 105, 103, 104, 116, 101, 110, 34,
  44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 76, 105,
  110, 101, 97, 114, 32, 98, 117, 114, 110, 34, 44, 34, 76, 105, 110, 101,
  97, 114, 32, 108, 105, 103, 104, 116, 34, 44, 34, 76, 117, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  34, 77, 117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 78, 101, 103, 97,
  116, 105, 111, 110, 34, 44, 34, 79, 114, 34, 44, 34, 79, 118, 101, 114,
  108, 97, 121, 34, 44, 34, 80, 105, 110, 32, 108, 105, 103, 104, 116, 34,
  44, 34, 82, 101, 100, 34, 44, 34, 82, 101, 102, 108, 101, 99, 116, 34,
  44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 34, 83, 104, 97, 112, 101, 32, 65,
  118, 101, 114, 97, 103, 101, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65,
  118, 101, 114, 97, 103, 101, 48, 34, 44, 34, 83, 111, 102, 116, 32, 98,
  117, 114, 110, 34, 44, 34, 83, 111, 102, 116, 32, 100, 111, 100, 103, 101,
  34, 44, 34, 83, 111, 102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34,
  83, 99, 114, 101, 101, 110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44,
  34, 83, 117, 98, 116, 114, 97, 99, 116, 34, 44, 34, 86, 97, 108, 117,
  101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 86, 105,
  118, 105, 100, 32, 108, 105, 103, 104, 116, 34, 44, 34, 88, 111, 114, 34,
  44, 34, 77, 111, 100, 101, 32, 67, 111, 117, 108, 101, 117, 114, 115, 34,
  44, 34, 50, 32, 67, 97, 108, 113, 117, 101, 115, 32, 47, 32, 50, 32,
  76, 97, 121, 101, 114, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121, 101, 114, 115, 32,
  61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121,
  112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60,
  105, 62, 83, 97, 109, 106, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58,
  32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 49, 55, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 109, 111,
  115, 97, 105, 113, 117, 101, 95, 49, 95, 98, 97, 108, 108, 101, 115, 95,
  115, 97, 109, 106, 58, 10, 35, 35, 32, 118, 97, 114, 105, 97, 98, 108,
  101, 115, 10, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 61, 36, 49,
  10, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 98, 97, 108, 108, 101,
  61, 36, 50, 10, 82, 95, 66, 97, 108, 108, 101, 61, 36, 51, 10, 86,
  95, 66, 97, 108, 108, 101, 61, 36, 52, 10, 66, 95, 66, 97, 108, 108,
  101, 61, 36, 53, 10, 88, 95, 108, 105, 103, 104, 116, 61, 36, 54, 10,
  89, 95, 108, 105, 103, 104, 116, 61, 36, 55, 10, 88, 95, 114, 97, 100,
  105, 117, 115, 61, 36, 56, 10, 89, 95, 114, 97, 100, 105, 117, 115, 61,
  36, 57, 10, 82, 95, 108, 105, 103, 104, 116, 61, 36, 49, 48, 10, 71,
  95, 108, 105, 103, 104, 116, 61, 36, 49, 49, 10, 66, 95, 108, 105, 103,
  104, 116, 61, 36, 49, 50, 10, 70, 108, 111, 117, 95, 98, 97, 108, 108,
  101, 61, 36, 49, 51, 10, 65, 110, 103, 108, 101, 95, 114, 111, 116, 97,
  116, 105, 111, 110, 61, 36, 49, 52, 10, 67, 111, 110, 116, 111, 117, 114,
  95, 98, 97, 108, 108, 101, 61, 36, 49, 53, 10, 68, 101, 99, 97, 108,
  97, 103, 101, 95, 88, 95, 67, 111, 110, 116, 111, 117, 114, 61, 36, 49,
  54, 10, 68, 101, 99, 97, 108, 97, 103, 101, 95, 89, 95, 67, 111, 110,
  116, 111, 117, 114, 61, 36, 49, 55, 10, 65, 106, 117, 115, 116, 101, 114,
  95, 114, 101, 103, 108, 97, 103, 101, 115, 61, 36, 49, 56, 10, 82, 95,
  102, 111, 110, 100, 61, 36, 49, 57, 10, 86, 95, 102, 111, 110, 100, 61,
  36, 50, 48, 10, 66, 95, 102, 111, 110, 100, 61, 36, 50, 49, 10, 110,
  111, 114, 109, 97, 108, 105, 122, 101, 95, 76, 95, 98, 97, 108, 108, 101,
  115, 61, 36, 50, 50, 10, 99, 117, 116, 95, 76, 95, 98, 97, 108, 108,
  101, 115, 61, 36, 50, 51, 10, 110, 101, 116, 116, 101, 116, 101, 61, 36,
  50, 52, 10, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 76, 95, 102,
  105, 110, 97, 108, 61, 36, 50, 53, 10, 99, 117, 116, 95, 76, 95, 102,
  105, 110, 97, 108, 61, 36, 50, 54, 10, 73, 116, 101, 114, 97, 116, 105,
  111, 110, 115, 95, 65, 99, 99, 101, 110, 116, 117, 97, 116, 105, 111, 110,
  61, 36, 50, 55, 10, 98, 108, 101, 110, 100, 61, 36, 50, 56, 10, 111,
  112, 97, 99, 105, 116, 101, 61, 36, 50, 57, 10, 82, 101, 118, 101, 114,
  116, 95, 108, 97, 121, 101, 114, 115, 61, 36, 51, 48, 10, 35, 32, 86,
  97, 114, 105, 97, 98, 108, 101, 115, 32, 99, 97, 108, 99, 117, 108, -23,
  101, 115, 10, 45, 105, 102, 32, 123, 36, 67, 111, 110, 116, 111, 117, 114,
  95, 98, 97, 108, 108, 101, 62, 123, 36, 68, 105, 109, 101, 110, 115, 105,
  111, 110, 95, 98, 97, 108, 108, 101, 42, 48, 46, 51, 125, 125, 10, 67,
  111, 110, 116, 111, 117, 114, 95, 98, 97, 108, 108, 101, 61, 123, 114, 111,
  117, 110, 100, 40, 123, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95,
  98, 97, 108, 108, 101, 42, 48, 46, 51, 125, 41, 125, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 123, 36, 82, 101, 115, 111, 108,
  117, 116, 105, 111, 110, 42, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110,
  95, 98, 97, 108, 108, 101, 125, 62, 52, 56, 48, 48, 125, 10, 68, 105,
  109, 101, 110, 115, 105, 111, 110, 95, 98, 97, 108, 108, 101, 61, 123, 114,
  111, 117, 110, 100, 40, 123, 52, 56, 48, 48, 47, 36, 82, 101, 115, 111,
  108, 117, 116, 105, 111, 110, 125, 41, 125, 10, 45, 101, 110, 100, 105, 102,
  10, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 114, 101, 115, 117, 108,
  116, 97, 116, 61, 123, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110,
  42, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 98, 97, 108, 108,
  101, 125, 10, 45, 116, 111, 95, 114, 103, 98, 97, 10, 45, 105, 102, 32,
  123, 36, 98, 108, 101, 110, 100, 61, 61, 52, 51, 125, 10, 75, 95, 105,
  109, 95, 73, 77, 61, 49, 54, 10, 45, 45, 103, 105, 109, 112, 95, 100,
  111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 103,
  105, 109, 112, 95, 100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104,
  97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 50, 44, 48, 44, 49,
  44, 48, 32, 73, 77, 65, 88, 61, 123, 114, 111, 117, 110, 100, 40, 123,
  123, 105, 77, 125, 45, 36, 75, 95, 105, 109, 95, 73, 77, 125, 41, 125,
  32, 73, 77, 73, 78, 61, 123, 114, 111, 117, 110, 100, 40, 123, 123, 105,
  109, 125, 43, 36, 75, 95, 105, 109, 95, 73, 77, 125, 41, 125, 32, 45,
  114, 109, 91, 45, 49, 44, 45, 50, 44, 45, 51, 93, 10, 45, 105, 102,
  32, 123, 36, 73, 77, 65, 88, 62, 50, 53, 53, 125, 32, 73, 77, 65,
  88, 61, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 32, 45, 105, 102,
  32, 123, 36, 73, 77, 73, 78, 60, 48, 125, 32, 73, 77, 73, 78, 61,
  48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 65, 106, 117, 115, 116, 101, 114, 95, 114, 101,
  103, 108, 97, 103, 101, 115, 61, 61, 48, 125, 10, 45, 105, 102, 32, 123,
  123, 119, 125, 62, 123, 104, 125, 125, 10, 45, 114, 101, 115, 105, 122, 101,
  91, 45, 49, 93, 32, 123, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110,
  95, 114, 101, 115, 117, 108, 116, 97, 116, 47, 36, 68, 105, 109, 101, 110,
  115, 105, 111, 110, 95, 98, 97, 108, 108, 101, 125, 44, 123, 123, 123, 104,
  125, 42, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 114, 101, 115,
  117, 108, 116, 97, 116, 47, 123, 119, 125, 125, 47, 36, 68, 105, 109, 101,
  110, 115, 105, 111, 110, 95, 98, 97, 108, 108, 101, 125, 44, 49, 44, 51,
  10, 45, 101, 108, 115, 101, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45,
  49, 93, 32, 123, 123, 123, 119, 125, 42, 36, 68, 105, 109, 101, 110, 115,
  105, 111, 110, 95, 114, 101, 115, 117, 108, 116, 97, 116, 47, 123, 104, 125,
  125, 47, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 98, 97, 108,
  108, 101, 125, 44, 123, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95,
  114, 101, 115, 117, 108, 116, 97, 116, 47, 36, 68, 105, 109, 101, 110, 115,
  105, 111, 110, 95, 98, 97, 108, 108, 101, 125, 44, 49, 44, 51, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 105, 109, 60, 48, 125,
  32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101,
  108, 105, 102, 32, 123, 105, 77, 62, 50, 53, 53, 125, 32, 45, 99, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 123, 119,
  125, 42, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 98, 97, 108,
  108, 101, 125, 44, 123, 123, 104, 125, 42, 36, 68, 105, 109, 101, 110, 115,
  105, 111, 110, 95, 98, 97, 108, 108, 101, 125, 10, 123, 36, 68, 105, 109,
  101, 110, 115, 105, 111, 110, 95, 98, 97, 108, 108, 101, 43, 36, 67, 111,
  110, 116, 111, 117, 114, 95, 98, 97, 108, 108, 101, 125, 44, 123, 36, 68,
  105, 109, 101, 110, 115, 105, 111, 110, 95, 98, 97, 108, 108, 101, 43, 36,
  67, 111, 110, 116, 111, 117, 114, 95, 98, 97, 108, 108, 101, 125, 44, 49,
  44, 52, 10, 45, 98, 97, 108, 108, 95, 109, 111, 100, 105, 102, 105, 99,
  97, 116, 105, 111, 110, 95, 115, 97, 109, 106, 91, 45, 49, 93, 32, 36,
  82, 95, 66, 97, 108, 108, 101, 44, 36, 86, 95, 66, 97, 108, 108, 101,
  44, 36, 66, 95, 66, 97, 108, 108, 101, 44, 36, 88, 95, 108, 105, 103,
  104, 116, 44, 36, 89, 95, 108, 105, 103, 104, 116, 44, 36, 88, 95, 114,
  97, 100, 105, 117, 115, 44, 36, 89, 95, 114, 97, 100, 105, 117, 115, 44,
  36, 82, 95, 108, 105, 103, 104, 116, 44, 36, 71, 95, 108, 105, 103, 104,
  116, 44, 36, 66, 95, 108, 105, 103, 104, 116, 10, 45, 105, 102, 32, 123,
  36, 67, 111, 110, 116, 111, 117, 114, 95, 98, 97, 108, 108, 101, 62, 48,
  125, 10, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 123, 36, 67, 111,
  110, 116, 111, 117, 114, 95, 98, 97, 108, 108, 101, 43, 36, 68, 101, 99,
  97, 108, 97, 103, 101, 95, 88, 95, 67, 111, 110, 116, 111, 117, 114, 125,
  44, 123, 36, 67, 111, 110, 116, 111, 117, 114, 95, 98, 97, 108, 108, 101,
  43, 36, 68, 101, 99, 97, 108, 97, 103, 101, 95, 89, 95, 67, 111, 110,
  116, 111, 117, 114, 125, 44, 123, 123, 119, 125, 45, 123, 36, 67, 111, 110,
  116, 111, 117, 114, 95, 98, 97, 108, 108, 101, 43, 36, 68, 101, 99, 97,
  108, 97, 103, 101, 95, 88, 95, 67, 111, 110, 116, 111, 117, 114, 125, 125,
  44, 123, 123, 104, 125, 45, 123, 36, 67, 111, 110, 116, 111, 117, 114, 95,
  98, 97, 108, 108, 101, 43, 36, 68, 101, 99, 97, 108, 97, 103, 101, 95,
  89, 95, 67, 111, 110, 116, 111, 117, 114, 125, 125, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10,
  45, 105, 102, 32, 123, 36, 65, 110, 103, 108, 101, 95, 114, 111, 116, 97,
  116, 105, 111, 110, 62, 48, 125, 10, 45, 114, 111, 116, 97, 116, 101, 91,
  45, 49, 93, 32, 36, 65, 110, 103, 108, 101, 95, 114, 111, 116, 97, 116,
  105, 111, 110, 44, 48, 44, 50, 44, 123, 123, 119, 125, 47, 50, 125, 44,
  123, 123, 104, 125, 47, 50, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 10, 45, 114, 101,
  115, 105, 122, 101, 91, 45, 49, 93, 32, 36, 68, 105, 109, 101, 110, 115,
  105, 111, 110, 95, 98, 97, 108, 108, 101, 44, 36, 68, 105, 109, 101, 110,
  115, 105, 111, 110, 95, 98, 97, 108, 108, 101, 44, 49, 44, 51, 10, 45,
  110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50,
  93, 44, 49, 44, 49, 44, 48, 44, 50, 10, 45, 116, 111, 95, 114, 103,
  98, 97, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 98, 108, 101,
  110, 100, 60, 52, 52, 125, 10, 45, 105, 102, 32, 123, 123, 36, 82, 95,
  102, 111, 110, 100, 43, 36, 86, 95, 102, 111, 110, 100, 43, 36, 66, 95,
  102, 111, 110, 100, 125, 62, 48, 125, 10, 45, 114, 101, 112, 108, 97, 99,
  101, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 52, 48, 44, 51,
  44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 36, 82, 95, 102, 111,
  110, 100, 44, 36, 86, 95, 102, 111, 110, 100, 44, 36, 66, 95, 102, 111,
  110, 100, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 76, 95,
  98, 97, 108, 108, 101, 115, 33, 61, 49, 50, 56, 125, 10, 45, 103, 105,
  109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 45,
  49, 93, 32, 48, 44, 49, 50, 56, 44, 36, 110, 111, 114, 109, 97, 108,
  105, 122, 101, 95, 76, 95, 98, 97, 108, 108, 101, 115, 44, 45, 49, 44,
  49, 50, 56, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50,
  56, 44, 45, 49, 44, 49, 50, 56, 44, 50, 53, 53, 44, 49, 44, 51,
  44, 49, 44, 48, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 99, 117, 116, 95, 76, 95, 98, 97, 108, 108, 101, 115,
  33, 61, 49, 50, 56, 125, 10, 45, 103, 105, 109, 112, 95, 97, 112, 112,
  108, 121, 95, 99, 117, 114, 118, 101, 91, 45, 49, 93, 32, 48, 44, 49,
  50, 56, 44, 36, 99, 117, 116, 95, 76, 95, 98, 97, 108, 108, 101, 115,
  44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50, 56, 44, 45,
  49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50, 56, 44, 50, 53, 53,
  44, 49, 44, 51, 44, 48, 44, 48, 44, 48, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 70, 108, 111,
  117, 95, 98, 97, 108, 108, 101, 10, 45, 105, 102, 32, 123, 36, 98, 108,
  101, 110, 100, 61, 61, 52, 51, 125, 10, 45, 99, 91, 45, 49, 44, 45,
  50, 93, 32, 36, 73, 77, 73, 78, 44, 36, 73, 77, 65, 88, 32, 45,
  103, 105, 109, 112, 95, 100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99,
  104, 97, 110, 110, 101, 108, 115, 32, 50, 44, 48, 44, 49, 44, 48, 32,
  45, 114, 101, 109, 111, 118, 101, 91, 45, 50, 44, 45, 51, 44, 45, 52,
  93, 32, 45, 103, 105, 109, 112, 95, 100, 101, 99, 111, 109, 112, 111, 115,
  101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32, 50, 44, 49, 44, 49,
  44, 48, 10, 45, 101, 108, 115, 101, 10, 45, 103, 105, 109, 112, 95, 98,
  108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 36, 98, 108, 101,
  110, 100, 44, 36, 111, 112, 97, 99, 105, 116, 101, 44, 36, 82, 101, 118,
  101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 110, 101, 116, 116, 101, 116, 101, 62,
  48, 125, 10, 45, 115, 104, 97, 114, 112, 101, 110, 91, 45, 49, 93, 32,
  36, 110, 101, 116, 116, 101, 116, 101, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 36, 73, 116, 101, 114, 97, 116, 105,
  111, 110, 115, 95, 65, 99, 99, 101, 110, 116, 117, 97, 116, 105, 111, 110,
  10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105,
  110, 103, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101,
  110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 50, 55, 44, 49, 44, 48,
  10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 110, 111, 114,
  109, 97, 108, 105, 122, 101, 95, 76, 95, 102, 105, 110, 97, 108, 33, 61,
  49, 50, 56, 125, 10, 45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121,
  95, 99, 117, 114, 118, 101, 91, 45, 49, 93, 32, 48, 44, 49, 50, 56,
  44, 36, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 76, 95, 102, 105,
  110, 97, 108, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50,
  56, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50, 56, 44,
  50, 53, 53, 44, 49, 44, 51, 44, 49, 44, 48, 44, 48, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 99, 117, 116, 95, 76,
  95, 102, 105, 110, 97, 108, 33, 61, 49, 50, 56, 125, 10, 45, 103, 105,
  109, 112, 95, 97, 112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 45,
  49, 93, 32, 48, 44, 49, 50, 56, 44, 36, 99, 117, 116, 95, 76, 95,
  102, 105, 110, 97, 108, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44,
  49, 50, 56, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50,
  56, 44, 50, 53, 53, 44, 49, 44, 51, 44, 48, 44, 48, 44, 48, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  108, 115, 101, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32,
  123, 123, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 98, 97, 108,
  108, 101, 43, 36, 67, 111, 110, 116, 111, 117, 114, 95, 98, 97, 108, 108,
  101, 125, 42, 49, 46, 53, 125, 44, 123, 123, 36, 68, 105, 109, 101, 110,
  115, 105, 111, 110, 95, 98, 97, 108, 108, 101, 43, 36, 67, 111, 110, 116,
  111, 117, 114, 95, 98, 97, 108, 108, 101, 125, 42, 49, 46, 53, 125, 44,
  49, 44, 51, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91,
  45, 49, 93, 32, 50, 53, 53, 44, 49, 50, 56, 44, 54, 52, 44, 50,
  53, 53, 10, 123, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 98,
  97, 108, 108, 101, 43, 36, 67, 111, 110, 116, 111, 117, 114, 95, 98, 97,
  108, 108, 101, 125, 44, 123, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110,
  95, 98, 97, 108, 108, 101, 43, 36, 67, 111, 110, 116, 111, 117, 114, 95,
  98, 97, 108, 108, 101, 125, 44, 49, 44, 52, 10, 45, 98, 97, 108, 108,
  95, 109, 111, 100, 105, 102, 105, 99, 97, 116, 105, 111, 110, 95, 115, 97,
  109, 106, 91, 45, 49, 93, 32, 36, 82, 95, 66, 97, 108, 108, 101, 44,
  36, 86, 95, 66, 97, 108, 108, 101, 44, 36, 66, 95, 66, 97, 108, 108,
  101, 44, 36, 88, 95, 108, 105, 103, 104, 116, 44, 36, 89, 95, 108, 105,
  103, 104, 116, 44, 36, 88, 95, 114, 97, 100, 105, 117, 115, 44, 36, 89,
  95, 114, 97, 100, 105, 117, 115, 44, 36, 82, 95, 108, 105, 103, 104, 116,
  44, 36, 71, 95, 108, 105, 103, 104, 116, 44, 36, 66, 95, 108, 105, 103,
  104, 116, 10, 45, 105, 102, 32, 123, 36, 67, 111, 110, 116, 111, 117, 114,
  95, 98, 97, 108, 108, 101, 62, 48, 125, 10, 45, 99, 114, 111, 112, 91,
  45, 49, 93, 32, 123, 36, 67, 111, 110, 116, 111, 117, 114, 95, 98, 97,
  108, 108, 101, 43, 36, 68, 101, 99, 97, 108, 97, 103, 101, 95, 88, 95,
  67, 111, 110, 116, 111, 117, 114, 125, 44, 123, 36, 67, 111, 110, 116, 111,
  117, 114, 95, 98, 97, 108, 108, 101, 43, 36, 68, 101, 99, 97, 108, 97,
  103, 101, 95, 89, 95, 67, 111, 110, 116, 111, 117, 114, 125, 44, 123, 123,
  119, 125, 45, 123, 36, 67, 111, 110, 116, 111, 117, 114, 95, 98, 97, 108,
  108, 101, 43, 36, 68, 101, 99, 97, 108, 97, 103, 101, 95, 88, 95, 67,
  111, 110, 116, 111, 117, 114, 125, 125, 44, 123, 123, 104, 125, 45, 123, 36,
  67, 111, 110, 116, 111, 117, 114, 95, 98, 97, 108, 108, 101, 43, 36, 68,
  101, 99, 97, 108, 97, 103, 101, 95, 89, 95, 67, 111, 110, 116, 111, 117,
  114, 125, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 110, 91, 45, 49,
  93, 32, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36, 65, 110,
  103, 108, 101, 95, 114, 111, 116, 97, 116, 105, 111, 110, 62, 48, 125, 10,
  45, 114, 111, 116, 97, 116, 101, 91, 45, 49, 93, 32, 36, 65, 110, 103,
  108, 101, 95, 114, 111, 116, 97, 116, 105, 111, 110, 44, 48, 44, 50, 44,
  123, 123, 119, 125, 47, 50, 125, 44, 123, 123, 104, 125, 47, 50, 125, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 97, 117, 116, 111, 99, 114, 111, 112,
  91, 45, 49, 93, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93,
  32, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 98, 97, 108, 108,
  101, 44, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 98, 97, 108,
  108, 101, 44, 49, 44, 51, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91,
  45, 49, 44, 45, 50, 93, 32, 51, 54, 44, 49, 44, 49, 10, 45, 101,
  110, 100, 105, 102, 10, 35, 64, 103, 105, 109, 112, 32, 79, 110, 100, 101,
  115, 32, 48, 48, 49, 32, 58, 32, 115, 97, 109, 106, 95, 79, 110, 100,
  101, 115, 95, 48, 48, 49, 44, 32, 115, 97, 109, 106, 95, 79, 110, 100,
  101, 115, 95, 48, 48, 49, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110,
  32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97,
  110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 77,
  97, 115, 113, 117, 101, 32, 79, 110, 100, 101, 32, 47, 32, 77, 97, 115,
  107, 32, 87, 97, 118, 101, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47,
  115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 84, 111, 108, 101, 114, 97, 110, 99, 101, 32, 37, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 105, 115, 32, 47, 32, 103,
  114, 97, 121, 32, 61, 32, 105, 110, 116, 40, 49, 54, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 108, 111,
  117, 32, 47, 32, 98, 108, 117, 114, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 44, 48, 44, 51, 41, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 73, 110, 118, 101, 114, 115, 101, 114, 32, 47, 32, 110, 101, 103,
  97, 116, 105, 118, 101, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102,
  111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103,
  101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 66, 108, 101,
  110, 100, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 110,
  100, 117, 32, 47, 32, 114, 101, 110, 100, 101, 114, 105, 110, 103, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 50, 44, 34, 77, 97, 115, 113, 117,
  101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34, 79, 118, 101, 114,
  108, 97, 121, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79,
  112, 97, 99, 105, 116, 101, 32, 47, 32, 111, 112, 97, 99, 105, 116, 121,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97, 109, 106,
  32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 50, 51,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  115, 97, 109, 106, 95, 79, 110, 100, 101, 115, 95, 48, 48, 49, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 84, 111, 108, 101, 114, 97, 110, 99, 101, 61, 36, 49, 10,
  71, 114, 105, 115, 61, 36, 50, 10, 70, 108, 111, 117, 61, 36, 51, 10,
  73, 110, 118, 101, 114, 115, 101, 114, 61, 36, 52, 10, 82, 101, 110, 100,
  117, 61, 36, 53, 10, 66, 108, 101, 110, 100, 95, 79, 112, 97, 99, 105,
  116, 121, 61, 36, 54, 10, 45, 105, 102, 32, 123, 36, 82, 101, 110, 100,
  117, 62, 48, 125, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110,
  111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 49, 93, 10, 45,
  115, 101, 108, 101, 99, 116, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93,
  32, 36, 84, 111, 108, 101, 114, 97, 110, 99, 101, 44, 36, 71, 114, 105,
  115, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45,
  116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 10, 45, 114, 101, 112,
  108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48,
  44, 48, 44, 48, 44, 48, 10, 45, 42, 91, 45, 49, 93, 32, 91, 45,
  49, 93, 10, 45, 97, 110, 100, 91, 45, 49, 93, 32, 49, 50, 55, 10,
  45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 105, 102,
  32, 123, 36, 73, 110, 118, 101, 114, 115, 101, 114, 61, 61, 49, 125, 10,
  45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 70, 108, 111, 117, 62,
  48, 125, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 70, 108,
  111, 117, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  82, 101, 110, 100, 117, 61, 61, 49, 125, 10, 45, 103, 105, 109, 112, 95,
  98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 49, 44, 36,
  66, 108, 101, 110, 100, 95, 79, 112, 97, 99, 105, 116, 121, 44, 49, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 82, 101, 110, 100, 117, 61, 61, 50,
  125, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49,
  44, 45, 50, 93, 32, 50, 55, 44, 36, 66, 108, 101, 110, 100, 95, 79,
  112, 97, 99, 105, 116, 121, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115, 97, 109, 106,
  95, 79, 110, 100, 101, 115, 95, 48, 48, 49, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95,
  79, 110, 100, 101, 115, 95, 48, 48, 49, 32, 36, 42, 34, 44, 36, 45,
  49, 10, 35, 64, 103, 105, 109, 112, 32, 80, 111, 105, 110, 116, 115, 32,
  97, 108, 101, 97, 116, 111, 105, 114, 101, 115, 32, 48, 48, 49, 32, 58,
  32, 115, 97, 109, 106, 95, 80, 111, 105, 110, 116, 115, 95, 65, 108, 101,
  97, 116, 111, 105, 114, 101, 115, 95, 48, 48, 49, 44, 32, 115, 97, 109,
  106, 95, 80, 111, 105, 110, 116, 115, 95, 65, 108, 101, 97, 116, 111, 105,
  114, 101, 115, 95, 48, 48, 49, 95, 112, 114, 101, 118, 105, 101, 119, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114,
  101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114,
  101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 80, 111, 105, 110, 116,
  115, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101, 114,
  97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 49, 48, 44,
  49, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 117, 108, 101, 117, 114, 32, 112, 111, 105, 110, 116, 32, 61, 32,
  99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111,
  100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 88,
  89, 32, 65, 108, 101, 97, 116, 111, 105, 114, 101, 34, 44, 34, 88, 32,
  65, 108, 101, 97, 116, 111, 105, 114, 101, 34, 44, 34, 89, 32, 65, 108,
  101, 97, 116, 111, 105, 114, 101, 34, 44, 34, 67, 97, 118, 97, 108, 105,
  101, 114, 34, 44, 34, 70, 111, 117, 34, 44, 34, 84, 111, 117, 114, 34,
  44, 34, 82, 101, 105, 110, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 115, 32, 97, 108, 101, 97,
  116, 111, 105, 114, 101, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116, 105, 110,
  117, 105, 116, 101, 32, 101, 110, 116, 114, 101, 32, 105, 116, 101, 114, 97,
  116, 105, 111, 110, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97, 109, 106,
  32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 51, 48,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  115, 97, 109, 106, 95, 80, 111, 105, 110, 116, 115, 95, 65, 108, 101, 97,
  116, 111, 105, 114, 101, 115, 95, 48, 48, 49, 32, 58, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 73,
  116, 101, 114, 97, 116, 105, 111, 110, 115, 61, 36, 49, 10, 82, 95, 80,
  111, 105, 110, 116, 61, 36, 50, 10, 86, 95, 80, 111, 105, 110, 116, 61,
  36, 51, 10, 66, 95, 80, 111, 105, 110, 116, 61, 36, 52, 10, 65, 95,
  80, 111, 105, 110, 116, 61, 36, 53, 10, 77, 111, 100, 101, 61, 36, 54,
  10, 67, 111, 117, 108, 101, 117, 114, 115, 95, 65, 108, 101, 97, 116, 111,
  105, 114, 101, 115, 61, 36, 55, 10, 67, 111, 110, 116, 105, 110, 117, 105,
  116, 101, 61, 36, 56, 10, 67, 104, 111, 105, 120, 61, 48, 10, 67, 97,
  118, 97, 108, 105, 101, 114, 61, 48, 10, 76, 97, 114, 103, 101, 117, 114,
  95, 79, 114, 105, 103, 105, 110, 101, 61, 123, 119, 125, 10, 72, 97, 117,
  116, 101, 117, 114, 95, 79, 114, 105, 103, 105, 110, 101, 61, 123, 104, 125,
  10, 80, 111, 115, 105, 116, 105, 111, 110, 95, 88, 61, 123, 114, 111, 117,
  110, 100, 40, 63, 40, 48, 44, 123, 36, 76, 97, 114, 103, 101, 117, 114,
  95, 79, 114, 105, 103, 105, 110, 101, 45, 49, 125, 41, 41, 125, 10, 80,
  111, 115, 105, 116, 105, 111, 110, 95, 89, 61, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 48, 44, 123, 36, 72, 97, 117, 116, 101, 117, 114, 95, 79,
  114, 105, 103, 105, 110, 101, 45, 49, 125, 41, 41, 125, 10, 123, 119, 125,
  44, 123, 104, 125, 44, 49, 44, 52, 10, 45, 102, 105, 108, 108, 95, 99,
  111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48,
  10, 45, 114, 109, 91, 45, 50, 93, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 36, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 10, 45, 105, 102,
  32, 123, 36, 67, 111, 117, 108, 101, 117, 114, 115, 95, 65, 108, 101, 97,
  116, 111, 105, 114, 101, 115, 61, 61, 49, 125, 10, 82, 95, 80, 111, 105,
  110, 116, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53,
  53, 41, 41, 125, 10, 86, 95, 80, 111, 105, 110, 116, 61, 123, 114, 111,
  117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 66,
  95, 80, 111, 105, 110, 116, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40,
  48, 44, 50, 53, 53, 41, 41, 125, 10, 65, 95, 80, 111, 105, 110, 116,
  61, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 67, 111, 110, 116, 105, 110, 117, 105, 116, 101, 61, 61, 48, 125,
  10, 80, 111, 115, 105, 116, 105, 111, 110, 95, 88, 61, 123, 114, 111, 117,
  110, 100, 40, 63, 40, 48, 44, 123, 36, 76, 97, 114, 103, 101, 117, 114,
  95, 79, 114, 105, 103, 105, 110, 101, 45, 49, 125, 41, 41, 125, 10, 80,
  111, 115, 105, 116, 105, 111, 110, 95, 89, 61, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 48, 44, 123, 36, 72, 97, 117, 116, 101, 117, 114, 95, 79,
  114, 105, 103, 105, 110, 101, 45, 49, 125, 41, 41, 125, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 76, 97,
  114, 103, 101, 117, 114, 95, 79, 114, 105, 103, 105, 110, 101, 43, 36, 72,
  97, 117, 116, 101, 117, 114, 95, 79, 114, 105, 103, 105, 110, 101, 125, 10,
  67, 104, 111, 105, 120, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 49, 41, 41, 125, 10, 45, 105, 102, 32, 123, 36, 77, 111, 100, 101,
  61, 61, 48, 125, 10, 73, 110, 99, 95, 88, 61, 123, 123, 114, 111, 117,
  110, 100, 40, 63, 40, 48, 44, 50, 41, 41, 125, 45, 49, 125, 10, 73,
  110, 99, 95, 89, 61, 123, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 50, 41, 41, 125, 45, 49, 125, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 77, 111, 100, 101, 61, 61, 49, 125, 10, 73, 110, 99, 95, 88, 61,
  123, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 41, 41, 125,
  45, 49, 125, 10, 73, 110, 99, 95, 89, 61, 123, 123, 114, 111, 117, 110,
  100, 40, 63, 40, 48, 44, 123, 64, 124, 125, 41, 41, 37, 51, 125, 45,
  49, 125, 10, 45, 101, 108, 105, 102, 32, 123, 36, 77, 111, 100, 101, 61,
  61, 50, 125, 10, 73, 110, 99, 95, 88, 61, 123, 123, 114, 111, 117, 110,
  100, 40, 63, 40, 48, 44, 123, 64, 124, 125, 41, 41, 37, 51, 125, 45,
  49, 125, 10, 73, 110, 99, 95, 89, 61, 123, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 48, 44, 50, 41, 41, 125, 45, 49, 125, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 77, 111, 100, 101, 61, 61, 51, 125, 10, 45, 105,
  102, 32, 123, 36, 67, 104, 111, 105, 120, 61, 61, 48, 125, 10, 67, 97,
  118, 97, 108, 105, 101, 114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40,
  48, 44, 55, 41, 41, 125, 10, 45, 101, 108, 115, 101, 10, 67, 97, 118,
  97, 108, 105, 101, 114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 52, 48, 57, 53, 41, 37, 56, 41, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 67, 97, 118, 97, 108, 105, 101, 114,
  61, 61, 48, 125, 10, 73, 110, 99, 95, 88, 61, 45, 49, 10, 73, 110,
  99, 95, 89, 61, 50, 10, 45, 101, 108, 105, 102, 32, 123, 36, 67, 97,
  118, 97, 108, 105, 101, 114, 61, 61, 49, 125, 10, 73, 110, 99, 95, 88,
  61, 49, 10, 73, 110, 99, 95, 89, 61, 50, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 67, 97, 118, 97, 108, 105, 101, 114, 61, 61, 50, 125, 10,
  73, 110, 99, 95, 88, 61, 50, 10, 73, 110, 99, 95, 89, 61, 49, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 67, 97, 118, 97, 108, 105, 101, 114,
  61, 61, 51, 125, 10, 73, 110, 99, 95, 88, 61, 50, 10, 73, 110, 99,
  95, 89, 61, 45, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 67, 97,
  118, 97, 108, 105, 101, 114, 61, 61, 52, 125, 10, 73, 110, 99, 95, 88,
  61, 49, 10, 73, 110, 99, 95, 89, 61, 45, 50, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 67, 97, 118, 97, 108, 105, 101, 114, 61, 61, 53, 125,
  10, 73, 110, 99, 95, 88, 61, 45, 49, 10, 73, 110, 99, 95, 89, 61,
  45, 50, 10, 45, 101, 108, 105, 102, 32, 123, 36, 67, 97, 118, 97, 108,
  105, 101, 114, 61, 61, 54, 125, 10, 73, 110, 99, 95, 88, 61, 45, 50,
  10, 73, 110, 99, 95, 89, 61, 45, 49, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 67, 97, 118, 97, 108, 105, 101, 114, 61, 61, 55, 125, 10, 73,
  110, 99, 95, 88, 61, 45, 50, 10, 73, 110, 99, 95, 89, 61, 49, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 105, 102, 32, 123, 36, 77,
  111, 100, 101, 61, 61, 52, 125, 10, 73, 110, 99, 95, 88, 61, 123, 123,
  114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 56, 41, 41, 125, 45, 123,
  114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 56, 41, 41, 125, 125, 10,
  45, 105, 102, 32, 123, 36, 67, 104, 111, 105, 120, 61, 61, 48, 125, 10,
  73, 110, 99, 95, 89, 61, 36, 73, 110, 99, 95, 88, 10, 45, 101, 108,
  115, 101, 10, 73, 110, 99, 95, 89, 61, 123, 48, 45, 36, 73, 110, 99,
  95, 88, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 77, 111, 100, 101, 61, 61, 53, 125, 10, 45, 105, 102, 32,
  123, 36, 67, 104, 111, 105, 120, 61, 61, 48, 125, 10, 73, 110, 99, 95,
  88, 61, 123, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 56, 41,
  41, 125, 45, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 56, 41,
  41, 125, 125, 10, 73, 110, 99, 95, 89, 61, 48, 10, 45, 101, 108, 115,
  101, 10, 73, 110, 99, 95, 88, 61, 48, 10, 73, 110, 99, 95, 89, 61,
  123, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 56, 41, 41, 125,
  45, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 56, 41, 41, 125,
  125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 77, 111, 100, 101, 61, 61, 54, 125, 10, 67, 104, 111, 105, 120, 61,
  123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 51, 41, 41, 125, 10,
  45, 105, 102, 32, 123, 36, 67, 104, 111, 105, 120, 61, 61, 48, 125, 10,
  73, 110, 99, 95, 88, 61, 123, 123, 114, 111, 117, 110, 100, 40, 63, 40,
  48, 44, 56, 41, 41, 125, 45, 123, 114, 111, 117, 110, 100, 40, 63, 40,
  48, 44, 56, 41, 41, 125, 125, 10, 73, 110, 99, 95, 89, 61, 36, 73,
  110, 99, 95, 88, 10, 45, 101, 108, 105, 102, 32, 123, 36, 67, 104, 111,
  105, 120, 61, 61, 49, 125, 10, 73, 110, 99, 95, 88, 61, 123, 123, 114,
  111, 117, 110, 100, 40, 63, 40, 48, 44, 56, 41, 41, 125, 45, 123, 114,
  111, 117, 110, 100, 40, 63, 40, 48, 44, 56, 41, 41, 125, 125, 10, 73,
  110, 99, 95, 89, 61, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 67,
  104, 111, 105, 120, 61, 61, 50, 125, 10, 73, 110, 99, 95, 88, 61, 48,
  10, 73, 110, 99, 95, 89, 61, 123, 123, 114, 111, 117, 110, 100, 40, 63,
  40, 48, 44, 56, 41, 41, 125, 45, 123, 114, 111, 117, 110, 100, 40, 63,
  40, 48, 44, 56, 41, 41, 125, 125, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 67, 104, 111, 105, 120, 61, 61, 51, 125, 10, 73, 110, 99, 95, 88,
  61, 123, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 56, 41, 41,
  125, 45, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 56, 41, 41,
  125, 125, 10, 73, 110, 99, 95, 89, 61, 123, 48, 45, 36, 73, 110, 99,
  95, 88, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105,
  102, 10, 80, 111, 115, 105, 116, 105, 111, 110, 95, 88, 61, 123, 36, 80,
  111, 115, 105, 116, 105, 111, 110, 95, 88, 43, 36, 73, 110, 99, 95, 88,
  125, 10, 45, 105, 102, 32, 123, 36, 80, 111, 115, 105, 116, 105, 111, 110,
  95, 88, 60, 48, 125, 10, 80, 111, 115, 105, 116, 105, 111, 110, 95, 88,
  61, 123, 36, 76, 97, 114, 103, 101, 117, 114, 95, 79, 114, 105, 103, 105,
  110, 101, 45, 49, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 88, 62, 123, 36,
  76, 97, 114, 103, 101, 117, 114, 95, 79, 114, 105, 103, 105, 110, 101, 45,
  49, 125, 125, 10, 80, 111, 115, 105, 116, 105, 111, 110, 95, 88, 61, 48,
  10, 45, 101, 110, 100, 105, 102, 10, 80, 111, 115, 105, 116, 105, 111, 110,
  95, 89, 61, 123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 89, 43,
  36, 73, 110, 99, 95, 89, 125, 10, 45, 105, 102, 32, 123, 36, 80, 111,
  115, 105, 116, 105, 111, 110, 95, 89, 60, 48, 125, 10, 80, 111, 115, 105,
  116, 105, 111, 110, 95, 89, 61, 123, 36, 72, 97, 117, 116, 101, 117, 114,
  95, 79, 114, 105, 103, 105, 110, 101, 45, 49, 125, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 80, 111, 115, 105, 116, 105, 111,
  110, 95, 89, 62, 123, 36, 72, 97, 117, 116, 101, 117, 114, 95, 79, 114,
  105, 103, 105, 110, 101, 45, 49, 125, 125, 10, 80, 111, 115, 105, 116, 105,
  111, 110, 95, 89, 61, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 112,
  111, 105, 110, 116, 91, 45, 49, 93, 32, 36, 80, 111, 115, 105, 116, 105,
  111, 110, 95, 88, 44, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 89,
  44, 48, 44, 49, 44, 36, 82, 95, 80, 111, 105, 110, 116, 44, 36, 86,
  95, 80, 111, 105, 110, 116, 44, 36, 66, 95, 80, 111, 105, 110, 116, 44,
  36, 65, 95, 80, 111, 105, 110, 116, 10, 45, 100, 111, 110, 101, 10, 45,
  100, 111, 110, 101, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 115, 97, 109, 106, 95, 80, 111, 105, 110, 116, 115, 95, 65, 108, 101,
  97, 116, 111, 105, 114, 101, 115, 95, 48, 48, 49, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106,
  95, 80, 111, 105, 110, 116, 115, 95, 65, 108, 101, 97, 116, 111, 105, 114,
  101, 115, 95, 48, 48, 49, 32, 36, 42, 34, 44, 36, 45, 49, 10, 115,
  97, 109, 106, 95, 114, 105, 101, 110, 95, 97, 116, 105, 115, 116, 105, 99,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104,
  105, 110, 103, 91, 45, 49, 93, 10, 35, 64, 103, 105, 109, 112, 32, 80,
  111, 105, 110, 116, 115, 32, 100, 111, 116, 115, 32, 58, 32, 80, 111, 105,
  110, 116, 115, 95, 68, 111, 116, 115, 95, 115, 97, 109, 106, 44, 32, 80,
  111, 105, 110, 116, 115, 95, 68, 111, 116, 115, 95, 115, 97, 109, 106, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 80, 111, 105, 110, 116, 32, 68, 111, 116, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  82, 97, 121, 111, 110, 32, 47, 32, 114, 97, 100, 105, 117, 115, 32, 40,
  112, 105, 120, 101, 108, 41, 32, 61, 32, 105, 110, 116, 40, 52, 44, 50,
  44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 69, 99, 104, 101, 108, 108, 101, 32, 45, 32, 83,
  99, 97, 108, 101, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 69, 99, 104, 101, 108, 108, 101, 32,
  47, 32, 115, 99, 97, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 44, 48, 46, 53, 44, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 77, 97, 115, 113, 117, 101, 32,
  45, 32, 77, 97, 115, 107, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 111, 110, 100, 32, 47,
  32, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 32, 61, 32, 99, 111,
  108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 111,
  105, 110, 116, 115, 32, 47, 32, 100, 111, 116, 115, 32, 61, 32, 99, 111,
  108, 111, 114, 40, 48, 44, 48, 44, 48, 44, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 66, 108, 101,
  110, 100, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 49, 44, 34, 65, 100, 100, 34, 44, 34, 65, 108, 112,
  104, 97, 34, 44, 34, 65, 110, 100, 34, 44, 34, 65, 118, 101, 114, 97,
  103, 101, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 66, 117, 114, 110,
  34, 44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 68, 105, 102, 102,
  101, 114, 101, 110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 34, 68, 105, 118, 105, 100, 101, 34, 44, 34, 68, 111, 100, 103,
  101, 34, 44, 34, 69, 120, 99, 108, 117, 115, 105, 111, 110, 34, 44, 34,
  70, 114, 101, 101, 122, 101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 101,
  120, 116, 114, 97, 99, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 109,
  101, 114, 103, 101, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 72,
  97, 114, 100, 32, 108, 105, 103, 104, 116, 34, 44, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44,
  34, 72, 117, 101, 34, 44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97,
  116, 105, 111, 110, 34, 44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44,
  34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110,
  101, 97, 114, 32, 98, 117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97,
  114, 32, 108, 105, 103, 104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34,
  77, 117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 78, 101, 103, 97, 116,
  105, 111, 110, 34, 44, 34, 79, 114, 34, 44, 34, 79, 118, 101, 114, 108,
  97, 121, 34, 44, 34, 80, 105, 110, 32, 108, 105, 103, 104, 116, 34, 44,
  34, 82, 101, 100, 34, 44, 34, 82, 101, 102, 108, 101, 99, 116, 34, 44,
  34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 34, 83, 104, 97, 112, 101, 32, 65, 118,
  101, 114, 97, 103, 101, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118,
  101, 114, 97, 103, 101, 48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117,
  114, 110, 34, 44, 34, 83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34,
  44, 34, 83, 111, 102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83,
  99, 114, 101, 101, 110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34,
  83, 117, 98, 116, 114, 97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101,
  34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 86, 105, 118,
  105, 100, 32, 108, 105, 103, 104, 116, 34, 44, 34, 88, 111, 114, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116,
  121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116,
  32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 70, 111, 110, 99, 116, 105, 111, 110, 110, 101, 109, 101, 110, 116,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 70, 111, 110, 99, 116, 105, 111, 110, 110, 101, 109, 101,
  110, 116, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 79,
  114, 105, 103, 105, 110, 101, 34, 44, 34, 82, 111, 110, 111, 117, 110, 111,
  117, 114, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 86, 111, 105, 114, 32, 101, 120, 101, 109, 112, 108, 101, 32,
  100, 101, 32, 82, 111, 110, 111, 117, 110, 111, 117, 114, 115, 32, 100, 97,
  110, 115, 32, 99, 111, 100, 101, 32, 115, 111, 117, 114, 99, 101, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 101, 117, 114, 115, 32, 47, 32, 65, 117, 116, 104, 111, 114,
  115, 32, 58, 32, 60, 105, 62, 83, 97, 109, 106, 47, 82, 111, 110, 111,
  117, 110, 111, 117, 114, 115, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58,
  32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 49, 47, 50, 53, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 80, 111,
  105, 110, 116, 115, 95, 68, 111, 116, 115, 95, 115, 97, 109, 106, 32, 58,
  10, 114, 97, 121, 111, 110, 61, 36, 49, 10, 101, 99, 104, 101, 108, 108,
  101, 61, 36, 50, 10, 82, 95, 102, 111, 110, 100, 61, 36, 51, 10, 86,
  95, 102, 111, 110, 100, 61, 36, 52, 10, 66, 95, 102, 111, 110, 100, 61,
  36, 53, 10, 65, 95, 102, 111, 110, 100, 61, 36, 54, 10, 82, 95, 112,
  111, 105, 110, 116, 61, 36, 55, 10, 86, 95, 112, 111, 105, 110, 116, 61,
  36, 56, 10, 66, 95, 112, 111, 105, 110, 116, 61, 36, 57, 10, 65, 95,
  112, 111, 105, 110, 116, 61, 36, 49, 48, 10, 98, 108, 101, 110, 100, 61,
  36, 49, 49, 10, 111, 112, 97, 99, 105, 116, 101, 61, 36, 49, 50, 10,
  82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 61, 36, 49,
  51, 10, 70, 111, 110, 99, 116, 105, 111, 110, 110, 101, 109, 101, 110, 116,
  61, 36, 49, 52, 10, 100, 105, 97, 109, 101, 116, 114, 101, 95, 101, 110,
  95, 112, 105, 120, 101, 108, 115, 61, 123, 36, 114, 97, 121, 111, 110, 42,
  50, 125, 10, 100, 101, 108, 116, 97, 49, 61, 49, 10, 100, 101, 108, 116,
  97, 50, 61, 49, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 114, 101, 115, 105, 122, 101, 32, 123,
  123, 119, 125, 42, 36, 101, 99, 104, 101, 108, 108, 101, 125, 44, 123, 123,
  104, 125, 42, 36, 101, 99, 104, 101, 108, 108, 101, 125, 10, 45, 114, 101,
  115, 105, 122, 101, 32, 123, 123, 119, 125, 47, 36, 100, 105, 97, 109, 101,
  116, 114, 101, 95, 101, 110, 95, 112, 105, 120, 101, 108, 115, 125, 44, 123,
  123, 104, 125, 47, 36, 100, 105, 97, 109, 101, 116, 114, 101, 95, 101, 110,
  95, 112, 105, 120, 101, 108, 115, 125, 10, 45, 114, 101, 115, 105, 122, 101,
  32, 123, 123, 119, 125, 42, 36, 100, 105, 97, 109, 101, 116, 114, 101, 95,
  101, 110, 95, 112, 105, 120, 101, 108, 115, 125, 44, 123, 123, 104, 125, 42,
  36, 100, 105, 97, 109, 101, 116, 114, 101, 95, 101, 110, 95, 112, 105, 120,
  101, 108, 115, 125, 10, 108, 97, 114, 103, 101, 117, 114, 95, 105, 109, 97,
  103, 101, 95, 116, 101, 109, 112, 111, 114, 97, 105, 114, 101, 61, 123, 119,
  125, 10, 104, 97, 117, 116, 101, 117, 114, 95, 105, 109, 97, 103, 101, 95,
  116, 101, 109, 112, 111, 114, 97, 105, 114, 101, 61, 123, 104, 125, 10, 45,
  105, 102, 32, 123, 36, 70, 111, 110, 99, 116, 105, 111, 110, 110, 101, 109,
  101, 110, 116, 61, 61, 48, 125, 10, 36, 108, 97, 114, 103, 101, 117, 114,
  95, 105, 109, 97, 103, 101, 95, 116, 101, 109, 112, 111, 114, 97, 105, 114,
  101, 44, 36, 104, 97, 117, 116, 101, 117, 114, 95, 105, 109, 97, 103, 101,
  95, 116, 101, 109, 112, 111, 114, 97, 105, 114, 101, 44, 49, 44, 52, 10,
  45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32,
  36, 82, 95, 102, 111, 110, 100, 44, 36, 86, 95, 102, 111, 110, 100, 44,
  36, 66, 95, 102, 111, 110, 100, 44, 36, 65, 95, 102, 111, 110, 100, 10,
  88, 61, 123, 36, 114, 97, 121, 111, 110, 125, 10, 89, 61, 123, 36, 114,
  97, 121, 111, 110, 125, 10, 45, 100, 111, 10, 45, 100, 111, 10, 45, 101,
  108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 123, 36, 88, 45, 36,
  100, 101, 108, 116, 97, 49, 125, 44, 123, 36, 89, 45, 36, 100, 101, 108,
  116, 97, 49, 125, 44, 123, 36, 114, 97, 121, 111, 110, 45, 36, 100, 101,
  108, 116, 97, 50, 125, 44, 123, 36, 114, 97, 121, 111, 110, 45, 36, 100,
  101, 108, 116, 97, 50, 125, 44, 48, 44, 49, 44, 36, 82, 95, 112, 111,
  105, 110, 116, 44, 36, 86, 95, 112, 111, 105, 110, 116, 44, 36, 66, 95,
  112, 111, 105, 110, 116, 44, 36, 65, 95, 112, 111, 105, 110, 116, 10, 89,
  61, 123, 36, 89, 43, 36, 100, 105, 97, 109, 101, 116, 114, 101, 95, 101,
  110, 95, 112, 105, 120, 101, 108, 115, 125, 10, 45, 119, 104, 105, 108, 101,
  32, 123, 36, 89, 60, 36, 104, 97, 117, 116, 101, 117, 114, 95, 105, 109,
  97, 103, 101, 95, 116, 101, 109, 112, 111, 114, 97, 105, 114, 101, 125, 10,
  88, 61, 123, 36, 88, 43, 36, 100, 105, 97, 109, 101, 116, 114, 101, 95,
  101, 110, 95, 112, 105, 120, 101, 108, 115, 125, 10, 89, 61, 36, 114, 97,
  121, 111, 110, 10, 45, 119, 104, 105, 108, 101, 32, 123, 36, 88, 60, 36,
  108, 97, 114, 103, 101, 117, 114, 95, 105, 109, 97, 103, 101, 95, 116, 101,
  109, 112, 111, 114, 97, 105, 114, 101, 125, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 70, 111, 110, 99, 116, 105, 111, 110, 110,
  101, 109, 101, 110, 116, 61, 61, 49, 125, 10, 36, 100, 105, 97, 109, 101,
  116, 114, 101, 95, 101, 110, 95, 112, 105, 120, 101, 108, 115, 44, 36, 100,
  105, 97, 109, 101, 116, 114, 101, 95, 101, 110, 95, 112, 105, 120, 101, 108,
  115, 44, 49, 44, 52, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111,
  114, 91, 45, 49, 93, 32, 36, 82, 95, 102, 111, 110, 100, 44, 36, 86,
  95, 102, 111, 110, 100, 44, 36, 66, 95, 102, 111, 110, 100, 44, 36, 65,
  95, 102, 111, 110, 100, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45,
  49, 93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 123, 36, 114, 97, 121,
  111, 110, 45, 36, 100, 101, 108, 116, 97, 50, 125, 44, 123, 36, 114, 97,
  121, 111, 110, 45, 36, 100, 101, 108, 116, 97, 50, 125, 44, 48, 44, 49,
  44, 36, 82, 95, 112, 111, 105, 110, 116, 44, 36, 86, 95, 112, 111, 105,
  110, 116, 44, 36, 66, 95, 112, 111, 105, 110, 116, 44, 36, 65, 95, 112,
  111, 105, 110, 116, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 49, 48, 48,
  37, 44, 48, 44, 50, 10, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105,
  109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32,
  36, 98, 108, 101, 110, 100, 44, 36, 111, 112, 97, 99, 105, 116, 101, 44,
  36, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109,
  112, 32, 80, 111, 105, 110, 116, 115, 32, 100, 111, 116, 115, 32, 48, 48,
  49, 32, 58, 32, 115, 97, 109, 106, 95, 80, 111, 105, 110, 116, 115, 95,
  68, 111, 116, 115, 95, 48, 48, 49, 44, 32, 115, 97, 109, 106, 95, 80,
  111, 105, 110, 116, 115, 95, 68, 111, 116, 115, 95, 48, 48, 49, 95, 112,
  114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111,
  117, 110, 100, 61, 34, 114, 101, 100, 34, 62, 68, 101, 115, 32, 112, 111,
  105, 110, 116, 115, 32, 100, 101, 32, 99, 111, 117, 108, 101, 117, 114, 32,
  115, 117, 114, 32, 108, 39, 105, 109, 97, 103, 101, 46, 60, 47, 115, 112,
  97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  101, 115, 111, 108, 117, 116, 105, 111, 110, 32, 61, 32, 105, 110, 116, 40,
  49, 54, 44, 52, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 82, 101, 109, 112, 108, 105, 115, 115, 97, 103, 101, 32, 37,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 55, 48, 46, 55, 44, 50, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  111, 117, 108, 101, 117, 114, 32, 47, 32, 99, 111, 108, 111, 114, 32, 61,
  32, 99, 111, 108, 111, 114, 40, 54, 52, 44, 49, 50, 56, 44, 49, 57,
  50, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 97, 108, 113, 117, 101, 32, 116, 114, 97, 110, 115, 112, 97, 114, 101,
  110, 116, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97, 109, 106, 32, 45, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32,
  60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 49, 53, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109,
  106, 95, 80, 111, 105, 110, 116, 115, 95, 68, 111, 116, 115, 95, 48, 48,
  49, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110,
  61, 36, 49, 10, 82, 101, 109, 112, 108, 105, 115, 115, 97, 103, 101, 61,
  36, 50, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 51, 10,
  86, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 52, 10, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 61, 36, 53, 10, 65, 95, 67, 111, 117, 108,
  101, 117, 114, 61, 36, 54, 10, 67, 97, 108, 113, 117, 101, 95, 84, 114,
  97, 110, 115, 112, 97, 114, 101, 110, 116, 61, 36, 55, 10, 36, 82, 101,
  115, 111, 108, 117, 116, 105, 111, 110, 44, 36, 82, 101, 115, 111, 108, 117,
  116, 105, 111, 110, 44, 49, 44, 52, 10, 45, 102, 105, 108, 108, 95, 99,
  111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48,
  10, 35, 35, 35, 35, 32, -64, 32, 118, 111, 105, 114, 32, 58, 32, 97,
  106, 111, 117, 116, 101, 114, 32, 100, 39, 97, 117, 116, 114, 101, 115, 32,
  102, 111, 114, 109, 101, 115, 32, 113, 117, 101, 32, 99, 101, 114, 99, 108,
  101, 32, 63, 10, 45, 99, 105, 114, 99, 108, 101, 91, 45, 49, 93, 32,
  53, 48, 37, 44, 53, 48, 37, 44, 123, 36, 82, 101, 109, 112, 108, 105,
  115, 115, 97, 103, 101, 47, 50, 125, 37, 44, 49, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50,
  93, 44, 49, 44, 49, 44, 48, 44, 50, 10, 45, 116, 111, 95, 114, 103,
  98, 97, 91, 45, 49, 93, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95,
  99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48,
  44, 48, 10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 52, 10, 45,
  102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 123,
  50, 53, 53, 45, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 125, 44,
  123, 50, 53, 53, 45, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 125,
  44, 123, 50, 53, 53, 45, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114,
  125, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 103, 105,
  109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32,
  52, 50, 44, 49, 44, 49, 10, 45, 105, 102, 32, 123, 36, 67, 97, 108,
  113, 117, 101, 95, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 116, 61,
  61, 49, 125, 10, 45, 114, 109, 91, 45, 50, 93, 10, 45, 101, 108, 115,
  101, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 97, 108, 112, 104, 97,
  91, 45, 49, 44, 45, 50, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115, 97, 109, 106, 95,
  80, 111, 105, 110, 116, 115, 95, 68, 111, 116, 115, 95, 48, 48, 49, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  115, 97, 109, 106, 95, 80, 111, 105, 110, 116, 115, 95, 68, 111, 116, 115,
  95, 48, 48, 49, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103,
  105, 109, 112, 32, 80, 111, 105, 110, 116, 115, 32, 100, 111, 116, 115, 32,
  48, 48, 50, 32, 58, 32, 115, 97, 109, 106, 95, 80, 111, 105, 110, 116,
  115, 95, 68, 111, 116, 115, 95, 48, 48, 50, 44, 32, 115, 97, 109, 106,
  95, 80, 111, 105, 110, 116, 115, 95, 68, 111, 116, 115, 95, 48, 48, 50,
  95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103,
  114, 111, 117, 110, 100, 61, 34, 114, 101, 100, 34, 62, 68, 101, 115, 32,
  112, 111, 105, 110, 116, 115, 32, 97, 117, 120, 32, 99, 111, 117, 108, 101,
  117, 114, 115, 32, 100, 101, 32, 108, 39, 105, 109, 97, 103, 101, 46, 60,
  47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117,
  110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60,
  115, 109, 97, 108, 108, 62, 80, 111, 105, 110, 116, 115, 32, 47, 32, 68,
  111, 116, 115, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97,
  110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101,
  115, 111, 108, 117, 116, 105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 49,
  54, 44, 52, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 82, 101, 109, 112, 108, 105, 115, 115, 97, 103, 101, 32, 37, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 55, 48, 46, 55, 44, 50, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34,
  111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108,
  108, 62, 73, 109, 97, 103, 101, 32, 67, 111, 117, 108, 101, 117, 114, 115,
  32, 47, 32, 67, 111, 108, 111, 114, 115, 60, 47, 115, 109, 97, 108, 108,
  62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111,
  110, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 51, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 105, 115, 32, 61, 32, 98,
  111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 108, 111, 114, 115, 32, 98, 111, 111, 115, 116, 32, 61, 32, 98,
  111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  70, 111, 110, 100, 32, 99, 111, 108, 111, 114, 92, 51, 48, 51, 92, 50,
  53, 49, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 102, 111,
  110, 100, 32, 47, 32, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 32,
  99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 48, 44,
  48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50,
  48, 49, 52, 47, 48, 49, 47, 49, 53, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 80, 111,
  105, 110, 116, 115, 95, 68, 111, 116, 115, 95, 48, 48, 50, 32, 58, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 61, 36, 49, 10,
  82, 101, 109, 112, 108, 105, 115, 115, 97, 103, 101, 61, 36, 50, 10, 73,
  110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 61, 36, 51, 10,
  71, 114, 105, 115, 61, 36, 52, 10, 66, 111, 111, 115, 116, 61, 36, 53,
  10, 70, 111, 110, 100, 95, 67, 111, 108, 111, 114, 101, 61, 36, 54, 10,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 55, 10, 86, 95, 67,
  111, 117, 108, 101, 117, 114, 61, 36, 56, 10, 66, 95, 67, 111, 117, 108,
  101, 117, 114, 61, 36, 57, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114,
  61, 36, 49, 48, 10, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45,
  49, 93, 10, 45, 105, 102, 32, 123, 36, 73, 110, 116, 101, 114, 112, 111,
  108, 97, 116, 105, 111, 110, 61, 61, 48, 125, 10, 45, 114, 101, 115, 105,
  122, 101, 91, 45, 49, 93, 32, 123, 123, 119, 125, 47, 36, 82, 101, 115,
  111, 108, 117, 116, 105, 111, 110, 125, 44, 123, 123, 104, 125, 47, 36, 82,
  101, 115, 111, 108, 117, 116, 105, 111, 110, 125, 10, 45, 99, 91, 45, 49,
  93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 61, 61, 49,
  125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 123,
  119, 125, 47, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 125, 44,
  123, 123, 104, 125, 47, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110,
  125, 44, 49, 44, 51, 44, 51, 10, 45, 99, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 10, 45, 101, 108, 105, 102, 32, 123, 36, 73, 110, 116,
  101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 61, 61, 50, 125, 10, 45,
  114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 123, 119, 125, 47,
  36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 125, 44, 123, 123, 104,
  125, 47, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 125, 10, 45,
  110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111,
  110, 61, 61, 51, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49,
  93, 32, 123, 123, 119, 125, 47, 36, 82, 101, 115, 111, 108, 117, 116, 105,
  111, 110, 125, 44, 123, 123, 104, 125, 47, 36, 82, 101, 115, 111, 108, 117,
  116, 105, 111, 110, 125, 44, 49, 44, 51, 44, 51, 10, 45, 110, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 71, 114, 105, 115, 61, 61, 49, 125, 10, 45,
  116, 111, 95, 103, 114, 97, 121, 91, 45, 49, 93, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123,
  123, 119, 125, 42, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 125,
  44, 123, 123, 104, 125, 42, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111,
  110, 125, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10,
  45, 105, 102, 32, 123, 36, 66, 111, 111, 115, 116, 61, 61, 49, 125, 10,
  45, 103, 105, 109, 112, 95, 98, 97, 108, 97, 110, 99, 101, 95, 103, 97,
  109, 109, 97, 91, 45, 49, 93, 32, 49, 50, 56, 44, 49, 50, 56, 44,
  49, 50, 56, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111,
  95, 114, 103, 98, 97, 91, 45, 49, 93, 10, 36, 82, 101, 115, 111, 108,
  117, 116, 105, 111, 110, 44, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111,
  110, 44, 49, 44, 52, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111,
  114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 10, 35, 35,
  35, 35, 32, -64, 32, 118, 111, 105, 114, 32, 58, 32, 97, 106, 111, 117,
  116, 101, 114, 32, 100, 39, 97, 117, 116, 114, 101, 115, 32, 102, 111, 114,
  109, 101, 115, 32, 113, 117, 101, 32, 99, 101, 114, 99, 108, 101, 32, 63,
  10, 45, 99, 105, 114, 99, 108, 101, 91, 45, 49, 93, 32, 53, 48, 37,
  44, 53, 48, 37, 44, 123, 36, 82, 101, 109, 112, 108, 105, 115, 115, 97,
  103, 101, 47, 50, 125, 37, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 114, 101, 115, 105, 122, 101,
  91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 49,
  44, 49, 44, 48, 44, 50, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91,
  45, 49, 93, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108,
  111, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 48, 44, 48, 44,
  48, 44, 48, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 48, 10,
  45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 50, 44, 45,
  49, 93, 32, 52, 50, 44, 49, 44, 48, 10, 45, 105, 102, 32, 123, 36,
  70, 111, 110, 100, 95, 67, 111, 108, 111, 114, 101, 61, 61, 49, 125, 10,
  123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 52, 10, 45, 102, 105, 108,
  108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 123, 50, 53, 53,
  45, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 125, 44, 123, 50, 53,
  53, 45, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 125, 44, 123, 50,
  53, 53, 45, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 125, 44, 36,
  65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 36, 82, 101, 115, 111, 108,
  117, 116, 105, 111, 110, 44, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111,
  110, 44, 49, 44, 52, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111,
  114, 91, 45, 49, 93, 32, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 10, 45, 99, 105, 114, 99, 108, 101, 91, 45, 49,
  93, 32, 53, 48, 37, 44, 53, 48, 37, 44, 123, 36, 82, 101, 109, 112,
  108, 105, 115, 115, 97, 103, 101, 47, 50, 125, 37, 44, 49, 44, 48, 44,
  48, 44, 48, 44, 48, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49,
  93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 49, 44,
  48, 44, 50, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93,
  10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91,
  45, 49, 93, 32, 49, 48, 48, 37, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 48, 10, 45, 103, 105,
  109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32,
  52, 50, 44, 49, 44, 48, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  97, 108, 112, 104, 97, 91, 45, 49, 44, 45, 50, 93, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  115, 97, 109, 106, 95, 80, 111, 105, 110, 116, 115, 95, 68, 111, 116, 115,
  95, 48, 48, 50, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 80, 111, 105, 110, 116, 115,
  95, 68, 111, 116, 115, 95, 48, 48, 50, 32, 36, 42, 34, 44, 36, 45,
  49, 10, 35, 64, 103, 105, 109, 112, 32, 84, 111, 112, 111, 103, 114, 97,
  112, 104, 105, 99, 32, 109, 97, 112, 32, 48, 48, 49, 32, 58, 32, 115,
  97, 109, 106, 95, 84, 111, 112, 111, 103, 114, 97, 112, 104, 105, 99, 95,
  77, 97, 112, 95, 48, 48, 49, 44, 32, 115, 97, 109, 106, 95, 84, 111,
  112, 111, 103, 114, 97, 112, 104, 105, 99, 95, 77, 97, 112, 95, 48, 48,
  49, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101,
  103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101,
  100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 82, 92, 51, 48, 51, 92,
  50, 53, 49, 115, 111, 108, 117, 116, 105, 111, 110, 60, 47, 115, 109, 97,
  108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 88, 32, 61, 32, 105, 110, 116, 40, 49, 54,
  44, 52, 44, 52, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  89, 32, 61, 32, 105, 110, 116, 40, 49, 54, 44, 52, 44, 52, 56, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 48, 44,
  48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114,
  105, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 115, 32, 98, 111, 111,
  115, 116, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101,
  103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101,
  100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 84, 111, 112, 111, 103, 114,
  97, 112, 104, 105, 99, 32, 77, 97, 112, 60, 47, 115, 109, 97, 108, 108,
  62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 76, 101, 118, 101, 108, 115, 32, 61, 32, 105, 110, 116,
  40, 56, 44, 49, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97, 109, 106, 32, 45, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32,
  60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 49, 52, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109,
  106, 95, 84, 111, 112, 111, 103, 114, 97, 112, 104, 105, 99, 95, 77, 97,
  112, 95, 48, 48, 49, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 82, 101, 115, 111, 108, 117,
  116, 105, 111, 110, 95, 88, 61, 36, 49, 10, 82, 101, 115, 111, 108, 117,
  116, 105, 111, 110, 95, 89, 61, 36, 50, 10, 73, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 105, 111, 110, 61, 36, 51, 10, 71, 114, 105, 115, 61,
  36, 52, 10, 66, 111, 111, 115, 116, 61, 36, 53, 10, 76, 101, 118, 101,
  108, 115, 95, 84, 77, 61, 36, 54, 10, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 95, 84, 77, 61, 36, 55, 10, 45, 105, 102, 32, 123, 36,
  73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 61, 61, 48,
  125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 123,
  119, 125, 47, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 95, 88,
  125, 44, 123, 123, 104, 125, 47, 36, 82, 101, 115, 111, 108, 117, 116, 105,
  111, 110, 95, 89, 125, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 10, 45, 101, 108, 105, 102, 32, 123, 36, 73, 110, 116, 101, 114,
  112, 111, 108, 97, 116, 105, 111, 110, 61, 61, 49, 125, 10, 45, 114, 101,
  115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 123, 119, 125, 47, 36, 82,
  101, 115, 111, 108, 117, 116, 105, 111, 110, 95, 88, 125, 44, 123, 123, 104,
  125, 47, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 95, 89, 125,
  44, 49, 44, 51, 44, 51, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 10, 45, 101, 108, 105, 102, 32, 123, 36, 73, 110, 116, 101,
  114, 112, 111, 108, 97, 116, 105, 111, 110, 61, 61, 50, 125, 10, 45, 114,
  101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 123, 119, 125, 47, 36,
  82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 95, 88, 125, 44, 123, 123,
  104, 125, 47, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 95, 89,
  125, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 73, 110, 116, 101, 114, 112, 111, 108, 97,
  116, 105, 111, 110, 61, 61, 51, 125, 10, 45, 114, 101, 115, 105, 122, 101,
  91, 45, 49, 93, 32, 123, 123, 119, 125, 47, 36, 82, 101, 115, 111, 108,
  117, 116, 105, 111, 110, 95, 88, 125, 44, 123, 123, 104, 125, 47, 36, 82,
  101, 115, 111, 108, 117, 116, 105, 111, 110, 95, 89, 125, 44, 49, 44, 51,
  44, 51, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 71, 114, 105,
  115, 61, 61, 49, 125, 10, 45, 116, 111, 95, 103, 114, 97, 121, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49,
  93, 32, 123, 123, 119, 125, 42, 36, 82, 101, 115, 111, 108, 117, 116, 105,
  111, 110, 95, 88, 125, 44, 123, 123, 104, 125, 42, 36, 82, 101, 115, 111,
  108, 117, 116, 105, 111, 110, 95, 89, 125, 10, 45, 99, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 10, 45, 116, 111, 112, 111, 103, 114, 97, 112,
  104, 105, 99, 95, 109, 97, 112, 91, 45, 49, 93, 32, 36, 76, 101, 118,
  101, 108, 115, 95, 84, 77, 44, 36, 83, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 95, 84, 77, 10, 45, 105, 102, 32, 123, 36, 66, 111, 111, 115,
  116, 61, 61, 49, 125, 10, 45, 103, 105, 109, 112, 95, 98, 97, 108, 97,
  110, 99, 101, 95, 103, 97, 109, 109, 97, 91, 45, 49, 93, 32, 49, 50,
  56, 44, 49, 50, 56, 44, 49, 50, 56, 44, 49, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115,
  97, 109, 106, 95, 84, 111, 112, 111, 103, 114, 97, 112, 104, 105, 99, 95,
  77, 97, 112, 95, 48, 48, 49, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 84, 111, 112,
  111, 103, 114, 97, 112, 104, 105, 99, 95, 77, 97, 112, 95, 48, 48, 49,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32,
  95, 10, 35, 64, 103, 105, 109, 112, 32, 60, 105, 62, 65, 114, 116, 105,
  115, 116, 105, 99, 60, 47, 105, 62, 10, 35, 64, 103, 105, 109, 112, 32,
  67, 101, 107, 111, 97, 115, 97, 32, 48, 48, 49, 32, 58, 32, 115, 97,
  109, 106, 95, 67, 101, 75, 111, 97, 83, 97, 95, 48, 48, 49, 44, 32,
  115, 97, 109, 106, 95, 67, 101, 75, 111, 97, 83, 97, 95, 48, 48, 49,
  95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 53, 44, 48, 44, 53, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 102, 111, 114, 109, 97, 116,
  105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44, 48, 44,
  54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 111, 111, 115,
  116, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40,
  51, 44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48,
  49, 51, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 67, 101, 75,
  111, 97, 83, 97, 95, 48, 48, 49, 32, 58, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 83, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 95, 116, 104, 105, 110, 95, 101, 100, 103,
  101, 115, 61, 36, 49, 10, 84, 104, 114, 101, 115, 104, 111, 108, 100, 95,
  116, 104, 105, 110, 95, 101, 100, 103, 101, 115, 61, 36, 50, 10, 65, 109,
  112, 108, 105, 116, 117, 100, 101, 95, 114, 105, 112, 112, 108, 101, 61, 36,
  51, 10, 66, 111, 111, 115, 116, 61, 36, 52, 10, 83, 105, 122, 101, 95,
  109, 111, 114, 112, 104, 111, 61, 36, 53, 10, 45, 45, 103, 105, 109, 112,
  95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10,
  45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110,
  103, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 116, 104, 105, 110,
  95, 101, 100, 103, 101, 115, 91, 45, 49, 93, 32, 36, 83, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 95, 116, 104, 105, 110, 95, 101, 100, 103, 101,
  115, 44, 36, 84, 104, 114, 101, 115, 104, 111, 108, 100, 95, 116, 104, 105,
  110, 95, 101, 100, 103, 101, 115, 44, 48, 10, 45, 45, 103, 105, 109, 112,
  95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10,
  45, 114, 105, 112, 112, 108, 101, 91, 45, 49, 93, 32, 36, 65, 109, 112,
  108, 105, 116, 117, 100, 101, 95, 114, 105, 112, 112, 108, 101, 44, 50, 48,
  44, 50, 44, 48, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100,
  91, 45, 49, 44, 45, 50, 93, 32, 51, 44, 49, 44, 48, 10, 45, 114,
  105, 112, 112, 108, 101, 91, 45, 49, 93, 32, 123, 49, 46, 50, 42, 123,
  36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 95, 114, 105, 112, 112, 108,
  101, 125, 125, 44, 50, 48, 44, 50, 44, 48, 10, 45, 103, 105, 109, 112,
  95, 101, 100, 103, 101, 115, 91, 45, 50, 93, 32, 48, 44, 49, 53, 44,
  48, 44, 48, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91,
  45, 49, 44, 45, 50, 93, 32, 51, 44, 49, 44, 48, 10, 45, 105, 102,
  32, 123, 36, 66, 111, 111, 115, 116, 61, 61, 49, 125, 10, 45, 103, 105,
  109, 112, 95, 98, 97, 108, 97, 110, 99, 101, 95, 103, 97, 109, 109, 97,
  91, 45, 49, 93, 32, 49, 50, 56, 44, 49, 50, 56, 44, 49, 50, 56,
  44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95,
  109, 111, 114, 112, 104, 111, 91, 45, 49, 93, 32, 48, 44, 36, 83, 105,
  122, 101, 95, 109, 111, 114, 112, 104, 111, 44, 48, 44, 50, 44, 48, 44,
  49, 10, 45, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97, 108, 105, 122,
  101, 95, 108, 111, 99, 97, 108, 91, 45, 50, 93, 32, 50, 44, 54, 44,
  53, 44, 50, 48, 44, 49, 44, 51, 10, 45, 103, 105, 109, 112, 95, 98,
  108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 51, 55, 44, 49,
  44, 49, 10, 45, 103, 105, 109, 112, 95, 76, 67, 69, 91, 45, 49, 93,
  32, 56, 48, 44, 48, 46, 53, 44, 49, 44, 49, 44, 51, 44, 48, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115, 97, 109, 106,
  95, 67, 101, 75, 111, 97, 83, 97, 95, 48, 48, 49, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109,
  106, 95, 67, 101, 75, 111, 97, 83, 97, 95, 48, 48, 49, 32, 36, 42,
  34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 67, 101, 107,
  111, 97, 115, 97, 32, 48, 48, 50, 32, 58, 32, 115, 97, 109, 106, 95,
  67, 101, 75, 111, 97, 83, 97, 95, 48, 48, 50, 44, 32, 115, 97, 109,
  106, 95, 67, 101, 75, 111, 97, 83, 97, 95, 48, 48, 50, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 53, 44, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 68, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44, 48, 44, 54, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 111, 111, 115, 116, 32, 61,
  32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 51, 44, 49,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 116,
  115, 117, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97, 109, 106, 32, 45, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32,
  60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 50, 48, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109,
  106, 95, 67, 101, 75, 111, 97, 83, 97, 95, 48, 48, 50, 32, 58, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 95, 116, 104, 105,
  110, 95, 101, 100, 103, 101, 115, 61, 36, 49, 10, 84, 104, 114, 101, 115,
  104, 111, 108, 100, 95, 116, 104, 105, 110, 95, 101, 100, 103, 101, 115, 61,
  36, 50, 10, 65, 109, 112, 108, 105, 116, 117, 100, 101, 95, 114, 105, 112,
  112, 108, 101, 61, 36, 51, 10, 66, 111, 111, 115, 116, 61, 36, 52, 10,
  83, 105, 122, 101, 95, 109, 111, 114, 112, 104, 111, 61, 36, 53, 10, 86,
  97, 108, 105, 100, 101, 114, 95, 79, 116, 115, 117, 61, 36, 54, 10, 45,
  116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 10, 45, 103, 105, 109,
  112, 95, 102, 114, 97, 109, 101, 91, 45, 49, 93, 32, 48, 44, 49, 48,
  48, 44, 48, 44, 49, 48, 48, 44, 49, 44, 49, 44, 48, 44, 48, 44,
  48, 44, 50, 53, 53, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36, 86, 97,
  108, 105, 100, 101, 114, 95, 79, 116, 115, 117, 61, 61, 49, 125, 10, 45,
  111, 116, 115, 117, 91, 45, 49, 93, 32, 52, 32, 45, 110, 91, 45, 49,
  93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103,
  91, 45, 49, 93, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110,
  111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112,
  95, 116, 104, 105, 110, 95, 101, 100, 103, 101, 115, 91, 45, 49, 93, 32,
  36, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 95, 116, 104, 105, 110,
  95, 101, 100, 103, 101, 115, 44, 36, 84, 104, 114, 101, 115, 104, 111, 108,
  100, 95, 116, 104, 105, 110, 95, 101, 100, 103, 101, 115, 44, 48, 10, 45,
  45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103,
  91, 45, 49, 93, 10, 45, 114, 105, 112, 112, 108, 101, 91, 45, 49, 93,
  32, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 95, 114, 105, 112, 112,
  108, 101, 44, 50, 48, 44, 50, 44, 48, 10, 45, 103, 105, 109, 112, 95,
  98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 51, 44, 49,
  44, 48, 10, 45, 114, 105, 112, 112, 108, 101, 91, 45, 49, 93, 32, 123,
  49, 46, 50, 42, 123, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 95,
  114, 105, 112, 112, 108, 101, 125, 125, 44, 50, 48, 44, 50, 44, 48, 10,
  45, 103, 105, 109, 112, 95, 101, 100, 103, 101, 115, 91, 45, 50, 93, 32,
  48, 44, 49, 53, 44, 48, 44, 48, 10, 45, 103, 105, 109, 112, 95, 98,
  108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 51, 44, 49, 44,
  48, 10, 45, 105, 102, 32, 123, 36, 66, 111, 111, 115, 116, 61, 61, 49,
  125, 10, 45, 103, 105, 109, 112, 95, 98, 97, 108, 97, 110, 99, 101, 95,
  103, 97, 109, 109, 97, 91, 45, 49, 93, 32, 49, 50, 56, 44, 49, 50,
  56, 44, 49, 50, 56, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111, 91, 45, 49, 93, 32,
  48, 44, 36, 83, 105, 122, 101, 95, 109, 111, 114, 112, 104, 111, 44, 48,
  44, 50, 44, 48, 44, 49, 10, 45, 103, 105, 109, 112, 95, 110, 111, 114,
  109, 97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 91, 45, 50, 93,
  32, 50, 44, 54, 44, 53, 44, 50, 48, 44, 49, 44, 51, 10, 45, 103,
  105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93,
  32, 51, 55, 44, 49, 44, 49, 10, 45, 80, 111, 108, 121, 103, 111, 110,
  105, 122, 101, 95, 71, 85, 73, 91, 45, 49, 93, 32, 49, 48, 44, 49,
  48, 44, 49, 48, 44, 49, 48, 44, 49, 48, 44, 48, 10, 45, 103, 105,
  109, 112, 95, 76, 67, 69, 91, 45, 49, 93, 32, 56, 48, 44, 48, 46,
  53, 44, 49, 44, 49, 44, 51, 44, 48, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 115, 97, 109, 106, 95, 67, 101, 75, 111, 97,
  83, 97, 95, 48, 48, 50, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 67, 101, 75, 111,
  97, 83, 97, 95, 48, 48, 50, 32, 36, 42, 34, 44, 36, 45, 49, 10,
  35, 64, 103, 105, 109, 112, 32, 67, 101, 107, 111, 97, 115, 97, 32, 48,
  48, 51, 32, 58, 32, 115, 97, 109, 106, 95, 67, 101, 75, 111, 97, 83,
  97, 95, 48, 48, 51, 44, 32, 115, 97, 109, 106, 95, 67, 101, 75, 111,
  97, 83, 97, 95, 48, 48, 51, 95, 112, 114, 101, 118, 105, 101, 119, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115,
  104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48,
  44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101,
  102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 44, 48, 44, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 66, 111, 111, 115, 116, 32, 61, 32, 98, 111, 111, 108, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 105, 122, 101, 32,
  61, 32, 105, 110, 116, 40, 51, 44, 49, 44, 49, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101,
  119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97, 109, 106, 32, 45,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58,
  32, 60, 105, 62, 50, 48, 49, 51, 47, 49, 50, 47, 50, 57, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97,
  109, 106, 95, 67, 101, 75, 111, 97, 83, 97, 95, 48, 48, 51, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 95, 116, 104,
  105, 110, 95, 101, 100, 103, 101, 115, 61, 36, 49, 10, 84, 104, 114, 101,
  115, 104, 111, 108, 100, 95, 116, 104, 105, 110, 95, 101, 100, 103, 101, 115,
  61, 36, 50, 10, 65, 109, 112, 108, 105, 116, 117, 100, 101, 95, 114, 105,
  112, 112, 108, 101, 61, 36, 51, 10, 66, 111, 111, 115, 116, 61, 36, 52,
  10, 83, 105, 122, 101, 95, 109, 111, 114, 112, 104, 111, 61, 36, 53, 10,
  45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110,
  103, 91, 45, 49, 93, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95,
  110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 45, 103, 105,
  109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49,
  93, 10, 45, 103, 105, 109, 112, 95, 116, 104, 105, 110, 95, 101, 100, 103,
  101, 115, 91, 45, 49, 93, 32, 36, 83, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 95, 116, 104, 105, 110, 95, 101, 100, 103, 101, 115, 44, 36, 84,
  104, 114, 101, 115, 104, 111, 108, 100, 95, 116, 104, 105, 110, 95, 101, 100,
  103, 101, 115, 44, 48, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95,
  110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 114, 105, 112,
  112, 108, 101, 91, 45, 49, 93, 32, 36, 65, 109, 112, 108, 105, 116, 117,
  100, 101, 95, 114, 105, 112, 112, 108, 101, 44, 50, 48, 44, 50, 44, 48,
  10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44,
  45, 50, 93, 32, 51, 44, 49, 44, 48, 10, 45, 114, 105, 112, 112, 108,
  101, 91, 45, 49, 93, 32, 123, 49, 46, 50, 42, 123, 36, 65, 109, 112,
  108, 105, 116, 117, 100, 101, 95, 114, 105, 112, 112, 108, 101, 125, 125, 44,
  50, 48, 44, 50, 44, 48, 10, 45, 103, 105, 109, 112, 95, 101, 100, 103,
  101, 115, 91, 45, 50, 93, 32, 48, 44, 49, 53, 44, 48, 44, 48, 10,
  45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45,
  50, 93, 32, 51, 44, 49, 44, 48, 10, 45, 105, 102, 32, 123, 36, 66,
  111, 111, 115, 116, 61, 61, 49, 125, 10, 45, 103, 105, 109, 112, 95, 98,
  97, 108, 97, 110, 99, 101, 95, 103, 97, 109, 109, 97, 91, 45, 49, 93,
  32, 49, 50, 56, 44, 49, 50, 56, 44, 49, 50, 56, 44, 49, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 109, 111, 114, 112,
  104, 111, 91, 45, 49, 93, 32, 48, 44, 36, 83, 105, 122, 101, 95, 109,
  111, 114, 112, 104, 111, 44, 48, 44, 50, 44, 48, 44, 49, 10, 45, 103,
  105, 109, 112, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 108, 111,
  99, 97, 108, 91, 45, 50, 93, 32, 50, 44, 54, 44, 53, 44, 50, 48,
  44, 49, 44, 51, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100,
  91, 45, 49, 44, 45, 50, 93, 32, 51, 55, 44, 49, 44, 49, 10, 45,
  103, 105, 109, 112, 95, 76, 67, 69, 91, 45, 49, 93, 32, 56, 48, 44,
  48, 46, 53, 44, 49, 44, 49, 44, 51, 44, 48, 10, 45, 80, 111, 108,
  121, 103, 111, 110, 105, 122, 101, 95, 71, 85, 73, 91, 45, 50, 93, 32,
  49, 48, 44, 49, 48, 44, 49, 48, 44, 49, 48, 44, 49, 48, 44, 48,
  10, 45, 103, 105, 109, 112, 95, 103, 97, 117, 115, 115, 105, 97, 110, 95,
  98, 108, 117, 114, 91, 45, 50, 93, 32, 50, 48, 44, 48, 44, 48, 44,
  49, 44, 48, 44, 48, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110,
  100, 91, 45, 49, 44, 45, 50, 93, 32, 51, 44, 48, 46, 53, 44, 48,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115, 97, 109,
  106, 95, 67, 101, 75, 111, 97, 83, 97, 95, 48, 48, 51, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112,
  108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97,
  109, 106, 95, 67, 101, 75, 111, 97, 83, 97, 95, 48, 48, 51, 32, 36,
  42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 67, 101,
  107, 111, 97, 115, 97, 32, 48, 48, 52, 32, 58, 32, 115, 97, 109, 106,
  95, 67, 101, 75, 111, 97, 83, 97, 95, 48, 48, 52, 44, 32, 115, 97,
  109, 106, 95, 67, 101, 75, 111, 97, 83, 97, 95, 48, 48, 52, 95, 112,
  114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111,
  100, 117, 108, 111, 32, 61, 32, 105, 110, 116, 40, 51, 48, 44, 48, 44,
  49, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 101,
  103, 97, 116, 105, 102, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 38, 119, 32, 112, 101, 110,
  99, 105, 108, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 49, 50,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99,
  105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 56, 44,
  48, 46, 53, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  68, 101, 110, 111, 105, 115, 101, 32, 61, 32, 105, 110, 116, 40, 48, 44,
  48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52,
  47, 48, 49, 47, 48, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 67, 101, 75, 111, 97,
  83, 97, 95, 48, 48, 52, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 77, 111, 100, 117, 108,
  111, 61, 36, 49, 10, 78, 101, 103, 97, 116, 105, 102, 61, 36, 50, 10,
  66, 95, 87, 95, 112, 101, 110, 99, 105, 108, 95, 97, 109, 112, 108, 105,
  116, 117, 100, 101, 61, 36, 51, 10, 79, 112, 97, 99, 105, 116, 121, 95,
  98, 108, 101, 110, 100, 95, 101, 100, 103, 101, 115, 61, 36, 52, 10, 68,
  101, 110, 111, 105, 115, 101, 95, 73, 109, 97, 103, 101, 61, 36, 53, 10,
  45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10, 45, 45, 103, 105,
  109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49,
  93, 10, 45, 109, 111, 100, 91, 45, 49, 93, 32, 123, 50, 48, 43, 36,
  77, 111, 100, 117, 108, 111, 125, 10, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 10, 45, 103, 105, 109, 112, 95, 100, 105, 116, 104, 101,
  114, 101, 100, 98, 119, 91, 45, 49, 93, 32, 48, 44, 49, 44, 48, 44,
  48, 44, 48, 44, 48, 10, 45, 105, 102, 32, 123, 36, 78, 101, 103, 97,
  116, 105, 102, 61, 61, 49, 125, 10, 45, 110, 101, 103, 97, 116, 105, 118,
  101, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 66, 95, 87, 95, 112, 101, 110, 99, 105, 108, 95, 97, 109,
  112, 108, 105, 116, 117, 100, 101, 62, 48, 125, 10, 45, 112, 101, 110, 99,
  105, 108, 98, 119, 91, 45, 49, 93, 32, 48, 46, 51, 44, 36, 66, 95,
  87, 95, 112, 101, 110, 99, 105, 108, 95, 97, 109, 112, 108, 105, 116, 117,
  100, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95,
  98, 108, 101, 110, 100, 95, 101, 100, 103, 101, 115, 91, 45, 49, 44, 45,
  50, 93, 32, 49, 44, 36, 79, 112, 97, 99, 105, 116, 121, 95, 98, 108,
  101, 110, 100, 95, 101, 100, 103, 101, 115, 44, 48, 10, 45, 105, 102, 32,
  123, 36, 68, 101, 110, 111, 105, 115, 101, 95, 73, 109, 97, 103, 101, 62,
  48, 125, 10, 45, 100, 101, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32,
  36, 68, 101, 110, 111, 105, 115, 101, 95, 73, 109, 97, 103, 101, 44, 36,
  68, 101, 110, 111, 105, 115, 101, 95, 73, 109, 97, 103, 101, 44, 53, 44,
  54, 44, 49, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 115, 97, 109, 106, 95, 67, 101,
  75, 111, 97, 83, 97, 95, 48, 48, 52, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 67,
  101, 75, 111, 97, 83, 97, 95, 48, 48, 52, 32, 36, 42, 34, 44, 36,
  45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 67, 101, 107, 111, 97, 115,
  97, 32, 48, 48, 55, 32, 58, 32, 115, 97, 109, 106, 95, 67, 101, 75,
  111, 97, 83, 97, 95, 48, 48, 55, 44, 32, 115, 97, 109, 106, 95, 67,
  101, 75, 111, 97, 83, 97, 95, 48, 48, 55, 95, 112, 114, 101, 118, 105,
  101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61,
  34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97,
  108, 108, 62, 67, 111, 108, 111, 114, 115, 32, 47, 32, 67, 111, 117, 108,
  101, 117, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112,
  97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  111, 108, 111, 114, 115, 32, 47, 32, 99, 111, 117, 108, 101, 117, 114, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 46, 56, 44, 49,
  46, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112,
  97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111,
  114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108,
  62, 71, 114, 97, 100, 105, 101, 110, 116, 32, 78, 111, 114, 109, 60, 47,
  115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112,
  97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111,
  114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108,
  62, 82, 111, 100, 105, 108, 105, 117, 115, 60, 47, 115, 109, 97, 108, 108,
  62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 51, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 105, 99, 107, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97,
  114, 112, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51,
  48, 48, 44, 48, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 79, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 115,
  32, 61, 32, 105, 110, 116, 40, 53, 44, 50, 44, 51, 54, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 102, 102, 115, 101, 116, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 51, 48, 44, 48, 44, 49, 56, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97,
  109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47,
  50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 115, 97, 109, 106, 95, 67, 101, 75, 111, 97, 83, 97, 95, 48,
  48, 55, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 67, 111, 108, 111, 114, 115, 95, 67, 111,
  117, 108, 101, 117, 114, 115, 61, 36, 49, 10, 83, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 95, 71, 78, 61, 36, 50, 10, 65, 109, 112, 108, 105,
  116, 117, 100, 101, 95, 82, 61, 36, 51, 10, 84, 104, 105, 99, 107, 110,
  101, 115, 115, 95, 82, 61, 36, 52, 10, 83, 104, 97, 114, 112, 110, 101,
  115, 115, 95, 82, 61, 36, 53, 10, 79, 114, 105, 101, 110, 116, 97, 116,
  105, 111, 110, 115, 95, 82, 61, 36, 54, 10, 79, 102, 102, 115, 101, 116,
  95, 82, 61, 36, 55, 10, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  95, 82, 61, 36, 56, 10, 45, 112, 111, 119, 91, 45, 49, 93, 32, 36,
  67, 111, 108, 111, 114, 115, 95, 67, 111, 117, 108, 101, 117, 114, 115, 10,
  45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 45, 103,
  105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45,
  49, 93, 10, 45, 103, 105, 109, 112, 95, 103, 114, 97, 100, 105, 101, 110,
  116, 95, 110, 111, 114, 109, 91, 45, 49, 93, 32, 36, 83, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 95, 71, 78, 44, 48, 46, 53, 44, 48, 44,
  49, 48, 48, 44, 48, 10, 45, 103, 105, 109, 112, 95, 114, 111, 100, 105,
  108, 105, 117, 115, 91, 45, 49, 93, 32, 36, 65, 109, 112, 108, 105, 116,
  117, 100, 101, 95, 82, 44, 36, 84, 104, 105, 99, 107, 110, 101, 115, 115,
  95, 82, 44, 36, 83, 104, 97, 114, 112, 110, 101, 115, 115, 95, 82, 44,
  36, 79, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 115, 95, 82, 44,
  36, 79, 102, 102, 115, 101, 116, 95, 82, 44, 36, 83, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 95, 82, 44, 49, 44, 48, 10, 45, 103, 105, 109,
  112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 49,
  50, 44, 49, 44, 49, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 115, 97, 109, 106, 95, 67, 101, 75, 111, 97, 83, 97, 95, 48,
  48, 55, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 115, 97, 109, 106, 95, 67, 101, 75, 111, 97, 83, 97, 95,
  48, 48, 55, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105,
  109, 112, 32, 67, 104, 97, 108, 107, 32, 105, 116, 32, 117, 112, 32, 58,
  32, 115, 97, 109, 106, 95, 99, 104, 97, 108, 107, 105, 116, 117, 112, 44,
  32, 115, 97, 109, 106, 95, 99, 104, 97, 108, 107, 105, 116, 117, 112, 95,
  112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 73, 110,
  115, 112, 105, 114, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 116, 117,
  116, 111, 114, 105, 97, 108, 32, 112, 114, 111, 112, 111, 115, 101, 100, 32,
  98, 121, 32, 76, 121, 108, 101, 106, 107, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107,
  40, 34, 104, 116, 116, 112, 58, 47, 47, 106, 117, 115, 116, 112, 97, 115,
  116, 101, 46, 105, 116, 47, 99, 104, 97, 108, 107, 95, 105, 116, 95, 117,
  112, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 106, 117, 115, 116, 112,
  97, 115, 116, 101, 46, 105, 116, 47, 99, 104, 97, 108, 107, 95, 105, 116,
  95, 117, 112, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 80, 97, 105, 110, 116, 105, 110, 103, 32, 112,
  97, 114, 97, 109, 101, 116, 101, 114, 115, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 98, 115,
  116, 114, 97, 99, 116, 105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 53,
  44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  68, 101, 116, 97, 105, 108, 115, 32, 115, 99, 97, 108, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 50, 46, 53, 44, 48, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 46, 53, 44, 48, 44, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48,
  44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  104, 97, 114, 112, 101, 110, 32, 115, 104, 97, 100, 101, 115, 32, 61, 32,
  98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 77, 111, 114, 112, 104, 111, 32, 112,
  97, 114, 97, 109, 101, 116, 101, 114, 115, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 99, 116,
  105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 53, 44, 34,
  69, 114, 111, 115, 105, 111, 110, 34, 44, 34, 68, 105, 108, 97, 116, 105,
  111, 110, 34, 44, 34, 79, 112, 101, 110, 105, 110, 103, 34, 44, 34, 67,
  108, 111, 115, 105, 110, 103, 34, 44, 34, 79, 114, 105, 103, 105, 110, 97,
  108, 32, 45, 32, 69, 114, 111, 115, 105, 111, 110, 34, 44, 34, 68, 105,
  108, 97, 116, 105, 111, 110, 32, 45, 32, 79, 114, 105, 103, 105, 110, 97,
  108, 34, 44, 34, 79, 114, 105, 103, 105, 110, 97, 108, 32, 45, 32, 79,
  112, 101, 110, 105, 110, 103, 34, 44, 34, 67, 108, 111, 115, 105, 110, 103,
  32, 45, 32, 79, 114, 105, 103, 105, 110, 97, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 105, 110,
  116, 40, 53, 44, 48, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 73, 110, 118, 101, 114, 116, 32, 99, 111, 108, 111, 114, 115,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 104, 97, 112, 101, 32, 61, 32, 105, 110, 116, 40,
  48, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 50, 44, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66,
  65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108,
  117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97,
  98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44,
  34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97,
  108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 65, 108, 112, 104,
  97, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34,
  82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108,
  117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 83, 112, 114,
  101, 97, 100, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 45, 118, 97, 114, 105, 97, 116, 105, 111, 110, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 56, 44, 45, 53, 44, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  46, 57, 44, 45, 53, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66,
  65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108,
  117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97,
  98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44,
  34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97,
  108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 65, 108, 112, 104,
  97, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34,
  82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108,
  117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 115,
  32, 58, 32, 60, 105, 62, 83, 97, 109, 106, 47, 82, 111, 110, 111, 117,
  110, 111, 117, 114, 115, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32,
  60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 49, 55, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109,
  106, 95, 99, 104, 97, 108, 107, 105, 116, 117, 112, 32, 58, 10, 35, 103,
  105, 109, 112, 95, 112, 97, 105, 110, 116, 105, 110, 103, 10, 65, 98, 115,
  116, 114, 97, 99, 116, 105, 111, 110, 61, 36, 49, 10, 68, 101, 116, 97,
  105, 108, 115, 95, 115, 99, 97, 108, 101, 61, 36, 50, 10, 67, 111, 108,
  111, 114, 61, 36, 51, 10, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  61, 36, 52, 10, 83, 104, 97, 114, 112, 101, 110, 95, 115, 104, 97, 100,
  101, 115, 61, 36, 53, 10, 35, 103, 105, 109, 112, 95, 109, 111, 114, 112,
  104, 111, 10, 65, 99, 116, 105, 111, 110, 61, 36, 54, 10, 83, 105, 122,
  101, 61, 36, 55, 10, 73, 110, 118, 101, 114, 116, 95, 99, 111, 108, 111,
  114, 115, 61, 36, 56, 10, 83, 104, 97, 112, 101, 61, 36, 57, 10, 67,
  104, 97, 110, 110, 101, 108, 95, 109, 111, 114, 112, 104, 111, 61, 36, 49,
  48, 10, 35, 103, 105, 109, 112, 95, 115, 112, 114, 101, 97, 100, 10, 88,
  95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 115, 61, 36, 49, 49, 10,
  89, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 115, 61, 36, 49, 50,
  10, 67, 104, 97, 110, 110, 101, 108, 95, 115, 112, 114, 101, 97, 100, 61,
  36, 49, 51, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 114, 101, 109, 111, 118, 101, 95, 111, 112,
  97, 99, 105, 116, 121, 32, 45, 103, 105, 109, 112, 95, 112, 97, 105, 110,
  116, 105, 110, 103, 32, 36, 65, 98, 115, 116, 114, 97, 99, 116, 105, 111,
  110, 44, 36, 68, 101, 116, 97, 105, 108, 115, 95, 115, 99, 97, 108, 101,
  44, 36, 67, 111, 108, 111, 114, 44, 36, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 44, 36, 83, 104, 97, 114, 112, 101, 110, 95, 115, 104, 97,
  100, 101, 115, 32, 45, 103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111,
  32, 36, 65, 99, 116, 105, 111, 110, 44, 36, 83, 105, 122, 101, 44, 36,
  73, 110, 118, 101, 114, 116, 95, 99, 111, 108, 111, 114, 115, 44, 36, 83,
  104, 97, 112, 101, 44, 36, 67, 104, 97, 110, 110, 101, 108, 95, 109, 111,
  114, 112, 104, 111, 44, 48, 32, 45, 103, 105, 109, 112, 95, 115, 112, 114,
  101, 97, 100, 32, 36, 88, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110,
  115, 44, 36, 89, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 115, 44,
  36, 67, 104, 97, 110, 110, 101, 108, 95, 115, 112, 114, 101, 97, 100, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115, 97, 109, 106,
  95, 99, 104, 97, 108, 107, 105, 116, 117, 112, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95,
  99, 104, 97, 108, 107, 105, 116, 117, 112, 32, 36, 123, 49, 45, 45, 50,
  125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 67, 114,
  97, 105, 101, 32, 115, 117, 114, 32, 116, 97, 98, 108, 101, 97, 117, 32,
  110, 111, 105, 114, 32, 45, 32, 99, 104, 97, 108, 107, 32, 111, 110, 32,
  98, 108, 97, 99, 107, 98, 111, 97, 114, 100, 32, 58, 32, 115, 97, 109,
  106, 95, 99, 114, 97, 105, 101, 95, 115, 117, 114, 95, 116, 97, 98, 108,
  101, 97, 117, 95, 110, 111, 105, 114, 44, 32, 115, 97, 109, 106, 95, 99,
  114, 97, 105, 101, 95, 115, 117, 114, 95, 116, 97, 98, 108, 101, 97, 117,
  95, 110, 111, 105, 114, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 82, 101, 103, 114, 111, 117, 112, 101, 109, 101, 110, 116,
  32, 100, 101, 32, 116, 101, 115, 116, 95, 100, 101, 115, 115, 105, 110, 95,
  112, 101, 105, 110, 116, 117, 114, 101, 32, 101, 116, 32, 115, 97, 109, 106,
  95, 99, 104, 97, 108, 107, 105, 116, 117, 112, 44, 32, 100, 111, 117, 98,
  108, 101, 32, 108, 101, 115, 32, 116, 114, 97, 105, 116, 115, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  116, 101, 115, 116, 95, 100, 101, 115, 115, 105, 110, 95, 112, 101, 105, 110,
  116, 117, 114, 101, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 101, 116, 116, 101, 116, 92, 51,
  48, 51, 92, 50, 53, 49, 32, 61, 32, 105, 110, 116, 40, 49, 55, 48,
  44, 48, 44, 52, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 68, 92, 51, 48, 51, 92, 50, 53, 49, 116, 97, 105, 108, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 50, 46, 49, 53, 44, 48, 44, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 80, 97, 105, 110, 116, 105, 110, 103, 32, 112, 97, 114, 97, 109, 101,
  116, 101, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 98, 115, 116, 114, 97, 99, 116,
  105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 53, 44, 48, 44, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 116, 97, 105,
  108, 115, 32, 115, 99, 97, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 46, 53, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 46, 53, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 50, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 114, 112, 101,
  110, 32, 115, 104, 97, 100, 101, 115, 32, 61, 32, 98, 111, 111, 108, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 77, 111, 114, 112, 104, 111, 32, 112, 97, 114, 97, 109, 101,
  116, 101, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 99, 116, 105, 111, 110, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 53, 44, 34, 69, 114, 111, 115, 105,
  111, 110, 34, 44, 34, 68, 105, 108, 97, 116, 105, 111, 110, 34, 44, 34,
  79, 112, 101, 110, 105, 110, 103, 34, 44, 34, 67, 108, 111, 115, 105, 110,
  103, 34, 44, 34, 79, 114, 105, 103, 105, 110, 97, 108, 32, 45, 32, 69,
  114, 111, 115, 105, 111, 110, 34, 44, 34, 68, 105, 108, 97, 116, 105, 111,
  110, 32, 45, 32, 79, 114, 105, 103, 105, 110, 97, 108, 34, 44, 34, 79,
  114, 105, 103, 105, 110, 97, 108, 32, 45, 32, 79, 112, 101, 110, 105, 110,
  103, 34, 44, 34, 67, 108, 111, 115, 105, 110, 103, 32, 45, 32, 79, 114,
  105, 103, 105, 110, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 53, 44, 48,
  44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110,
  118, 101, 114, 116, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32, 98, 111,
  111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  104, 97, 112, 101, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110,
  101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 50,
  44, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82,
  71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105,
  110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32,
  99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105,
  103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117,
  114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44,
  34, 75, 101, 121, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34, 99,
  104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44,
  34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34,
  65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 83, 112, 114, 101, 97, 100, 32, 112,
  97, 114, 97, 109, 101, 116, 101, 114, 115, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 118,
  97, 114, 105, 97, 116, 105, 111, 110, 115, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 56, 44, 45, 53, 44, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 89, 45, 118, 97, 114, 105, 97, 116, 105, 111, 110,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 57, 44, 45, 53,
  44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97,
  110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82,
  71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105,
  110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32,
  99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105,
  103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117,
  114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44,
  34, 75, 101, 121, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34, 99,
  104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44,
  34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34,
  65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 115, 105,
  122, 101, 32, 119, 105, 100, 116, 104, 32, 52, 48, 48, 32, 61, 32, 98,
  111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 83,
  97, 109, 106, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105,
  62, 50, 48, 49, 52, 47, 48, 49, 47, 49, 55, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95,
  99, 114, 97, 105, 101, 95, 115, 117, 114, 95, 116, 97, 98, 108, 101, 97,
  117, 95, 110, 111, 105, 114, 32, 58, 10, 110, 101, 116, 116, 101, 116, 101,
  61, 36, 49, 10, 100, 101, 116, 97, 105, 108, 61, 36, 50, 10, 35, 103,
  105, 109, 112, 95, 112, 97, 105, 110, 116, 105, 110, 103, 10, 65, 98, 115,
  116, 114, 97, 99, 116, 105, 111, 110, 61, 36, 51, 10, 68, 101, 116, 97,
  105, 108, 115, 95, 115, 99, 97, 108, 101, 61, 36, 52, 10, 67, 111, 108,
  111, 114, 61, 36, 53, 10, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  61, 36, 54, 10, 83, 104, 97, 114, 112, 101, 110, 95, 115, 104, 97, 100,
  101, 115, 61, 36, 55, 10, 35, 103, 105, 109, 112, 95, 109, 111, 114, 112,
  104, 111, 10, 65, 99, 116, 105, 111, 110, 61, 36, 56, 10, 83, 105, 122,
  101, 61, 36, 57, 10, 73, 110, 118, 101, 114, 116, 95, 99, 111, 108, 111,
  114, 115, 61, 36, 49, 48, 10, 83, 104, 97, 112, 101, 61, 36, 49, 49,
  10, 67, 104, 97, 110, 110, 101, 108, 95, 109, 111, 114, 112, 104, 111, 61,
  36, 49, 50, 10, 35, 103, 105, 109, 112, 95, 115, 112, 114, 101, 97, 100,
  10, 88, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 115, 61, 36, 49,
  51, 10, 89, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 115, 61, 36,
  49, 52, 10, 67, 104, 97, 110, 110, 101, 108, 95, 115, 112, 114, 101, 97,
  100, 61, 36, 49, 53, 10, 82, 101, 100, 117, 105, 114, 101, 61, 36, 49,
  54, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99,
  105, 116, 121, 10, 45, 105, 102, 32, 123, 36, 82, 101, 100, 117, 105, 114,
  101, 61, 61, 49, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49,
  93, 32, 52, 48, 48, 44, 123, 123, 104, 125, 47, 123, 119, 125, 42, 52,
  48, 48, 125, 44, 49, 44, 51, 44, 51, 10, 45, 101, 110, 100, 105, 102,
  10, 110, 101, 116, 116, 101, 116, 101, 61, 123, 36, 110, 101, 116, 116, 101,
  116, 101, 43, 49, 48, 125, 10, 110, 101, 116, 116, 101, 116, 101, 49, 61,
  123, 36, 110, 101, 116, 116, 101, 116, 101, 47, 49, 48, 48, 48, 125, 10,
  110, 101, 116, 116, 101, 116, 101, 49, 61, 123, 36, 110, 101, 116, 116, 101,
  116, 101, 49, 43, 48, 46, 56, 125, 10, 110, 101, 116, 116, 101, 116, 101,
  50, 61, 123, 36, 110, 101, 116, 116, 101, 116, 101, 47, 50, 125, 10, 110,
  101, 116, 116, 101, 116, 101, 51, 61, 123, 36, 110, 101, 116, 116, 101, 116,
  101, 47, 52, 125, 10, 110, 101, 116, 116, 101, 116, 101, 51, 61, 123, 36,
  110, 101, 116, 116, 101, 116, 101, 51, 43, 49, 48, 125, 10, 45, 103, 105,
  109, 112, 95, 97, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115,
  109, 111, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 32, 56, 48, 44,
  36, 110, 101, 116, 116, 101, 116, 101, 49, 44, 48, 46, 51, 44, 48, 46,
  54, 44, 49, 46, 49, 44, 48, 46, 56, 44, 51, 48, 44, 50, 44, 48,
  44, 49, 44, 53, 44, 49, 44, 49, 10, 45, 110, 91, 45, 49, 93, 32,
  49, 50, 55, 44, 50, 53, 53, 10, 45, 115, 104, 97, 114, 112, 101, 110,
  91, 45, 49, 93, 32, 36, 110, 101, 116, 116, 101, 116, 101, 50, 10, 45,
  99, 97, 114, 116, 111, 111, 110, 91, 45, 49, 93, 32, 36, 100, 101, 116,
  97, 105, 108, 44, 36, 110, 101, 116, 116, 101, 116, 101, 51, 44, 51, 48,
  44, 48, 46, 49, 56, 44, 48, 46, 55, 53, 44, 50, 53, 54, 10, 45,
  115, 104, 97, 114, 112, 101, 110, 91, 45, 49, 93, 32, 36, 110, 101, 116,
  116, 101, 116, 101, 10, 45, 103, 105, 109, 112, 95, 112, 97, 105, 110, 116,
  105, 110, 103, 91, 45, 49, 93, 32, 36, 65, 98, 115, 116, 114, 97, 99,
  116, 105, 111, 110, 44, 36, 68, 101, 116, 97, 105, 108, 115, 95, 115, 99,
  97, 108, 101, 44, 36, 67, 111, 108, 111, 114, 44, 36, 83, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 44, 36, 83, 104, 97, 114, 112, 101, 110, 95,
  115, 104, 97, 100, 101, 115, 10, 45, 103, 105, 109, 112, 95, 109, 111, 114,
  112, 104, 111, 91, 45, 49, 93, 32, 36, 65, 99, 116, 105, 111, 110, 44,
  36, 83, 105, 122, 101, 44, 36, 73, 110, 118, 101, 114, 116, 95, 99, 111,
  108, 111, 114, 115, 44, 36, 83, 104, 97, 112, 101, 44, 36, 67, 104, 97,
  110, 110, 101, 108, 95, 109, 111, 114, 112, 104, 111, 44, 48, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 114, 101, 97, 100, 91, 45, 49, 93, 32, 36,
  88, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 115, 44, 36, 89, 95,
  118, 97, 114, 105, 97, 116, 105, 111, 110, 115, 44, 36, 67, 104, 97, 110,
  110, 101, 108, 95, 115, 112, 114, 101, 97, 100, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 115, 97, 109, 106, 95, 99, 114, 97, 105,
  101, 95, 115, 117, 114, 95, 116, 97, 98, 108, 101, 97, 117, 95, 110, 111,
  105, 114, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 115, 97, 109, 106, 95, 99, 114, 97, 105, 101, 95, 115, 117,
  114, 95, 116, 97, 98, 108, 101, 97, 117, 95, 110, 111, 105, 114, 32, 36,
  123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105,
  109, 112, 32, 70, 105, 108, 116, 114, 101, 32, 110, 111, 101, 108, 32, 50,
  48, 49, 50, 32, 58, 32, 70, 105, 108, 116, 114, 101, 95, 78, 111, 101,
  108, 95, 50, 48, 49, 50, 95, 115, 97, 109, 106, 44, 32, 70, 105, 108,
  116, 114, 101, 95, 78, 111, 101, 108, 95, 50, 48, 49, 50, 95, 115, 97,
  109, 106, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 66, 108, 101, 110, 100,
  32, 85, 115, 101, 32, 58, 32, 70, 114, 101, 101, 122, 101, 32, 67, 111,
  108, 111, 114, 98, 117, 114, 110, 32, 83, 111, 102, 116, 108, 105, 103, 104,
  116, 32, 77, 111, 100, 101, 32, 67, 111, 117, 108, 101, 117, 114, 115, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 49, 49, 44, 34, 65, 100, 100, 34, 44, 34, 65, 108, 112, 104, 97,
  34, 44, 34, 65, 110, 100, 34, 44, 34, 65, 118, 101, 114, 97, 103, 101,
  34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 66, 117, 114, 110, 34, 44,
  34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 68, 105, 102, 102, 101, 114,
  101, 110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  34, 68, 105, 118, 105, 100, 101, 34, 44, 34, 68, 111, 100, 103, 101, 34,
  44, 34, 69, 120, 99, 108, 117, 115, 105, 111, 110, 34, 44, 34, 70, 114,
  101, 101, 122, 101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 101, 120, 116,
  114, 97, 99, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 109, 101, 114,
  103, 101, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 72, 97, 114,
  100, 32, 108, 105, 103, 104, 116, 34, 44, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44, 34, 72,
  117, 101, 34, 44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105,
  111, 110, 34, 44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44, 34, 76,
  105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110, 101, 97,
  114, 32, 98, 117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32,
  108, 105, 103, 104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 77, 117,
  108, 116, 105, 112, 108, 121, 34, 44, 34, 78, 101, 103, 97, 116, 105, 111,
  110, 34, 44, 34, 79, 114, 34, 44, 34, 79, 118, 101, 114, 108, 97, 121,
  34, 44, 34, 80, 105, 110, 32, 108, 105, 103, 104, 116, 34, 44, 34, 82,
  101, 100, 34, 44, 34, 82, 101, 102, 108, 101, 99, 116, 34, 44, 34, 83,
  97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114,
  97, 103, 101, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114,
  97, 103, 101, 48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117, 114, 110,
  34, 44, 34, 83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34, 44, 34,
  83, 111, 102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83, 99, 114,
  101, 101, 110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34, 83, 117,
  98, 116, 114, 97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 86, 105, 118, 105, 100,
  32, 108, 105, 103, 104, 116, 34, 44, 34, 88, 111, 114, 34, 44, 34, 77,
  111, 100, 101, 32, 67, 111, 117, 108, 101, 117, 114, 115, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108,
  97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  68, 101, 116, 101, 99, 116, 105, 111, 110, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108,
  101, 117, 114, 32, 111, 114, 105, 103, 105, 110, 101, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 50, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 68, 105, 102, 102, 101, 114, 101, 110, 99,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 50, 44, 48, 46, 53,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 66, 108, 101, 110, 100, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79,
  112, 97, 99, 105, 116, 92, 51, 48, 51, 92, 50, 53, 49, 32, 47, 32,
  111, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 44, 48, 46, 55, 53, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 71, 114, 105, 122, 111, 117, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 82, 111, 117, 103,
  101, 47, 82, 101, 100, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 116, 32, 118, 97, 108,
  101, 117, 114, 32, 49, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117,
  116, 32, 118, 97, 108, 101, 117, 114, 32, 50, 32, 61, 32, 105, 110, 116,
  40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 114, 109, 97, 108, 105, 122, 101, 32, 61,
  32, 105, 110, 116, 40, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 86, 101,
  114, 116, 47, 71, 114, 101, 101, 110, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 116, 32,
  118, 97, 108, 101, 117, 114, 32, 49, 32, 61, 32, 105, 110, 116, 40, 48,
  44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 117, 116, 32, 118, 97, 108, 101, 117, 114, 32, 50, 32, 61, 32,
  105, 110, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 114, 109, 97, 108, 105, 122,
  101, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 66, 108, 101, 117, 47, 66, 108, 117, 101, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117,
  116, 32, 118, 97, 108, 101, 117, 114, 32, 49, 32, 61, 32, 105, 110, 116,
  40, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 117, 116, 32, 118, 97, 108, 101, 117, 114, 32, 50, 32,
  61, 32, 105, 110, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 114, 109, 97, 108,
  105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 82, 43, 86, 43, 66, 32, 47, 32, 82, 43, 71, 43, 66,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 117, 116, 32, 118, 97, 108, 101, 117, 114, 32, 49,
  32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 55, 54, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 116, 32, 118, 97, 108,
  101, 117, 114, 32, 50, 32, 61, 32, 105, 110, 116, 40, 55, 54, 53, 44,
  48, 44, 55, 54, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 114, 109, 97, 108, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40,
  50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 73, 110, 118, 101, 114, 115, 101, 114, 32, 47,
  32, 73, 110, 118, 101, 114, 116, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 118, 101, 114,
  115, 101, 114, 32, 45, 32, 105, 110, 118, 101, 114, 116, 32, 61, 32, 98,
  111, 111, 108, 40, 102, 97, 108, 115, 101, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 70, 108, 111, 117, 32,
  47, 32, 66, 108, 117, 114, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 108, 111, 117, 32, 47,
  32, 98, 108, 117, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44,
  48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 101,
  117, 114, 115, 32, 47, 32, 65, 117, 116, 104, 111, 114, 115, 32, 58, 32,
  60, 105, 62, 83, 97, 109, 106, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32,
  58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 49, 47, 50, 53, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 70,
  105, 108, 116, 114, 101, 95, 78, 111, 101, 108, 95, 50, 48, 49, 50, 95,
  115, 97, 109, 106, 32, 58, 10, 98, 108, 101, 110, 100, 61, 36, 49, 10,
  111, 112, 97, 99, 105, 116, 101, 61, 36, 50, 10, 82, 101, 118, 101, 114,
  116, 95, 108, 97, 121, 101, 114, 115, 61, 36, 51, 10, 86, 97, 108, 101,
  117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 61, 36, 52, 10, 68, 105,
  102, 102, 101, 114, 101, 110, 99, 101, 61, 36, 53, 10, 111, 112, 97, 99,
  105, 116, 101, 95, 100, 101, 117, 120, 61, 36, 54, 10, 35, 35, 32, 71,
  114, 105, 122, 111, 117, 10, 86, 97, 108, 101, 117, 114, 95, 65, 61, 36,
  55, 10, 86, 97, 108, 101, 117, 114, 95, 66, 61, 36, 56, 10, 82, 95,
  78, 111, 114, 109, 97, 108, 105, 122, 101, 61, 36, 57, 10, 86, 97, 108,
  101, 117, 114, 95, 67, 61, 36, 49, 48, 10, 86, 97, 108, 101, 117, 114,
  95, 68, 61, 36, 49, 49, 10, 86, 95, 78, 111, 114, 109, 97, 108, 105,
  122, 101, 61, 36, 49, 50, 10, 86, 97, 108, 101, 117, 114, 95, 69, 61,
  36, 49, 51, 10, 86, 97, 108, 101, 117, 114, 95, 70, 61, 36, 49, 52,
  10, 66, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 61, 36, 49, 53,
  10, 86, 97, 108, 101, 117, 114, 95, 71, 61, 36, 49, 54, 10, 86, 97,
  108, 101, 117, 114, 95, 72, 61, 36, 49, 55, 10, 82, 86, 66, 95, 82,
  71, 66, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 61, 36, 49, 56,
  10, 73, 110, 118, 101, 114, 115, 101, 114, 61, 36, 49, 57, 10, 70, 108,
  111, 117, 61, 36, 50, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 36, 98,
  108, 101, 110, 100, 61, 61, 52, 51, 125, 10, 75, 95, 105, 109, 95, 73,
  77, 61, 49, 54, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110,
  111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112,
  95, 100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110,
  101, 108, 115, 91, 45, 49, 93, 32, 50, 44, 48, 44, 49, 44, 48, 32,
  73, 77, 65, 88, 61, 123, 114, 111, 117, 110, 100, 40, 123, 123, 105, 77,
  125, 45, 36, 75, 95, 105, 109, 95, 73, 77, 125, 41, 125, 32, 73, 77,
  73, 78, 61, 123, 114, 111, 117, 110, 100, 40, 123, 123, 105, 109, 125, 43,
  36, 75, 95, 105, 109, 95, 73, 77, 125, 41, 125, 32, 45, 114, 109, 91,
  45, 49, 44, 45, 50, 44, 45, 51, 93, 10, 45, 105, 102, 32, 123, 36,
  73, 77, 65, 88, 62, 50, 53, 53, 125, 32, 73, 77, 65, 88, 61, 50,
  53, 53, 32, 45, 101, 110, 100, 105, 102, 32, 45, 105, 102, 32, 123, 36,
  73, 77, 73, 78, 60, 48, 125, 32, 73, 77, 73, 78, 61, 48, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 45, 103,
  105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 10, 45,
  45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103,
  91, 45, 49, 93, 10, 45, 98, 108, 117, 114, 91, 45, 50, 93, 32, 36,
  86, 97, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 10, 45,
  98, 108, 117, 114, 91, 45, 49, 93, 32, 123, 36, 86, 97, 108, 101, 117,
  114, 95, 111, 114, 105, 103, 105, 110, 101, 43, 36, 68, 105, 102, 102, 101,
  114, 101, 110, 99, 101, 125, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101,
  110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 52, 50, 44, 36, 111, 112,
  97, 99, 105, 116, 101, 95, 100, 101, 117, 120, 44, 48, 10, 45, 71, 114,
  105, 122, 111, 117, 95, 115, 97, 109, 106, 91, 45, 49, 93, 32, 48, 44,
  36, 86, 97, 108, 101, 117, 114, 95, 65, 44, 36, 86, 97, 108, 101, 117,
  114, 95, 66, 44, 36, 82, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101,
  44, 36, 86, 97, 108, 101, 117, 114, 95, 67, 44, 36, 86, 97, 108, 101,
  117, 114, 95, 68, 44, 36, 86, 95, 78, 111, 114, 109, 97, 108, 105, 122,
  101, 44, 36, 86, 97, 108, 101, 117, 114, 95, 69, 44, 36, 86, 97, 108,
  101, 117, 114, 95, 70, 44, 36, 66, 95, 78, 111, 114, 109, 97, 108, 105,
  122, 101, 44, 36, 86, 97, 108, 101, 117, 114, 95, 71, 44, 36, 86, 97,
  108, 101, 117, 114, 95, 72, 44, 36, 82, 86, 66, 95, 82, 71, 66, 95,
  78, 111, 114, 109, 97, 108, 105, 122, 101, 10, 45, 105, 102, 32, 123, 36,
  73, 110, 118, 101, 114, 115, 101, 114, 61, 61, 48, 125, 32, 45, 110, 101,
  103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 70, 108, 111,
  117, 10, 45, 105, 102, 32, 123, 36, 98, 108, 101, 110, 100, 61, 61, 52,
  51, 125, 10, 45, 99, 91, 45, 49, 44, 45, 50, 93, 32, 36, 73, 77,
  73, 78, 44, 36, 73, 77, 65, 88, 32, 45, 103, 105, 109, 112, 95, 100,
  101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 50, 44, 48, 44, 49, 44, 48, 32, 45, 114, 101, 109, 111, 118,
  101, 91, 45, 50, 44, 45, 51, 44, 45, 52, 93, 32, 45, 103, 105, 109,
  112, 95, 100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 32, 50, 44, 49, 44, 49, 44, 48, 10, 45, 101, 108,
  115, 101, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45,
  49, 44, 45, 50, 93, 32, 36, 98, 108, 101, 110, 100, 44, 36, 111, 112,
  97, 99, 105, 116, 101, 44, 36, 82, 101, 118, 101, 114, 116, 95, 108, 97,
  121, 101, 114, 115, 10, 45, 101, 110, 100, 105, 102, 10, 35, 32, 118, -23,
  114, 105, 102, 105, 99, 97, 116, 105, 111, 110, 10, 45, 116, 101, 120, 116,
  95, 111, 117, 116, 108, 105, 110, 101, 91, 45, 49, 93, 32, 123, 36, 73,
  77, 73, 78, 125, 45, 123, 36, 73, 77, 65, 88, 125, 44, 49, 44, 48,
  44, 49, 51, 44, 49, 44, 49, 44, 50, 53, 53, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 70, 105, 108, 116, 114, 101, 95, 78,
  111, 101, 108, 95, 50, 48, 49, 50, 95, 115, 97, 109, 106, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112,
  108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 70, 105,
  108, 116, 114, 101, 95, 78, 111, 101, 108, 95, 50, 48, 49, 50, 95, 115,
  97, 109, 106, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 73, 109, 97, 103, 101, 32, 116, 101,
  120, 116, 117, 114, 101, 32, 109, 105, 120, 105, 110, 103, 32, 48, 48, 49,
  32, 58, 32, 73, 109, 97, 103, 101, 95, 84, 101, 120, 116, 117, 114, 101,
  95, 77, 105, 120, 105, 110, 103, 95, 48, 48, 49, 95, 115, 97, 109, 106,
  44, 32, 73, 109, 97, 103, 101, 95, 84, 101, 120, 116, 117, 114, 101, 95,
  77, 105, 120, 105, 110, 103, 95, 48, 48, 49, 95, 115, 97, 109, 106, 95,
  112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114,
  111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34,
  62, 60, 115, 109, 97, 108, 108, 62, 73, 109, 97, 103, 101, 60, 47, 115,
  109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 102, 111, 114, 109, 97, 116,
  105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112,
  97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111,
  114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108,
  62, 77, 97, 115, 113, 117, 101, 32, 47, 32, 77, 97, 115, 107, 60, 47,
  115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 111, 114, 109, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 69, 108, 108, 105, 112,
  115, 101, 34, 44, 34, 82, 101, 99, 116, 97, 110, 103, 108, 101, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 97, 117, 116, 101, 117,
  114, 32, 47, 32, 119, 105, 100, 116, 104, 32, 37, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 55, 53, 44, 53, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 76, 97, 114, 103, 101, 117, 114, 32,
  47, 32, 104, 101, 105, 103, 104, 116, 32, 37, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 55, 53, 44, 53, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 68, 101, 102, 111, 114, 109, 97, 116, 105,
  111, 110, 32, 100, 105, 115, 116, 111, 114, 115, 105, 111, 110, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 50, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 114, 101, 97, 100, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 53, 44, 50, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110,
  32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97,
  110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 84,
  101, 120, 116, 117, 114, 101, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47,
  115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 111, 117, 108, 101, 117, 114, 32, 47, 32, 99, 111, 108, 111, 114,
  32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 49, 44, 50, 51, 55,
  44, 50, 48, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61,
  34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97,
  108, 108, 62, 66, 108, 101, 110, 100, 32, 73, 109, 97, 103, 101, 32, 84,
  101, 120, 116, 117, 114, 101, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47,
  115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 73, 109, 97, 103, 101, 32, 118, 115, 32, 116, 101, 120, 116, 117, 114,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116, 114, 97,
  115, 116, 101, 115, 32, 105, 109, 97, 103, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 53, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 114, 109, 97, 108, 105, 122, 101, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 101, 117, 114, 115, 32, 47, 32, 65, 117, 116, 104, 111, 114,
  115, 32, 58, 32, 60, 105, 62, 83, 97, 109, 106, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 49, 50,
  47, 50, 56, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 73, 109, 97, 103, 101, 95, 84, 101, 120, 116, 117, 114, 101,
  95, 77, 105, 120, 105, 110, 103, 95, 48, 48, 49, 95, 115, 97, 109, 106,
  32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 69, 100, 103, 101, 95, 116, 104, 114, 101, 115, 104,
  111, 108, 100, 95, 83, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111, 110,
  61, 50, 10, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 95, 83, 101,
  103, 109, 101, 110, 116, 97, 116, 105, 111, 110, 61, 51, 46, 56, 10, 68,
  105, 115, 116, 111, 114, 115, 105, 111, 110, 95, 83, 101, 103, 109, 101, 110,
  116, 97, 116, 105, 111, 110, 61, 36, 49, 10, 66, 95, 69, 100, 103, 101,
  95, 116, 104, 114, 101, 115, 104, 111, 108, 100, 95, 83, 101, 103, 109, 101,
  110, 116, 97, 116, 105, 111, 110, 61, 51, 46, 52, 10, 66, 95, 83, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 95, 83, 101, 103, 109, 101, 110, 116,
  97, 116, 105, 111, 110, 61, 48, 46, 57, 10, 77, 101, 108, 97, 110, 103,
  101, 95, 83, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111, 110, 61, 49,
  10, 70, 111, 114, 109, 101, 95, 77, 97, 115, 113, 117, 101, 61, 36, 50,
  10, 67, 101, 110, 116, 114, 101, 95, 88, 61, 53, 48, 10, 67, 101, 110,
  116, 114, 101, 95, 89, 61, 53, 48, 10, 76, 97, 114, 103, 101, 117, 114,
  95, 77, 97, 115, 113, 117, 101, 61, 36, 51, 10, 72, 97, 117, 116, 101,
  117, 114, 95, 77, 97, 115, 113, 117, 101, 61, 36, 52, 10, 77, 97, 115,
  113, 117, 101, 95, 68, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 61,
  36, 53, 10, 77, 97, 115, 113, 117, 101, 95, 83, 112, 114, 101, 97, 100,
  61, 36, 54, 10, 65, 109, 112, 108, 105, 116, 117, 100, 101, 95, 78, 111,
  105, 115, 101, 61, 49, 48, 10, 68, 101, 110, 115, 105, 116, 121, 95, 72,
  97, 114, 100, 115, 107, 101, 116, 99, 104, 98, 119, 61, 49, 48, 10, 83,
  112, 114, 101, 97, 100, 95, 86, 97, 114, 105, 97, 116, 105, 111, 110, 115,
  61, 52, 10, 65, 109, 112, 108, 105, 116, 117, 100, 101, 95, 87, 97, 116,
  101, 114, 61, 51, 10, 82, 51, 61, 36, 55, 10, 86, 51, 61, 36, 56,
  10, 66, 51, 61, 36, 57, 10, 79, 112, 97, 99, 105, 116, 101, 61, 49,
  10, 77, 101, 108, 97, 110, 103, 101, 95, 84, 101, 120, 116, 117, 114, 101,
  61, 36, 49, 48, 10, 67, 111, 110, 116, 114, 97, 115, 116, 101, 115, 95,
  76, 67, 69, 61, 36, 49, 49, 10, 78, 111, 114, 109, 97, 108, 105, 122,
  101, 95, 82, 101, 115, 117, 108, 116, 97, 116, 61, 36, 49, 50, 10, 45,
  77, 101, 108, 97, 110, 103, 101, 95, 73, 109, 97, 103, 101, 95, 84, 101,
  120, 116, 117, 114, 101, 95, 48, 48, 49, 95, 115, 97, 109, 106, 91, 45,
  49, 93, 32, 32, 36, 69, 100, 103, 101, 95, 116, 104, 114, 101, 115, 104,
  111, 108, 100, 95, 83, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111, 110,
  44, 36, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 95, 83, 101, 103,
  109, 101, 110, 116, 97, 116, 105, 111, 110, 44, 36, 68, 105, 115, 116, 111,
  114, 115, 105, 111, 110, 95, 83, 101, 103, 109, 101, 110, 116, 97, 116, 105,
  111, 110, 44, 36, 66, 95, 69, 100, 103, 101, 95, 116, 104, 114, 101, 115,
  104, 111, 108, 100, 95, 83, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111,
  110, 44, 36, 66, 95, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 95,
  83, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111, 110, 44, 36, 77, 101,
  108, 97, 110, 103, 101, 95, 83, 101, 103, 109, 101, 110, 116, 97, 116, 105,
  111, 110, 44, 36, 70, 111, 114, 109, 101, 95, 77, 97, 115, 113, 117, 101,
  44, 36, 67, 101, 110, 116, 114, 101, 95, 88, 44, 36, 67, 101, 110, 116,
  114, 101, 95, 89, 44, 36, 76, 97, 114, 103, 101, 117, 114, 95, 77, 97,
  115, 113, 117, 101, 44, 36, 72, 97, 117, 116, 101, 117, 114, 95, 77, 97,
  115, 113, 117, 101, 44, 36, 77, 97, 115, 113, 117, 101, 95, 68, 101, 102,
  111, 114, 109, 97, 116, 105, 111, 110, 44, 36, 77, 97, 115, 113, 117, 101,
  95, 83, 112, 114, 101, 97, 100, 44, 36, 65, 109, 112, 108, 105, 116, 117,
  100, 101, 95, 78, 111, 105, 115, 101, 44, 36, 68, 101, 110, 115, 105, 116,
  121, 95, 72, 97, 114, 100, 115, 107, 101, 116, 99, 104, 98, 119, 44, 36,
  83, 112, 114, 101, 97, 100, 95, 86, 97, 114, 105, 97, 116, 105, 111, 110,
  115, 44, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 95, 87, 97, 116,
  101, 114, 44, 36, 82, 51, 44, 36, 86, 51, 44, 36, 66, 51, 44, 36,
  79, 112, 97, 99, 105, 116, 101, 44, 36, 77, 101, 108, 97, 110, 103, 101,
  95, 84, 101, 120, 116, 117, 114, 101, 44, 36, 67, 111, 110, 116, 114, 97,
  115, 116, 101, 115, 95, 76, 67, 69, 44, 36, 78, 111, 114, 109, 97, 108,
  105, 122, 101, 95, 82, 101, 115, 117, 108, 116, 97, 116, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 73, 109, 97, 103, 101, 95, 84,
  101, 120, 116, 117, 114, 101, 95, 77, 105, 120, 105, 110, 103, 95, 48, 48,
  49, 95, 115, 97, 109, 106, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 73, 109, 97, 103, 101, 95, 84, 101, 120,
  116, 117, 114, 101, 95, 77, 105, 120, 105, 110, 103, 95, 48, 48, 49, 95,
  115, 97, 109, 106, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103,
  105, 109, 112, 32, 74, 111, 117, 114, 32, 100, 101, 32, 108, 97, 32, 109,
  97, 114, 109, 111, 116, 116, 101, 32, 58, 32, 115, 97, 109, 106, 95, 74,
  111, 117, 114, 95, 68, 101, 95, 76, 97, 95, 77, 97, 114, 109, 111, 116,
  116, 101, 44, 32, 115, 97, 109, 106, 95, 74, 111, 117, 114, 95, 68, 101,
  95, 76, 97, 95, 77, 97, 114, 109, 111, 116, 116, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97,
  110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 114, 101,
  100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 70, 108, 111, 117, 60, 47,
  115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 105, 108, 97, 116, 101, 114,
  97, 108, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 49, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101, 32, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 53, 44, 48, 44, 49, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 46, 49, 44, 49, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32,
  102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 114, 101, 100, 34,
  62, 60, 115, 109, 97, 108, 108, 62, 76, 111, 99, 97, 108, 32, 110, 111,
  114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110, 60, 47, 115, 109, 97,
  108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 44, 54, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 100, 105, 117, 115, 32,
  61, 32, 105, 110, 116, 40, 54, 44, 49, 44, 54, 52, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 101, 105, 103, 104, 98, 111, 114, 104,
  111, 111, 100, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 52, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 118, 101, 114, 97, 103, 101, 32,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 50, 48, 44, 48, 44, 52, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 111, 110, 115, 116, 114, 97, 105, 110, 32, 118,
  97, 108, 117, 101, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108,
  40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 51, 44, 34,
  65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66,
  34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66,
  108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104,
  116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97,
  116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75,
  101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110,
  34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97,
  109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 50, 47,
  48, 50, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 115, 97, 109, 106, 95, 74, 111, 117, 114, 95, 68, 101, 95, 76,
  97, 95, 77, 97, 114, 109, 111, 116, 116, 101, 32, 58, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 66,
  105, 108, 97, 116, 101, 114, 97, 108, 95, 73, 116, 101, 114, 61, 36, 49,
  10, 69, 100, 103, 101, 95, 84, 104, 114, 101, 115, 104, 111, 108, 100, 95,
  83, 87, 61, 36, 50, 10, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  95, 65, 67, 61, 36, 51, 10, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  95, 76, 78, 61, 36, 52, 10, 82, 97, 100, 105, 117, 115, 95, 76, 78,
  61, 36, 53, 10, 78, 101, 105, 103, 104, 98, 111, 114, 104, 111, 111, 100,
  95, 76, 78, 61, 36, 54, 10, 65, 118, 101, 114, 97, 103, 101, 95, 76,
  78, 61, 36, 55, 10, 67, 111, 110, 115, 116, 114, 97, 105, 110, 95, 76,
  78, 61, 36, 56, 10, 67, 104, 97, 110, 110, 101, 108, 115, 95, 76, 78,
  61, 36, 57, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 66, 105, 108,
  97, 116, 101, 114, 97, 108, 95, 73, 116, 101, 114, 32, 45, 98, 105, 108,
  97, 116, 101, 114, 97, 108, 91, 45, 49, 93, 32, 49, 48, 44, 49, 48,
  32, 45, 100, 111, 110, 101, 10, 45, 103, 105, 109, 112, 95, 115, 101, 103,
  109, 101, 110, 116, 95, 119, 97, 116, 101, 114, 115, 104, 101, 100, 91, 45,
  49, 93, 32, 36, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 95, 65,
  67, 44, 36, 69, 100, 103, 101, 95, 84, 104, 114, 101, 115, 104, 111, 108,
  100, 95, 83, 87, 44, 50, 10, 45, 103, 105, 109, 112, 95, 110, 111, 114,
  109, 97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 91, 45, 49, 93,
  32, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 95, 76, 78, 44, 36,
  82, 97, 100, 105, 117, 115, 95, 76, 78, 44, 36, 78, 101, 105, 103, 104,
  98, 111, 114, 104, 111, 111, 100, 95, 76, 78, 44, 36, 65, 118, 101, 114,
  97, 103, 101, 95, 76, 78, 44, 36, 67, 111, 110, 115, 116, 114, 97, 105,
  110, 95, 76, 78, 44, 36, 67, 104, 97, 110, 110, 101, 108, 115, 95, 76,
  78, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115, 97,
  109, 106, 95, 74, 111, 117, 114, 95, 68, 101, 95, 76, 97, 95, 77, 97,
  114, 109, 111, 116, 116, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 74, 111, 117, 114,
  95, 68, 101, 95, 76, 97, 95, 77, 97, 114, 109, 111, 116, 116, 101, 32,
  36, 42, 34, 44, 36, 45, 49, 10, 115, 97, 109, 106, 95, 114, 105, 101,
  110, 95, 98, 108, 97, 99, 107, 95, 97, 110, 100, 95, 119, 104, 105, 116,
  101, 32, 58, 10, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116,
  104, 105, 110, 103, 91, 45, 49, 93, 10, 35, 64, 103, 105, 109, 112, 32,
  75, 97, 114, 112, 97, 105, 110, 116, 32, 58, 32, 75, 97, 114, 80, 97,
  105, 110, 116, 95, 115, 97, 109, 106, 44, 32, 75, 97, 114, 80, 97, 105,
  110, 116, 95, 115, 97, 109, 106, 95, 112, 114, 101, 118, 105, 101, 119, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  80, 97, 114, 97, 109, 92, 51, 48, 51, 92, 50, 53, 48, 116, 114, 101,
  115, 32, 67, 117, 116, 32, 45, 32, 67, 117, 116, 32, 112, 97, 114, 97,
  109, 101, 116, 101, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108, 101, 117, 114,
  32, 97, 32, 61, 32, 105, 110, 116, 40, 50, 53, 44, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108, 101,
  117, 114, 32, 98, 32, 61, 32, 105, 110, 116, 40, 49, 55, 53, 44, 48,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 80, 97, 114, 97, 109, 92, 51, 48, 51, 92,
  50, 53, 48, 116, 114, 101, 115, 32, 75, 117, 119, 97, 104, 97, 114, 97,
  32, 45, 32, 75, 117, 119, 97, 104, 97, 114, 97, 32, 112, 97, 114, 97,
  109, 101, 116, 101, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 97, 105, 108, 108, 101,
  32, 47, 32, 115, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 50, 44,
  49, 44, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 80, 97, 114, 97, 109, 92, 51, 48, 51, 92, 50,
  53, 48, 116, 114, 101, 115, 32, 71, 105, 109, 112, 32, 65, 110, 105, 115,
  111, 116, 114, 111, 112, 105, 99, 32, 83, 109, 111, 111, 116, 104, 105, 110,
  103, 32, 45, 32, 71, 105, 109, 112, 32, 65, 110, 105, 115, 111, 116, 114,
  111, 112, 105, 99, 32, 83, 109, 111, 111, 116, 104, 105, 110, 103, 32, 112,
  97, 114, 97, 109, 101, 116, 101, 114, 115, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112,
  108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 54,
  48, 44, 48, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 101, 117, 114, 115, 32, 47, 32, 65, 117, 116, 104, 111,
  114, 115, 32, 58, 32, 60, 105, 62, 83, 97, 109, 106, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 50, 47, 49,
  48, 47, 48, 52, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 75, 97, 114, 80, 97, 105, 110, 116, 95, 115, 97, 109,
  106, 32, 58, 10, 86, 97, 108, 101, 117, 114, 95, 65, 61, 36, 49, 10,
  86, 97, 108, 101, 117, 114, 95, 66, 61, 36, 50, 10, 75, 95, 115, 105,
  122, 101, 61, 36, 51, 10, 65, 109, 112, 108, 105, 116, 117, 100, 101, 61,
  36, 52, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108,
  91, 36, 62, 93, 10, 45, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97,
  99, 105, 116, 121, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 86,
  97, 108, 101, 117, 114, 95, 65, 62, 36, 86, 97, 108, 101, 117, 114, 95,
  66, 125, 10, 45, 99, 117, 116, 91, 45, 49, 93, 32, 36, 86, 97, 108,
  101, 117, 114, 95, 66, 44, 36, 86, 97, 108, 101, 117, 114, 95, 65, 10,
  45, 101, 108, 115, 101, 10, 45, 99, 117, 116, 91, 45, 49, 93, 32, 36,
  86, 97, 108, 101, 117, 114, 95, 65, 44, 36, 86, 97, 108, 101, 117, 114,
  95, 66, 10, 45, 101, 110, 100, 105, 102, 10, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 10, 45, 107, 117, 119, 97, 104, 97, 114, 97,
  91, 45, 49, 93, 32, 36, 75, 95, 115, 105, 122, 101, 32, 45, 107, 117,
  119, 97, 104, 97, 114, 97, 91, 45, 49, 93, 32, 36, 75, 95, 115, 105,
  122, 101, 32, 45, 100, 114, 97, 119, 105, 110, 103, 91, 45, 49, 93, 32,
  50, 48, 48, 48, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 10, 45, 103, 105, 109, 112, 95, 97, 110, 105, 115, 111, 116, 114, 111,
  112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 91, 45, 49,
  93, 32, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 44, 48, 46, 55,
  44, 48, 46, 51, 44, 48, 46, 54, 44, 49, 46, 49, 44, 48, 46, 56,
  44, 51, 48, 44, 50, 44, 48, 44, 49, 44, 49, 44, 49, 44, 49, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 75, 97, 114, 80,
  97, 105, 110, 116, 95, 115, 97, 109, 106, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 75, 97, 114, 80, 97, 105,
  110, 116, 95, 115, 97, 109, 106, 32, 36, 123, 49, 45, 45, 50, 125, 34,
  44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 75, 117, 119, 97,
  104, 97, 114, 97, 32, 48, 48, 49, 32, 58, 32, 115, 97, 109, 106, 95,
  75, 117, 119, 97, 104, 97, 114, 97, 95, 48, 48, 49, 44, 32, 115, 97,
  109, 106, 95, 75, 117, 119, 97, 104, 97, 114, 97, 95, 48, 48, 49, 95,
  112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114,
  111, 117, 110, 100, 61, 34, 114, 101, 100, 34, 62, 67, 111, 109, 112, 97,
  114, 97, 105, 115, 111, 110, 115, 46, 60, 47, 115, 112, 97, 110, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108, 105, 100,
  101, 114, 32, 118, 97, 108, 101, 117, 114, 32, 100, 101, 32, 99, 111, 109,
  112, 97, 114, 97, 105, 115, 111, 110, 32, 61, 32, 98, 111, 111, 108, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108, 101,
  117, 114, 32, 100, 101, 32, 99, 111, 109, 112, 97, 114, 97, 105, 115, 111,
  110, 32, 61, 32, 105, 110, 116, 40, 56, 48, 44, 48, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114,
  115, 32, 98, 111, 111, 115, 116, 32, 61, 32, 98, 111, 111, 108, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 115, 115, 105,
  110, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103,
  114, 111, 117, 110, 100, 61, 34, 114, 101, 100, 34, 62, 75, 117, 119, 97,
  104, 97, 114, 97, 32, 112, 97, 114, 32, 68, 97, 118, 105, 100, 32, 84,
  115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60,
  47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105,
  110, 116, 40, 50, 44, 49, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 82, 97, 100, 105, 117, 115, 32, 61, 32, 105, 110, 116,
  40, 53, 44, 49, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66,
  65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108,
  117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97,
  98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44,
  34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97,
  108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101,
  110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34,
  99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34,
  44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44,
  34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50,
  48, 49, 52, 47, 48, 49, 47, 49, 54, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 75, 117,
  119, 97, 104, 97, 114, 97, 95, 48, 48, 49, 32, 58, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 86,
  97, 108, 105, 100, 101, 114, 95, 86, 97, 108, 101, 117, 114, 95, 68, 101,
  95, 67, 111, 109, 112, 97, 114, 97, 105, 115, 111, 110, 61, 36, 49, 10,
  86, 97, 108, 101, 117, 114, 95, 68, 101, 95, 67, 111, 109, 112, 97, 114,
  97, 105, 115, 111, 110, 61, 36, 50, 10, 66, 111, 111, 115, 116, 61, 36,
  51, 10, 67, 111, 115, 115, 105, 110, 61, 36, 52, 10, 73, 116, 101, 114,
  97, 116, 105, 111, 110, 115, 95, 75, 117, 119, 97, 104, 97, 114, 97, 61,
  36, 53, 10, 82, 97, 100, 105, 117, 115, 95, 75, 117, 119, 97, 104, 97,
  114, 97, 61, 36, 54, 10, 67, 104, 97, 110, 110, 101, 108, 115, 95, 75,
  117, 119, 97, 104, 97, 114, 97, 61, 36, 55, 10, 45, 116, 111, 95, 114,
  103, 98, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 67, 111, 115,
  115, 105, 110, 61, 61, 49, 125, 10, 45, 45, 103, 105, 109, 112, 95, 100,
  111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 66, 111, 111, 115, 116,
  61, 61, 49, 125, 10, 45, 103, 105, 109, 112, 95, 98, 97, 108, 97, 110,
  99, 101, 95, 103, 97, 109, 109, 97, 91, 45, 49, 93, 32, 49, 50, 56,
  44, 49, 50, 56, 44, 49, 50, 56, 44, 49, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 86, 97, 108, 105, 100, 101, 114, 95,
  86, 97, 108, 101, 117, 114, 95, 68, 101, 95, 67, 111, 109, 112, 97, 114,
  97, 105, 115, 111, 110, 61, 61, 49, 125, 10, 45, 108, 101, 91, 45, 49,
  93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 68, 101, 95, 67, 111, 109,
  112, 97, 114, 97, 105, 115, 111, 110, 10, 45, 101, 108, 115, 101, 10, 45,
  108, 101, 91, 45, 49, 93, 32, 123, 105, 97, 125, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10,
  45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 10, 45, 103,
  105, 109, 112, 95, 107, 117, 119, 97, 104, 97, 114, 97, 91, 45, 49, 93,
  32, 36, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 95, 75, 117, 119,
  97, 104, 97, 114, 97, 44, 36, 82, 97, 100, 105, 117, 115, 95, 75, 117,
  119, 97, 104, 97, 114, 97, 44, 36, 67, 104, 97, 110, 110, 101, 108, 115,
  95, 75, 117, 119, 97, 104, 97, 114, 97, 10, 45, 105, 102, 32, 123, 36,
  67, 111, 115, 115, 105, 110, 61, 61, 49, 125, 10, 45, 103, 105, 109, 112,
  95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 49, 55,
  44, 49, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 115, 97, 109, 106, 95, 75, 117, 119,
  97, 104, 97, 114, 97, 95, 48, 48, 49, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 75,
  117, 119, 97, 104, 97, 114, 97, 95, 48, 48, 49, 32, 36, 42, 34, 44,
  36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 77, 101, 108, 97, 110,
  103, 101, 32, 105, 109, 97, 103, 101, 32, 116, 101, 120, 116, 117, 114, 101,
  32, 48, 48, 49, 32, 58, 32, 77, 101, 108, 97, 110, 103, 101, 95, 73,
  109, 97, 103, 101, 95, 84, 101, 120, 116, 117, 114, 101, 95, 48, 48, 49,
  95, 115, 97, 109, 106, 44, 32, 77, 101, 108, 97, 110, 103, 101, 95, 73,
  109, 97, 103, 101, 95, 84, 101, 120, 116, 117, 114, 101, 95, 48, 48, 49,
  95, 115, 97, 109, 106, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32,
  102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110,
  103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 83, 101,
  103, 109, 101, 110, 116, 32, 87, 97, 116, 101, 114, 115, 104, 101, 100, 60,
  47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101, 32, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 32, 91, 115, 101, 103, 109, 101, 110,
  116, 97, 116, 105, 111, 110, 93, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  50, 46, 48, 48, 44, 48, 44, 49, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 91,
  115, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111, 110, 93, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 51, 46, 56, 48, 44, 48, 44, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 102, 111, 114, 109, 97,
  116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100,
  103, 101, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 91, 115, 101,
  103, 109, 101, 110, 116, 97, 116, 105, 111, 110, 32, 50, 93, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 51, 46, 52, 44, 48, 44, 49, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 91, 115, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111,
  110, 32, 50, 93, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 57,
  44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77,
  101, 108, 97, 110, 103, 101, 32, 47, 32, 98, 108, 101, 110, 100, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 45, 49, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111,
  114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101,
  114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 77, 97, 115, 113,
  117, 101, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 111, 114,
  109, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 69,
  108, 108, 105, 112, 115, 101, 34, 44, 34, 82, 101, 99, 116, 97, 110, 103,
  108, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 101,
  110, 116, 114, 101, 32, 120, 32, 37, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 53, 48, 44, 45, 50, 53, 44, 49, 50, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 101, 110, 116, 114, 101, 32, 121, 32, 37,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 45, 50, 53, 44,
  49, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72, 97,
  117, 116, 101, 117, 114, 32, 47, 32, 119, 105, 100, 116, 104, 32, 37, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 55, 53, 44, 53, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 97, 114, 103,
  101, 117, 114, 32, 47, 32, 104, 101, 105, 103, 104, 116, 32, 37, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 55, 53, 44, 53, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 97, 115, 113, 117,
  101, 32, 100, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 50, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 114, 101, 97, 100, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 53, 44, 50, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110,
  32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97,
  110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 84,
  101, 120, 116, 117, 114, 101, 32, 48, 48, 51, 60, 47, 115, 109, 97, 108,
  108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 110,
  111, 105, 115, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44,
  53, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  68, 101, 110, 115, 105, 116, 121, 32, 104, 97, 114, 100, 115, 107, 101, 116,
  99, 104, 98, 119, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44,
  53, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 112, 114, 101, 97, 100, 32, 118, 97, 114, 105, 97, 116, 105, 111, 110,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 44, 51, 44, 50, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105,
  116, 117, 100, 101, 32, 119, 97, 116, 101, 114, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 51, 44, 50, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 47, 32, 99, 111,
  108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 49, 44,
  50, 51, 55, 44, 50, 48, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 79, 112, 97, 99, 105, 116, 92, 51, 48, 51, 92, 50, 53, 49,
  32, 47, 32, 111, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 44, 45, 49, 44, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114,
  111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34,
  62, 60, 115, 109, 97, 108, 108, 62, 66, 108, 101, 110, 100, 32, 84, 101,
  120, 116, 117, 114, 101, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115,
  112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  77, 101, 108, 97, 110, 103, 101, 32, 47, 32, 98, 108, 101, 110, 100, 32,
  116, 101, 120, 116, 117, 114, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 110, 116, 114, 97, 115, 116, 101, 115, 32, 108, 99, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 114, 109, 97, 108, 105,
  122, 101, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 101, 117, 114, 115, 32, 47, 32, 65, 117,
  116, 104, 111, 114, 115, 32, 58, 32, 60, 105, 62, 83, 97, 109, 106, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49,
  51, 47, 49, 50, 47, 50, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 77, 101, 108, 97, 110, 103, 101, 95, 73,
  109, 97, 103, 101, 95, 84, 101, 120, 116, 117, 114, 101, 95, 48, 48, 49,
  95, 115, 97, 109, 106, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 69, 100, 103, 101, 95, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 95, 83, 101, 103, 109, 101, 110, 116,
  97, 116, 105, 111, 110, 61, 36, 49, 10, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 95, 83, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111, 110,
  61, 36, 50, 10, 68, 105, 115, 116, 111, 114, 115, 105, 111, 110, 95, 83,
  101, 103, 109, 101, 110, 116, 97, 116, 105, 111, 110, 61, 36, 51, 10, 66,
  95, 69, 100, 103, 101, 95, 116, 104, 114, 101, 115, 104, 111, 108, 100, 95,
  83, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111, 110, 61, 36, 52, 10,
  66, 95, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 95, 83, 101, 103,
  109, 101, 110, 116, 97, 116, 105, 111, 110, 61, 36, 53, 10, 77, 101, 108,
  97, 110, 103, 101, 95, 83, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111,
  110, 61, 36, 54, 10, 70, 111, 114, 109, 101, 95, 77, 97, 115, 113, 117,
  101, 61, 36, 55, 10, 67, 101, 110, 116, 114, 101, 95, 88, 61, 36, 56,
  10, 67, 101, 110, 116, 114, 101, 95, 89, 61, 36, 57, 10, 76, 97, 114,
  103, 101, 117, 114, 95, 77, 97, 115, 113, 117, 101, 61, 36, 49, 48, 10,
  72, 97, 117, 116, 101, 117, 114, 95, 77, 97, 115, 113, 117, 101, 61, 36,
  49, 49, 10, 77, 97, 115, 113, 117, 101, 95, 68, 101, 102, 111, 114, 109,
  97, 116, 105, 111, 110, 61, 36, 49, 50, 10, 77, 97, 115, 113, 117, 101,
  95, 83, 112, 114, 101, 97, 100, 61, 36, 49, 51, 10, 65, 109, 112, 108,
  105, 116, 117, 100, 101, 95, 78, 111, 105, 115, 101, 61, 36, 49, 52, 10,
  68, 101, 110, 115, 105, 116, 121, 95, 72, 97, 114, 100, 115, 107, 101, 116,
  99, 104, 98, 119, 61, 36, 49, 53, 10, 83, 112, 114, 101, 97, 100, 95,
  86, 97, 114, 105, 97, 116, 105, 111, 110, 115, 61, 36, 49, 54, 10, 65,
  109, 112, 108, 105, 116, 117, 100, 101, 95, 87, 97, 116, 101, 114, 61, 36,
  49, 55, 10, 82, 51, 61, 36, 49, 56, 10, 86, 51, 61, 36, 49, 57,
  10, 66, 51, 61, 36, 50, 48, 10, 79, 112, 97, 99, 105, 116, 101, 61,
  36, 50, 49, 10, 77, 101, 108, 97, 110, 103, 101, 95, 84, 101, 120, 116,
  117, 114, 101, 61, 36, 50, 50, 10, 67, 111, 110, 116, 114, 97, 115, 116,
  101, 115, 95, 76, 67, 69, 61, 36, 50, 51, 10, 78, 111, 114, 109, 97,
  108, 105, 122, 101, 95, 82, 101, 115, 117, 108, 116, 97, 116, 61, 36, 50,
  52, 10, 35, 32, 109, -23, 108, 97, 110, 103, 101, 114, 32, 50, 32, 103,
  105, 109, 112, 95, 115, 101, 103, 109, 101, 110, 116, 95, 119, 97, 116, 101,
  114, 115, 104, 101, 100, 32, 101, 116, 32, 111, 98, 116, 101, 110, 105, 114,
  32, 50, 32, 105, 109, 97, 103, 101, 115, 10, 45, 45, 103, 105, 109, 112,
  95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10,
  45, 103, 105, 109, 112, 95, 115, 101, 103, 109, 101, 110, 116, 95, 119, 97,
  116, 101, 114, 115, 104, 101, 100, 91, 45, 49, 93, 32, 36, 69, 100, 103,
  101, 95, 116, 104, 114, 101, 115, 104, 111, 108, 100, 95, 83, 101, 103, 109,
  101, 110, 116, 97, 116, 105, 111, 110, 44, 36, 83, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 95, 83, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111,
  110, 44, 48, 10, 45, 100, 101, 102, 111, 114, 109, 91, 45, 49, 93, 32,
  36, 68, 105, 115, 116, 111, 114, 115, 105, 111, 110, 95, 83, 101, 103, 109,
  101, 110, 116, 97, 116, 105, 111, 110, 10, 45, 103, 105, 109, 112, 95, 115,
  101, 103, 109, 101, 110, 116, 95, 119, 97, 116, 101, 114, 115, 104, 101, 100,
  91, 45, 50, 93, 32, 36, 66, 95, 69, 100, 103, 101, 95, 116, 104, 114,
  101, 115, 104, 111, 108, 100, 95, 83, 101, 103, 109, 101, 110, 116, 97, 116,
  105, 111, 110, 44, 36, 66, 95, 83, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 95, 83, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111, 110, 44, 48,
  10, 45, 105, 102, 32, 123, 36, 77, 101, 108, 97, 110, 103, 101, 95, 83,
  101, 103, 109, 101, 110, 116, 97, 116, 105, 111, 110, 62, 61, 48, 125, 10,
  45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45,
  50, 93, 32, 51, 44, 36, 77, 101, 108, 97, 110, 103, 101, 95, 83, 101,
  103, 109, 101, 110, 116, 97, 116, 105, 111, 110, 44, 48, 10, 45, 101, 108,
  115, 101, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45,
  49, 44, 45, 50, 93, 32, 51, 44, 40, 49, 43, 36, 77, 101, 108, 97,
  110, 103, 101, 95, 83, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111, 110,
  41, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 114,
  103, 98, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 76, 67, 69,
  91, 45, 49, 93, 32, 56, 48, 44, 36, 67, 111, 110, 116, 114, 97, 115,
  116, 101, 115, 95, 76, 67, 69, 44, 49, 44, 49, 44, 51, 10, 45, 110,
  101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 10, 45, 116, 111, 95,
  114, 103, 98, 97, 91, 45, 49, 93, 10, 35, 35, 35, 35, 32, 77, 97,
  115, 113, 117, 101, 10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 52,
  10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93,
  32, 48, 44, 48, 44, 48, 44, 48, 10, 45, 116, 111, 95, 114, 103, 98,
  97, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 70, 111, 114, 109,
  101, 95, 77, 97, 115, 113, 117, 101, 61, 61, 48, 125, 10, 45, 101, 108,
  108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 123, 36, 67, 101, 110, 116,
  114, 101, 95, 88, 125, 37, 44, 123, 36, 67, 101, 110, 116, 114, 101, 95,
  89, 125, 37, 44, 123, 123, 119, 125, 47, 50, 48, 48, 42, 36, 76, 97,
  114, 103, 101, 117, 114, 95, 77, 97, 115, 113, 117, 101, 125, 44, 123, 123,
  104, 125, 47, 50, 48, 48, 42, 36, 72, 97, 117, 116, 101, 117, 114, 95,
  77, 97, 115, 113, 117, 101, 125, 44, 48, 44, 49, 44, 50, 53, 53, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 70, 111, 114, 109, 101, 95, 77, 97,
  115, 113, 117, 101, 61, 61, 49, 125, 10, 45, 114, 101, 99, 116, 97, 110,
  103, 108, 101, 91, 45, 49, 93, 32, 123, 123, 123, 119, 125, 42, 123, 123,
  36, 67, 101, 110, 116, 114, 101, 95, 88, 125, 37, 125, 125, 45, 123, 123,
  119, 125, 47, 50, 48, 48, 42, 36, 76, 97, 114, 103, 101, 117, 114, 95,
  77, 97, 115, 113, 117, 101, 125, 125, 44, 123, 123, 123, 104, 125, 42, 123,
  123, 36, 67, 101, 110, 116, 114, 101, 95, 89, 125, 37, 125, 125, 45, 123,
  123, 104, 125, 47, 50, 48, 48, 42, 36, 72, 97, 117, 116, 101, 117, 114,
  95, 77, 97, 115, 113, 117, 101, 125, 125, 44, 123, 123, 123, 119, 125, 42,
  123, 123, 36, 67, 101, 110, 116, 114, 101, 95, 88, 125, 37, 125, 125, 43,
  123, 123, 119, 125, 47, 50, 48, 48, 42, 36, 76, 97, 114, 103, 101, 117,
  114, 95, 77, 97, 115, 113, 117, 101, 125, 125, 44, 123, 123, 123, 104, 125,
  42, 123, 123, 36, 67, 101, 110, 116, 114, 101, 95, 89, 125, 37, 125, 125,
  43, 123, 123, 104, 125, 47, 50, 48, 48, 42, 36, 72, 97, 117, 116, 101,
  117, 114, 95, 77, 97, 115, 113, 117, 101, 125, 125, 44, 49, 44, 50, 53,
  53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 115,
  112, 114, 101, 97, 100, 91, 45, 49, 93, 32, 36, 77, 97, 115, 113, 117,
  101, 95, 83, 112, 114, 101, 97, 100, 44, 36, 77, 97, 115, 113, 117, 101,
  95, 83, 112, 114, 101, 97, 100, 44, 48, 10, 45, 100, 101, 102, 111, 114,
  109, 91, 45, 49, 93, 32, 36, 77, 97, 115, 113, 117, 101, 95, 68, 101,
  102, 111, 114, 109, 97, 116, 105, 111, 110, 10, 45, 103, 105, 109, 112, 95,
  98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 52, 50, 44,
  49, 44, 48, 10, 35, 35, 35, 35, 32, 116, 101, 120, 116, 117, 114, 101,
  10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 52, 10, 45, 102, 105,
  108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 10, 45, 115,
  97, 109, 106, 95, 84, 101, 120, 116, 117, 114, 101, 95, 65, 113, 117, 97,
  114, 101, 108, 108, 101, 95, 49, 91, 45, 49, 93, 32, 36, 65, 109, 112,
  108, 105, 116, 117, 100, 101, 95, 78, 111, 105, 115, 101, 44, 36, 68, 101,
  110, 115, 105, 116, 121, 95, 72, 97, 114, 100, 115, 107, 101, 116, 99, 104,
  98, 119, 44, 36, 83, 112, 114, 101, 97, 100, 95, 86, 97, 114, 105, 97,
  116, 105, 111, 110, 115, 44, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  95, 87, 97, 116, 101, 114, 44, 36, 82, 51, 44, 36, 86, 51, 44, 36,
  66, 51, 44, 36, 79, 112, 97, 99, 105, 116, 101, 10, 45, 103, 105, 109,
  112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 51,
  44, 36, 77, 101, 108, 97, 110, 103, 101, 95, 84, 101, 120, 116, 117, 114,
  101, 44, 48, 10, 45, 105, 102, 32, 123, 36, 78, 111, 114, 109, 97, 108,
  105, 122, 101, 95, 82, 101, 115, 117, 108, 116, 97, 116, 61, 61, 49, 125,
  10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101,
  110, 100, 105, 102, 10, 35, 32, 45, 116, 101, 120, 116, 95, 111, 117, 116,
  108, 105, 110, 101, 91, 45, 49, 93, 32, 123, 123, 119, 125, 42, 123, 123,
  36, 67, 101, 110, 116, 114, 101, 95, 88, 125, 37, 125, 125, 44, 49, 48,
  44, 49, 48, 44, 54, 52, 44, 49, 44, 49, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 50, 53, 53, 10, 35, 32, 45, 116, 101, 120, 116, 95, 111,
  117, 116, 108, 105, 110, 101, 91, 45, 49, 93, 32, 123, 123, 104, 125, 42,
  123, 123, 36, 67, 101, 110, 116, 114, 101, 95, 89, 125, 37, 125, 125, 44,
  49, 48, 44, 54, 48, 44, 54, 52, 44, 49, 44, 49, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 10, 35, 32, 45, 116, 101, 120, 116,
  95, 111, 117, 116, 108, 105, 110, 101, 91, 45, 49, 93, 32, 123, 123, 119,
  125, 47, 50, 48, 48, 42, 36, 76, 97, 114, 103, 101, 117, 114, 95, 77,
  97, 115, 113, 117, 101, 125, 44, 49, 48, 44, 49, 49, 48, 44, 54, 52,
  44, 49, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  10, 35, 32, 45, 116, 101, 120, 116, 95, 111, 117, 116, 108, 105, 110, 101,
  91, 45, 49, 93, 32, 123, 123, 104, 125, 47, 50, 48, 48, 42, 36, 72,
  97, 117, 116, 101, 117, 114, 95, 77, 97, 115, 113, 117, 101, 125, 44, 49,
  48, 44, 49, 54, 48, 44, 54, 52, 44, 49, 44, 49, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 77, 101, 108, 97, 110, 103, 101, 95, 73, 109, 97,
  103, 101, 95, 84, 101, 120, 116, 117, 114, 101, 95, 48, 48, 49, 95, 115,
  97, 109, 106, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 77, 101, 108, 97, 110, 103, 101, 95, 73, 109, 97, 103,
  101, 95, 84, 101, 120, 116, 117, 114, 101, 95, 48, 48, 49, 95, 115, 97,
  109, 106, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 80, 111, 108, 121, 103, 111, 110, 105, 122, 101, 32, 58, 32, 80,
  111, 108, 121, 103, 111, 110, 105, 122, 101, 95, 71, 85, 73, 44, 32, 80,
  111, 108, 121, 103, 111, 110, 105, 122, 101, 95, 71, 85, 73, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 80, 111, 108, 121, 103, 111, 110,
  105, 122, 101, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 105, 110,
  116, 40, 51, 48, 48, 44, 48, 44, 50, 48, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 105, 110,
  105, 109, 97, 108, 32, 97, 114, 101, 97, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 88, 45, 114, 101, 115, 111, 108, 117, 116, 105, 111,
  110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 49, 44, 50,
  53, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 114,
  101, 115, 111, 108, 117, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 48, 44, 49, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 84, 101, 115, 116,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 84, 101, 115, 116, 32, 99, 97, 100, 114, 101, 32, 101,
  116, 32, 111, 116, 115, 117, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101,
  118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 70, 105, 108,
  116, 101, 114, 115, 32, 98, 121, 32, 68, 97, 118, 105, 100, 32, 84, 115,
  99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32,
  60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 50, 48, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 80, 111, 108,
  121, 103, 111, 110, 105, 122, 101, 95, 71, 85, 73, 32, 58, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  45, 112, 111, 108, 121, 103, 111, 110, 105, 122, 101, 91, 45, 49, 93, 32,
  36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 10, 45,
  105, 102, 32, 123, 36, 54, 61, 61, 49, 125, 32, 45, 116, 111, 95, 114,
  103, 98, 97, 91, 45, 49, 93, 32, 45, 103, 105, 109, 112, 95, 102, 114,
  97, 109, 101, 91, 45, 49, 93, 32, 48, 44, 49, 48, 48, 44, 48, 44,
  49, 48, 48, 44, 49, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 53,
  53, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 32, 45, 111, 116, 115, 117, 91, 45, 49, 93, 32, 52, 32,
  45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 112, 111,
  108, 121, 103, 111, 110, 105, 122, 101, 91, 45, 49, 93, 32, 36, 49, 44,
  36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 80,
  111, 108, 121, 103, 111, 110, 105, 122, 101, 95, 71, 85, 73, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112,
  108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 80, 111,
  108, 121, 103, 111, 110, 105, 122, 101, 95, 71, 85, 73, 32, 36, 42, 34,
  44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 80, 111, 108, 121,
  103, 111, 110, 105, 122, 101, 32, 99, 111, 108, 111, 114, 101, 100, 32, 112,
  101, 110, 99, 105, 108, 115, 32, 58, 32, 103, 105, 109, 112, 95, 80, 111,
  108, 121, 103, 111, 110, 105, 122, 101, 95, 67, 111, 108, 111, 114, 101, 100,
  95, 80, 101, 110, 99, 105, 108, 115, 44, 32, 103, 105, 109, 112, 95, 80,
  111, 108, 121, 103, 111, 110, 105, 122, 101, 95, 67, 111, 108, 111, 114, 101,
  100, 95, 80, 101, 110, 99, 105, 108, 115, 95, 112, 114, 101, 118, 105, 101,
  119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 80, 111, 108, 121, 103, 111, 110, 105, 122, 101, 32,
  112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109,
  112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 105, 110, 116, 40, 51, 48,
  48, 44, 48, 44, 50, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 105, 110, 105, 109, 97, 108,
  32, 97, 114, 101, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48,
  44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 88, 45, 114, 101, 115, 111, 108, 117, 116, 105, 111, 110, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 48, 44, 49, 44, 50, 53, 54, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 114, 101, 115, 111, 108,
  117, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48,
  44, 49, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 67, 111, 108, 111, 114, 101, 100, 32,
  80, 101, 110, 99, 105, 108, 115, 32, 112, 97, 114, 97, 109, 101, 116, 101,
  114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 46, 51, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 50, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 81, 117, 97, 110, 116, 105,
  122, 101, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32, 105, 110, 116, 32,
  40, 50, 48, 44, 50, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48,
  44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 105,
  120, 101, 114, 32, 109, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 50, 44, 34, 67, 111, 108, 111, 114, 32, 68, 111, 112, 105, 110,
  103, 34, 44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 72, 97, 114,
  100, 32, 76, 105, 103, 104, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32,
  77, 101, 114, 103, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115,
  115, 34, 44, 34, 77, 117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 83,
  111, 102, 116, 32, 76, 105, 103, 104, 116, 34, 44, 34, 86, 97, 108, 117,
  101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108,
  111, 114, 32, 105, 110, 116, 101, 110, 115, 105, 116, 121, 32, 61, 102, 108,
  111, 97, 116, 32, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 76, 111, 99, 97,
  108, 32, 78, 111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 78, 111, 34,
  44, 34, 65, 76, 76, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99,
  101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  70, 105, 108, 116, 101, 114, 115, 32, 98, 121, 32, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 32, 45, 32, 80, 104, 111, 116, 111, 67, 111, 109, 105, 88, 32, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32,
  60, 105, 62, 50, 48, 49, 51, 47, 49, 50, 47, 48, 52, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 80, 111, 108, 121, 103, 111, 110, 105, 122, 101, 95, 67, 111, 108,
  111, 114, 101, 100, 95, 80, 101, 110, 99, 105, 108, 115, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 45, 112, 111, 108, 121, 103, 111, 110, 105, 122, 101, 91, 45, 49, 93,
  32, 36, 49, 44, 36, 50, 44, 36, 51, 44, 36, 52, 44, 36, 53, 10,
  45, 103, 105, 109, 112, 95, 99, 112, 101, 110, 99, 105, 108, 91, 45, 49,
  93, 32, 36, 54, 44, 36, 55, 44, 36, 56, 44, 36, 57, 44, 36, 49,
  48, 44, 36, 49, 49, 10, 45, 105, 102, 32, 123, 36, 49, 50, 61, 61,
  49, 125, 10, 45, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97, 108, 105,
  122, 101, 95, 108, 111, 99, 97, 108, 91, 45, 49, 93, 32, 50, 44, 54,
  44, 53, 44, 50, 48, 44, 49, 44, 48, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 49, 50, 61, 61, 50, 125, 10, 45, 103, 105, 109, 112, 95, 110,
  111, 114, 109, 97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 91, 45,
  49, 93, 32, 50, 44, 54, 44, 53, 44, 50, 48, 44, 49, 44, 51, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 103, 105, 109, 112, 95, 80, 111, 108, 121, 103, 111, 110, 105,
  122, 101, 95, 67, 111, 108, 111, 114, 101, 100, 95, 80, 101, 110, 99, 105,
  108, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 103, 105, 109, 112, 95, 80, 111, 108, 121, 103, 111, 110, 105,
  122, 101, 95, 67, 111, 108, 111, 114, 101, 100, 95, 80, 101, 110, 99, 105,
  108, 115, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 83, 105, 109, 112, 108, 101, 32, 102, 105, 108, 116, 114, 101, 32,
  110, 111, 101, 108, 32, 50, 48, 49, 50, 32, 58, 32, 83, 105, 109, 112,
  108, 101, 95, 70, 105, 108, 116, 114, 101, 95, 78, 111, 101, 108, 95, 50,
  48, 49, 50, 95, 115, 97, 109, 106, 44, 32, 83, 105, 109, 112, 108, 101,
  95, 70, 105, 108, 116, 114, 101, 95, 78, 111, 101, 108, 95, 50, 48, 49,
  50, 95, 115, 97, 109, 106, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 67,
  111, 117, 108, 101, 117, 114, 115, 32, 47, 32, 67, 111, 108, 111, 114, 115,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 68, 101, 116, 101, 99,
  116, 105, 111, 110, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108, 101, 117, 114, 32, 111,
  114, 105, 103, 105, 110, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  46, 53, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 68, 105, 102, 102, 101, 114, 101, 110, 99, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 50, 44, 48, 46, 53, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 71, 114, 105, 122, 111, 117,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 114, 109,
  97, 108, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 50, 53, 53, 44,
  48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 73, 110, 118, 101, 114, 115, 101, 114, 32, 47, 32, 73, 110, 118,
  101, 114, 116, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 73, 110, 118, 101, 114, 115, 101, 114, 32,
  45, 32, 105, 110, 118, 101, 114, 116, 32, 61, 32, 98, 111, 111, 108, 40,
  102, 97, 108, 115, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 70, 108, 111, 117, 32, 47, 32, 66, 108,
  117, 114, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 70, 108, 111, 117, 32, 47, 32, 98, 108, 117,
  114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 51, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 67, 117, 116, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 116, 32, 97, 32, 61, 32,
  105, 110, 116, 40, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 117, 116, 32, 98, 32, 61, 32, 105, 110,
  116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 101, 117, 114, 115,
  32, 47, 32, 65, 117, 116, 104, 111, 114, 115, 32, 58, 32, 60, 105, 62,
  83, 97, 109, 106, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60,
  105, 62, 50, 48, 49, 51, 47, 48, 49, 47, 50, 53, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 83, 105, 109, 112,
  108, 101, 95, 70, 105, 108, 116, 114, 101, 95, 78, 111, 101, 108, 95, 50,
  48, 49, 50, 95, 115, 97, 109, 106, 32, 58, 10, 86, 97, 108, 101, 117,
  114, 95, 111, 114, 105, 103, 105, 110, 101, 61, 36, 49, 10, 68, 105, 102,
  102, 101, 114, 101, 110, 99, 101, 61, 36, 50, 10, 111, 112, 97, 99, 105,
  116, 101, 61, 49, 10, 35, 35, 32, 71, 114, 105, 122, 111, 117, 10, 86,
  97, 108, 101, 117, 114, 95, 65, 61, 48, 10, 86, 97, 108, 101, 117, 114,
  95, 66, 61, 50, 53, 53, 10, 82, 95, 78, 111, 114, 109, 97, 108, 105,
  122, 101, 61, 48, 10, 86, 97, 108, 101, 117, 114, 95, 67, 61, 48, 10,
  86, 97, 108, 101, 117, 114, 95, 68, 61, 50, 53, 53, 10, 86, 95, 78,
  111, 114, 109, 97, 108, 105, 122, 101, 61, 48, 10, 86, 97, 108, 101, 117,
  114, 95, 69, 61, 48, 10, 86, 97, 108, 101, 117, 114, 95, 70, 61, 50,
  53, 53, 10, 66, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 61, 48,
  10, 86, 97, 108, 101, 117, 114, 95, 71, 61, 48, 10, 86, 97, 108, 101,
  117, 114, 95, 72, 61, 55, 54, 52, 10, 82, 86, 66, 95, 82, 71, 66,
  95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 61, 36, 51, 10, 73, 110,
  118, 101, 114, 115, 101, 114, 61, 36, 52, 10, 70, 108, 111, 117, 61, 36,
  53, 10, 67, 117, 116, 95, 65, 61, 36, 54, 10, 67, 117, 116, 95, 66,
  61, 36, 55, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95,
  110, 111, 116, 104, 105, 110, 103, 10, 45, 70, 105, 108, 116, 114, 101, 95,
  78, 111, 101, 108, 95, 50, 48, 49, 50, 95, 115, 97, 109, 106, 91, 45,
  50, 93, 32, 49, 49, 44, 49, 44, 48, 44, 36, 86, 97, 108, 101, 117,
  114, 95, 111, 114, 105, 103, 105, 110, 101, 44, 36, 68, 105, 102, 102, 101,
  114, 101, 110, 99, 101, 44, 36, 111, 112, 97, 99, 105, 116, 101, 44, 36,
  86, 97, 108, 101, 117, 114, 95, 65, 44, 36, 86, 97, 108, 101, 117, 114,
  95, 66, 44, 36, 82, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 44,
  36, 86, 97, 108, 101, 117, 114, 95, 67, 44, 36, 86, 97, 108, 101, 117,
  114, 95, 68, 44, 36, 86, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101,
  44, 36, 86, 97, 108, 101, 117, 114, 95, 69, 44, 36, 86, 97, 108, 101,
  117, 114, 95, 70, 44, 36, 66, 95, 78, 111, 114, 109, 97, 108, 105, 122,
  101, 44, 36, 86, 97, 108, 101, 117, 114, 95, 71, 44, 36, 86, 97, 108,
  101, 117, 114, 95, 72, 44, 36, 82, 86, 66, 95, 82, 71, 66, 95, 78,
  111, 114, 109, 97, 108, 105, 122, 101, 44, 36, 73, 110, 118, 101, 114, 115,
  101, 114, 44, 36, 70, 108, 111, 117, 44, 36, 67, 117, 116, 95, 65, 44,
  36, 67, 117, 116, 95, 66, 10, 45, 70, 105, 108, 116, 114, 101, 95, 78,
  111, 101, 108, 95, 50, 48, 49, 50, 95, 115, 97, 109, 106, 91, 45, 49,
  93, 32, 52, 51, 44, 49, 44, 48, 44, 36, 86, 97, 108, 101, 117, 114,
  95, 111, 114, 105, 103, 105, 110, 101, 44, 36, 68, 105, 102, 102, 101, 114,
  101, 110, 99, 101, 44, 36, 111, 112, 97, 99, 105, 116, 101, 44, 36, 86,
  97, 108, 101, 117, 114, 95, 65, 44, 36, 86, 97, 108, 101, 117, 114, 95,
  66, 44, 36, 82, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 44, 36,
  86, 97, 108, 101, 117, 114, 95, 67, 44, 36, 86, 97, 108, 101, 117, 114,
  95, 68, 44, 36, 86, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 44,
  36, 86, 97, 108, 101, 117, 114, 95, 69, 44, 36, 86, 97, 108, 101, 117,
  114, 95, 70, 44, 36, 66, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101,
  44, 36, 86, 97, 108, 101, 117, 114, 95, 71, 44, 36, 86, 97, 108, 101,
  117, 114, 95, 72, 44, 36, 82, 86, 66, 95, 82, 71, 66, 95, 78, 111,
  114, 109, 97, 108, 105, 122, 101, 44, 36, 73, 110, 118, 101, 114, 115, 101,
  114, 44, 36, 70, 108, 111, 117, 44, 36, 67, 117, 116, 95, 65, 44, 36,
  67, 117, 116, 95, 66, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110,
  100, 91, 45, 49, 44, 45, 50, 93, 32, 50, 52, 44, 49, 44, 48, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 83, 105, 109, 112,
  108, 101, 95, 70, 105, 108, 116, 114, 101, 95, 78, 111, 101, 108, 95, 50,
  48, 49, 50, 95, 115, 97, 109, 106, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 83, 105, 109, 112, 108, 101, 95,
  70, 105, 108, 116, 114, 101, 95, 78, 111, 101, 108, 95, 50, 48, 49, 50,
  95, 115, 97, 109, 106, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36,
  45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 83, 116, 114, 117, 99, 116,
  117, 114, 101, 116, 101, 110, 115, 111, 114, 115, 32, 48, 48, 49, 32, 58,
  32, 115, 97, 109, 106, 95, 83, 116, 114, 117, 99, 116, 117, 114, 101, 116,
  101, 110, 115, 111, 114, 115, 95, 48, 48, 49, 44, 32, 115, 97, 109, 106,
  95, 83, 116, 114, 117, 99, 116, 117, 114, 101, 116, 101, 110, 115, 111, 114,
  115, 95, 48, 48, 49, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32,
  102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110,
  103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 83, 116,
  114, 117, 99, 116, 117, 114, 101, 116, 101, 110, 115, 111, 114, 115, 60, 47,
  115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 104, 101, 109, 101, 32,
  61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 50, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101,
  103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101,
  100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 67, 111, 108, 111, 114, 115,
  60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114,
  115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 72, 111, 116, 32, 112, 105, 120, 101, 108, 115, 32,
  61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 72, 111, 116, 32, 112, 105, 120, 101, 108, 115, 32, 109, 97,
  115, 107, 32, 115, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 51, 44,
  51, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72,
  111, 116, 32, 112, 105, 120, 101, 108, 115, 32, 116, 104, 114, 101, 115, 104,
  111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48,
  44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52,
  47, 48, 49, 47, 50, 48, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 83, 116, 114, 117, 99,
  116, 117, 114, 101, 116, 101, 110, 115, 111, 114, 115, 95, 48, 48, 49, 32,
  58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 83, 99, 104, 101, 109, 101, 61, 36, 49, 10, 67, 111,
  117, 108, 101, 117, 114, 115, 61, 36, 50, 10, 86, 97, 108, 105, 100, 97,
  116, 105, 111, 110, 95, 104, 111, 116, 112, 105, 120, 101, 108, 115, 61, 36,
  51, 10, 77, 97, 115, 107, 95, 83, 105, 122, 101, 95, 104, 111, 116, 112,
  105, 120, 101, 108, 115, 61, 36, 52, 10, 84, 104, 114, 101, 115, 104, 111,
  108, 100, 95, 104, 111, 116, 112, 105, 120, 101, 108, 115, 61, 36, 53, 10,
  45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10, 45, 105, 102, 32,
  123, 36, 67, 111, 117, 108, 101, 117, 114, 115, 61, 61, 49, 125, 10, 45,
  45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103,
  91, 45, 49, 93, 10, 45, 115, 116, 114, 117, 99, 116, 117, 114, 101, 116,
  101, 110, 115, 111, 114, 115, 91, 45, 49, 93, 32, 36, 49, 10, 45, 116,
  111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 91, 45, 49, 93, 32,
  49, 10, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 10,
  45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45,
  50, 93, 32, 50, 55, 44, 49, 44, 48, 10, 45, 105, 102, 32, 123, 36,
  86, 97, 108, 105, 100, 97, 116, 105, 111, 110, 95, 104, 111, 116, 112, 105,
  120, 101, 108, 115, 61, 61, 49, 125, 10, 45, 114, 101, 109, 111, 118, 101,
  95, 104, 111, 116, 112, 105, 120, 101, 108, 115, 32, 36, 77, 97, 115, 107,
  95, 83, 105, 122, 101, 95, 104, 111, 116, 112, 105, 120, 101, 108, 115, 44,
  36, 84, 104, 114, 101, 115, 104, 111, 108, 100, 95, 104, 111, 116, 112, 105,
  120, 101, 108, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115,
  101, 10, 45, 115, 116, 114, 117, 99, 116, 117, 114, 101, 116, 101, 110, 115,
  111, 114, 115, 91, 45, 49, 93, 32, 36, 49, 10, 45, 116, 111, 95, 99,
  111, 108, 111, 114, 109, 111, 100, 101, 91, 45, 49, 93, 32, 49, 10, 45,
  110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  115, 97, 109, 106, 95, 83, 116, 114, 117, 99, 116, 117, 114, 101, 116, 101,
  110, 115, 111, 114, 115, 95, 48, 48, 49, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 83,
  116, 114, 117, 99, 116, 117, 114, 101, 116, 101, 110, 115, 111, 114, 115, 95,
  48, 48, 49, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105,
  109, 112, 32, 84, 101, 115, 116, 32, 100, 101, 115, 115, 105, 110, 32, 112,
  101, 105, 110, 116, 117, 114, 101, 32, 58, 32, 116, 101, 115, 116, 95, 100,
  101, 115, 115, 105, 110, 95, 112, 101, 105, 110, 116, 117, 114, 101, 44, 32,
  116, 101, 115, 116, 95, 100, 101, 115, 115, 105, 110, 95, 112, 101, 105, 110,
  116, 117, 114, 101, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 78, 101, 116,
  116, 101, 116, 92, 51, 48, 51, 92, 50, 53, 49, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  101, 116, 116, 101, 116, 92, 51, 48, 51, 92, 50, 53, 49, 32, 61, 32,
  105, 110, 116, 40, 49, 55, 48, 44, 48, 44, 52, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 92, 51, 48, 51, 92, 50, 53,
  49, 116, 97, 105, 108, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 46,
  49, 53, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 82, 101, 115, 105, 122, 101, 32, 119, 105, 100, 116, 104, 32, 52, 48,
  48, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32,
  116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70,
  117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58,
  32, 60, 105, 62, 83, 97, 109, 106, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 49, 55,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  116, 101, 115, 116, 95, 100, 101, 115, 115, 105, 110, 95, 112, 101, 105, 110,
  116, 117, 114, 101, 32, 58, 10, 110, 101, 116, 116, 101, 116, 101, 61, 36,
  49, 10, 100, 101, 116, 97, 105, 108, 61, 36, 50, 10, 82, 101, 100, 117,
  105, 114, 101, 61, 36, 51, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 114, 101, 109, 111, 118, 101,
  95, 111, 112, 97, 99, 105, 116, 121, 91, 45, 49, 93, 10, 45, 105, 102,
  32, 123, 36, 82, 101, 100, 117, 105, 114, 101, 61, 61, 49, 125, 10, 45,
  114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 52, 48, 48, 44, 123,
  123, 104, 125, 47, 123, 119, 125, 42, 52, 48, 48, 125, 44, 49, 44, 51,
  44, 51, 10, 45, 101, 110, 100, 105, 102, 10, 110, 101, 116, 116, 101, 116,
  101, 61, 123, 36, 110, 101, 116, 116, 101, 116, 101, 43, 49, 48, 125, 10,
  110, 101, 116, 116, 101, 116, 101, 49, 61, 123, 36, 110, 101, 116, 116, 101,
  116, 101, 47, 49, 48, 48, 48, 125, 10, 110, 101, 116, 116, 101, 116, 101,
  49, 61, 123, 36, 110, 101, 116, 116, 101, 116, 101, 49, 43, 48, 46, 56,
  125, 10, 110, 101, 116, 116, 101, 116, 101, 50, 61, 123, 36, 110, 101, 116,
  116, 101, 116, 101, 47, 50, 125, 10, 110, 101, 116, 116, 101, 116, 101, 51,
  61, 123, 36, 110, 101, 116, 116, 101, 116, 101, 47, 52, 125, 10, 110, 101,
  116, 116, 101, 116, 101, 51, 61, 123, 36, 110, 101, 116, 116, 101, 116, 101,
  51, 43, 49, 48, 125, 10, 45, 103, 105, 109, 112, 95, 97, 110, 105, 115,
  111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105, 110,
  103, 91, 45, 49, 93, 32, 56, 48, 44, 36, 110, 101, 116, 116, 101, 116,
  101, 49, 44, 48, 46, 51, 44, 48, 46, 54, 44, 49, 46, 49, 44, 48,
  46, 56, 44, 51, 48, 44, 50, 44, 48, 44, 49, 44, 53, 44, 49, 44,
  49, 10, 45, 110, 91, 45, 49, 93, 32, 49, 50, 55, 44, 50, 53, 53,
  10, 45, 115, 104, 97, 114, 112, 101, 110, 91, 45, 49, 93, 32, 36, 110,
  101, 116, 116, 101, 116, 101, 50, 10, 45, 99, 97, 114, 116, 111, 111, 110,
  91, 45, 49, 93, 32, 36, 100, 101, 116, 97, 105, 108, 44, 36, 110, 101,
  116, 116, 101, 116, 101, 51, 44, 51, 48, 44, 48, 46, 49, 56, 44, 48,
  46, 55, 53, 44, 50, 53, 54, 10, 45, 115, 104, 97, 114, 112, 101, 110,
  91, 45, 49, 93, 32, 36, 110, 101, 116, 116, 101, 116, 101, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 116, 101, 115, 116, 95, 100,
  101, 115, 115, 105, 110, 95, 112, 101, 105, 110, 116, 117, 114, 101, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115,
  112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 116,
  101, 115, 116, 95, 100, 101, 115, 115, 105, 110, 95, 112, 101, 105, 110, 116,
  117, 114, 101, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 84, 101, 115, 116, 32, 119, 97, 116,
  101, 114, 99, 111, 108, 111, 114, 32, 58, 32, 84, 101, 115, 116, 95, 87,
  97, 116, 101, 114, 99, 111, 108, 111, 114, 95, 115, 97, 109, 106, 44, 32,
  84, 101, 115, 116, 95, 87, 97, 116, 101, 114, 99, 111, 108, 111, 114, 95,
  115, 97, 109, 106, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 73, 110,
  115, 112, 105, 114, 97, 116, 105, 111, 110, 32, 58, 32, 67, 114, 101, 97,
  116, 101, 32, 97, 32, 99, 111, 108, 111, 114, 102, 117, 108, 32, 119, 97,
  116, 101, 114, 99, 111, 108, 111, 114, 32, 112, 111, 114, 116, 114, 97, 105,
  116, 32, 119, 105, 116, 104, 32, 71, 73, 77, 80, 32, 71, 77, 73, 67,
  32, 66, 121, 32, 67, 104, 114, 105, 115, 32, 70, 105, 101, 100, 108, 101,
  114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 104, 116, 116, 112, 58, 47,
  47, 119, 119, 119, 46, 121, 111, 117, 116, 117, 98, 101, 46, 99, 111, 109,
  47, 119, 97, 116, 99, 104, 63, 118, 61, 122, 120, 68, 72, 82, 45, 99,
  119, 121, 53, 107, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 115, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111,
  117, 110, 100, 61, 34, 114, 101, 100, 34, 62, 67, 111, 117, 108, 101, 117,
  114, 115, 32, 65, 106, 111, 117, 116, 92, 51, 48, 51, 92, 50, 53, 49,
  101, 115, 32, 47, 32, 65, 100, 100, 101, 100, 32, 67, 111, 108, 111, 114,
  115, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114,
  111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34,
  62, 60, 115, 109, 97, 108, 108, 62, 67, 111, 108, 111, 114, 105, 115, 97,
  116, 105, 111, 110, 32, 47, 32, 67, 111, 108, 111, 114, 105, 122, 97, 116,
  105, 111, 110, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97,
  110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 121,
  112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 83,
  97, 110, 115, 47, 87, 105, 116, 104, 111, 117, 116, 32, 67, 111, 108, 111,
  114, 105, 115, 97, 116, 105, 111, 110, 34, 44, 34, 65, 118, 101, 99, 47,
  87, 105, 116, 104, 32, 67, 111, 108, 111, 114, 105, 115, 97, 116, 105, 111,
  110, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108,
  111, 114, 105, 115, 97, 116, 105, 111, 110, 32, 61, 32, 99, 111, 108, 111,
  114, 40, 50, 51, 54, 44, 50, 51, 54, 44, 51, 50, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 105, 118, 101, 97, 117, 47, 105, 110,
  116, 101, 110, 115, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 56, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117,
  110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60,
  115, 109, 97, 108, 108, 62, 80, 108, 97, 115, 109, 97, 32, 118, 115, 32,
  71, 114, 97, 100, 105, 101, 110, 116, 60, 47, 115, 109, 97, 108, 108, 62,
  60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 104, 111, 105, 120, 47, 99, 104, 111, 105, 99, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 83, 97, 110, 115,
  47, 87, 105, 116, 104, 111, 117, 116, 34, 44, 34, 80, 108, 97, 115, 109,
  97, 34, 44, 34, 52, 32, 67, 111, 108, 111, 114, 115, 32, 45, 32, 71,
  114, 97, 100, 105, 101, 110, 116, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 114, 109, 97, 108, 105, 122, 101, 32, 112, 108, 97,
  115, 109, 97, 32, 61, 32, 105, 110, 116, 40, 51, 50, 44, 48, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 105,
  110, 47, 99, 111, 114, 110, 101, 114, 32, 49, 32, 103, 114, 97, 100, 105,
  101, 110, 116, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44,
  50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 105, 110, 47, 99, 111, 114, 110, 101, 114, 32,
  50, 32, 103, 114, 97, 100, 105, 101, 110, 116, 32, 61, 32, 99, 111, 108,
  111, 114, 40, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 105, 110, 47, 99, 111,
  114, 110, 101, 114, 32, 51, 32, 103, 114, 97, 100, 105, 101, 110, 116, 32,
  61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 48, 44, 48, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111,
  105, 110, 47, 99, 111, 114, 110, 101, 114, 32, 52, 32, 103, 114, 97, 100,
  105, 101, 110, 116, 32, 61, 32, 99, 111, 108, 111, 114, 40, 48, 44, 50,
  53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111,
  117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62,
  60, 115, 109, 97, 108, 108, 62, 84, 97, 99, 104, 101, 115, 32, 102, 111,
  110, 99, 92, 51, 48, 51, 92, 50, 53, 49, 101, 115, 32, 47, 32, 68,
  97, 114, 107, 32, 83, 112, 111, 116, 115, 60, 47, 115, 109, 97, 108, 108,
  62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 106, 111, 117, 116, 101, 114, 47, 97, 100, 100, 32,
  61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 50, 46, 55, 53, 44, 48, 44, 54, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 117, 105, 108, 32,
  47, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 105, 110,
  116, 40, 52, 48, 44, 49, 48, 44, 50, 53, 54, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 101, 102, 111, 114, 109, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 49, 44, 48, 44, 51, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 117, 114, 102, 97, 99, 101, 32, 97,
  118, 101, 99, 32, 116, 97, 99, 104, 101, 115, 47, 119, 105, 116, 104, 32,
  115, 112, 111, 116, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 44,
  49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70,
  108, 111, 117, 47, 98, 108, 117, 114, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 46, 54, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 66, 108, 101, 110, 100, 32, 111, 112, 97, 99, 105, 116,
  92, 51, 48, 51, 92, 50, 53, 49, 32, 47, 32, 111, 112, 97, 99, 105,
  116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 48, 55, 44,
  48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34,
  111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108,
  108, 62, 83, 97, 110, 115, 32, 67, 111, 117, 108, 101, 117, 114, 115, 32,
  79, 114, 105, 103, 105, 110, 101, 32, 47, 32, 87, 105, 116, 104, 111, 117,
  116, 32, 67, 111, 108, 111, 114, 115, 32, 111, 102, 32, 79, 114, 105, 103,
  105, 110, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 117, 112,
  112, 114, 105, 109, 101, 114, 32, 99, 111, 117, 108, 101, 117, 114, 115, 32,
  111, 114, 105, 103, 105, 110, 101, 47, 100, 101, 108, 101, 116, 101, 32, 111,
  114, 105, 103, 105, 110, 97, 108, 32, 99, 111, 108, 111, 114, 115, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 115, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103,
  114, 111, 117, 110, 100, 61, 34, 114, 101, 100, 34, 62, 83, 101, 103, 109,
  101, 110, 116, 97, 116, 105, 111, 110, 60, 47, 115, 112, 97, 110, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101, 32,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 91, 115, 101, 103, 109, 101,
  110, 116, 97, 116, 105, 111, 110, 93, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 46, 48, 48, 44, 48, 44, 49, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  91, 115, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111, 110, 93, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 51, 46, 56, 48, 44, 48, 44, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101, 32, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 32, 91, 115, 101, 103, 109, 101, 110,
  116, 97, 116, 105, 111, 110, 32, 50, 93, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 51, 46, 51, 55, 44, 48, 44, 49, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  32, 91, 115, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111, 110, 32, 50,
  93, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 56, 57, 44, 48,
  44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 101,
  110, 100, 32, 49, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53,
  44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 115, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117,
  110, 100, 61, 34, 114, 101, 100, 34, 62, 69, 100, 103, 101, 115, 60, 47,
  115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 91, 101, 100, 103,
  101, 115, 93, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  48, 46, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104,
  114, 101, 115, 104, 111, 108, 100, 32, 91, 101, 100, 103, 101, 115, 93, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 54, 46, 54, 44, 48, 44, 53, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 101, 110, 100,
  32, 50, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 45, 49, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 115,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61,
  34, 114, 101, 100, 34, 62, 67, 111, 110, 116, 111, 117, 114, 115, 60, 47,
  115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 84, 121, 112, 101, 32, 99, 111, 110, 116, 111, 117, 114, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 51, 44, 34, 83, 97, 110, 115, 47, 87,
  105, 116, 104, 111, 117, 116, 32, 67, 111, 110, 116, 111, 117, 114, 34, 44,
  34, 69, 108, 108, 105, 112, 115, 101, 34, 44, 34, 69, 108, 108, 105, 112,
  115, 101, 43, 68, 101, 102, 111, 114, 109, 34, 44, 34, 69, 108, 108, 105,
  112, 115, 101, 43, 68, 101, 102, 111, 114, 109, 43, 83, 112, 114, 101, 97,
  100, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110,
  116, 111, 117, 114, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46,
  48, 48, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 115, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114,
  111, 117, 110, 100, 61, 34, 114, 101, 100, 34, 62, 84, 101, 120, 116, 117,
  114, 101, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61,
  32, 105, 110, 116, 40, 49, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 70, 105, 98, 114, 111, 117, 115, 110,
  101, 115, 115, 32, 61, 32, 105, 110, 116, 40, 50, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 109, 98, 111,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 51, 44, 48,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 66, 108, 101, 110, 100, 32, 111, 118, 101, 114, 108, 97,
  121, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 50, 55, 44, 34, 65, 100, 100, 34, 44, 34, 65, 108, 112,
  104, 97, 34, 44, 34, 65, 110, 100, 34, 44, 34, 65, 118, 101, 114, 97,
  103, 101, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 66, 117, 114, 110,
  34, 44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 68, 105, 102, 102,
  101, 114, 101, 110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 34, 68, 105, 118, 105, 100, 101, 34, 44, 34, 68, 111, 100, 103,
  101, 34, 44, 34, 69, 120, 99, 108, 117, 115, 105, 111, 110, 34, 44, 34,
  70, 114, 101, 101, 122, 101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 101,
  120, 116, 114, 97, 99, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 109,
  101, 114, 103, 101, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 72,
  97, 114, 100, 32, 108, 105, 103, 104, 116, 34, 44, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44,
  34, 72, 117, 101, 34, 44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97,
  116, 105, 111, 110, 34, 44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44,
  34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110,
  101, 97, 114, 32, 98, 117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97,
  114, 32, 108, 105, 103, 104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34,
  77, 117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 78, 101, 103, 97, 116,
  105, 111, 110, 34, 44, 34, 79, 114, 34, 44, 34, 79, 118, 101, 114, 108,
  97, 121, 34, 44, 34, 80, 105, 110, 32, 108, 105, 103, 104, 116, 34, 44,
  34, 82, 101, 100, 34, 44, 34, 82, 101, 102, 108, 101, 99, 116, 34, 44,
  34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 34, 83, 104, 97, 112, 101, 32, 65, 118,
  101, 114, 97, 103, 101, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118,
  101, 114, 97, 103, 101, 48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117,
  114, 110, 34, 44, 34, 83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34,
  44, 34, 83, 111, 102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83,
  99, 114, 101, 101, 110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34,
  83, 117, 98, 116, 114, 97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101,
  34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 86, 105, 118,
  105, 100, 32, 108, 105, 103, 104, 116, 34, 44, 34, 88, 111, 114, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116,
  121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116,
  32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 101, 117, 114, 115,
  32, 47, 32, 65, 117, 116, 104, 111, 114, 115, 32, 58, 32, 60, 105, 62,
  83, 97, 109, 106, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60,
  105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 49, 55, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 84, 101, 115, 116,
  95, 87, 97, 116, 101, 114, 99, 111, 108, 111, 114, 95, 115, 97, 109, 106,
  32, 58, 10, 84, 121, 112, 101, 61, 36, 49, 10, 82, 95, 67, 111, 108,
  111, 114, 95, 84, 121, 112, 101, 95, 50, 61, 36, 50, 10, 86, 95, 67,
  111, 108, 111, 114, 95, 84, 121, 112, 101, 95, 50, 61, 36, 51, 10, 66,
  95, 67, 111, 108, 111, 114, 95, 84, 121, 112, 101, 95, 50, 61, 36, 52,
  10, 67, 111, 108, 111, 114, 95, 73, 110, 116, 101, 110, 115, 105, 116, 121,
  61, 36, 53, 10, 80, 108, 97, 115, 109, 97, 95, 71, 114, 97, 100, 105,
  101, 110, 116, 61, 36, 54, 10, 78, 111, 114, 109, 97, 108, 105, 122, 101,
  95, 80, 108, 97, 115, 109, 97, 61, 36, 55, 10, 82, 95, 67, 111, 105,
  110, 95, 49, 61, 36, 56, 10, 86, 95, 67, 111, 105, 110, 95, 49, 61,
  36, 57, 10, 66, 95, 67, 111, 105, 110, 95, 49, 61, 36, 49, 48, 10,
  65, 95, 67, 111, 105, 110, 95, 49, 61, 36, 49, 49, 10, 82, 95, 67,
  111, 105, 110, 95, 50, 61, 36, 49, 50, 10, 86, 95, 67, 111, 105, 110,
  95, 50, 61, 36, 49, 51, 10, 66, 95, 67, 111, 105, 110, 95, 50, 61,
  36, 49, 52, 10, 65, 95, 67, 111, 105, 110, 95, 50, 61, 36, 49, 53,
  10, 82, 95, 67, 111, 105, 110, 95, 51, 61, 36, 49, 54, 10, 86, 95,
  67, 111, 105, 110, 95, 51, 61, 36, 49, 55, 10, 66, 95, 67, 111, 105,
  110, 95, 51, 61, 36, 49, 56, 10, 65, 95, 67, 111, 105, 110, 95, 51,
  61, 36, 49, 57, 10, 82, 95, 67, 111, 105, 110, 95, 52, 61, 36, 50,
  48, 10, 86, 95, 67, 111, 105, 110, 95, 52, 61, 36, 50, 49, 10, 66,
  95, 67, 111, 105, 110, 95, 52, 61, 36, 50, 50, 10, 65, 95, 67, 111,
  105, 110, 95, 52, 61, 36, 50, 51, 10, 65, 106, 111, 117, 116, 101, 114,
  95, 84, 97, 99, 104, 101, 115, 61, 36, 50, 52, 10, 70, 108, 111, 117,
  95, 84, 97, 99, 104, 101, 115, 61, 36, 50, 53, 10, 79, 116, 115, 117,
  95, 116, 97, 99, 104, 101, 115, 61, 36, 50, 54, 10, 68, 101, 102, 111,
  114, 109, 97, 116, 105, 111, 110, 95, 84, 97, 99, 104, 101, 115, 61, 36,
  50, 55, 10, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 83, 97, 110,
  115, 95, 84, 97, 99, 104, 101, 61, 36, 50, 56, 10, 70, 108, 111, 117,
  95, 116, 97, 99, 104, 101, 61, 36, 50, 57, 10, 77, 95, 66, 108, 101,
  110, 100, 95, 79, 112, 97, 99, 105, 116, 101, 61, 36, 51, 48, 10, 83,
  117, 112, 112, 114, 105, 109, 101, 114, 95, 99, 111, 117, 108, 101, 117, 114,
  115, 95, 111, 114, 105, 103, 105, 110, 101, 61, 36, 51, 49, 10, 69, 100,
  103, 101, 95, 116, 104, 114, 101, 115, 104, 111, 108, 100, 95, 83, 101, 103,
  109, 101, 110, 116, 97, 116, 105, 111, 110, 61, 36, 51, 50, 10, 83, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 95, 83, 101, 103, 109, 101, 110, 116,
  97, 116, 105, 111, 110, 61, 36, 51, 51, 10, 66, 95, 69, 100, 103, 101,
  95, 116, 104, 114, 101, 115, 104, 111, 108, 100, 95, 83, 101, 103, 109, 101,
  110, 116, 97, 116, 105, 111, 110, 61, 36, 51, 52, 10, 66, 95, 83, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 95, 83, 101, 103, 109, 101, 110, 116,
  97, 116, 105, 111, 110, 61, 36, 51, 53, 10, 66, 108, 101, 110, 100, 95,
  65, 61, 36, 51, 54, 10, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  95, 69, 100, 103, 101, 115, 61, 36, 51, 55, 10, 84, 104, 114, 101, 115,
  104, 111, 108, 100, 95, 69, 100, 103, 101, 115, 61, 36, 51, 56, 10, 66,
  108, 101, 110, 100, 95, 66, 61, 36, 51, 57, 10, 84, 121, 112, 101, 95,
  67, 111, 110, 116, 111, 117, 114, 61, 36, 52, 48, 10, 67, 111, 110, 116,
  111, 117, 114, 115, 61, 36, 52, 49, 10, 78, 105, 118, 101, 97, 117, 95,
  116, 101, 120, 116, 117, 114, 101, 61, 36, 52, 50, 10, 70, 105, 98, 114,
  111, 117, 115, 110, 101, 115, 115, 95, 116, 101, 120, 116, 117, 114, 101, 61,
  36, 52, 51, 10, 69, 109, 98, 111, 115, 115, 95, 116, 101, 120, 116, 117,
  114, 101, 61, 36, 52, 52, 10, 98, 108, 101, 110, 100, 61, 36, 52, 53,
  10, 111, 112, 97, 99, 105, 116, 101, 61, 36, 52, 54, 10, 82, 101, 118,
  101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 61, 36, 52, 55, 10, 76,
  97, 114, 103, 101, 117, 114, 61, 123, 119, 125, 10, 72, 97, 117, 116, 101,
  117, 114, 61, 123, 104, 125, 10, 45, 105, 102, 32, 123, 36, 83, 117, 112,
  112, 114, 105, 109, 101, 114, 95, 99, 111, 117, 108, 101, 117, 114, 115, 95,
  111, 114, 105, 103, 105, 110, 101, 61, 61, 49, 125, 10, 45, 116, 111, 95,
  114, 103, 98, 32, 45, 103, 105, 109, 112, 95, 100, 101, 99, 111, 109, 112,
  111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93,
  32, 52, 44, 48, 44, 49, 44, 48, 32, 45, 114, 101, 109, 111, 118, 101,
  91, 45, 49, 44, 45, 50, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 84, 121, 112, 101, 61, 61, 49, 125, 10, 45, 116,
  111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 10, 36, 76, 97, 114, 103,
  101, 117, 114, 44, 36, 72, 97, 117, 116, 101, 117, 114, 44, 49, 44, 51,
  10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93,
  32, 36, 82, 95, 67, 111, 108, 111, 114, 95, 84, 121, 112, 101, 95, 50,
  44, 36, 86, 95, 67, 111, 108, 111, 114, 95, 84, 121, 112, 101, 95, 50,
  44, 36, 66, 95, 67, 111, 108, 111, 114, 95, 84, 121, 112, 101, 95, 50,
  10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44,
  45, 50, 93, 32, 51, 44, 36, 67, 111, 108, 111, 114, 95, 73, 110, 116,
  101, 110, 115, 105, 116, 121, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10,
  35, 32, 97, 100, 111, 117, 99, 105, 114, 10, 45, 103, 105, 109, 112, 95,
  98, 105, 108, 97, 116, 101, 114, 97, 108, 91, 45, 49, 93, 32, 49, 48,
  44, 55, 44, 50, 44, 48, 10, 35, 32, 109, -23, 108, 97, 110, 103, 101,
  114, 32, 50, 32, 103, 105, 109, 112, 95, 115, 101, 103, 109, 101, 110, 116,
  95, 119, 97, 116, 101, 114, 115, 104, 101, 100, 32, 101, 116, 32, 111, 98,
  116, 101, 110, 105, 114, 32, 50, 32, 105, 109, 97, 103, 101, 115, 10, 45,
  45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103,
  91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 115, 101, 103, 109, 101,
  110, 116, 95, 119, 97, 116, 101, 114, 115, 104, 101, 100, 91, 45, 49, 93,
  32, 36, 69, 100, 103, 101, 95, 116, 104, 114, 101, 115, 104, 111, 108, 100,
  95, 83, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111, 110, 44, 36, 83,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 95, 83, 101, 103, 109, 101, 110,
  116, 97, 116, 105, 111, 110, 44, 48, 10, 45, 100, 101, 102, 111, 114, 109,
  91, 45, 49, 93, 32, 49, 10, 45, 103, 105, 109, 112, 95, 115, 101, 103,
  109, 101, 110, 116, 95, 119, 97, 116, 101, 114, 115, 104, 101, 100, 91, 45,
  50, 93, 32, 36, 66, 95, 69, 100, 103, 101, 95, 116, 104, 114, 101, 115,
  104, 111, 108, 100, 95, 83, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111,
  110, 44, 36, 66, 95, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 95,
  83, 101, 103, 109, 101, 110, 116, 97, 116, 105, 111, 110, 44, 48, 10, 35,
  97, 118, 101, 114, 97, 103, 101, 10, 45, 103, 105, 109, 112, 95, 98, 108,
  101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 51, 44, 36, 66, 108,
  101, 110, 100, 95, 65, 44, 49, 10, 45, 45, 103, 105, 109, 112, 95, 100,
  111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 35, 32,
  99, 114, -23, 101, 114, 32, 100, 101, 115, 32, 99, 111, 110, 116, 111, 117,
  114, 115, 32, 98, 108, 97, 110, 99, 115, 32, 111, 117, 32, 110, 111, 105,
  114, 115, 10, 45, 103, 105, 109, 112, 95, 101, 100, 103, 101, 115, 91, 45,
  49, 93, 32, 36, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 95, 69,
  100, 103, 101, 115, 44, 36, 84, 104, 114, 101, 115, 104, 111, 108, 100, 95,
  69, 100, 103, 101, 115, 44, 48, 10, 45, 105, 102, 32, 123, 36, 66, 108,
  101, 110, 100, 95, 66, 62, 48, 125, 10, 45, 103, 105, 109, 112, 95, 98,
  108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 56, 44, 36, 66,
  108, 101, 110, 100, 95, 66, 44, 49, 10, 45, 101, 108, 115, 101, 10, 45,
  103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50,
  93, 32, 56, 44, 123, 49, 43, 36, 66, 108, 101, 110, 100, 95, 66, 125,
  44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 35, 32, 99, 114, -23, 101,
  114, 32, 117, 110, 32, 109, 97, 115, 113, 117, 101, 32, 112, 111, 117, 114,
  32, 103, 97, 114, 100, 101, 114, 32, 108, 101, 32, 99, 101, 110, 116, 114,
  101, 32, 101, 116, 32, 100, 111, 110, 110, 101, 114, 32, 117, 110, 101, 32,
  116, 101, 120, 116, 117, 114, 101, 10, 45, 105, 102, 32, 123, 123, 36, 84,
  121, 112, 101, 95, 67, 111, 110, 116, 111, 117, 114, 61, 61, 49, 125, 124,
  124, 123, 36, 84, 121, 112, 101, 95, 67, 111, 110, 116, 111, 117, 114, 61,
  61, 50, 125, 124, 124, 123, 36, 84, 121, 112, 101, 95, 67, 111, 110, 116,
  111, 117, 114, 61, 61, 51, 125, 125, 10, 36, 76, 97, 114, 103, 101, 117,
  114, 44, 36, 72, 97, 117, 116, 101, 117, 114, 44, 49, 44, 52, 10, 45,
  101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 123, 36, 76, 97,
  114, 103, 101, 117, 114, 47, 50, 125, 44, 123, 36, 72, 97, 117, 116, 101,
  117, 114, 47, 50, 125, 44, 123, 36, 76, 97, 114, 103, 101, 117, 114, 47,
  50, 46, 50, 125, 44, 123, 36, 72, 97, 117, 116, 101, 117, 114, 47, 50,
  46, 50, 125, 44, 48, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123, 123, 36, 84,
  121, 112, 101, 95, 67, 111, 110, 116, 111, 117, 114, 61, 61, 50, 125, 124,
  124, 123, 36, 84, 121, 112, 101, 95, 67, 111, 110, 116, 111, 117, 114, 61,
  61, 51, 125, 125, 10, 45, 100, 101, 102, 111, 114, 109, 91, 45, 49, 93,
  32, 123, 123, 114, 111, 117, 110, 100, 40, 123, 123, 36, 76, 97, 114, 103,
  101, 117, 114, 43, 36, 72, 97, 117, 116, 101, 117, 114, 125, 47, 53, 48,
  125, 41, 125, 42, 36, 67, 111, 110, 116, 111, 117, 114, 115, 125, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84, 121, 112, 101,
  95, 67, 111, 110, 116, 111, 117, 114, 61, 61, 51, 125, 10, 45, 115, 112,
  114, 101, 97, 100, 91, 45, 49, 93, 32, 123, 123, 114, 111, 117, 110, 100,
  40, 123, 123, 36, 76, 97, 114, 103, 101, 117, 114, 43, 36, 72, 97, 117,
  116, 101, 117, 114, 125, 47, 49, 48, 48, 125, 41, 125, 42, 36, 67, 111,
  110, 116, 111, 117, 114, 115, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  102, 105, 115, 104, 101, 121, 101, 91, 45, 49, 93, 32, 123, 36, 76, 97,
  114, 103, 101, 117, 114, 47, 50, 125, 44, 123, 36, 72, 97, 117, 116, 101,
  117, 114, 47, 50, 125, 44, 49, 48, 48, 44, 50, 10, 45, 103, 105, 109,
  112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 56,
  44, 49, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 116, 101, 120,
  116, 117, 114, 105, 122, 101, 95, 99, 97, 110, 118, 97, 115, 91, 45, 49,
  93, 32, 36, 78, 105, 118, 101, 97, 117, 95, 116, 101, 120, 116, 117, 114,
  101, 44, 36, 70, 105, 98, 114, 111, 117, 115, 110, 101, 115, 115, 95, 116,
  101, 120, 116, 117, 114, 101, 44, 36, 69, 109, 98, 111, 115, 115, 95, 116,
  101, 120, 116, 117, 114, 101, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111,
  95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 35, 32, 99,
  114, -23, 101, 114, 32, 100, 101, 115, 32, 102, 97, 117, 115, 115, 101, 115,
  32, 99, 111, 117, 108, 101, 117, 114, 115, 10, 45, 105, 102, 32, 123, 36,
  80, 108, 97, 115, 109, 97, 95, 71, 114, 97, 100, 105, 101, 110, 116, 61,
  61, 49, 125, 10, 36, 76, 97, 114, 103, 101, 117, 114, 44, 36, 72, 97,
  117, 116, 101, 117, 114, 44, 49, 44, 52, 10, 45, 112, 108, 97, 115, 109,
  97, 91, 45, 49, 93, 32, 49, 48, 44, 51, 10, 36, 76, 97, 114, 103,
  101, 117, 114, 44, 36, 72, 97, 117, 116, 101, 117, 114, 44, 49, 44, 52,
  10, 45, 112, 108, 97, 115, 109, 97, 91, 45, 49, 93, 32, 49, 48, 44,
  51, 10, 45, 43, 91, 45, 49, 44, 45, 50, 93, 10, 45, 98, 108, 117,
  114, 91, 45, 49, 93, 32, 123, 123, 114, 111, 117, 110, 100, 40, 123, 123,
  36, 76, 97, 114, 103, 101, 117, 114, 43, 36, 72, 97, 117, 116, 101, 117,
  114, 125, 47, 49, 48, 48, 125, 41, 125, 43, 50, 125, 10, 45, 110, 91,
  45, 49, 93, 32, 36, 78, 111, 114, 109, 97, 108, 105, 122, 101, 95, 80,
  108, 97, 115, 109, 97, 44, 50, 53, 53, 10, 45, 114, 101, 118, 101, 114,
  115, 101, 91, 45, 49, 44, 45, 50, 93, 10, 45, 103, 105, 109, 112, 95,
  100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101,
  108, 115, 91, 45, 49, 44, 45, 50, 93, 32, 50, 44, 48, 44, 49, 44,
  48, 32, 45, 114, 101, 109, 111, 118, 101, 91, 45, 50, 44, 45, 51, 44,
  45, 52, 93, 32, 45, 103, 105, 109, 112, 95, 100, 101, 99, 111, 109, 112,
  111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 44,
  45, 50, 44, 45, 51, 93, 32, 50, 44, 49, 44, 49, 44, 48, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 80, 108, 97, 115,
  109, 97, 95, 71, 114, 97, 100, 105, 101, 110, 116, 61, 61, 50, 125, 10,
  36, 76, 97, 114, 103, 101, 117, 114, 44, 36, 72, 97, 117, 116, 101, 117,
  114, 44, 49, 44, 52, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111,
  114, 91, 45, 49, 93, 32, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 10, 45, 103, 105, 109, 112, 95, 99, 111, 114, 110,
  101, 114, 95, 103, 114, 97, 100, 105, 101, 110, 116, 91, 45, 49, 93, 32,
  36, 82, 95, 67, 111, 105, 110, 95, 49, 44, 36, 86, 95, 67, 111, 105,
  110, 95, 49, 44, 36, 66, 95, 67, 111, 105, 110, 95, 49, 44, 36, 65,
  95, 67, 111, 105, 110, 95, 49, 44, 36, 82, 95, 67, 111, 105, 110, 95,
  50, 44, 36, 86, 95, 67, 111, 105, 110, 95, 50, 44, 36, 66, 95, 67,
  111, 105, 110, 95, 50, 44, 36, 65, 95, 67, 111, 105, 110, 95, 50, 44,
  36, 82, 95, 67, 111, 105, 110, 95, 51, 44, 36, 86, 95, 67, 111, 105,
  110, 95, 51, 44, 36, 66, 95, 67, 111, 105, 110, 95, 51, 44, 36, 65,
  95, 67, 111, 105, 110, 95, 51, 44, 36, 82, 95, 67, 111, 105, 110, 95,
  52, 44, 36, 86, 95, 67, 111, 105, 110, 95, 52, 44, 36, 66, 95, 67,
  111, 105, 110, 95, 52, 44, 36, 65, 95, 67, 111, 105, 110, 95, 52, 10,
  45, 114, 101, 118, 101, 114, 115, 101, 91, 45, 49, 44, 45, 50, 93, 10,
  45, 103, 105, 109, 112, 95, 100, 101, 99, 111, 109, 112, 111, 115, 101, 95,
  99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 44, 45, 50, 93, 32,
  50, 44, 48, 44, 49, 44, 48, 32, 45, 114, 101, 109, 111, 118, 101, 91,
  45, 50, 44, 45, 51, 44, 45, 52, 93, 32, 45, 103, 105, 109, 112, 95,
  100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101,
  108, 115, 91, 45, 49, 44, 45, 50, 44, 45, 51, 93, 32, 50, 44, 49,
  44, 49, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 65, 106, 111, 117, 116, 101, 114, 95, 84, 97, 99, 104, 101, 115,
  61, 61, 49, 125, 10, 36, 76, 97, 114, 103, 101, 117, 114, 44, 36, 72,
  97, 117, 116, 101, 117, 114, 44, 49, 44, 52, 10, 45, 114, 97, 110, 100,
  91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 98, 108, 117, 114,
  91, 45, 49, 93, 32, 36, 70, 108, 111, 117, 95, 84, 97, 99, 104, 101,
  115, 32, 45, 111, 116, 115, 117, 91, 45, 49, 93, 32, 36, 79, 116, 115,
  117, 95, 116, 97, 99, 104, 101, 115, 32, 45, 110, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45,
  49, 93, 32, 123, 36, 76, 97, 114, 103, 101, 117, 114, 47, 50, 125, 44,
  123, 36, 72, 97, 117, 116, 101, 117, 114, 47, 50, 125, 44, 123, 36, 76,
  97, 114, 103, 101, 117, 114, 47, 36, 68, 105, 109, 101, 110, 115, 105, 111,
  110, 95, 83, 97, 110, 115, 95, 84, 97, 99, 104, 101, 125, 44, 123, 36,
  72, 97, 117, 116, 101, 117, 114, 47, 36, 68, 105, 109, 101, 110, 115, 105,
  111, 110, 95, 83, 97, 110, 115, 95, 84, 97, 99, 104, 101, 125, 44, 48,
  44, 49, 44, 48, 44, 48, 44, 48, 44, 48, 48, 10, 45, 100, 101, 102,
  111, 114, 109, 91, 45, 49, 93, 32, 123, 123, 114, 111, 117, 110, 100, 40,
  123, 123, 36, 76, 97, 114, 103, 101, 117, 114, 43, 36, 72, 97, 117, 116,
  101, 117, 114, 125, 47, 53, 48, 125, 41, 125, 42, 36, 68, 101, 102, 111,
  114, 109, 97, 116, 105, 111, 110, 95, 84, 97, 99, 104, 101, 115, 125, 10,
  45, 116, 111, 95, 103, 114, 97, 121, 97, 91, 45, 49, 93, 10, 45, 116,
  111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 10, 45, 98, 108, 117, 114,
  91, 45, 49, 93, 32, 36, 70, 108, 111, 117, 95, 116, 97, 99, 104, 101,
  10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44,
  45, 50, 93, 32, 54, 44, 36, 77, 95, 66, 108, 101, 110, 100, 95, 79,
  112, 97, 99, 105, 116, 101, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45,
  50, 93, 32, 36, 98, 108, 101, 110, 100, 44, 36, 111, 112, 97, 99, 105,
  116, 101, 44, 36, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114,
  115, 10, 35, 64, 103, 105, 109, 112, 32, 95, 10, 35, 64, 103, 105, 109,
  112, 32, 60, 105, 62, 66, 108, 97, 99, 107, 32, 38, 97, 109, 112, 59,
  32, 119, 104, 105, 116, 101, 60, 47, 105, 62, 10, 35, 64, 103, 105, 109,
  112, 32, 67, 101, 107, 111, 97, 115, 97, 32, 48, 48, 54, 32, 58, 32,
  115, 97, 109, 106, 95, 67, 101, 75, 111, 97, 83, 97, 95, 48, 48, 54,
  44, 32, 115, 97, 109, 106, 95, 67, 101, 75, 111, 97, 83, 97, 95, 48,
  48, 54, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114,
  101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114,
  101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 77, 97, 114, 98, 108,
  101, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 109, 97, 103,
  101, 32, 119, 101, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 48, 53, 44, 48, 44, 51, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 80, 97, 116, 116, 101, 114, 110, 32, 119, 101, 105,
  103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 49, 44,
  48, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80,
  97, 116, 116, 101, 114, 110, 32, 97, 110, 103, 108, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 52, 53, 44, 48, 44, 51, 54, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97,
  114, 112, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  46, 52, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 65, 110, 105, 115, 111, 116, 114, 111, 112, 121, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 56, 44, 48, 44, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101,
  103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101,
  100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 68, 105, 102, 102, 101, 114,
  101, 110, 99, 101, 32, 111, 102, 32, 103, 97, 117, 115, 115, 105, 97, 110,
  115, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 49, 115, 116, 32,
  118, 97, 114, 105, 97, 110, 99, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 46, 52, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 50, 110, 100, 32, 118, 97, 114, 105, 97, 110, 99, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 53, 44, 48, 44, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104,
  111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  52, 57, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 101, 103,
  97, 116, 105, 118, 101, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32, 98,
  111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100,
  61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109,
  97, 108, 108, 62, 83, 116, 97, 109, 112, 60, 47, 115, 109, 97, 108, 108,
  62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 117, 116, 111, 45, 116, 104, 114, 101, 115, 104, 111,
  108, 100, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32,
  61, 32, 105, 110, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97,
  114, 112, 101, 110, 105, 110, 103, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 71, 114, 97, 105, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 73, 110, 118, 101, 114, 116, 32, 99, 111, 108, 111, 114, 115, 32, 61,
  32, 98, 111, 111, 108, 40, 102, 97, 108, 115, 101, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97, 109, 106, 32, 45, 32,
  76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32,
  60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 50, 50, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109,
  106, 95, 67, 101, 75, 111, 97, 83, 97, 95, 48, 48, 54, 32, 58, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 73, 109, 97, 103, 101, 95, 119, 101, 105, 103, 104, 116, 95, 109,
  97, 114, 98, 108, 101, 61, 36, 49, 10, 80, 97, 116, 116, 101, 114, 110,
  95, 119, 101, 105, 103, 104, 116, 95, 109, 97, 114, 98, 108, 101, 61, 36,
  50, 10, 80, 97, 116, 116, 101, 114, 110, 95, 97, 110, 103, 108, 101, 95,
  109, 97, 114, 98, 108, 101, 61, 36, 51, 10, 65, 109, 112, 108, 105, 116,
  117, 100, 101, 95, 109, 97, 114, 98, 108, 101, 61, 36, 52, 10, 83, 104,
  97, 114, 112, 110, 101, 115, 115, 95, 109, 97, 114, 98, 108, 101, 61, 36,
  53, 10, 65, 110, 105, 115, 111, 116, 114, 111, 112, 121, 95, 109, 97, 114,
  98, 108, 101, 61, 36, 54, 10, 65, 95, 118, 97, 114, 105, 97, 110, 99,
  101, 95, 68, 79, 71, 61, 36, 55, 10, 66, 95, 118, 97, 114, 105, 97,
  110, 99, 101, 95, 68, 79, 71, 61, 36, 56, 10, 84, 104, 114, 101, 115,
  104, 111, 108, 100, 95, 68, 79, 71, 61, 36, 57, 10, 78, 101, 103, 97,
  116, 105, 118, 101, 95, 99, 111, 108, 111, 114, 115, 95, 68, 79, 71, 61,
  36, 49, 48, 10, 65, 117, 116, 111, 95, 116, 104, 114, 101, 115, 104, 111,
  108, 100, 95, 83, 116, 97, 109, 112, 61, 36, 49, 49, 10, 84, 104, 114,
  101, 115, 104, 111, 108, 100, 95, 83, 116, 97, 109, 112, 61, 36, 49, 50,
  10, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 95, 83, 116, 97, 109,
  112, 61, 36, 49, 51, 10, 83, 104, 97, 114, 112, 101, 110, 105, 110, 103,
  95, 83, 116, 97, 109, 112, 61, 36, 49, 52, 10, 71, 114, 97, 105, 110,
  95, 83, 116, 97, 109, 112, 61, 36, 49, 53, 10, 73, 110, 118, 101, 114,
  116, 95, 99, 111, 108, 111, 114, 115, 95, 83, 116, 97, 109, 112, 61, 36,
  49, 54, 10, 45, 109, 97, 114, 98, 108, 101, 91, 45, 49, 93, 32, 36,
  73, 109, 97, 103, 101, 95, 119, 101, 105, 103, 104, 116, 95, 109, 97, 114,
  98, 108, 101, 44, 36, 80, 97, 116, 116, 101, 114, 110, 95, 119, 101, 105,
  103, 104, 116, 95, 109, 97, 114, 98, 108, 101, 44, 36, 80, 97, 116, 116,
  101, 114, 110, 95, 97, 110, 103, 108, 101, 95, 109, 97, 114, 98, 108, 101,
  44, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 95, 109, 97, 114, 98,
  108, 101, 44, 36, 83, 104, 97, 114, 112, 110, 101, 115, 115, 95, 109, 97,
  114, 98, 108, 101, 44, 36, 65, 110, 105, 115, 111, 116, 114, 111, 112, 121,
  95, 109, 97, 114, 98, 108, 101, 10, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 10, 45, 103, 105, 109, 112, 95, 100, 111, 103, 91, 45,
  49, 93, 32, 36, 65, 95, 118, 97, 114, 105, 97, 110, 99, 101, 95, 68,
  79, 71, 44, 36, 66, 95, 118, 97, 114, 105, 97, 110, 99, 101, 95, 68,
  79, 71, 44, 36, 84, 104, 114, 101, 115, 104, 111, 108, 100, 95, 68, 79,
  71, 44, 36, 78, 101, 103, 97, 116, 105, 118, 101, 95, 99, 111, 108, 111,
  114, 115, 95, 68, 79, 71, 10, 45, 103, 105, 109, 112, 95, 115, 116, 97,
  109, 112, 91, 45, 49, 93, 32, 36, 65, 117, 116, 111, 95, 116, 104, 114,
  101, 115, 104, 111, 108, 100, 95, 83, 116, 97, 109, 112, 44, 36, 84, 104,
  114, 101, 115, 104, 111, 108, 100, 95, 83, 116, 97, 109, 112, 44, 36, 83,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 95, 83, 116, 97, 109, 112, 44,
  36, 83, 104, 97, 114, 112, 101, 110, 105, 110, 103, 95, 83, 116, 97, 109,
  112, 44, 36, 71, 114, 97, 105, 110, 95, 83, 116, 97, 109, 112, 44, 36,
  73, 110, 118, 101, 114, 116, 95, 99, 111, 108, 111, 114, 115, 95, 83, 116,
  97, 109, 112, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  115, 97, 109, 106, 95, 67, 101, 75, 111, 97, 83, 97, 95, 48, 48, 54,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 115, 97, 109, 106, 95, 67, 101, 75, 111, 97, 83, 97, 95, 48, 48,
  54, 32, 36, 42, 34, 44, 36, 45, 49, 10, 115, 97, 109, 106, 95, 114,
  105, 101, 110, 95, 99, 111, 108, 111, 114, 115, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49,
  93, 10, 35, 64, 103, 105, 109, 112, 32, 71, 114, 105, 115, 32, 103, 114,
  101, 121, 32, 99, 97, 110, 97, 108, 32, 121, 32, 58, 32, 71, 114, 105,
  115, 95, 89, 95, 115, 97, 109, 106, 44, 32, 71, 114, 105, 115, 95, 89,
  95, 115, 97, 109, 106, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 67, 97, 110, 97,
  108, 32, 89, 32, 100, 101, 32, 89, 85, 86, 32, 32, 45, 32, 76, 117,
  109, 105, 110, 97, 110, 99, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34,
  104, 116, 116, 112, 58, 47, 47, 102, 114, 46, 119, 105, 107, 105, 112, 101,
  100, 105, 97, 46, 111, 114, 103, 47, 119, 105, 107, 105, 47, 89, 85, 86,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 108, 105, 110, 107, 40, 34, 104, 116, 116, 112, 58, 47, 47,
  101, 110, 46, 119, 105, 107, 105, 112, 101, 100, 105, 97, 46, 111, 114, 103,
  47, 119, 105, 107, 105, 47, 89, 85, 86, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 101, 117, 114, 115, 32, 47, 32, 65, 117, 116,
  104, 111, 114, 115, 32, 58, 32, 60, 105, 62, 83, 97, 109, 106, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51,
  47, 48, 49, 47, 48, 56, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 71, 114, 105, 115, 95, 89, 95, 115, 97, 109,
  106, 32, 58, 10, 45, 116, 111, 95, 114, 103, 98, 32, 45, 103, 105, 109,
  112, 95, 100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 91, 45, 49, 93, 32, 52, 44, 48, 44, 49, 44, 48,
  32, 45, 114, 101, 109, 111, 118, 101, 91, 45, 49, 44, 45, 50, 93, 10,
  35, 64, 103, 105, 109, 112, 32, 71, 114, 105, 122, 111, 117, 32, 58, 32,
  71, 114, 105, 122, 111, 117, 95, 115, 97, 109, 106, 44, 32, 71, 114, 105,
  122, 111, 117, 95, 115, 97, 109, 106, 95, 112, 114, 101, 118, 105, 101, 119,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 68, 92, 51, 48, 51, 92, 50, 53, 49, 99, 111, 109, 112, 111, 115,
  105, 116, 105, 111, 110, 47, 100, 101, 99, 111, 109, 112, 111, 115, 101, 32,
  99, 104, 97, 110, 110, 101, 108, 115, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 100, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 82, 86, 66,
  47, 82, 71, 66, 34, 44, 34, 88, 89, 90, 32, 56, 34, 44, 34, 72,
  83, 86, 32, 56, 32, 58, 32, 67, 97, 110, 97, 108, 47, 67, 104, 97,
  110, 110, 101, 108, 32, 86, 34, 44, 34, 72, 83, 76, 32, 56, 32, 58,
  32, 67, 97, 110, 97, 108, 47, 67, 104, 97, 110, 110, 101, 108, 32, 76,
  34, 44, 34, 72, 83, 73, 32, 56, 32, 58, 32, 67, 97, 110, 97, 108,
  47, 67, 104, 97, 110, 110, 101, 108, 32, 73, 34, 44, 34, 89, 85, 86,
  32, 56, 32, 58, 32, 67, 97, 110, 97, 108, 47, 67, 104, 97, 110, 110,
  101, 108, 32, 89, 34, 44, 34, 89, 67, 98, 67, 114, 32, 58, 32, 67,
  97, 110, 97, 108, 47, 67, 104, 97, 110, 110, 101, 108, 32, 89, 34, 44,
  34, 76, 97, 98, 32, 56, 32, 58, 32, 67, 97, 110, 97, 108, 47, 67,
  104, 97, 110, 110, 101, 108, 32, 76, 34, 44, 34, 76, 67, 72, 32, 56,
  32, 58, 32, 67, 97, 110, 97, 108, 47, 67, 104, 97, 110, 110, 101, 108,
  32, 76, 34, 44, 34, 67, 77, 89, 75, 32, 58, 32, 78, 101, 103, 97,
  116, 105, 102, 32, 67, 97, 110, 97, 108, 47, 67, 104, 97, 110, 110, 101,
  108, 32, 75, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 67, 97, 110, 97, 108, 45, 67, 104, 97, 110,
  110, 101, 108, 32, 58, 32, 82, 111, 117, 103, 101, 47, 82, 101, 100, 32,
  45, 32, 88, 32, 45, 32, 86, 32, 45, 32, 76, 32, 45, 32, 73, 32,
  45, 32, 89, 32, 45, 32, 75, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 116, 32, 118,
  97, 108, 101, 117, 114, 32, 49, 32, 61, 32, 105, 110, 116, 40, 48, 44,
  48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 117, 116, 32, 118, 97, 108, 101, 117, 114, 32, 50, 32, 61, 32, 105,
  110, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 114, 109, 97, 108, 105, 122, 101,
  32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  67, 97, 110, 97, 108, 45, 67, 104, 97, 110, 110, 101, 108, 32, 58, 32,
  86, 101, 114, 116, 47, 71, 114, 101, 101, 110, 32, 45, 32, 89, 91, 120,
  121, 122, 93, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 117, 116, 32, 118, 97, 108, 101, 117,
  114, 32, 49, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 116, 32,
  118, 97, 108, 101, 117, 114, 32, 50, 32, 61, 32, 105, 110, 116, 40, 50,
  53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 114, 109, 97, 108, 105, 122, 101, 32, 61, 32, 105,
  110, 116, 40, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 67, 97, 110, 97,
  108, 45, 67, 104, 97, 110, 110, 101, 108, 32, 58, 32, 66, 108, 101, 117,
  47, 66, 108, 117, 101, 32, 45, 32, 90, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 116,
  32, 118, 97, 108, 101, 117, 114, 32, 49, 32, 61, 32, 105, 110, 116, 40,
  48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 117, 116, 32, 118, 97, 108, 101, 117, 114, 32, 50, 32, 61,
  32, 105, 110, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 114, 109, 97, 108, 105,
  122, 101, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 82, 43, 86, 43, 66, 47, 82, 43, 71, 43, 66, 32, 45, 32,
  88, 43, 89, 43, 90, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 116, 32, 118, 97, 108,
  101, 117, 114, 32, 49, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44,
  55, 54, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117,
  116, 32, 118, 97, 108, 101, 117, 114, 32, 50, 32, 61, 32, 105, 110, 116,
  40, 55, 54, 53, 44, 48, 44, 55, 54, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 114, 109, 97, 108, 105, 122, 101, 32, 61,
  32, 105, 110, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117,
  108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 101, 117, 114, 115, 32, 47,
  32, 65, 117, 116, 104, 111, 114, 115, 32, 58, 32, 60, 105, 62, 83, 97,
  109, 106, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62,
  50, 48, 49, 50, 47, 49, 50, 47, 50, 49, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 71, 114, 105, 122, 111, 117,
  95, 115, 97, 109, 106, 32, 58, 10, 77, 111, 100, 101, 95, 68, 101, 99,
  111, 109, 112, 111, 115, 105, 116, 105, 111, 110, 61, 36, 49, 10, 86, 97,
  108, 101, 117, 114, 95, 65, 61, 36, 50, 10, 86, 97, 108, 101, 117, 114,
  95, 66, 61, 36, 51, 10, 82, 95, 78, 111, 114, 109, 97, 108, 105, 122,
  101, 61, 36, 52, 10, 86, 97, 108, 101, 117, 114, 95, 67, 61, 36, 53,
  10, 86, 97, 108, 101, 117, 114, 95, 68, 61, 36, 54, 10, 86, 95, 78,
  111, 114, 109, 97, 108, 105, 122, 101, 61, 36, 55, 10, 86, 97, 108, 101,
  117, 114, 95, 69, 61, 36, 56, 10, 86, 97, 108, 101, 117, 114, 95, 70,
  61, 36, 57, 10, 66, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 61,
  36, 49, 48, 10, 86, 97, 108, 101, 117, 114, 95, 71, 61, 36, 49, 49,
  10, 86, 97, 108, 101, 117, 114, 95, 72, 61, 36, 49, 50, 10, 82, 86,
  66, 95, 82, 71, 66, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 61,
  36, 49, 51, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 36, 77, 111, 100, 101,
  95, 68, 101, 99, 111, 109, 112, 111, 115, 105, 116, 105, 111, 110, 61, 61,
  48, 125, 10, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10, 45,
  115, 112, 108, 105, 116, 91, 45, 49, 93, 32, 99, 10, 45, 105, 102, 32,
  123, 36, 86, 97, 108, 101, 117, 114, 95, 65, 62, 36, 86, 97, 108, 101,
  117, 114, 95, 66, 125, 10, 45, 99, 117, 116, 91, 45, 51, 93, 32, 36,
  86, 97, 108, 101, 117, 114, 95, 66, 44, 36, 86, 97, 108, 101, 117, 114,
  95, 65, 10, 45, 101, 108, 115, 101, 10, 45, 99, 117, 116, 91, 45, 51,
  93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 65, 44, 36, 86, 97, 108,
  101, 117, 114, 95, 66, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 82, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 62, 48,
  125, 10, 45, 110, 91, 45, 51, 93, 32, 48, 44, 36, 82, 95, 78, 111,
  114, 109, 97, 108, 105, 122, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 86, 97, 108, 101, 117, 114, 95, 67, 62, 36, 86,
  97, 108, 101, 117, 114, 95, 68, 125, 10, 45, 99, 117, 116, 91, 45, 50,
  93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 68, 44, 36, 86, 97, 108,
  101, 117, 114, 95, 67, 10, 45, 101, 108, 115, 101, 10, 45, 99, 117, 116,
  91, 45, 50, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 67, 44, 36,
  86, 97, 108, 101, 117, 114, 95, 68, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 86, 95, 78, 111, 114, 109, 97, 108, 105, 122,
  101, 62, 48, 125, 10, 45, 110, 91, 45, 50, 93, 32, 48, 44, 36, 86,
  95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 86, 97, 108, 101, 117, 114, 95, 69,
  62, 36, 86, 97, 108, 101, 117, 114, 95, 70, 125, 10, 45, 99, 117, 116,
  91, 45, 49, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 70, 44, 36,
  86, 97, 108, 101, 117, 114, 95, 69, 10, 45, 101, 108, 115, 101, 10, 45,
  99, 117, 116, 91, 45, 49, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95,
  69, 44, 36, 86, 97, 108, 101, 117, 114, 95, 70, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 66, 95, 78, 111, 114, 109, 97,
  108, 105, 122, 101, 62, 48, 125, 10, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 36, 66, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 97, 100, 100, 91, 45, 49, 44, 45, 50, 44,
  45, 51, 93, 10, 45, 105, 102, 32, 123, 36, 86, 97, 108, 101, 117, 114,
  95, 71, 62, 36, 86, 97, 108, 101, 117, 114, 95, 72, 125, 10, 45, 99,
  117, 116, 91, 45, 49, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 72,
  44, 36, 86, 97, 108, 101, 117, 114, 95, 71, 10, 45, 101, 108, 115, 101,
  10, 45, 99, 117, 116, 91, 45, 49, 93, 32, 36, 86, 97, 108, 101, 117,
  114, 95, 71, 44, 36, 86, 97, 108, 101, 117, 114, 95, 72, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 86, 66, 95, 82,
  71, 66, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 62, 48, 125, 10,
  45, 110, 91, 45, 49, 93, 32, 48, 44, 36, 82, 86, 66, 95, 82, 71,
  66, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  77, 111, 100, 101, 95, 68, 101, 99, 111, 109, 112, 111, 115, 105, 116, 105,
  111, 110, 61, 61, 49, 125, 10, 45, 116, 111, 95, 114, 103, 98, 91, 45,
  49, 93, 10, 45, 114, 103, 98, 50, 120, 121, 122, 56, 91, 45, 49, 93,
  10, 45, 115, 112, 108, 105, 116, 91, 45, 49, 93, 32, 99, 10, 45, 105,
  102, 32, 123, 36, 86, 97, 108, 101, 117, 114, 95, 65, 62, 36, 86, 97,
  108, 101, 117, 114, 95, 66, 125, 10, 45, 99, 117, 116, 91, 45, 51, 93,
  32, 36, 86, 97, 108, 101, 117, 114, 95, 66, 44, 36, 86, 97, 108, 101,
  117, 114, 95, 65, 10, 45, 101, 108, 115, 101, 10, 45, 99, 117, 116, 91,
  45, 51, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 65, 44, 36, 86,
  97, 108, 101, 117, 114, 95, 66, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 82, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101,
  62, 48, 125, 10, 45, 110, 91, 45, 51, 93, 32, 48, 44, 36, 82, 95,
  78, 111, 114, 109, 97, 108, 105, 122, 101, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 86, 97, 108, 101, 117, 114, 95, 67, 62,
  36, 86, 97, 108, 101, 117, 114, 95, 68, 125, 10, 45, 99, 117, 116, 91,
  45, 50, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 68, 44, 36, 86,
  97, 108, 101, 117, 114, 95, 67, 10, 45, 101, 108, 115, 101, 10, 45, 99,
  117, 116, 91, 45, 50, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 67,
  44, 36, 86, 97, 108, 101, 117, 114, 95, 68, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 86, 95, 78, 111, 114, 109, 97, 108,
  105, 122, 101, 62, 48, 125, 10, 45, 110, 91, 45, 50, 93, 32, 48, 44,
  36, 86, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 97, 108, 101, 117, 114,
  95, 69, 62, 36, 86, 97, 108, 101, 117, 114, 95, 70, 125, 10, 45, 99,
  117, 116, 91, 45, 49, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 70,
  44, 36, 86, 97, 108, 101, 117, 114, 95, 69, 10, 45, 101, 108, 115, 101,
  10, 45, 99, 117, 116, 91, 45, 49, 93, 32, 36, 86, 97, 108, 101, 117,
  114, 95, 69, 44, 36, 86, 97, 108, 101, 117, 114, 95, 70, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 66, 95, 78, 111, 114,
  109, 97, 108, 105, 122, 101, 62, 48, 125, 10, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 36, 66, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 97, 100, 100, 91, 45, 49, 44, 45,
  50, 44, 45, 51, 93, 10, 45, 105, 102, 32, 123, 36, 86, 97, 108, 101,
  117, 114, 95, 71, 62, 36, 86, 97, 108, 101, 117, 114, 95, 72, 125, 10,
  45, 99, 117, 116, 91, 45, 49, 93, 32, 36, 86, 97, 108, 101, 117, 114,
  95, 72, 44, 36, 86, 97, 108, 101, 117, 114, 95, 71, 10, 45, 101, 108,
  115, 101, 10, 45, 99, 117, 116, 91, 45, 49, 93, 32, 36, 86, 97, 108,
  101, 117, 114, 95, 71, 44, 36, 86, 97, 108, 101, 117, 114, 95, 72, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 86, 66,
  95, 82, 71, 66, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 62, 48,
  125, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 36, 82, 86, 66, 95,
  82, 71, 66, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 77, 111, 100, 101, 95, 68, 101, 99, 111, 109, 112, 111, 115, 105,
  116, 105, 111, 110, 61, 61, 50, 125, 10, 45, 116, 111, 95, 114, 103, 98,
  91, 45, 49, 93, 10, 45, 114, 103, 98, 50, 104, 115, 118, 56, 91, 45,
  49, 93, 10, 45, 115, 112, 108, 105, 116, 91, 45, 49, 93, 32, 99, 10,
  45, 114, 109, 91, 45, 50, 44, 45, 51, 93, 10, 45, 105, 102, 32, 123,
  36, 86, 97, 108, 101, 117, 114, 95, 65, 62, 36, 86, 97, 108, 101, 117,
  114, 95, 66, 125, 10, 45, 99, 117, 116, 91, 45, 49, 93, 32, 36, 86,
  97, 108, 101, 117, 114, 95, 66, 44, 36, 86, 97, 108, 101, 117, 114, 95,
  65, 10, 45, 101, 108, 115, 101, 10, 45, 99, 117, 116, 91, 45, 49, 93,
  32, 36, 86, 97, 108, 101, 117, 114, 95, 65, 44, 36, 86, 97, 108, 101,
  117, 114, 95, 66, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 82, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 62, 48, 125,
  10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 36, 82, 95, 78, 111, 114,
  109, 97, 108, 105, 122, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 77, 111, 100, 101, 95,
  68, 101, 99, 111, 109, 112, 111, 115, 105, 116, 105, 111, 110, 61, 61, 51,
  125, 10, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10, 45, 114,
  103, 98, 50, 104, 115, 108, 56, 91, 45, 49, 93, 10, 45, 115, 112, 108,
  105, 116, 91, 45, 49, 93, 32, 99, 10, 45, 114, 109, 91, 45, 50, 44,
  45, 51, 93, 10, 45, 105, 102, 32, 123, 36, 86, 97, 108, 101, 117, 114,
  95, 65, 62, 36, 86, 97, 108, 101, 117, 114, 95, 66, 125, 10, 45, 99,
  117, 116, 91, 45, 49, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 66,
  44, 36, 86, 97, 108, 101, 117, 114, 95, 65, 10, 45, 101, 108, 115, 101,
  10, 45, 99, 117, 116, 91, 45, 49, 93, 32, 36, 86, 97, 108, 101, 117,
  114, 95, 65, 44, 36, 86, 97, 108, 101, 117, 114, 95, 66, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 95, 78, 111, 114,
  109, 97, 108, 105, 122, 101, 62, 48, 125, 10, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 36, 82, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 77, 111, 100, 101, 95, 68, 101, 99, 111, 109, 112, 111,
  115, 105, 116, 105, 111, 110, 61, 61, 52, 125, 10, 45, 116, 111, 95, 114,
  103, 98, 91, 45, 49, 93, 10, 45, 114, 103, 98, 50, 104, 115, 105, 56,
  91, 45, 49, 93, 10, 45, 115, 112, 108, 105, 116, 91, 45, 49, 93, 32,
  99, 10, 45, 114, 109, 91, 45, 50, 44, 45, 51, 93, 10, 45, 105, 102,
  32, 123, 36, 86, 97, 108, 101, 117, 114, 95, 65, 62, 36, 86, 97, 108,
  101, 117, 114, 95, 66, 125, 10, 45, 99, 117, 116, 91, 45, 49, 93, 32,
  36, 86, 97, 108, 101, 117, 114, 95, 66, 44, 36, 86, 97, 108, 101, 117,
  114, 95, 65, 10, 45, 101, 108, 115, 101, 10, 45, 99, 117, 116, 91, 45,
  49, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 65, 44, 36, 86, 97,
  108, 101, 117, 114, 95, 66, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 82, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 62,
  48, 125, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 36, 82, 95, 78,
  111, 114, 109, 97, 108, 105, 122, 101, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 77, 111, 100,
  101, 95, 68, 101, 99, 111, 109, 112, 111, 115, 105, 116, 105, 111, 110, 61,
  61, 53, 125, 10, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10,
  45, 114, 103, 98, 50, 121, 117, 118, 56, 91, 45, 49, 93, 10, 45, 115,
  112, 108, 105, 116, 91, 45, 49, 93, 32, 99, 10, 45, 114, 109, 91, 45,
  49, 44, 45, 50, 93, 10, 45, 105, 102, 32, 123, 36, 86, 97, 108, 101,
  117, 114, 95, 65, 62, 36, 86, 97, 108, 101, 117, 114, 95, 66, 125, 10,
  45, 99, 117, 116, 91, 45, 49, 93, 32, 36, 86, 97, 108, 101, 117, 114,
  95, 66, 44, 36, 86, 97, 108, 101, 117, 114, 95, 65, 10, 45, 101, 108,
  115, 101, 10, 45, 99, 117, 116, 91, 45, 49, 93, 32, 36, 86, 97, 108,
  101, 117, 114, 95, 65, 44, 36, 86, 97, 108, 101, 117, 114, 95, 66, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 95, 78,
  111, 114, 109, 97, 108, 105, 122, 101, 62, 48, 125, 10, 45, 110, 91, 45,
  49, 93, 32, 48, 44, 36, 82, 95, 78, 111, 114, 109, 97, 108, 105, 122,
  101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 77, 111, 100, 101, 95, 68, 101, 99, 111, 109,
  112, 111, 115, 105, 116, 105, 111, 110, 61, 61, 54, 125, 10, 45, 116, 111,
  95, 114, 103, 98, 91, 45, 49, 93, 10, 45, 114, 103, 98, 50, 121, 99,
  98, 99, 114, 91, 45, 49, 93, 10, 45, 115, 112, 108, 105, 116, 91, 45,
  49, 93, 32, 99, 10, 45, 114, 109, 91, 45, 49, 44, 45, 50, 93, 10,
  45, 105, 102, 32, 123, 36, 86, 97, 108, 101, 117, 114, 95, 65, 62, 36,
  86, 97, 108, 101, 117, 114, 95, 66, 125, 10, 45, 99, 117, 116, 91, 45,
  49, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 66, 44, 36, 86, 97,
  108, 101, 117, 114, 95, 65, 10, 45, 101, 108, 115, 101, 10, 45, 99, 117,
  116, 91, 45, 49, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 65, 44,
  36, 86, 97, 108, 101, 117, 114, 95, 66, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 82, 95, 78, 111, 114, 109, 97, 108, 105,
  122, 101, 62, 48, 125, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 36,
  82, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  77, 111, 100, 101, 95, 68, 101, 99, 111, 109, 112, 111, 115, 105, 116, 105,
  111, 110, 61, 61, 55, 125, 10, 45, 116, 111, 95, 114, 103, 98, 91, 45,
  49, 93, 10, 45, 114, 103, 98, 50, 108, 97, 98, 56, 91, 45, 49, 93,
  10, 45, 115, 112, 108, 105, 116, 91, 45, 49, 93, 32, 99, 10, 45, 114,
  109, 91, 45, 49, 44, 45, 50, 93, 10, 45, 105, 102, 32, 123, 36, 86,
  97, 108, 101, 117, 114, 95, 65, 62, 36, 86, 97, 108, 101, 117, 114, 95,
  66, 125, 10, 45, 99, 117, 116, 91, 45, 49, 93, 32, 36, 86, 97, 108,
  101, 117, 114, 95, 66, 44, 36, 86, 97, 108, 101, 117, 114, 95, 65, 10,
  45, 101, 108, 115, 101, 10, 45, 99, 117, 116, 91, 45, 49, 93, 32, 36,
  86, 97, 108, 101, 117, 114, 95, 65, 44, 36, 86, 97, 108, 101, 117, 114,
  95, 66, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  82, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 62, 48, 125, 10, 45,
  110, 91, 45, 49, 93, 32, 48, 44, 36, 82, 95, 78, 111, 114, 109, 97,
  108, 105, 122, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 77, 111, 100, 101, 95, 68, 101,
  99, 111, 109, 112, 111, 115, 105, 116, 105, 111, 110, 61, 61, 56, 125, 10,
  45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10, 45, 114, 103, 98,
  50, 108, 99, 104, 56, 91, 45, 49, 93, 10, 45, 115, 112, 108, 105, 116,
  91, 45, 49, 93, 32, 99, 10, 45, 114, 109, 91, 45, 49, 44, 45, 50,
  93, 10, 45, 105, 102, 32, 123, 36, 86, 97, 108, 101, 117, 114, 95, 65,
  62, 36, 86, 97, 108, 101, 117, 114, 95, 66, 125, 10, 45, 99, 117, 116,
  91, 45, 49, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 66, 44, 36,
  86, 97, 108, 101, 117, 114, 95, 65, 10, 45, 101, 108, 115, 101, 10, 45,
  99, 117, 116, 91, 45, 49, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95,
  65, 44, 36, 86, 97, 108, 101, 117, 114, 95, 66, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 95, 78, 111, 114, 109, 97,
  108, 105, 122, 101, 62, 48, 125, 10, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 36, 82, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 77, 111, 100, 101, 95, 68, 101, 99, 111, 109, 112, 111, 115, 105,
  116, 105, 111, 110, 61, 61, 57, 125, 10, 45, 116, 111, 95, 114, 103, 98,
  91, 45, 49, 93, 10, 45, 45, 114, 103, 98, 50, 99, 109, 121, 107, 91,
  45, 49, 93, 10, 45, 115, 112, 108, 105, 116, 91, 45, 49, 93, 32, 99,
  10, 45, 114, 109, 91, 45, 50, 44, 45, 51, 44, 45, 52, 44, 45, 53,
  93, 10, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 10,
  45, 105, 102, 32, 123, 36, 86, 97, 108, 101, 117, 114, 95, 65, 62, 36,
  86, 97, 108, 101, 117, 114, 95, 66, 125, 10, 45, 99, 117, 116, 91, 45,
  49, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 66, 44, 36, 86, 97,
  108, 101, 117, 114, 95, 65, 10, 45, 101, 108, 115, 101, 10, 45, 99, 117,
  116, 91, 45, 49, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 65, 44,
  36, 86, 97, 108, 101, 117, 114, 95, 66, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 82, 95, 78, 111, 114, 109, 97, 108, 105,
  122, 101, 62, 48, 125, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 36,
  82, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 71, 114, 105, 122, 111, 117, 95, 115, 97, 109,
  106, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 71, 114, 105, 122, 111, 117, 95, 115, 97, 109, 106, 32, 36, 123,
  49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109,
  112, 32, 72, 97, 114, 100, 32, 115, 107, 101, 116, 99, 104, 32, 120, 121,
  32, 58, 32, 88, 89, 95, 104, 97, 114, 100, 115, 107, 101, 116, 99, 104,
  98, 119, 95, 115, 97, 109, 106, 44, 32, 88, 89, 95, 104, 97, 114, 100,
  115, 107, 101, 116, 99, 104, 98, 119, 95, 115, 97, 109, 106, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 72, 97, 114, 100, 32, 83, 107, 101, 116, 99, 104, 32, 66, 87, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 88, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  50, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 51, 48, 48, 44, 48, 44, 52, 48, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 68, 101, 110, 115, 105, 116, 121, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112,
  97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  69, 100, 103, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  70, 97, 115, 116, 32, 97, 112, 112, 114, 111, 120, 105, 109, 97, 116, 105,
  111, 110, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 101, 103, 97, 116, 105, 118, 101, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 67, 97, 108, 113, 117, 101, 115,
  32, 47, 32, 76, 97, 121, 101, 114, 115, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 98, 46,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 49, 32, 58,
  32, 88, 89, 34, 44, 34, 50, 32, 58, 32, 88, 89, 32, 43, 32, 72,
  97, 114, 100, 32, 83, 107, 101, 116, 99, 104, 32, 66, 87, 32, 78, 111,
  114, 109, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 83, 104, 97, 114, 112, 101, 110, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 79, 99, 116, 97, 118, 101, 32, 115, 104, 97, 114, 112, 101, 110,
  105, 110, 103, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 88, 89,
  95, 104, 97, 114, 100, 115, 107, 101, 116, 99, 104, 32, 67, 111, 108, 111,
  114, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 47, 32, 99,
  111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 49, 56, 48,
  44, 52, 48, 44, 49, 54, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 82, 101, 109, 112, 108, 105, 114, 32, 47, 32,
  102, 105, 108, 108, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121,
  112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 101, 117, 114, 115, 32, 47, 32,
  65, 117, 116, 104, 111, 114, 115, 32, 58, 32, 60, 105, 62, 83, 97, 109,
  106, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50,
  48, 49, 51, 47, 48, 49, 47, 50, 53, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 88, 89, 95, 104, 97, 114, 100,
  115, 107, 101, 116, 99, 104, 98, 119, 95, 115, 97, 109, 106, 32, 58, 10,
  88, 89, 61, 36, 49, 10, 65, 109, 112, 108, 105, 116, 117, 100, 101, 61,
  36, 50, 10, 68, 101, 110, 115, 105, 116, 121, 61, 36, 51, 10, 83, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 61, 36, 52, 10, 79, 112, 97, 99,
  105, 116, 121, 61, 36, 53, 10, 69, 100, 103, 101, 61, 36, 54, 10, 70,
  97, 115, 116, 95, 97, 112, 112, 114, 111, 120, 105, 109, 97, 116, 105, 111,
  110, 61, 36, 55, 10, 78, 101, 103, 97, 116, 105, 118, 101, 61, 36, 56,
  10, 67, 97, 108, 113, 117, 101, 115, 61, 36, 57, 10, 79, 99, 116, 97,
  118, 101, 95, 83, 104, 97, 114, 112, 101, 110, 105, 110, 103, 61, 36, 49,
  48, 10, 82, 95, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101,
  61, 36, 49, 49, 10, 86, 95, 84, 114, 97, 110, 115, 112, 97, 114, 101,
  110, 99, 101, 61, 36, 49, 50, 10, 66, 95, 84, 114, 97, 110, 115, 112,
  97, 114, 101, 110, 99, 101, 61, 36, 49, 51, 10, 65, 95, 84, 114, 97,
  110, 115, 112, 97, 114, 101, 110, 99, 101, 61, 36, 49, 52, 10, 82, 101,
  109, 112, 108, 105, 114, 61, 36, 49, 53, 10, 76, 97, 114, 103, 101, 117,
  114, 61, 123, 119, 125, 10, 72, 97, 117, 116, 101, 117, 114, 61, 123, 104,
  125, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 10, 45,
  45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103,
  91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 67, 97, 108, 113, 117,
  101, 115, 61, 61, 49, 125, 32, 45, 45, 103, 105, 109, 112, 95, 100, 111,
  95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 76, 97, 114, 103, 101, 117,
  114, 62, 36, 72, 97, 117, 116, 101, 117, 114, 125, 10, 71, 114, 97, 110,
  100, 101, 95, 100, 105, 109, 101, 110, 115, 105, 111, 110, 61, 123, 36, 76,
  97, 114, 103, 101, 117, 114, 42, 49, 46, 53, 125, 10, 45, 101, 108, 115,
  101, 10, 71, 114, 97, 110, 100, 101, 95, 100, 105, 109, 101, 110, 115, 105,
  111, 110, 61, 123, 36, 72, 97, 117, 116, 101, 117, 114, 42, 49, 46, 53,
  125, 10, 45, 101, 110, 100, 105, 102, 10, 79, 114, 105, 103, 105, 110, 101,
  95, 88, 61, 123, 114, 111, 117, 110, 100, 40, 123, 123, 123, 36, 71, 114,
  97, 110, 100, 101, 95, 100, 105, 109, 101, 110, 115, 105, 111, 110, 125, 45,
  36, 76, 97, 114, 103, 101, 117, 114, 125, 47, 50, 125, 41, 125, 10, 79,
  114, 105, 103, 105, 110, 101, 95, 89, 61, 123, 114, 111, 117, 110, 100, 40,
  123, 123, 123, 36, 71, 114, 97, 110, 100, 101, 95, 100, 105, 109, 101, 110,
  115, 105, 111, 110, 125, 45, 36, 72, 97, 117, 116, 101, 117, 114, 125, 47,
  50, 125, 41, 125, 10, 45, 101, 120, 112, 97, 110, 100, 95, 120, 91, 45,
  49, 93, 32, 36, 79, 114, 105, 103, 105, 110, 101, 95, 88, 44, 50, 10,
  45, 101, 120, 112, 97, 110, 100, 95, 121, 91, 45, 49, 93, 32, 36, 79,
  114, 105, 103, 105, 110, 101, 95, 89, 44, 50, 10, 45, 116, 119, 105, 114,
  108, 91, 45, 49, 93, 32, 36, 88, 89, 44, 48, 46, 53, 44, 48, 46,
  53, 44, 49, 10, 45, 103, 105, 109, 112, 95, 104, 97, 114, 100, 115, 107,
  101, 116, 99, 104, 98, 119, 91, 45, 49, 93, 32, 36, 65, 109, 112, 108,
  105, 116, 117, 100, 101, 44, 36, 68, 101, 110, 115, 105, 116, 121, 44, 36,
  83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 44, 36, 79, 112, 97, 99,
  105, 116, 121, 44, 36, 69, 100, 103, 101, 44, 36, 70, 97, 115, 116, 95,
  97, 112, 112, 114, 111, 120, 105, 109, 97, 116, 105, 111, 110, 44, 36, 78,
  101, 103, 97, 116, 105, 118, 101, 10, 45, 116, 119, 105, 114, 108, 91, 45,
  49, 93, 32, 45, 36, 88, 89, 44, 48, 46, 53, 44, 48, 46, 53, 44,
  49, 10, 45, 101, 120, 112, 97, 110, 100, 95, 120, 91, 45, 50, 93, 32,
  36, 79, 114, 105, 103, 105, 110, 101, 95, 88, 44, 50, 10, 45, 101, 120,
  112, 97, 110, 100, 95, 121, 91, 45, 50, 93, 32, 36, 79, 114, 105, 103,
  105, 110, 101, 95, 89, 44, 50, 10, 45, 116, 119, 105, 114, 108, 91, 45,
  50, 93, 32, 45, 36, 88, 89, 44, 48, 46, 53, 44, 48, 46, 53, 44,
  49, 10, 45, 103, 105, 109, 112, 95, 104, 97, 114, 100, 115, 107, 101, 116,
  99, 104, 98, 119, 91, 45, 50, 93, 32, 36, 65, 109, 112, 108, 105, 116,
  117, 100, 101, 44, 36, 68, 101, 110, 115, 105, 116, 121, 44, 36, 83, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 44, 36, 79, 112, 97, 99, 105, 116,
  121, 44, 36, 69, 100, 103, 101, 44, 36, 70, 97, 115, 116, 95, 97, 112,
  112, 114, 111, 120, 105, 109, 97, 116, 105, 111, 110, 44, 36, 78, 101, 103,
  97, 116, 105, 118, 101, 10, 45, 116, 119, 105, 114, 108, 91, 45, 50, 93,
  32, 36, 88, 89, 44, 48, 46, 53, 44, 48, 46, 53, 44, 49, 10, 35,
  97, 118, 101, 114, 97, 103, 101, 10, 45, 103, 105, 109, 112, 95, 98, 108,
  101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 51, 44, 49, 44, 49,
  10, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 36, 79, 114, 105, 103,
  105, 110, 101, 95, 88, 44, 36, 79, 114, 105, 103, 105, 110, 101, 95, 89,
  44, 123, 36, 76, 97, 114, 103, 101, 117, 114, 43, 36, 79, 114, 105, 103,
  105, 110, 101, 95, 88, 45, 49, 125, 44, 123, 36, 72, 97, 117, 116, 101,
  117, 114, 43, 36, 79, 114, 105, 103, 105, 110, 101, 95, 89, 45, 49, 125,
  10, 45, 105, 102, 32, 123, 36, 79, 99, 116, 97, 118, 101, 95, 83, 104,
  97, 114, 112, 101, 110, 105, 110, 103, 61, 61, 49, 125, 10, 45, 103, 105,
  109, 112, 95, 117, 110, 115, 104, 97, 114, 112, 95, 111, 99, 116, 97, 118,
  101, 32, 52, 44, 53, 44, 51, 44, 48, 44, 48, 44, 48, 44, 50, 52,
  44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  67, 97, 108, 113, 117, 101, 115, 61, 61, 49, 125, 10, 45, 103, 105, 109,
  112, 95, 104, 97, 114, 100, 115, 107, 101, 116, 99, 104, 98, 119, 91, 45,
  50, 93, 32, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 44, 36, 68,
  101, 110, 115, 105, 116, 121, 44, 36, 83, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 44, 36, 79, 112, 97, 99, 105, 116, 121, 44, 36, 69, 100, 103,
  101, 44, 36, 70, 97, 115, 116, 95, 97, 112, 112, 114, 111, 120, 105, 109,
  97, 116, 105, 111, 110, 44, 36, 78, 101, 103, 97, 116, 105, 118, 101, 10,
  45, 114, 101, 118, 101, 114, 115, 101, 91, 45, 49, 44, 45, 50, 93, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 101, 109,
  112, 108, 105, 114, 61, 61, 49, 125, 10, 36, 76, 97, 114, 103, 101, 117,
  114, 44, 36, 72, 97, 117, 116, 101, 117, 114, 44, 49, 44, 52, 10, 45,
  102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 36,
  82, 95, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 44, 36,
  86, 95, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 44, 36,
  66, 95, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 44, 36,
  65, 95, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 10, 45,
  105, 102, 32, 123, 36, 67, 97, 108, 113, 117, 101, 115, 61, 61, 49, 125,
  10, 45, 114, 101, 118, 101, 114, 115, 101, 91, 45, 49, 44, 45, 50, 93,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 98, 108,
  101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 51, 55, 44, 49, 44,
  48, 10, 45, 105, 102, 32, 123, 36, 67, 97, 108, 113, 117, 101, 115, 61,
  61, 49, 125, 10, 45, 114, 101, 118, 101, 114, 115, 101, 91, 45, 49, 44,
  45, 50, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105,
  102, 10, 35, 64, 103, 105, 109, 112, 32, 73, 105, 32, 99, 111, 117, 108,
  101, 117, 114, 115, 32, 58, 32, 73, 73, 95, 67, 111, 117, 108, 101, 117,
  114, 115, 95, 115, 97, 109, 106, 44, 32, 73, 73, 95, 67, 111, 117, 108,
  101, 117, 114, 115, 95, 115, 97, 109, 106, 95, 112, 114, 101, 118, 105, 101,
  119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 83, 101, 108, 101, 99, 116, 105, 111, 110, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84,
  111, 108, 101, 114, 97, 110, 99, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 82, 32, 61, 32, 105, 110, 116, 40, 49, 50, 55, 44,
  48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  86, 32, 47, 32, 103, 32, 61, 32, 105, 110, 116, 40, 49, 50, 55, 44,
  48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  66, 32, 61, 32, 105, 110, 116, 40, 49, 50, 55, 44, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 73, 73, 32, 67, 111, 117, 108, 101, 117, 114, 115, 32, 47,
  32, 73, 73, 32, 67, 111, 108, 111, 114, 115, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111,
  117, 108, 101, 117, 114, 32, 47, 32, 99, 111, 108, 111, 114, 32, 49, 32,
  61, 32, 99, 111, 108, 111, 114, 40, 48, 44, 48, 44, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32,
  47, 32, 99, 111, 108, 111, 114, 32, 50, 32, 61, 32, 99, 111, 108, 111,
  114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 118, 101, 114, 115, 101, 114,
  32, 47, 32, 105, 110, 118, 101, 114, 116, 32, 61, 32, 98, 111, 111, 108,
  40, 102, 97, 108, 115, 101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80,
  114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65,
  117, 116, 101, 117, 114, 115, 32, 47, 32, 65, 117, 116, 104, 111, 114, 115,
  32, 58, 32, 60, 105, 62, 83, 97, 109, 106, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 50, 47, 49, 50, 47,
  49, 53, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 73, 73, 95, 67, 111, 117, 108, 101, 117, 114, 115, 95, 115, 97,
  109, 106, 32, 58, 10, 84, 111, 108, 101, 114, 97, 110, 99, 101, 95, 83,
  67, 61, 36, 49, 10, 82, 95, 83, 67, 61, 36, 50, 10, 86, 95, 83,
  67, 61, 36, 51, 10, 66, 95, 83, 67, 61, 36, 52, 10, 82, 95, 67,
  49, 61, 36, 53, 10, 86, 95, 67, 49, 61, 36, 54, 10, 66, 95, 67,
  49, 61, 36, 55, 10, 82, 95, 67, 50, 61, 36, 56, 10, 86, 95, 67,
  50, 61, 36, 57, 10, 66, 95, 67, 50, 61, 36, 49, 48, 10, 73, 110,
  118, 101, 114, 115, 101, 114, 61, 36, 49, 49, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 116, 111,
  95, 114, 103, 98, 10, 45, 115, 101, 108, 101, 99, 116, 95, 99, 111, 108,
  111, 114, 32, 36, 84, 111, 108, 101, 114, 97, 110, 99, 101, 95, 83, 67,
  44, 36, 82, 95, 83, 67, 44, 36, 86, 95, 83, 67, 44, 36, 66, 95,
  83, 67, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32,
  123, 36, 73, 110, 118, 101, 114, 115, 101, 114, 61, 61, 49, 125, 10, 45,
  110, 101, 103, 97, 116, 105, 118, 101, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 116, 111, 95, 114, 103, 98, 10, 45, 114, 101, 112, 108, 97, 99, 101,
  95, 99, 111, 108, 111, 114, 32, 48, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 36, 82, 95, 67, 49, 44, 36, 86, 95, 67, 49, 44, 36, 66, 95,
  67, 49, 32, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111,
  114, 32, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 36, 82, 95, 67, 50, 44, 36, 86, 95, 67, 50, 44, 36, 66,
  95, 67, 50, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  73, 73, 95, 67, 111, 117, 108, 101, 117, 114, 115, 95, 115, 97, 109, 106,
  95, 112, 114, 101, 118, 105, 101, 119, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  73, 73, 95, 67, 111, 117, 108, 101, 117, 114, 115, 95, 115, 97, 109, 106,
  32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35, 64,
  103, 105, 109, 112, 32, 78, 111, 105, 114, 32, 101, 116, 32, 98, 108, 97,
  110, 99, 32, 48, 48, 49, 32, 58, 32, 115, 97, 109, 106, 95, 78, 111,
  105, 114, 95, 101, 116, 95, 66, 108, 97, 110, 99, 95, 48, 48, 49, 44,
  32, 115, 97, 109, 106, 95, 78, 111, 105, 114, 95, 101, 116, 95, 66, 108,
  97, 110, 99, 95, 48, 48, 49, 95, 112, 114, 101, 118, 105, 101, 119, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 101, 118, 101, 108,
  115, 32, 61, 32, 105, 110, 116, 40, 51, 48, 44, 50, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116, 114,
  97, 115, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 51, 44,
  48, 46, 48, 49, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 68, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 51, 44, 48, 44, 54, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32,
  116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70,
  117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 115, 97, 109, 106, 32, 45, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60,
  105, 62, 50, 48, 49, 51, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109, 106,
  95, 78, 111, 105, 114, 95, 101, 116, 95, 66, 108, 97, 110, 99, 95, 48,
  48, 49, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 83, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 95, 99, 111, 108, 111, 114, 95, 97, 98, 115, 116, 114, 97, 99, 116,
  105, 111, 110, 61, 36, 49, 10, 76, 101, 118, 101, 108, 115, 95, 99, 111,
  108, 111, 114, 95, 97, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 61,
  36, 50, 10, 67, 111, 110, 116, 114, 97, 115, 116, 95, 99, 111, 108, 111,
  114, 95, 97, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 61, 36, 51,
  10, 65, 109, 112, 108, 105, 116, 117, 100, 101, 95, 114, 105, 112, 112, 108,
  101, 61, 36, 52, 10, 45, 103, 105, 109, 112, 95, 99, 111, 108, 111, 114,
  95, 97, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 91, 45, 49, 93,
  32, 36, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 95, 99, 111, 108,
  111, 114, 95, 97, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 44, 36,
  76, 101, 118, 101, 108, 115, 95, 99, 111, 108, 111, 114, 95, 97, 98, 115,
  116, 114, 97, 99, 116, 105, 111, 110, 44, 36, 67, 111, 110, 116, 114, 97,
  115, 116, 95, 99, 111, 108, 111, 114, 95, 97, 98, 115, 116, 114, 97, 99,
  116, 105, 111, 110, 10, 45, 103, 105, 109, 112, 95, 101, 100, 103, 101, 115,
  91, 45, 49, 93, 32, 48, 44, 49, 53, 44, 48, 10, 45, 45, 103, 105,
  109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49,
  93, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104,
  105, 110, 103, 91, 45, 49, 93, 10, 45, 114, 105, 112, 112, 108, 101, 91,
  45, 49, 93, 32, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 95, 114,
  105, 112, 112, 108, 101, 44, 50, 48, 44, 50, 44, 48, 10, 45, 103, 105,
  109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32,
  51, 44, 49, 44, 48, 10, 45, 114, 105, 112, 112, 108, 101, 91, 45, 49,
  93, 32, 123, 49, 46, 50, 42, 123, 36, 65, 109, 112, 108, 105, 116, 117,
  100, 101, 95, 114, 105, 112, 112, 108, 101, 125, 125, 44, 50, 48, 44, 50,
  44, 48, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45,
  49, 44, 45, 50, 93, 32, 51, 44, 49, 44, 48, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 115, 97, 109, 106, 95, 78, 111, 105,
  114, 95, 101, 116, 95, 66, 108, 97, 110, 99, 95, 48, 48, 49, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115,
  112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115,
  97, 109, 106, 95, 78, 111, 105, 114, 95, 101, 116, 95, 66, 108, 97, 110,
  99, 95, 48, 48, 49, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64,
  103, 105, 109, 112, 32, 78, 111, 105, 114, 32, 101, 116, 32, 98, 108, 97,
  110, 99, 32, 48, 48, 50, 32, 58, 32, 115, 97, 109, 106, 95, 78, 111,
  105, 114, 95, 101, 116, 95, 66, 108, 97, 110, 99, 95, 48, 48, 50, 44,
  32, 115, 97, 109, 106, 95, 78, 111, 105, 114, 95, 101, 116, 95, 66, 108,
  97, 110, 99, 95, 48, 48, 50, 95, 112, 114, 101, 118, 105, 101, 119, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115,
  104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 53, 44,
  48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68,
  101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 51, 44, 48, 44, 54, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 66, 111, 111, 115, 116, 32, 61, 32, 98, 111, 111, 108, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80,
  114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115,
  97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 49, 50,
  47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 115, 97, 109, 106, 95, 78, 111, 105, 114, 95, 101, 116, 95,
  66, 108, 97, 110, 99, 95, 48, 48, 50, 32, 58, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 83, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 95, 116, 104, 105, 110, 95, 101, 100,
  103, 101, 115, 61, 36, 49, 10, 84, 104, 114, 101, 115, 104, 111, 108, 100,
  95, 116, 104, 105, 110, 95, 101, 100, 103, 101, 115, 61, 36, 50, 10, 65,
  109, 112, 108, 105, 116, 117, 100, 101, 95, 114, 105, 112, 112, 108, 101, 61,
  36, 51, 10, 66, 111, 111, 115, 116, 61, 36, 52, 10, 45, 103, 105, 109,
  112, 95, 116, 104, 105, 110, 95, 101, 100, 103, 101, 115, 91, 45, 49, 93,
  32, 36, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 95, 116, 104, 105,
  110, 95, 101, 100, 103, 101, 115, 44, 36, 84, 104, 114, 101, 115, 104, 111,
  108, 100, 95, 116, 104, 105, 110, 95, 101, 100, 103, 101, 115, 44, 48, 10,
  45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110,
  103, 91, 45, 49, 93, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95,
  110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 114, 105, 112,
  112, 108, 101, 91, 45, 49, 93, 32, 36, 65, 109, 112, 108, 105, 116, 117,
  100, 101, 95, 114, 105, 112, 112, 108, 101, 44, 50, 48, 44, 50, 44, 48,
  10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44,
  45, 50, 93, 32, 51, 44, 49, 44, 48, 10, 45, 114, 105, 112, 112, 108,
  101, 91, 45, 49, 93, 32, 123, 49, 46, 50, 42, 123, 36, 65, 109, 112,
  108, 105, 116, 117, 100, 101, 95, 114, 105, 112, 112, 108, 101, 125, 125, 44,
  50, 48, 44, 50, 44, 48, 10, 45, 103, 105, 109, 112, 95, 101, 100, 103,
  101, 115, 91, 45, 50, 93, 32, 48, 44, 49, 53, 44, 48, 44, 48, 10,
  45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45,
  50, 93, 32, 51, 44, 49, 44, 48, 10, 45, 105, 102, 32, 123, 36, 66,
  111, 111, 115, 116, 61, 61, 49, 125, 10, 45, 103, 105, 109, 112, 95, 98,
  97, 108, 97, 110, 99, 101, 95, 103, 97, 109, 109, 97, 91, 45, 49, 93,
  32, 49, 50, 56, 44, 49, 50, 56, 44, 49, 50, 56, 44, 49, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 115, 97, 109, 106, 95, 78, 111, 105, 114, 95, 101, 116, 95, 66,
  108, 97, 110, 99, 95, 48, 48, 50, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 78, 111,
  105, 114, 95, 101, 116, 95, 66, 108, 97, 110, 99, 95, 48, 48, 50, 32,
  36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 78,
  111, 105, 114, 32, 101, 116, 32, 98, 108, 97, 110, 99, 32, 48, 48, 51,
  32, 58, 32, 115, 97, 109, 106, 95, 78, 111, 105, 114, 95, 101, 116, 95,
  66, 108, 97, 110, 99, 95, 48, 48, 51, 44, 32, 115, 97, 109, 106, 95,
  78, 111, 105, 114, 95, 101, 116, 95, 66, 108, 97, 110, 99, 95, 48, 48,
  51, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 53, 44, 48, 44, 53, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 102, 111, 114, 109, 97,
  116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44, 48,
  44, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 111, 111,
  115, 116, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 105, 110, 116,
  40, 51, 44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50,
  48, 49, 51, 47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 78, 111,
  105, 114, 95, 101, 116, 95, 66, 108, 97, 110, 99, 95, 48, 48, 51, 32,
  58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 95, 116,
  104, 105, 110, 95, 101, 100, 103, 101, 115, 61, 36, 49, 10, 84, 104, 114,
  101, 115, 104, 111, 108, 100, 95, 116, 104, 105, 110, 95, 101, 100, 103, 101,
  115, 61, 36, 50, 10, 65, 109, 112, 108, 105, 116, 117, 100, 101, 95, 114,
  105, 112, 112, 108, 101, 61, 36, 51, 10, 66, 111, 111, 115, 116, 61, 36,
  52, 10, 83, 105, 122, 101, 95, 109, 111, 114, 112, 104, 111, 61, 36, 53,
  10, 45, 103, 105, 109, 112, 95, 116, 104, 105, 110, 95, 101, 100, 103, 101,
  115, 91, 45, 49, 93, 32, 36, 83, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 95, 116, 104, 105, 110, 95, 101, 100, 103, 101, 115, 44, 36, 84, 104,
  114, 101, 115, 104, 111, 108, 100, 95, 116, 104, 105, 110, 95, 101, 100, 103,
  101, 115, 44, 48, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110,
  111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 45, 103, 105, 109,
  112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93,
  10, 45, 114, 105, 112, 112, 108, 101, 91, 45, 49, 93, 32, 36, 65, 109,
  112, 108, 105, 116, 117, 100, 101, 95, 114, 105, 112, 112, 108, 101, 44, 50,
  48, 44, 50, 44, 48, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110,
  100, 91, 45, 49, 44, 45, 50, 93, 32, 51, 44, 49, 44, 48, 10, 45,
  114, 105, 112, 112, 108, 101, 91, 45, 49, 93, 32, 123, 49, 46, 50, 42,
  123, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 95, 114, 105, 112, 112,
  108, 101, 125, 125, 44, 50, 48, 44, 50, 44, 48, 10, 45, 103, 105, 109,
  112, 95, 101, 100, 103, 101, 115, 91, 45, 50, 93, 32, 48, 44, 49, 53,
  44, 48, 44, 48, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100,
  91, 45, 49, 44, 45, 50, 93, 32, 51, 44, 49, 44, 48, 10, 45, 105,
  102, 32, 123, 36, 66, 111, 111, 115, 116, 61, 61, 49, 125, 10, 45, 103,
  105, 109, 112, 95, 98, 97, 108, 97, 110, 99, 101, 95, 103, 97, 109, 109,
  97, 91, 45, 49, 93, 32, 49, 50, 56, 44, 49, 50, 56, 44, 49, 50,
  56, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112,
  95, 109, 111, 114, 112, 104, 111, 91, 45, 49, 93, 32, 48, 44, 36, 83,
  105, 122, 101, 95, 109, 111, 114, 112, 104, 111, 44, 48, 44, 50, 44, 48,
  44, 49, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115,
  97, 109, 106, 95, 78, 111, 105, 114, 95, 101, 116, 95, 66, 108, 97, 110,
  99, 95, 48, 48, 51, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 78, 111, 105, 114, 95,
  101, 116, 95, 66, 108, 97, 110, 99, 95, 48, 48, 51, 32, 36, 42, 34,
  44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 78, 111, 105, 114,
  32, 101, 116, 32, 98, 108, 97, 110, 99, 32, 48, 48, 52, 32, 58, 32,
  115, 97, 109, 106, 95, 78, 111, 105, 114, 95, 101, 116, 95, 66, 108, 97,
  110, 99, 95, 48, 48, 52, 44, 32, 115, 97, 109, 106, 95, 78, 111, 105,
  114, 95, 101, 116, 95, 66, 108, 97, 110, 99, 95, 48, 48, 52, 95, 112,
  114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111,
  100, 117, 108, 111, 32, 61, 32, 105, 110, 116, 40, 50, 48, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 101,
  103, 97, 116, 105, 102, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 38, 119, 32, 112, 101, 110,
  99, 105, 108, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 49, 50,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80,
  114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115,
  97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49,
  47, 48, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 115, 97, 109, 106, 95, 78, 111, 105, 114, 95, 101, 116, 95,
  66, 108, 97, 110, 99, 95, 48, 48, 52, 32, 58, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 77, 111,
  100, 117, 108, 111, 61, 36, 49, 10, 78, 101, 103, 97, 116, 105, 102, 61,
  36, 50, 10, 66, 95, 87, 95, 112, 101, 110, 99, 105, 108, 95, 97, 109,
  112, 108, 105, 116, 117, 100, 101, 61, 36, 51, 10, 45, 116, 111, 95, 114,
  103, 98, 91, 45, 49, 93, 10, 45, 109, 111, 100, 91, 45, 49, 93, 32,
  123, 50, 48, 43, 36, 77, 111, 100, 117, 108, 111, 125, 10, 45, 110, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 103, 105, 109, 112, 95,
  100, 105, 116, 104, 101, 114, 101, 100, 98, 119, 91, 45, 49, 93, 32, 48,
  44, 49, 44, 48, 44, 48, 44, 48, 44, 48, 10, 45, 105, 102, 32, 123,
  36, 78, 101, 103, 97, 116, 105, 102, 61, 61, 49, 125, 10, 45, 110, 101,
  103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 66, 95, 87, 95, 112, 101, 110, 99,
  105, 108, 95, 97, 109, 112, 108, 105, 116, 117, 100, 101, 62, 48, 125, 10,
  45, 112, 101, 110, 99, 105, 108, 98, 119, 91, 45, 49, 93, 32, 48, 46,
  51, 44, 36, 66, 95, 87, 95, 112, 101, 110, 99, 105, 108, 95, 97, 109,
  112, 108, 105, 116, 117, 100, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115, 97, 109, 106, 95,
  78, 111, 105, 114, 95, 101, 116, 95, 66, 108, 97, 110, 99, 95, 48, 48,
  52, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 115, 97, 109, 106, 95, 78, 111, 105, 114, 95, 101, 116, 95, 66,
  108, 97, 110, 99, 95, 48, 48, 52, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 78, 111, 105, 114, 32, 101, 116, 32,
  98, 108, 97, 110, 99, 32, 48, 48, 53, 32, 58, 32, 115, 97, 109, 106,
  95, 78, 111, 105, 114, 95, 101, 116, 95, 66, 108, 97, 110, 99, 95, 48,
  48, 53, 44, 32, 115, 97, 109, 106, 95, 78, 111, 105, 114, 95, 101, 116,
  95, 66, 108, 97, 110, 99, 95, 48, 48, 53, 95, 112, 114, 101, 118, 105,
  101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 37, 32, 61, 32, 105, 110,
  116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 82, 32, 61, 32, 105, 110, 116, 40, 49, 50, 55,
  44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 86, 32, 61, 32, 105, 110, 116, 40, 49, 50, 55, 44, 48, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 32, 61,
  32, 105, 110, 116, 40, 49, 50, 55, 44, 48, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 101, 103, 97, 116, 105, 118,
  101, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 69, 102, 102, 101, 116, 32, 61, 32, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47,
  48, 49, 47, 49, 54, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 78, 111, 105, 114, 95, 101,
  116, 95, 66, 108, 97, 110, 99, 95, 48, 48, 53, 32, 58, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10, 45, 115, 101, 108,
  101, 99, 116, 95, 99, 111, 108, 111, 114, 32, 36, 49, 44, 36, 50, 44,
  36, 51, 44, 36, 52, 10, 45, 110, 32, 48, 44, 50, 53, 53, 10, 45,
  105, 102, 32, 123, 36, 53, 61, 61, 49, 125, 10, 45, 110, 101, 103, 97,
  116, 105, 118, 101, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 54, 61, 61, 49, 125, 10, 45, 103, 105, 109,
  112, 95, 103, 108, 111, 119, 91, 45, 49, 93, 32, 49, 53, 44, 51, 44,
  48, 10, 45, 103, 105, 109, 112, 95, 110, 111, 105, 115, 101, 91, 45, 49,
  93, 32, 51, 48, 44, 48, 44, 51, 44, 48, 44, 48, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 49, 93,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115, 97, 109,
  106, 95, 78, 111, 105, 114, 95, 101, 116, 95, 66, 108, 97, 110, 99, 95,
  48, 48, 53, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 115, 97, 109, 106, 95, 78, 111, 105, 114, 95, 101, 116,
  95, 66, 108, 97, 110, 99, 95, 48, 48, 53, 32, 36, 42, 34, 44, 36,
  45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 95, 10, 35, 64, 103, 105,
  109, 112, 32, 60, 105, 62, 67, 111, 108, 111, 114, 115, 60, 47, 105, 62,
  10, 35, 64, 103, 105, 109, 112, 32, 67, 111, 117, 108, 101, 117, 114, 115,
  32, 109, 101, 116, 97, 108, 108, 105, 113, 117, 101, 115, 32, 58, 32, 67,
  111, 117, 108, 101, 117, 114, 115, 95, 77, 101, 116, 97, 108, 108, 105, 113,
  117, 101, 115, 44, 32, 67, 111, 117, 108, 101, 117, 114, 115, 95, 77, 101,
  116, 97, 108, 108, 105, 113, 117, 101, 115, 95, 112, 114, 101, 118, 105, 101,
  119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 82, 101, 110, 100, 117, 32, 45, 32, 82, 101, 110, 100, 101, 114,
  105, 110, 103, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 84, 114, 97, 110, 115, 112, 97, 114, 101,
  110, 99, 101, 32, 47, 32, 116, 114, 97, 110, 115, 112, 97, 114, 101, 110,
  99, 121, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 67,
  111, 110, 115, 101, 114, 118, 101, 114, 32, 47, 32, 80, 114, 101, 115, 101,
  114, 118, 101, 34, 44, 34, 83, 117, 112, 112, 114, 105, 109, 101, 114, 32,
  47, 32, 82, 101, 109, 111, 118, 101, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 82, 101, 110, 100, 117, 32, 47, 32, 114, 101, 110, 100,
  101, 114, 105, 110, 103, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48,
  44, 34, 84, 121, 112, 101, 32, 49, 34, 44, 34, 84, 121, 112, 101, 32,
  50, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 80, 97, 114, 97, 109, 92, 51, 48, 51, 92, 50, 53,
  48, 116, 114, 101, 115, 32, 70, 105, 108, 116, 114, 101, 32, 78, 111, 105,
  115, 101, 32, 45, 32, 78, 111, 105, 115, 101, 32, 112, 97, 114, 97, 109,
  101, 116, 101, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117,
  100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 50, 44, 48, 44,
  50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 121,
  112, 101, 32, 100, 101, 32, 98, 114, 117, 105, 116, 32, 47, 32, 110, 111,
  105, 115, 101, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 71, 97, 117, 115, 115, 105, 97, 110, 34, 44, 34, 85, 110,
  105, 102, 111, 114, 109, 34, 44, 34, 83, 97, 108, 116, 32, 97, 110, 100,
  32, 112, 101, 112, 112, 101, 114, 34, 44, 34, 80, 111, 105, 115, 115, 111,
  110, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108,
  117, 101, 32, 114, 97, 110, 103, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 67, 117, 116, 34, 44, 34, 78, 111, 114, 109, 97, 108, 105,
  122, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 80, 97, 114, 97, 109, 92, 51, 48, 51, 92, 50,
  53, 48, 116, 114, 101, 115, 32, 70, 105, 108, 116, 114, 101, 32, 76, 111,
  99, 97, 108, 32, 110, 111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111,
  110, 32, 45, 32, 76, 111, 99, 97, 108, 32, 110, 111, 114, 109, 97, 108,
  105, 122, 97, 116, 105, 111, 110, 32, 112, 97, 114, 97, 109, 101, 116, 101,
  114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 111, 117, 98, 108, 101, 32, 101, 102, 102,
  101, 116, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 54, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 121, 111, 110, 32, 47,
  32, 114, 97, 100, 105, 117, 115, 32, 61, 32, 105, 110, 116, 40, 54, 44,
  49, 44, 54, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  101, 105, 103, 104, 98, 111, 114, 104, 111, 111, 100, 32, 115, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53,
  44, 48, 44, 52, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  65, 118, 101, 114, 97, 103, 101, 32, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 48, 44,
  52, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110,
  115, 116, 114, 97, 105, 110, 32, 118, 97, 108, 117, 101, 115, 32, 61, 32,
  98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 97, 110, 97, 117, 120, 32, 47, 32, 99, 104, 97, 110, 110, 101,
  108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44,
  34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71,
  66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114,
  111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103,
  104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114,
  97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34,
  75, 101, 121, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34, 99, 104,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34,
  71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65,
  108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 80, 97, 114, 97, 109, 92, 51, 48, 51,
  92, 50, 53, 48, 116, 114, 101, 115, 32, 70, 105, 108, 116, 114, 101, 32,
  66, 111, 111, 115, 116, 45, 70, 97, 100, 101, 32, 45, 32, 66, 111, 111,
  115, 116, 45, 70, 97, 100, 101, 32, 112, 97, 114, 97, 109, 101, 116, 101,
  114, 115, 32, 58, 32, 83, 105, 45, 73, 102, 32, 65, 109, 112, 108, 105,
  116, 117, 100, 101, 32, 83, 117, 112, 46, 32, 48, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 80, 104, 111, 116, 111, 67, 111,
  109, 105, 120, 32, 79, 112, 116, 105, 111, 110, 115, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 85,
  116, 105, 108, 105, 115, 101, 114, 32, 47, 32, 117, 115, 101, 32, 112, 99,
  32, 111, 112, 116, 105, 111, 110, 115, 32, 61, 32, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 101, 110, 99,
  105, 108, 98, 119, 32, 115, 105, 122, 101, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 51, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 80, 101, 110, 99, 105, 108, 98, 119, 32, 97, 109, 112,
  108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 54,
  48, 44, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 66, 108, 101, 110, 100, 32, 111, 112, 97, 99, 105, 116, 121, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 101, 110, 100, 32, 114, 101,
  118, 101, 114, 116, 32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111,
  111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101,
  118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  101, 117, 114, 115, 32, 47, 32, 65, 117, 116, 104, 111, 114, 115, 32, 58,
  32, 60, 105, 62, 83, 97, 109, 106, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 49, 47, 50, 53,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  67, 111, 117, 108, 101, 117, 114, 115, 95, 77, 101, 116, 97, 108, 108, 105,
  113, 117, 101, 115, 32, 58, 10, 84, 114, 97, 110, 115, 112, 97, 114, 101,
  110, 99, 101, 61, 36, 49, 10, 82, 101, 110, 100, 117, 61, 36, 50, 10,
  65, 109, 112, 108, 105, 116, 117, 100, 101, 61, 36, 51, 10, 78, 111, 105,
  115, 101, 95, 116, 121, 112, 101, 61, 36, 52, 10, 78, 111, 105, 115, 101,
  95, 67, 104, 97, 110, 110, 101, 108, 61, 55, 10, 86, 97, 108, 117, 101,
  95, 114, 97, 110, 103, 101, 61, 36, 53, 10, 68, 111, 117, 98, 108, 101,
  95, 101, 102, 102, 101, 116, 61, 36, 54, 10, 76, 111, 99, 97, 108, 95,
  110, 111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110, 95, 65, 109,
  112, 108, 105, 116, 117, 100, 101, 61, 36, 55, 10, 82, 97, 100, 105, 117,
  115, 61, 36, 56, 10, 78, 101, 105, 103, 104, 98, 111, 114, 104, 111, 111,
  100, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 36, 57, 10,
  65, 118, 101, 114, 97, 103, 101, 95, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 61, 36, 49, 48, 10, 67, 111, 110, 115, 116, 114, 97, 105, 110,
  95, 118, 97, 108, 117, 101, 115, 61, 36, 49, 49, 10, 76, 111, 99, 97,
  108, 95, 110, 111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110, 95,
  67, 104, 97, 110, 110, 101, 108, 61, 36, 49, 50, 10, 98, 111, 111, 115,
  116, 95, 102, 97, 100, 101, 95, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  61, 36, 49, 51, 10, 85, 116, 105, 108, 105, 115, 101, 114, 95, 80, 104,
  111, 116, 111, 99, 111, 109, 105, 120, 95, 79, 112, 116, 105, 111, 110, 115,
  61, 36, 49, 52, 10, 80, 101, 110, 99, 105, 108, 98, 119, 95, 83, 105,
  122, 101, 61, 36, 49, 53, 10, 80, 101, 110, 99, 105, 108, 98, 119, 95,
  65, 109, 112, 108, 105, 116, 117, 100, 101, 61, 36, 49, 54, 10, 66, 108,
  101, 110, 100, 95, 115, 111, 102, 116, 95, 108, 105, 103, 104, 116, 95, 79,
  112, 97, 99, 105, 116, 121, 61, 36, 49, 55, 10, 66, 108, 101, 110, 100,
  95, 115, 111, 102, 116, 95, 108, 105, 103, 104, 116, 95, 82, 101, 118, 101,
  114, 116, 95, 108, 97, 121, 101, 114, 115, 61, 36, 49, 56, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  45, 105, 102, 32, 123, 36, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110,
  99, 101, 61, 61, 49, 125, 10, 45, 114, 101, 109, 111, 118, 101, 95, 111,
  112, 97, 99, 105, 116, 121, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 85, 116, 105, 108, 105, 115, 101, 114,
  95, 80, 104, 111, 116, 111, 99, 111, 109, 105, 120, 95, 79, 112, 116, 105,
  111, 110, 115, 61, 61, 49, 125, 10, 45, 45, 112, 101, 110, 99, 105, 108,
  98, 119, 91, 45, 49, 93, 32, 36, 80, 101, 110, 99, 105, 108, 98, 119,
  95, 83, 105, 122, 101, 44, 36, 80, 101, 110, 99, 105, 108, 98, 119, 95,
  65, 109, 112, 108, 105, 116, 117, 100, 101, 10, 45, 105, 102, 32, 123, 36,
  68, 111, 117, 98, 108, 101, 95, 101, 102, 102, 101, 116, 61, 61, 49, 125,
  10, 45, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101,
  95, 108, 111, 99, 97, 108, 91, 45, 50, 93, 32, 36, 76, 111, 99, 97,
  108, 95, 110, 111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110, 95,
  65, 109, 112, 108, 105, 116, 117, 100, 101, 44, 36, 82, 97, 100, 105, 117,
  115, 44, 36, 78, 101, 105, 103, 104, 98, 111, 114, 104, 111, 111, 100, 95,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 44, 36, 65, 118, 101, 114,
  97, 103, 101, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 44, 36,
  67, 111, 110, 115, 116, 114, 97, 105, 110, 95, 118, 97, 108, 117, 101, 115,
  44, 36, 76, 111, 99, 97, 108, 95, 110, 111, 114, 109, 97, 108, 105, 122,
  97, 116, 105, 111, 110, 95, 67, 104, 97, 110, 110, 101, 108, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 110, 111, 105, 115, 101,
  91, 45, 50, 93, 32, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 44,
  36, 78, 111, 105, 115, 101, 95, 116, 121, 112, 101, 44, 36, 78, 111, 105,
  115, 101, 95, 67, 104, 97, 110, 110, 101, 108, 44, 36, 86, 97, 108, 117,
  101, 95, 114, 97, 110, 103, 101, 10, 45, 105, 102, 32, 123, 36, 82, 101,
  110, 100, 117, 61, 61, 48, 125, 10, 45, 103, 105, 109, 112, 95, 108, 111,
  99, 97, 108, 95, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 91,
  45, 50, 93, 32, 48, 44, 48, 44, 49, 48, 48, 44, 48, 44, 55, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 101, 110,
  100, 117, 61, 61, 49, 125, 10, 45, 103, 105, 109, 112, 95, 108, 111, 99,
  97, 108, 95, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 91, 45,
  50, 93, 32, 48, 44, 48, 44, 49, 48, 48, 44, 48, 44, 49, 52, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 110, 111, 114,
  109, 97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 91, 45, 50, 93,
  32, 36, 76, 111, 99, 97, 108, 95, 110, 111, 114, 109, 97, 108, 105, 122,
  97, 116, 105, 111, 110, 95, 65, 109, 112, 108, 105, 116, 117, 100, 101, 44,
  36, 82, 97, 100, 105, 117, 115, 44, 36, 78, 101, 105, 103, 104, 98, 111,
  114, 104, 111, 111, 100, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  44, 36, 65, 118, 101, 114, 97, 103, 101, 95, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 44, 36, 67, 111, 110, 115, 116, 114, 97, 105, 110, 95,
  118, 97, 108, 117, 101, 115, 44, 36, 76, 111, 99, 97, 108, 95, 110, 111,
  114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110, 95, 67, 104, 97, 110,
  110, 101, 108, 10, 45, 105, 102, 32, 123, 36, 98, 111, 111, 115, 116, 95,
  102, 97, 100, 101, 95, 65, 109, 112, 108, 105, 116, 117, 100, 101, 62, 48,
  125, 10, 45, 103, 105, 109, 112, 95, 98, 111, 111, 115, 116, 95, 102, 97,
  100, 101, 91, 45, 50, 93, 32, 36, 98, 111, 111, 115, 116, 95, 102, 97,
  100, 101, 95, 65, 109, 112, 108, 105, 116, 117, 100, 101, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91,
  45, 50, 44, 45, 49, 93, 32, 51, 54, 44, 36, 66, 108, 101, 110, 100,
  95, 115, 111, 102, 116, 95, 108, 105, 103, 104, 116, 95, 79, 112, 97, 99,
  105, 116, 121, 44, 36, 66, 108, 101, 110, 100, 95, 115, 111, 102, 116, 95,
  108, 105, 103, 104, 116, 95, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121,
  101, 114, 115, 10, 45, 101, 108, 115, 101, 10, 45, 105, 102, 32, 123, 36,
  68, 111, 117, 98, 108, 101, 95, 101, 102, 102, 101, 116, 61, 61, 49, 125,
  10, 45, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101,
  95, 108, 111, 99, 97, 108, 91, 45, 49, 93, 32, 36, 76, 111, 99, 97,
  108, 95, 110, 111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110, 95,
  65, 109, 112, 108, 105, 116, 117, 100, 101, 44, 36, 82, 97, 100, 105, 117,
  115, 44, 36, 78, 101, 105, 103, 104, 98, 111, 114, 104, 111, 111, 100, 95,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 44, 36, 65, 118, 101, 114,
  97, 103, 101, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 44, 36,
  67, 111, 110, 115, 116, 114, 97, 105, 110, 95, 118, 97, 108, 117, 101, 115,
  44, 36, 76, 111, 99, 97, 108, 95, 110, 111, 114, 109, 97, 108, 105, 122,
  97, 116, 105, 111, 110, 95, 67, 104, 97, 110, 110, 101, 108, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 110, 111, 105, 115, 101,
  91, 45, 49, 93, 32, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 44,
  36, 78, 111, 105, 115, 101, 95, 116, 121, 112, 101, 44, 36, 78, 111, 105,
  115, 101, 95, 67, 104, 97, 110, 110, 101, 108, 44, 36, 86, 97, 108, 117,
  101, 95, 114, 97, 110, 103, 101, 10, 45, 105, 102, 32, 123, 36, 82, 101,
  110, 100, 117, 61, 61, 48, 125, 10, 45, 103, 105, 109, 112, 95, 108, 111,
  99, 97, 108, 95, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 91,
  45, 49, 93, 32, 48, 44, 48, 44, 49, 48, 48, 44, 48, 44, 55, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 101, 110,
  100, 117, 61, 61, 49, 125, 10, 45, 103, 105, 109, 112, 95, 108, 111, 99,
  97, 108, 95, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 91, 45,
  49, 93, 32, 48, 44, 48, 44, 49, 48, 48, 44, 48, 44, 49, 52, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 110, 111, 114,
  109, 97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 91, 45, 49, 93,
  32, 36, 76, 111, 99, 97, 108, 95, 110, 111, 114, 109, 97, 108, 105, 122,
  97, 116, 105, 111, 110, 95, 65, 109, 112, 108, 105, 116, 117, 100, 101, 44,
  36, 82, 97, 100, 105, 117, 115, 44, 36, 78, 101, 105, 103, 104, 98, 111,
  114, 104, 111, 111, 100, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  44, 36, 65, 118, 101, 114, 97, 103, 101, 95, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 44, 36, 67, 111, 110, 115, 116, 114, 97, 105, 110, 95,
  118, 97, 108, 117, 101, 115, 44, 36, 76, 111, 99, 97, 108, 95, 110, 111,
  114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110, 95, 67, 104, 97, 110,
  110, 101, 108, 10, 45, 105, 102, 32, 123, 36, 98, 111, 111, 115, 116, 95,
  102, 97, 100, 101, 95, 65, 109, 112, 108, 105, 116, 117, 100, 101, 62, 48,
  125, 10, 45, 103, 105, 109, 112, 95, 98, 111, 111, 115, 116, 95, 102, 97,
  100, 101, 91, 45, 49, 93, 32, 36, 98, 111, 111, 115, 116, 95, 102, 97,
  100, 101, 95, 65, 109, 112, 108, 105, 116, 117, 100, 101, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 67, 111, 117, 108, 101, 117, 114, 115, 95,
  77, 101, 116, 97, 108, 108, 105, 113, 117, 101, 115, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 67, 111, 117, 108,
  101, 117, 114, 115, 95, 77, 101, 116, 97, 108, 108, 105, 113, 117, 101, 115,
  32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35, 64,
  103, 105, 109, 112, 32, 67, 111, 117, 108, 101, 117, 114, 115, 32, 112, 115,
  121, 99, 104, 101, 100, 101, 108, 105, 113, 117, 101, 115, 32, 58, 32, 67,
  111, 117, 108, 101, 117, 114, 115, 95, 80, 115, 121, 99, 104, 101, 100, 101,
  108, 105, 113, 117, 101, 115, 44, 32, 67, 111, 117, 108, 101, 117, 114, 115,
  95, 80, 115, 121, 99, 104, 101, 100, 101, 108, 105, 113, 117, 101, 115, 95,
  112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 80, 97, 114, 97, 109, 92, 51, 48,
  51, 92, 50, 53, 48, 116, 114, 101, 115, 32, 70, 105, 108, 116, 114, 101,
  32, 80, 97, 105, 110, 116, 105, 110, 103, 32, 45, 32, 80, 97, 105, 110,
  116, 105, 110, 103, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 32, 61,
  32, 105, 110, 116, 40, 53, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 101, 116, 97, 105, 108, 115, 32, 115, 99,
  97, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 46, 53, 44,
  48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  111, 108, 111, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 53,
  44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 53, 48, 44, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 104, 97, 114, 112, 101, 110, 32, 115, 104, 97,
  100, 101, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 80, 97,
  114, 97, 109, 92, 51, 48, 51, 92, 50, 53, 48, 116, 114, 101, 115, 32,
  70, 105, 108, 116, 114, 101, 32, 77, 111, 114, 112, 104, 111, 32, 45, 32,
  77, 111, 114, 112, 104, 111, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114,
  115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 99, 116, 105, 111, 110, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 53, 44, 34, 69, 114, 111, 115, 105, 111, 110, 34,
  44, 34, 68, 105, 108, 97, 116, 105, 111, 110, 34, 44, 34, 79, 112, 101,
  110, 105, 110, 103, 34, 44, 34, 67, 108, 111, 115, 105, 110, 103, 34, 44,
  34, 79, 114, 105, 103, 105, 110, 97, 108, 32, 45, 32, 69, 114, 111, 115,
  105, 111, 110, 34, 44, 34, 68, 105, 108, 97, 116, 105, 111, 110, 32, 45,
  32, 79, 114, 105, 103, 105, 110, 97, 108, 34, 44, 34, 79, 114, 105, 103,
  105, 110, 97, 108, 32, 45, 32, 79, 112, 101, 110, 105, 110, 103, 34, 44,
  34, 67, 108, 111, 115, 105, 110, 103, 32, 45, 32, 79, 114, 105, 103, 105,
  110, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 53, 44, 48, 44, 51, 50,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 118, 101, 114,
  116, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 83, 113,
  117, 97, 114, 101, 34, 44, 34, 79, 99, 116, 97, 103, 111, 110, 97, 108,
  34, 44, 34, 67, 105, 114, 99, 117, 108, 97, 114, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 97, 110, 97, 117, 120, 32, 47, 32,
  99, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 50, 44, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66,
  65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108,
  117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97,
  98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44,
  34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97,
  108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 65, 108, 112, 104,
  97, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34,
  82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108,
  117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 80, 97, 114,
  97, 109, 92, 51, 48, 51, 92, 50, 53, 48, 116, 114, 101, 115, 32, 70,
  105, 108, 116, 114, 101, 32, 67, 97, 114, 116, 111, 111, 110, 32, 45, 32,
  67, 97, 114, 116, 111, 111, 110, 32, 112, 97, 114, 97, 109, 101, 116, 101,
  114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 56, 44, 48, 44, 49, 54, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 114, 112, 101,
  110, 105, 110, 103, 32, 61, 32, 102, 108, 111, 97, 116, 40, 56, 48, 44,
  48, 44, 52, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  84, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 50, 48, 44, 49, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 84, 104, 105, 99, 107, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 50, 53, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 46, 53, 44, 48, 44, 51, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 81, 117, 97, 110, 116, 105, 122,
  97, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 56, 44,
  50, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 73, 110, 118, 101, 114, 115, 101, 114, 32,
  108, 101, 115, 32, 99, 111, 117, 108, 101, 117, 114, 115, 32, 45, 32, 78,
  101, 103, 97, 116, 105, 118, 101, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 118, 101, 114,
  115, 101, 114, 32, 108, 101, 115, 32, 99, 111, 117, 108, 101, 117, 114, 115,
  32, 47, 32, 110, 101, 103, 97, 116, 105, 118, 101, 32, 61, 32, 98, 111,
  111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 80, 105, 120, 92, 51, 48, 51, 92, 50, 53,
  49, 108, 105, 115, 101, 114, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 105, 120, 101, 108, 105,
  115, 101, 114, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 101, 117, 114, 115, 32, 47, 32, 65,
  117, 116, 104, 111, 114, 115, 32, 58, 32, 60, 105, 62, 83, 97, 109, 106,
  47, 82, 111, 110, 111, 117, 110, 111, 117, 114, 115, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49,
  47, 49, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 67, 111, 117, 108, 101, 117, 114, 115, 95, 80, 115, 121, 99,
  104, 101, 100, 101, 108, 105, 113, 117, 101, 115, 32, 58, 10, 65, 98, 115,
  116, 114, 97, 99, 116, 105, 111, 110, 61, 36, 49, 10, 68, 101, 116, 97,
  105, 108, 115, 95, 115, 99, 97, 108, 101, 61, 36, 50, 10, 67, 111, 108,
  111, 114, 61, 36, 51, 10, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  61, 36, 52, 10, 83, 104, 97, 114, 112, 101, 110, 95, 115, 104, 97, 100,
  101, 115, 61, 36, 53, 10, 65, 99, 116, 105, 111, 110, 61, 36, 54, 10,
  83, 105, 122, 101, 61, 36, 55, 10, 73, 110, 118, 101, 114, 116, 95, 99,
  111, 108, 111, 114, 115, 61, 36, 56, 10, 83, 104, 97, 112, 101, 61, 36,
  57, 10, 67, 104, 97, 110, 110, 101, 108, 95, 109, 111, 114, 112, 104, 111,
  61, 36, 49, 48, 10, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 95,
  99, 97, 114, 116, 111, 111, 110, 61, 36, 49, 49, 10, 83, 104, 97, 114,
  112, 101, 110, 105, 110, 103, 95, 99, 97, 114, 116, 111, 111, 110, 61, 36,
  49, 50, 10, 84, 104, 114, 101, 115, 104, 111, 108, 100, 95, 99, 97, 114,
  116, 111, 111, 110, 61, 36, 49, 51, 10, 84, 104, 105, 99, 107, 110, 101,
  115, 115, 95, 99, 97, 114, 116, 111, 111, 110, 61, 36, 49, 52, 10, 67,
  111, 108, 111, 114, 95, 99, 97, 114, 116, 111, 111, 110, 61, 36, 49, 53,
  10, 81, 117, 97, 110, 116, 105, 122, 97, 116, 105, 111, 110, 95, 99, 97,
  114, 116, 111, 111, 110, 61, 36, 49, 54, 10, 78, 101, 103, 97, 116, 105,
  102, 61, 36, 49, 55, 10, 80, 105, 120, 101, 108, 105, 115, 101, 114, 61,
  36, 49, 56, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 36, 80, 105, 120, 101,
  108, 105, 115, 101, 114, 61, 61, 49, 125, 10, 108, 97, 114, 103, 101, 117,
  114, 95, 111, 114, 105, 103, 105, 110, 101, 61, 123, 119, 125, 10, 104, 97,
  117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 61, 123, 104,
  125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 50, 48,
  37, 44, 50, 48, 37, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 10, 45, 114, 101, 115, 105, 122, 101, 32, 36, 108, 97, 114, 103,
  101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 44, 36, 104, 97, 117,
  116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 10, 45, 99, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121,
  91, 45, 49, 93, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110,
  111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112,
  95, 112, 97, 105, 110, 116, 105, 110, 103, 91, 45, 49, 93, 32, 36, 65,
  98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 44, 36, 68, 101, 116, 97,
  105, 108, 115, 95, 115, 99, 97, 108, 101, 44, 36, 67, 111, 108, 111, 114,
  44, 36, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 44, 36, 83, 104,
  97, 114, 112, 101, 110, 95, 115, 104, 97, 100, 101, 115, 10, 45, 103, 105,
  109, 112, 95, 109, 111, 114, 112, 104, 111, 91, 45, 49, 93, 32, 36, 65,
  99, 116, 105, 111, 110, 44, 36, 83, 105, 122, 101, 44, 36, 73, 110, 118,
  101, 114, 116, 95, 99, 111, 108, 111, 114, 115, 44, 36, 83, 104, 97, 112,
  101, 44, 36, 67, 104, 97, 110, 110, 101, 108, 95, 109, 111, 114, 112, 104,
  111, 44, 48, 10, 45, 45, 99, 97, 114, 116, 111, 111, 110, 91, 45, 49,
  93, 32, 36, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 95, 99, 97,
  114, 116, 111, 111, 110, 44, 36, 83, 104, 97, 114, 112, 101, 110, 105, 110,
  103, 95, 99, 97, 114, 116, 111, 111, 110, 44, 36, 84, 104, 114, 101, 115,
  104, 111, 108, 100, 95, 99, 97, 114, 116, 111, 111, 110, 44, 36, 84, 104,
  105, 99, 107, 110, 101, 115, 115, 95, 99, 97, 114, 116, 111, 111, 110, 44,
  36, 67, 111, 108, 111, 114, 95, 99, 97, 114, 116, 111, 111, 110, 44, 36,
  81, 117, 97, 110, 116, 105, 122, 97, 116, 105, 111, 110, 95, 99, 97, 114,
  116, 111, 111, 110, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100,
  91, 45, 50, 44, 45, 49, 93, 32, 51, 55, 44, 49, 44, 48, 10, 45,
  116, 114, 97, 110, 115, 102, 101, 114, 95, 99, 111, 108, 111, 114, 115, 32,
  48, 10, 45, 105, 102, 32, 123, 36, 78, 101, 103, 97, 116, 105, 102, 61,
  61, 49, 125, 10, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49,
  93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 67, 111, 117, 108, 101, 117, 114, 115, 95, 80, 115,
  121, 99, 104, 101, 100, 101, 108, 105, 113, 117, 101, 115, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 67, 111, 117,
  108, 101, 117, 114, 115, 95, 80, 115, 121, 99, 104, 101, 100, 101, 108, 105,
  113, 117, 101, 115, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45,
  49, 10, 35, 64, 103, 105, 109, 112, 32, 84, 101, 120, 116, 117, 114, 101,
  32, 48, 48, 49, 32, 58, 32, 115, 97, 109, 106, 95, 103, 105, 109, 112,
  95, 116, 101, 120, 116, 117, 114, 101, 95, 122, 101, 114, 111, 95, 122, 101,
  114, 111, 95, 117, 110, 44, 32, 115, 97, 109, 106, 95, 103, 105, 109, 112,
  95, 116, 101, 120, 116, 117, 114, 101, 95, 122, 101, 114, 111, 95, 122, 101,
  114, 111, 95, 117, 110, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 66, 108,
  111, 103, 32, 45, 32, 67, 111, 109, 109, 101, 110, 116, 97, 105, 114, 101,
  115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107,
  40, 34, 104, 116, 116, 112, 58, 47, 47, 115, 97, 109, 106, 99, 114, 101,
  97, 116, 105, 111, 110, 115, 46, 98, 108, 111, 103, 115, 112, 111, 116, 46,
  99, 97, 47, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 115, 97, 109,
  106, 99, 114, 101, 97, 116, 105, 111, 110, 115, 46, 98, 108, 111, 103, 115,
  112, 111, 116, 46, 99, 97, 47, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 103, 114, 97, 100, 105, 101, 110,
  116, 32, 82, 71, 66, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 46, 53, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  77, 97, 120, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 103, 114,
  97, 100, 105, 101, 110, 116, 32, 82, 71, 66, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 50, 48, 44, 49, 48, 44, 53, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 110, 111, 105, 115, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 56, 48, 46, 48, 44, 52, 48,
  44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 50, 48, 44, 50,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 117, 116, 111,
  109, 97, 116, 105, 99, 32, 99, 111, 108, 111, 114, 32, 98, 97, 108, 97,
  110, 99, 101, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50,
  48, 49, 51, 47, 49, 50, 47, 48, 52, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 103, 105,
  109, 112, 95, 116, 101, 120, 116, 117, 114, 101, 95, 122, 101, 114, 111, 95,
  122, 101, 114, 111, 95, 117, 110, 32, 58, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 83, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 95, 71, 114, 97, 100, 105, 101, 110, 116, 95,
  82, 71, 66, 61, 36, 49, 10, 77, 97, 120, 95, 116, 104, 114, 101, 115,
  104, 111, 108, 100, 95, 71, 114, 97, 100, 105, 101, 110, 116, 95, 82, 71,
  66, 61, 36, 50, 10, 65, 109, 112, 108, 105, 116, 117, 100, 101, 95, 78,
  111, 105, 115, 101, 61, 36, 51, 10, 67, 111, 108, 111, 114, 115, 61, 36,
  52, 10, 65, 117, 116, 111, 109, 97, 116, 105, 99, 95, 99, 111, 108, 111,
  114, 95, 98, 97, 108, 97, 110, 99, 101, 61, 36, 53, 10, 45, 45, 103,
  105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 10, 45,
  103, 105, 109, 112, 95, 103, 114, 97, 100, 105, 101, 110, 116, 50, 114, 103,
  98, 91, 45, 49, 93, 32, 36, 83, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 95, 71, 114, 97, 100, 105, 101, 110, 116, 95, 82, 71, 66, 44, 48,
  44, 36, 77, 97, 120, 95, 116, 104, 114, 101, 115, 104, 111, 108, 100, 95,
  71, 114, 97, 100, 105, 101, 110, 116, 95, 82, 71, 66, 44, 48, 44, 48,
  10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 51, 10, 45, 102, 105,
  108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 116, 111, 95, 114, 103, 98,
  91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 110, 111, 105, 115, 101,
  91, 45, 49, 93, 32, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 95,
  78, 111, 105, 115, 101, 44, 48, 44, 50, 44, 48, 10, 45, 103, 105, 109,
  112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 50,
  53, 44, 49, 44, 48, 10, 45, 103, 105, 109, 112, 95, 116, 107, 95, 99,
  111, 108, 111, 114, 116, 101, 109, 112, 91, 45, 49, 93, 32, 36, 67, 111,
  108, 111, 114, 115, 44, 36, 65, 117, 116, 111, 109, 97, 116, 105, 99, 95,
  99, 111, 108, 111, 114, 95, 98, 97, 108, 97, 110, 99, 101, 10, 45, 103,
  105, 109, 112, 95, 108, 111, 99, 97, 108, 95, 111, 114, 105, 101, 110, 116,
  97, 116, 105, 111, 110, 91, 45, 49, 93, 32, 48, 44, 48, 44, 49, 48,
  48, 44, 48, 44, 55, 10, 45, 103, 105, 109, 112, 95, 110, 111, 114, 109,
  97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 91, 45, 49, 93, 32,
  48, 44, 54, 44, 53, 44, 50, 48, 44, 49, 44, 50, 10, 45, 103, 105,
  109, 112, 95, 98, 108, 101, 110, 100, 91, 48, 44, 45, 49, 93, 32, 49,
  51, 44, 49, 44, 48, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 115, 97, 109, 106, 95, 103, 105, 109, 112, 95, 116, 101, 120, 116,
  117, 114, 101, 95, 122, 101, 114, 111, 95, 122, 101, 114, 111, 95, 117, 110,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 115, 97, 109, 106, 95, 103, 105, 109, 112, 95, 116, 101, 120, 116, 117,
  114, 101, 95, 122, 101, 114, 111, 95, 122, 101, 114, 111, 95, 117, 110, 32,
  36, 42, 34, 44, 36, 45, 49, 10, 115, 97, 109, 106, 95, 114, 105, 101,
  110, 95, 99, 111, 110, 116, 111, 117, 114, 115, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49,
  93, 10, 35, 64, 103, 105, 109, 112, 32, 95, 10, 35, 64, 103, 105, 109,
  112, 32, 60, 105, 62, 67, 111, 110, 116, 111, 117, 114, 115, 60, 47, 105,
  62, 10, 35, 64, 103, 105, 109, 112, 32, 84, 101, 115, 116, 115, 32, 99,
  111, 110, 116, 111, 117, 114, 115, 32, 58, 32, 84, 101, 115, 116, 115, 95,
  67, 111, 110, 116, 111, 117, 114, 115, 95, 115, 97, 109, 106, 44, 32, 84,
  101, 115, 116, 115, 95, 67, 111, 110, 116, 111, 117, 114, 115, 95, 115, 97,
  109, 106, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 82, 101, 110, 100, 117,
  32, 45, 32, 82, 101, 110, 100, 101, 114, 105, 110, 103, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  82, 101, 110, 100, 117, 32, 47, 32, 114, 101, 110, 100, 101, 114, 105, 110,
  103, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 69, 100,
  103, 101, 32, 79, 102, 102, 115, 101, 116, 115, 34, 44, 34, 69, 100, 103,
  101, 32, 79, 102, 102, 115, 101, 116, 115, 32, 38, 32, 73, 115, 111, 112,
  104, 111, 116, 101, 115, 34, 44, 34, 73, 115, 111, 112, 104, 111, 116, 101,
  115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 80, 97, 114, 97, 109, 92, 51, 48, 51, 92, 50, 53,
  48, 116, 114, 101, 115, 32, 70, 105, 108, 116, 114, 101, 32, 69, 100, 103,
  101, 115, 32, 79, 102, 102, 115, 101, 116, 115, 32, 45, 32, 69, 100, 103,
  101, 115, 32, 79, 102, 102, 115, 101, 116, 115, 32, 112, 97, 114, 97, 109,
  101, 116, 101, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114,
  101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  53, 44, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 99, 97, 108, 101, 32, 61, 32, 105, 110, 116, 40, 52, 44, 48,
  44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104,
  105, 99, 107, 110, 101, 115, 115, 32, 61, 32, 105, 110, 116, 40, 49, 44,
  48, 44, 49, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 80, 97, 114, 97, 109, 92, 51, 48, 51, 92,
  50, 53, 48, 116, 114, 101, 115, 32, 70, 105, 108, 116, 114, 101, 32, 73,
  115, 111, 112, 104, 111, 116, 101, 115, 32, 45, 32, 73, 115, 111, 112, 104,
  111, 116, 101, 115, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 76, 101, 118, 101, 108, 115, 32, 61, 32, 105, 110, 116, 40,
  52, 48, 44, 49, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 80, 97, 114,
  97, 109, 92, 51, 48, 51, 92, 50, 53, 48, 116, 114, 101, 115, 32, 71,
  105, 109, 112, 32, 65, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 32,
  83, 109, 111, 111, 116, 104, 105, 110, 103, 32, 45, 32, 71, 105, 109, 112,
  32, 65, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 32, 83, 109, 111,
  111, 116, 104, 105, 110, 103, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114,
  115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 48, 48, 48, 44, 48, 44, 51, 48,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 66, 108, 101, 110, 100, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 100,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 65, 100,
  100, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34, 65, 110, 100, 34,
  44, 34, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 66, 108, 117, 101,
  34, 44, 34, 66, 117, 114, 110, 34, 44, 34, 68, 97, 114, 107, 101, 110,
  34, 44, 34, 68, 105, 102, 102, 101, 114, 101, 110, 99, 101, 34, 44, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 68, 105, 118, 105, 100, 101,
  34, 44, 34, 68, 111, 100, 103, 101, 34, 44, 34, 69, 120, 99, 108, 117,
  115, 105, 111, 110, 34, 44, 34, 70, 114, 101, 101, 122, 101, 34, 44, 34,
  71, 114, 97, 105, 110, 32, 101, 120, 116, 114, 97, 99, 116, 34, 44, 34,
  71, 114, 97, 105, 110, 32, 109, 101, 114, 103, 101, 34, 44, 34, 71, 114,
  101, 101, 110, 34, 44, 34, 72, 97, 114, 100, 32, 108, 105, 103, 104, 116,
  34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 72, 97, 114,
  100, 32, 109, 105, 120, 34, 44, 34, 72, 117, 101, 34, 44, 34, 73, 110,
  116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 34, 44, 34, 76, 105,
  103, 104, 116, 101, 110, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115,
  115, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 98, 117, 114, 110, 34,
  44, 34, 76, 105, 110, 101, 97, 114, 32, 108, 105, 103, 104, 116, 34, 44,
  34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 34, 77, 117, 108, 116, 105, 112, 108, 121, 34,
  44, 34, 78, 101, 103, 97, 116, 105, 111, 110, 34, 44, 34, 79, 114, 34,
  44, 34, 79, 118, 101, 114, 108, 97, 121, 34, 44, 34, 80, 105, 110, 32,
  108, 105, 103, 104, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 82, 101,
  102, 108, 101, 99, 116, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105,
  111, 110, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 83,
  104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 83,
  104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101, 48, 34, 44, 34,
  83, 111, 102, 116, 32, 98, 117, 114, 110, 34, 44, 34, 83, 111, 102, 116,
  32, 100, 111, 100, 103, 101, 34, 44, 34, 83, 111, 102, 116, 32, 108, 105,
  103, 104, 116, 34, 44, 34, 83, 99, 114, 101, 101, 110, 34, 44, 34, 83,
  116, 97, 109, 112, 34, 44, 34, 83, 117, 98, 116, 114, 97, 99, 116, 34,
  44, 34, 86, 97, 108, 117, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 34, 86, 105, 118, 105, 100, 32, 108, 105, 103, 104, 116, 34,
  44, 34, 88, 111, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121, 101, 114, 115, 32, 61,
  32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 101, 117, 114, 115, 32, 47, 32, 65, 117, 116, 104, 111, 114,
  115, 32, 58, 32, 60, 105, 62, 83, 97, 109, 106, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49,
  47, 49, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 84, 101, 115, 116, 115, 95, 67, 111, 110, 116, 111, 117, 114,
  115, 95, 115, 97, 109, 106, 32, 58, 10, 82, 101, 110, 100, 117, 61, 36,
  49, 10, 35, 35, 70, 105, 108, 116, 114, 101, 32, 69, 100, 103, 101, 115,
  32, 79, 102, 102, 115, 101, 116, 115, 10, 69, 79, 95, 83, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 61, 36, 50, 10, 69, 79, 95, 84, 104, 114,
  101, 115, 104, 111, 108, 100, 61, 36, 51, 10, 69, 79, 95, 83, 99, 97,
  108, 101, 61, 36, 52, 10, 69, 79, 95, 84, 104, 105, 99, 107, 110, 101,
  115, 115, 61, 36, 53, 10, 69, 79, 95, 78, 101, 103, 97, 116, 105, 118,
  101, 95, 99, 111, 108, 111, 114, 115, 61, 48, 10, 35, 35, 70, 105, 108,
  116, 114, 101, 32, 73, 115, 111, 112, 104, 111, 116, 101, 115, 10, 73, 115,
  111, 112, 104, 111, 116, 101, 115, 95, 76, 101, 118, 101, 108, 115, 61, 36,
  54, 10, 73, 115, 111, 112, 104, 111, 116, 101, 115, 95, 83, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 61, 36, 55, 10, 73, 115, 111, 112, 104, 111,
  116, 101, 115, 95, 70, 105, 108, 108, 105, 110, 103, 61, 48, 10, 35, 35,
  70, 105, 108, 116, 114, 101, 32, 71, 105, 109, 112, 32, 65, 110, 105, 115,
  111, 116, 114, 111, 112, 105, 99, 32, 83, 109, 111, 111, 116, 104, 105, 110,
  103, 10, 65, 109, 112, 108, 105, 116, 117, 100, 101, 61, 36, 56, 10, 35,
  35, 66, 108, 101, 110, 100, 10, 98, 108, 101, 110, 100, 61, 36, 57, 10,
  111, 112, 97, 99, 105, 116, 101, 61, 36, 49, 48, 10, 82, 101, 118, 101,
  114, 116, 95, 108, 97, 121, 101, 114, 115, 61, 36, 49, 49, 10, 108, 97,
  114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 61, 123, 119,
  125, 10, 104, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110,
  101, 61, 123, 104, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 36, 82, 101,
  110, 100, 117, 61, 61, 48, 125, 10, 45, 45, 103, 105, 109, 112, 95, 101,
  100, 103, 101, 95, 111, 102, 102, 115, 101, 116, 115, 32, 36, 69, 79, 95,
  83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 44, 36, 69, 79, 95, 84,
  104, 114, 101, 115, 104, 111, 108, 100, 44, 36, 69, 79, 95, 83, 99, 97,
  108, 101, 44, 36, 69, 79, 95, 84, 104, 105, 99, 107, 110, 101, 115, 115,
  44, 36, 69, 79, 95, 78, 101, 103, 97, 116, 105, 118, 101, 95, 99, 111,
  108, 111, 114, 115, 10, 45, 103, 105, 109, 112, 95, 97, 110, 105, 115, 111,
  116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103,
  91, 45, 49, 93, 32, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 44,
  48, 46, 55, 44, 48, 46, 51, 44, 48, 46, 54, 44, 49, 46, 49, 44,
  48, 46, 56, 44, 51, 48, 44, 50, 44, 48, 44, 49, 44, 49, 44, 49,
  44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  82, 101, 110, 100, 117, 61, 61, 49, 125, 10, 45, 45, 103, 105, 109, 112,
  95, 101, 100, 103, 101, 95, 111, 102, 102, 115, 101, 116, 115, 32, 36, 69,
  79, 95, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 44, 36, 69, 79,
  95, 84, 104, 114, 101, 115, 104, 111, 108, 100, 44, 36, 69, 79, 95, 83,
  99, 97, 108, 101, 44, 36, 69, 79, 95, 84, 104, 105, 99, 107, 110, 101,
  115, 115, 44, 36, 69, 79, 95, 78, 101, 103, 97, 116, 105, 118, 101, 95,
  99, 111, 108, 111, 114, 115, 10, 45, 103, 105, 109, 112, 95, 97, 110, 105,
  115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105,
  110, 103, 91, 45, 49, 93, 32, 36, 65, 109, 112, 108, 105, 116, 117, 100,
  101, 44, 48, 46, 55, 44, 48, 46, 51, 44, 48, 46, 54, 44, 49, 46,
  49, 44, 48, 46, 56, 44, 51, 48, 44, 50, 44, 48, 44, 49, 44, 49,
  44, 49, 44, 49, 10, 45, 103, 105, 109, 112, 95, 105, 115, 111, 112, 104,
  111, 116, 101, 115, 91, 48, 93, 32, 36, 73, 115, 111, 112, 104, 111, 116,
  101, 115, 95, 76, 101, 118, 101, 108, 115, 44, 36, 73, 115, 111, 112, 104,
  111, 116, 101, 115, 95, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 44,
  36, 73, 115, 111, 112, 104, 111, 116, 101, 115, 95, 70, 105, 108, 108, 105,
  110, 103, 10, 45, 103, 105, 109, 112, 95, 97, 110, 105, 115, 111, 116, 114,
  111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 91, 45,
  49, 93, 32, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 44, 48, 46,
  55, 44, 48, 46, 51, 44, 48, 46, 54, 44, 49, 46, 49, 44, 48, 46,
  56, 44, 51, 48, 44, 50, 44, 48, 44, 49, 44, 49, 44, 49, 44, 49,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 101,
  110, 100, 117, 61, 61, 50, 125, 10, 45, 45, 103, 105, 109, 112, 95, 105,
  115, 111, 112, 104, 111, 116, 101, 115, 91, 48, 93, 32, 36, 73, 115, 111,
  112, 104, 111, 116, 101, 115, 95, 76, 101, 118, 101, 108, 115, 44, 36, 73,
  115, 111, 112, 104, 111, 116, 101, 115, 95, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 44, 36, 73, 115, 111, 112, 104, 111, 116, 101, 115, 95, 70,
  105, 108, 108, 105, 110, 103, 10, 45, 103, 105, 109, 112, 95, 97, 110, 105,
  115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105,
  110, 103, 91, 45, 49, 93, 32, 36, 65, 109, 112, 108, 105, 116, 117, 100,
  101, 44, 48, 46, 55, 44, 48, 46, 51, 44, 48, 46, 54, 44, 49, 46,
  49, 44, 48, 46, 56, 44, 51, 48, 44, 50, 44, 48, 44, 49, 44, 49,
  44, 49, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109,
  112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 36,
  98, 108, 101, 110, 100, 44, 36, 111, 112, 97, 99, 105, 116, 101, 44, 36,
  82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 84, 101, 115, 116, 115, 95,
  67, 111, 110, 116, 111, 117, 114, 115, 95, 115, 97, 109, 106, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112,
  108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 84, 101,
  115, 116, 115, 95, 67, 111, 110, 116, 111, 117, 114, 115, 95, 115, 97, 109,
  106, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35,
  64, 103, 105, 109, 112, 32, 84, 101, 115, 116, 32, 105, 115, 111, 108, 105,
  110, 101, 51, 100, 32, 58, 32, 84, 101, 115, 116, 95, 73, 115, 111, 76,
  105, 110, 101, 51, 68, 95, 115, 97, 109, 106, 44, 32, 84, 101, 115, 116,
  95, 73, 115, 111, 76, 105, 110, 101, 51, 68, 95, 115, 97, 109, 106, 95,
  112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 80, 97, 114, 97, 109, 92, 51, 48,
  51, 92, 50, 53, 48, 116, 114, 101, 115, 32, 45, 32, 76, 111, 99, 97,
  108, 32, 78, 111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110, 32,
  45, 32, 80, 97, 114, 97, 109, 101, 116, 101, 114, 115, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  76, 111, 99, 97, 108, 32, 110, 111, 114, 109, 97, 108, 105, 122, 97, 116,
  105, 111, 110, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 44, 54, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 100, 105, 117, 115,
  32, 61, 32, 105, 110, 116, 40, 54, 44, 49, 44, 54, 52, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 101, 105, 103, 104, 98, 111, 114,
  104, 111, 111, 100, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 52, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 118, 101, 114, 97, 103, 101,
  32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 50, 48, 44, 48, 44, 52, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 110, 115, 116, 114, 97, 105, 110, 32,
  118, 97, 108, 117, 101, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101,
  108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 51, 44,
  34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71,
  66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114,
  111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103,
  104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114,
  97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34,
  75, 101, 121, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34, 99, 104,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34,
  71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65,
  108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 80, 97, 114, 97, 109, 92, 51, 48, 51,
  92, 50, 53, 48, 116, 114, 101, 115, 32, 73, 115, 111, 76, 105, 110, 101,
  51, 100, 32, 45, 32, 73, 115, 111, 76, 105, 110, 101, 51, 100, 32, 112,
  97, 114, 97, 109, 101, 116, 101, 114, 115, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 115, 111,
  108, 105, 110, 101, 51, 100, 32, 40, 37, 41, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 48, 48, 44, 50, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 67,
  111, 117, 108, 101, 117, 114, 32, 45, 32, 67, 111, 108, 111, 114, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 47, 32, 99, 111, 108, 111,
  114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 48, 44,
  48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 117, 108, 101, 117, 114, 32, 97, 108, 92, 51, 48, 51, 92, 50,
  53, 49, 97, 116, 111, 105, 114, 101, 32, 47, 32, 114, 97, 110, 100, 111,
  109, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 78, 111, 110, 32, 47, 32, 78, 111, 34, 44, 34, 82, 86, 66,
  32, 47, 32, 82, 71, 66, 34, 44, 34, 78, 105, 118, 101, 97, 117, 120,
  32, 100, 101, 32, 71, 114, 105, 115, 32, 47, 32, 71, 114, 97, 121, 115,
  99, 97, 108, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 82, 101, 110, 100, 117, 32, 51, 68, 32,
  45, 32, 82, 101, 110, 100, 101, 114, 105, 110, 103, 32, 51, 68, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110, 115, 32, 40, 53, 49,
  50, 42, 120, 41, 32, 61, 32, 105, 110, 116, 40, 50, 44, 49, 44, 56,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 97, 110, 103,
  108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 51,
  54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 97,
  110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90,
  45, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 82, 101, 110, 100, 117, 32, 45, 32,
  82, 101, 110, 100, 101, 114, 105, 110, 103, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 106, 117,
  115, 116, 101, 109, 101, 110, 116, 32, 100, 105, 109, 101, 110, 115, 105, 111,
  110, 115, 32, 45, 32, 97, 117, 116, 111, 99, 114, 111, 112, 32, 61, 32,
  98, 111, 111, 108, 40, 116, 114, 117, 101, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 84, 121, 112, 101, 32, 100, 101, 32, 114, 101, 110, 100,
  117, 32, 47, 32, 114, 101, 110, 100, 101, 114, 105, 110, 103, 32, 116, 121,
  112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 67, 111, 110,
  116, 111, 117, 114, 34, 44, 34, 67, 114, 97, 105, 101, 32, 45, 32, 67,
  104, 97, 108, 107, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 101, 117, 114, 115, 32, 47, 32, 65, 117, 116, 104, 111, 114, 115, 32,
  58, 32, 60, 105, 62, 83, 97, 109, 106, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 50, 47, 49, 48, 47, 50,
  49, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 84, 101, 115, 116, 95, 73, 115, 111, 76, 105, 110, 101, 51, 68, 95,
  115, 97, 109, 106, 32, 58, 10, 85, 116, 105, 108, 105, 115, 101, 114, 95,
  76, 111, 99, 97, 108, 95, 78, 111, 114, 109, 97, 108, 105, 122, 97, 116,
  105, 111, 110, 61, 36, 49, 10, 76, 95, 78, 95, 65, 109, 112, 108, 105,
  116, 117, 100, 101, 61, 36, 50, 10, 76, 95, 78, 95, 82, 97, 100, 105,
  117, 115, 61, 36, 51, 10, 76, 95, 78, 95, 78, 101, 105, 103, 104, 98,
  111, 114, 104, 111, 111, 100, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 61, 36, 52, 10, 76, 95, 78, 95, 65, 118, 101, 114, 97, 103, 101,
  95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 36, 53, 10, 76,
  95, 78, 95, 67, 111, 110, 115, 116, 114, 97, 105, 110, 95, 118, 97, 108,
  117, 101, 115, 61, 36, 54, 10, 76, 95, 78, 95, 67, 104, 97, 110, 110,
  101, 108, 61, 36, 55, 10, 73, 115, 111, 76, 105, 110, 101, 51, 100, 95,
  80, 111, 117, 114, 99, 101, 110, 116, 61, 36, 56, 10, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 61, 36, 57, 10, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 61, 36, 49, 48, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114,
  61, 36, 49, 49, 10, 65, 108, 112, 104, 97, 95, 67, 111, 117, 108, 101,
  117, 114, 61, 36, 49, 50, 10, 67, 111, 117, 108, 101, 117, 114, 115, 95,
  97, 108, 101, 97, 116, 111, 105, 114, 101, 115, 61, 36, 49, 51, 10, 68,
  105, 109, 101, 110, 115, 105, 111, 110, 115, 61, 36, 49, 52, 10, 88, 95,
  97, 110, 103, 108, 101, 61, 36, 49, 53, 10, 89, 95, 97, 110, 103, 108,
  101, 61, 36, 49, 54, 10, 90, 95, 97, 110, 103, 108, 101, 61, 36, 49,
  55, 10, 65, 106, 117, 115, 116, 101, 109, 101, 110, 116, 95, 68, 105, 109,
  101, 110, 115, 105, 111, 110, 115, 61, 36, 49, 56, 10, 84, 121, 112, 101,
  95, 100, 101, 95, 114, 101, 110, 100, 117, 61, 36, 49, 57, 10, 108, 97,
  114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 61, 123, 119,
  125, 10, 104, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110,
  101, 61, 123, 104, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 36, 108, 97,
  114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 62, 36, 104,
  97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 125, 10,
  68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 77, 97, 120, 61, 36, 108,
  97, 114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 10, 45,
  105, 102, 32, 123, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 77,
  97, 120, 62, 50, 48, 48, 48, 125, 10, 45, 114, 101, 115, 105, 122, 101,
  91, 45, 49, 93, 32, 50, 53, 48, 48, 44, 123, 36, 104, 97, 117, 116,
  101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 47, 36, 108, 97, 114,
  103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 42, 50, 53, 48,
  48, 125, 44, 49, 44, 49, 44, 51, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 108, 115, 101, 10, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95,
  77, 97, 120, 61, 36, 104, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105,
  103, 105, 110, 101, 10, 45, 105, 102, 32, 123, 36, 68, 105, 109, 101, 110,
  115, 105, 111, 110, 95, 77, 97, 120, 62, 50, 48, 48, 48, 125, 10, 45,
  114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 108, 97, 114,
  103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 47, 36, 104, 97,
  117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 42, 50, 53,
  48, 48, 125, 44, 50, 53, 48, 48, 44, 49, 44, 49, 44, 51, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 67, 111, 117, 108, 101, 117, 114, 115, 95, 97, 108, 101, 97,
  116, 111, 105, 114, 101, 115, 61, 61, 49, 125, 10, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44,
  50, 53, 53, 41, 41, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41,
  41, 125, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114, 111,
  117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 67, 111, 117, 108,
  101, 117, 114, 115, 95, 97, 108, 101, 97, 116, 111, 105, 114, 101, 115, 61,
  61, 50, 125, 10, 78, 105, 118, 101, 97, 117, 95, 100, 101, 95, 103, 114,
  105, 115, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53,
  53, 41, 41, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36,
  78, 105, 118, 101, 97, 117, 95, 100, 101, 95, 103, 114, 105, 115, 10, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 78, 105, 118, 101, 97, 117,
  95, 100, 101, 95, 103, 114, 105, 115, 10, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 61, 36, 78, 105, 118, 101, 97, 117, 95, 100, 101, 95, 103, 114,
  105, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  85, 116, 105, 108, 105, 115, 101, 114, 95, 76, 111, 99, 97, 108, 95, 78,
  111, 114, 109, 97, 108, 105, 122, 97, 116, 105, 111, 110, 61, 61, 49, 125,
  10, 45, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101,
  95, 108, 111, 99, 97, 108, 91, 45, 49, 93, 32, 36, 76, 95, 78, 95,
  65, 109, 112, 108, 105, 116, 117, 100, 101, 44, 36, 76, 95, 78, 95, 82,
  97, 100, 105, 117, 115, 44, 36, 76, 95, 78, 95, 78, 101, 105, 103, 104,
  98, 111, 114, 104, 111, 111, 100, 95, 115, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 44, 36, 76, 95, 78, 95, 65, 118, 101, 114, 97, 103, 101, 95,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 44, 36, 76, 95, 78, 95,
  67, 111, 110, 115, 116, 114, 97, 105, 110, 95, 118, 97, 108, 117, 101, 115,
  44, 36, 76, 95, 78, 95, 67, 104, 97, 110, 110, 101, 108, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 115, 111, 108, 105, 110, 101, 51, 100, 91,
  45, 49, 93, 32, 36, 73, 115, 111, 76, 105, 110, 101, 51, 100, 95, 80,
  111, 117, 114, 99, 101, 110, 116, 10, 45, 99, 111, 108, 51, 100, 91, 45,
  49, 93, 32, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117, 108,
  101, 117, 114, 44, 36, 65, 108, 112, 104, 97, 95, 67, 111, 117, 108, 101,
  117, 114, 10, 45, 103, 105, 109, 112, 95, 114, 101, 110, 100, 101, 114, 51,
  100, 91, 45, 49, 93, 32, 123, 53, 49, 50, 42, 36, 68, 105, 109, 101,
  110, 115, 105, 111, 110, 115, 125, 44, 123, 53, 49, 50, 42, 36, 68, 105,
  109, 101, 110, 115, 105, 111, 110, 115, 125, 44, 48, 46, 53, 44, 36, 88,
  95, 97, 110, 103, 108, 101, 44, 36, 89, 95, 97, 110, 103, 108, 101, 44,
  36, 90, 95, 97, 110, 103, 108, 101, 44, 57, 48, 44, 45, 49, 48, 48,
  44, 48, 44, 45, 49, 48, 48, 44, 49, 44, 48, 44, 52, 10, 45, 114,
  101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 91, 45, 49,
  93, 10, 45, 105, 102, 32, 123, 36, 65, 106, 117, 115, 116, 101, 109, 101,
  110, 116, 95, 68, 105, 109, 101, 110, 115, 105, 111, 110, 115, 61, 61, 49,
  125, 10, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32,
  48, 10, 45, 101, 110, 100, 105, 102, 10, 123, 119, 125, 44, 123, 104, 125,
  44, 49, 44, 52, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114,
  91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 50, 53, 53, 10, 45,
  97, 100, 100, 91, 45, 49, 44, 45, 50, 93, 10, 45, 105, 102, 32, 123,
  36, 84, 121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100, 117, 61, 61,
  49, 125, 10, 45, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105,
  116, 121, 91, 45, 49, 93, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93,
  32, 123, 48, 46, 50, 53, 42, 123, 49, 43, 36, 68, 105, 109, 101, 110,
  115, 105, 111, 110, 115, 125, 125, 10, 45, 115, 112, 114, 101, 97, 100, 91,
  45, 49, 93, 32, 123, 48, 46, 53, 42, 123, 49, 43, 36, 68, 105, 109,
  101, 110, 115, 105, 111, 110, 115, 125, 125, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 84, 101, 115,
  116, 95, 73, 115, 111, 76, 105, 110, 101, 51, 68, 95, 115, 97, 109, 106,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 84, 101, 115, 116, 95, 73, 115, 111, 76, 105, 110, 101, 51, 68, 95,
  115, 97, 109, 106, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45,
  49, 10, 35, 64, 103, 105, 109, 112, 32, 84, 101, 120, 116, 117, 114, 101,
  32, 48, 48, 50, 32, 58, 32, 115, 97, 109, 106, 95, 103, 105, 109, 112,
  95, 116, 101, 120, 116, 117, 114, 101, 95, 122, 101, 114, 111, 95, 122, 101,
  114, 111, 95, 100, 101, 117, 120, 44, 32, 115, 97, 109, 106, 95, 103, 105,
  109, 112, 95, 116, 101, 120, 116, 117, 114, 101, 95, 122, 101, 114, 111, 95,
  122, 101, 114, 111, 95, 100, 101, 117, 120, 95, 112, 114, 101, 118, 105, 101,
  119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101,
  116, 97, 105, 108, 115, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44,
  49, 50, 55, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101,
  115, 111, 108, 117, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 48, 44, 52, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 52, 44, 50, 44, 50, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 69, 100, 103, 101, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  48, 44, 53, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 66, 108, 101, 110, 100, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 115, 32, 98,
  111, 111, 115, 116, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 66, 111, 111, 115, 116, 32, 105, 110,
  116, 101, 110, 115, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 97, 99, 107,
  32, 108, 105, 110, 101, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 108, 101, 110, 100, 32,
  98, 108, 97, 99, 107, 32, 108, 105, 110, 101, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48,
  49, 51, 47, 49, 50, 47, 49, 52, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 103, 105, 109,
  112, 95, 116, 101, 120, 116, 117, 114, 101, 95, 122, 101, 114, 111, 95, 122,
  101, 114, 111, 95, 100, 101, 117, 120, 32, 58, 10, 68, 101, 116, 97, 105,
  108, 115, 95, 84, 65, 61, 36, 49, 10, 80, 111, 108, 121, 103, 111, 110,
  105, 122, 101, 95, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 95, 84,
  65, 61, 36, 50, 10, 84, 104, 114, 101, 115, 104, 111, 108, 100, 95, 84,
  104, 105, 110, 95, 69, 100, 103, 101, 115, 95, 84, 65, 61, 36, 51, 10,
  69, 100, 103, 101, 115, 95, 84, 104, 114, 101, 115, 104, 111, 108, 100, 61,
  36, 52, 10, 66, 108, 101, 110, 100, 95, 67, 111, 108, 111, 114, 115, 95,
  79, 112, 97, 99, 105, 116, 121, 61, 36, 53, 10, 67, 111, 108, 111, 114,
  115, 95, 66, 111, 111, 115, 116, 61, 36, 54, 10, 66, 111, 111, 115, 116,
  95, 73, 110, 116, 101, 110, 115, 105, 116, 121, 61, 36, 55, 10, 66, 108,
  97, 99, 107, 95, 76, 105, 110, 101, 115, 61, 36, 56, 10, 66, 108, 101,
  110, 100, 95, 66, 108, 97, 99, 107, 95, 76, 105, 110, 101, 115, 95, 79,
  112, 97, 99, 105, 116, 121, 61, 36, 57, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 103, 105,
  109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49,
  93, 10, 45, 105, 102, 32, 123, 36, 67, 111, 108, 111, 114, 115, 95, 66,
  111, 111, 115, 116, 61, 61, 49, 125, 10, 45, 45, 103, 105, 109, 112, 95,
  100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 115, 97, 109, 106, 95, 84, 111, 105, 108,
  101, 95, 68, 95, 65, 114, 97, 105, 103, 110, 101, 101, 91, 45, 49, 93,
  32, 36, 68, 101, 116, 97, 105, 108, 115, 95, 84, 65, 44, 36, 80, 111,
  108, 121, 103, 111, 110, 105, 122, 101, 95, 82, 101, 115, 111, 108, 117, 116,
  105, 111, 110, 95, 84, 65, 44, 36, 84, 104, 114, 101, 115, 104, 111, 108,
  100, 95, 84, 104, 105, 110, 95, 69, 100, 103, 101, 115, 95, 84, 65, 10,
  45, 105, 102, 32, 123, 36, 66, 108, 97, 99, 107, 95, 76, 105, 110, 101,
  115, 61, 61, 49, 125, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95,
  110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 103, 105, 109,
  112, 95, 101, 100, 103, 101, 115, 91, 45, 49, 93, 32, 48, 44, 36, 69,
  100, 103, 101, 115, 95, 84, 104, 114, 101, 115, 104, 111, 108, 100, 44, 48,
  10, 45, 103, 105, 109, 112, 95, 108, 111, 99, 97, 108, 95, 111, 114, 105,
  101, 110, 116, 97, 116, 105, 111, 110, 91, 45, 49, 93, 32, 48, 44, 48,
  44, 49, 48, 48, 44, 48, 44, 48, 44, 48, 10, 45, 103, 105, 109, 112,
  95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 51, 93, 32, 51, 44,
  36, 66, 108, 101, 110, 100, 95, 67, 111, 108, 111, 114, 115, 95, 79, 112,
  97, 99, 105, 116, 121, 44, 48, 10, 45, 103, 105, 109, 112, 95, 98, 108,
  101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 50, 52, 44, 36, 66,
  108, 101, 110, 100, 95, 66, 108, 97, 99, 107, 95, 76, 105, 110, 101, 115,
  95, 79, 112, 97, 99, 105, 116, 121, 44, 48, 10, 45, 101, 108, 115, 101,
  10, 45, 103, 105, 109, 112, 95, 101, 100, 103, 101, 115, 91, 45, 49, 93,
  32, 48, 44, 36, 69, 100, 103, 101, 115, 95, 84, 104, 114, 101, 115, 104,
  111, 108, 100, 44, 48, 10, 45, 103, 105, 109, 112, 95, 108, 111, 99, 97,
  108, 95, 111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 91, 45, 49,
  93, 32, 48, 44, 48, 44, 49, 48, 48, 44, 48, 44, 48, 44, 48, 10,
  45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45,
  50, 93, 32, 51, 44, 36, 66, 108, 101, 110, 100, 95, 67, 111, 108, 111,
  114, 115, 95, 79, 112, 97, 99, 105, 116, 121, 44, 48, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 67, 111, 108, 111, 114, 115,
  95, 66, 111, 111, 115, 116, 61, 61, 49, 125, 10, 45, 103, 105, 109, 112,
  95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 49, 51,
  44, 36, 66, 111, 111, 115, 116, 95, 73, 110, 116, 101, 110, 115, 105, 116,
  121, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 10, 115, 97, 109, 106, 95, 103, 105, 109, 112,
  95, 116, 101, 120, 116, 117, 114, 101, 95, 122, 101, 114, 111, 95, 122, 101,
  114, 111, 95, 100, 101, 117, 120, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 103, 105, 109,
  112, 95, 116, 101, 120, 116, 117, 114, 101, 95, 122, 101, 114, 111, 95, 122,
  101, 114, 111, 95, 100, 101, 117, 120, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 115, 97, 109, 106, 95, 114, 105, 101, 110, 95, 100, 101, 102, 111, 114,
  109, 97, 116, 105, 111, 110, 115, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 35,
  64, 103, 105, 109, 112, 32, 84, 111, 105, 108, 101, 32, 97, 114, 97, 105,
  103, 110, 38, 35, 50, 51, 51, 59, 101, 32, 45, 32, 99, 111, 98, 119,
  101, 98, 32, 58, 32, 115, 97, 109, 106, 95, 84, 111, 105, 108, 101, 95,
  68, 95, 65, 114, 97, 105, 103, 110, 101, 101, 44, 32, 115, 97, 109, 106,
  95, 84, 111, 105, 108, 101, 95, 68, 95, 65, 114, 97, 105, 103, 110, 101,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 101, 116, 97, 105, 108, 115, 32, 61, 32,
  105, 110, 116, 40, 48, 44, 48, 44, 49, 50, 55, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 52, 44, 50, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115,
  104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 44, 50,
  44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97, 109, 106,
  32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 49, 50, 47, 49, 51,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  115, 97, 109, 106, 95, 84, 111, 105, 108, 101, 95, 68, 95, 65, 114, 97,
  105, 103, 110, 101, 101, 32, 58, 10, 68, 101, 116, 97, 105, 108, 115, 61,
  36, 49, 10, 80, 111, 108, 121, 103, 111, 110, 105, 122, 101, 95, 82, 101,
  115, 111, 108, 117, 116, 105, 111, 110, 61, 36, 50, 10, 84, 104, 114, 101,
  115, 104, 111, 108, 100, 95, 84, 104, 105, 110, 95, 69, 100, 103, 101, 115,
  61, 36, 51, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 103, 105, 109, 112, 95, 97, 112, 112, 108,
  121, 95, 99, 117, 114, 118, 101, 91, 48, 93, 32, 36, 68, 101, 116, 97,
  105, 108, 115, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50,
  56, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50, 56, 44,
  45, 49, 44, 49, 50, 56, 44, 50, 53, 53, 44, 49, 44, 48, 44, 48,
  44, 48, 44, 48, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110,
  111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 45, 103, 105, 109,
  112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93,
  10, 45, 103, 105, 109, 112, 95, 112, 111, 108, 121, 103, 111, 110, 105, 122,
  101, 91, 45, 50, 93, 32, 51, 48, 48, 44, 49, 48, 48, 44, 48, 44,
  36, 80, 111, 108, 121, 103, 111, 110, 105, 122, 101, 95, 82, 101, 115, 111,
  108, 117, 116, 105, 111, 110, 44, 36, 80, 111, 108, 121, 103, 111, 110, 105,
  122, 101, 95, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 44, 48, 44,
  48, 44, 48, 44, 50, 53, 53, 10, 45, 103, 105, 109, 112, 95, 116, 104,
  105, 110, 95, 101, 100, 103, 101, 115, 91, 45, 49, 93, 32, 48, 44, 36,
  84, 104, 114, 101, 115, 104, 111, 108, 100, 95, 84, 104, 105, 110, 95, 69,
  100, 103, 101, 115, 44, 48, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101,
  110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 51, 54, 44, 49, 44, 49,
  10, 45, 103, 105, 109, 112, 95, 105, 115, 111, 112, 104, 111, 116, 101, 115,
  91, 45, 49, 93, 32, 56, 44, 48, 44, 49, 10, 45, 103, 105, 109, 112,
  95, 98, 108, 101, 110, 100, 95, 101, 100, 103, 101, 115, 91, 45, 50, 44,
  45, 49, 93, 32, 49, 44, 53, 44, 48, 10, 45, 116, 111, 95, 114, 103,
  98, 91, 45, 49, 93, 10, 45, 114, 103, 98, 50, 104, 115, 108, 56, 91,
  45, 49, 93, 10, 45, 115, 112, 108, 105, 116, 91, 45, 49, 93, 32, 99,
  10, 45, 114, 109, 91, 45, 50, 44, 45, 51, 93, 10, 45, 103, 105, 109,
  112, 95, 116, 104, 105, 110, 95, 101, 100, 103, 101, 115, 91, 45, 49, 93,
  32, 48, 44, 49, 53, 44, 48, 44, 48, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 115, 97, 109, 106, 95, 84, 111, 105, 108, 101,
  95, 68, 95, 65, 114, 97, 105, 103, 110, 101, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106,
  95, 84, 111, 105, 108, 101, 95, 68, 95, 65, 114, 97, 105, 103, 110, 101,
  101, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112,
  32, 95, 10, 35, 64, 103, 105, 109, 112, 32, 60, 105, 62, 68, 101, 102,
  111, 114, 109, 97, 116, 105, 111, 110, 115, 60, 47, 105, 62, 10, 35, 64,
  103, 105, 109, 112, 32, 66, 117, 116, 116, 101, 114, 102, 108, 121, 32, 48,
  48, 49, 32, 58, 32, 115, 97, 109, 106, 95, 66, 117, 116, 116, 101, 114,
  102, 108, 121, 95, 48, 48, 49, 44, 32, 115, 97, 109, 106, 95, 66, 117,
  116, 116, 101, 114, 102, 108, 121, 95, 48, 48, 49, 95, 112, 114, 101, 118,
  105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110,
  32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97,
  110, 103, 101, 114, 101, 100, 34, 62, 85, 110, 101, 32, 102, 111, 114, 109,
  101, 32, 100, 101, 32, 112, 97, 112, 105, 108, 108, 111, 110, 32, 46, 46,
  46, 32, 65, 118, 101, 99, 32, 108, 101, 115, 32, 98, 111, 110, 110, 101,
  115, 32, 118, 97, 108, 101, 117, 114, 115, 32, 46, 46, 46, 32, 66, 111,
  110, 110, 101, 32, 99, 104, 97, 110, 99, 101, 32, 33, 60, 47, 115, 112,
  97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34,
  84, 121, 112, 101, 32, 49, 34, 44, 34, 84, 121, 112, 101, 32, 50, 34,
  44, 34, 84, 121, 112, 101, 32, 51, 34, 44, 34, 84, 121, 112, 101, 32,
  52, 34, 44, 34, 68, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 115,
  32, 68, 105, 118, 101, 114, 115, 101, 115, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 111, 115, 115, 105, 110, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 55, 44, 45, 49, 48, 44, 49, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 114, 111, 116,
  97, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 101, 110, 116, 114, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 45,
  53, 44, 45, 53, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 101, 110, 116, 114, 101, 32, 116, 121, 112, 101, 115, 32,
  51, 32, 38, 32, 52, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 50,
  46, 53, 44, 45, 51, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114,
  111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34,
  62, 65, 115, 112, 101, 99, 116, 60, 47, 115, 112, 97, 110, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 101, 114, 109, 117, 116,
  97, 116, 105, 111, 110, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 105, 109, 101, 110, 115, 105,
  111, 110, 115, 32, 111, 114, 105, 103, 105, 110, 101, 32, 61, 32, 98, 111,
  111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52,
  47, 48, 49, 47, 49, 49, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 66, 117, 116, 116, 101,
  114, 102, 108, 121, 95, 48, 48, 49, 32, 58, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 84, 121, 112,
  101, 95, 80, 97, 112, 105, 108, 108, 111, 110, 61, 36, 49, 10, 67, 111,
  115, 115, 105, 110, 61, 36, 50, 10, 65, 110, 103, 108, 101, 95, 114, 111,
  116, 97, 116, 105, 111, 110, 61, 36, 51, 10, 67, 101, 110, 116, 114, 101,
  61, 36, 52, 10, 67, 101, 110, 116, 114, 101, 95, 84, 121, 112, 101, 61,
  36, 53, 10, 80, 101, 114, 109, 117, 116, 97, 116, 105, 111, 110, 61, 36,
  54, 10, 68, 105, 109, 101, 110, 115, 105, 111, 110, 115, 95, 79, 114, 105,
  103, 105, 110, 101, 61, 36, 55, 10, 76, 97, 114, 103, 101, 117, 114, 95,
  79, 114, 105, 103, 105, 110, 101, 61, 123, 119, 125, 10, 72, 97, 117, 116,
  101, 117, 114, 95, 79, 114, 105, 103, 105, 110, 101, 61, 123, 104, 125, 10,
  76, 97, 114, 103, 101, 117, 114, 95, 68, 101, 99, 111, 117, 112, 101, 61,
  48, 10, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10, 45, 105,
  102, 32, 123, 36, 84, 121, 112, 101, 95, 80, 97, 112, 105, 108, 108, 111,
  110, 61, 61, 48, 125, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99,
  111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 49, 44, 49, 44, 49, 10, 45, 103, 105, 109, 112, 95, 116,
  114, 97, 110, 115, 102, 111, 114, 109, 95, 112, 111, 108, 97, 114, 91, 45,
  49, 93, 32, 48, 44, 53, 48, 44, 53, 48, 44, 34, 114, 47, 115, 105,
  110, 40, 97, 43, 34, 36, 67, 111, 115, 115, 105, 110, 34, 41, 34, 44,
  34, 97, 34, 44, 48, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 10, 45, 114, 111, 116, 97, 116, 101, 91, 45, 49, 93, 32, 36,
  65, 110, 103, 108, 101, 95, 114, 111, 116, 97, 116, 105, 111, 110, 44, 50,
  44, 48, 44, 123, 123, 119, 125, 47, 50, 125, 44, 123, 123, 104, 125, 47,
  50, 125, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10,
  45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 45,
  49, 93, 32, 49, 48, 44, 49, 48, 44, 48, 44, 48, 44, 48, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 97, 117, 116, 111,
  99, 114, 111, 112, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 115,
  121, 109, 109, 101, 116, 114, 105, 122, 101, 91, 45, 49, 93, 32, 53, 48,
  44, 53, 48, 44, 49, 56, 48, 44, 49, 44, 48, 44, 48, 10, 45, 103,
  105, 109, 112, 95, 115, 121, 109, 109, 101, 116, 114, 105, 122, 101, 91, 45,
  49, 93, 32, 123, 36, 67, 101, 110, 116, 114, 101, 43, 53, 48, 125, 44,
  53, 48, 44, 57, 48, 44, 49, 44, 48, 44, 48, 10, 76, 97, 114, 103,
  101, 117, 114, 95, 68, 101, 99, 111, 117, 112, 101, 61, 123, 123, 119, 47,
  50, 125, 43, 123, 119, 47, 50, 48, 48, 42, 36, 67, 101, 110, 116, 114,
  101, 125, 125, 10, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 48, 44,
  48, 44, 36, 76, 97, 114, 103, 101, 117, 114, 95, 68, 101, 99, 111, 117,
  112, 101, 44, 123, 104, 125, 44, 48, 10, 45, 103, 105, 109, 112, 95, 97,
  114, 114, 97, 121, 95, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32,
  49, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 48, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95, 80, 97, 112, 105, 108,
  108, 111, 110, 61, 61, 49, 125, 10, 45, 114, 101, 112, 108, 97, 99, 101,
  95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 49, 44, 49, 44, 49, 10, 45, 103, 105, 109, 112,
  95, 116, 114, 97, 110, 115, 102, 111, 114, 109, 95, 112, 111, 108, 97, 114,
  91, 45, 49, 93, 32, 48, 44, 53, 48, 44, 53, 48, 44, 34, 114, 47,
  99, 111, 115, 40, 97, 43, 34, 36, 67, 111, 115, 115, 105, 110, 34, 41,
  34, 44, 34, 97, 34, 44, 48, 10, 45, 99, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 10, 45, 114, 111, 116, 97, 116, 101, 91, 45, 49, 93,
  32, 36, 65, 110, 103, 108, 101, 95, 114, 111, 116, 97, 116, 105, 111, 110,
  44, 50, 44, 48, 44, 123, 123, 119, 125, 47, 50, 125, 44, 123, 123, 104,
  125, 47, 50, 125, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114,
  91, 45, 49, 93, 32, 49, 48, 44, 49, 48, 44, 48, 44, 48, 44, 48,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 97, 117,
  116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112,
  95, 115, 121, 109, 109, 101, 116, 114, 105, 122, 101, 91, 45, 49, 93, 32,
  53, 48, 44, 53, 48, 44, 49, 56, 48, 44, 49, 44, 48, 44, 48, 10,
  45, 103, 105, 109, 112, 95, 115, 121, 109, 109, 101, 116, 114, 105, 122, 101,
  91, 45, 49, 93, 32, 123, 36, 67, 101, 110, 116, 114, 101, 43, 53, 48,
  125, 44, 53, 48, 44, 57, 48, 44, 49, 44, 48, 44, 48, 10, 76, 97,
  114, 103, 101, 117, 114, 95, 68, 101, 99, 111, 117, 112, 101, 61, 123, 123,
  119, 47, 50, 125, 43, 123, 119, 47, 50, 48, 48, 42, 36, 67, 101, 110,
  116, 114, 101, 125, 125, 10, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32,
  48, 44, 48, 44, 36, 76, 97, 114, 103, 101, 117, 114, 95, 68, 101, 99,
  111, 117, 112, 101, 44, 123, 104, 125, 44, 48, 10, 45, 103, 105, 109, 112,
  95, 97, 114, 114, 97, 121, 95, 109, 105, 114, 114, 111, 114, 91, 45, 49,
  93, 32, 49, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 48, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95, 80, 97, 112,
  105, 108, 108, 111, 110, 61, 61, 50, 125, 10, 45, 114, 101, 112, 108, 97,
  99, 101, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 49, 44, 49, 44, 49, 10, 45, 103, 105,
  109, 112, 95, 116, 114, 97, 110, 115, 102, 111, 114, 109, 95, 112, 111, 108,
  97, 114, 91, 45, 49, 93, 32, 48, 44, 53, 48, 44, 53, 48, 44, 34,
  114, 47, 115, 105, 110, 40, 97, 43, 34, 36, 67, 111, 115, 115, 105, 110,
  34, 41, 34, 44, 34, 97, 34, 44, 48, 10, 45, 99, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 10, 45, 114, 111, 116, 97, 116, 101, 91, 45,
  49, 93, 32, 36, 65, 110, 103, 108, 101, 95, 114, 111, 116, 97, 116, 105,
  111, 110, 44, 50, 44, 48, 44, 123, 123, 119, 125, 47, 50, 125, 44, 123,
  123, 104, 125, 47, 50, 125, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108,
  111, 114, 91, 45, 49, 93, 32, 49, 48, 44, 49, 48, 44, 48, 44, 48,
  44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45,
  97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 10, 45, 103, 105,
  109, 112, 95, 115, 121, 109, 109, 101, 116, 114, 105, 122, 101, 91, 45, 49,
  93, 32, 53, 48, 44, 53, 48, 44, 49, 56, 48, 44, 49, 44, 48, 44,
  48, 10, 45, 103, 105, 109, 112, 95, 115, 121, 109, 109, 101, 116, 114, 105,
  122, 101, 91, 45, 49, 93, 32, 123, 36, 67, 101, 110, 116, 114, 101, 43,
  53, 48, 125, 44, 53, 48, 44, 57, 48, 44, 49, 44, 48, 44, 48, 10,
  76, 97, 114, 103, 101, 117, 114, 95, 68, 101, 99, 111, 117, 112, 101, 61,
  123, 123, 119, 47, 50, 125, 43, 123, 119, 47, 50, 48, 48, 42, 36, 67,
  101, 110, 116, 114, 101, 125, 125, 10, 45, 99, 114, 111, 112, 91, 45, 49,
  93, 32, 48, 44, 48, 44, 36, 76, 97, 114, 103, 101, 117, 114, 95, 68,
  101, 99, 111, 117, 112, 101, 44, 123, 104, 125, 44, 48, 10, 45, 103, 105,
  109, 112, 95, 97, 114, 114, 97, 121, 95, 109, 105, 114, 114, 111, 114, 91,
  45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44,
  48, 10, 45, 103, 105, 109, 112, 95, 116, 114, 97, 110, 115, 102, 111, 114,
  109, 95, 112, 111, 108, 97, 114, 32, 48, 44, 53, 48, 44, 53, 48, 44,
  34, 114, 47, 97, 42, 52, 34, 44, 34, 97, 34, 44, 48, 10, 45, 116,
  111, 95, 114, 103, 98, 91, 45, 49, 93, 10, 45, 99, 114, 111, 112, 91,
  45, 49, 93, 32, 123, 123, 119, 125, 42, 48, 46, 49, 125, 44, 123, 123,
  104, 125, 42, 48, 46, 50, 125, 44, 123, 123, 123, 119, 125, 47, 50, 125,
  43, 123, 123, 119, 125, 47, 49, 48, 48, 42, 36, 67, 101, 110, 116, 114,
  101, 95, 84, 121, 112, 101, 125, 125, 44, 123, 123, 104, 125, 42, 48, 46,
  56, 125, 44, 48, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111,
  108, 111, 114, 91, 45, 49, 93, 32, 49, 48, 44, 49, 48, 44, 48, 44,
  48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10,
  45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 10, 45, 103,
  105, 109, 112, 95, 97, 114, 114, 97, 121, 95, 109, 105, 114, 114, 111, 114,
  91, 45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49,
  44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95,
  80, 97, 112, 105, 108, 108, 111, 110, 61, 61, 51, 125, 10, 45, 114, 101,
  112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32,
  48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 49, 44, 49, 10,
  45, 103, 105, 109, 112, 95, 116, 114, 97, 110, 115, 102, 111, 114, 109, 95,
  112, 111, 108, 97, 114, 91, 45, 49, 93, 32, 48, 44, 53, 48, 44, 53,
  48, 44, 34, 114, 47, 99, 111, 115, 40, 97, 43, 34, 36, 67, 111, 115,
  115, 105, 110, 34, 41, 34, 44, 34, 97, 34, 44, 48, 10, 45, 99, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 114, 111, 116, 97, 116,
  101, 91, 45, 49, 93, 32, 36, 65, 110, 103, 108, 101, 95, 114, 111, 116,
  97, 116, 105, 111, 110, 44, 50, 44, 48, 44, 123, 123, 119, 125, 47, 50,
  125, 44, 123, 123, 104, 125, 47, 50, 125, 10, 45, 99, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95,
  99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 49, 48, 44, 49, 48, 44,
  48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53,
  53, 10, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 10,
  45, 103, 105, 109, 112, 95, 115, 121, 109, 109, 101, 116, 114, 105, 122, 101,
  91, 45, 49, 93, 32, 53, 48, 44, 53, 48, 44, 49, 56, 48, 44, 49,
  44, 48, 44, 48, 10, 45, 103, 105, 109, 112, 95, 115, 121, 109, 109, 101,
  116, 114, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 67, 101, 110, 116,
  114, 101, 43, 53, 48, 125, 44, 53, 48, 44, 57, 48, 44, 49, 44, 48,
  44, 48, 10, 76, 97, 114, 103, 101, 117, 114, 95, 68, 101, 99, 111, 117,
  112, 101, 61, 123, 123, 119, 47, 50, 125, 43, 123, 119, 47, 50, 48, 48,
  42, 36, 67, 101, 110, 116, 114, 101, 125, 125, 10, 45, 99, 114, 111, 112,
  91, 45, 49, 93, 32, 48, 44, 48, 44, 36, 76, 97, 114, 103, 101, 117,
  114, 95, 68, 101, 99, 111, 117, 112, 101, 44, 123, 104, 125, 44, 48, 10,
  45, 103, 105, 109, 112, 95, 97, 114, 114, 97, 121, 95, 109, 105, 114, 114,
  111, 114, 91, 45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 49, 44, 48, 10, 45, 103, 105, 109, 112, 95, 116, 114, 97, 110, 115,
  102, 111, 114, 109, 95, 112, 111, 108, 97, 114, 32, 48, 44, 53, 48, 44,
  53, 48, 44, 34, 114, 47, 97, 42, 52, 34, 44, 34, 97, 34, 44, 48,
  10, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10, 45, 99, 114,
  111, 112, 91, 45, 49, 93, 32, 123, 123, 119, 125, 42, 48, 46, 49, 125,
  44, 123, 123, 104, 125, 42, 48, 46, 50, 125, 44, 123, 123, 123, 119, 125,
  47, 50, 125, 43, 123, 123, 119, 125, 47, 49, 48, 48, 42, 36, 67, 101,
  110, 116, 114, 101, 95, 84, 121, 112, 101, 125, 125, 44, 123, 123, 104, 125,
  42, 48, 46, 56, 125, 44, 48, 10, 45, 114, 101, 112, 108, 97, 99, 101,
  95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 49, 48, 44, 49, 48,
  44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 10, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93,
  10, 45, 103, 105, 109, 112, 95, 97, 114, 114, 97, 121, 95, 109, 105, 114,
  114, 111, 114, 91, 45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 48, 44,
  48, 44, 49, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 84, 121,
  112, 101, 95, 80, 97, 112, 105, 108, 108, 111, 110, 61, 61, 52, 125, 10,
  45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 45,
  49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 49,
  44, 49, 10, 45, 103, 105, 109, 112, 95, 116, 114, 97, 110, 115, 102, 111,
  114, 109, 95, 112, 111, 108, 97, 114, 91, 45, 49, 93, 32, 48, 44, 53,
  48, 44, 53, 48, 44, 34, 48, 46, 53, 42, 114, 47, 40, 115, 105, 110,
  40, 97, 43, 34, 36, 67, 111, 115, 115, 105, 110, 34, 41, 43, 99, 111,
  115, 40, 97, 43, 34, 36, 67, 111, 115, 115, 105, 110, 34, 41, 41, 34,
  44, 34, 97, 34, 44, 48, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 10, 45, 114, 111, 116, 97, 116, 101, 91, 45, 49, 93, 32,
  36, 65, 110, 103, 108, 101, 95, 114, 111, 116, 97, 116, 105, 111, 110, 44,
  50, 44, 48, 44, 123, 123, 119, 125, 47, 50, 125, 44, 123, 123, 104, 125,
  47, 50, 125, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91,
  45, 49, 93, 32, 49, 48, 44, 49, 48, 44, 48, 44, 48, 44, 48, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 97, 117, 116,
  111, 99, 114, 111, 112, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95,
  115, 121, 109, 109, 101, 116, 114, 105, 122, 101, 91, 45, 49, 93, 32, 53,
  48, 44, 53, 48, 44, 49, 56, 48, 44, 49, 44, 48, 44, 48, 10, 45,
  103, 105, 109, 112, 95, 115, 121, 109, 109, 101, 116, 114, 105, 122, 101, 91,
  45, 49, 93, 32, 123, 36, 67, 101, 110, 116, 114, 101, 43, 53, 48, 125,
  44, 53, 48, 44, 57, 48, 44, 49, 44, 48, 44, 48, 10, 76, 97, 114,
  103, 101, 117, 114, 95, 68, 101, 99, 111, 117, 112, 101, 61, 123, 123, 119,
  47, 50, 125, 43, 123, 119, 47, 50, 48, 48, 42, 123, 123, 36, 67, 101,
  110, 116, 114, 101, 95, 84, 121, 112, 101, 43, 51, 48, 125, 47, 50, 125,
  125, 125, 10, 45, 99, 114, 111, 112, 91, 45, 49, 93, 32, 48, 44, 48,
  44, 36, 76, 97, 114, 103, 101, 117, 114, 95, 68, 101, 99, 111, 117, 112,
  101, 44, 123, 104, 125, 44, 48, 10, 45, 103, 105, 109, 112, 95, 97, 114,
  114, 97, 121, 95, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 49,
  44, 48, 44, 48, 44, 48, 44, 48, 44, 49, 44, 48, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 80, 101, 114, 109, 117, 116,
  97, 116, 105, 111, 110, 61, 61, 49, 125, 10, 45, 112, 101, 114, 109, 117,
  116, 101, 91, 45, 49, 93, 32, 121, 120, 122, 99, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 68, 105, 109, 101, 110, 115, 105,
  111, 110, 115, 95, 79, 114, 105, 103, 105, 110, 101, 61, 61, 49, 125, 10,
  45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 36, 76, 97, 114,
  103, 101, 117, 114, 95, 79, 114, 105, 103, 105, 110, 101, 44, 36, 72, 97,
  117, 116, 101, 117, 114, 95, 79, 114, 105, 103, 105, 110, 101, 44, 49, 44,
  51, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 115, 97, 109, 106, 95, 66, 117, 116, 116, 101, 114, 102, 108, 121,
  95, 48, 48, 49, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 66, 117, 116, 116, 101, 114,
  102, 108, 121, 95, 48, 48, 49, 32, 36, 42, 34, 44, 36, 45, 49, 10,
  35, 64, 103, 105, 109, 112, 32, 75, 97, 108, 101, 105, 100, 111, 115, 99,
  111, 112, 101, 32, 48, 48, 49, 32, 58, 32, 115, 97, 109, 106, 95, 75,
  97, 108, 101, 105, 100, 111, 115, 99, 111, 112, 101, 95, 48, 48, 49, 44,
  32, 115, 97, 109, 106, 95, 75, 97, 108, 101, 105, 100, 111, 115, 99, 111,
  112, 101, 95, 48, 48, 49, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101,
  103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101,
  100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 65, 115, 112, 101, 99, 116,
  60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 105, 109, 101, 110,
  115, 105, 111, 110, 32, 112, 105, 120, 101, 108, 115, 32, 61, 32, 105, 110,
  116, 40, 53, 49, 50, 44, 50, 53, 54, 44, 50, 48, 52, 56, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 110, 115, 105, 116, 101,
  32, 61, 32, 105, 110, 116, 40, 49, 44, 49, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 69, 112, 97, 105, 115, 115, 101, 117,
  114, 32, 61, 32, 105, 110, 116, 40, 51, 44, 49, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 109, 111,
  100, 101, 32, 61, 32, 105, 110, 116, 40, 52, 44, 49, 44, 52, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 101, 116, 97, 108, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117,
  110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60,
  115, 109, 97, 108, 108, 62, 75, 97, 108, 101, 105, 100, 111, 115, 99, 111,
  112, 101, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101,
  114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 50, 44,
  49, 44, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47,
  48, 49, 47, 49, 49, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 75, 97, 108, 101, 105, 100,
  111, 115, 99, 111, 112, 101, 95, 48, 48, 49, 32, 58, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 68,
  105, 109, 101, 110, 115, 105, 111, 110, 95, 80, 105, 120, 101, 108, 115, 61,
  36, 49, 10, 68, 101, 110, 115, 105, 116, 101, 95, 76, 105, 103, 110, 101,
  115, 61, 36, 50, 10, 69, 112, 97, 105, 115, 115, 101, 117, 114, 61, 36,
  51, 10, 67, 111, 108, 111, 114, 109, 111, 100, 101, 95, 85, 116, 105, 108,
  105, 115, 97, 116, 101, 117, 114, 61, 36, 52, 10, 77, 101, 116, 97, 108,
  61, 36, 53, 10, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 95, 75,
  97, 108, 101, 105, 100, 111, 115, 99, 111, 112, 101, 61, 36, 54, 10, 82,
  51, 68, 95, 79, 98, 106, 101, 99, 116, 95, 115, 105, 122, 101, 61, 48,
  46, 54, 10, 88, 95, 97, 110, 103, 108, 101, 61, 45, 52, 48, 10, 89,
  95, 97, 110, 103, 108, 101, 61, 48, 10, 90, 95, 97, 110, 103, 108, 101,
  61, 48, 10, 82, 51, 68, 95, 70, 79, 86, 61, 52, 53, 10, 82, 51,
  68, 95, 88, 95, 108, 105, 103, 104, 116, 61, 48, 10, 82, 51, 68, 95,
  89, 95, 108, 105, 103, 104, 116, 61, 48, 10, 82, 51, 68, 95, 90, 95,
  108, 105, 103, 104, 116, 61, 45, 49, 48, 48, 10, 82, 51, 68, 95, 83,
  112, 101, 99, 117, 108, 97, 114, 95, 108, 105, 103, 104, 116, 110, 101, 115,
  115, 61, 48, 46, 53, 10, 82, 51, 68, 95, 83, 112, 101, 99, 117, 108,
  97, 114, 95, 115, 104, 105, 110, 105, 110, 101, 115, 115, 61, 48, 46, 55,
  10, 82, 51, 68, 95, 82, 101, 110, 100, 101, 114, 105, 110, 103, 95, 109,
  111, 100, 101, 61, 52, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 123, 36, 68, 101, 110, 115, 105, 116, 101, 95,
  76, 105, 103, 110, 101, 115, 42, 49, 48, 48, 125, 10, 97, 61, 123, 36,
  62, 42, 112, 105, 47, 53, 48, 125, 10, 45, 108, 105, 110, 101, 51, 100,
  32, 48, 44, 48, 44, 48, 44, 123, 99, 111, 115, 40, 51, 42, 36, 97,
  41, 125, 44, 123, 115, 105, 110, 40, 50, 42, 36, 97, 41, 125, 44, 48,
  10, 45, 99, 111, 108, 111, 114, 51, 100, 91, 45, 49, 93, 32, 64, 123,
  45, 82, 71, 66, 125, 10, 45, 100, 111, 110, 101, 10, 45, 97, 100, 100,
  51, 100, 10, 45, 103, 105, 109, 112, 95, 114, 101, 110, 100, 101, 114, 51,
  100, 91, 45, 49, 93, 32, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110,
  95, 80, 105, 120, 101, 108, 115, 44, 36, 68, 105, 109, 101, 110, 115, 105,
  111, 110, 95, 80, 105, 120, 101, 108, 115, 44, 36, 82, 51, 68, 95, 79,
  98, 106, 101, 99, 116, 95, 115, 105, 122, 101, 44, 36, 88, 95, 97, 110,
  103, 108, 101, 44, 36, 89, 95, 97, 110, 103, 108, 101, 44, 36, 90, 95,
  97, 110, 103, 108, 101, 44, 36, 82, 51, 68, 95, 70, 79, 86, 44, 36,
  82, 51, 68, 95, 88, 95, 108, 105, 103, 104, 116, 44, 36, 82, 51, 68,
  95, 89, 95, 108, 105, 103, 104, 116, 44, 36, 82, 51, 68, 95, 90, 95,
  108, 105, 103, 104, 116, 44, 36, 82, 51, 68, 95, 83, 112, 101, 99, 117,
  108, 97, 114, 95, 108, 105, 103, 104, 116, 110, 101, 115, 115, 44, 36, 82,
  51, 68, 95, 83, 112, 101, 99, 117, 108, 97, 114, 95, 115, 104, 105, 110,
  105, 110, 101, 115, 115, 44, 36, 82, 51, 68, 95, 82, 101, 110, 100, 101,
  114, 105, 110, 103, 95, 109, 111, 100, 101, 10, 45, 100, 105, 108, 97, 116,
  101, 95, 99, 105, 114, 99, 91, 45, 49, 93, 32, 36, 69, 112, 97, 105,
  115, 115, 101, 117, 114, 10, 45, 103, 105, 109, 112, 95, 99, 105, 114, 99,
  108, 101, 95, 116, 114, 97, 110, 115, 102, 111, 114, 109, 91, 45, 49, 93,
  32, 48, 46, 53, 44, 48, 46, 53, 44, 45, 50, 44, 45, 50, 44, 48,
  46, 50, 44, 48, 44, 49, 44, 48, 44, 49, 10, 45, 45, 103, 105, 109,
  112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93,
  10, 45, 103, 105, 109, 112, 95, 97, 114, 114, 97, 121, 95, 109, 105, 114,
  114, 111, 114, 91, 45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 50, 44,
  48, 44, 48, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91,
  45, 49, 44, 45, 50, 93, 32, 49, 44, 49, 44, 48, 10, 45, 103, 105,
  109, 112, 95, 115, 121, 109, 109, 101, 116, 114, 105, 122, 111, 115, 99, 111,
  112, 101, 91, 45, 49, 93, 32, 123, 123, 36, 73, 116, 101, 114, 97, 116,
  105, 111, 110, 115, 95, 75, 97, 108, 101, 105, 100, 111, 115, 99, 111, 112,
  101, 42, 52, 125, 43, 49, 125, 44, 48, 44, 48, 44, 48, 10, 45, 105,
  102, 32, 123, 36, 77, 101, 116, 97, 108, 61, 61, 49, 125, 10, 45, 115,
  97, 109, 106, 95, 103, 105, 109, 112, 95, 116, 101, 120, 116, 117, 114, 101,
  95, 122, 101, 114, 111, 95, 122, 101, 114, 111, 95, 117, 110, 91, 45, 49,
  93, 32, 48, 46, 53, 44, 50, 48, 44, 56, 48, 44, 48, 44, 48, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114,
  109, 111, 100, 101, 91, 45, 49, 93, 32, 36, 67, 111, 108, 111, 114, 109,
  111, 100, 101, 95, 85, 116, 105, 108, 105, 115, 97, 116, 101, 117, 114, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115, 97, 109, 106,
  95, 75, 97, 108, 101, 105, 100, 111, 115, 99, 111, 112, 101, 95, 48, 48,
  49, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 115, 97, 109, 106, 95, 75, 97, 108, 101, 105, 100, 111, 115, 99,
  111, 112, 101, 95, 48, 48, 49, 32, 36, 42, 34, 44, 36, 45, 49, 10,
  35, 64, 103, 105, 109, 112, 32, 83, 121, 109, 101, 116, 114, 105, 101, 32,
  99, 97, 114, 116, 101, 115, 105, 97, 110, 32, 116, 114, 97, 110, 115, 102,
  111, 114, 109, 32, 48, 48, 49, 32, 58, 32, 115, 97, 109, 106, 95, 83,
  121, 109, 101, 116, 114, 105, 101, 95, 67, 97, 114, 116, 101, 115, 105, 97,
  110, 95, 84, 114, 97, 110, 115, 102, 111, 114, 109, 95, 48, 48, 49, 44,
  32, 115, 97, 109, 106, 95, 83, 121, 109, 101, 116, 114, 105, 101, 95, 67,
  97, 114, 116, 101, 115, 105, 97, 110, 95, 84, 114, 97, 110, 115, 102, 111,
  114, 109, 95, 48, 48, 49, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101,
  103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101,
  100, 34, 62, 83, 104, 105, 102, 116, 60, 47, 115, 112, 97, 110, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 97, 32, 37, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 97, 32, 37, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 98, 32, 37, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 89, 98, 32, 37, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 66, 111, 117, 110, 100, 97, 114, 121, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 84, 114, 97, 110,
  115, 112, 97, 114, 101, 110, 116, 34, 44, 34, 78, 101, 97, 114, 101, 115,
  116, 34, 44, 34, 82, 101, 112, 101, 97, 116, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110,
  100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 65, 114,
  114, 97, 121, 32, 77, 105, 114, 114, 111, 114, 60, 47, 115, 112, 97, 110,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 114, 114,
  97, 121, 32, 109, 105, 114, 114, 111, 114, 32, 61, 32, 98, 111, 111, 108,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101,
  114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 49, 44,
  49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88,
  45, 111, 102, 102, 115, 101, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 89, 45, 111, 102, 102, 115, 101, 116, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 114, 114, 97, 121, 32, 109, 111, 100, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 120, 45, 97, 120,
  105, 115, 34, 44, 34, 121, 45, 97, 120, 105, 115, 34, 44, 34, 120, 121,
  45, 97, 120, 101, 115, 34, 44, 34, 50, 120, 121, 45, 97, 120, 101, 115,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 105, 116,
  105, 97, 108, 105, 122, 97, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 79, 114, 105, 103, 105, 110, 97, 108, 34, 44, 34,
  77, 105, 114, 114, 111, 114, 32, 88, 34, 44, 34, 77, 105, 114, 114, 111,
  114, 32, 89, 34, 44, 34, 82, 111, 116, 97, 116, 101, 32, 57, 48, 32,
  100, 101, 103, 46, 34, 44, 34, 82, 111, 116, 97, 116, 101, 32, 49, 56,
  48, 32, 100, 101, 103, 46, 34, 44, 34, 82, 111, 116, 97, 116, 101, 32,
  50, 55, 48, 32, 100, 101, 103, 46, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 69, 120, 112, 97, 110, 100, 32, 115, 105, 122, 101, 32,
  61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 114, 111, 112, 32, 61, 32, 105, 110, 116, 40, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110,
  32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97,
  110, 103, 101, 114, 101, 100, 34, 62, 67, 97, 114, 116, 101, 115, 105, 97,
  110, 32, 84, 114, 97, 110, 115, 102, 111, 114, 109, 32, 112, 97, 114, 32,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 121, 112, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 83, 97, 110, 115, 32, 47,
  32, 87, 105, 116, 104, 111, 117, 116, 34, 44, 34, 49, 32, 65, 66, 34,
  44, 34, 50, 32, 65, 66, 67, 68, 34, 44, 34, 51, 32, 65, 66, 67,
  68, 34, 44, 34, 52, 32, 65, 66, 34, 44, 34, 53, 32, 65, 66, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 66, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 48, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 68, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73,
  110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 49, 44, 34, 78, 101, 97, 114, 101, 115, 116,
  32, 110, 101, 105, 103, 104, 98, 111, 114, 34, 44, 34, 76, 105, 110, 101,
  97, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 111,
  117, 110, 100, 97, 114, 121, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  49, 44, 34, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 116, 34, 44,
  34, 78, 101, 97, 114, 101, 115, 116, 34, 44, 34, 82, 101, 112, 101, 97,
  116, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97, 109, 106, 32,
  45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32,
  58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 50, 56, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 115,
  97, 109, 106, 95, 83, 121, 109, 101, 116, 114, 105, 101, 95, 67, 97, 114,
  116, 101, 115, 105, 97, 110, 95, 84, 114, 97, 110, 115, 102, 111, 114, 109,
  95, 48, 48, 49, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 88, 97, 95, 83, 104, 105, 102,
  116, 61, 36, 49, 10, 89, 97, 95, 83, 104, 105, 102, 116, 61, 36, 50,
  10, 88, 98, 95, 83, 104, 105, 102, 116, 61, 36, 51, 10, 89, 98, 95,
  83, 104, 105, 102, 116, 61, 36, 52, 10, 66, 111, 117, 110, 100, 97, 114,
  121, 95, 83, 104, 105, 102, 116, 61, 36, 53, 10, 65, 114, 114, 97, 121,
  95, 77, 105, 114, 114, 111, 114, 61, 36, 54, 10, 73, 116, 101, 114, 97,
  116, 105, 111, 110, 115, 95, 71, 77, 61, 36, 55, 10, 88, 95, 79, 102,
  102, 115, 101, 116, 95, 71, 77, 61, 36, 56, 10, 89, 95, 79, 102, 102,
  115, 101, 116, 95, 71, 77, 61, 36, 57, 10, 65, 114, 114, 97, 121, 95,
  77, 111, 100, 101, 95, 71, 77, 61, 36, 49, 48, 10, 73, 110, 105, 116,
  105, 97, 108, 105, 122, 97, 116, 105, 111, 110, 95, 71, 77, 61, 36, 49,
  49, 10, 69, 120, 112, 97, 110, 100, 95, 83, 105, 122, 101, 95, 71, 77,
  61, 36, 49, 50, 10, 67, 114, 111, 112, 95, 71, 77, 61, 36, 49, 51,
  10, 84, 121, 112, 101, 95, 67, 84, 61, 36, 49, 52, 10, 65, 95, 67,
  84, 61, 36, 49, 53, 10, 66, 95, 67, 84, 61, 36, 49, 54, 10, 67,
  95, 67, 84, 61, 36, 49, 55, 10, 68, 95, 67, 84, 61, 36, 49, 56,
  10, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 95, 67,
  84, 61, 36, 49, 57, 10, 66, 111, 117, 110, 100, 97, 114, 121, 95, 67,
  84, 61, 36, 50, 48, 10, 82, 101, 108, 97, 116, 105, 118, 101, 95, 87,
  97, 114, 112, 105, 110, 103, 95, 67, 84, 61, 48, 10, 88, 95, 87, 97,
  114, 112, 105, 110, 103, 95, 67, 84, 61, 48, 10, 89, 95, 87, 97, 114,
  112, 105, 110, 103, 95, 67, 84, 61, 48, 10, 45, 116, 111, 95, 114, 103,
  98, 97, 91, 45, 49, 93, 10, 45, 115, 104, 105, 102, 116, 91, 45, 49,
  93, 32, 123, 36, 88, 97, 95, 83, 104, 105, 102, 116, 125, 37, 44, 123,
  36, 89, 97, 95, 83, 104, 105, 102, 116, 125, 37, 44, 48, 44, 48, 44,
  36, 66, 111, 117, 110, 100, 97, 114, 121, 95, 83, 104, 105, 102, 116, 10,
  45, 114, 111, 116, 97, 116, 101, 91, 45, 49, 93, 32, 49, 56, 48, 44,
  48, 44, 50, 44, 123, 123, 119, 125, 47, 50, 125, 44, 123, 123, 104, 125,
  47, 50, 125, 10, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93, 32, 123,
  36, 88, 98, 95, 83, 104, 105, 102, 116, 125, 37, 44, 123, 36, 89, 98,
  95, 83, 104, 105, 102, 116, 125, 37, 44, 48, 44, 48, 44, 36, 66, 111,
  117, 110, 100, 97, 114, 121, 95, 83, 104, 105, 102, 116, 10, 45, 114, 111,
  116, 97, 116, 101, 91, 45, 49, 93, 32, 49, 56, 48, 44, 48, 44, 50,
  44, 123, 123, 119, 125, 47, 50, 125, 44, 123, 123, 104, 125, 47, 50, 125,
  10, 45, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95, 67, 84, 61, 61,
  49, 125, 10, 82, 101, 108, 97, 116, 105, 118, 101, 95, 87, 97, 114, 112,
  105, 110, 103, 95, 67, 84, 61, 48, 10, 88, 95, 87, 97, 114, 112, 105,
  110, 103, 95, 67, 84, 61, 34, 120, 43, 40, 119, 47, 49, 48, 48, 48,
  42, 34, 36, 65, 95, 67, 84, 34, 41, 34, 10, 89, 95, 87, 97, 114,
  112, 105, 110, 103, 95, 67, 84, 61, 34, 121, 43, 40, 104, 47, 49, 48,
  48, 48, 42, 34, 36, 66, 95, 67, 84, 34, 41, 34, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 84, 121, 112, 101, 95, 67, 84, 61, 61, 50, 125,
  10, 82, 101, 108, 97, 116, 105, 118, 101, 95, 87, 97, 114, 112, 105, 110,
  103, 95, 67, 84, 61, 49, 10, 65, 95, 67, 84, 61, 123, 49, 43, 123,
  36, 65, 95, 67, 84, 47, 53, 48, 125, 125, 10, 66, 95, 67, 84, 61,
  123, 49, 43, 123, 36, 66, 95, 67, 84, 47, 53, 48, 125, 125, 10, 67,
  95, 67, 84, 61, 123, 49, 43, 123, 36, 67, 95, 67, 84, 47, 53, 48,
  125, 125, 10, 68, 95, 67, 84, 61, 123, 49, 43, 123, 36, 68, 95, 67,
  84, 47, 53, 48, 125, 125, 10, 88, 95, 87, 97, 114, 112, 105, 110, 103,
  95, 67, 84, 61, 34, 40, 119, 43, 104, 41, 47, 34, 36, 65, 95, 67,
  84, 34, 42, 99, 111, 115, 40, 121, 42, 34, 36, 66, 95, 67, 84, 34,
  47, 104, 41, 34, 10, 89, 95, 87, 97, 114, 112, 105, 110, 103, 95, 67,
  84, 61, 34, 40, 119, 43, 104, 41, 47, 34, 36, 67, 95, 67, 84, 34,
  42, 115, 105, 110, 40, 120, 42, 34, 36, 68, 95, 67, 84, 34, 47, 119,
  41, 34, 10, 45, 101, 108, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95,
  67, 84, 61, 61, 51, 125, 10, 82, 101, 108, 97, 116, 105, 118, 101, 95,
  87, 97, 114, 112, 105, 110, 103, 95, 67, 84, 61, 49, 10, 65, 95, 67,
  84, 61, 123, 49, 43, 123, 36, 65, 95, 67, 84, 47, 53, 48, 125, 125,
  10, 66, 95, 67, 84, 61, 123, 49, 43, 123, 36, 66, 95, 67, 84, 47,
  53, 48, 125, 125, 10, 67, 95, 67, 84, 61, 123, 49, 43, 123, 36, 67,
  95, 67, 84, 47, 53, 48, 125, 125, 10, 68, 95, 67, 84, 61, 123, 49,
  43, 123, 36, 68, 95, 67, 84, 47, 53, 48, 125, 125, 10, 88, 95, 87,
  97, 114, 112, 105, 110, 103, 95, 67, 84, 61, 34, 40, 119, 43, 104, 41,
  47, 34, 36, 65, 95, 67, 84, 34, 42, 115, 105, 110, 40, 121, 42, 34,
  36, 66, 95, 67, 84, 34, 47, 104, 41, 34, 10, 89, 95, 87, 97, 114,
  112, 105, 110, 103, 95, 67, 84, 61, 34, 40, 119, 43, 104, 41, 47, 34,
  36, 67, 95, 67, 84, 34, 42, 99, 111, 115, 40, 120, 42, 34, 36, 68,
  95, 67, 84, 34, 47, 119, 41, 34, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 84, 121, 112, 101, 95, 67, 84, 61, 61, 52, 125, 10, 82, 101, 108,
  97, 116, 105, 118, 101, 95, 87, 97, 114, 112, 105, 110, 103, 95, 67, 84,
  61, 49, 10, 88, 95, 87, 97, 114, 112, 105, 110, 103, 95, 67, 84, 61,
  34, 109, 105, 110, 40, 120, 44, 121, 41, 42, 34, 123, 36, 65, 95, 67,
  84, 45, 53, 48, 48, 125, 34, 47, 50, 48, 48, 34, 10, 89, 95, 87,
  97, 114, 112, 105, 110, 103, 95, 67, 84, 61, 34, 109, 97, 120, 40, 120,
  44, 121, 41, 42, 34, 123, 36, 66, 95, 67, 84, 45, 53, 48, 48, 125,
  34, 47, 50, 48, 48, 34, 10, 45, 101, 108, 105, 102, 32, 123, 36, 84,
  121, 112, 101, 95, 67, 84, 61, 61, 53, 125, 10, 82, 101, 108, 97, 116,
  105, 118, 101, 95, 87, 97, 114, 112, 105, 110, 103, 95, 67, 84, 61, 49,
  10, 88, 95, 87, 97, 114, 112, 105, 110, 103, 95, 67, 84, 61, 34, 109,
  97, 120, 40, 120, 44, 121, 41, 42, 34, 123, 36, 65, 95, 67, 84, 45,
  53, 48, 48, 125, 34, 47, 50, 48, 48, 34, 10, 89, 95, 87, 97, 114,
  112, 105, 110, 103, 95, 67, 84, 61, 34, 109, 105, 110, 40, 120, 44, 121,
  41, 42, 34, 123, 36, 66, 95, 67, 84, 45, 53, 48, 48, 125, 34, 47,
  50, 48, 48, 34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 84, 121, 112, 101, 95, 67, 84, 62, 48, 125, 10, 45, 45, 110,
  111, 114, 109, 91, 45, 49, 93, 32, 91, 45, 49, 93, 10, 45, 102, 105,
  108, 108, 91, 45, 50, 93, 32, 36, 88, 95, 87, 97, 114, 112, 105, 110,
  103, 95, 67, 84, 10, 45, 102, 105, 108, 108, 91, 45, 49, 93, 32, 36,
  89, 95, 87, 97, 114, 112, 105, 110, 103, 95, 67, 84, 10, 45, 97, 112,
  112, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 119,
  97, 114, 112, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 82, 101,
  108, 97, 116, 105, 118, 101, 95, 87, 97, 114, 112, 105, 110, 103, 95, 67,
  84, 44, 36, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110,
  95, 67, 84, 44, 36, 66, 111, 117, 110, 100, 97, 114, 121, 95, 67, 84,
  44, 49, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 109, 111, 118, 101,
  91, 45, 49, 93, 32, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 65, 114, 114, 97, 121, 95, 77, 105, 114, 114, 111, 114,
  61, 61, 49, 125, 10, 45, 103, 105, 109, 112, 95, 97, 114, 114, 97, 121,
  95, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 36, 73, 116, 101,
  114, 97, 116, 105, 111, 110, 115, 95, 71, 77, 44, 36, 88, 95, 79, 102,
  102, 115, 101, 116, 95, 71, 77, 44, 36, 89, 95, 79, 102, 102, 115, 101,
  116, 95, 71, 77, 44, 36, 65, 114, 114, 97, 121, 95, 77, 111, 100, 101,
  95, 71, 77, 44, 36, 73, 110, 105, 116, 105, 97, 108, 105, 122, 97, 116,
  105, 111, 110, 95, 71, 77, 44, 36, 69, 120, 112, 97, 110, 100, 95, 83,
  105, 122, 101, 95, 71, 77, 44, 36, 67, 114, 111, 112, 95, 71, 77, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 97, 117, 116, 111, 99, 114, 111, 112,
  91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 115, 97, 109, 106, 95, 83, 121,
  109, 101, 116, 114, 105, 101, 95, 67, 97, 114, 116, 101, 115, 105, 97, 110,
  95, 84, 114, 97, 110, 115, 102, 111, 114, 109, 95, 48, 48, 49, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115,
  112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115,
  97, 109, 106, 95, 83, 121, 109, 101, 116, 114, 105, 101, 95, 67, 97, 114,
  116, 101, 115, 105, 97, 110, 95, 84, 114, 97, 110, 115, 102, 111, 114, 109,
  95, 48, 48, 49, 32, 36, 42, 34, 44, 36, 45, 49, 10, 115, 97, 109,
  106, 95, 114, 105, 101, 110, 95, 100, 101, 103, 114, 97, 100, 97, 116, 105,
  111, 110, 115, 32, 58, 10, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110,
  111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 35, 64, 103, 105, 109,
  112, 32, 83, 121, 109, 101, 116, 114, 105, 101, 32, 112, 111, 108, 97, 114,
  32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32, 48, 48, 49, 32, 58,
  32, 115, 97, 109, 106, 95, 83, 121, 109, 101, 116, 114, 105, 101, 95, 80,
  111, 108, 97, 114, 95, 84, 114, 97, 110, 115, 102, 111, 114, 109, 95, 48,
  48, 49, 44, 32, 115, 97, 109, 106, 95, 83, 121, 109, 101, 116, 114, 105,
  101, 95, 80, 111, 108, 97, 114, 95, 84, 114, 97, 110, 115, 102, 111, 114,
  109, 95, 48, 48, 49, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103,
  114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100,
  34, 62, 83, 104, 105, 102, 116, 60, 47, 115, 112, 97, 110, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 97, 32, 37, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 97, 32, 37, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 88, 98, 32, 37, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 89, 98, 32, 37, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 66, 111, 117, 110, 100, 97, 114, 121, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 84, 114, 97, 110, 115,
  112, 97, 114, 101, 110, 116, 34, 44, 34, 78, 101, 97, 114, 101, 115, 116,
  34, 44, 34, 82, 101, 112, 101, 97, 116, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100,
  61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 65, 114, 114,
  97, 121, 32, 77, 105, 114, 114, 111, 114, 60, 47, 115, 112, 97, 110, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 114, 114, 97,
  121, 32, 109, 105, 114, 114, 111, 114, 32, 61, 32, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101, 114,
  97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45,
  111, 102, 102, 115, 101, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 89, 45, 111, 102, 102, 115, 101, 116, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 114, 114, 97, 121, 32, 109, 111, 100, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 120, 45, 97, 120, 105,
  115, 34, 44, 34, 121, 45, 97, 120, 105, 115, 34, 44, 34, 120, 121, 45,
  97, 120, 101, 115, 34, 44, 34, 50, 120, 121, 45, 97, 120, 101, 115, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 105, 116, 105,
  97, 108, 105, 122, 97, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 79, 114, 105, 103, 105, 110, 97, 108, 34, 44, 34, 77,
  105, 114, 114, 111, 114, 32, 88, 34, 44, 34, 77, 105, 114, 114, 111, 114,
  32, 89, 34, 44, 34, 82, 111, 116, 97, 116, 101, 32, 57, 48, 32, 100,
  101, 103, 46, 34, 44, 34, 82, 111, 116, 97, 116, 101, 32, 49, 56, 48,
  32, 100, 101, 103, 46, 34, 44, 34, 82, 111, 116, 97, 116, 101, 32, 50,
  55, 48, 32, 100, 101, 103, 46, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 69, 120, 112, 97, 110, 100, 32, 115, 105, 122, 101, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 114, 111, 112, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32,
  102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110,
  103, 101, 114, 101, 100, 34, 62, 80, 111, 108, 97, 114, 32, 84, 114, 97,
  110, 115, 102, 111, 114, 109, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 121, 112, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 83, 97, 110, 115, 32, 47,
  32, 87, 105, 116, 104, 111, 117, 116, 34, 44, 34, 49, 32, 65, 32, 114,
  66, 34, 44, 34, 50, 32, 65, 45, 66, 32, 114, 67, 34, 44, 34, 51,
  32, 65, 32, 114, 66, 34, 44, 34, 52, 32, 65, 32, 114, 66, 34, 44,
  34, 53, 32, 65, 32, 114, 66, 34, 44, 34, 54, 32, 65, 32, 114, 66,
  67, 34, 44, 34, 55, 32, 65, 32, 114, 66, 34, 44, 34, 56, 32, 65,
  45, 66, 32, 114, 67, 34, 44, 34, 57, 32, 65, 32, 114, 66, 34, 44,
  34, 49, 48, 32, 65, 32, 114, 66, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 88, 45, 99, 101, 110, 116, 101, 114, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 101, 110, 116, 101, 114,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 66, 111, 117, 110, 100, 97, 114, 121, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 48, 44, 34, 84, 114, 97, 110, 115, 112, 97, 114,
  101, 110, 116, 34, 44, 34, 78, 101, 97, 114, 101, 115, 116, 34, 44, 34,
  82, 101, 112, 101, 97, 116, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 65, 117, 116, 111, 99, 114, 111, 112, 32, 112, 111, 108, 97, 114,
  32, 116, 114, 97, 110, 115, 102, 111, 114, 109, 32, 61, 32, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97, 109, 106,
  32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 50, 56,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  115, 97, 109, 106, 95, 83, 121, 109, 101, 116, 114, 105, 101, 95, 80, 111,
  108, 97, 114, 95, 84, 114, 97, 110, 115, 102, 111, 114, 109, 95, 48, 48,
  49, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 88, 97, 95, 83, 104, 105, 102, 116, 61, 36,
  49, 10, 89, 97, 95, 83, 104, 105, 102, 116, 61, 36, 50, 10, 88, 98,
  95, 83, 104, 105, 102, 116, 61, 36, 51, 10, 89, 98, 95, 83, 104, 105,
  102, 116, 61, 36, 52, 10, 66, 111, 117, 110, 100, 97, 114, 121, 95, 83,
  104, 105, 102, 116, 61, 36, 53, 10, 65, 114, 114, 97, 121, 95, 77, 105,
  114, 114, 111, 114, 61, 36, 54, 10, 73, 116, 101, 114, 97, 116, 105, 111,
  110, 115, 95, 71, 77, 61, 36, 55, 10, 88, 95, 79, 102, 102, 115, 101,
  116, 95, 71, 77, 61, 36, 56, 10, 89, 95, 79, 102, 102, 115, 101, 116,
  95, 71, 77, 61, 36, 57, 10, 65, 114, 114, 97, 121, 95, 77, 111, 100,
  101, 95, 71, 77, 61, 36, 49, 48, 10, 73, 110, 105, 116, 105, 97, 108,
  105, 122, 97, 116, 105, 111, 110, 95, 71, 77, 61, 36, 49, 49, 10, 69,
  120, 112, 97, 110, 100, 95, 83, 105, 122, 101, 95, 71, 77, 61, 36, 49,
  50, 10, 67, 114, 111, 112, 95, 71, 77, 61, 36, 49, 51, 10, 84, 121,
  112, 101, 95, 80, 84, 61, 36, 49, 52, 10, 88, 95, 67, 101, 110, 116,
  101, 114, 95, 80, 84, 61, 36, 49, 53, 10, 89, 95, 67, 101, 110, 116,
  101, 114, 95, 80, 84, 61, 36, 49, 54, 10, 65, 95, 80, 84, 61, 36,
  49, 55, 10, 66, 95, 80, 84, 61, 36, 49, 56, 10, 67, 95, 80, 84,
  61, 36, 49, 57, 10, 66, 111, 117, 110, 100, 97, 114, 121, 95, 80, 84,
  61, 36, 50, 48, 10, 65, 117, 116, 111, 67, 114, 111, 112, 95, 80, 84,
  61, 36, 50, 49, 10, 82, 97, 100, 105, 117, 115, 95, 80, 84, 61, 48,
  10, 65, 110, 103, 108, 101, 95, 80, 84, 61, 48, 10, 45, 116, 111, 95,
  114, 103, 98, 97, 91, 45, 49, 93, 10, 45, 115, 104, 105, 102, 116, 91,
  45, 49, 93, 32, 123, 36, 88, 97, 95, 83, 104, 105, 102, 116, 125, 37,
  44, 123, 36, 89, 97, 95, 83, 104, 105, 102, 116, 125, 37, 44, 48, 44,
  48, 44, 36, 66, 111, 117, 110, 100, 97, 114, 121, 95, 83, 104, 105, 102,
  116, 10, 45, 114, 111, 116, 97, 116, 101, 91, 45, 49, 93, 32, 49, 56,
  48, 44, 48, 44, 50, 44, 123, 123, 119, 125, 47, 50, 125, 44, 123, 123,
  104, 125, 47, 50, 125, 10, 45, 115, 104, 105, 102, 116, 91, 45, 49, 93,
  32, 123, 36, 88, 98, 95, 83, 104, 105, 102, 116, 125, 37, 44, 123, 36,
  89, 98, 95, 83, 104, 105, 102, 116, 125, 37, 44, 48, 44, 48, 44, 36,
  66, 111, 117, 110, 100, 97, 114, 121, 95, 83, 104, 105, 102, 116, 10, 45,
  114, 111, 116, 97, 116, 101, 91, 45, 49, 93, 32, 49, 56, 48, 44, 48,
  44, 50, 44, 123, 123, 119, 125, 47, 50, 125, 44, 123, 123, 104, 125, 47,
  50, 125, 10, 45, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95, 80, 84,
  61, 61, 49, 125, 10, 82, 97, 100, 105, 117, 115, 95, 80, 84, 61, 34,
  114, 47, 97, 42, 34, 123, 48, 46, 52, 43, 123, 36, 65, 95, 80, 84,
  47, 49, 48, 48, 125, 125, 34, 34, 10, 65, 110, 103, 108, 101, 95, 80,
  84, 61, 34, 97, 43, 34, 123, 123, 112, 105, 125, 47, 53, 48, 48, 42,
  36, 66, 95, 80, 84, 125, 34, 34, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 84, 121, 112, 101, 95, 80, 84, 61, 61, 50, 125, 10, 82, 97, 100,
  105, 117, 115, 95, 80, 84, 61, 34, 40, 82, 42, 34, 123, 123, 45, 36,
  65, 95, 80, 84, 125, 47, 49, 48, 48, 125, 34, 41, 45, 40, 114, 42,
  34, 123, 123, 45, 36, 66, 95, 80, 84, 125, 47, 49, 48, 48, 125, 34,
  41, 34, 10, 65, 110, 103, 108, 101, 95, 80, 84, 61, 34, 97, 43, 34,
  123, 123, 112, 105, 125, 47, 53, 48, 48, 42, 36, 67, 95, 80, 84, 125,
  34, 34, 10, 45, 101, 108, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95,
  80, 84, 61, 61, 51, 125, 10, 82, 97, 100, 105, 117, 115, 95, 80, 84,
  61, 34, 97, 42, 82, 47, 34, 123, 123, 112, 105, 125, 47, 53, 48, 48,
  42, 36, 65, 95, 80, 84, 125, 34, 34, 10, 65, 110, 103, 108, 101, 95,
  80, 84, 61, 34, 114, 42, 34, 123, 123, 112, 105, 125, 47, 50, 53, 48,
  42, 36, 66, 95, 80, 84, 125, 34, 47, 82, 34, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 84, 121, 112, 101, 95, 80, 84, 61, 61, 52, 125, 10,
  82, 97, 100, 105, 117, 115, 95, 80, 84, 61, 34, 114, 42, 34, 123, 48,
  46, 53, 43, 123, 36, 65, 95, 80, 84, 47, 53, 48, 48, 125, 125, 34,
  34, 10, 65, 110, 103, 108, 101, 95, 80, 84, 61, 34, 97, 43, 99, 111,
  115, 40, 114, 47, 82, 42, 34, 123, 123, 112, 105, 125, 47, 49, 50, 53,
  42, 36, 66, 95, 80, 84, 125, 34, 41, 34, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 84, 121, 112, 101, 95, 80, 84, 61, 61, 53, 125, 10, 82,
  97, 100, 105, 117, 115, 95, 80, 84, 61, 34, 114, 42, 34, 123, 48, 46,
  53, 43, 123, 36, 65, 95, 80, 84, 47, 53, 48, 48, 125, 125, 34, 34,
  10, 65, 110, 103, 108, 101, 95, 80, 84, 61, 34, 97, 45, 99, 111, 115,
  40, 114, 47, 82, 42, 34, 123, 123, 112, 105, 125, 47, 49, 50, 53, 42,
  36, 66, 95, 80, 84, 125, 34, 41, 34, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 84, 121, 112, 101, 95, 80, 84, 61, 61, 54, 125, 10, 82, 97,
  100, 105, 117, 115, 95, 80, 84, 61, 34, 114, 43, 40, 97, 42, 34, 123,
  36, 65, 95, 80, 84, 47, 49, 48, 125, 34, 41, 34, 10, 65, 110, 103,
  108, 101, 95, 80, 84, 61, 34, 40, 97, 42, 34, 36, 66, 95, 80, 84,
  34, 47, 49, 48, 48, 41, 43, 34, 123, 123, 112, 105, 125, 47, 49, 48,
  48, 48, 42, 36, 67, 95, 80, 84, 125, 34, 34, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 84, 121, 112, 101, 95, 80, 84, 61, 61, 55, 125, 10,
  82, 97, 100, 105, 117, 115, 95, 80, 84, 61, 34, 114, 45, 40, 97, 42,
  34, 123, 36, 65, 95, 80, 84, 47, 49, 48, 125, 34, 41, 34, 10, 65,
  110, 103, 108, 101, 95, 80, 84, 61, 34, 97, 42, 112, 105, 42, 34, 36,
  66, 95, 80, 84, 47, 53, 48, 48, 34, 34, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 84, 121, 112, 101, 95, 80, 84, 61, 61, 56, 125, 10, 82,
  97, 100, 105, 117, 115, 95, 80, 84, 61, 34, 40, 114, 42, 34, 123, 49,
  43, 123, 36, 65, 95, 80, 84, 47, 50, 53, 48, 125, 125, 34, 41, 45,
  40, 82, 42, 34, 123, 49, 43, 123, 36, 66, 95, 80, 84, 47, 50, 53,
  48, 125, 125, 34, 41, 34, 10, 65, 110, 103, 108, 101, 95, 80, 84, 61,
  34, 97, 43, 40, 97, 42, 112, 105, 42, 34, 36, 67, 95, 80, 84, 47,
  50, 53, 48, 34, 41, 34, 10, 45, 101, 108, 105, 102, 32, 123, 36, 84,
  121, 112, 101, 95, 80, 84, 61, 61, 57, 125, 10, 82, 97, 100, 105, 117,
  115, 95, 80, 84, 61, 34, 114, 43, 40, 114, 42, 34, 123, 36, 65, 95,
  80, 84, 47, 53, 48, 48, 125, 34, 41, 34, 10, 65, 110, 103, 108, 101,
  95, 80, 84, 61, 34, 97, 43, 99, 111, 115, 40, 114, 47, 82, 42, 112,
  105, 47, 50, 41, 42, 34, 123, 36, 66, 95, 80, 84, 47, 49, 48, 48,
  125, 34, 34, 10, 45, 101, 108, 105, 102, 32, 123, 36, 84, 121, 112, 101,
  95, 80, 84, 61, 61, 49, 48, 125, 10, 82, 97, 100, 105, 117, 115, 95,
  80, 84, 61, 34, 114, 43, 40, 114, 42, 34, 123, 36, 65, 95, 80, 84,
  47, 53, 48, 48, 125, 34, 41, 34, 10, 65, 110, 103, 108, 101, 95, 80,
  84, 61, 34, 97, 45, 99, 111, 115, 40, 114, 47, 82, 42, 112, 105, 47,
  50, 41, 42, 34, 123, 36, 66, 95, 80, 84, 47, 49, 48, 48, 125, 34,
  34, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84,
  121, 112, 101, 95, 80, 84, 62, 48, 125, 10, 45, 116, 114, 97, 110, 115,
  102, 111, 114, 109, 95, 112, 111, 108, 97, 114, 32, 36, 82, 97, 100, 105,
  117, 115, 95, 80, 84, 44, 36, 65, 110, 103, 108, 101, 95, 80, 84, 44,
  36, 88, 95, 67, 101, 110, 116, 101, 114, 95, 80, 84, 44, 36, 89, 95,
  67, 101, 110, 116, 101, 114, 95, 80, 84, 44, 36, 66, 111, 117, 110, 100,
  97, 114, 121, 95, 80, 84, 10, 45, 105, 102, 32, 123, 36, 65, 117, 116,
  111, 67, 114, 111, 112, 95, 80, 84, 61, 61, 49, 125, 10, 45, 97, 117,
  116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48,
  44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 65, 114, 114, 97, 121, 95, 77, 105, 114,
  114, 111, 114, 61, 61, 49, 125, 10, 45, 103, 105, 109, 112, 95, 97, 114,
  114, 97, 121, 95, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 36,
  73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 95, 71, 77, 44, 36, 88,
  95, 79, 102, 102, 115, 101, 116, 95, 71, 77, 44, 36, 89, 95, 79, 102,
  102, 115, 101, 116, 95, 71, 77, 44, 36, 65, 114, 114, 97, 121, 95, 77,
  111, 100, 101, 95, 71, 77, 44, 36, 73, 110, 105, 116, 105, 97, 108, 105,
  122, 97, 116, 105, 111, 110, 95, 71, 77, 44, 36, 69, 120, 112, 97, 110,
  100, 95, 83, 105, 122, 101, 95, 71, 77, 44, 36, 67, 114, 111, 112, 95,
  71, 77, 10, 45, 101, 110, 100, 105, 102, 10, 45, 97, 117, 116, 111, 99,
  114, 111, 112, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115, 97, 109, 106,
  95, 83, 121, 109, 101, 116, 114, 105, 101, 95, 80, 111, 108, 97, 114, 95,
  84, 114, 97, 110, 115, 102, 111, 114, 109, 95, 48, 48, 49, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112,
  108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97,
  109, 106, 95, 83, 121, 109, 101, 116, 114, 105, 101, 95, 80, 111, 108, 97,
  114, 95, 84, 114, 97, 110, 115, 102, 111, 114, 109, 95, 48, 48, 49, 32,
  36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 84,
  101, 115, 116, 32, 100, 105, 108, 97, 116, 101, 32, 58, 32, 84, 101, 115,
  116, 95, 68, 105, 108, 97, 116, 101, 95, 115, 97, 109, 106, 44, 32, 84,
  101, 115, 116, 95, 68, 105, 108, 97, 116, 101, 95, 115, 97, 109, 106, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 98, 62, 78, 111, 116, 101,
  60, 47, 98, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 85, 116, 105,
  108, 105, 115, 101, 114, 32, 99, 101, 32, 102, 105, 108, 116, 114, 101, 32,
  115, 117, 114, 32, 100, 101, 115, 32, 116, 114, 97, 105, 116, 115, 44, 32,
  100, 101, 115, 32, 108, 105, 103, 110, 101, 115, 46, 46, 46, 32, 115, 117,
  114, 32, 105, 109, 97, 103, 101, 115, 32, 97, 118, 101, 99, 32, 102, 111,
  110, 100, 32, 116, 114, 97, 110, 115, 112, 97, 114, 101, 110, 116, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 85, 115, 101, 32, 116, 104, 105, 115, 32,
  102, 105, 108, 116, 101, 114, 32, 111, 110, 32, 115, 116, 114, 111, 107, 101,
  115, 44, 32, 108, 105, 110, 101, 115, 46, 46, 46, 32, 111, 110, 32, 105,
  109, 97, 103, 101, 115, 32, 119, 105, 116, 104, 32, 116, 114, 97, 110, 115,
  112, 97, 114, 101, 110, 116, 32, 98, 97, 99, 107, 103, 114, 111, 117, 110,
  100, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112,
  97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111,
  114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108,
  62, 68, 105, 108, 97, 116, 101, 60, 47, 115, 109, 97, 108, 108, 62, 60,
  47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 84, 97, 105, 108, 108, 101, 47, 115, 105, 122, 101, 32, 61, 32,
  105, 110, 116, 40, 49, 44, 48, 44, 54, 52, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 84, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 48, 44, 34, 67, 105, 114, 99, 117, 108, 97, 114, 32, 68,
  105, 108, 97, 116, 105, 111, 110, 34, 44, 34, 79, 99, 116, 97, 103, 111,
  110, 97, 108, 32, 68, 105, 108, 97, 116, 105, 111, 110, 34, 44, 34, 82,
  101, 99, 116, 97, 110, 103, 117, 108, 97, 114, 32, 68, 105, 108, 97, 116,
  97, 116, 105, 111, 110, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 66, 111, 111, 115, 116, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48,
  44, 54, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34,
  111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108,
  108, 62, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 60, 47, 115, 109,
  97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 73, 116, 101, 114, 97, 116, 105, 111, 110,
  115, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49, 44, 49, 54, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102,
  111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103,
  101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 68, 101, 102,
  111, 114, 109, 97, 116, 105, 111, 110, 60, 47, 115, 109, 97, 108, 108, 62,
  60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 51, 50, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101,
  103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101,
  100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 70, 108, 111, 117, 47, 66,
  108, 117, 114, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97,
  110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109,
  112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110,
  100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115,
  109, 97, 108, 108, 62, 83, 112, 114, 101, 97, 100, 60, 47, 115, 109, 97,
  108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 51, 50, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102,
  111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103,
  101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 78, 111, 114,
  109, 97, 108, 105, 122, 101, 32, 76, 111, 99, 97, 108, 60, 47, 115, 109,
  97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 114, 109, 97, 108, 105, 122, 101,
  32, 108, 111, 99, 97, 108, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116,
  117, 100, 101, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49, 44, 54, 52,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 121, 111, 110,
  47, 114, 97, 100, 105, 117, 115, 32, 61, 32, 105, 110, 116, 40, 49, 44,
  49, 44, 54, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101,
  118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  101, 117, 114, 115, 32, 32, 58, 32, 60, 105, 62, 83, 97, 109, 106, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 86, 101, 114, 115, 105, 111,
  110, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 49, 47, 51,
  49, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 84, 101, 115, 116, 95, 68, 105, 108, 97, 116, 101, 95, 115, 97, 109,
  106, 32, 58, 10, 84, 97, 105, 108, 108, 101, 95, 83, 105, 122, 101, 61,
  36, 49, 10, 84, 121, 112, 101, 95, 68, 105, 108, 97, 116, 101, 61, 36,
  50, 10, 66, 111, 111, 115, 116, 61, 36, 51, 10, 73, 116, 101, 114, 97,
  116, 105, 111, 110, 115, 61, 36, 52, 10, 65, 109, 112, 108, 105, 116, 117,
  100, 101, 95, 68, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 61, 36,
  53, 10, 65, 109, 112, 108, 105, 116, 117, 100, 101, 95, 66, 108, 117, 114,
  61, 36, 54, 10, 65, 109, 112, 108, 105, 116, 117, 100, 101, 95, 83, 112,
  114, 101, 97, 100, 61, 36, 55, 10, 86, 97, 108, 105, 100, 101, 114, 95,
  78, 111, 114, 109, 97, 108, 105, 122, 101, 61, 36, 56, 10, 78, 111, 114,
  109, 97, 108, 105, 122, 101, 95, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  61, 36, 57, 10, 78, 111, 114, 109, 97, 108, 105, 122, 101, 95, 82, 97,
  121, 111, 110, 61, 36, 49, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  36, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 10, 45, 105, 102, 32,
  123, 36, 66, 111, 111, 115, 116, 62, 48, 125, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 36, 66, 111, 111, 115, 116, 10, 45, 98, 108, 117, 114, 91,
  45, 49, 93, 32, 49, 10, 45, 100, 105, 108, 97, 116, 101, 95, 99, 105,
  114, 99, 91, 45, 49, 93, 32, 49, 10, 45, 100, 111, 110, 101, 10, 45,
  115, 104, 97, 114, 112, 101, 110, 91, 45, 49, 93, 32, 123, 36, 66, 111,
  111, 115, 116, 42, 49, 48, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 84, 97, 105, 108, 108, 101, 95, 83, 105, 122, 101,
  62, 48, 125, 10, 45, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95, 68,
  105, 108, 97, 116, 101, 61, 61, 48, 125, 32, 45, 100, 105, 108, 97, 116,
  101, 95, 99, 105, 114, 99, 91, 45, 49, 93, 32, 36, 84, 97, 105, 108,
  108, 101, 95, 83, 105, 122, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 84, 121, 112, 101, 95, 68, 105, 108, 97, 116, 101,
  61, 61, 49, 125, 32, 45, 100, 105, 108, 97, 116, 101, 95, 111, 99, 116,
  91, 45, 49, 93, 32, 36, 84, 97, 105, 108, 108, 101, 95, 83, 105, 122,
  101, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84,
  121, 112, 101, 95, 68, 105, 108, 97, 116, 101, 61, 61, 50, 125, 32, 45,
  100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 36, 84, 97, 105, 108,
  108, 101, 95, 83, 105, 122, 101, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 100, 101, 102,
  111, 114, 109, 91, 45, 49, 93, 32, 36, 65, 109, 112, 108, 105, 116, 117,
  100, 101, 95, 68, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 10, 45,
  98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 65, 109, 112, 108, 105, 116,
  117, 100, 101, 95, 66, 108, 117, 114, 10, 45, 115, 112, 114, 101, 97, 100,
  91, 45, 49, 93, 32, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 95,
  83, 112, 114, 101, 97, 100, 10, 45, 105, 102, 32, 123, 36, 86, 97, 108,
  105, 100, 101, 114, 95, 78, 111, 114, 109, 97, 108, 105, 122, 101, 61, 61,
  49, 125, 10, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95, 108, 111,
  99, 97, 108, 91, 45, 49, 93, 32, 36, 78, 111, 114, 109, 97, 108, 105,
  122, 101, 95, 65, 109, 112, 108, 105, 116, 117, 100, 101, 44, 36, 78, 111,
  114, 109, 97, 108, 105, 122, 101, 95, 82, 97, 121, 111, 110, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 66, 111, 111, 115, 116,
  62, 48, 125, 10, 45, 115, 104, 97, 114, 112, 101, 110, 91, 45, 49, 93,
  32, 49, 48, 48, 10, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103, 105,
  109, 112, 32, 87, 105, 110, 100, 32, 113, 117, 97, 116, 114, 101, 32, 122,
  111, 110, 101, 115, 32, 48, 48, 49, 32, 58, 32, 115, 97, 109, 106, 95,
  87, 105, 110, 100, 95, 81, 117, 97, 116, 114, 101, 95, 90, 111, 110, 101,
  115, 95, 48, 48, 49, 44, 32, 115, 97, 109, 106, 95, 87, 105, 110, 100,
  95, 81, 117, 97, 116, 114, 101, 95, 90, 111, 110, 101, 115, 95, 48, 48,
  49, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101,
  103, 114, 111, 117, 110, 100, 61, 34, 114, 101, 100, 34, 62, 87, 105, 110,
  100, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32,
  105, 110, 116, 40, 52, 48, 44, 48, 44, 53, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 52, 53, 44, 48, 44, 51, 54, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 116, 116, 101, 110, 117, 97, 116,
  105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 44,
  48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104,
  114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  50, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 49, 44, 34, 68, 97, 114, 107, 101, 114, 34, 44, 34, 66, 114, 105,
  103, 104, 116, 101, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 50, 44, 34, 65, 108, 108, 34, 44, 34, 82, 71,
  66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32,
  99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66,
  108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34,
  44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34,
  97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34,
  97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34,
  44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86,
  97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 71, 114, 101,
  101, 110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44,
  34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100,
  34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34,
  44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121,
  112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 115, 97, 109, 106, 32, 45, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62,
  50, 48, 49, 52, 47, 48, 49, 47, 50, 48, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 87,
  105, 110, 100, 95, 81, 117, 97, 116, 114, 101, 95, 90, 111, 110, 101, 115,
  95, 48, 48, 49, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 65, 109, 112, 108, 105, 116, 117,
  100, 101, 95, 87, 105, 110, 100, 61, 36, 49, 10, 65, 110, 103, 108, 101,
  95, 87, 105, 110, 100, 61, 36, 50, 10, 65, 116, 116, 101, 110, 117, 97,
  116, 105, 111, 110, 95, 87, 105, 110, 100, 61, 36, 51, 10, 84, 104, 114,
  101, 115, 104, 111, 108, 100, 95, 87, 105, 110, 100, 61, 36, 52, 10, 77,
  111, 100, 101, 95, 87, 105, 110, 100, 61, 36, 53, 10, 67, 104, 97, 110,
  110, 101, 108, 115, 95, 87, 105, 110, 100, 61, 36, 54, 10, 65, 110, 103,
  108, 101, 95, 67, 97, 108, 99, 117, 108, 101, 61, 48, 10, 45, 115, 112,
  108, 105, 116, 91, 45, 49, 93, 32, 120, 121, 44, 50, 10, 65, 110, 103,
  108, 101, 95, 67, 97, 108, 99, 117, 108, 101, 61, 36, 65, 110, 103, 108,
  101, 95, 87, 105, 110, 100, 10, 45, 103, 105, 109, 112, 95, 119, 105, 110,
  100, 91, 45, 49, 93, 32, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  95, 87, 105, 110, 100, 44, 36, 65, 110, 103, 108, 101, 95, 67, 97, 108,
  99, 117, 108, 101, 44, 36, 65, 116, 116, 101, 110, 117, 97, 116, 105, 111,
  110, 95, 87, 105, 110, 100, 44, 36, 84, 104, 114, 101, 115, 104, 111, 108,
  100, 95, 87, 105, 110, 100, 44, 36, 77, 111, 100, 101, 95, 87, 105, 110,
  100, 44, 36, 67, 104, 97, 110, 110, 101, 108, 115, 95, 87, 105, 110, 100,
  10, 65, 110, 103, 108, 101, 95, 67, 97, 108, 99, 117, 108, 101, 61, 123,
  36, 65, 110, 103, 108, 101, 95, 87, 105, 110, 100, 43, 50, 55, 48, 125,
  10, 45, 105, 102, 32, 123, 36, 65, 110, 103, 108, 101, 95, 67, 97, 108,
  99, 117, 108, 101, 62, 51, 54, 48, 125, 32, 65, 110, 103, 108, 101, 95,
  67, 97, 108, 99, 117, 108, 101, 61, 123, 36, 65, 110, 103, 108, 101, 95,
  67, 97, 108, 99, 117, 108, 101, 45, 51, 54, 48, 125, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 119, 105, 110, 100, 91, 45,
  50, 93, 32, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 95, 87, 105,
  110, 100, 44, 36, 65, 110, 103, 108, 101, 95, 67, 97, 108, 99, 117, 108,
  101, 44, 36, 65, 116, 116, 101, 110, 117, 97, 116, 105, 111, 110, 95, 87,
  105, 110, 100, 44, 36, 84, 104, 114, 101, 115, 104, 111, 108, 100, 95, 87,
  105, 110, 100, 44, 36, 77, 111, 100, 101, 95, 87, 105, 110, 100, 44, 36,
  67, 104, 97, 110, 110, 101, 108, 115, 95, 87, 105, 110, 100, 10, 65, 110,
  103, 108, 101, 95, 67, 97, 108, 99, 117, 108, 101, 61, 123, 36, 65, 110,
  103, 108, 101, 95, 87, 105, 110, 100, 43, 57, 48, 125, 10, 45, 105, 102,
  32, 123, 36, 65, 110, 103, 108, 101, 95, 67, 97, 108, 99, 117, 108, 101,
  62, 51, 54, 48, 125, 32, 65, 110, 103, 108, 101, 95, 67, 97, 108, 99,
  117, 108, 101, 61, 123, 36, 65, 110, 103, 108, 101, 95, 67, 97, 108, 99,
  117, 108, 101, 45, 51, 54, 48, 125, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 103, 105, 109, 112, 95, 119, 105, 110, 100, 91, 45, 51, 93, 32, 36,
  65, 109, 112, 108, 105, 116, 117, 100, 101, 95, 87, 105, 110, 100, 44, 36,
  65, 110, 103, 108, 101, 95, 67, 97, 108, 99, 117, 108, 101, 44, 36, 65,
  116, 116, 101, 110, 117, 97, 116, 105, 111, 110, 95, 87, 105, 110, 100, 44,
  36, 84, 104, 114, 101, 115, 104, 111, 108, 100, 95, 87, 105, 110, 100, 44,
  36, 77, 111, 100, 101, 95, 87, 105, 110, 100, 44, 36, 67, 104, 97, 110,
  110, 101, 108, 115, 95, 87, 105, 110, 100, 10, 65, 110, 103, 108, 101, 95,
  67, 97, 108, 99, 117, 108, 101, 61, 123, 36, 65, 110, 103, 108, 101, 95,
  87, 105, 110, 100, 43, 49, 56, 48, 125, 10, 45, 105, 102, 32, 123, 36,
  65, 110, 103, 108, 101, 95, 67, 97, 108, 99, 117, 108, 101, 62, 51, 54,
  48, 125, 32, 65, 110, 103, 108, 101, 95, 67, 97, 108, 99, 117, 108, 101,
  61, 123, 36, 65, 110, 103, 108, 101, 95, 67, 97, 108, 99, 117, 108, 101,
  45, 51, 54, 48, 125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105,
  109, 112, 95, 119, 105, 110, 100, 91, 45, 52, 93, 32, 36, 65, 109, 112,
  108, 105, 116, 117, 100, 101, 95, 87, 105, 110, 100, 44, 36, 65, 110, 103,
  108, 101, 95, 67, 97, 108, 99, 117, 108, 101, 44, 36, 65, 116, 116, 101,
  110, 117, 97, 116, 105, 111, 110, 95, 87, 105, 110, 100, 44, 36, 84, 104,
  114, 101, 115, 104, 111, 108, 100, 95, 87, 105, 110, 100, 44, 36, 77, 111,
  100, 101, 95, 87, 105, 110, 100, 44, 36, 67, 104, 97, 110, 110, 101, 108,
  115, 95, 87, 105, 110, 100, 10, 45, 97, 112, 112, 101, 110, 100, 91, 45,
  49, 44, 45, 50, 93, 32, 121, 10, 45, 97, 112, 112, 101, 110, 100, 91,
  45, 50, 44, 45, 51, 93, 32, 121, 10, 45, 97, 112, 112, 101, 110, 100,
  91, 45, 49, 44, 45, 50, 93, 32, 120, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 115, 97, 109, 106, 95, 87, 105, 110, 100, 95,
  81, 117, 97, 116, 114, 101, 95, 90, 111, 110, 101, 115, 95, 48, 48, 49,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112,
  95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34,
  45, 115, 97, 109, 106, 95, 87, 105, 110, 100, 95, 81, 117, 97, 116, 114,
  101, 95, 90, 111, 110, 101, 115, 95, 48, 48, 49, 32, 36, 42, 34, 44,
  36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 87, 105, 110, 100, 32,
  113, 117, 97, 116, 114, 101, 32, 122, 111, 110, 101, 115, 32, 48, 48, 50,
  32, 58, 32, 115, 97, 109, 106, 95, 87, 105, 110, 100, 95, 81, 117, 97,
  116, 114, 101, 95, 90, 111, 110, 101, 115, 95, 48, 48, 50, 44, 32, 115,
  97, 109, 106, 95, 87, 105, 110, 100, 95, 81, 117, 97, 116, 114, 101, 95,
  90, 111, 110, 101, 115, 95, 48, 48, 50, 95, 112, 114, 101, 118, 105, 101,
  119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34,
  111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 77, 97, 120, 32, 80,
  97, 116, 99, 104, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 80, 97, 116, 99, 104, 32, 115, 105, 122,
  101, 32, 61, 32, 105, 110, 116, 40, 54, 52, 44, 49, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 105, 108, 97, 116,
  101, 32, 61, 32, 105, 110, 116, 40, 49, 48, 44, 49, 44, 49, 50, 56,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110,
  32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97,
  110, 103, 101, 114, 101, 100, 34, 62, 77, 105, 110, 32, 80, 97, 116, 99,
  104, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 80, 97, 116, 99, 104, 32, 115, 105, 122, 101, 32, 61,
  32, 105, 110, 116, 40, 54, 52, 44, 49, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 105, 108, 97, 116, 101, 32, 61,
  32, 105, 110, 116, 40, 49, 48, 44, 49, 44, 49, 50, 56, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111,
  114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101,
  114, 101, 100, 34, 62, 87, 105, 110, 100, 60, 47, 115, 112, 97, 110, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108,
  105, 116, 117, 100, 101, 32, 61, 32, 105, 110, 116, 40, 52, 48, 44, 48,
  44, 53, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 53, 44,
  48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  65, 116, 116, 101, 110, 117, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 55, 44, 48, 44, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 84, 104, 114, 101, 115, 104, 111, 108, 100, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 100, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 68, 97, 114, 107,
  101, 114, 34, 44, 34, 66, 114, 105, 103, 104, 116, 101, 114, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108,
  40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 50, 44, 34,
  65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66,
  34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66,
  108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97,
  110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104,
  116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97,
  116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75,
  101, 121, 34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112,
  111, 110, 101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111,
  110, 101, 110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110,
  34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110,
  32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97,
  110, 103, 101, 114, 101, 100, 34, 62, 66, 108, 101, 110, 100, 60, 47, 115,
  112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  77, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44,
  34, 65, 100, 100, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34, 65,
  110, 100, 34, 44, 34, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 66,
  108, 117, 101, 34, 44, 34, 66, 117, 114, 110, 34, 44, 34, 68, 97, 114,
  107, 101, 110, 34, 44, 34, 68, 105, 102, 102, 101, 114, 101, 110, 99, 101,
  34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 68, 105, 118,
  105, 100, 101, 34, 44, 34, 68, 111, 100, 103, 101, 34, 44, 34, 69, 120,
  99, 108, 117, 115, 105, 111, 110, 34, 44, 34, 70, 114, 101, 101, 122, 101,
  34, 44, 34, 71, 114, 97, 105, 110, 32, 101, 120, 116, 114, 97, 99, 116,
  34, 44, 34, 71, 114, 97, 105, 110, 32, 109, 101, 114, 103, 101, 34, 44,
  34, 71, 114, 101, 101, 110, 34, 44, 34, 72, 97, 114, 100, 32, 108, 105,
  103, 104, 116, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34,
  72, 97, 114, 100, 32, 109, 105, 120, 34, 44, 34, 72, 117, 101, 34, 44,
  34, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 34, 44,
  34, 76, 105, 103, 104, 116, 101, 110, 34, 44, 34, 76, 105, 103, 104, 116,
  110, 101, 115, 115, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 98, 117,
  114, 110, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 108, 105, 103, 104,
  116, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 77, 117, 108, 116, 105, 112,
  108, 121, 34, 44, 34, 78, 101, 103, 97, 116, 105, 111, 110, 34, 44, 34,
  79, 114, 34, 44, 34, 79, 118, 101, 114, 108, 97, 121, 34, 44, 34, 80,
  105, 110, 32, 108, 105, 103, 104, 116, 34, 44, 34, 82, 101, 100, 34, 44,
  34, 82, 101, 102, 108, 101, 99, 116, 34, 44, 34, 83, 97, 116, 117, 114,
  97, 116, 105, 111, 110, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101, 34,
  44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101, 48,
  34, 44, 34, 83, 111, 102, 116, 32, 98, 117, 114, 110, 34, 44, 34, 83,
  111, 102, 116, 32, 100, 111, 100, 103, 101, 34, 44, 34, 83, 111, 102, 116,
  32, 108, 105, 103, 104, 116, 34, 44, 34, 83, 99, 114, 101, 101, 110, 34,
  44, 34, 83, 116, 97, 109, 112, 34, 44, 34, 83, 117, 98, 116, 114, 97,
  99, 116, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 34, 86, 105, 118, 105, 100, 32, 108, 105, 103,
  104, 116, 34, 44, 34, 88, 111, 114, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121, 101, 114,
  115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103,
  114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100,
  34, 62, 67, 111, 117, 108, 101, 117, 114, 115, 32, 47, 32, 67, 111, 108,
  111, 114, 115, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 115, 32, 47,
  32, 99, 111, 108, 111, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97,
  109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47,
  50, 48, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 115, 97, 109, 106, 95, 87, 105, 110, 100, 95, 81, 117, 97, 116,
  114, 101, 95, 90, 111, 110, 101, 115, 95, 48, 48, 50, 32, 58, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93,
  10, 77, 97, 120, 95, 80, 97, 116, 99, 104, 95, 80, 97, 116, 99, 104,
  95, 83, 105, 122, 101, 61, 36, 49, 10, 68, 105, 108, 97, 116, 101, 95,
  77, 97, 120, 95, 80, 97, 116, 99, 104, 61, 36, 50, 10, 77, 105, 110,
  95, 80, 97, 116, 99, 104, 95, 80, 97, 116, 99, 104, 95, 83, 105, 122,
  101, 61, 36, 51, 10, 68, 105, 108, 97, 116, 101, 95, 77, 105, 110, 95,
  80, 97, 116, 99, 104, 61, 36, 52, 10, 65, 109, 112, 108, 105, 116, 117,
  100, 101, 95, 87, 105, 110, 100, 61, 36, 53, 10, 65, 110, 103, 108, 101,
  95, 87, 105, 110, 100, 61, 36, 54, 10, 65, 116, 116, 101, 110, 117, 97,
  116, 105, 111, 110, 95, 87, 105, 110, 100, 61, 36, 55, 10, 84, 104, 114,
  101, 115, 104, 111, 108, 100, 95, 87, 105, 110, 100, 61, 36, 56, 10, 77,
  111, 100, 101, 95, 87, 105, 110, 100, 61, 36, 57, 10, 67, 104, 97, 110,
  110, 101, 108, 115, 95, 87, 105, 110, 100, 61, 36, 49, 48, 10, 98, 108,
  101, 110, 100, 61, 36, 49, 49, 10, 111, 112, 97, 99, 105, 116, 101, 61,
  36, 49, 50, 10, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114,
  115, 61, 36, 49, 51, 10, 67, 111, 117, 108, 101, 117, 114, 115, 61, 36,
  49, 52, 10, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10, 45,
  45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103,
  91, 45, 49, 93, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110,
  111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 109, 97, 120, 95,
  112, 97, 116, 99, 104, 91, 45, 49, 93, 32, 36, 77, 97, 120, 95, 80,
  97, 116, 99, 104, 95, 80, 97, 116, 99, 104, 95, 83, 105, 122, 101, 10,
  45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10, 45, 110, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 100, 105, 108, 97, 116, 101,
  95, 99, 105, 114, 99, 91, 45, 49, 93, 32, 36, 68, 105, 108, 97, 116,
  101, 95, 77, 97, 120, 95, 80, 97, 116, 99, 104, 10, 45, 109, 105, 110,
  95, 112, 97, 116, 99, 104, 91, 45, 50, 93, 32, 36, 77, 105, 110, 95,
  80, 97, 116, 99, 104, 95, 80, 97, 116, 99, 104, 95, 83, 105, 122, 101,
  10, 45, 116, 111, 95, 114, 103, 98, 91, 45, 50, 93, 10, 45, 110, 91,
  45, 50, 93, 32, 48, 44, 50, 53, 53, 10, 45, 100, 105, 108, 97, 116,
  101, 95, 99, 105, 114, 99, 91, 45, 50, 93, 32, 36, 68, 105, 108, 97,
  116, 101, 95, 77, 105, 110, 95, 80, 97, 116, 99, 104, 10, 45, 105, 102,
  32, 123, 36, 67, 111, 117, 108, 101, 117, 114, 115, 61, 61, 48, 125, 10,
  45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 49, 44, 45, 50, 93, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91,
  45, 49, 44, 45, 50, 93, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95,
  99, 111, 108, 111, 114, 91, 45, 49, 44, 45, 50, 93, 32, 52, 48, 44,
  51, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 48, 44, 48, 44,
  48, 44, 48, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 97, 108, 112,
  104, 97, 91, 45, 49, 44, 45, 50, 93, 10, 45, 115, 97, 109, 106, 95,
  87, 105, 110, 100, 95, 81, 117, 97, 116, 114, 101, 95, 90, 111, 110, 101,
  115, 95, 48, 48, 49, 91, 45, 49, 93, 32, 36, 65, 109, 112, 108, 105,
  116, 117, 100, 101, 95, 87, 105, 110, 100, 44, 36, 65, 110, 103, 108, 101,
  95, 87, 105, 110, 100, 44, 36, 65, 116, 116, 101, 110, 117, 97, 116, 105,
  111, 110, 95, 87, 105, 110, 100, 44, 36, 84, 104, 114, 101, 115, 104, 111,
  108, 100, 95, 87, 105, 110, 100, 44, 36, 77, 111, 100, 101, 95, 87, 105,
  110, 100, 44, 36, 67, 104, 97, 110, 110, 101, 108, 115, 95, 87, 105, 110,
  100, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49,
  44, 45, 50, 93, 32, 36, 98, 108, 101, 110, 100, 44, 36, 111, 112, 97,
  99, 105, 116, 101, 44, 36, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121,
  101, 114, 115, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  115, 97, 109, 106, 95, 87, 105, 110, 100, 95, 81, 117, 97, 116, 114, 101,
  95, 90, 111, 110, 101, 115, 95, 48, 48, 50, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95,
  87, 105, 110, 100, 95, 81, 117, 97, 116, 114, 101, 95, 90, 111, 110, 101,
  115, 95, 48, 48, 50, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64,
  103, 105, 109, 112, 32, 95, 10, 35, 64, 103, 105, 109, 112, 32, 60, 105,
  62, 68, 101, 103, 114, 97, 100, 97, 116, 105, 111, 110, 115, 60, 47, 105,
  62, 10, 35, 64, 103, 105, 109, 112, 32, 69, 99, 104, 101, 99, 115, 32,
  102, 111, 117, 32, 48, 48, 49, 32, 58, 32, 115, 97, 109, 106, 95, 69,
  99, 104, 101, 99, 115, 95, 70, 111, 117, 95, 48, 48, 49, 44, 32, 115,
  97, 109, 106, 95, 69, 99, 104, 101, 99, 115, 95, 70, 111, 117, 95, 48,
  48, 49, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117,
  110, 100, 61, 34, 114, 101, 100, 34, 62, 67, 101, 32, 102, 105, 108, 116,
  114, 101, 32, 101, 115, 116, 32, 108, 101, 110, 116, 46, 46, 46, 60, 47,
  115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110,
  100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115,
  109, 97, 108, 108, 62, 68, 38, 35, 50, 51, 51, 59, 112, 108, 97, 99,
  101, 109, 101, 110, 116, 115, 32, 100, 117, 32, 70, 111, 117, 60, 47, 115,
  109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 101, 114, 97, 116, 105, 111,
  110, 115, 32, 61, 32, 105, 110, 116, 40, 49, 48, 44, 49, 44, 50, 53,
  54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108,
  105, 116, 117, 100, 101, 32, 61, 32, 105, 110, 116, 40, 56, 44, 56, 44,
  51, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110,
  116, 105, 110, 117, 105, 116, 101, 32, 101, 110, 116, 114, 101, 32, 105, 116,
  101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 98, 111, 111, 108, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 66, 108, 101, 110, 100, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 100, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 49, 44, 34, 65, 100,
  100, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34, 65, 110, 100, 34,
  44, 34, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 66, 108, 117, 101,
  34, 44, 34, 66, 117, 114, 110, 34, 44, 34, 68, 97, 114, 107, 101, 110,
  34, 44, 34, 68, 105, 102, 102, 101, 114, 101, 110, 99, 101, 34, 44, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 68, 105, 118, 105, 100, 101,
  34, 44, 34, 68, 111, 100, 103, 101, 34, 44, 34, 69, 120, 99, 108, 117,
  115, 105, 111, 110, 34, 44, 34, 70, 114, 101, 101, 122, 101, 34, 44, 34,
  71, 114, 97, 105, 110, 32, 101, 120, 116, 114, 97, 99, 116, 34, 44, 34,
  71, 114, 97, 105, 110, 32, 109, 101, 114, 103, 101, 34, 44, 34, 71, 114,
  101, 101, 110, 34, 44, 34, 72, 97, 114, 100, 32, 108, 105, 103, 104, 116,
  34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 72, 97, 114,
  100, 32, 109, 105, 120, 34, 44, 34, 72, 117, 101, 34, 44, 34, 73, 110,
  116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 34, 44, 34, 76, 105,
  103, 104, 116, 101, 110, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115,
  115, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 98, 117, 114, 110, 34,
  44, 34, 76, 105, 110, 101, 97, 114, 32, 108, 105, 103, 104, 116, 34, 44,
  34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 34, 77, 117, 108, 116, 105, 112, 108, 121, 34,
  44, 34, 78, 101, 103, 97, 116, 105, 111, 110, 34, 44, 34, 79, 114, 34,
  44, 34, 79, 118, 101, 114, 108, 97, 121, 34, 44, 34, 80, 105, 110, 32,
  108, 105, 103, 104, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 82, 101,
  102, 108, 101, 99, 116, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105,
  111, 110, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 83,
  104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 83,
  104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101, 48, 34, 44, 34,
  83, 111, 102, 116, 32, 98, 117, 114, 110, 34, 44, 34, 83, 111, 102, 116,
  32, 100, 111, 100, 103, 101, 34, 44, 34, 83, 111, 102, 116, 32, 108, 105,
  103, 104, 116, 34, 44, 34, 83, 99, 114, 101, 101, 110, 34, 44, 34, 83,
  116, 97, 109, 112, 34, 44, 34, 83, 117, 98, 116, 114, 97, 99, 116, 34,
  44, 34, 86, 97, 108, 117, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 34, 86, 105, 118, 105, 100, 32, 108, 105, 103, 104, 116, 34,
  44, 34, 88, 111, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121, 101, 114, 115, 32, 61,
  32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 68, 105, 118, 101, 114, 115, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 70, 108, 111, 117, 32, 47, 32, 98, 108, 117, 114, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 112, 114, 101, 97, 100, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 68, 101, 102, 111, 114, 109, 97, 116, 105,
  111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 50,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80,
  114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115,
  97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49,
  47, 51, 49, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 115, 97, 109, 106, 95, 69, 99, 104, 101, 99, 115, 95, 70,
  111, 117, 95, 48, 48, 49, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 73, 116, 101, 114, 97,
  116, 105, 111, 110, 115, 61, 36, 49, 10, 65, 109, 112, 108, 105, 116, 117,
  100, 101, 61, 36, 50, 10, 67, 111, 110, 116, 105, 110, 117, 105, 116, 101,
  61, 36, 51, 10, 98, 108, 101, 110, 100, 61, 36, 52, 10, 111, 112, 97,
  99, 105, 116, 101, 61, 36, 53, 10, 82, 101, 118, 101, 114, 116, 95, 108,
  97, 121, 101, 114, 115, 61, 36, 54, 10, 70, 108, 111, 117, 95, 70, 111,
  117, 61, 36, 55, 10, 83, 112, 114, 101, 97, 100, 95, 70, 111, 117, 61,
  36, 56, 10, 68, 101, 102, 111, 114, 109, 95, 70, 111, 117, 61, 36, 57,
  10, 67, 104, 111, 105, 120, 61, 48, 10, 76, 97, 114, 103, 101, 117, 114,
  95, 79, 114, 105, 103, 105, 110, 101, 61, 123, 119, 125, 10, 72, 97, 117,
  116, 101, 117, 114, 95, 79, 114, 105, 103, 105, 110, 101, 61, 123, 104, 125,
  10, 80, 111, 115, 105, 116, 105, 111, 110, 95, 88, 61, 123, 114, 111, 117,
  110, 100, 40, 63, 40, 48, 44, 123, 36, 76, 97, 114, 103, 101, 117, 114,
  95, 79, 114, 105, 103, 105, 110, 101, 45, 49, 125, 41, 41, 125, 10, 80,
  111, 115, 105, 116, 105, 111, 110, 95, 89, 61, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 48, 44, 123, 36, 72, 97, 117, 116, 101, 117, 114, 95, 79,
  114, 105, 103, 105, 110, 101, 45, 49, 125, 41, 41, 125, 10, 82, 95, 80,
  111, 105, 110, 116, 61, 49, 50, 55, 10, 86, 95, 80, 111, 105, 110, 116,
  61, 49, 50, 55, 10, 66, 95, 80, 111, 105, 110, 116, 61, 49, 50, 55,
  10, 65, 95, 80, 111, 105, 110, 116, 61, 50, 53, 53, 10, 45, 116, 111,
  95, 114, 103, 98, 97, 91, 45, 49, 93, 10, 35, 45, 45, 103, 105, 109,
  112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 10, 45, 45, 103,
  105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 10, 36,
  76, 97, 114, 103, 101, 117, 114, 95, 79, 114, 105, 103, 105, 110, 101, 44,
  36, 72, 97, 117, 116, 101, 117, 114, 95, 79, 114, 105, 103, 105, 110, 101,
  44, 49, 44, 52, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114,
  91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 10, 35, 35, 32,
  68, -23, 112, 108, 97, 99, 101, 109, 101, 110, 116, 115, 32, 100, 117, 32,
  70, 111, 117, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 73, 116, 101,
  114, 97, 116, 105, 111, 110, 115, 10, 45, 105, 102, 32, 123, 36, 67, 111,
  110, 116, 105, 110, 117, 105, 116, 101, 61, 61, 48, 125, 10, 80, 111, 115,
  105, 116, 105, 111, 110, 95, 88, 61, 123, 114, 111, 117, 110, 100, 40, 63,
  40, 48, 44, 123, 36, 76, 97, 114, 103, 101, 117, 114, 95, 79, 114, 105,
  103, 105, 110, 101, 45, 49, 125, 41, 41, 125, 10, 80, 111, 115, 105, 116,
  105, 111, 110, 95, 89, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 123, 36, 72, 97, 117, 116, 101, 117, 114, 95, 79, 114, 105, 103, 105,
  110, 101, 45, 49, 125, 41, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 36, 76, 97, 114, 103, 101, 117,
  114, 95, 79, 114, 105, 103, 105, 110, 101, 43, 36, 72, 97, 117, 116, 101,
  117, 114, 95, 79, 114, 105, 103, 105, 110, 101, 125, 10, 67, 104, 111, 105,
  120, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 49, 41, 41,
  125, 10, 73, 110, 99, 95, 88, 61, 123, 123, 114, 111, 117, 110, 100, 40,
  63, 40, 48, 44, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 41, 41,
  125, 45, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 36, 65, 109,
  112, 108, 105, 116, 117, 100, 101, 41, 41, 125, 125, 10, 45, 105, 102, 32,
  123, 36, 67, 104, 111, 105, 120, 61, 61, 48, 125, 32, 73, 110, 99, 95,
  89, 61, 36, 73, 110, 99, 95, 88, 32, 45, 101, 108, 115, 101, 32, 73,
  110, 99, 95, 89, 61, 123, 48, 45, 36, 73, 110, 99, 95, 88, 125, 32,
  45, 101, 110, 100, 105, 102, 10, 80, 111, 115, 105, 116, 105, 111, 110, 95,
  88, 61, 123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 88, 43, 36,
  73, 110, 99, 95, 88, 125, 10, 45, 105, 102, 32, 123, 36, 80, 111, 115,
  105, 116, 105, 111, 110, 95, 88, 60, 48, 125, 32, 80, 111, 115, 105, 116,
  105, 111, 110, 95, 88, 61, 123, 36, 76, 97, 114, 103, 101, 117, 114, 95,
  79, 114, 105, 103, 105, 110, 101, 45, 49, 125, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 80, 111, 115, 105, 116, 105, 111, 110,
  95, 88, 62, 123, 36, 76, 97, 114, 103, 101, 117, 114, 95, 79, 114, 105,
  103, 105, 110, 101, 45, 49, 125, 125, 32, 80, 111, 115, 105, 116, 105, 111,
  110, 95, 88, 61, 48, 32, 45, 101, 110, 100, 105, 102, 10, 80, 111, 115,
  105, 116, 105, 111, 110, 95, 89, 61, 123, 36, 80, 111, 115, 105, 116, 105,
  111, 110, 95, 89, 43, 36, 73, 110, 99, 95, 89, 125, 10, 45, 105, 102,
  32, 123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 89, 60, 48, 125,
  32, 80, 111, 115, 105, 116, 105, 111, 110, 95, 89, 61, 123, 36, 72, 97,
  117, 116, 101, 117, 114, 95, 79, 114, 105, 103, 105, 110, 101, 45, 49, 125,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 80, 111,
  115, 105, 116, 105, 111, 110, 95, 89, 62, 123, 36, 72, 97, 117, 116, 101,
  117, 114, 95, 79, 114, 105, 103, 105, 110, 101, 45, 49, 125, 125, 32, 80,
  111, 115, 105, 116, 105, 111, 110, 95, 89, 61, 48, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 112, 111, 105, 110, 116, 91, 45, 49, 93, 32, 36, 80,
  111, 115, 105, 116, 105, 111, 110, 95, 88, 44, 36, 80, 111, 115, 105, 116,
  105, 111, 110, 95, 89, 44, 48, 44, 49, 44, 36, 82, 95, 80, 111, 105,
  110, 116, 44, 36, 86, 95, 80, 111, 105, 110, 116, 44, 36, 66, 95, 80,
  111, 105, 110, 116, 44, 36, 65, 95, 80, 111, 105, 110, 116, 10, 45, 100,
  111, 110, 101, 10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36,
  70, 108, 111, 117, 95, 70, 111, 117, 62, 48, 125, 32, 45, 98, 108, 117,
  114, 91, 45, 49, 93, 32, 36, 70, 108, 111, 117, 95, 70, 111, 117, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 83, 112, 114,
  101, 97, 100, 95, 70, 111, 117, 62, 48, 125, 32, 45, 115, 112, 114, 101,
  97, 100, 91, 45, 49, 93, 32, 36, 83, 112, 114, 101, 97, 100, 95, 70,
  111, 117, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  68, 101, 102, 111, 114, 109, 95, 70, 111, 117, 62, 48, 125, 32, 45, 100,
  101, 102, 111, 114, 109, 91, 45, 49, 93, 32, 36, 68, 101, 102, 111, 114,
  109, 95, 70, 111, 117, 32, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105,
  109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32,
  52, 50, 44, 49, 44, 48, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101,
  110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 36, 98, 108, 101, 110, 100,
  44, 36, 111, 112, 97, 99, 105, 116, 101, 44, 36, 82, 101, 118, 101, 114,
  116, 95, 108, 97, 121, 101, 114, 115, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 115, 97, 109, 106, 95, 69, 99, 104, 101, 99, 115,
  95, 70, 111, 117, 95, 48, 48, 49, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 69, 99,
  104, 101, 99, 115, 95, 70, 111, 117, 95, 48, 48, 49, 32, 36, 42, 34,
  44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 69, 99, 104, 101,
  99, 115, 32, 102, 111, 117, 32, 48, 48, 50, 32, 58, 32, 115, 97, 109,
  106, 95, 69, 99, 104, 101, 99, 115, 95, 70, 111, 117, 95, 48, 48, 50,
  44, 32, 115, 97, 109, 106, 95, 69, 99, 104, 101, 99, 115, 95, 70, 111,
  117, 95, 48, 48, 50, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103,
  114, 111, 117, 110, 100, 61, 34, 114, 101, 100, 34, 62, 67, 101, 32, 102,
  105, 108, 116, 114, 101, 32, 101, 115, 116, 32, 108, 101, 110, 116, 46, 46,
  46, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114,
  111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34,
  62, 60, 115, 109, 97, 108, 108, 62, 69, 102, 102, 101, 116, 32, 117, 115,
  117, 114, 101, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97,
  110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116,
  101, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 52,
  44, 50, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49,
  52, 47, 48, 49, 47, 51, 49, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 69, 99, 104, 101,
  99, 115, 95, 70, 111, 117, 95, 48, 48, 50, 32, 58, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 36, 49, 10, 45, 115, 97, 109, 106, 95,
  69, 99, 104, 101, 99, 115, 95, 70, 111, 117, 95, 48, 48, 49, 91, 45,
  49, 93, 32, 49, 48, 44, 56, 44, 49, 44, 49, 49, 44, 49, 44, 49,
  44, 48, 44, 48, 44, 48, 10, 45, 100, 111, 110, 101, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 10, 115, 97, 109, 106, 95, 69, 99,
  104, 101, 99, 115, 95, 70, 111, 117, 95, 48, 48, 50, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109,
  106, 95, 69, 99, 104, 101, 99, 115, 95, 70, 111, 117, 95, 48, 48, 50,
  32, 36, 42, 34, 44, 36, 45, 49, 10, 115, 97, 109, 106, 95, 114, 105,
  101, 110, 95, 100, 101, 116, 97, 105, 108, 115, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49,
  93, 10, 115, 97, 109, 106, 95, 114, 105, 101, 110, 95, 102, 114, 97, 109,
  101, 115, 32, 58, 10, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111,
  116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 35, 64, 103, 105, 109, 112,
  32, 84, 101, 115, 116, 32, 110, 111, 105, 115, 101, 32, 58, 32, 84, 101,
  115, 116, 95, 78, 111, 105, 115, 101, 95, 115, 97, 109, 106, 44, 32, 84,
  101, 115, 116, 95, 78, 111, 105, 115, 101, 95, 115, 97, 109, 106, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 98, 62, 78, 111, 116, 101, 60,
  47, 98, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 85, 116, 105, 108,
  105, 115, 101, 114, 32, 99, 101, 32, 102, 105, 108, 116, 114, 101, 32, 115,
  117, 114, 32, 100, 101, 115, 32, 99, 111, 117, 108, 101, 117, 114, 115, 32,
  117, 110, 105, 101, 115, 32, 111, 117, 32, 100, 101, 115, 32, 116, 101, 120,
  116, 101, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 85, 115, 101, 32,
  116, 104, 105, 115, 32, 102, 105, 108, 116, 101, 114, 32, 111, 110, 32, 112,
  97, 116, 116, 101, 114, 110, 115, 32, 119, 105, 116, 104, 32, 115, 111, 108,
  105, 100, 32, 99, 111, 108, 111, 114, 115, 32, 111, 114, 32, 116, 101, 120,
  116, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34,
  111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108,
  108, 62, 80, 108, 97, 115, 109, 97, 60, 47, 115, 109, 97, 108, 108, 62,
  60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 108, 112, 104, 97, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 48, 44, 48, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 66, 101, 116, 97, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 48, 44, 48, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 99, 97, 108, 101, 32, 61, 32, 105, 110, 116, 40, 50, 44,
  48, 44, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34,
  111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108,
  108, 62, 66, 114, 117, 105, 116, 32, 47, 32, 78, 111, 105, 115, 101, 60,
  47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116,
  117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 48, 44, 48,
  44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 105, 115, 101, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 71, 97, 117, 115, 115, 105, 97, 110, 34, 44, 34, 85,
  110, 105, 102, 111, 114, 109, 34, 44, 34, 83, 97, 108, 116, 32, 97, 110,
  100, 32, 112, 101, 112, 112, 101, 114, 34, 44, 34, 80, 111, 105, 115, 115,
  111, 110, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104,
  97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 50, 44, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65, 34,
  44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104, 114,
  111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117, 101,
  32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 82,
  101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111, 109,
  112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34, 83,
  97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108, 117,
  101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 65, 108, 112, 104, 97, 34,
  44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34,
  44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34,
  104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101,
  100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101,
  34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 86, 97, 108, 117, 101, 32, 114, 97, 110, 103, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 67, 117, 116, 34, 44, 34,
  78, 111, 114, 109, 97, 108, 105, 122, 101, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103,
  114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100,
  34, 62, 60, 115, 109, 97, 108, 108, 62, 83, 104, 97, 114, 112, 101, 110,
  60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105,
  116, 117, 100, 101, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 54,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112,
  97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111,
  114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108,
  62, 78, 111, 114, 109, 97, 108, 105, 122, 101, 60, 47, 115, 109, 97, 108,
  108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66,
  32, 61, 32, 105, 110, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110,
  32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97,
  110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 73,
  116, 101, 114, 97, 116, 105, 111, 110, 115, 60, 47, 115, 109, 97, 108, 108,
  62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 61,
  32, 105, 110, 116, 40, 49, 44, 49, 44, 49, 54, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 101, 117, 114, 115, 32, 32, 58, 32, 60,
  105, 62, 83, 97, 109, 106, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 86, 101, 114, 115, 105, 111, 110, 32, 58, 32, 60, 105, 62, 50, 48,
  49, 52, 47, 48, 49, 47, 49, 55, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 84, 101, 115, 116, 95, 78, 111, 105,
  115, 101, 95, 115, 97, 109, 106, 32, 58, 10, 80, 108, 97, 115, 109, 97,
  95, 65, 108, 112, 104, 97, 61, 36, 49, 10, 80, 108, 97, 115, 109, 97,
  95, 66, 101, 116, 97, 61, 36, 50, 10, 80, 108, 97, 115, 109, 97, 95,
  83, 99, 97, 108, 101, 61, 36, 51, 10, 78, 111, 105, 115, 101, 95, 65,
  109, 112, 108, 105, 116, 117, 100, 101, 61, 36, 52, 10, 78, 111, 105, 115,
  101, 95, 84, 121, 112, 101, 61, 36, 53, 10, 78, 111, 105, 115, 101, 95,
  67, 104, 97, 110, 110, 101, 108, 61, 36, 54, 10, 78, 111, 105, 115, 101,
  95, 82, 97, 110, 103, 101, 61, 36, 55, 10, 83, 104, 97, 114, 112, 101,
  110, 95, 65, 109, 112, 108, 105, 116, 117, 100, 101, 61, 36, 56, 10, 78,
  111, 114, 109, 97, 108, 105, 122, 101, 95, 65, 61, 36, 57, 10, 78, 111,
  114, 109, 97, 108, 105, 122, 101, 95, 66, 61, 36, 49, 48, 10, 78, 98,
  95, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 61, 36, 49, 49, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 36, 78, 98, 95, 73, 116, 101, 114,
  97, 116, 105, 111, 110, 115, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91,
  45, 49, 93, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111,
  116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 116, 111, 95, 114, 103,
  98, 91, 45, 49, 93, 10, 45, 112, 108, 97, 115, 109, 97, 91, 45, 49,
  93, 32, 36, 80, 108, 97, 115, 109, 97, 95, 65, 108, 112, 104, 97, 44,
  36, 80, 108, 97, 115, 109, 97, 95, 66, 101, 116, 97, 44, 36, 80, 108,
  97, 115, 109, 97, 95, 83, 99, 97, 108, 101, 10, 45, 103, 105, 109, 112,
  95, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 36, 78, 111, 105, 115,
  101, 95, 65, 109, 112, 108, 105, 116, 117, 100, 101, 44, 36, 78, 111, 105,
  115, 101, 95, 84, 121, 112, 101, 44, 36, 78, 111, 105, 115, 101, 95, 67,
  104, 97, 110, 110, 101, 108, 44, 36, 78, 111, 105, 115, 101, 95, 82, 97,
  110, 103, 101, 10, 45, 105, 102, 32, 123, 36, 83, 104, 97, 114, 112, 101,
  110, 95, 65, 109, 112, 108, 105, 116, 117, 100, 101, 62, 48, 125, 32, 45,
  115, 104, 97, 114, 112, 101, 110, 91, 45, 49, 93, 32, 36, 83, 104, 97,
  114, 112, 101, 110, 95, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45,
  49, 93, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 10,
  45, 105, 102, 32, 123, 36, 78, 111, 114, 109, 97, 108, 105, 122, 101, 95,
  65, 62, 36, 78, 111, 114, 109, 97, 108, 105, 122, 101, 95, 66, 125, 10,
  45, 110, 91, 45, 49, 93, 32, 36, 78, 111, 114, 109, 97, 108, 105, 122,
  101, 95, 66, 44, 36, 78, 111, 114, 109, 97, 108, 105, 122, 101, 95, 65,
  10, 45, 101, 108, 115, 101, 10, 45, 110, 91, 45, 49, 93, 32, 36, 78,
  111, 114, 109, 97, 108, 105, 122, 101, 95, 65, 44, 36, 78, 111, 114, 109,
  97, 108, 105, 122, 101, 95, 66, 10, 45, 101, 110, 100, 105, 102, 10, 35,
  108, 105, 103, 104, 116, 110, 101, 115, 115, 10, 45, 103, 105, 109, 112, 95,
  98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 50, 48, 44,
  49, 44, 49, 10, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112,
  32, 84, 114, 97, 109, 101, 115, 32, 58, 32, 84, 114, 97, 109, 101, 115,
  95, 115, 97, 109, 106, 44, 32, 84, 114, 97, 109, 101, 115, 95, 115, 97,
  109, 106, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 80, 97, 114, 97, 109, 92, 51, 48, 51, 92,
  50, 53, 48, 116, 114, 101, 115, 32, 67, 117, 116, 32, 45, 32, 67, 117,
  116, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  86, 97, 108, 101, 117, 114, 32, 97, 32, 61, 32, 105, 110, 116, 40, 54,
  51, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 86, 97, 108, 101, 117, 114, 32, 98, 32, 61, 32, 105, 110, 116,
  40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 80, 97, 114, 97,
  109, 92, 51, 48, 51, 92, 50, 53, 48, 116, 114, 101, 115, 32, 68, 111,
  116, 115, 66, 87, 32, 45, 32, 68, 111, 116, 115, 66, 87, 32, 112, 97,
  114, 97, 109, 101, 116, 101, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 98, 46, 32,
  115, 99, 97, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 56, 44, 49,
  44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101,
  115, 111, 108, 117, 116, 105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 51,
  48, 44, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 82, 97, 100, 105, 117, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 51, 44, 48, 44, 49, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 80, 97, 114, 97, 109, 92, 51,
  48, 51, 92, 50, 53, 48, 116, 114, 101, 115, 32, 77, 117, 108, 116, 105,
  112, 108, 121, 32, 45, 32, 77, 117, 108, 116, 105, 112, 108, 121, 32, 112,
  97, 114, 97, 109, 101, 116, 101, 114, 115, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 117, 108,
  116, 105, 112, 108, 121, 32, 61, 32, 105, 110, 116, 40, 50, 53, 53, 44,
  48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 80, 97, 114, 97, 109, 92, 51, 48, 51,
  92, 50, 53, 48, 116, 114, 101, 115, 32, 65, 117, 116, 111, 73, 110, 100,
  101, 120, 32, 45, 32, 65, 117, 116, 111, 73, 110, 100, 101, 120, 32, 112,
  97, 114, 97, 109, 101, 116, 101, 114, 115, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 98, 32,
  99, 111, 108, 111, 114, 115, 32, 61, 32, 105, 110, 116, 40, 52, 48, 44,
  49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  68, 105, 116, 104, 101, 114, 105, 110, 103, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 77, 101, 116, 104, 111, 100, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 49, 44, 34, 109, 101, 100, 105, 97, 110, 45, 99, 117, 116, 34,
  44, 34, 107, 45, 109, 101, 97, 110, 115, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 66, 108, 101, 110,
  100, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 49, 44, 34, 65, 100, 100, 34, 44, 34, 65, 108, 112, 104,
  97, 34, 44, 34, 65, 110, 100, 34, 44, 34, 65, 118, 101, 114, 97, 103,
  101, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 66, 117, 114, 110, 34,
  44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 68, 105, 102, 102, 101,
  114, 101, 110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 34, 68, 105, 118, 105, 100, 101, 34, 44, 34, 68, 111, 100, 103, 101,
  34, 44, 34, 69, 120, 99, 108, 117, 115, 105, 111, 110, 34, 44, 34, 70,
  114, 101, 101, 122, 101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 101, 120,
  116, 114, 97, 99, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 109, 101,
  114, 103, 101, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 72, 97,
  114, 100, 32, 108, 105, 103, 104, 116, 34, 44, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44, 34,
  72, 117, 101, 34, 44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116,
  105, 111, 110, 34, 44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44, 34,
  76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110, 101,
  97, 114, 32, 98, 117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97, 114,
  32, 108, 105, 103, 104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 77,
  117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 78, 101, 103, 97, 116, 105,
  111, 110, 34, 44, 34, 79, 114, 34, 44, 34, 79, 118, 101, 114, 108, 97,
  121, 34, 44, 34, 80, 105, 110, 32, 108, 105, 103, 104, 116, 34, 44, 34,
  82, 101, 100, 34, 44, 34, 82, 101, 102, 108, 101, 99, 116, 34, 44, 34,
  83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101,
  114, 97, 103, 101, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101,
  114, 97, 103, 101, 48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117, 114,
  110, 34, 44, 34, 83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34, 44,
  34, 83, 111, 102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83, 99,
  114, 101, 101, 110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34, 83,
  117, 98, 116, 114, 97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101, 34,
  44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 86, 105, 118, 105,
  100, 32, 108, 105, 103, 104, 116, 34, 44, 34, 88, 111, 114, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32,
  108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 80, 97, 114, 97, 109, 92, 51, 48, 51, 92, 50, 53, 48, 116, 114,
  101, 115, 32, 78, 111, 114, 109, 97, 108, 105, 122, 101, 32, 45, 32, 78,
  111, 114, 109, 97, 108, 105, 122, 101, 32, 112, 97, 114, 97, 109, 101, 116,
  101, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 114, 109, 97, 108, 105, 122, 101,
  32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108, 115, 101, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108, 101, 117, 114, 32, 99,
  32, 61, 32, 105, 110, 116, 40, 52, 48, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108, 101, 117, 114,
  32, 100, 32, 61, 32, 105, 110, 116, 40, 50, 49, 53, 44, 48, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 101, 117,
  114, 115, 32, 47, 32, 65, 117, 116, 104, 111, 114, 115, 32, 58, 32, 60,
  105, 62, 83, 97, 109, 106, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58,
  32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 49, 55, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 84, 114,
  97, 109, 101, 115, 95, 115, 97, 109, 106, 32, 58, 10, 86, 97, 108, 101,
  117, 114, 95, 65, 61, 36, 49, 10, 86, 97, 108, 101, 117, 114, 95, 66,
  61, 36, 50, 10, 100, 111, 116, 115, 98, 119, 95, 110, 98, 95, 115, 99,
  97, 108, 101, 115, 61, 36, 51, 10, 100, 111, 116, 115, 98, 119, 95, 114,
  101, 115, 111, 108, 117, 116, 105, 111, 110, 61, 36, 52, 10, 100, 111, 116,
  115, 98, 119, 95, 114, 97, 100, 105, 117, 115, 61, 36, 53, 10, 77, 117,
  108, 116, 105, 112, 108, 121, 61, 36, 54, 10, 97, 117, 116, 111, 105, 110,
  100, 101, 120, 95, 110, 98, 95, 99, 111, 108, 111, 114, 115, 61, 36, 55,
  10, 97, 117, 116, 111, 105, 110, 100, 101, 120, 95, 100, 105, 116, 104, 101,
  114, 105, 110, 103, 61, 36, 56, 10, 97, 117, 116, 111, 105, 110, 100, 101,
  120, 95, 109, 101, 116, 104, 111, 100, 61, 36, 57, 10, 98, 108, 101, 110,
  100, 61, 36, 49, 48, 10, 111, 112, 97, 99, 105, 116, 101, 61, 36, 49,
  49, 10, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 61,
  36, 49, 50, 10, 85, 116, 105, 108, 105, 115, 101, 114, 95, 110, 111, 114,
  109, 97, 108, 105, 122, 101, 61, 36, 49, 51, 10, 86, 97, 108, 101, 117,
  114, 95, 67, 61, 36, 49, 52, 10, 86, 97, 108, 101, 117, 114, 95, 68,
  61, 36, 49, 53, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 36, 86, 97, 108,
  101, 117, 114, 95, 65, 62, 36, 86, 97, 108, 101, 117, 114, 95, 66, 125,
  10, 45, 45, 99, 117, 116, 91, 45, 49, 93, 32, 36, 86, 97, 108, 101,
  117, 114, 95, 66, 44, 36, 86, 97, 108, 101, 117, 114, 95, 65, 10, 45,
  101, 108, 115, 101, 10, 45, 45, 99, 117, 116, 91, 45, 49, 93, 32, 36,
  86, 97, 108, 101, 117, 114, 95, 65, 44, 36, 86, 97, 108, 101, 117, 114,
  95, 66, 10, 45, 101, 110, 100, 105, 102, 10, 45, 100, 111, 116, 115, 98,
  119, 95, 97, 110, 99, 105, 101, 110, 91, 45, 49, 93, 32, 36, 100, 111,
  116, 115, 98, 119, 95, 110, 98, 95, 115, 99, 97, 108, 101, 115, 44, 36,
  100, 111, 116, 115, 98, 119, 95, 114, 101, 115, 111, 108, 117, 116, 105, 111,
  110, 44, 36, 100, 111, 116, 115, 98, 119, 95, 114, 97, 100, 105, 117, 115,
  10, 45, 109, 117, 108, 91, 45, 49, 93, 32, 36, 77, 117, 108, 116, 105,
  112, 108, 121, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  10, 45, 97, 117, 116, 111, 105, 110, 100, 101, 120, 91, 45, 50, 93, 32,
  36, 97, 117, 116, 111, 105, 110, 100, 101, 120, 95, 110, 98, 95, 99, 111,
  108, 111, 114, 115, 44, 36, 97, 117, 116, 111, 105, 110, 100, 101, 120, 95,
  100, 105, 116, 104, 101, 114, 105, 110, 103, 44, 36, 97, 117, 116, 111, 105,
  110, 100, 101, 120, 95, 109, 101, 116, 104, 111, 100, 10, 45, 103, 105, 109,
  112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 36,
  98, 108, 101, 110, 100, 44, 36, 111, 112, 97, 99, 105, 116, 101, 44, 36,
  82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 10, 45, 105,
  102, 32, 123, 36, 85, 116, 105, 108, 105, 115, 101, 114, 95, 110, 111, 114,
  109, 97, 108, 105, 122, 101, 61, 61, 49, 125, 10, 45, 105, 102, 32, 123,
  36, 86, 97, 108, 101, 117, 114, 95, 67, 62, 36, 86, 97, 108, 101, 117,
  114, 95, 68, 125, 10, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 91,
  45, 49, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 68, 44, 36, 86,
  97, 108, 101, 117, 114, 95, 67, 10, 45, 101, 108, 115, 101, 10, 45, 110,
  111, 114, 109, 97, 108, 105, 122, 101, 91, 45, 49, 93, 32, 36, 86, 97,
  108, 101, 117, 114, 95, 67, 44, 36, 86, 97, 108, 101, 117, 114, 95, 68,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109,
  112, 32, 95, 10, 35, 64, 103, 105, 109, 112, 32, 60, 105, 62, 70, 114,
  97, 109, 101, 115, 60, 47, 105, 62, 10, 35, 64, 103, 105, 109, 112, 32,
  67, 97, 100, 114, 101, 32, 105, 109, 97, 103, 101, 32, 48, 48, 49, 32,
  58, 32, 115, 97, 109, 106, 95, 67, 97, 100, 114, 101, 95, 73, 109, 97,
  103, 101, 95, 48, 48, 49, 44, 32, 115, 97, 109, 106, 95, 67, 97, 100,
  114, 101, 95, 73, 109, 97, 103, 101, 95, 48, 48, 49, 95, 112, 114, 101,
  118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110,
  100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115,
  109, 97, 108, 108, 62, 67, 97, 100, 114, 101, 60, 47, 115, 109, 97, 108,
  108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110, 32, 37,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 49, 48, 44, 49, 48, 48,
  44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  101, 110, 100, 117, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 78,
  111, 114, 109, 97, 108, 34, 44, 34, 77, 105, 114, 114, 111, 114, 32, 88,
  34, 44, 34, 77, 105, 114, 114, 111, 114, 32, 89, 34, 44, 34, 77, 105,
  114, 114, 111, 114, 32, 88, 89, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 70, 114, 97, 109, 101, 32, 99, 117, 98, 101, 32, 61, 32,
  98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110,
  100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115,
  109, 97, 108, 108, 62, 67, 111, 108, 111, 114, 115, 32, 47, 32, 67, 111,
  117, 108, 101, 117, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47,
  115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 111, 108, 111, 114, 115, 32, 47, 32, 99, 111, 117, 108, 101, 117,
  114, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 46, 53, 44, 48,
  46, 48, 53, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110,
  100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115,
  109, 97, 108, 108, 62, 68, 105, 115, 116, 111, 114, 115, 105, 111, 110, 115,
  60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 114, 101, 97,
  100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 108, 111, 117, 32,
  47, 32, 98, 108, 117, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  68, 101, 102, 111, 114, 109, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49,
  52, 47, 48, 49, 47, 50, 49, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 67, 97, 100, 114,
  101, 95, 73, 109, 97, 103, 101, 95, 48, 48, 49, 32, 58, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 80, 111, 117, 114, 99, 101,
  110, 116, 61, 36, 49, 10, 82, 101, 110, 100, 117, 61, 36, 50, 10, 70,
  114, 97, 109, 101, 67, 117, 98, 101, 61, 36, 51, 10, 67, 111, 108, 111,
  114, 115, 95, 67, 111, 117, 108, 101, 117, 114, 115, 61, 36, 52, 10, 118,
  97, 108, 101, 117, 114, 95, 115, 112, 114, 101, 97, 100, 61, 36, 53, 10,
  102, 108, 111, 117, 61, 36, 54, 10, 100, 101, 102, 111, 114, 109, 97, 116,
  105, 111, 110, 61, 36, 55, 10, 76, 97, 114, 103, 101, 117, 114, 95, 79,
  114, 105, 103, 105, 110, 101, 61, 123, 119, 125, 10, 72, 97, 117, 116, 101,
  117, 114, 95, 79, 114, 105, 103, 105, 110, 101, 61, 123, 104, 125, 10, 76,
  97, 114, 103, 101, 117, 114, 95, 70, 105, 110, 97, 108, 101, 61, 123, 50,
  42, 123, 114, 111, 117, 110, 100, 40, 123, 123, 119, 125, 47, 50, 48, 48,
  42, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 80, 111, 117, 114,
  99, 101, 110, 116, 125, 41, 125, 125, 10, 72, 97, 117, 116, 101, 117, 114,
  95, 70, 105, 110, 97, 108, 101, 61, 123, 50, 42, 123, 114, 111, 117, 110,
  100, 40, 123, 123, 104, 125, 47, 50, 48, 48, 42, 36, 68, 105, 109, 101,
  110, 115, 105, 111, 110, 95, 80, 111, 117, 114, 99, 101, 110, 116, 125, 41,
  125, 125, 10, 69, 120, 112, 95, 76, 61, 123, 123, 123, 36, 76, 97, 114,
  103, 101, 117, 114, 95, 70, 105, 110, 97, 108, 101, 125, 45, 36, 76, 97,
  114, 103, 101, 117, 114, 95, 79, 114, 105, 103, 105, 110, 101, 125, 47, 50,
  125, 10, 69, 120, 112, 95, 72, 61, 123, 123, 123, 36, 72, 97, 117, 116,
  101, 117, 114, 95, 70, 105, 110, 97, 108, 101, 125, 45, 36, 72, 97, 117,
  116, 101, 117, 114, 95, 79, 114, 105, 103, 105, 110, 101, 125, 47, 50, 125,
  10, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10, 45, 45, 103,
  105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45,
  49, 93, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 36,
  76, 97, 114, 103, 101, 117, 114, 95, 70, 105, 110, 97, 108, 101, 44, 36,
  72, 97, 117, 116, 101, 117, 114, 95, 70, 105, 110, 97, 108, 101, 44, 49,
  44, 51, 10, 45, 112, 111, 119, 91, 45, 49, 93, 32, 36, 67, 111, 108,
  111, 114, 115, 95, 67, 111, 117, 108, 101, 117, 114, 115, 10, 45, 110, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 98, 108, 117, 114, 91,
  45, 49, 93, 32, 36, 102, 108, 111, 117, 10, 45, 100, 101, 102, 111, 114,
  109, 91, 45, 49, 93, 32, 36, 100, 101, 102, 111, 114, 109, 97, 116, 105,
  111, 110, 10, 45, 115, 112, 114, 101, 97, 100, 91, 45, 49, 93, 32, 36,
  118, 97, 108, 101, 117, 114, 95, 115, 112, 114, 101, 97, 100, 10, 45, 105,
  102, 32, 123, 36, 82, 101, 110, 100, 117, 61, 61, 49, 125, 10, 45, 109,
  105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 120, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 82, 101, 110, 100, 117, 61, 61, 50, 125, 10, 45, 109,
  105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 121, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 82, 101, 110, 100, 117, 61, 61, 51, 125, 10, 45, 109,
  105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 120, 10, 45, 109, 105, 114,
  114, 111, 114, 91, 45, 49, 93, 32, 121, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 70, 114, 97, 109, 101, 67, 117, 98, 101,
  61, 61, 49, 125, 10, 45, 102, 114, 97, 109, 101, 95, 99, 117, 98, 101,
  91, 45, 49, 93, 32, 51, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 120, 112, 97, 110,
  100, 95, 120, 91, 45, 50, 93, 32, 36, 69, 120, 112, 95, 76, 44, 48,
  10, 45, 101, 120, 112, 97, 110, 100, 95, 121, 91, 45, 50, 93, 32, 36,
  69, 120, 112, 95, 72, 44, 48, 10, 45, 112, 111, 108, 121, 103, 111, 110,
  91, 45, 49, 93, 32, 52, 44, 36, 69, 120, 112, 95, 76, 44, 36, 69,
  120, 112, 95, 72, 44, 123, 36, 76, 97, 114, 103, 101, 117, 114, 95, 70,
  105, 110, 97, 108, 101, 45, 36, 69, 120, 112, 95, 76, 125, 44, 36, 69,
  120, 112, 95, 72, 44, 123, 36, 76, 97, 114, 103, 101, 117, 114, 95, 70,
  105, 110, 97, 108, 101, 45, 36, 69, 120, 112, 95, 76, 125, 44, 123, 36,
  72, 97, 117, 116, 101, 117, 114, 95, 70, 105, 110, 97, 108, 101, 45, 36,
  69, 120, 112, 95, 72, 125, 44, 36, 69, 120, 112, 95, 76, 44, 123, 36,
  72, 97, 117, 116, 101, 117, 114, 95, 70, 105, 110, 97, 108, 101, 45, 36,
  69, 120, 112, 95, 72, 125, 44, 49, 44, 48, 44, 48, 44, 48, 44, 48,
  10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44,
  45, 50, 93, 32, 48, 44, 49, 44, 48, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 115, 97, 109, 106, 95, 67, 97, 100, 114, 101,
  95, 73, 109, 97, 103, 101, 95, 48, 48, 49, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95,
  67, 97, 100, 114, 101, 95, 73, 109, 97, 103, 101, 95, 48, 48, 49, 32,
  36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 67,
  97, 100, 114, 101, 32, 105, 109, 97, 103, 101, 32, 48, 48, 50, 32, 58,
  32, 115, 97, 109, 106, 95, 67, 97, 100, 114, 101, 95, 73, 109, 97, 103,
  101, 95, 48, 48, 50, 44, 32, 115, 97, 109, 106, 95, 67, 97, 100, 114,
  101, 95, 73, 109, 97, 103, 101, 95, 48, 48, 50, 95, 112, 114, 101, 118,
  105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100,
  61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109,
  97, 108, 108, 62, 67, 97, 100, 114, 101, 60, 47, 115, 109, 97, 108, 108,
  62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110, 32, 37, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 49, 48, 44, 49, 48, 48, 44,
  50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 99,
  104, 97, 110, 116, 105, 108, 108, 111, 110, 32, 40, 97, 116, 32, 108, 105,
  110, 101, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34,
  72, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 86, 101, 114,
  116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 80, 111, 115, 105, 116, 105, 111, 110, 32, 101, 99, 104, 97, 110, 116,
  105, 108, 108, 111, 110, 32, 37, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 82, 111, 116, 97, 116, 105, 111, 110, 32, 101, 99, 104, 97,
  110, 116, 105, 108, 108, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 82, 101, 110, 100, 117, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 78, 111, 114, 109, 97, 108, 34, 44, 34, 77, 105, 114, 114, 111,
  114, 32, 88, 34, 44, 34, 77, 105, 114, 114, 111, 114, 32, 89, 34, 44,
  34, 77, 105, 114, 114, 111, 114, 32, 88, 89, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 70, 114, 97, 109, 101, 32, 99, 117, 98, 101,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114,
  111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34,
  62, 60, 115, 109, 97, 108, 108, 62, 67, 111, 108, 111, 114, 115, 32, 47,
  32, 67, 111, 117, 108, 101, 117, 114, 115, 60, 47, 115, 109, 97, 108, 108,
  62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 108, 111, 114, 115, 32, 47, 32, 99, 111, 117,
  108, 101, 117, 114, 115, 32, 40, 49, 41, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 44, 48, 46, 57, 44, 49, 46, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 101, 103, 97, 116, 105, 118, 101, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 66, 111, 111, 115, 116, 32, 61, 32, 98, 111, 111, 108, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110,
  32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97,
  110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 68,
  105, 115, 116, 111, 114, 115, 105, 111, 110, 115, 60, 47, 115, 109, 97, 108,
  108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 112, 114, 101, 97, 100, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 70, 108, 111, 117, 32, 47, 32, 98, 108, 117, 114,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 53, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 102, 111, 114, 109,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 53, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32,
  102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110,
  103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 76, 105,
  103, 110, 101, 32, 67, 111, 110, 116, 111, 117, 114, 60, 47, 115, 109, 97,
  108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 69, 112, 97, 105, 115, 115, 101, 117, 114, 32,
  47, 32, 116, 104, 105, 99, 107, 110, 101, 115, 115, 32, 112, 105, 120, 101,
  108, 115, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 52, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114,
  32, 47, 32, 99, 111, 108, 111, 114, 32, 108, 105, 103, 110, 101, 32, 61,
  32, 99, 111, 108, 111, 114, 40, 48, 44, 48, 44, 48, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97,
  109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47,
  50, 49, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 115, 97, 109, 106, 95, 67, 97, 100, 114, 101, 95, 73, 109, 97,
  103, 101, 95, 48, 48, 50, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 68, 105, 109, 101, 110,
  115, 105, 111, 110, 95, 80, 111, 117, 114, 99, 101, 110, 116, 61, 36, 49,
  10, 69, 99, 104, 97, 110, 116, 105, 108, 108, 111, 110, 61, 36, 50, 10,
  80, 111, 115, 105, 116, 105, 111, 110, 95, 69, 99, 104, 97, 110, 116, 105,
  108, 108, 111, 110, 61, 36, 51, 10, 82, 111, 116, 97, 116, 105, 111, 110,
  95, 69, 99, 104, 97, 110, 116, 105, 108, 108, 111, 110, 61, 36, 52, 10,
  82, 101, 110, 100, 117, 61, 36, 53, 10, 70, 114, 97, 109, 101, 67, 117,
  98, 101, 61, 36, 54, 10, 67, 111, 108, 111, 114, 115, 95, 67, 111, 117,
  108, 101, 117, 114, 115, 61, 36, 55, 10, 78, 101, 103, 97, 116, 105, 118,
  101, 95, 67, 111, 108, 111, 114, 115, 61, 36, 56, 10, 66, 111, 111, 115,
  116, 61, 36, 57, 10, 118, 97, 108, 101, 117, 114, 95, 115, 112, 114, 101,
  97, 100, 61, 36, 49, 48, 10, 102, 108, 111, 117, 61, 36, 49, 49, 10,
  100, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 61, 36, 49, 50, 10,
  69, 112, 97, 105, 115, 115, 101, 117, 114, 95, 76, 105, 103, 110, 101, 95,
  67, 111, 110, 116, 111, 117, 114, 61, 36, 49, 51, 10, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 76, 105, 103, 110, 101, 61, 36, 49, 52, 10,
  86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 76, 105, 103, 110, 101, 61,
  36, 49, 53, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 76, 105,
  103, 110, 101, 61, 36, 49, 54, 10, 65, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 76, 105, 103, 110, 101, 61, 36, 49, 55, 10, 76, 97, 114, 103,
  101, 117, 114, 95, 79, 114, 105, 103, 105, 110, 101, 61, 123, 119, 125, 10,
  72, 97, 117, 116, 101, 117, 114, 95, 79, 114, 105, 103, 105, 110, 101, 61,
  123, 104, 125, 10, 76, 97, 114, 103, 101, 117, 114, 95, 70, 105, 110, 97,
  108, 101, 61, 123, 50, 42, 123, 114, 111, 117, 110, 100, 40, 123, 123, 119,
  125, 47, 50, 48, 48, 42, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110,
  95, 80, 111, 117, 114, 99, 101, 110, 116, 125, 41, 125, 125, 10, 72, 97,
  117, 116, 101, 117, 114, 95, 70, 105, 110, 97, 108, 101, 61, 123, 50, 42,
  123, 114, 111, 117, 110, 100, 40, 123, 123, 104, 125, 47, 50, 48, 48, 42,
  36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 80, 111, 117, 114, 99,
  101, 110, 116, 125, 41, 125, 125, 10, 69, 120, 112, 95, 76, 61, 123, 123,
  123, 36, 76, 97, 114, 103, 101, 117, 114, 95, 70, 105, 110, 97, 108, 101,
  125, 45, 36, 76, 97, 114, 103, 101, 117, 114, 95, 79, 114, 105, 103, 105,
  110, 101, 125, 47, 50, 125, 10, 69, 120, 112, 95, 72, 61, 123, 123, 123,
  36, 72, 97, 117, 116, 101, 117, 114, 95, 70, 105, 110, 97, 108, 101, 125,
  45, 36, 72, 97, 117, 116, 101, 117, 114, 95, 79, 114, 105, 103, 105, 110,
  101, 125, 47, 50, 125, 10, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49,
  93, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104,
  105, 110, 103, 91, 45, 49, 93, 10, 45, 112, 111, 119, 91, 45, 49, 93,
  32, 36, 67, 111, 108, 111, 114, 115, 95, 67, 111, 117, 108, 101, 117, 114,
  115, 10, 45, 105, 102, 32, 123, 36, 66, 111, 111, 115, 116, 61, 61, 49,
  125, 10, 45, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97, 108, 105, 122,
  101, 95, 108, 111, 99, 97, 108, 91, 45, 49, 93, 32, 50, 44, 54, 44,
  53, 44, 50, 48, 44, 49, 44, 51, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 78, 101, 103, 97, 116, 105, 118, 101, 95, 67,
  111, 108, 111, 114, 115, 61, 61, 49, 125, 10, 45, 110, 101, 103, 97, 116,
  105, 118, 101, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 69, 99, 104, 97, 110, 116, 105, 108, 108, 111, 110,
  61, 61, 48, 125, 10, 45, 97, 116, 95, 108, 105, 110, 101, 91, 45, 49,
  93, 32, 48, 44, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 69, 99,
  104, 97, 110, 116, 105, 108, 108, 111, 110, 44, 48, 44, 49, 48, 48, 37,
  44, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 69, 99, 104, 97, 110,
  116, 105, 108, 108, 111, 110, 44, 48, 10, 45, 101, 108, 115, 101, 10, 45,
  97, 116, 95, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 80, 111, 115,
  105, 116, 105, 111, 110, 95, 69, 99, 104, 97, 110, 116, 105, 108, 108, 111,
  110, 44, 48, 44, 48, 44, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95,
  69, 99, 104, 97, 110, 116, 105, 108, 108, 111, 110, 44, 49, 48, 48, 37,
  44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 111, 116, 97, 116,
  101, 91, 45, 49, 93, 32, 36, 82, 111, 116, 97, 116, 105, 111, 110, 95,
  69, 99, 104, 97, 110, 116, 105, 108, 108, 111, 110, 44, 50, 44, 50, 10,
  45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 36, 76, 97, 114,
  103, 101, 117, 114, 95, 70, 105, 110, 97, 108, 101, 44, 36, 72, 97, 117,
  116, 101, 117, 114, 95, 70, 105, 110, 97, 108, 101, 44, 49, 44, 51, 10,
  45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 102, 108, 111, 117, 10,
  45, 100, 101, 102, 111, 114, 109, 91, 45, 49, 93, 32, 36, 100, 101, 102,
  111, 114, 109, 97, 116, 105, 111, 110, 10, 45, 115, 112, 114, 101, 97, 100,
  91, 45, 49, 93, 32, 36, 118, 97, 108, 101, 117, 114, 95, 115, 112, 114,
  101, 97, 100, 10, 45, 105, 102, 32, 123, 36, 82, 101, 110, 100, 117, 61,
  61, 49, 125, 10, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32,
  120, 10, 45, 101, 108, 105, 102, 32, 123, 36, 82, 101, 110, 100, 117, 61,
  61, 50, 125, 10, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32,
  121, 10, 45, 101, 108, 105, 102, 32, 123, 36, 82, 101, 110, 100, 117, 61,
  61, 51, 125, 10, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32,
  120, 10, 45, 109, 105, 114, 114, 111, 114, 91, 45, 49, 93, 32, 121, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 70, 114, 97,
  109, 101, 67, 117, 98, 101, 61, 61, 49, 125, 10, 45, 102, 114, 97, 109,
  101, 95, 99, 117, 98, 101, 91, 45, 49, 93, 32, 51, 44, 48, 44, 48,
  44, 48, 44, 48, 44, 48, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 69, 112, 97, 105, 115, 115, 101, 117, 114, 95,
  76, 105, 103, 110, 101, 95, 67, 111, 110, 116, 111, 117, 114, 62, 48, 125,
  10, 36, 76, 97, 114, 103, 101, 117, 114, 95, 70, 105, 110, 97, 108, 101,
  44, 36, 72, 97, 117, 116, 101, 117, 114, 95, 70, 105, 110, 97, 108, 101,
  44, 49, 44, 52, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114,
  91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 10, 45, 112, 111,
  108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 52, 44, 123, 36, 69, 120,
  112, 95, 76, 45, 36, 69, 112, 97, 105, 115, 115, 101, 117, 114, 95, 76,
  105, 103, 110, 101, 95, 67, 111, 110, 116, 111, 117, 114, 125, 44, 123, 36,
  69, 120, 112, 95, 72, 45, 36, 69, 112, 97, 105, 115, 115, 101, 117, 114,
  95, 76, 105, 103, 110, 101, 95, 67, 111, 110, 116, 111, 117, 114, 125, 44,
  123, 36, 76, 97, 114, 103, 101, 117, 114, 95, 70, 105, 110, 97, 108, 101,
  45, 36, 69, 120, 112, 95, 76, 43, 36, 69, 112, 97, 105, 115, 115, 101,
  117, 114, 95, 76, 105, 103, 110, 101, 95, 67, 111, 110, 116, 111, 117, 114,
  125, 44, 123, 36, 69, 120, 112, 95, 72, 45, 36, 69, 112, 97, 105, 115,
  115, 101, 117, 114, 95, 76, 105, 103, 110, 101, 95, 67, 111, 110, 116, 111,
  117, 114, 125, 44, 123, 36, 76, 97, 114, 103, 101, 117, 114, 95, 70, 105,
  110, 97, 108, 101, 45, 36, 69, 120, 112, 95, 76, 43, 36, 69, 112, 97,
  105, 115, 115, 101, 117, 114, 95, 76, 105, 103, 110, 101, 95, 67, 111, 110,
  116, 111, 117, 114, 125, 44, 123, 36, 72, 97, 117, 116, 101, 117, 114, 95,
  70, 105, 110, 97, 108, 101, 45, 36, 69, 120, 112, 95, 72, 43, 36, 69,
  112, 97, 105, 115, 115, 101, 117, 114, 95, 76, 105, 103, 110, 101, 95, 67,
  111, 110, 116, 111, 117, 114, 125, 44, 123, 36, 69, 120, 112, 95, 76, 45,
  36, 69, 112, 97, 105, 115, 115, 101, 117, 114, 95, 76, 105, 103, 110, 101,
  95, 67, 111, 110, 116, 111, 117, 114, 125, 44, 123, 36, 72, 97, 117, 116,
  101, 117, 114, 95, 70, 105, 110, 97, 108, 101, 45, 36, 69, 120, 112, 95,
  72, 43, 36, 69, 112, 97, 105, 115, 115, 101, 117, 114, 95, 76, 105, 103,
  110, 101, 95, 67, 111, 110, 116, 111, 117, 114, 125, 44, 49, 44, 36, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 76, 105, 103, 110, 101, 44, 36,
  86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 76, 105, 103, 110, 101, 44,
  36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 76, 105, 103, 110, 101,
  44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 76, 105, 103, 110,
  101, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 97, 108, 112, 104, 97,
  91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 120, 112, 97, 110, 100, 95, 120, 91, 45, 50, 93, 32, 36, 69, 120,
  112, 95, 76, 44, 48, 10, 45, 101, 120, 112, 97, 110, 100, 95, 121, 91,
  45, 50, 93, 32, 36, 69, 120, 112, 95, 72, 44, 48, 10, 45, 112, 111,
  108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 52, 44, 36, 69, 120, 112,
  95, 76, 44, 36, 69, 120, 112, 95, 72, 44, 123, 36, 76, 97, 114, 103,
  101, 117, 114, 95, 70, 105, 110, 97, 108, 101, 45, 36, 69, 120, 112, 95,
  76, 125, 44, 36, 69, 120, 112, 95, 72, 44, 123, 36, 76, 97, 114, 103,
  101, 117, 114, 95, 70, 105, 110, 97, 108, 101, 45, 36, 69, 120, 112, 95,
  76, 125, 44, 123, 36, 72, 97, 117, 116, 101, 117, 114, 95, 70, 105, 110,
  97, 108, 101, 45, 36, 69, 120, 112, 95, 72, 125, 44, 36, 69, 120, 112,
  95, 76, 44, 123, 36, 72, 97, 117, 116, 101, 117, 114, 95, 70, 105, 110,
  97, 108, 101, 45, 36, 69, 120, 112, 95, 72, 125, 44, 49, 44, 48, 44,
  48, 44, 48, 44, 48, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110,
  100, 91, 45, 49, 44, 45, 50, 93, 32, 48, 44, 49, 44, 48, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115, 97, 109, 106, 95,
  67, 97, 100, 114, 101, 95, 73, 109, 97, 103, 101, 95, 48, 48, 50, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  115, 97, 109, 106, 95, 67, 97, 100, 114, 101, 95, 73, 109, 97, 103, 101,
  95, 48, 48, 50, 32, 36, 42, 34, 44, 36, 45, 49, 10, 115, 97, 109,
  106, 95, 114, 105, 101, 110, 95, 108, 97, 121, 101, 114, 115, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103,
  91, 45, 49, 93, 10, 115, 97, 109, 106, 95, 114, 105, 101, 110, 95, 108,
  105, 103, 104, 116, 115, 95, 97, 110, 100, 95, 115, 104, 97, 100, 111, 119,
  115, 32, 58, 10, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116,
  104, 105, 110, 103, 91, 45, 49, 93, 10, 35, 64, 103, 105, 109, 112, 32,
  68, 101, 115, 32, 108, 105, 103, 110, 101, 115, 32, 48, 48, 49, 32, 58,
  32, 115, 97, 109, 106, 95, 68, 101, 115, 95, 76, 105, 103, 110, 101, 115,
  95, 48, 48, 49, 44, 32, 115, 97, 109, 106, 95, 68, 101, 115, 95, 76,
  105, 103, 110, 101, 115, 95, 48, 48, 49, 95, 112, 114, 101, 118, 105, 101,
  119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34,
  111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108,
  108, 62, 80, 97, 114, 97, 109, 101, 116, 114, 101, 115, 32, 100, 101, 115,
  32, 108, 105, 103, 110, 101, 115, 60, 47, 115, 109, 97, 108, 108, 62, 60,
  47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 109, 98, 114, 101, 32, 108, 105, 103, 110, 101, 115, 32,
  61, 32, 105, 110, 116, 40, 50, 53, 54, 44, 49, 44, 52, 48, 57, 54,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 110, 100, 111,
  109, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 71, 114, 105, 115,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 47, 32, 99, 111,
  108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 49, 57, 50, 44,
  49, 50, 56, 44, 54, 52, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 121, 109, 101, 116, 114, 105, 101, 32, 61, 32,
  98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 69, 102, 102, 101, 116, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  48, 44, 34, 49, 34, 44, 34, 50, 34, 44, 34, 51, 34, 44, 34, 52,
  34, 44, 34, 53, 34, 44, 34, 54, 34, 44, 34, 55, 34, 44, 34, 56,
  34, 44, 34, 57, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100,
  61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109,
  97, 108, 108, 62, 68, 105, 115, 116, 111, 114, 115, 105, 111, 110, 115, 60,
  47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 114, 101, 97, 100,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 108, 111, 117, 32, 47,
  32, 98, 108, 117, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68,
  101, 102, 111, 114, 109, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61,
  34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97,
  108, 108, 62, 66, 108, 101, 110, 100, 60, 47, 115, 109, 97, 108, 108, 62,
  60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 77, 101, 108, 97, 110, 103, 101, 32, 47, 32, 98, 108, 101,
  110, 100, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 83,
  97, 110, 115, 32, 47, 32, 87, 105, 116, 104, 111, 117, 116, 34, 44, 34,
  79, 117, 105, 32, 47, 32, 89, 101, 115, 34, 44, 34, 83, 97, 110, 115,
  32, 70, 111, 110, 100, 32, 47, 32, 87, 105, 116, 104, 111, 117, 116, 32,
  66, 97, 99, 107, 103, 114, 111, 117, 110, 100, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 48, 44, 34, 65, 100, 100, 34, 44, 34, 65, 108, 112,
  104, 97, 34, 44, 34, 65, 110, 100, 34, 44, 34, 65, 118, 101, 114, 97,
  103, 101, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 66, 117, 114, 110,
  34, 44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 68, 105, 102, 102,
  101, 114, 101, 110, 99, 101, 34, 44, 34, 68, 105, 118, 105, 100, 101, 34,
  44, 34, 68, 111, 100, 103, 101, 34, 44, 34, 69, 120, 99, 108, 117, 115,
  105, 111, 110, 34, 44, 34, 70, 114, 101, 101, 122, 101, 34, 44, 34, 71,
  114, 97, 105, 110, 32, 101, 120, 116, 114, 97, 99, 116, 34, 44, 34, 71,
  114, 97, 105, 110, 32, 109, 101, 114, 103, 101, 34, 44, 34, 71, 114, 101,
  101, 110, 34, 44, 34, 72, 97, 114, 100, 32, 108, 105, 103, 104, 116, 34,
  44, 34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44, 34, 72, 117, 101,
  34, 44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110,
  34, 44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44, 34, 76, 105, 103,
  104, 116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32,
  98, 117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 108, 105,
  103, 104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34,
  44, 34, 77, 117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 78, 101, 103,
  97, 116, 105, 111, 110, 34, 44, 34, 79, 114, 34, 44, 34, 79, 118, 101,
  114, 108, 97, 121, 34, 44, 34, 80, 105, 110, 32, 108, 105, 103, 104, 116,
  34, 44, 34, 82, 101, 100, 34, 44, 34, 82, 101, 102, 108, 101, 99, 116,
  34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34,
  83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34,
  83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101, 48, 34, 44,
  34, 83, 111, 102, 116, 32, 98, 117, 114, 110, 34, 44, 34, 83, 111, 102,
  116, 32, 100, 111, 100, 103, 101, 34, 44, 34, 83, 111, 102, 116, 32, 108,
  105, 103, 104, 116, 34, 44, 34, 83, 99, 114, 101, 101, 110, 34, 44, 34,
  83, 116, 97, 109, 112, 34, 44, 34, 83, 117, 98, 116, 114, 97, 99, 116,
  34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 86, 105, 118, 105, 100,
  32, 108, 105, 103, 104, 116, 34, 44, 34, 88, 111, 114, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108,
  97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97, 109, 106,
  32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 48, 54,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  115, 97, 109, 106, 95, 68, 101, 115, 95, 76, 105, 103, 110, 101, 115, 95,
  48, 48, 49, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 78, 111, 109, 98, 114, 101, 95, 76,
  105, 103, 110, 101, 115, 61, 36, 49, 10, 82, 97, 110, 100, 111, 109, 95,
  67, 111, 108, 111, 114, 115, 61, 36, 50, 10, 71, 114, 105, 115, 61, 36,
  51, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 52, 10, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 53, 10, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 61, 36, 54, 10, 65, 95, 67, 111, 117, 108, 101,
  117, 114, 61, 36, 55, 10, 83, 121, 109, 101, 116, 114, 105, 101, 61, 36,
  56, 10, 69, 102, 102, 101, 116, 61, 36, 57, 10, 118, 97, 108, 101, 117,
  114, 95, 115, 112, 114, 101, 97, 100, 61, 36, 49, 48, 10, 102, 108, 111,
  117, 61, 36, 49, 49, 10, 100, 101, 102, 111, 114, 109, 97, 116, 105, 111,
  110, 61, 36, 49, 50, 10, 77, 101, 108, 97, 110, 103, 101, 61, 36, 49,
  51, 10, 77, 111, 100, 101, 95, 77, 101, 108, 97, 110, 103, 101, 61, 36,
  49, 52, 10, 79, 112, 97, 99, 105, 116, 121, 95, 77, 101, 108, 97, 110,
  103, 101, 61, 36, 49, 53, 10, 82, 101, 118, 101, 114, 116, 95, 108, 97,
  121, 101, 114, 115, 95, 77, 101, 108, 97, 110, 103, 101, 61, 36, 49, 54,
  10, 73, 110, 99, 95, 76, 61, 123, 123, 119, 125, 47, 123, 36, 78, 111,
  109, 98, 114, 101, 95, 76, 105, 103, 110, 101, 115, 43, 49, 125, 125, 10,
  73, 110, 99, 95, 72, 61, 123, 123, 104, 125, 47, 123, 36, 78, 111, 109,
  98, 114, 101, 95, 76, 105, 103, 110, 101, 115, 43, 49, 125, 125, 10, 79,
  114, 105, 103, 105, 110, 101, 95, 76, 61, 48, 10, 79, 114, 105, 103, 105,
  110, 101, 95, 72, 61, 48, 10, 45, 105, 102, 32, 123, 36, 77, 101, 108,
  97, 110, 103, 101, 61, 61, 48, 125, 10, 123, 119, 125, 44, 123, 104, 125,
  44, 49, 44, 52, 10, 45, 101, 108, 105, 102, 32, 123, 36, 77, 101, 108,
  97, 110, 103, 101, 61, 61, 49, 125, 10, 45, 116, 111, 95, 114, 103, 98,
  97, 91, 45, 49, 93, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95,
  110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 77, 101, 108, 97, 110, 103, 101, 61, 61, 50, 125, 10,
  45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 10, 45, 102, 105,
  108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48,
  44, 48, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 36, 78, 111, 109, 98, 114, 101, 95, 76, 105, 103, 110,
  101, 115, 10, 79, 114, 105, 103, 105, 110, 101, 95, 76, 61, 123, 36, 79,
  114, 105, 103, 105, 110, 101, 95, 76, 43, 36, 73, 110, 99, 95, 76, 125,
  10, 79, 114, 105, 103, 105, 110, 101, 95, 72, 61, 123, 36, 79, 114, 105,
  103, 105, 110, 101, 95, 72, 43, 36, 73, 110, 99, 95, 72, 125, 10, 45,
  105, 102, 32, 123, 36, 82, 97, 110, 100, 111, 109, 95, 67, 111, 108, 111,
  114, 115, 61, 61, 49, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114,
  61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41,
  41, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114, 111,
  117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40,
  63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 71, 114, 105, 115, 61, 61, 49, 125,
  10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 123, 36, 82, 95,
  67, 111, 117, 108, 101, 117, 114, 43, 36, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 43, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 125, 47, 51,
  125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114,
  61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 69, 102, 102, 101, 116, 61, 61,
  48, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 79, 114,
  105, 103, 105, 110, 101, 95, 76, 44, 48, 44, 123, 119, 125, 44, 36, 79,
  114, 105, 103, 105, 110, 101, 95, 72, 44, 49, 44, 36, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 65, 95, 67,
  111, 117, 108, 101, 117, 114, 10, 45, 101, 108, 105, 102, 32, 123, 36, 69,
  102, 102, 101, 116, 61, 61, 49, 125, 10, 45, 108, 105, 110, 101, 91, 45,
  49, 93, 32, 36, 79, 114, 105, 103, 105, 110, 101, 95, 76, 44, 48, 44,
  123, 119, 125, 44, 36, 79, 114, 105, 103, 105, 110, 101, 95, 72, 44, 49,
  44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 86, 95, 67,
  111, 117, 108, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117,
  114, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 69, 102, 102, 101, 116, 61, 61, 51, 125, 10, 45,
  108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 79, 114, 105, 103, 105, 110,
  101, 95, 76, 44, 48, 44, 123, 119, 125, 44, 36, 79, 114, 105, 103, 105,
  110, 101, 95, 72, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 66, 95,
  67, 111, 117, 108, 101, 117, 114, 44, 36, 65, 95, 67, 111, 117, 108, 101,
  117, 114, 10, 45, 101, 108, 105, 102, 32, 123, 36, 69, 102, 102, 101, 116,
  61, 61, 53, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36,
  79, 114, 105, 103, 105, 110, 101, 95, 76, 44, 48, 44, 123, 119, 125, 44,
  36, 79, 114, 105, 103, 105, 110, 101, 95, 72, 44, 49, 44, 36, 82, 95,
  67, 111, 117, 108, 101, 117, 114, 44, 36, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 65,
  95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 82, 97, 110, 100, 111, 109, 95, 67, 111, 108,
  111, 114, 115, 61, 61, 49, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53,
  41, 41, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114,
  111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 71, 114, 105, 115, 61, 61, 49,
  125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 123, 36, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 43, 36, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 43, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 125, 47,
  51, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 82, 95,
  67, 111, 117, 108, 101, 117, 114, 10, 66, 95, 67, 111, 117, 108, 101, 117,
  114, 61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 69, 102, 102, 101, 116, 61,
  61, 48, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 123, 119,
  125, 44, 36, 79, 114, 105, 103, 105, 110, 101, 95, 72, 44, 123, 123, 119,
  125, 45, 36, 79, 114, 105, 103, 105, 110, 101, 95, 76, 125, 44, 123, 104,
  125, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36,
  86, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117,
  108, 101, 117, 114, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 69, 102, 102, 101, 116, 61, 61, 50,
  125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 123, 119, 125, 44,
  36, 79, 114, 105, 103, 105, 110, 101, 95, 72, 44, 123, 123, 119, 125, 45,
  36, 79, 114, 105, 103, 105, 110, 101, 95, 76, 125, 44, 123, 104, 125, 44,
  49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 69, 102, 102, 101, 116, 61, 61, 51, 125, 10,
  45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 123, 119, 125, 44, 36, 79,
  114, 105, 103, 105, 110, 101, 95, 72, 44, 123, 123, 119, 125, 45, 36, 79,
  114, 105, 103, 105, 110, 101, 95, 76, 125, 44, 123, 104, 125, 44, 49, 44,
  36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 86, 95, 67, 111,
  117, 108, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114,
  44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 69, 102, 102, 101, 116, 61, 61, 54, 125, 10, 45, 108,
  105, 110, 101, 91, 45, 49, 93, 32, 123, 119, 125, 44, 36, 79, 114, 105,
  103, 105, 110, 101, 95, 72, 44, 123, 123, 119, 125, 45, 36, 79, 114, 105,
  103, 105, 110, 101, 95, 76, 125, 44, 123, 104, 125, 44, 49, 44, 36, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36,
  65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 82, 97, 110, 100, 111, 109, 95, 67, 111,
  108, 111, 114, 115, 61, 61, 49, 125, 10, 82, 95, 67, 111, 117, 108, 101,
  117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53,
  53, 41, 41, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123,
  114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125,
  10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110,
  100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 71, 114, 105, 115, 61, 61,
  49, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 123, 36,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 43, 36, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 43, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 125,
  47, 51, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 10, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 69, 102, 102, 101, 116,
  61, 61, 48, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 123,
  123, 119, 125, 45, 36, 79, 114, 105, 103, 105, 110, 101, 95, 76, 125, 44,
  123, 104, 125, 44, 48, 44, 123, 123, 104, 125, 45, 36, 79, 114, 105, 103,
  105, 110, 101, 95, 72, 125, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 65, 95, 67, 111, 117,
  108, 101, 117, 114, 10, 45, 101, 108, 105, 102, 32, 123, 36, 69, 102, 102,
  101, 116, 61, 61, 49, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93,
  32, 123, 123, 119, 125, 45, 36, 79, 114, 105, 103, 105, 110, 101, 95, 76,
  125, 44, 123, 104, 125, 44, 48, 44, 123, 123, 104, 125, 45, 36, 79, 114,
  105, 103, 105, 110, 101, 95, 72, 125, 44, 49, 44, 36, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 65, 95, 67,
  111, 117, 108, 101, 117, 114, 10, 45, 101, 108, 105, 102, 32, 123, 36, 69,
  102, 102, 101, 116, 61, 61, 52, 125, 10, 45, 108, 105, 110, 101, 91, 45,
  49, 93, 32, 123, 123, 119, 125, 45, 36, 79, 114, 105, 103, 105, 110, 101,
  95, 76, 125, 44, 123, 104, 125, 44, 48, 44, 123, 123, 104, 125, 45, 36,
  79, 114, 105, 103, 105, 110, 101, 95, 72, 125, 44, 49, 44, 36, 82, 95,
  67, 111, 117, 108, 101, 117, 114, 44, 36, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 65,
  95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 69, 102, 102, 101, 116, 61, 61, 55, 125, 10, 45, 108, 105, 110, 101,
  91, 45, 49, 93, 32, 123, 123, 119, 125, 45, 36, 79, 114, 105, 103, 105,
  110, 101, 95, 76, 125, 44, 123, 104, 125, 44, 48, 44, 123, 123, 104, 125,
  45, 36, 79, 114, 105, 103, 105, 110, 101, 95, 72, 125, 44, 49, 44, 36,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 44,
  36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 82, 97, 110, 100, 111, 109, 95, 67,
  111, 108, 111, 114, 115, 61, 61, 49, 125, 10, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50,
  53, 53, 41, 41, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 61,
  123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41,
  125, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114, 111, 117,
  110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 71, 114, 105, 115, 61,
  61, 49, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 123,
  36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 43, 36, 86, 95, 67, 111,
  117, 108, 101, 117, 114, 43, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114,
  125, 47, 51, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 10, 66, 95, 67, 111, 117, 108,
  101, 117, 114, 61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 69, 102, 102, 101,
  116, 61, 61, 48, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32,
  48, 44, 123, 123, 104, 125, 45, 36, 79, 114, 105, 103, 105, 110, 101, 95,
  72, 125, 44, 36, 79, 114, 105, 103, 105, 110, 101, 95, 76, 44, 48, 44,
  49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 69, 102, 102, 101, 116, 61, 61, 50, 125, 10,
  45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 48, 44, 123, 123, 104, 125,
  45, 36, 79, 114, 105, 103, 105, 110, 101, 95, 72, 125, 44, 36, 79, 114,
  105, 103, 105, 110, 101, 95, 76, 44, 48, 44, 49, 44, 36, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117,
  114, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 65, 95,
  67, 111, 117, 108, 101, 117, 114, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  69, 102, 102, 101, 116, 61, 61, 52, 125, 10, 45, 108, 105, 110, 101, 91,
  45, 49, 93, 32, 48, 44, 123, 123, 104, 125, 45, 36, 79, 114, 105, 103,
  105, 110, 101, 95, 72, 125, 44, 36, 79, 114, 105, 103, 105, 110, 101, 95,
  76, 44, 48, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114,
  44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117,
  114, 10, 45, 101, 108, 105, 102, 32, 123, 36, 69, 102, 102, 101, 116, 61,
  61, 56, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 48, 44,
  123, 123, 104, 125, 45, 36, 79, 114, 105, 103, 105, 110, 101, 95, 72, 125,
  44, 36, 79, 114, 105, 103, 105, 110, 101, 95, 76, 44, 48, 44, 49, 44,
  36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 86, 95, 67, 111,
  117, 108, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114,
  44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 83,
  121, 109, 101, 116, 114, 105, 101, 61, 61, 49, 125, 10, 45, 109, 105, 114,
  114, 111, 114, 91, 45, 49, 93, 32, 120, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 115, 112, 114, 101, 97, 100, 91, 45, 49, 93, 32, 36, 118, 97,
  108, 101, 117, 114, 95, 115, 112, 114, 101, 97, 100, 10, 45, 98, 108, 117,
  114, 91, 45, 49, 93, 32, 36, 102, 108, 111, 117, 10, 45, 100, 101, 102,
  111, 114, 109, 91, 45, 49, 93, 32, 36, 100, 101, 102, 111, 114, 109, 97,
  116, 105, 111, 110, 10, 45, 105, 102, 32, 123, 36, 77, 101, 108, 97, 110,
  103, 101, 61, 61, 48, 125, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  97, 108, 112, 104, 97, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 77, 101, 108, 97, 110, 103, 101, 61, 61, 49, 125,
  10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44,
  45, 50, 93, 32, 32, 36, 77, 111, 100, 101, 95, 77, 101, 108, 97, 110,
  103, 101, 44, 36, 79, 112, 97, 99, 105, 116, 121, 95, 77, 101, 108, 97,
  110, 103, 101, 44, 36, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101,
  114, 115, 95, 77, 101, 108, 97, 110, 103, 101, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115, 97,
  109, 106, 95, 68, 101, 115, 95, 76, 105, 103, 110, 101, 115, 95, 48, 48,
  49, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 115, 97, 109, 106, 95, 68, 101, 115, 95, 76, 105, 103, 110, 101,
  115, 95, 48, 48, 49, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64,
  103, 105, 109, 112, 32, 68, 101, 115, 32, 108, 105, 103, 110, 101, 115, 32,
  48, 48, 50, 32, 58, 32, 115, 97, 109, 106, 95, 68, 101, 115, 95, 76,
  105, 103, 110, 101, 115, 95, 48, 48, 50, 44, 32, 115, 97, 109, 106, 95,
  68, 101, 115, 95, 76, 105, 103, 110, 101, 115, 95, 48, 48, 50, 95, 112,
  114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111,
  117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62,
  60, 115, 109, 97, 108, 108, 62, 80, 97, 114, 97, 109, 101, 116, 114, 101,
  115, 32, 100, 101, 115, 32, 108, 105, 103, 110, 101, 115, 60, 47, 115, 109,
  97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 109, 98, 114, 101, 32, 108, 105,
  103, 110, 101, 115, 32, 61, 32, 105, 110, 116, 40, 50, 53, 54, 44, 49,
  44, 52, 48, 57, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  82, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32,
  98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 71, 114, 105, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114,
  32, 47, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114,
  40, 49, 57, 50, 44, 49, 50, 56, 44, 54, 52, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 121, 109, 101, 116, 114,
  105, 101, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 69, 102, 102, 101, 116, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 48, 44, 34, 49, 34, 44, 34, 50, 34, 44, 34,
  51, 34, 44, 34, 52, 34, 44, 34, 53, 34, 44, 34, 54, 34, 44, 34,
  55, 34, 44, 34, 56, 34, 44, 34, 57, 34, 44, 34, 49, 48, 34, 44,
  34, 49, 49, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69,
  116, 101, 110, 100, 117, 101, 32, 47, 32, 101, 120, 116, 101, 110, 116, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 84, 111, 117, 116,
  101, 32, 47, 32, 65, 108, 108, 32, 68, 105, 109, 101, 110, 115, 105, 111,
  110, 34, 44, 34, 49, 47, 50, 32, 72, 97, 108, 102, 32, 68, 105, 109,
  101, 110, 115, 105, 111, 110, 34, 44, 34, 49, 47, 51, 32, 68, 105, 109,
  101, 110, 115, 105, 111, 110, 34, 44, 34, 49, 47, 52, 32, 68, 105, 109,
  101, 110, 115, 105, 111, 110, 34, 44, 34, 49, 47, 53, 32, 68, 105, 109,
  101, 110, 115, 105, 111, 110, 34, 44, 34, 49, 47, 54, 32, 68, 105, 109,
  101, 110, 115, 105, 111, 110, 34, 44, 34, 49, 47, 55, 32, 68, 105, 109,
  101, 110, 115, 105, 111, 110, 34, 44, 34, 49, 47, 56, 32, 68, 105, 109,
  101, 110, 115, 105, 111, 110, 34, 44, 34, 49, 47, 57, 32, 68, 105, 109,
  101, 110, 115, 105, 111, 110, 34, 44, 34, 49, 47, 49, 48, 32, 68, 105,
  109, 101, 110, 115, 105, 111, 110, 34, 32, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114,
  111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34,
  62, 60, 115, 109, 97, 108, 108, 62, 68, 105, 115, 116, 111, 114, 115, 105,
  111, 110, 115, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97,
  110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112,
  114, 101, 97, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 108,
  111, 117, 32, 47, 32, 98, 108, 117, 114, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 68, 101, 102, 111, 114, 109, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111,
  117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62,
  60, 115, 109, 97, 108, 108, 62, 66, 108, 101, 110, 100, 60, 47, 115, 109,
  97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 77, 101, 108, 97, 110, 103, 101, 32, 47,
  32, 98, 108, 101, 110, 100, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  48, 44, 34, 83, 97, 110, 115, 32, 47, 32, 87, 105, 116, 104, 111, 117,
  116, 34, 44, 34, 79, 117, 105, 32, 47, 32, 89, 101, 115, 34, 44, 34,
  83, 97, 110, 115, 32, 70, 111, 110, 100, 32, 47, 32, 87, 105, 116, 104,
  111, 117, 116, 32, 66, 97, 99, 107, 103, 114, 111, 117, 110, 100, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 100, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 65, 100, 100, 34, 44,
  34, 65, 108, 112, 104, 97, 34, 44, 34, 65, 110, 100, 34, 44, 34, 65,
  118, 101, 114, 97, 103, 101, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34,
  66, 117, 114, 110, 34, 44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34,
  68, 105, 102, 102, 101, 114, 101, 110, 99, 101, 34, 44, 34, 68, 105, 118,
  105, 100, 101, 34, 44, 34, 68, 111, 100, 103, 101, 34, 44, 34, 69, 120,
  99, 108, 117, 115, 105, 111, 110, 34, 44, 34, 70, 114, 101, 101, 122, 101,
  34, 44, 34, 71, 114, 97, 105, 110, 32, 101, 120, 116, 114, 97, 99, 116,
  34, 44, 34, 71, 114, 97, 105, 110, 32, 109, 101, 114, 103, 101, 34, 44,
  34, 71, 114, 101, 101, 110, 34, 44, 34, 72, 97, 114, 100, 32, 108, 105,
  103, 104, 116, 34, 44, 34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44,
  34, 72, 117, 101, 34, 44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97,
  116, 105, 111, 110, 34, 44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44,
  34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110,
  101, 97, 114, 32, 98, 117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97,
  114, 32, 108, 105, 103, 104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 77, 117, 108, 116, 105, 112, 108, 121, 34, 44,
  34, 78, 101, 103, 97, 116, 105, 111, 110, 34, 44, 34, 79, 114, 34, 44,
  34, 79, 118, 101, 114, 108, 97, 121, 34, 44, 34, 80, 105, 110, 32, 108,
  105, 103, 104, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 82, 101, 102,
  108, 101, 99, 116, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111,
  110, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103,
  101, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103,
  101, 48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117, 114, 110, 34, 44,
  34, 83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34, 44, 34, 83, 111,
  102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83, 99, 114, 101, 101,
  110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34, 83, 117, 98, 116,
  114, 97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 86,
  105, 118, 105, 100, 32, 108, 105, 103, 104, 116, 34, 44, 34, 88, 111, 114,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99,
  105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101,
  114, 116, 32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48,
  49, 47, 49, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 115, 97, 109, 106, 95, 68, 101, 115, 95, 76, 105, 103,
  110, 101, 115, 95, 48, 48, 50, 32, 58, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 78, 111, 109, 98,
  114, 101, 95, 76, 105, 103, 110, 101, 115, 61, 36, 49, 10, 82, 97, 110,
  100, 111, 109, 95, 67, 111, 108, 111, 114, 115, 61, 36, 50, 10, 71, 114,
  105, 115, 61, 36, 51, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61,
  36, 52, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 53, 10,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 54, 10, 65, 95, 67,
  111, 117, 108, 101, 117, 114, 61, 36, 55, 10, 83, 121, 109, 101, 116, 114,
  105, 101, 61, 36, 56, 10, 69, 102, 102, 101, 116, 61, 36, 57, 10, 69,
  116, 101, 110, 100, 117, 101, 61, 36, 49, 48, 10, 118, 97, 108, 101, 117,
  114, 95, 115, 112, 114, 101, 97, 100, 61, 36, 49, 49, 10, 102, 108, 111,
  117, 61, 36, 49, 50, 10, 100, 101, 102, 111, 114, 109, 97, 116, 105, 111,
  110, 61, 36, 49, 51, 10, 77, 101, 108, 97, 110, 103, 101, 61, 36, 49,
  52, 10, 77, 111, 100, 101, 95, 77, 101, 108, 97, 110, 103, 101, 61, 36,
  49, 53, 10, 79, 112, 97, 99, 105, 116, 121, 95, 77, 101, 108, 97, 110,
  103, 101, 61, 36, 49, 54, 10, 82, 101, 118, 101, 114, 116, 95, 108, 97,
  121, 101, 114, 115, 95, 77, 101, 108, 97, 110, 103, 101, 61, 36, 49, 55,
  10, 73, 110, 99, 95, 76, 61, 123, 123, 119, 125, 47, 123, 123, 36, 78,
  111, 109, 98, 114, 101, 95, 76, 105, 103, 110, 101, 115, 43, 49, 125, 42,
  123, 36, 69, 116, 101, 110, 100, 117, 101, 43, 49, 125, 125, 125, 10, 73,
  110, 99, 95, 72, 61, 123, 123, 104, 125, 47, 123, 123, 36, 78, 111, 109,
  98, 114, 101, 95, 76, 105, 103, 110, 101, 115, 43, 49, 125, 42, 123, 36,
  69, 116, 101, 110, 100, 117, 101, 43, 49, 125, 125, 125, 10, 79, 114, 105,
  103, 105, 110, 101, 95, 76, 61, 48, 10, 79, 114, 105, 103, 105, 110, 101,
  95, 72, 61, 48, 10, 45, 105, 102, 32, 123, 36, 77, 101, 108, 97, 110,
  103, 101, 61, 61, 48, 125, 10, 123, 119, 125, 44, 123, 104, 125, 44, 49,
  44, 52, 10, 45, 101, 108, 105, 102, 32, 123, 36, 77, 101, 108, 97, 110,
  103, 101, 61, 61, 49, 125, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91,
  45, 49, 93, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111,
  116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 77, 101, 108, 97, 110, 103, 101, 61, 61, 50, 125, 10, 45, 116,
  111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 10, 45, 102, 105, 108, 108,
  95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48,
  44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 36, 78, 111, 109, 98, 114, 101, 95, 76, 105, 103, 110, 101, 115,
  10, 79, 114, 105, 103, 105, 110, 101, 95, 76, 61, 123, 36, 79, 114, 105,
  103, 105, 110, 101, 95, 76, 43, 36, 73, 110, 99, 95, 76, 125, 10, 79,
  114, 105, 103, 105, 110, 101, 95, 72, 61, 123, 36, 79, 114, 105, 103, 105,
  110, 101, 95, 72, 43, 36, 73, 110, 99, 95, 72, 125, 10, 45, 105, 102,
  32, 123, 36, 82, 97, 110, 100, 111, 109, 95, 67, 111, 108, 111, 114, 115,
  61, 61, 49, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123,
  114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125,
  10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110,
  100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40,
  48, 44, 50, 53, 53, 41, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 71, 114, 105, 115, 61, 61, 49, 125, 10, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 123, 36, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 43, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  43, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 125, 47, 51, 125, 10,
  86, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 69, 102, 102, 101, 116, 61, 61, 48, 125,
  10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 79, 114, 105, 103,
  105, 110, 101, 95, 76, 44, 48, 44, 123, 119, 125, 44, 36, 79, 114, 105,
  103, 105, 110, 101, 95, 72, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 65, 95, 67, 111, 117,
  108, 101, 117, 114, 10, 45, 101, 108, 105, 102, 32, 123, 36, 69, 102, 102,
  101, 116, 61, 61, 49, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93,
  32, 36, 79, 114, 105, 103, 105, 110, 101, 95, 76, 44, 48, 44, 123, 119,
  125, 44, 36, 79, 114, 105, 103, 105, 110, 101, 95, 72, 44, 49, 44, 36,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 44,
  36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 69, 102, 102, 101, 116, 61, 61, 51, 125, 10, 45, 108, 105,
  110, 101, 91, 45, 49, 93, 32, 36, 79, 114, 105, 103, 105, 110, 101, 95,
  76, 44, 48, 44, 123, 119, 125, 44, 36, 79, 114, 105, 103, 105, 110, 101,
  95, 72, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 44,
  36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 69, 102, 102, 101, 116, 61, 61,
  53, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 79, 114,
  105, 103, 105, 110, 101, 95, 76, 44, 48, 44, 123, 119, 125, 44, 36, 79,
  114, 105, 103, 105, 110, 101, 95, 72, 44, 49, 44, 36, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 65, 95, 67,
  111, 117, 108, 101, 117, 114, 10, 45, 101, 108, 105, 102, 32, 123, 36, 69,
  102, 102, 101, 116, 61, 61, 57, 125, 10, 45, 108, 105, 110, 101, 91, 45,
  49, 93, 32, 36, 79, 114, 105, 103, 105, 110, 101, 95, 76, 44, 48, 44,
  123, 119, 125, 44, 36, 79, 114, 105, 103, 105, 110, 101, 95, 72, 44, 49,
  44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 86, 95, 67,
  111, 117, 108, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117,
  114, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 97, 110, 100, 111, 109,
  95, 67, 111, 108, 111, 114, 115, 61, 61, 49, 125, 10, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 50, 53, 53, 41, 41, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117,
  114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53,
  41, 41, 125, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114,
  111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 71, 114, 105,
  115, 61, 61, 49, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61,
  123, 123, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 43, 36, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 43, 36, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 125, 47, 51, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 10, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 69, 102,
  102, 101, 116, 61, 61, 48, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49,
  93, 32, 123, 119, 125, 44, 36, 79, 114, 105, 103, 105, 110, 101, 95, 72,
  44, 123, 123, 119, 125, 45, 36, 79, 114, 105, 103, 105, 110, 101, 95, 76,
  125, 44, 123, 104, 125, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101,
  117, 114, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 65, 95, 67, 111, 117, 108,
  101, 117, 114, 10, 45, 101, 108, 105, 102, 32, 123, 36, 69, 102, 102, 101,
  116, 61, 61, 50, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32,
  123, 119, 125, 44, 36, 79, 114, 105, 103, 105, 110, 101, 95, 72, 44, 123,
  123, 119, 125, 45, 36, 79, 114, 105, 103, 105, 110, 101, 95, 76, 125, 44,
  123, 104, 125, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114,
  44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117,
  114, 10, 45, 101, 108, 105, 102, 32, 123, 36, 69, 102, 102, 101, 116, 61,
  61, 51, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 123, 119,
  125, 44, 36, 79, 114, 105, 103, 105, 110, 101, 95, 72, 44, 123, 123, 119,
  125, 45, 36, 79, 114, 105, 103, 105, 110, 101, 95, 76, 125, 44, 123, 104,
  125, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36,
  86, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117,
  108, 101, 117, 114, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 69, 102, 102, 101, 116, 61, 61, 54,
  125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 123, 119, 125, 44,
  36, 79, 114, 105, 103, 105, 110, 101, 95, 72, 44, 123, 123, 119, 125, 45,
  36, 79, 114, 105, 103, 105, 110, 101, 95, 76, 125, 44, 123, 104, 125, 44,
  49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 69, 102, 102, 101, 116, 61, 61, 49, 48, 125,
  10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 123, 119, 125, 44, 36,
  79, 114, 105, 103, 105, 110, 101, 95, 72, 44, 123, 123, 119, 125, 45, 36,
  79, 114, 105, 103, 105, 110, 101, 95, 76, 125, 44, 123, 104, 125, 44, 49,
  44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 86, 95, 67,
  111, 117, 108, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117,
  114, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 97, 110, 100, 111, 109,
  95, 67, 111, 108, 111, 114, 115, 61, 61, 49, 125, 10, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 50, 53, 53, 41, 41, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117,
  114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53,
  41, 41, 125, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114,
  111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 71, 114, 105,
  115, 61, 61, 49, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61,
  123, 123, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 43, 36, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 43, 36, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 125, 47, 51, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 10, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 69, 102,
  102, 101, 116, 61, 61, 48, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49,
  93, 32, 123, 123, 119, 125, 45, 36, 79, 114, 105, 103, 105, 110, 101, 95,
  76, 125, 44, 123, 104, 125, 44, 48, 44, 123, 123, 104, 125, 45, 36, 79,
  114, 105, 103, 105, 110, 101, 95, 72, 125, 44, 49, 44, 36, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117,
  114, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 65, 95,
  67, 111, 117, 108, 101, 117, 114, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  69, 102, 102, 101, 116, 61, 61, 49, 125, 10, 45, 108, 105, 110, 101, 91,
  45, 49, 93, 32, 123, 123, 119, 125, 45, 36, 79, 114, 105, 103, 105, 110,
  101, 95, 76, 125, 44, 123, 104, 125, 44, 48, 44, 123, 123, 104, 125, 45,
  36, 79, 114, 105, 103, 105, 110, 101, 95, 72, 125, 44, 49, 44, 36, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36,
  65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 69, 102, 102, 101, 116, 61, 61, 52, 125, 10, 45, 108, 105, 110,
  101, 91, 45, 49, 93, 32, 123, 123, 119, 125, 45, 36, 79, 114, 105, 103,
  105, 110, 101, 95, 76, 125, 44, 123, 104, 125, 44, 48, 44, 123, 123, 104,
  125, 45, 36, 79, 114, 105, 103, 105, 110, 101, 95, 72, 125, 44, 49, 44,
  36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 86, 95, 67, 111,
  117, 108, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114,
  44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 69, 102, 102, 101, 116, 61, 61, 55, 125, 10, 45, 108,
  105, 110, 101, 91, 45, 49, 93, 32, 123, 123, 119, 125, 45, 36, 79, 114,
  105, 103, 105, 110, 101, 95, 76, 125, 44, 123, 104, 125, 44, 48, 44, 123,
  123, 104, 125, 45, 36, 79, 114, 105, 103, 105, 110, 101, 95, 72, 125, 44,
  49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 69, 102, 102, 101, 116, 61, 61, 49, 48, 125,
  10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 123, 123, 119, 125, 45,
  36, 79, 114, 105, 103, 105, 110, 101, 95, 76, 125, 44, 123, 104, 125, 44,
  48, 44, 123, 123, 104, 125, 45, 36, 79, 114, 105, 103, 105, 110, 101, 95,
  72, 125, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 44,
  36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 97,
  110, 100, 111, 109, 95, 67, 111, 108, 111, 114, 115, 61, 61, 49, 125, 10,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 86, 95, 67, 111,
  117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 50, 53, 53, 41, 41, 125, 10, 66, 95, 67, 111, 117, 108, 101, 117,
  114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53,
  41, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 71, 114, 105, 115, 61, 61, 49, 125, 10, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 61, 123, 123, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114,
  43, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 43, 36, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 125, 47, 51, 125, 10, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 10,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 69, 102, 102, 101, 116, 61, 61, 48, 125, 10, 45, 108, 105, 110,
  101, 91, 45, 49, 93, 32, 48, 44, 123, 123, 104, 125, 45, 36, 79, 114,
  105, 103, 105, 110, 101, 95, 72, 125, 44, 36, 79, 114, 105, 103, 105, 110,
  101, 95, 76, 44, 48, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101,
  117, 114, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 65, 95, 67, 111, 117, 108,
  101, 117, 114, 10, 45, 101, 108, 105, 102, 32, 123, 36, 69, 102, 102, 101,
  116, 61, 61, 50, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32,
  48, 44, 123, 123, 104, 125, 45, 36, 79, 114, 105, 103, 105, 110, 101, 95,
  72, 125, 44, 36, 79, 114, 105, 103, 105, 110, 101, 95, 76, 44, 48, 44,
  49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 69, 102, 102, 101, 116, 61, 61, 52, 125, 10,
  45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 48, 44, 123, 123, 104, 125,
  45, 36, 79, 114, 105, 103, 105, 110, 101, 95, 72, 125, 44, 36, 79, 114,
  105, 103, 105, 110, 101, 95, 76, 44, 48, 44, 49, 44, 36, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117,
  114, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 65, 95,
  67, 111, 117, 108, 101, 117, 114, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  69, 102, 102, 101, 116, 61, 61, 56, 125, 10, 45, 108, 105, 110, 101, 91,
  45, 49, 93, 32, 48, 44, 123, 123, 104, 125, 45, 36, 79, 114, 105, 103,
  105, 110, 101, 95, 72, 125, 44, 36, 79, 114, 105, 103, 105, 110, 101, 95,
  76, 44, 48, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114,
  44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117,
  114, 10, 45, 101, 108, 105, 102, 32, 123, 36, 69, 102, 102, 101, 116, 61,
  61, 57, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 48, 44,
  123, 123, 104, 125, 45, 36, 79, 114, 105, 103, 105, 110, 101, 95, 72, 125,
  44, 36, 79, 114, 105, 103, 105, 110, 101, 95, 76, 44, 48, 44, 49, 44,
  36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 86, 95, 67, 111,
  117, 108, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114,
  44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 83,
  121, 109, 101, 116, 114, 105, 101, 61, 61, 49, 125, 10, 45, 109, 105, 114,
  114, 111, 114, 91, 45, 49, 93, 32, 120, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 115, 112, 114, 101, 97, 100, 91, 45, 49, 93, 32, 36, 118, 97,
  108, 101, 117, 114, 95, 115, 112, 114, 101, 97, 100, 10, 45, 98, 108, 117,
  114, 91, 45, 49, 93, 32, 36, 102, 108, 111, 117, 10, 45, 100, 101, 102,
  111, 114, 109, 91, 45, 49, 93, 32, 36, 100, 101, 102, 111, 114, 109, 97,
  116, 105, 111, 110, 10, 45, 105, 102, 32, 123, 36, 77, 101, 108, 97, 110,
  103, 101, 61, 61, 48, 125, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95,
  97, 108, 112, 104, 97, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 77, 101, 108, 97, 110, 103, 101, 61, 61, 49, 125,
  10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44,
  45, 50, 93, 32, 32, 36, 77, 111, 100, 101, 95, 77, 101, 108, 97, 110,
  103, 101, 44, 36, 79, 112, 97, 99, 105, 116, 121, 95, 77, 101, 108, 97,
  110, 103, 101, 44, 36, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101,
  114, 115, 95, 77, 101, 108, 97, 110, 103, 101, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115, 97,
  109, 106, 95, 68, 101, 115, 95, 76, 105, 103, 110, 101, 115, 95, 48, 48,
  50, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 115, 97, 109, 106, 95, 68, 101, 115, 95, 76, 105, 103, 110, 101,
  115, 95, 48, 48, 50, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64,
  103, 105, 109, 112, 32, 69, 120, 112, 97, 110, 100, 32, 120, 121, 32, 48,
  48, 49, 32, 58, 32, 115, 97, 109, 106, 95, 69, 120, 112, 97, 110, 100,
  95, 88, 89, 95, 48, 48, 49, 44, 32, 115, 97, 109, 106, 95, 69, 120,
  112, 97, 110, 100, 95, 88, 89, 95, 48, 48, 49, 95, 112, 114, 101, 118,
  105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100,
  61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109,
  97, 108, 108, 62, 67, 97, 100, 114, 101, 60, 47, 115, 109, 97, 108, 108,
  62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110, 32, 112, 105,
  120, 101, 108, 115, 32, 61, 32, 105, 110, 116, 40, 50, 48, 44, 49, 44,
  52, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34,
  111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108,
  108, 62, 68, 105, 115, 116, 111, 114, 115, 105, 111, 110, 115, 60, 47, 115,
  109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 114, 101, 97, 100, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 70, 108, 111, 117, 32, 47, 32, 98,
  108, 117, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 48,
  44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101,
  102, 111, 114, 109, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44,
  48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61,
  34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97,
  108, 108, 62, 67, 111, 108, 111, 114, 115, 60, 47, 115, 109, 97, 108, 108,
  62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 78, 101, 103, 97, 116, 105, 118, 101, 32, 61, 32, 98,
  111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  66, 111, 111, 115, 116, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97, 109, 106,
  32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 49, 56,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  115, 97, 109, 106, 95, 69, 120, 112, 97, 110, 100, 95, 88, 89, 95, 48,
  48, 49, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 68, 105, 109, 101, 110, 115, 105, 111, 110,
  95, 80, 105, 120, 101, 108, 115, 61, 36, 49, 10, 118, 97, 108, 101, 117,
  114, 95, 115, 112, 114, 101, 97, 100, 61, 36, 50, 10, 102, 108, 111, 117,
  61, 36, 51, 10, 100, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 61,
  36, 52, 10, 78, 101, 103, 97, 116, 105, 118, 101, 95, 67, 111, 108, 111,
  114, 115, 61, 36, 53, 10, 66, 111, 111, 115, 116, 61, 36, 54, 10, 45,
  45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103,
  91, 45, 49, 93, 10, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 91,
  45, 49, 93, 32, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 80,
  105, 120, 101, 108, 115, 44, 49, 10, 45, 105, 102, 32, 123, 36, 66, 111,
  111, 115, 116, 61, 61, 49, 125, 10, 45, 103, 105, 109, 112, 95, 110, 111,
  114, 109, 97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 91, 45, 49,
  93, 32, 50, 44, 54, 44, 53, 44, 50, 48, 44, 49, 44, 51, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 78, 101, 103, 97,
  116, 105, 118, 101, 95, 67, 111, 108, 111, 114, 115, 61, 61, 49, 125, 10,
  45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93,
  10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 102, 108, 111, 117,
  10, 45, 100, 101, 102, 111, 114, 109, 91, 45, 49, 93, 32, 36, 100, 101,
  102, 111, 114, 109, 97, 116, 105, 111, 110, 10, 45, 115, 112, 114, 101, 97,
  100, 91, 45, 49, 93, 32, 36, 118, 97, 108, 101, 117, 114, 95, 115, 112,
  114, 101, 97, 100, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49,
  93, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 52,
  44, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 80, 105, 120, 101,
  108, 115, 44, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 80, 105,
  120, 101, 108, 115, 44, 123, 123, 119, 125, 45, 36, 68, 105, 109, 101, 110,
  115, 105, 111, 110, 95, 80, 105, 120, 101, 108, 115, 125, 44, 36, 68, 105,
  109, 101, 110, 115, 105, 111, 110, 95, 80, 105, 120, 101, 108, 115, 44, 123,
  123, 119, 125, 45, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 80,
  105, 120, 101, 108, 115, 125, 44, 123, 123, 104, 125, 45, 36, 68, 105, 109,
  101, 110, 115, 105, 111, 110, 95, 80, 105, 120, 101, 108, 115, 125, 44, 36,
  68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 80, 105, 120, 101, 108, 115,
  44, 123, 123, 104, 125, 45, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110,
  95, 80, 105, 120, 101, 108, 115, 125, 44, 49, 44, 48, 44, 48, 44, 48,
  44, 48, 10, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 91, 45, 50,
  93, 32, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 80, 105, 120,
  101, 108, 115, 44, 48, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 97,
  108, 112, 104, 97, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 115, 97, 109, 106, 95, 69, 120, 112,
  97, 110, 100, 95, 88, 89, 95, 48, 48, 49, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95,
  69, 120, 112, 97, 110, 100, 95, 88, 89, 95, 48, 48, 49, 32, 36, 42,
  34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 70, 105, 108,
  101, 116, 115, 32, 48, 48, 49, 32, 58, 32, 115, 97, 109, 106, 95, 70,
  105, 108, 101, 116, 115, 95, 48, 48, 49, 44, 32, 115, 97, 109, 106, 95,
  70, 105, 108, 101, 116, 115, 95, 48, 48, 49, 95, 112, 114, 101, 118, 105,
  101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61,
  34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97,
  108, 108, 62, 67, 97, 100, 114, 101, 60, 47, 115, 109, 97, 108, 108, 62,
  60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 48, 53, 44, 48, 44, 48, 46, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 109, 98, 114,
  101, 32, 108, 105, 103, 110, 101, 115, 32, 61, 32, 105, 110, 116, 40, 55,
  53, 44, 49, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 68, 101, 102, 111, 114, 109, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 48, 44, 48, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 121, 109, 101, 116, 114, 105, 101, 32, 61, 32, 98,
  111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  69, 102, 102, 101, 116, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48,
  44, 34, 49, 34, 44, 34, 50, 34, 44, 34, 51, 34, 44, 34, 52, 34,
  44, 34, 53, 34, 44, 34, 54, 34, 44, 34, 55, 34, 44, 34, 56, 34,
  44, 34, 57, 34, 44, 34, 49, 48, 34, 44, 34, 49, 49, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 116, 101, 110, 100, 117, 101,
  32, 47, 32, 101, 120, 116, 101, 110, 116, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 48, 44, 34, 84, 111, 117, 116, 101, 32, 47, 32, 65, 108,
  108, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110, 34, 44, 34, 49, 47,
  50, 32, 72, 97, 108, 102, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110,
  34, 44, 34, 49, 47, 51, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110,
  34, 44, 34, 49, 47, 52, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110,
  34, 44, 34, 49, 47, 53, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110,
  34, 44, 34, 49, 47, 54, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110,
  34, 44, 34, 49, 47, 55, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110,
  34, 44, 34, 49, 47, 56, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110,
  34, 44, 34, 49, 47, 57, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110,
  34, 44, 34, 49, 47, 49, 48, 32, 68, 105, 109, 101, 110, 115, 105, 111,
  110, 34, 32, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 112,
  97, 105, 115, 115, 101, 117, 114, 32, 47, 32, 116, 104, 105, 99, 107, 110,
  101, 115, 115, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 51, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32,
  102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110,
  103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 67, 111,
  108, 111, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112,
  97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70,
  105, 108, 101, 116, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53,
  44, 49, 50, 56, 44, 54, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50,
  48, 49, 52, 47, 48, 49, 47, 49, 57, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 70, 105,
  108, 101, 116, 115, 95, 48, 48, 49, 32, 58, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 68, 105, 109,
  101, 110, 115, 105, 111, 110, 95, 80, 105, 120, 101, 108, 115, 61, 36, 49,
  10, 78, 111, 109, 98, 114, 101, 95, 76, 105, 103, 110, 101, 115, 61, 36,
  50, 10, 100, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 61, 36, 51,
  10, 83, 121, 109, 101, 116, 114, 105, 101, 61, 36, 52, 10, 69, 102, 102,
  101, 116, 61, 36, 53, 10, 69, 116, 101, 110, 100, 117, 101, 61, 36, 54,
  10, 69, 112, 97, 105, 115, 115, 101, 117, 114, 61, 36, 55, 10, 82, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 70, 105, 108, 101, 116, 61, 36, 56,
  10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 70, 105, 108, 101, 116,
  61, 36, 57, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 70, 105,
  108, 101, 116, 61, 36, 49, 48, 10, 67, 97, 100, 114, 101, 61, 123, 50,
  43, 123, 114, 111, 117, 110, 100, 40, 123, 109, 97, 120, 40, 123, 119, 125,
  44, 123, 104, 125, 41, 125, 42, 36, 68, 105, 109, 101, 110, 115, 105, 111,
  110, 95, 80, 105, 120, 101, 108, 115, 41, 125, 125, 10, 45, 45, 103, 105,
  109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49,
  93, 10, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 91, 45, 49, 93,
  32, 123, 36, 67, 97, 100, 114, 101, 45, 50, 125, 44, 49, 10, 35, 35,
  32, 115, 101, 109, 98, 108, 97, 98, 108, 97, 32, -32, 32, 69, 120, 112,
  97, 110, 100, 95, 88, 89, 95, 48, 48, 49, 10, 45, 116, 111, 95, 114,
  103, 98, 91, 45, 49, 93, 10, 45, 115, 112, 114, 101, 97, 100, 91, 45,
  49, 93, 32, 49, 48, 10, 45, 100, 101, 102, 111, 114, 109, 91, 45, 49,
  93, 32, 50, 48, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 123,
  50, 48, 43, 123, 36, 67, 97, 100, 114, 101, 47, 50, 48, 125, 125, 10,
  45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 10, 45, 112, 111,
  108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 52, 44, 36, 67, 97, 100,
  114, 101, 44, 36, 67, 97, 100, 114, 101, 44, 123, 123, 119, 125, 45, 36,
  67, 97, 100, 114, 101, 125, 44, 36, 67, 97, 100, 114, 101, 44, 123, 123,
  119, 125, 45, 36, 67, 97, 100, 114, 101, 125, 44, 123, 123, 104, 125, 45,
  36, 67, 97, 100, 114, 101, 125, 44, 36, 67, 97, 100, 114, 101, 44, 123,
  123, 104, 125, 45, 36, 67, 97, 100, 114, 101, 125, 44, 49, 44, 48, 44,
  48, 44, 48, 44, 48, 10, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121,
  91, 45, 50, 93, 32, 36, 67, 97, 100, 114, 101, 44, 48, 10, 45, 99,
  111, 109, 112, 111, 115, 101, 95, 97, 108, 112, 104, 97, 91, 45, 50, 44,
  45, 49, 93, 10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 52, 10,
  45, 115, 97, 109, 106, 95, 68, 101, 115, 95, 76, 105, 103, 110, 101, 115,
  95, 48, 48, 50, 91, 45, 49, 93, 32, 36, 78, 111, 109, 98, 114, 101,
  95, 76, 105, 103, 110, 101, 115, 44, 49, 44, 49, 44, 49, 57, 50, 44,
  49, 50, 56, 44, 54, 52, 44, 50, 53, 53, 44, 36, 83, 121, 109, 101,
  116, 114, 105, 101, 44, 36, 69, 102, 102, 101, 116, 44, 36, 69, 116, 101,
  110, 100, 117, 101, 44, 48, 44, 48, 44, 36, 100, 101, 102, 111, 114, 109,
  97, 116, 105, 111, 110, 44, 48, 44, 48, 44, 49, 44, 48, 10, 45, 105,
  102, 32, 123, 36, 69, 112, 97, 105, 115, 115, 101, 117, 114, 62, 48, 125,
  10, 45, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 91, 45, 49,
  93, 32, 36, 69, 112, 97, 105, 115, 115, 101, 117, 114, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 108, 111, 99, 97, 108, 95,
  111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 91, 45, 49, 93, 32,
  48, 44, 48, 44, 49, 48, 48, 44, 48, 44, 48, 10, 123, 119, 125, 44,
  123, 104, 125, 44, 49, 44, 52, 10, 45, 102, 105, 108, 108, 95, 99, 111,
  108, 111, 114, 91, 45, 49, 93, 32, 36, 82, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 70, 105, 108, 101, 116, 44, 36, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 70, 105, 108, 101, 116, 44, 36, 66, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 70, 105, 108, 101, 116, 44, 50, 53, 53, 10, 45,
  103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50,
  93, 32, 51, 54, 44, 49, 44, 49, 10, 45, 99, 111, 109, 112, 111, 115,
  101, 95, 97, 108, 112, 104, 97, 91, 45, 50, 44, 45, 49, 93, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115, 97, 109, 106, 95,
  70, 105, 108, 101, 116, 115, 95, 48, 48, 49, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95,
  70, 105, 108, 101, 116, 115, 95, 48, 48, 49, 32, 36, 42, 34, 44, 36,
  45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 71, 114, 97, 100, 105, 101,
  110, 116, 32, 48, 48, 49, 32, 58, 32, 115, 97, 109, 106, 95, 71, 114,
  97, 100, 105, 101, 110, 116, 95, 48, 48, 49, 44, 32, 115, 97, 109, 106,
  95, 71, 114, 97, 100, 105, 101, 110, 116, 95, 48, 48, 49, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117,
  110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60,
  115, 109, 97, 108, 108, 62, 67, 97, 100, 114, 101, 60, 47, 115, 109, 97,
  108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110, 32,
  37, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 49, 48, 44, 49, 48,
  48, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  82, 101, 110, 100, 117, 32, 109, 105, 114, 114, 111, 114, 32, 61, 32, 98,
  111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100,
  61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109,
  97, 108, 108, 62, 67, 111, 108, 111, 114, 115, 32, 47, 32, 67, 111, 117,
  108, 101, 117, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115,
  112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 117, 108, 101, 117, 114, 32, 47, 32, 99, 111, 108, 111, 114, 32,
  97, 32, 61, 32, 99, 111, 108, 111, 114, 40, 51, 50, 44, 51, 50, 44,
  51, 50, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 111, 117, 108, 101, 117, 114, 32, 47, 32, 99, 111, 108, 111, 114,
  32, 98, 32, 61, 32, 99, 111, 108, 111, 114, 40, 49, 54, 48, 44, 49,
  54, 48, 44, 49, 54, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 86, 97, 114, 105, 97, 116, 105, 111, 110, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 46, 53, 44, 52, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32,
  102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110,
  103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 68, 105,
  115, 116, 111, 114, 115, 105, 111, 110, 115, 60, 47, 115, 109, 97, 108, 108,
  62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 68, 101, 102, 111, 114, 109, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103,
  114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100,
  34, 62, 60, 115, 109, 97, 108, 108, 62, 76, 105, 103, 110, 101, 32, 67,
  111, 110, 116, 111, 117, 114, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47,
  115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 69, 112, 97, 105, 115, 115, 101, 117, 114, 32, 47, 32, 116, 104, 105,
  99, 107, 110, 101, 115, 115, 32, 112, 105, 120, 101, 108, 115, 32, 61, 32,
  105, 110, 116, 40, 48, 44, 48, 44, 52, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 47, 32, 99, 111,
  108, 111, 114, 32, 108, 105, 103, 110, 101, 32, 61, 32, 99, 111, 108, 111,
  114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 49, 50,
  55, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80,
  114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115,
  97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49,
  47, 50, 49, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 115, 97, 109, 106, 95, 71, 114, 97, 100, 105, 101, 110, 116,
  95, 48, 48, 49, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 68, 105, 109, 101, 110, 115, 105,
  111, 110, 95, 80, 111, 117, 114, 99, 101, 110, 116, 61, 36, 49, 10, 82,
  101, 110, 100, 117, 61, 36, 50, 10, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 65, 61, 36, 51, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 65, 61, 36, 52, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  65, 61, 36, 53, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 65,
  61, 36, 54, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 66, 61,
  36, 55, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 66, 61, 36,
  56, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 66, 61, 36, 57,
  10, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 66, 61, 36, 49, 48,
  10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 115, 95, 67, 111, 117, 108,
  101, 117, 114, 115, 61, 36, 49, 49, 10, 100, 101, 102, 111, 114, 109, 97,
  116, 105, 111, 110, 61, 36, 49, 50, 10, 69, 112, 97, 105, 115, 115, 101,
  117, 114, 95, 76, 105, 103, 110, 101, 95, 67, 111, 110, 116, 111, 117, 114,
  61, 36, 49, 51, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 76,
  105, 103, 110, 101, 61, 36, 49, 52, 10, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 76, 105, 103, 110, 101, 61, 36, 49, 53, 10, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 76, 105, 103, 110, 101, 61, 36, 49, 54,
  10, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 76, 105, 103, 110, 101,
  61, 36, 49, 55, 10, 76, 97, 114, 103, 101, 117, 114, 95, 79, 114, 105,
  103, 105, 110, 101, 61, 123, 119, 125, 10, 72, 97, 117, 116, 101, 117, 114,
  95, 79, 114, 105, 103, 105, 110, 101, 61, 123, 104, 125, 10, 76, 97, 114,
  103, 101, 117, 114, 95, 70, 105, 110, 97, 108, 101, 61, 123, 50, 42, 123,
  114, 111, 117, 110, 100, 40, 123, 123, 119, 125, 47, 50, 48, 48, 42, 36,
  68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 80, 111, 117, 114, 99, 101,
  110, 116, 125, 41, 125, 125, 10, 72, 97, 117, 116, 101, 117, 114, 95, 70,
  105, 110, 97, 108, 101, 61, 123, 50, 42, 123, 114, 111, 117, 110, 100, 40,
  123, 123, 104, 125, 47, 50, 48, 48, 42, 36, 68, 105, 109, 101, 110, 115,
  105, 111, 110, 95, 80, 111, 117, 114, 99, 101, 110, 116, 125, 41, 125, 125,
  10, 69, 120, 112, 95, 76, 61, 123, 123, 123, 36, 76, 97, 114, 103, 101,
  117, 114, 95, 70, 105, 110, 97, 108, 101, 125, 45, 36, 76, 97, 114, 103,
  101, 117, 114, 95, 79, 114, 105, 103, 105, 110, 101, 125, 47, 50, 125, 10,
  69, 120, 112, 95, 72, 61, 123, 123, 123, 36, 72, 97, 117, 116, 101, 117,
  114, 95, 70, 105, 110, 97, 108, 101, 125, 45, 36, 72, 97, 117, 116, 101,
  117, 114, 95, 79, 114, 105, 103, 105, 110, 101, 125, 47, 50, 125, 10, 45,
  116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10, 45, 45, 103, 105, 109,
  112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93,
  10, 35, 35, 32, 68, -55, 66, 85, 84, 32, 112, 97, 114, 116, 105, 101,
  32, 100, 101, 32, 34, 103, 105, 109, 112, 95, 99, 111, 114, 110, 101, 114,
  95, 103, 114, 97, 100, 105, 101, 110, 116, 34, 32, 100, 101, 32, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, -23, 10,
  40, 123, 119, 125, 44, 123, 104, 125, 41, 10, 45, 114, 109, 91, 45, 50,
  93, 10, 40, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 65, 44,
  36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 66, 59, 36, 82, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 66, 44, 36, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 65, 94, 36, 86, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 65, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 66,
  59, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 66, 44, 36, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 65, 94, 36, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 65, 44, 36, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 66, 59, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  66, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 65, 94, 36,
  65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 65, 44, 36, 65, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 66, 59, 36, 65, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 66, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 65, 41, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32,
  64, 45, 50, 44, 49, 44, 52, 44, 51, 10, 45, 114, 109, 91, 45, 50,
  93, 10, 35, 35, 32, 70, 73, 78, 32, 112, 97, 114, 116, 105, 101, 32,
  100, 101, 32, 34, 103, 105, 109, 112, 95, 99, 111, 114, 110, 101, 114, 95,
  103, 114, 97, 100, 105, 101, 110, 116, 34, 10, 45, 105, 102, 32, 123, 36,
  82, 101, 110, 100, 117, 61, 61, 49, 125, 10, 45, 109, 105, 114, 114, 111,
  114, 91, 45, 49, 93, 32, 120, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 36, 76, 97, 114, 103,
  101, 117, 114, 95, 70, 105, 110, 97, 108, 101, 44, 36, 72, 97, 117, 116,
  101, 117, 114, 95, 70, 105, 110, 97, 108, 101, 44, 49, 44, 51, 10, 45,
  112, 111, 119, 91, 45, 49, 93, 32, 36, 86, 97, 114, 105, 97, 116, 105,
  111, 110, 115, 95, 67, 111, 117, 108, 101, 117, 114, 115, 10, 45, 100, 101,
  102, 111, 114, 109, 91, 45, 49, 93, 32, 36, 100, 101, 102, 111, 114, 109,
  97, 116, 105, 111, 110, 10, 45, 101, 120, 112, 97, 110, 100, 95, 120, 91,
  45, 50, 93, 32, 36, 69, 120, 112, 95, 76, 44, 48, 10, 45, 101, 120,
  112, 97, 110, 100, 95, 121, 91, 45, 50, 93, 32, 36, 69, 120, 112, 95,
  72, 44, 48, 10, 45, 105, 102, 32, 123, 36, 69, 112, 97, 105, 115, 115,
  101, 117, 114, 95, 76, 105, 103, 110, 101, 95, 67, 111, 110, 116, 111, 117,
  114, 62, 48, 125, 10, 36, 76, 97, 114, 103, 101, 117, 114, 95, 70, 105,
  110, 97, 108, 101, 44, 36, 72, 97, 117, 116, 101, 117, 114, 95, 70, 105,
  110, 97, 108, 101, 44, 49, 44, 52, 10, 45, 102, 105, 108, 108, 95, 99,
  111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48,
  10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 52, 44,
  123, 36, 69, 120, 112, 95, 76, 45, 36, 69, 112, 97, 105, 115, 115, 101,
  117, 114, 95, 76, 105, 103, 110, 101, 95, 67, 111, 110, 116, 111, 117, 114,
  125, 44, 123, 36, 69, 120, 112, 95, 72, 45, 36, 69, 112, 97, 105, 115,
  115, 101, 117, 114, 95, 76, 105, 103, 110, 101, 95, 67, 111, 110, 116, 111,
  117, 114, 125, 44, 123, 36, 76, 97, 114, 103, 101, 117, 114, 95, 70, 105,
  110, 97, 108, 101, 45, 36, 69, 120, 112, 95, 76, 43, 36, 69, 112, 97,
  105, 115, 115, 101, 117, 114, 95, 76, 105, 103, 110, 101, 95, 67, 111, 110,
  116, 111, 117, 114, 125, 44, 123, 36, 69, 120, 112, 95, 72, 45, 36, 69,
  112, 97, 105, 115, 115, 101, 117, 114, 95, 76, 105, 103, 110, 101, 95, 67,
  111, 110, 116, 111, 117, 114, 125, 44, 123, 36, 76, 97, 114, 103, 101, 117,
  114, 95, 70, 105, 110, 97, 108, 101, 45, 36, 69, 120, 112, 95, 76, 43,
  36, 69, 112, 97, 105, 115, 115, 101, 117, 114, 95, 76, 105, 103, 110, 101,
  95, 67, 111, 110, 116, 111, 117, 114, 125, 44, 123, 36, 72, 97, 117, 116,
  101, 117, 114, 95, 70, 105, 110, 97, 108, 101, 45, 36, 69, 120, 112, 95,
  72, 43, 36, 69, 112, 97, 105, 115, 115, 101, 117, 114, 95, 76, 105, 103,
  110, 101, 95, 67, 111, 110, 116, 111, 117, 114, 125, 44, 123, 36, 69, 120,
  112, 95, 76, 45, 36, 69, 112, 97, 105, 115, 115, 101, 117, 114, 95, 76,
  105, 103, 110, 101, 95, 67, 111, 110, 116, 111, 117, 114, 125, 44, 123, 36,
  72, 97, 117, 116, 101, 117, 114, 95, 70, 105, 110, 97, 108, 101, 45, 36,
  69, 120, 112, 95, 72, 43, 36, 69, 112, 97, 105, 115, 115, 101, 117, 114,
  95, 76, 105, 103, 110, 101, 95, 67, 111, 110, 116, 111, 117, 114, 125, 44,
  49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 76, 105, 103,
  110, 101, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 76, 105,
  103, 110, 101, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 76,
  105, 103, 110, 101, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  76, 105, 103, 110, 101, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 97,
  108, 112, 104, 97, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32,
  52, 44, 36, 69, 120, 112, 95, 76, 44, 36, 69, 120, 112, 95, 72, 44,
  123, 36, 76, 97, 114, 103, 101, 117, 114, 95, 70, 105, 110, 97, 108, 101,
  45, 36, 69, 120, 112, 95, 76, 125, 44, 36, 69, 120, 112, 95, 72, 44,
  123, 36, 76, 97, 114, 103, 101, 117, 114, 95, 70, 105, 110, 97, 108, 101,
  45, 36, 69, 120, 112, 95, 76, 125, 44, 123, 36, 72, 97, 117, 116, 101,
  117, 114, 95, 70, 105, 110, 97, 108, 101, 45, 36, 69, 120, 112, 95, 72,
  125, 44, 36, 69, 120, 112, 95, 76, 44, 123, 36, 72, 97, 117, 116, 101,
  117, 114, 95, 70, 105, 110, 97, 108, 101, 45, 36, 69, 120, 112, 95, 72,
  125, 44, 49, 44, 48, 44, 48, 44, 48, 44, 48, 10, 45, 103, 105, 109,
  112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 48,
  44, 49, 44, 48, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 115, 97, 109, 106, 95, 71, 114, 97, 100, 105, 101, 110, 116, 95, 48,
  48, 49, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105,
  109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 34, 45, 115, 97, 109, 106, 95, 71, 114, 97, 100, 105, 101, 110, 116,
  95, 48, 48, 49, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35, 64, 103,
  105, 109, 112, 32, 95, 10, 35, 64, 103, 105, 109, 112, 32, 60, 105, 62,
  76, 105, 103, 104, 116, 115, 32, 38, 97, 109, 112, 59, 32, 115, 104, 97,
  100, 111, 119, 115, 60, 47, 105, 62, 10, 35, 64, 103, 105, 109, 112, 32,
  77, 97, 120, 32, 109, 105, 110, 32, 112, 97, 116, 99, 104, 32, 48, 48,
  49, 32, 58, 32, 115, 97, 109, 106, 95, 77, 97, 120, 95, 77, 105, 110,
  95, 80, 97, 116, 99, 104, 95, 48, 48, 49, 44, 32, 115, 97, 109, 106,
  95, 77, 97, 120, 95, 77, 105, 110, 95, 80, 97, 116, 99, 104, 95, 48,
  48, 49, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114,
  101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114,
  101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 77, 97, 120, 32, 80,
  97, 116, 99, 104, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112,
  97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80,
  97, 116, 99, 104, 32, 115, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40,
  49, 50, 55, 44, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 68, 105, 108, 97, 116, 101, 32, 61, 32, 105, 110, 116,
  40, 52, 48, 44, 49, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114,
  111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34,
  62, 60, 115, 109, 97, 108, 108, 62, 77, 105, 110, 32, 80, 97, 116, 99,
  104, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 97, 116, 99,
  104, 32, 115, 105, 122, 101, 32, 61, 32, 105, 110, 116, 40, 49, 50, 55,
  44, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 68, 105, 108, 97, 116, 101, 32, 61, 32, 105, 110, 116, 40, 52, 48,
  44, 49, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110,
  100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115,
  109, 97, 108, 108, 62, 66, 108, 117, 114, 32, 82, 97, 100, 105, 97, 108,
  60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 100, 100, 32, 116,
  101, 120, 116, 117, 114, 101, 100, 32, 103, 108, 97, 115, 115, 32, 61, 32,
  98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 53, 44, 48, 44, 52, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 88, 45, 99, 101, 110, 116, 101, 114, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 101, 110, 116, 101, 114,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 114, 112,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 53, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 50, 44, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66, 65,
  34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99, 104,
  114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108, 117,
  101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34,
  44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97, 98,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99, 111,
  109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44, 34,
  83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97, 108,
  117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101, 110,
  32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 99,
  104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 99,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34, 44,
  34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34,
  65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 86, 97, 108, 117, 101, 32, 114, 97, 110, 103, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 67, 117, 116, 34, 44, 34, 78, 111, 114,
  109, 97, 108, 105, 122, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 67, 111, 117, 108, 101, 117, 114,
  115, 32, 47, 32, 67, 111, 108, 111, 114, 115, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111,
  117, 108, 101, 117, 114, 115, 32, 47, 32, 99, 111, 108, 111, 114, 115, 32,
  61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 66, 108, 101, 110, 100, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 48, 44, 34, 65, 100, 100, 34, 44, 34, 65, 108, 112, 104, 97, 34,
  44, 34, 65, 110, 100, 34, 44, 34, 65, 118, 101, 114, 97, 103, 101, 34,
  44, 34, 66, 108, 117, 101, 34, 44, 34, 66, 117, 114, 110, 34, 44, 34,
  68, 97, 114, 107, 101, 110, 34, 44, 34, 68, 105, 102, 102, 101, 114, 101,
  110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34,
  68, 105, 118, 105, 100, 101, 34, 44, 34, 68, 111, 100, 103, 101, 34, 44,
  34, 69, 120, 99, 108, 117, 115, 105, 111, 110, 34, 44, 34, 70, 114, 101,
  101, 122, 101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 101, 120, 116, 114,
  97, 99, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 109, 101, 114, 103,
  101, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 72, 97, 114, 100,
  32, 108, 105, 103, 104, 116, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44, 34, 72, 117,
  101, 34, 44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111,
  110, 34, 44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44, 34, 76, 105,
  103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110, 101, 97, 114,
  32, 98, 117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 108,
  105, 103, 104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101,
  34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 77, 117, 108,
  116, 105, 112, 108, 121, 34, 44, 34, 78, 101, 103, 97, 116, 105, 111, 110,
  34, 44, 34, 79, 114, 34, 44, 34, 79, 118, 101, 114, 108, 97, 121, 34,
  44, 34, 80, 105, 110, 32, 108, 105, 103, 104, 116, 34, 44, 34, 82, 101,
  100, 34, 44, 34, 82, 101, 102, 108, 101, 99, 116, 34, 44, 34, 83, 97,
  116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97,
  103, 101, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97,
  103, 101, 48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117, 114, 110, 34,
  44, 34, 83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34, 44, 34, 83,
  111, 102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83, 99, 114, 101,
  101, 110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34, 83, 117, 98,
  116, 114, 97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 86, 105, 118, 105, 100, 32,
  108, 105, 103, 104, 116, 34, 44, 34, 88, 111, 114, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97,
  121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97, 109, 106, 32,
  45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32,
  58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 50, 48, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 115,
  97, 109, 106, 95, 77, 97, 120, 95, 77, 105, 110, 95, 80, 97, 116, 99,
  104, 95, 48, 48, 49, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 77, 97, 120, 95, 80, 97,
  116, 99, 104, 95, 80, 97, 116, 99, 104, 95, 83, 105, 122, 101, 61, 36,
  49, 10, 68, 105, 108, 97, 116, 101, 95, 77, 97, 120, 95, 80, 97, 116,
  99, 104, 61, 36, 50, 10, 77, 105, 110, 95, 80, 97, 116, 99, 104, 95,
  80, 97, 116, 99, 104, 95, 83, 105, 122, 101, 61, 36, 51, 10, 68, 105,
  108, 97, 116, 101, 95, 77, 105, 110, 95, 80, 97, 116, 99, 104, 61, 36,
  52, 10, 65, 100, 100, 95, 84, 101, 120, 116, 117, 114, 101, 100, 95, 71,
  108, 97, 115, 115, 61, 36, 53, 10, 66, 82, 95, 65, 109, 112, 108, 105,
  116, 117, 100, 101, 61, 36, 54, 10, 66, 82, 95, 88, 95, 99, 101, 110,
  116, 101, 114, 61, 36, 55, 10, 66, 82, 95, 89, 95, 99, 101, 110, 116,
  101, 114, 61, 36, 56, 10, 66, 82, 95, 83, 104, 97, 114, 112, 110, 101,
  115, 115, 61, 36, 57, 10, 66, 82, 95, 67, 104, 97, 110, 110, 101, 108,
  115, 61, 36, 49, 48, 10, 66, 82, 95, 86, 97, 108, 117, 101, 95, 114,
  97, 110, 103, 101, 61, 36, 49, 49, 10, 67, 111, 117, 108, 101, 117, 114,
  115, 61, 36, 49, 50, 10, 98, 108, 101, 110, 100, 61, 36, 49, 51, 10,
  111, 112, 97, 99, 105, 116, 101, 61, 36, 49, 52, 10, 82, 101, 118, 101,
  114, 116, 95, 108, 97, 121, 101, 114, 115, 61, 36, 49, 53, 10, 45, 116,
  111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 10, 45, 45, 103, 105, 109,
  112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93,
  10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105,
  110, 103, 91, 45, 49, 93, 10, 45, 109, 97, 120, 95, 112, 97, 116, 99,
  104, 91, 45, 49, 93, 32, 36, 77, 97, 120, 95, 80, 97, 116, 99, 104,
  95, 80, 97, 116, 99, 104, 95, 83, 105, 122, 101, 10, 45, 116, 111, 95,
  114, 103, 98, 91, 45, 49, 93, 10, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 10, 45, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114,
  99, 91, 45, 49, 93, 32, 36, 68, 105, 108, 97, 116, 101, 95, 77, 97,
  120, 95, 80, 97, 116, 99, 104, 10, 45, 109, 105, 110, 95, 112, 97, 116,
  99, 104, 91, 45, 50, 93, 32, 36, 77, 105, 110, 95, 80, 97, 116, 99,
  104, 95, 80, 97, 116, 99, 104, 95, 83, 105, 122, 101, 10, 45, 116, 111,
  95, 114, 103, 98, 91, 45, 50, 93, 10, 45, 110, 91, 45, 50, 93, 32,
  48, 44, 50, 53, 53, 10, 45, 100, 105, 108, 97, 116, 101, 95, 99, 105,
  114, 99, 91, 45, 50, 93, 32, 36, 68, 105, 108, 97, 116, 101, 95, 77,
  105, 110, 95, 80, 97, 116, 99, 104, 10, 45, 103, 105, 109, 112, 95, 98,
  108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 48, 44, 49, 44,
  48, 10, 45, 105, 102, 32, 123, 36, 67, 111, 117, 108, 101, 117, 114, 115,
  61, 61, 48, 125, 10, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 49,
  93, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 49, 50, 55, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45,
  49, 93, 10, 45, 105, 102, 32, 123, 36, 65, 100, 100, 95, 84, 101, 120,
  116, 117, 114, 101, 100, 95, 71, 108, 97, 115, 115, 61, 61, 49, 125, 10,
  45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 45,
  49, 93, 32, 52, 48, 44, 51, 44, 48, 44, 48, 44, 48, 44, 50, 53,
  53, 44, 48, 44, 48, 44, 48, 44, 48, 10, 45, 45, 103, 105, 109, 112,
  95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10,
  45, 103, 105, 109, 112, 95, 98, 108, 117, 114, 95, 114, 97, 100, 105, 97,
  108, 91, 45, 49, 93, 32, 36, 66, 82, 95, 65, 109, 112, 108, 105, 116,
  117, 100, 101, 44, 36, 66, 82, 95, 88, 95, 99, 101, 110, 116, 101, 114,
  44, 36, 66, 82, 95, 89, 95, 99, 101, 110, 116, 101, 114, 44, 36, 66,
  82, 95, 83, 104, 97, 114, 112, 110, 101, 115, 115, 44, 36, 66, 82, 95,
  67, 104, 97, 110, 110, 101, 108, 115, 44, 36, 66, 82, 95, 86, 97, 108,
  117, 101, 95, 114, 97, 110, 103, 101, 10, 45, 110, 91, 45, 50, 93, 32,
  48, 44, 123, 48, 46, 53, 42, 123, 123, 105, 97, 125, 43, 123, 105, 77,
  125, 125, 125, 10, 45, 103, 105, 109, 112, 95, 116, 101, 120, 116, 117, 114,
  101, 100, 95, 103, 108, 97, 115, 115, 91, 45, 50, 93, 32, 123, 114, 111,
  117, 110, 100, 40, 123, 49, 46, 53, 42, 123, 109, 97, 120, 40, 36, 68,
  105, 108, 97, 116, 101, 95, 77, 97, 120, 95, 80, 97, 116, 99, 104, 44,
  36, 68, 105, 108, 97, 116, 101, 95, 77, 105, 110, 95, 80, 97, 116, 99,
  104, 41, 125, 125, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 123, 49,
  46, 53, 42, 123, 109, 97, 120, 40, 36, 68, 105, 108, 97, 116, 101, 95,
  77, 97, 120, 95, 80, 97, 116, 99, 104, 44, 36, 68, 105, 108, 97, 116,
  101, 95, 77, 105, 110, 95, 80, 97, 116, 99, 104, 41, 125, 125, 41, 125,
  44, 49, 44, 49, 44, 48, 44, 50, 44, 48, 10, 45, 99, 111, 109, 112,
  111, 115, 101, 95, 97, 108, 112, 104, 97, 91, 45, 49, 44, 45, 50, 93,
  10, 45, 101, 108, 115, 101, 10, 45, 103, 105, 109, 112, 95, 98, 108, 117,
  114, 95, 114, 97, 100, 105, 97, 108, 91, 45, 49, 93, 32, 36, 66, 82,
  95, 65, 109, 112, 108, 105, 116, 117, 100, 101, 44, 36, 66, 82, 95, 88,
  95, 99, 101, 110, 116, 101, 114, 44, 36, 66, 82, 95, 89, 95, 99, 101,
  110, 116, 101, 114, 44, 36, 66, 82, 95, 83, 104, 97, 114, 112, 110, 101,
  115, 115, 44, 36, 66, 82, 95, 67, 104, 97, 110, 110, 101, 108, 115, 44,
  36, 66, 82, 95, 86, 97, 108, 117, 101, 95, 114, 97, 110, 103, 101, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101,
  110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 36, 98, 108, 101, 110, 100,
  44, 36, 111, 112, 97, 99, 105, 116, 101, 44, 36, 82, 101, 118, 101, 114,
  116, 95, 108, 97, 121, 101, 114, 115, 10, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 10, 115, 97, 109, 106, 95, 77, 97, 120, 95, 77, 105,
  110, 95, 80, 97, 116, 99, 104, 95, 48, 48, 49, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106,
  95, 77, 97, 120, 95, 77, 105, 110, 95, 80, 97, 116, 99, 104, 95, 48,
  48, 49, 32, 36, 42, 34, 44, 36, 45, 49, 10, 115, 97, 109, 106, 95,
  114, 105, 101, 110, 95, 112, 97, 116, 116, 101, 114, 110, 115, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103,
  91, 45, 49, 93, 10, 35, 64, 103, 105, 109, 112, 32, 84, 101, 115, 116,
  32, 98, 97, 108, 108, 101, 32, 51, 100, 32, 58, 32, 98, 97, 108, 108,
  101, 95, 51, 68, 95, 115, 97, 109, 106, 44, 32, 98, 97, 108, 108, 101,
  95, 51, 68, 95, 115, 97, 109, 106, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 66,
  97, 108, 108, 101, 32, 97, 118, 101, 99, 32, 115, 112, 104, 101, 114, 101,
  51, 100, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 80, 111, 115, 105, 116, 105, 111, 110, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 80, 111, 115, 105, 116, 105, 111, 110, 32, 120, 32, 40, 37, 41, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 111, 115, 105, 116,
  105, 111, 110, 32, 121, 32, 40, 37, 41, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 66, 97, 108, 108,
  101, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110, 32, 98,
  97, 108, 108, 101, 32, 61, 32, 105, 110, 116, 40, 51, 48, 48, 44, 49,
  48, 44, 54, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  66, 97, 108, 108, 101, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53,
  53, 44, 48, 44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 98, 32, 114, 101, 99, 117, 114, 115, 105, 111, 110, 115, 32, 61, 32,
  105, 110, 116, 40, 51, 44, 49, 44, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 82, 101, 110, 100, 117,
  32, 51, 68, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 79, 98, 106, 101, 99, 116, 32, 115, 105,
  122, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 45, 49, 44,
  51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 111, 118, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 53, 44, 49, 44, 57, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 108, 105, 103, 104,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 48, 44, 45, 49, 48,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  89, 45, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  45, 53, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 90, 45, 108, 105, 103, 104, 116, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 45, 49, 48, 48, 44, 45, 49, 48, 48,
  44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 101,
  99, 117, 108, 97, 114, 32, 108, 105, 103, 104, 116, 110, 101, 115, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 50, 48, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 101, 99, 117,
  108, 97, 114, 32, 115, 104, 105, 110, 105, 110, 101, 115, 115, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 54, 48, 44, 48, 44, 51, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 110, 100, 101, 114, 105,
  110, 103, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 52, 44, 34, 68,
  111, 116, 115, 34, 44, 34, 87, 105, 114, 101, 102, 114, 97, 109, 101, 34,
  44, 34, 70, 108, 97, 116, 34, 44, 34, 70, 108, 97, 116, 32, 115, 104,
  97, 100, 101, 100, 34, 44, 34, 71, 111, 117, 114, 97, 117, 100, 34, 44,
  34, 80, 104, 111, 110, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 66, 108, 101, 110, 100, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  49, 44, 34, 65, 100, 100, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44,
  34, 65, 110, 100, 34, 44, 34, 65, 118, 101, 114, 97, 103, 101, 34, 44,
  34, 66, 108, 117, 101, 34, 44, 34, 66, 117, 114, 110, 34, 44, 34, 68,
  97, 114, 107, 101, 110, 34, 44, 34, 68, 105, 102, 102, 101, 114, 101, 110,
  99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 68,
  105, 118, 105, 100, 101, 34, 44, 34, 68, 111, 100, 103, 101, 34, 44, 34,
  69, 120, 99, 108, 117, 115, 105, 111, 110, 34, 44, 34, 70, 114, 101, 101,
  122, 101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 101, 120, 116, 114, 97,
  99, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 109, 101, 114, 103, 101,
  34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 72, 97, 114, 100, 32,
  108, 105, 103, 104, 116, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44, 34, 72, 117, 101,
  34, 44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110,
  34, 44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44, 34, 76, 105, 103,
  104, 116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32,
  98, 117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 108, 105,
  103, 104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34,
  44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 77, 117, 108, 116,
  105, 112, 108, 121, 34, 44, 34, 78, 101, 103, 97, 116, 105, 111, 110, 34,
  44, 34, 79, 114, 34, 44, 34, 79, 118, 101, 114, 108, 97, 121, 34, 44,
  34, 80, 105, 110, 32, 108, 105, 103, 104, 116, 34, 44, 34, 82, 101, 100,
  34, 44, 34, 82, 101, 102, 108, 101, 99, 116, 34, 44, 34, 83, 97, 116,
  117, 114, 97, 116, 105, 111, 110, 34, 44, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103,
  101, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103,
  101, 48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117, 114, 110, 34, 44,
  34, 83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34, 44, 34, 83, 111,
  102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83, 99, 114, 101, 101,
  110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34, 83, 117, 98, 116,
  114, 97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 34, 86, 105, 118, 105, 100, 32, 108,
  105, 103, 104, 116, 34, 44, 34, 88, 111, 114, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121,
  101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 101, 117, 114, 115, 32, 47, 32, 65,
  117, 116, 104, 111, 114, 115, 32, 58, 32, 60, 105, 62, 83, 97, 109, 106,
  60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48,
  49, 52, 47, 48, 49, 47, 49, 55, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 98, 97, 108, 108, 101, 95, 51, 68,
  95, 115, 97, 109, 106, 32, 58, 10, 88, 95, 112, 111, 115, 105, 116, 105,
  111, 110, 61, 123, 114, 111, 117, 110, 100, 40, 123, 123, 123, 119, 125, 42,
  123, 36, 49, 47, 49, 48, 48, 125, 125, 45, 123, 36, 51, 47, 50, 125,
  125, 41, 125, 10, 89, 95, 112, 111, 115, 105, 116, 105, 111, 110, 61, 123,
  114, 111, 117, 110, 100, 40, 123, 123, 123, 104, 125, 42, 123, 36, 50, 47,
  49, 48, 48, 125, 125, 45, 123, 36, 51, 47, 50, 125, 125, 41, 125, 10,
  68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 98, 97, 108, 108, 101, 61,
  36, 51, 10, 82, 95, 66, 97, 108, 108, 101, 61, 36, 52, 10, 86, 95,
  66, 97, 108, 108, 101, 61, 36, 53, 10, 66, 95, 66, 97, 108, 108, 101,
  61, 36, 54, 10, 78, 98, 95, 82, 101, 99, 117, 114, 115, 105, 111, 110,
  115, 61, 36, 55, 10, 82, 51, 68, 95, 79, 98, 106, 101, 99, 116, 95,
  115, 105, 122, 101, 61, 36, 56, 10, 82, 51, 68, 95, 70, 79, 86, 61,
  36, 57, 10, 82, 51, 68, 95, 88, 95, 108, 105, 103, 104, 116, 61, 36,
  49, 48, 10, 82, 51, 68, 95, 89, 95, 108, 105, 103, 104, 116, 61, 36,
  49, 49, 10, 82, 51, 68, 95, 90, 95, 108, 105, 103, 104, 116, 61, 36,
  49, 50, 10, 82, 51, 68, 95, 83, 112, 101, 99, 117, 108, 97, 114, 95,
  108, 105, 103, 104, 116, 110, 101, 115, 115, 61, 36, 49, 51, 10, 82, 51,
  68, 95, 83, 112, 101, 99, 117, 108, 97, 114, 95, 115, 104, 105, 110, 105,
  110, 101, 115, 115, 61, 36, 49, 52, 10, 82, 51, 68, 95, 82, 101, 110,
  100, 101, 114, 105, 110, 103, 95, 109, 111, 100, 101, 61, 36, 49, 53, 10,
  98, 108, 101, 110, 100, 61, 36, 49, 54, 10, 111, 112, 97, 99, 105, 116,
  101, 61, 36, 49, 55, 10, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121,
  101, 114, 115, 61, 36, 49, 56, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 123, 119, 125, 44, 123, 104,
  125, 44, 49, 44, 52, 10, 45, 115, 112, 104, 101, 114, 101, 51, 100, 32,
  36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 98, 97, 108, 108, 101,
  44, 36, 78, 98, 95, 82, 101, 99, 117, 114, 115, 105, 111, 110, 115, 10,
  45, 99, 111, 108, 111, 114, 51, 100, 91, 45, 49, 93, 32, 36, 82, 95,
  66, 97, 108, 108, 101, 44, 36, 86, 95, 66, 97, 108, 108, 101, 44, 36,
  66, 95, 66, 97, 108, 108, 101, 10, 45, 103, 105, 109, 112, 95, 114, 101,
  110, 100, 101, 114, 51, 100, 91, 45, 49, 93, 32, 123, 36, 68, 105, 109,
  101, 110, 115, 105, 111, 110, 95, 98, 97, 108, 108, 101, 42, 54, 125, 44,
  123, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 98, 97, 108, 108,
  101, 42, 54, 125, 44, 36, 82, 51, 68, 95, 79, 98, 106, 101, 99, 116,
  95, 115, 105, 122, 101, 44, 48, 44, 48, 44, 48, 44, 36, 82, 51, 68,
  95, 70, 79, 86, 44, 36, 82, 51, 68, 95, 88, 95, 108, 105, 103, 104,
  116, 44, 36, 82, 51, 68, 95, 89, 95, 108, 105, 103, 104, 116, 44, 36,
  82, 51, 68, 95, 90, 95, 108, 105, 103, 104, 116, 44, 36, 82, 51, 68,
  95, 83, 112, 101, 99, 117, 108, 97, 114, 95, 108, 105, 103, 104, 116, 110,
  101, 115, 115, 44, 36, 82, 51, 68, 95, 83, 112, 101, 99, 117, 108, 97,
  114, 95, 115, 104, 105, 110, 105, 110, 101, 115, 115, 44, 36, 82, 51, 68,
  95, 82, 101, 110, 100, 101, 114, 105, 110, 103, 95, 109, 111, 100, 101, 10,
  45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 116, 111,
  95, 114, 103, 98, 97, 91, 45, 49, 93, 10, 45, 114, 101, 115, 105, 122,
  101, 91, 45, 49, 93, 32, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110,
  95, 98, 97, 108, 108, 101, 44, 36, 68, 105, 109, 101, 110, 115, 105, 111,
  110, 95, 98, 97, 108, 108, 101, 44, 49, 44, 51, 10, 45, 105, 102, 32,
  123, 105, 109, 60, 48, 125, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 32, 45, 101, 108, 105, 102, 32, 123, 105, 77, 62, 50, 53,
  53, 125, 32, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 50, 93, 10, 45,
  103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50,
  93, 32, 36, 98, 108, 101, 110, 100, 44, 36, 111, 112, 97, 99, 105, 116,
  101, 44, 36, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103,
  105, 109, 112, 32, 84, 101, 115, 116, 32, 102, 111, 110, 99, 116, 105, 111,
  110, 32, 98, 97, 108, 108, 101, 32, 58, 32, 116, 101, 115, 116, 95, 98,
  97, 108, 108, 101, 95, 115, 97, 109, 106, 44, 32, 116, 101, 115, 116, 95,
  98, 97, 108, 108, 101, 95, 115, 97, 109, 106, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 84, 69, 83, 84, 32, 100, 101, 32, 108, 97, 32, 102,
  111, 110, 99, 116, 105, 111, 110, 32, 45, 98, 97, 108, 108, 95, 109, 111,
  100, 105, 102, 105, 99, 97, 116, 105, 111, 110, 95, 115, 97, 109, 106, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 80, 111, 115, 105, 116, 105, 111, 110, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 111,
  115, 105, 116, 105, 111, 110, 32, 120, 32, 40, 37, 41, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 80, 111, 115, 105, 116, 105, 111, 110,
  32, 121, 32, 40, 37, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53,
  48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 66, 97, 108, 108, 101, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110, 32, 98, 97, 108, 108,
  101, 32, 61, 32, 105, 110, 116, 40, 51, 48, 48, 44, 49, 48, 44, 50,
  48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 97,
  108, 108, 101, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44,
  49, 50, 56, 44, 54, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 88, 32, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 51, 48, 44, 48, 46, 50, 48, 44, 48, 46, 56, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 32, 108, 105, 103, 104,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 48, 44, 48,
  46, 50, 48, 44, 48, 46, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 88, 32, 114, 97, 100, 105, 117, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 49, 50, 44, 48, 46, 48, 49, 44, 48, 46,
  50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 32, 114,
  97, 100, 105, 117, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  49, 50, 44, 48, 46, 48, 49, 44, 48, 46, 50, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 76, 105, 103, 104, 116, 32, 61, 32, 99,
  111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 51, 52, 44, 50, 50, 52,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 78, 111, 114, 109, 97, 108, 105, 115, 97, 116, 105, 111, 110, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 32, 109, 105, 110, 46, 32, 61, 32, 105, 110, 116, 40,
  48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 32, 109, 97, 120, 46, 32, 61, 32, 105, 110, 116, 40, 50,
  53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 82, 111, 116, 97, 116, 105,
  111, 110, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 114, 111, 116, 97,
  116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 48,
  48, 44, 48, 46, 48, 48, 44, 51, 54, 48, 46, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 66, 111, 117, 110, 100, 97, 114, 121,
  32, 114, 111, 116, 97, 116, 105, 111, 110, 32, 61, 32, 105, 110, 116, 40,
  48, 44, 48, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 70, 111, 110, 100, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  101, 109, 112, 108, 105, 114, 32, 99, 111, 117, 108, 101, 117, 114, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 70, 111, 110, 100, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 68, 105, 118, 101,
  114, 115, 32, 47, 32, 70, 111, 111, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 108, 111, 117,
  32, 47, 32, 98, 108, 117, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 112, 114, 101, 97, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 68, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 69, 112, 97, 105, 115, 115, 101, 117, 114, 32,
  47, 32, 116, 104, 105, 99, 107, 110, 101, 115, 115, 32, 61, 32, 105, 110,
  116, 40, 48, 44, 48, 44, 54, 52, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 66, 108, 101, 110, 100, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 49, 44, 34, 65, 100, 100, 34, 44, 34, 65, 108, 112, 104, 97, 34,
  44, 34, 65, 110, 100, 34, 44, 34, 65, 118, 101, 114, 97, 103, 101, 34,
  44, 34, 66, 108, 117, 101, 34, 44, 34, 66, 117, 114, 110, 34, 44, 34,
  68, 97, 114, 107, 101, 110, 34, 44, 34, 68, 105, 102, 102, 101, 114, 101,
  110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34,
  68, 105, 118, 105, 100, 101, 34, 44, 34, 68, 111, 100, 103, 101, 34, 44,
  34, 69, 120, 99, 108, 117, 115, 105, 111, 110, 34, 44, 34, 70, 114, 101,
  101, 122, 101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 101, 120, 116, 114,
  97, 99, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 109, 101, 114, 103,
  101, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 72, 97, 114, 100,
  32, 108, 105, 103, 104, 116, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44, 34, 72, 117,
  101, 34, 44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111,
  110, 34, 44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44, 34, 76, 105,
  103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110, 101, 97, 114,
  32, 98, 117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 108,
  105, 103, 104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101,
  34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 77, 117, 108,
  116, 105, 112, 108, 121, 34, 44, 34, 78, 101, 103, 97, 116, 105, 111, 110,
  34, 44, 34, 79, 114, 34, 44, 34, 79, 118, 101, 114, 108, 97, 121, 34,
  44, 34, 80, 105, 110, 32, 108, 105, 103, 104, 116, 34, 44, 34, 82, 101,
  100, 34, 44, 34, 82, 101, 102, 108, 101, 99, 116, 34, 44, 34, 83, 97,
  116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97,
  103, 101, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97,
  103, 101, 48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117, 114, 110, 34,
  44, 34, 83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34, 44, 34, 83,
  111, 102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83, 99, 114, 101,
  101, 110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34, 83, 117, 98,
  116, 114, 97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 86, 105, 118, 105, 100, 32,
  108, 105, 103, 104, 116, 34, 44, 34, 88, 111, 114, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97,
  121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111,
  114, 32, 58, 32, 60, 105, 62, 83, 97, 109, 106, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49,
  47, 49, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 116, 101, 115, 116, 95, 98, 97, 108, 108, 101, 95, 115, 97,
  109, 106, 58, 10, 35, 35, 32, 118, 97, 114, 105, 97, 98, 108, 101, 115,
  10, 88, 95, 112, 111, 115, 105, 116, 105, 111, 110, 61, 123, 114, 111, 117,
  110, 100, 40, 123, 123, 123, 119, 125, 42, 123, 36, 49, 47, 49, 48, 48,
  125, 125, 45, 123, 36, 51, 47, 50, 125, 125, 41, 125, 10, 89, 95, 112,
  111, 115, 105, 116, 105, 111, 110, 61, 123, 114, 111, 117, 110, 100, 40, 123,
  123, 123, 104, 125, 42, 123, 36, 50, 47, 49, 48, 48, 125, 125, 45, 123,
  36, 51, 47, 50, 125, 125, 41, 125, 10, 68, 105, 109, 101, 110, 115, 105,
  111, 110, 95, 98, 97, 108, 108, 101, 61, 36, 51, 10, 82, 95, 66, 97,
  108, 108, 101, 61, 36, 52, 10, 86, 95, 66, 97, 108, 108, 101, 61, 36,
  53, 10, 66, 95, 66, 97, 108, 108, 101, 61, 36, 54, 10, 88, 95, 108,
  105, 103, 104, 116, 61, 36, 55, 10, 89, 95, 108, 105, 103, 104, 116, 61,
  36, 56, 10, 88, 95, 114, 97, 100, 105, 117, 115, 61, 36, 57, 10, 89,
  95, 114, 97, 100, 105, 117, 115, 61, 36, 49, 48, 10, 82, 95, 108, 105,
  103, 104, 116, 61, 36, 49, 49, 10, 71, 95, 108, 105, 103, 104, 116, 61,
  36, 49, 50, 10, 66, 95, 108, 105, 103, 104, 116, 61, 36, 49, 51, 10,
  78, 95, 109, 105, 110, 61, 36, 49, 52, 10, 78, 95, 109, 97, 120, 61,
  36, 49, 53, 10, 65, 110, 103, 108, 101, 95, 114, 111, 116, 97, 116, 105,
  111, 110, 61, 36, 49, 54, 10, 66, 111, 117, 110, 100, 97, 114, 121, 95,
  114, 111, 116, 97, 116, 105, 111, 110, 61, 36, 49, 55, 10, 82, 101, 109,
  112, 108, 105, 114, 95, 70, 111, 110, 100, 61, 36, 49, 56, 10, 82, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 70, 111, 110, 100, 61, 36, 49, 57,
  10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 70, 111, 110, 100, 61,
  36, 50, 48, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 70, 111,
  110, 100, 61, 36, 50, 49, 10, 35, 32, 86, 97, 114, 105, 97, 98, 108,
  101, 115, 32, 100, 105, 118, 101, 114, 115, 10, 70, 108, 111, 117, 95, 98,
  97, 108, 108, 101, 61, 36, 50, 50, 10, 83, 112, 114, 101, 97, 100, 95,
  98, 97, 108, 108, 101, 61, 36, 50, 51, 10, 68, 101, 102, 111, 114, 109,
  95, 98, 97, 108, 108, 101, 61, 36, 50, 52, 10, 69, 112, 97, 105, 115,
  115, 101, 117, 114, 61, 36, 50, 53, 10, 98, 108, 101, 110, 100, 61, 36,
  50, 54, 10, 111, 112, 97, 99, 105, 116, 101, 61, 36, 50, 55, 10, 82,
  101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 61, 36, 50, 56,
  10, 45, 116, 111, 95, 114, 103, 98, 97, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 123, 119, 125, 44,
  123, 104, 125, 44, 49, 44, 52, 10, 45, 45, 103, 105, 109, 112, 95, 100,
  111, 95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 36, 68,
  105, 109, 101, 110, 115, 105, 111, 110, 95, 98, 97, 108, 108, 101, 44, 36,
  68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 98, 97, 108, 108, 101, 44,
  49, 44, 52, 10, 45, 105, 102, 32, 123, 36, 82, 101, 109, 112, 108, 105,
  114, 95, 70, 111, 110, 100, 62, 48, 125, 10, 45, 102, 105, 108, 108, 95,
  99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 36, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 70, 111, 110, 100, 44, 36, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 70, 111, 110, 100, 44, 36, 66, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 70, 111, 110, 100, 44, 50, 53, 53, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 98, 97, 108, 108, 95, 109, 111, 100, 105, 102,
  105, 99, 97, 116, 105, 111, 110, 95, 115, 97, 109, 106, 91, 45, 49, 93,
  32, 36, 82, 95, 66, 97, 108, 108, 101, 44, 36, 86, 95, 66, 97, 108,
  108, 101, 44, 36, 66, 95, 66, 97, 108, 108, 101, 44, 36, 88, 95, 108,
  105, 103, 104, 116, 44, 36, 89, 95, 108, 105, 103, 104, 116, 44, 36, 88,
  95, 114, 97, 100, 105, 117, 115, 44, 36, 89, 95, 114, 97, 100, 105, 117,
  115, 44, 36, 82, 95, 108, 105, 103, 104, 116, 44, 36, 71, 95, 108, 105,
  103, 104, 116, 44, 36, 66, 95, 108, 105, 103, 104, 116, 10, 45, 110, 91,
  45, 49, 93, 32, 36, 78, 95, 109, 105, 110, 44, 36, 78, 95, 109, 97,
  120, 10, 45, 105, 102, 32, 123, 36, 65, 110, 103, 108, 101, 95, 114, 111,
  116, 97, 116, 105, 111, 110, 62, 48, 125, 10, 45, 114, 111, 116, 97, 116,
  101, 91, 45, 49, 93, 32, 36, 65, 110, 103, 108, 101, 95, 114, 111, 116,
  97, 116, 105, 111, 110, 44, 36, 66, 111, 117, 110, 100, 97, 114, 121, 95,
  114, 111, 116, 97, 116, 105, 111, 110, 44, 50, 44, 123, 123, 119, 125, 47,
  50, 125, 44, 123, 123, 104, 125, 47, 50, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 109, 97, 103, 101, 91, 45, 50, 93, 32, 91, 45, 49,
  93, 44, 36, 88, 95, 112, 111, 115, 105, 116, 105, 111, 110, 44, 36, 89,
  95, 112, 111, 115, 105, 116, 105, 111, 110, 10, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 97, 108, 112, 104, 97,
  91, 45, 50, 44, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 69, 112,
  97, 105, 115, 115, 101, 117, 114, 62, 48, 125, 10, 45, 100, 105, 108, 97,
  116, 101, 95, 99, 105, 114, 99, 91, 45, 49, 93, 32, 36, 69, 112, 97,
  105, 115, 115, 101, 117, 114, 10, 45, 101, 110, 100, 105, 102, 10, 45, 98,
  108, 117, 114, 91, 45, 49, 93, 32, 36, 70, 108, 111, 117, 95, 98, 97,
  108, 108, 101, 10, 45, 115, 112, 114, 101, 97, 100, 91, 45, 49, 93, 32,
  36, 83, 112, 114, 101, 97, 100, 95, 98, 97, 108, 108, 101, 10, 45, 100,
  101, 102, 111, 114, 109, 91, 45, 49, 93, 32, 36, 68, 101, 102, 111, 114,
  109, 95, 98, 97, 108, 108, 101, 10, 45, 103, 105, 109, 112, 95, 98, 108,
  101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 36, 98, 108, 101, 110,
  100, 44, 36, 111, 112, 97, 99, 105, 116, 101, 44, 36, 82, 101, 118, 101,
  114, 116, 95, 108, 97, 121, 101, 114, 115, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 95, 10, 35,
  64, 103, 105, 109, 112, 32, 60, 105, 62, 80, 97, 116, 116, 101, 114, 110,
  115, 60, 47, 105, 62, 10, 35, 64, 103, 105, 109, 112, 32, 67, 111, 117,
  114, 116, 101, 112, 111, 105, 110, 116, 101, 32, 58, 32, 115, 97, 109, 106,
  95, 67, 111, 117, 114, 116, 101, 112, 111, 105, 110, 116, 101, 44, 32, 115,
  97, 109, 106, 95, 67, 111, 117, 114, 116, 101, 112, 111, 105, 110, 116, 101,
  95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 115, 115, 105, 110, 32, 61, 32, 105, 110, 116, 40, 50, 48, 44,
  49, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 115, 115, 105, 110, 32, 50, 32, 61, 32, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 112, 101,
  116, 105, 116, 105, 111, 110, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49,
  44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 114, 111,
  105, 120, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 84, 101, 120, 116, 117, 114, 101, 32, 61, 32,
  98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48,
  49, 52, 47, 48, 49, 47, 48, 54, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 67, 111, 117,
  114, 116, 101, 112, 111, 105, 110, 116, 101, 32, 58, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 67, 111,
  115, 115, 105, 110, 61, 36, 49, 10, 67, 111, 115, 115, 105, 110, 95, 68,
  101, 117, 120, 61, 36, 50, 10, 82, 101, 112, 101, 116, 105, 116, 105, 111,
  110, 61, 36, 51, 10, 67, 114, 111, 105, 120, 61, 36, 52, 10, 84, 101,
  120, 116, 117, 114, 101, 61, 36, 53, 10, 45, 114, 111, 114, 115, 99, 104,
  97, 99, 104, 91, 45, 49, 93, 32, 123, 36, 67, 111, 115, 115, 105, 110,
  125, 37, 44, 49, 10, 45, 105, 102, 32, 123, 36, 67, 111, 115, 115, 105,
  110, 95, 68, 101, 117, 120, 61, 61, 49, 125, 10, 45, 110, 91, 45, 49,
  93, 32, 54, 52, 44, 49, 57, 50, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 36, 82, 101, 112, 101, 116, 105, 116, 105, 111, 110,
  10, 45, 103, 105, 109, 112, 95, 97, 114, 114, 97, 121, 95, 109, 105, 114,
  114, 111, 114, 91, 45, 49, 93, 32, 49, 44, 48, 44, 48, 44, 50, 44,
  48, 44, 48, 10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36,
  67, 114, 111, 105, 120, 61, 61, 49, 125, 10, 45, 103, 105, 109, 112, 95,
  115, 121, 109, 109, 101, 116, 114, 105, 122, 111, 115, 99, 111, 112, 101, 91,
  45, 49, 93, 32, 53, 44, 48, 44, 49, 44, 48, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 84, 101, 120, 116, 117, 114, 101,
  61, 61, 49, 125, 10, 45, 115, 97, 109, 106, 95, 103, 105, 109, 112, 95,
  116, 101, 120, 116, 117, 114, 101, 95, 122, 101, 114, 111, 95, 122, 101, 114,
  111, 95, 117, 110, 91, 45, 49, 93, 32, 48, 46, 53, 44, 50, 48, 44,
  56, 48, 44, 48, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115, 97, 109, 106, 95, 67,
  111, 117, 114, 116, 101, 112, 111, 105, 110, 116, 101, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106,
  95, 67, 111, 117, 114, 116, 101, 112, 111, 105, 110, 116, 101, 32, 36, 42,
  34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 68, 101, 110,
  105, 109, 32, 116, 101, 120, 116, 117, 114, 101, 32, 58, 32, 68, 101, 110,
  105, 109, 95, 115, 97, 109, 106, 44, 32, 68, 101, 110, 105, 109, 95, 115,
  97, 109, 106, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100,
  61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109,
  97, 108, 108, 62, 84, 101, 120, 116, 117, 114, 101, 60, 47, 115, 109, 97,
  108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110, 32,
  109, 111, 116, 105, 102, 32, 98, 97, 115, 101, 32, 61, 32, 105, 110, 116,
  40, 53, 44, 50, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 68, 105, 108, 97, 116, 97, 116, 105, 111, 110, 32, 109, 111, 116,
  105, 102, 32, 61, 32, 105, 110, 116, 40, 50, 44, 48, 44, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 116, 111, 117, 114, 110,
  101, 114, 32, 109, 111, 116, 105, 102, 32, 61, 32, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 92, 51, 48,
  51, 92, 50, 53, 49, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 49,
  32, 61, 32, 105, 110, 116, 40, 52, 48, 44, 48, 44, 50, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 92, 51, 48, 51, 92,
  50, 53, 49, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 50, 32, 61,
  32, 105, 110, 116, 40, 52, 48, 44, 48, 44, 50, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 110, 105, 109, 32, 91, 98,
  114, 117, 105, 116, 93, 32, 61, 32, 105, 110, 116, 40, 50, 53, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 85,
  115, 117, 114, 101, 32, 91, 98, 114, 117, 105, 116, 93, 32, 61, 32, 105,
  110, 116, 40, 53, 48, 44, 48, 44, 52, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 101, 116, 116, 101, 116, 92, 51, 48, 51,
  92, 50, 53, 49, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 53, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61,
  34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97,
  108, 108, 62, 67, 111, 117, 108, 101, 117, 114, 115, 60, 47, 115, 109, 97,
  108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 100, 101,
  110, 105, 109, 32, 61, 32, 99, 111, 108, 111, 114, 40, 52, 51, 44, 49,
  48, 56, 44, 49, 50, 54, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 117, 115, 117,
  114, 101, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103,
  114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100,
  34, 62, 60, 115, 109, 97, 108, 108, 62, 77, 111, 100, 101, 32, 100, 101,
  32, 115, 111, 114, 116, 105, 101, 60, 47, 115, 109, 97, 108, 108, 62, 60,
  47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 114, 92, 51, 48, 51, 92, 50, 53, 49, 101, 114, 32, 117,
  110, 32, 110, 111, 117, 118, 101, 97, 117, 32, 99, 97, 108, 113, 117, 101,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 101, 117, 114, 115, 32, 32, 58, 32, 60, 105, 62,
  83, 97, 109, 106, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 86,
  101, 114, 115, 105, 111, 110, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52,
  47, 48, 49, 47, 49, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 68, 101, 110, 105, 109, 95, 115, 97, 109, 106,
  32, 58, 10, 68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 77, 111, 116,
  105, 102, 61, 36, 49, 10, 68, 105, 108, 97, 116, 97, 116, 105, 111, 110,
  61, 36, 50, 10, 82, 101, 116, 111, 117, 114, 110, 101, 114, 95, 109, 111,
  116, 105, 102, 61, 36, 51, 10, 68, 101, 102, 111, 114, 109, 97, 116, 105,
  111, 110, 95, 49, 61, 36, 52, 10, 68, 101, 102, 111, 114, 109, 97, 116,
  105, 111, 110, 95, 50, 61, 36, 53, 10, 65, 109, 112, 108, 105, 116, 117,
  100, 101, 95, 66, 114, 117, 105, 116, 61, 36, 54, 10, 65, 109, 112, 108,
  105, 116, 117, 100, 101, 95, 66, 114, 117, 105, 116, 95, 50, 61, 36, 55,
  10, 78, 101, 116, 116, 101, 116, 101, 61, 36, 56, 10, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 68, 101, 110, 105, 109, 61, 36, 57, 10, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 68, 101, 110, 105, 109, 61, 36,
  49, 48, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 68, 101, 110,
  105, 109, 61, 36, 49, 49, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 68, 101, 110, 105, 109, 61, 36, 49, 50, 10, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 85, 115, 117, 114, 101, 61, 36, 49, 51, 10, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 85, 115, 117, 114, 101, 61, 36,
  49, 52, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 85, 115, 117,
  114, 101, 61, 36, 49, 53, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 85, 115, 117, 114, 101, 61, 36, 49, 54, 10, 67, 114, 101, 101, 114,
  95, 117, 110, 95, 110, 111, 117, 118, 101, 97, 117, 95, 99, 97, 108, 113,
  117, 101, 61, 36, 49, 55, 10, 76, 97, 114, 103, 101, 117, 114, 61, 123,
  119, 125, 10, 72, 97, 117, 116, 101, 117, 114, 61, 123, 104, 125, 10, 36,
  76, 97, 114, 103, 101, 117, 114, 44, 36, 72, 97, 117, 116, 101, 117, 114,
  44, 49, 44, 52, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114,
  91, 45, 49, 93, 32, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  68, 101, 110, 105, 109, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 68, 101, 110, 105, 109, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 68, 101, 110, 105, 109, 44, 36, 65, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 68, 101, 110, 105, 109, 10, 45, 116, 111, 95, 114, 103, 98,
  97, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 110, 111, 105, 115,
  101, 91, 45, 49, 93, 32, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  95, 66, 114, 117, 105, 116, 44, 48, 44, 55, 44, 48, 10, 36, 68, 105,
  109, 101, 110, 115, 105, 111, 110, 95, 77, 111, 116, 105, 102, 44, 36, 68,
  105, 109, 101, 110, 115, 105, 111, 110, 95, 77, 111, 116, 105, 102, 44, 49,
  44, 52, 10, 45, 105, 102, 32, 123, 36, 82, 101, 116, 111, 117, 114, 110,
  101, 114, 95, 109, 111, 116, 105, 102, 61, 61, 48, 125, 10, 45, 108, 105,
  110, 101, 91, 45, 49, 93, 32, 48, 44, 36, 68, 105, 109, 101, 110, 115,
  105, 111, 110, 95, 77, 111, 116, 105, 102, 44, 36, 68, 105, 109, 101, 110,
  115, 105, 111, 110, 95, 77, 111, 116, 105, 102, 44, 48, 44, 49, 44, 48,
  44, 48, 44, 48, 44, 50, 53, 53, 10, 45, 101, 108, 115, 101, 10, 45,
  108, 105, 110, 101, 91, 45, 49, 93, 32, 48, 44, 48, 44, 36, 68, 105,
  109, 101, 110, 115, 105, 111, 110, 95, 77, 111, 116, 105, 102, 44, 36, 68,
  105, 109, 101, 110, 115, 105, 111, 110, 95, 77, 111, 116, 105, 102, 44, 49,
  44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 49, 48, 48, 37, 44, 48,
  44, 50, 10, 45, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 91,
  45, 49, 93, 32, 36, 68, 105, 108, 97, 116, 97, 116, 105, 111, 110, 10,
  35, 97, 108, 112, 104, 97, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101,
  110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 49, 44, 49, 44, 49, 10,
  45, 119, 97, 116, 101, 114, 91, 45, 49, 93, 32, 123, 36, 68, 101, 102,
  111, 114, 109, 97, 116, 105, 111, 110, 95, 49, 47, 49, 48, 48, 48, 125,
  44, 123, 36, 68, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 95, 50,
  47, 49, 48, 48, 125, 10, 45, 103, 105, 109, 112, 95, 110, 111, 105, 115,
  101, 91, 45, 49, 93, 32, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  95, 66, 114, 117, 105, 116, 95, 50, 44, 48, 44, 50, 50, 44, 48, 10,
  36, 76, 97, 114, 103, 101, 117, 114, 44, 36, 72, 97, 117, 116, 101, 117,
  114, 44, 49, 44, 52, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111,
  114, 91, 45, 49, 93, 32, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 85, 115, 117, 114, 101, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 85, 115, 117, 114, 101, 44, 36, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 85, 115, 117, 114, 101, 44, 36, 65, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 85, 115, 117, 114, 101, 10, 35, 97, 108, 112, 104, 97,
  10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44,
  45, 50, 93, 32, 49, 44, 49, 44, 48, 10, 45, 115, 104, 97, 114, 112,
  101, 110, 91, 45, 49, 93, 32, 36, 78, 101, 116, 116, 101, 116, 101, 10,
  45, 114, 101, 118, 101, 114, 115, 101, 91, 45, 50, 44, 45, 49, 93, 10,
  45, 105, 102, 32, 123, 36, 67, 114, 101, 101, 114, 95, 117, 110, 95, 110,
  111, 117, 118, 101, 97, 117, 95, 99, 97, 108, 113, 117, 101, 61, 61, 48,
  125, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102,
  10, 35, 64, 103, 105, 109, 112, 32, 82, 101, 109, 112, 108, 105, 114, 32,
  101, 116, 111, 105, 108, 101, 115, 32, 58, 32, 82, 101, 109, 112, 108, 105,
  114, 95, 69, 116, 111, 105, 108, 101, 115, 95, 115, 97, 109, 106, 44, 32,
  82, 101, 109, 112, 108, 105, 114, 95, 69, 116, 111, 105, 108, 101, 115, 95,
  115, 97, 109, 106, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 92, 51, 48, 51, 92, 50, 53, 49,
  116, 111, 105, 108, 101, 115, 32, 47, 32, 115, 116, 97, 114, 115, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 109, 98, 114, 101, 32, 61, 32, 105, 110, 116, 40, 50,
  53, 44, 49, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 109, 98, 114, 101, 32, 100, 101, 32, 115, 111, 109, 109,
  101, 116, 115, 32, 47, 32, 98, 114, 97, 110, 99, 104, 101, 115, 32, 109,
  105, 110, 46, 32, 61, 32, 105, 110, 116, 40, 53, 44, 50, 44, 55, 50,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 109, 98,
  114, 101, 32, 100, 101, 32, 115, 111, 109, 109, 101, 116, 115, 32, 47, 32,
  98, 114, 97, 110, 99, 104, 101, 115, 32, 109, 97, 120, 46, 32, 61, 32,
  105, 110, 116, 40, 56, 44, 50, 44, 55, 50, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 82, 97, 121, 111, 110, 32, 99, 101, 114, 99,
  108, 101, 32, 101, 120, 116, 92, 51, 48, 51, 92, 50, 53, 49, 114, 105,
  101, 117, 114, 32, 47, 32, 111, 117, 116, 101, 114, 32, 99, 105, 114, 99,
  108, 101, 32, 114, 97, 100, 105, 117, 115, 32, 109, 105, 110, 46, 32, 61,
  32, 105, 110, 116, 40, 52, 48, 44, 49, 54, 44, 50, 48, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 121, 111, 110, 32,
  99, 101, 114, 99, 108, 101, 32, 101, 120, 116, 92, 51, 48, 51, 92, 50,
  53, 49, 114, 105, 101, 117, 114, 32, 47, 32, 111, 117, 116, 101, 114, 32,
  99, 105, 114, 99, 108, 101, 32, 114, 97, 100, 105, 117, 115, 32, 109, 97,
  120, 46, 32, 61, 32, 105, 110, 116, 40, 49, 48, 48, 44, 49, 54, 44,
  50, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  97, 121, 111, 110, 32, 99, 101, 114, 99, 108, 101, 32, 105, 110, 116, 92,
  51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32, 47, 32, 105,
  110, 110, 101, 114, 32, 99, 105, 114, 99, 108, 101, 32, 114, 97, 100, 105,
  117, 115, 32, 40, 37, 41, 32, 109, 105, 110, 46, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 50, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 97, 121, 111, 110, 32, 99, 101, 114,
  99, 108, 101, 32, 105, 110, 116, 92, 51, 48, 51, 92, 50, 53, 49, 114,
  105, 101, 117, 114, 32, 47, 32, 105, 110, 110, 101, 114, 32, 99, 105, 114,
  99, 108, 101, 32, 114, 97, 100, 105, 117, 115, 32, 40, 37, 41, 32, 109,
  97, 120, 46, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 57, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69,
  120, 99, 101, 110, 116, 114, 105, 99, 105, 116, 92, 51, 48, 51, 92, 50,
  53, 49, 32, 47, 32, 101, 99, 99, 101, 110, 116, 114, 105, 99, 105, 116,
  121, 32, 40, 37, 41, 32, 109, 105, 110, 46, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 69, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116,
  92, 51, 48, 51, 92, 50, 53, 49, 32, 47, 32, 101, 99, 99, 101, 110,
  116, 114, 105, 99, 105, 116, 121, 32, 40, 37, 41, 32, 109, 97, 120, 46,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 50, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108,
  101, 32, 101, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116, 92, 51, 48,
  51, 92, 50, 53, 49, 32, 47, 32, 101, 99, 99, 101, 110, 116, 114, 105,
  99, 105, 116, 121, 32, 97, 110, 103, 108, 101, 32, 109, 105, 110, 46, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 51, 54, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32,
  101, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116, 92, 51, 48, 51, 92,
  50, 53, 49, 32, 47, 32, 101, 99, 99, 101, 110, 116, 114, 105, 99, 105,
  116, 121, 32, 97, 110, 103, 108, 101, 32, 109, 97, 120, 46, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 51, 54, 48, 44, 48, 44, 51, 54, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101, 117,
  114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53,
  53, 44, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 66, 114, 97, 110, 99, 104, 101, 115, 32, 58, 32, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 32, 100, 101, 32, 99, 111, 117, 108, 101, 117,
  114, 32, 47, 32, 99, 111, 108, 111, 114, 32, 118, 97, 114, 105, 97, 116,
  105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 80, 97,
  115, 32, 100, 101, 32, 118, 97, 114, 105, 97, 116, 105, 111, 110, 32, 47,
  32, 78, 111, 32, 99, 104, 97, 110, 103, 101, 34, 44, 34, 67, 111, 117,
  108, 101, 117, 114, 115, 32, 97, 108, 101, 97, 116, 111, 105, 114, 101, 115,
  32, 47, 32, 82, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111, 114, 115,
  34, 44, 34, 70, 97, 105, 98, 108, 101, 109, 101, 110, 116, 32, 110, 117,
  97, 110, 99, 101, 101, 32, 47, 32, 80, 111, 111, 114, 108, 121, 32, 110,
  117, 97, 110, 99, 101, 100, 34, 44, 34, 77, 111, 121, 101, 110, 110, 101,
  109, 101, 110, 116, 32, 110, 117, 97, 110, 99, 101, 101, 32, 47, 32, 77,
  111, 100, 101, 114, 97, 116, 101, 108, 121, 32, 110, 117, 97, 110, 99, 101,
  100, 34, 44, 34, 70, 111, 114, 116, 101, 109, 101, 110, 116, 32, 110, 117,
  97, 110, 99, 101, 101, 32, 47, 32, 72, 105, 103, 104, 108, 121, 32, 110,
  117, 97, 110, 99, 101, 100, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 116, 97, 114, 115, 32, 58, 32, 99, 111, 117, 108, 101, 117,
  114, 115, 32, 97, 108, 92, 51, 48, 51, 92, 50, 53, 49, 97, 116, 111,
  105, 114, 101, 115, 32, 47, 32, 114, 97, 110, 100, 111, 109, 32, 99, 111,
  108, 111, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108, 115,
  101, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 68, 105, 118, 101, 114, 115, 32, 47, 32, 70, 111, 111, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 70, 108, 111, 117, 32, 47, 32, 98, 108, 117, 114, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 114, 101, 97, 100, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 102, 111, 114, 109, 97, 116,
  105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 112, 97,
  105, 115, 115, 101, 117, 114, 32, 47, 32, 116, 104, 105, 99, 107, 110, 101,
  115, 115, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 54, 52, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 66, 108, 101, 110, 100, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 100, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 65, 100, 100, 34, 44,
  34, 65, 108, 112, 104, 97, 34, 44, 34, 65, 110, 100, 34, 44, 34, 65,
  118, 101, 114, 97, 103, 101, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34,
  66, 117, 114, 110, 34, 44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34,
  68, 105, 102, 102, 101, 114, 101, 110, 99, 101, 34, 44, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 34, 68, 105, 118, 105, 100, 101, 34, 44, 34,
  68, 111, 100, 103, 101, 34, 44, 34, 69, 120, 99, 108, 117, 115, 105, 111,
  110, 34, 44, 34, 70, 114, 101, 101, 122, 101, 34, 44, 34, 71, 114, 97,
  105, 110, 32, 101, 120, 116, 114, 97, 99, 116, 34, 44, 34, 71, 114, 97,
  105, 110, 32, 109, 101, 114, 103, 101, 34, 44, 34, 71, 114, 101, 101, 110,
  34, 44, 34, 72, 97, 114, 100, 32, 108, 105, 103, 104, 116, 34, 44, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 72, 97, 114, 100, 32, 109,
  105, 120, 34, 44, 34, 72, 117, 101, 34, 44, 34, 73, 110, 116, 101, 114,
  112, 111, 108, 97, 116, 105, 111, 110, 34, 44, 34, 76, 105, 103, 104, 116,
  101, 110, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44,
  34, 76, 105, 110, 101, 97, 114, 32, 98, 117, 114, 110, 34, 44, 34, 76,
  105, 110, 101, 97, 114, 32, 108, 105, 103, 104, 116, 34, 44, 34, 76, 117,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 34, 77, 117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 78,
  101, 103, 97, 116, 105, 111, 110, 34, 44, 34, 79, 114, 34, 44, 34, 79,
  118, 101, 114, 108, 97, 121, 34, 44, 34, 80, 105, 110, 32, 108, 105, 103,
  104, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 82, 101, 102, 108, 101,
  99, 116, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34,
  44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 83, 104, 97, 112,
  101, 32, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 83, 104, 97, 112,
  101, 32, 65, 118, 101, 114, 97, 103, 101, 48, 34, 44, 34, 83, 111, 102,
  116, 32, 98, 117, 114, 110, 34, 44, 34, 83, 111, 102, 116, 32, 100, 111,
  100, 103, 101, 34, 44, 34, 83, 111, 102, 116, 32, 108, 105, 103, 104, 116,
  34, 44, 34, 83, 99, 114, 101, 101, 110, 34, 44, 34, 83, 116, 97, 109,
  112, 34, 44, 34, 83, 117, 98, 116, 114, 97, 99, 116, 34, 44, 34, 86,
  97, 108, 117, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  34, 86, 105, 118, 105, 100, 32, 108, 105, 103, 104, 116, 34, 44, 34, 88,
  111, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112,
  97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44,
  48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101,
  118, 101, 114, 116, 32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111,
  111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 83, 97,
  109, 106, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62,
  50, 48, 49, 52, 47, 48, 49, 47, 49, 55, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 82, 101, 109, 112, 108, 105,
  114, 95, 69, 116, 111, 105, 108, 101, 115, 95, 115, 97, 109, 106, 58, 10,
  78, 111, 109, 98, 114, 101, 95, 101, 116, 111, 105, 108, 101, 115, 61, 36,
  49, 10, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 115, 111, 109, 109,
  101, 116, 115, 95, 109, 105, 110, 61, 36, 50, 10, 78, 111, 109, 98, 114,
  101, 95, 100, 101, 95, 115, 111, 109, 109, 101, 116, 115, 95, 109, 97, 120,
  61, 36, 51, 10, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101,
  95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 95, 109, 105, 110, 61, 36,
  52, 10, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 101,
  120, 116, 101, 114, 105, 101, 117, 114, 95, 109, 97, 120, 61, 36, 53, 10,
  82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116,
  101, 114, 105, 101, 117, 114, 95, 109, 105, 110, 61, 36, 54, 10, 82, 97,
  121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114,
  105, 101, 117, 114, 95, 109, 97, 120, 61, 36, 55, 10, 69, 120, 99, 101,
  110, 116, 114, 105, 99, 105, 116, 101, 95, 109, 105, 110, 61, 36, 56, 10,
  69, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116, 101, 95, 109, 97, 120,
  61, 36, 57, 10, 65, 110, 103, 108, 101, 95, 101, 120, 99, 101, 110, 116,
  114, 105, 99, 105, 116, 101, 95, 109, 105, 110, 61, 36, 49, 48, 10, 65,
  110, 103, 108, 101, 95, 101, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116,
  101, 95, 109, 97, 120, 61, 36, 49, 49, 10, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 61, 36, 49, 50, 10, 86, 95, 67, 111, 117, 108, 101, 117,
  114, 61, 36, 49, 51, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 61,
  36, 49, 52, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 49,
  53, 10, 86, 95, 68, 95, 67, 61, 36, 49, 54, 10, 67, 111, 117, 108,
  101, 117, 114, 115, 95, 97, 108, 101, 97, 116, 111, 105, 114, 101, 115, 61,
  36, 49, 55, 10, 70, 108, 111, 117, 95, 101, 116, 111, 105, 108, 101, 61,
  36, 49, 56, 10, 83, 112, 114, 101, 97, 100, 95, 101, 116, 111, 105, 108,
  101, 61, 36, 49, 57, 10, 68, 101, 102, 111, 114, 109, 95, 101, 116, 111,
  105, 108, 101, 61, 36, 50, 48, 10, 69, 112, 97, 105, 115, 115, 101, 117,
  114, 61, 36, 50, 49, 10, 98, 108, 101, 110, 100, 61, 36, 50, 50, 10,
  111, 112, 97, 99, 105, 116, 101, 61, 36, 50, 51, 10, 82, 101, 118, 101,
  114, 116, 95, 108, 97, 121, 101, 114, 115, 61, 36, 50, 52, 10, 35, 32,
  86, 97, 114, 105, 97, 98, 108, 101, 115, 32, 99, 97, 108, 99, 117, 108,
  -23, 101, 115, 10, 76, 97, 114, 103, 101, 117, 114, 95, 111, 114, 105, 103,
  105, 110, 101, 61, 123, 119, 125, 10, 72, 97, 117, 116, 101, 117, 114, 95,
  111, 114, 105, 103, 105, 110, 101, 61, 123, 104, 125, 10, 45, 105, 102, 32,
  123, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 115, 111, 109, 109,
  101, 116, 115, 95, 109, 105, 110, 62, 36, 78, 111, 109, 98, 114, 101, 95,
  100, 101, 95, 115, 111, 109, 109, 101, 116, 115, 95, 109, 97, 120, 125, 10,
  109, 105, 110, 61, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 115,
  111, 109, 109, 101, 116, 115, 95, 109, 97, 120, 10, 78, 111, 109, 98, 114,
  101, 95, 100, 101, 95, 115, 111, 109, 109, 101, 116, 115, 95, 109, 97, 120,
  61, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 115, 111, 109, 109,
  101, 116, 115, 95, 109, 105, 110, 10, 78, 111, 109, 98, 114, 101, 95, 100,
  101, 95, 115, 111, 109, 109, 101, 116, 115, 95, 109, 105, 110, 61, 36, 109,
  105, 110, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116,
  101, 114, 105, 101, 117, 114, 95, 109, 105, 110, 62, 36, 82, 97, 121, 111,
  110, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101,
  117, 114, 95, 109, 97, 120, 125, 10, 109, 105, 110, 61, 36, 82, 97, 121,
  111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105,
  101, 117, 114, 95, 109, 97, 120, 10, 82, 97, 121, 111, 110, 95, 99, 101,
  114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 95, 109,
  97, 120, 61, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101,
  95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 95, 109, 105, 110, 10, 82,
  97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101,
  114, 105, 101, 117, 114, 95, 109, 105, 110, 61, 36, 109, 105, 110, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 97, 121, 111,
  110, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101,
  117, 114, 95, 109, 105, 110, 62, 36, 82, 97, 121, 111, 110, 95, 99, 101,
  114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 109,
  97, 120, 125, 10, 109, 105, 110, 61, 36, 82, 97, 121, 111, 110, 95, 99,
  101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95,
  109, 97, 120, 10, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101,
  95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 109, 97, 120, 61, 36,
  82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116,
  101, 114, 105, 101, 117, 114, 95, 109, 105, 110, 10, 82, 97, 121, 111, 110,
  95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117,
  114, 95, 109, 105, 110, 61, 36, 109, 105, 110, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 69, 120, 99, 101, 110, 116, 114, 105,
  99, 105, 116, 101, 95, 109, 105, 110, 62, 36, 69, 120, 99, 101, 110, 116,
  114, 105, 99, 105, 116, 101, 95, 109, 97, 120, 125, 10, 109, 105, 110, 61,
  36, 69, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116, 101, 95, 109, 97,
  120, 10, 69, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116, 101, 95, 109,
  97, 120, 61, 36, 69, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116, 101,
  95, 109, 105, 110, 10, 69, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116,
  101, 95, 109, 105, 110, 61, 36, 109, 105, 110, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 65, 110, 103, 108, 101, 95, 101, 120,
  99, 101, 110, 116, 114, 105, 99, 105, 116, 101, 95, 109, 105, 110, 62, 36,
  65, 110, 103, 108, 101, 95, 101, 120, 99, 101, 110, 116, 114, 105, 99, 105,
  116, 101, 95, 109, 97, 120, 125, 10, 109, 105, 110, 61, 36, 65, 110, 103,
  108, 101, 95, 101, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116, 101, 95,
  109, 97, 120, 10, 65, 110, 103, 108, 101, 95, 101, 120, 99, 101, 110, 116,
  114, 105, 99, 105, 116, 101, 95, 109, 97, 120, 61, 36, 65, 110, 103, 108,
  101, 95, 101, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116, 101, 95, 109,
  105, 110, 10, 65, 110, 103, 108, 101, 95, 101, 120, 99, 101, 110, 116, 114,
  105, 99, 105, 116, 101, 95, 109, 105, 110, 61, 36, 109, 105, 110, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 114, 103, 98, 97, 10, 36,
  76, 97, 114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 44,
  36, 72, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101,
  44, 49, 44, 52, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 78, 111,
  109, 98, 114, 101, 95, 101, 116, 111, 105, 108, 101, 115, 10, 36, 76, 97,
  114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 44, 36, 72,
  97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 44, 49,
  44, 52, 10, 45, 105, 102, 32, 123, 36, 67, 111, 117, 108, 101, 117, 114,
  115, 95, 97, 108, 101, 97, 116, 111, 105, 114, 101, 115, 61, 61, 49, 125,
  10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110,
  100, 40, 123, 40, 63, 40, 50, 53, 53, 41, 41, 125, 41, 125, 10, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40,
  123, 40, 63, 40, 50, 53, 53, 41, 41, 125, 41, 125, 10, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 123, 40,
  63, 40, 50, 53, 53, 41, 41, 125, 41, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 76, 97, 114, 103, 101, 117, 114, 95, 101, 110, 95, 112, 105, 120,
  101, 108, 115, 61, 123, 50, 42, 123, 36, 82, 97, 121, 111, 110, 95, 99,
  101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 95,
  109, 105, 110, 43, 123, 114, 111, 117, 110, 100, 40, 63, 40, 123, 36, 82,
  97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101,
  114, 105, 101, 117, 114, 95, 109, 97, 120, 45, 36, 82, 97, 121, 111, 110,
  95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117,
  114, 95, 109, 105, 110, 125, 41, 41, 125, 125, 125, 10, 78, 111, 109, 98,
  114, 101, 95, 100, 101, 95, 115, 111, 109, 109, 101, 116, 115, 61, 123, 36,
  78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 115, 111, 109, 109, 101, 116,
  115, 95, 109, 105, 110, 43, 123, 114, 111, 117, 110, 100, 40, 63, 40, 123,
  36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 115, 111, 109, 109, 101,
  116, 115, 95, 109, 97, 120, 45, 36, 78, 111, 109, 98, 114, 101, 95, 100,
  101, 95, 115, 111, 109, 109, 101, 116, 115, 95, 109, 105, 110, 125, 41, 41,
  125, 125, 10, 80, 111, 117, 114, 99, 101, 110, 116, 97, 103, 101, 95, 82,
  97, 121, 111, 110, 95, 73, 110, 116, 101, 114, 105, 101, 117, 114, 61, 123,
  36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110,
  116, 101, 114, 105, 101, 117, 114, 95, 109, 105, 110, 43, 123, 114, 111, 117,
  110, 100, 40, 63, 40, 123, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114,
  99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 109, 97,
  120, 45, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95,
  105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 109, 105, 110, 125, 41, 41,
  125, 125, 10, 65, 110, 103, 108, 101, 95, 105, 110, 99, 108, 105, 110, 97,
  105, 115, 111, 110, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44,
  123, 51, 54, 48, 47, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95,
  115, 111, 109, 109, 101, 116, 115, 95, 109, 105, 110, 125, 41, 41, 125, 10,
  80, 111, 117, 114, 99, 101, 110, 116, 97, 103, 101, 95, 101, 120, 99, 101,
  110, 116, 114, 105, 99, 105, 116, 101, 61, 123, 36, 69, 120, 99, 101, 110,
  116, 114, 105, 99, 105, 116, 101, 95, 109, 105, 110, 43, 123, 114, 111, 117,
  110, 100, 40, 63, 40, 123, 36, 69, 120, 99, 101, 110, 116, 114, 105, 99,
  105, 116, 101, 95, 109, 97, 120, 45, 36, 69, 120, 99, 101, 110, 116, 114,
  105, 99, 105, 116, 101, 95, 109, 105, 110, 125, 41, 41, 125, 125, 10, 65,
  110, 103, 108, 101, 95, 101, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116,
  101, 61, 123, 36, 65, 110, 103, 108, 101, 95, 101, 120, 99, 101, 110, 116,
  114, 105, 99, 105, 116, 101, 95, 109, 105, 110, 43, 123, 114, 111, 117, 110,
  100, 40, 63, 40, 123, 36, 65, 110, 103, 108, 101, 95, 101, 120, 99, 101,
  110, 116, 114, 105, 99, 105, 116, 101, 95, 109, 97, 120, 45, 36, 65, 110,
  103, 108, 101, 95, 101, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116, 101,
  95, 109, 105, 110, 125, 41, 41, 125, 125, 10, 82, 101, 109, 112, 108, 105,
  114, 95, 112, 111, 105, 110, 116, 101, 115, 61, 49, 10, 82, 95, 112, 111,
  105, 110, 116, 101, 115, 95, 112, 108, 101, 105, 110, 61, 36, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 10, 86, 95, 112, 111, 105, 110, 116, 101, 115,
  95, 112, 108, 101, 105, 110, 61, 36, 86, 95, 67, 111, 117, 108, 101, 117,
  114, 10, 66, 95, 112, 111, 105, 110, 116, 101, 115, 95, 112, 108, 101, 105,
  110, 61, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 10, 65, 95, 112,
  111, 105, 110, 116, 101, 115, 95, 112, 108, 101, 105, 110, 61, 36, 65, 95,
  67, 111, 117, 108, 101, 117, 114, 10, 67, 111, 110, 116, 111, 117, 114, 95,
  112, 111, 105, 110, 116, 101, 115, 61, 48, 10, 82, 95, 112, 111, 105, 110,
  116, 101, 115, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 10, 86, 95, 112, 111, 105, 110, 116, 101, 115,
  95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 10, 66, 95, 112, 111, 105, 110, 116, 101, 115, 95, 99, 111,
  110, 116, 111, 117, 114, 61, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114,
  10, 65, 95, 112, 111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116, 111,
  117, 114, 61, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 82, 101,
  109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116,
  101, 114, 105, 101, 117, 114, 61, 49, 10, 82, 95, 67, 73, 95, 112, 108,
  101, 105, 110, 61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 10, 86,
  95, 67, 73, 95, 112, 108, 101, 105, 110, 61, 36, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 10, 66, 95, 67, 73, 95, 112, 108, 101, 105, 110, 61,
  36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 10, 65, 95, 67, 73, 95,
  112, 108, 101, 105, 110, 61, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114,
  10, 67, 111, 110, 116, 111, 117, 114, 95, 99, 101, 114, 99, 108, 101, 95,
  105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 48, 10, 82, 95, 67, 73,
  95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 10, 86, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114,
  61, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 10, 66, 95, 67, 73,
  95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 66, 95, 67, 111, 117, 108,
  101, 117, 114, 10, 65, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114,
  61, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 82, 101, 109, 112,
  108, 105, 114, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114,
  105, 101, 117, 114, 61, 48, 10, 82, 95, 67, 69, 95, 112, 108, 101, 105,
  110, 61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 10, 86, 95, 67,
  69, 95, 112, 108, 101, 105, 110, 61, 36, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 10, 66, 95, 67, 69, 95, 112, 108, 101, 105, 110, 61, 36, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 10, 65, 95, 67, 69, 95, 112, 108,
  101, 105, 110, 61, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 67,
  111, 110, 116, 111, 117, 114, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120,
  116, 101, 114, 105, 101, 117, 114, 61, 48, 10, 82, 95, 67, 69, 95, 99,
  111, 110, 116, 111, 117, 114, 61, 36, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 10, 86, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36,
  86, 95, 67, 111, 117, 108, 101, 117, 114, 10, 66, 95, 67, 69, 95, 99,
  111, 110, 116, 111, 117, 114, 61, 36, 66, 95, 67, 111, 117, 108, 101, 117,
  114, 10, 65, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36,
  65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 86, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 36,
  86, 95, 68, 95, 67, 10, 45, 115, 116, 97, 114, 95, 112, 97, 116, 116,
  101, 114, 110, 95, 115, 97, 109, 106, 91, 45, 49, 93, 32, 36, 76, 97,
  114, 103, 101, 117, 114, 95, 101, 110, 95, 112, 105, 120, 101, 108, 115, 44,
  36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 115, 111, 109, 109, 101,
  116, 115, 44, 36, 80, 111, 117, 114, 99, 101, 110, 116, 97, 103, 101, 95,
  82, 97, 121, 111, 110, 95, 73, 110, 116, 101, 114, 105, 101, 117, 114, 44,
  36, 65, 110, 103, 108, 101, 95, 105, 110, 99, 108, 105, 110, 97, 105, 115,
  111, 110, 44, 36, 80, 111, 117, 114, 99, 101, 110, 116, 97, 103, 101, 95,
  101, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116, 101, 44, 36, 65, 110,
  103, 108, 101, 95, 101, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116, 101,
  44, 36, 82, 101, 109, 112, 108, 105, 114, 95, 112, 111, 105, 110, 116, 101,
  115, 44, 36, 82, 95, 112, 111, 105, 110, 116, 101, 115, 95, 112, 108, 101,
  105, 110, 44, 36, 86, 95, 112, 111, 105, 110, 116, 101, 115, 95, 112, 108,
  101, 105, 110, 44, 36, 66, 95, 112, 111, 105, 110, 116, 101, 115, 95, 112,
  108, 101, 105, 110, 44, 36, 65, 95, 112, 111, 105, 110, 116, 101, 115, 95,
  112, 108, 101, 105, 110, 44, 36, 67, 111, 110, 116, 111, 117, 114, 95, 112,
  111, 105, 110, 116, 101, 115, 44, 36, 82, 95, 112, 111, 105, 110, 116, 101,
  115, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 86, 95, 112, 111, 105,
  110, 116, 101, 115, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 66, 95,
  112, 111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116, 111, 117, 114, 44,
  36, 65, 95, 112, 111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116, 111,
  117, 114, 44, 36, 82, 101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99,
  108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 36, 82, 95,
  67, 73, 95, 112, 108, 101, 105, 110, 44, 36, 86, 95, 67, 73, 95, 112,
  108, 101, 105, 110, 44, 36, 66, 95, 67, 73, 95, 112, 108, 101, 105, 110,
  44, 36, 65, 95, 67, 73, 95, 112, 108, 101, 105, 110, 44, 36, 67, 111,
  110, 116, 111, 117, 114, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116,
  101, 114, 105, 101, 117, 114, 44, 36, 82, 95, 67, 73, 95, 99, 111, 110,
  116, 111, 117, 114, 44, 36, 86, 95, 67, 73, 95, 99, 111, 110, 116, 111,
  117, 114, 44, 36, 66, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114,
  44, 36, 65, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36,
  82, 101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108, 101, 95, 101,
  120, 116, 101, 114, 105, 101, 117, 114, 44, 36, 82, 95, 67, 69, 95, 112,
  108, 101, 105, 110, 44, 36, 86, 95, 67, 69, 95, 112, 108, 101, 105, 110,
  44, 36, 66, 95, 67, 69, 95, 112, 108, 101, 105, 110, 44, 36, 65, 95,
  67, 69, 95, 112, 108, 101, 105, 110, 44, 36, 67, 111, 110, 116, 111, 117,
  114, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101,
  117, 114, 44, 36, 82, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114,
  44, 36, 86, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36,
  66, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 65, 95,
  67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 86, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114,
  10, 80, 111, 115, 105, 116, 105, 111, 110, 95, 88, 61, 123, 123, 114, 111,
  117, 110, 100, 40, 63, 40, 123, 36, 76, 97, 114, 103, 101, 117, 114, 95,
  111, 114, 105, 103, 105, 110, 101, 43, 36, 76, 97, 114, 103, 101, 117, 114,
  95, 101, 110, 95, 112, 105, 120, 101, 108, 115, 125, 41, 41, 125, 45, 36,
  76, 97, 114, 103, 101, 117, 114, 95, 101, 110, 95, 112, 105, 120, 101, 108,
  115, 125, 10, 80, 111, 115, 105, 116, 105, 111, 110, 95, 89, 61, 123, 123,
  114, 111, 117, 110, 100, 40, 63, 40, 123, 36, 72, 97, 117, 116, 101, 117,
  114, 95, 111, 114, 105, 103, 105, 110, 101, 43, 36, 76, 97, 114, 103, 101,
  117, 114, 95, 101, 110, 95, 112, 105, 120, 101, 108, 115, 125, 41, 41, 125,
  45, 36, 76, 97, 114, 103, 101, 117, 114, 95, 101, 110, 95, 112, 105, 120,
  101, 108, 115, 125, 10, 45, 105, 109, 97, 103, 101, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 88,
  44, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 89, 10, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 97, 108,
  112, 104, 97, 91, 45, 50, 44, 45, 49, 93, 10, 45, 100, 111, 110, 101,
  10, 45, 105, 102, 32, 123, 36, 69, 112, 97, 105, 115, 115, 101, 117, 114,
  62, 48, 125, 10, 45, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99,
  91, 45, 49, 93, 32, 36, 69, 112, 97, 105, 115, 115, 101, 117, 114, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93,
  32, 36, 70, 108, 111, 117, 95, 101, 116, 111, 105, 108, 101, 10, 45, 115,
  112, 114, 101, 97, 100, 91, 45, 49, 93, 32, 36, 83, 112, 114, 101, 97,
  100, 95, 101, 116, 111, 105, 108, 101, 10, 45, 100, 101, 102, 111, 114, 109,
  91, 45, 49, 93, 32, 36, 68, 101, 102, 111, 114, 109, 95, 101, 116, 111,
  105, 108, 101, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91,
  45, 49, 44, 45, 50, 93, 32, 36, 98, 108, 101, 110, 100, 44, 36, 111,
  112, 97, 99, 105, 116, 101, 44, 36, 82, 101, 118, 101, 114, 116, 95, 108,
  97, 121, 101, 114, 115, 10, 35, 64, 103, 105, 109, 112, 32, 82, 101, 109,
  112, 108, 105, 114, 32, 102, 108, 101, 117, 114, 115, 32, 58, 32, 82, 101,
  109, 112, 108, 105, 114, 95, 70, 108, 101, 117, 114, 115, 95, 115, 97, 109,
  106, 44, 32, 82, 101, 109, 112, 108, 105, 114, 95, 70, 108, 101, 117, 114,
  115, 95, 115, 97, 109, 106, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 70, 108, 101, 117, 114, 115,
  32, 47, 32, 70, 108, 111, 119, 101, 114, 115, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  109, 98, 114, 101, 32, 100, 101, 32, 102, 108, 101, 117, 114, 115, 32, 61,
  32, 105, 110, 116, 40, 51, 51, 44, 49, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 39, 114, 97, 121, 111, 110, 39, 32,
  100, 101, 32, 108, 97, 32, 102, 108, 101, 117, 114, 32, 47, 32, 102, 108,
  111, 119, 101, 114, 32, 39, 114, 97, 100, 105, 117, 115, 39, 32, 109, 105,
  110, 46, 32, 61, 32, 105, 110, 116, 40, 52, 48, 48, 44, 49, 54, 44,
  50, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 39,
  114, 97, 121, 111, 110, 39, 32, 100, 101, 32, 108, 97, 32, 102, 108, 101,
  117, 114, 32, 47, 32, 102, 108, 111, 119, 101, 114, 32, 39, 114, 97, 100,
  105, 117, 115, 39, 32, 109, 97, 120, 46, 32, 61, 32, 105, 110, 116, 40,
  56, 48, 48, 44, 49, 54, 44, 50, 48, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 109, 98, 114, 101, 32, 100, 101, 32,
  112, 92, 51, 48, 51, 92, 50, 53, 49, 116, 97, 108, 101, 115, 32, 47,
  32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 112, 101, 116, 97, 108,
  115, 32, 109, 105, 110, 46, 32, 61, 32, 105, 110, 116, 40, 50, 53, 44,
  50, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  78, 111, 109, 98, 114, 101, 32, 100, 101, 32, 112, 92, 51, 48, 51, 92,
  50, 53, 49, 116, 97, 108, 101, 115, 32, 47, 32, 110, 117, 109, 98, 101,
  114, 32, 111, 102, 32, 112, 101, 116, 97, 108, 115, 32, 109, 97, 120, 46,
  32, 61, 32, 105, 110, 116, 40, 53, 48, 44, 50, 44, 51, 54, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 121, 111, 110, 32,
  99, 101, 114, 99, 108, 101, 32, 49, 32, 47, 32, 114, 97, 100, 105, 117,
  115, 32, 99, 105, 114, 99, 108, 101, 32, 49, 32, 40, 37, 41, 32, 109,
  105, 110, 46, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 53, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  97, 121, 111, 110, 32, 99, 101, 114, 99, 108, 101, 32, 49, 32, 47, 32,
  114, 97, 100, 105, 117, 115, 32, 99, 105, 114, 99, 108, 101, 32, 49, 32,
  40, 37, 41, 32, 109, 97, 120, 46, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 52, 53, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 82, 97, 121, 111, 110, 32, 99, 101, 114, 99, 108, 101,
  32, 50, 32, 47, 32, 114, 97, 100, 105, 117, 115, 32, 99, 105, 114, 99,
  108, 101, 32, 50, 32, 40, 37, 41, 32, 109, 105, 110, 46, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 51, 53, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 121, 111, 110, 32, 99,
  101, 114, 99, 108, 101, 32, 50, 32, 47, 32, 114, 97, 100, 105, 117, 115,
  32, 99, 105, 114, 99, 108, 101, 32, 50, 32, 40, 37, 41, 32, 109, 97,
  120, 46, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 111,
  110, 103, 117, 101, 117, 114, 32, 112, 92, 51, 48, 51, 92, 50, 53, 49,
  116, 97, 108, 101, 115, 32, 47, 32, 108, 101, 110, 103, 116, 104, 32, 112,
  101, 116, 97, 108, 115, 32, 40, 37, 41, 32, 109, 105, 110, 46, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 52, 48, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 111, 110, 103, 117, 101,
  117, 114, 32, 112, 92, 51, 48, 51, 92, 50, 53, 49, 116, 97, 108, 101,
  115, 32, 47, 32, 108, 101, 110, 103, 116, 104, 32, 112, 101, 116, 97, 108,
  115, 32, 40, 37, 41, 32, 109, 97, 120, 46, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 54, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 76, 97, 114, 103, 101, 117, 114, 32, 112, 92,
  51, 48, 51, 92, 50, 53, 49, 116, 97, 108, 101, 115, 32, 47, 32, 119,
  105, 100, 116, 104, 32, 112, 101, 116, 97, 108, 115, 32, 40, 37, 41, 32,
  109, 105, 110, 46, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  76, 97, 114, 103, 101, 117, 114, 32, 112, 92, 51, 48, 51, 92, 50, 53,
  49, 116, 97, 108, 101, 115, 32, 47, 32, 119, 105, 100, 116, 104, 32, 112,
  101, 116, 97, 108, 115, 32, 40, 37, 41, 32, 109, 97, 120, 46, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 53, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 115, 112, 97, 99, 101,
  109, 101, 110, 116, 32, 100, 117, 32, 99, 101, 110, 116, 114, 101, 32, 47,
  32, 99, 101, 110, 116, 101, 114, 32, 115, 112, 97, 99, 105, 110, 103, 32,
  40, 37, 41, 32, 109, 105, 110, 46, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 51, 53, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 69, 115, 112, 97, 99, 101, 109, 101, 110, 116, 32, 100,
  117, 32, 99, 101, 110, 116, 114, 101, 32, 47, 32, 99, 101, 110, 116, 101,
  114, 32, 115, 112, 97, 99, 105, 110, 103, 32, 40, 37, 41, 32, 109, 97,
  120, 46, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97,
  114, 105, 97, 116, 105, 111, 110, 32, 108, 111, 110, 103, 117, 101, 117, 114,
  32, 47, 32, 108, 101, 110, 103, 116, 104, 32, 118, 97, 114, 105, 97, 116,
  105, 111, 110, 32, 40, 37, 41, 32, 109, 105, 110, 46, 32, 61, 32, 105,
  110, 116, 40, 48, 44, 48, 44, 49, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 86, 97, 114, 105, 97, 116, 105, 111, 110, 32, 108, 111,
  110, 103, 117, 101, 117, 114, 32, 47, 32, 108, 101, 110, 103, 116, 104, 32,
  118, 97, 114, 105, 97, 116, 105, 111, 110, 32, 40, 37, 41, 32, 109, 97,
  120, 46, 32, 61, 32, 105, 110, 116, 40, 49, 48, 44, 48, 44, 49, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 114, 105, 97,
  116, 105, 111, 110, 32, 92, 51, 48, 51, 92, 50, 53, 49, 112, 97, 105,
  115, 115, 101, 117, 114, 32, 47, 32, 116, 104, 105, 99, 107, 110, 101, 115,
  115, 32, 118, 97, 114, 105, 97, 116, 105, 111, 110, 32, 40, 37, 41, 32,
  109, 105, 110, 46, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 114,
  105, 97, 116, 105, 111, 110, 32, 92, 51, 48, 51, 92, 50, 53, 49, 112,
  97, 105, 115, 115, 101, 117, 114, 32, 47, 32, 116, 104, 105, 99, 107, 110,
  101, 115, 115, 32, 118, 97, 114, 105, 97, 116, 105, 111, 110, 32, 40, 37,
  41, 32, 109, 97, 120, 46, 32, 61, 32, 105, 110, 116, 40, 53, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86,
  97, 114, 105, 97, 116, 105, 111, 110, 32, 97, 110, 103, 108, 101, 32, 40,
  100, 101, 103, 46, 41, 32, 109, 105, 110, 46, 32, 61, 32, 105, 110, 116,
  40, 48, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 86, 97, 114, 105, 97, 116, 105, 111, 110, 32, 97, 110, 103, 108, 101,
  32, 40, 100, 101, 103, 46, 41, 32, 109, 97, 120, 46, 32, 61, 32, 105,
  110, 116, 40, 50, 44, 48, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 61, 32, 99, 111, 108,
  111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101,
  117, 114, 32, 99, 101, 114, 99, 108, 101, 32, 105, 110, 116, 92, 51, 48,
  51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32, 61, 32, 99, 111, 108,
  111, 114, 40, 49, 48, 48, 44, 49, 48, 48, 44, 50, 53, 53, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117,
  108, 101, 117, 114, 32, 99, 101, 114, 99, 108, 101, 32, 101, 120, 116, 92,
  51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32, 61, 32, 99,
  111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86,
  97, 114, 105, 97, 116, 105, 111, 110, 32, 100, 101, 32, 99, 111, 117, 108,
  101, 117, 114, 32, 47, 32, 99, 111, 108, 111, 114, 32, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 50,
  44, 34, 80, 97, 115, 32, 100, 101, 32, 118, 97, 114, 105, 97, 116, 105,
  111, 110, 32, 47, 32, 78, 111, 32, 99, 104, 97, 110, 103, 101, 34, 44,
  34, 67, 111, 117, 108, 101, 117, 114, 115, 32, 97, 108, 101, 97, 116, 111,
  105, 114, 101, 115, 32, 47, 32, 82, 97, 110, 100, 111, 109, 32, 99, 111,
  108, 111, 114, 115, 34, 44, 34, 70, 97, 105, 98, 108, 101, 109, 101, 110,
  116, 32, 110, 117, 97, 110, 99, 101, 101, 32, 47, 32, 80, 111, 111, 114,
  108, 121, 32, 110, 117, 97, 110, 99, 101, 100, 34, 44, 34, 77, 111, 121,
  101, 110, 110, 101, 109, 101, 110, 116, 32, 110, 117, 97, 110, 99, 101, 101,
  32, 47, 32, 77, 111, 100, 101, 114, 97, 116, 101, 108, 121, 32, 110, 117,
  97, 110, 99, 101, 100, 34, 44, 34, 70, 111, 114, 116, 101, 109, 101, 110,
  116, 32, 110, 117, 97, 110, 99, 101, 101, 32, 47, 32, 72, 105, 103, 104,
  108, 121, 32, 110, 117, 97, 110, 99, 101, 100, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 70, 108, 101, 117, 114, 115, 47, 102, 108, 111,
  119, 101, 114, 115, 32, 58, 32, 99, 111, 117, 108, 101, 117, 114, 115, 32,
  97, 108, 92, 51, 48, 51, 92, 50, 53, 49, 97, 116, 111, 105, 114, 101,
  115, 32, 47, 32, 114, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111, 114,
  115, 32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108, 115, 101, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  68, 105, 118, 101, 114, 115, 32, 47, 32, 70, 111, 111, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  70, 108, 111, 117, 32, 47, 32, 98, 108, 117, 114, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 112, 114, 101, 97, 100, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 68, 101, 102, 111, 114, 109, 97, 116, 105,
  111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 50,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 112, 97, 105,
  115, 115, 101, 117, 114, 32, 47, 32, 116, 104, 105, 99, 107, 110, 101, 115,
  115, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 54, 52, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  66, 108, 101, 110, 100, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 100, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 65, 100, 100, 34, 44, 34,
  65, 108, 112, 104, 97, 34, 44, 34, 65, 110, 100, 34, 44, 34, 65, 118,
  101, 114, 97, 103, 101, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 66,
  117, 114, 110, 34, 44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 68,
  105, 102, 102, 101, 114, 101, 110, 99, 101, 34, 44, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 34, 68, 105, 118, 105, 100, 101, 34, 44, 34, 68,
  111, 100, 103, 101, 34, 44, 34, 69, 120, 99, 108, 117, 115, 105, 111, 110,
  34, 44, 34, 70, 114, 101, 101, 122, 101, 34, 44, 34, 71, 114, 97, 105,
  110, 32, 101, 120, 116, 114, 97, 99, 116, 34, 44, 34, 71, 114, 97, 105,
  110, 32, 109, 101, 114, 103, 101, 34, 44, 34, 71, 114, 101, 101, 110, 34,
  44, 34, 72, 97, 114, 100, 32, 108, 105, 103, 104, 116, 34, 44, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 34, 72, 97, 114, 100, 32, 109, 105,
  120, 34, 44, 34, 72, 117, 101, 34, 44, 34, 73, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 105, 111, 110, 34, 44, 34, 76, 105, 103, 104, 116, 101,
  110, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34,
  76, 105, 110, 101, 97, 114, 32, 98, 117, 114, 110, 34, 44, 34, 76, 105,
  110, 101, 97, 114, 32, 108, 105, 103, 104, 116, 34, 44, 34, 76, 117, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 34, 77, 117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 78, 101,
  103, 97, 116, 105, 111, 110, 34, 44, 34, 79, 114, 34, 44, 34, 79, 118,
  101, 114, 108, 97, 121, 34, 44, 34, 80, 105, 110, 32, 108, 105, 103, 104,
  116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 82, 101, 102, 108, 101, 99,
  116, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 83, 104, 97, 112, 101,
  32, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 83, 104, 97, 112, 101,
  32, 65, 118, 101, 114, 97, 103, 101, 48, 34, 44, 34, 83, 111, 102, 116,
  32, 98, 117, 114, 110, 34, 44, 34, 83, 111, 102, 116, 32, 100, 111, 100,
  103, 101, 34, 44, 34, 83, 111, 102, 116, 32, 108, 105, 103, 104, 116, 34,
  44, 34, 83, 99, 114, 101, 101, 110, 34, 44, 34, 83, 116, 97, 109, 112,
  34, 44, 34, 83, 117, 98, 116, 114, 97, 99, 116, 34, 44, 34, 86, 97,
  108, 117, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34,
  86, 105, 118, 105, 100, 32, 108, 105, 103, 104, 116, 34, 44, 34, 88, 111,
  114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97,
  99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118,
  101, 114, 116, 32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111,
  108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 83, 97, 109,
  106, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50,
  48, 49, 51, 47, 48, 49, 47, 50, 53, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 82, 101, 109, 112, 108, 105, 114,
  95, 70, 108, 101, 117, 114, 115, 95, 115, 97, 109, 106, 58, 10, 78, 111,
  109, 98, 114, 101, 95, 70, 108, 101, 117, 114, 115, 61, 36, 49, 10, 82,
  97, 121, 111, 110, 95, 102, 108, 101, 117, 114, 95, 109, 105, 110, 61, 36,
  50, 10, 82, 97, 121, 111, 110, 95, 102, 108, 101, 117, 114, 95, 109, 97,
  120, 61, 36, 51, 10, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 112,
  101, 116, 97, 108, 101, 115, 95, 109, 105, 110, 61, 36, 52, 10, 78, 111,
  109, 98, 114, 101, 95, 100, 101, 95, 112, 101, 116, 97, 108, 101, 115, 95,
  109, 97, 120, 61, 36, 53, 10, 82, 97, 121, 111, 110, 95, 99, 101, 114,
  99, 108, 101, 95, 49, 95, 109, 105, 110, 61, 36, 54, 10, 82, 97, 121,
  111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 49, 95, 109, 97, 120, 61,
  36, 55, 10, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95,
  50, 95, 109, 105, 110, 61, 36, 56, 10, 82, 97, 121, 111, 110, 95, 99,
  101, 114, 99, 108, 101, 95, 50, 95, 109, 97, 120, 61, 36, 57, 10, 76,
  111, 110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95,
  109, 105, 110, 61, 36, 49, 48, 10, 76, 111, 110, 103, 117, 101, 117, 114,
  95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 97, 120, 61, 36, 49, 49,
  10, 76, 97, 114, 103, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  95, 109, 105, 110, 61, 36, 49, 50, 10, 76, 97, 114, 103, 101, 117, 114,
  95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 97, 120, 61, 36, 49, 51,
  10, 69, 115, 112, 97, 99, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99,
  101, 110, 116, 114, 101, 95, 109, 105, 110, 61, 36, 49, 52, 10, 69, 115,
  112, 97, 99, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101, 110, 116,
  114, 101, 95, 109, 97, 120, 61, 36, 49, 53, 10, 86, 97, 114, 105, 97,
  116, 105, 111, 110, 95, 108, 111, 110, 103, 117, 101, 117, 114, 95, 109, 105,
  110, 61, 36, 49, 54, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  108, 111, 110, 103, 117, 101, 117, 114, 95, 109, 97, 120, 61, 36, 49, 55,
  10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 101, 112, 97, 105, 115,
  115, 101, 117, 114, 95, 109, 105, 110, 61, 36, 49, 56, 10, 86, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114,
  95, 109, 97, 120, 61, 36, 49, 57, 10, 86, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 97, 110, 103, 108, 101, 95, 109, 105, 110, 61, 36, 50, 48,
  10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 97, 110, 103, 108, 101,
  95, 109, 97, 120, 61, 36, 50, 49, 10, 82, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 50, 50, 10, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  61, 36, 50, 51, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 61, 36, 50, 52, 10, 65, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 50, 53,
  10, 82, 95, 67, 73, 95, 112, 108, 101, 105, 110, 61, 36, 50, 54, 10,
  86, 95, 67, 73, 95, 112, 108, 101, 105, 110, 61, 36, 50, 55, 10, 66,
  95, 67, 73, 95, 112, 108, 101, 105, 110, 61, 36, 50, 56, 10, 65, 95,
  67, 73, 95, 112, 108, 101, 105, 110, 61, 36, 50, 57, 10, 82, 95, 67,
  69, 95, 112, 108, 101, 105, 110, 61, 36, 51, 48, 10, 86, 95, 67, 69,
  95, 112, 108, 101, 105, 110, 61, 36, 51, 49, 10, 66, 95, 67, 69, 95,
  112, 108, 101, 105, 110, 61, 36, 51, 50, 10, 65, 95, 67, 69, 95, 112,
  108, 101, 105, 110, 61, 36, 51, 51, 10, 86, 95, 68, 95, 67, 61, 36,
  51, 52, 10, 67, 111, 117, 108, 101, 117, 114, 115, 95, 97, 108, 101, 97,
  116, 111, 105, 114, 101, 115, 61, 36, 51, 53, 10, 70, 108, 111, 117, 95,
  102, 108, 101, 117, 114, 61, 36, 51, 54, 10, 83, 112, 114, 101, 97, 100,
  95, 102, 108, 101, 117, 114, 61, 36, 51, 55, 10, 68, 101, 102, 111, 114,
  109, 95, 102, 108, 101, 117, 114, 61, 36, 51, 56, 10, 69, 112, 97, 105,
  115, 115, 101, 117, 114, 61, 36, 51, 57, 10, 98, 108, 101, 110, 100, 61,
  36, 52, 48, 10, 111, 112, 97, 99, 105, 116, 101, 61, 36, 52, 49, 10,
  82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 61, 36, 52,
  50, 10, 35, 32, 86, 97, 114, 105, 97, 98, 108, 101, 115, 32, 99, 97,
  108, 99, 117, 108, -23, 101, 115, 10, 76, 97, 114, 103, 101, 117, 114, 95,
  111, 114, 105, 103, 105, 110, 101, 61, 123, 119, 125, 10, 72, 97, 117, 116,
  101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 61, 123, 104, 125, 10,
  45, 105, 102, 32, 123, 36, 82, 97, 121, 111, 110, 95, 102, 108, 101, 117,
  114, 95, 109, 105, 110, 62, 36, 82, 97, 121, 111, 110, 95, 102, 108, 101,
  117, 114, 95, 109, 97, 120, 125, 10, 109, 105, 110, 61, 36, 82, 97, 121,
  111, 110, 95, 102, 108, 101, 117, 114, 95, 109, 97, 120, 10, 82, 97, 121,
  111, 110, 95, 102, 108, 101, 117, 114, 95, 109, 97, 120, 61, 36, 82, 97,
  121, 111, 110, 95, 102, 108, 101, 117, 114, 95, 109, 105, 110, 10, 82, 97,
  121, 111, 110, 95, 102, 108, 101, 117, 114, 95, 109, 105, 110, 61, 36, 109,
  105, 110, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 112, 101, 116, 97, 108, 101,
  115, 95, 109, 105, 110, 62, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101,
  95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 97, 120, 125, 10, 109, 105,
  110, 61, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 112, 101, 116,
  97, 108, 101, 115, 95, 109, 97, 120, 10, 78, 111, 109, 98, 114, 101, 95,
  100, 101, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 97, 120, 61, 36,
  78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 112, 101, 116, 97, 108, 101,
  115, 95, 109, 105, 110, 10, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95,
  112, 101, 116, 97, 108, 101, 115, 95, 109, 105, 110, 61, 36, 109, 105, 110,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 97,
  121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 49, 95, 109, 105, 110,
  62, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 49,
  95, 109, 97, 120, 125, 10, 109, 105, 110, 61, 36, 82, 97, 121, 111, 110,
  95, 99, 101, 114, 99, 108, 101, 95, 49, 95, 109, 97, 120, 10, 82, 97,
  121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 49, 95, 109, 97, 120,
  61, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 49,
  95, 109, 105, 110, 10, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108,
  101, 95, 49, 95, 109, 105, 110, 61, 36, 109, 105, 110, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 97, 121, 111, 110, 95,
  99, 101, 114, 99, 108, 101, 95, 50, 95, 109, 105, 110, 62, 36, 82, 97,
  121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 50, 95, 109, 97, 120,
  125, 10, 109, 105, 110, 61, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114,
  99, 108, 101, 95, 50, 95, 109, 97, 120, 10, 82, 97, 121, 111, 110, 95,
  99, 101, 114, 99, 108, 101, 95, 50, 95, 109, 97, 120, 61, 36, 82, 97,
  121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 50, 95, 109, 105, 110,
  10, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 50, 95,
  109, 105, 110, 61, 36, 109, 105, 110, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 95, 109, 105, 110, 62, 36, 76, 111, 110, 103,
  117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 97, 120,
  125, 10, 109, 105, 110, 61, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 95, 109, 97, 120, 10, 76, 111, 110, 103,
  117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 97, 120,
  61, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108,
  101, 115, 95, 109, 105, 110, 10, 76, 111, 110, 103, 117, 101, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 95, 109, 105, 110, 61, 36, 109, 105, 110,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 76, 97,
  114, 103, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 105,
  110, 62, 36, 76, 97, 114, 103, 101, 117, 114, 95, 112, 101, 116, 97, 108,
  101, 115, 95, 109, 97, 120, 125, 10, 109, 105, 110, 61, 36, 76, 97, 114,
  103, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 97, 120,
  10, 76, 97, 114, 103, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  95, 109, 97, 120, 61, 36, 76, 97, 114, 103, 101, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 95, 109, 105, 110, 10, 76, 97, 114, 103, 101, 117,
  114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 105, 110, 61, 36, 109,
  105, 110, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  69, 115, 112, 97, 99, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101,
  110, 116, 114, 101, 95, 109, 105, 110, 62, 36, 69, 115, 112, 97, 99, 101,
  109, 101, 110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101, 95, 109,
  97, 120, 125, 10, 109, 105, 110, 61, 36, 69, 115, 112, 97, 99, 101, 109,
  101, 110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101, 95, 109, 97,
  120, 10, 69, 115, 112, 97, 99, 101, 109, 101, 110, 116, 95, 100, 117, 95,
  99, 101, 110, 116, 114, 101, 95, 109, 97, 120, 61, 36, 69, 115, 112, 97,
  99, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101,
  95, 109, 105, 110, 10, 69, 115, 112, 97, 99, 101, 109, 101, 110, 116, 95,
  100, 117, 95, 99, 101, 110, 116, 114, 101, 95, 109, 105, 110, 61, 36, 109,
  105, 110, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 108, 111, 110, 103, 117, 101,
  117, 114, 95, 109, 105, 110, 62, 36, 86, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 108, 111, 110, 103, 117, 101, 117, 114, 95, 109, 97, 120, 125, 10,
  109, 105, 110, 61, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 108,
  111, 110, 103, 117, 101, 117, 114, 95, 109, 97, 120, 10, 86, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 108, 111, 110, 103, 117, 101, 117, 114, 95, 109,
  97, 120, 61, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 108, 111,
  110, 103, 117, 101, 117, 114, 95, 109, 105, 110, 10, 86, 97, 114, 105, 97,
  116, 105, 111, 110, 95, 108, 111, 110, 103, 117, 101, 117, 114, 95, 109, 105,
  110, 61, 36, 109, 105, 110, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 101, 112,
  97, 105, 115, 115, 101, 117, 114, 95, 109, 105, 110, 62, 36, 86, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114,
  95, 109, 97, 120, 125, 10, 109, 105, 110, 61, 36, 86, 97, 114, 105, 97,
  116, 105, 111, 110, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114, 95, 109,
  97, 120, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 101, 112, 97,
  105, 115, 115, 101, 117, 114, 95, 109, 97, 120, 61, 36, 86, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114, 95,
  109, 105, 110, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 101, 112,
  97, 105, 115, 115, 101, 117, 114, 95, 109, 105, 110, 61, 36, 109, 105, 110,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 97, 110, 103, 108, 101, 95, 109, 105,
  110, 62, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 97, 110, 103,
  108, 101, 95, 109, 97, 120, 125, 10, 109, 105, 110, 61, 36, 86, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 97, 110, 103, 108, 101, 95, 109, 97, 120,
  10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 97, 110, 103, 108, 101,
  95, 109, 97, 120, 61, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  97, 110, 103, 108, 101, 95, 109, 105, 110, 10, 86, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 97, 110, 103, 108, 101, 95, 109, 105, 110, 61, 36, 109,
  105, 110, 10, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 114, 103,
  98, 97, 10, 36, 76, 97, 114, 103, 101, 117, 114, 95, 111, 114, 105, 103,
  105, 110, 101, 44, 36, 72, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105,
  103, 105, 110, 101, 44, 49, 44, 52, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 36, 78, 111, 109, 98, 114, 101, 95, 70, 108, 101, 117, 114, 115, 10,
  36, 76, 97, 114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101,
  44, 36, 72, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110,
  101, 44, 49, 44, 52, 10, 45, 105, 102, 32, 123, 36, 67, 111, 117, 108,
  101, 117, 114, 115, 95, 97, 108, 101, 97, 116, 111, 105, 114, 101, 115, 61,
  61, 49, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 61, 123, 114, 111, 117, 110, 100, 40, 123, 40, 63,
  40, 50, 53, 53, 41, 41, 125, 41, 125, 10, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 123, 114, 111, 117,
  110, 100, 40, 123, 40, 63, 40, 50, 53, 53, 41, 41, 125, 41, 125, 10,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101,
  115, 61, 123, 114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 53, 53,
  41, 41, 125, 41, 125, 10, 82, 95, 67, 73, 95, 112, 108, 101, 105, 110,
  61, 123, 114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 53, 53, 41,
  41, 125, 41, 125, 10, 86, 95, 67, 73, 95, 112, 108, 101, 105, 110, 61,
  123, 114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 53, 53, 41, 41,
  125, 41, 125, 10, 66, 95, 67, 73, 95, 112, 108, 101, 105, 110, 61, 123,
  114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 53, 53, 41, 41, 125,
  41, 125, 10, 65, 95, 67, 73, 95, 112, 108, 101, 105, 110, 61, 123, 123,
  114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 48, 48, 41, 41, 125,
  41, 125, 43, 53, 53, 125, 10, 82, 95, 67, 69, 95, 112, 108, 101, 105,
  110, 61, 123, 114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 53, 53,
  41, 41, 125, 41, 125, 10, 86, 95, 67, 69, 95, 112, 108, 101, 105, 110,
  61, 123, 114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 53, 53, 41,
  41, 125, 41, 125, 10, 66, 95, 67, 69, 95, 112, 108, 101, 105, 110, 61,
  123, 114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 53, 53, 41, 41,
  125, 41, 125, 10, 65, 95, 67, 69, 95, 112, 108, 101, 105, 110, 61, 123,
  123, 114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 48, 48, 41, 41,
  125, 41, 125, 43, 53, 53, 125, 10, 45, 101, 110, 100, 105, 102, 10, 76,
  97, 114, 103, 101, 117, 114, 95, 101, 110, 95, 112, 105, 120, 101, 108, 115,
  61, 123, 36, 82, 97, 121, 111, 110, 95, 102, 108, 101, 117, 114, 95, 109,
  105, 110, 43, 123, 114, 111, 117, 110, 100, 40, 63, 40, 123, 36, 82, 97,
  121, 111, 110, 95, 102, 108, 101, 117, 114, 95, 109, 97, 120, 45, 36, 82,
  97, 121, 111, 110, 95, 102, 108, 101, 117, 114, 95, 109, 105, 110, 125, 41,
  41, 125, 125, 10, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 112, 101,
  116, 97, 108, 101, 115, 61, 123, 36, 78, 111, 109, 98, 114, 101, 95, 100,
  101, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 105, 110, 43, 123, 114,
  111, 117, 110, 100, 40, 63, 40, 123, 36, 78, 111, 109, 98, 114, 101, 95,
  100, 101, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 97, 120, 45, 36,
  78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 112, 101, 116, 97, 108, 101,
  115, 95, 109, 105, 110, 125, 41, 41, 125, 125, 10, 65, 110, 103, 108, 101,
  95, 105, 110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 61, 123, 114, 111,
  117, 110, 100, 40, 63, 40, 48, 44, 123, 51, 54, 48, 47, 36, 78, 111,
  109, 98, 114, 101, 95, 100, 101, 95, 112, 101, 116, 97, 108, 101, 115, 95,
  109, 105, 110, 125, 41, 41, 125, 10, 82, 97, 121, 111, 110, 95, 103, 114,
  97, 110, 100, 95, 99, 101, 114, 99, 108, 101, 61, 123, 36, 82, 97, 121,
  111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 49, 95, 109, 105, 110, 43,
  123, 114, 111, 117, 110, 100, 40, 63, 40, 123, 36, 82, 97, 121, 111, 110,
  95, 99, 101, 114, 99, 108, 101, 95, 49, 95, 109, 97, 120, 45, 36, 82,
  97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 49, 95, 109, 105,
  110, 125, 41, 41, 125, 125, 10, 82, 97, 121, 111, 110, 95, 112, 101, 116,
  105, 116, 95, 99, 101, 114, 99, 108, 101, 61, 123, 36, 82, 97, 121, 111,
  110, 95, 99, 101, 114, 99, 108, 101, 95, 50, 95, 109, 105, 110, 43, 123,
  114, 111, 117, 110, 100, 40, 63, 40, 123, 36, 82, 97, 121, 111, 110, 95,
  99, 101, 114, 99, 108, 101, 95, 50, 95, 109, 97, 120, 45, 36, 82, 97,
  121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 50, 95, 109, 105, 110,
  125, 41, 41, 125, 125, 10, 76, 111, 110, 103, 117, 101, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 61, 123, 36, 76, 111, 110, 103, 117, 101, 117,
  114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 105, 110, 43, 123, 114,
  111, 117, 110, 100, 40, 63, 40, 123, 36, 76, 111, 110, 103, 117, 101, 117,
  114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 97, 120, 45, 36, 76,
  111, 110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95,
  109, 105, 110, 125, 41, 41, 125, 125, 10, 76, 97, 114, 103, 101, 117, 114,
  95, 112, 101, 116, 97, 108, 101, 115, 61, 123, 36, 76, 97, 114, 103, 101,
  117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 105, 110, 43, 123,
  114, 111, 117, 110, 100, 40, 63, 40, 123, 36, 76, 97, 114, 103, 101, 117,
  114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 97, 120, 45, 36, 76,
  97, 114, 103, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109,
  105, 110, 125, 41, 41, 125, 125, 10, 69, 115, 112, 97, 99, 101, 109, 101,
  110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101, 61, 123, 36, 69,
  115, 112, 97, 99, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101, 110,
  116, 114, 101, 95, 109, 105, 110, 43, 123, 114, 111, 117, 110, 100, 40, 63,
  40, 123, 36, 69, 115, 112, 97, 99, 101, 109, 101, 110, 116, 95, 100, 117,
  95, 99, 101, 110, 116, 114, 101, 95, 109, 97, 120, 45, 36, 69, 115, 112,
  97, 99, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114,
  101, 95, 109, 105, 110, 125, 41, 41, 125, 125, 10, 86, 97, 114, 105, 97,
  116, 105, 111, 110, 95, 108, 111, 110, 103, 117, 101, 117, 114, 61, 123, 36,
  86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 108, 111, 110, 103, 117, 101,
  117, 114, 95, 109, 105, 110, 43, 123, 114, 111, 117, 110, 100, 40, 63, 40,
  123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 108, 111, 110, 103,
  117, 101, 117, 114, 95, 109, 97, 120, 45, 36, 86, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 108, 111, 110, 103, 117, 101, 117, 114, 95, 109, 105, 110,
  125, 41, 41, 125, 125, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  101, 112, 97, 105, 115, 115, 101, 117, 114, 61, 123, 36, 86, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114, 95,
  109, 105, 110, 43, 123, 114, 111, 117, 110, 100, 40, 63, 40, 123, 36, 86,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 101, 112, 97, 105, 115, 115, 101,
  117, 114, 95, 109, 97, 120, 45, 36, 86, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114, 95, 109, 105, 110, 125,
  41, 41, 125, 125, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 97,
  110, 103, 108, 101, 61, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 97, 110, 103, 108, 101, 95, 109, 105, 110, 43, 123, 114, 111, 117, 110,
  100, 40, 63, 40, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  97, 110, 103, 108, 101, 95, 109, 97, 120, 45, 36, 86, 97, 114, 105, 97,
  116, 105, 111, 110, 95, 97, 110, 103, 108, 101, 95, 109, 105, 110, 125, 41,
  41, 125, 125, 10, 82, 101, 109, 112, 108, 105, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 61, 49, 10, 67, 111, 110, 116, 111, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 61, 48, 10, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101,
  115, 61, 48, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111,
  110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 48, 10,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117,
  114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 48, 10, 65, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 61, 50, 53, 53, 10, 82, 101, 109, 112, 108, 105,
  114, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101,
  117, 114, 61, 49, 10, 67, 111, 110, 116, 111, 117, 114, 95, 99, 101, 114,
  99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 48, 10,
  82, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 61, 48, 10, 86,
  95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 61, 48, 10, 66, 95,
  67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 61, 48, 10, 65, 95, 67,
  73, 95, 99, 111, 110, 116, 111, 117, 114, 61, 50, 53, 53, 10, 82, 101,
  109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116,
  101, 114, 105, 101, 117, 114, 61, 49, 10, 67, 111, 110, 116, 111, 117, 114,
  95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117,
  114, 61, 48, 10, 82, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114,
  61, 48, 10, 86, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 61,
  48, 10, 66, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 61, 48,
  10, 65, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 61, 50, 53,
  53, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99,
  111, 117, 108, 101, 117, 114, 61, 36, 86, 95, 68, 95, 67, 10, 45, 102,
  108, 111, 119, 101, 114, 95, 112, 97, 116, 116, 101, 114, 110, 95, 115, 97,
  109, 106, 32, 36, 76, 97, 114, 103, 101, 117, 114, 95, 101, 110, 95, 112,
  105, 120, 101, 108, 115, 44, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101,
  95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 65, 110, 103, 108, 101, 95,
  105, 110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 44, 36, 82, 97, 121,
  111, 110, 95, 103, 114, 97, 110, 100, 95, 99, 101, 114, 99, 108, 101, 44,
  36, 82, 97, 121, 111, 110, 95, 112, 101, 116, 105, 116, 95, 99, 101, 114,
  99, 108, 101, 44, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 44, 36, 76, 97, 114, 103, 101, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 44, 36, 69, 115, 112, 97, 99, 101, 109, 101,
  110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101, 44, 36, 86, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 108, 111, 110, 103, 117, 101, 117, 114,
  44, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 101, 112, 97, 105,
  115, 115, 101, 117, 114, 44, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 97, 110, 103, 108, 101, 44, 36, 82, 101, 109, 112, 108, 105, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 44, 36, 82, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 86, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 44, 36, 67, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116,
  97, 108, 101, 115, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44,
  36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111,
  117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  44, 36, 82, 101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108, 101,
  95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 36, 82, 95, 67, 73,
  95, 112, 108, 101, 105, 110, 44, 36, 86, 95, 67, 73, 95, 112, 108, 101,
  105, 110, 44, 36, 66, 95, 67, 73, 95, 112, 108, 101, 105, 110, 44, 36,
  65, 95, 67, 73, 95, 112, 108, 101, 105, 110, 44, 36, 67, 111, 110, 116,
  111, 117, 114, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114,
  105, 101, 117, 114, 44, 36, 82, 95, 67, 73, 95, 99, 111, 110, 116, 111,
  117, 114, 44, 36, 86, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114,
  44, 36, 66, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36,
  65, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 82, 101,
  109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116,
  101, 114, 105, 101, 117, 114, 44, 36, 82, 95, 67, 69, 95, 112, 108, 101,
  105, 110, 44, 36, 86, 95, 67, 69, 95, 112, 108, 101, 105, 110, 44, 36,
  66, 95, 67, 69, 95, 112, 108, 101, 105, 110, 44, 36, 65, 95, 67, 69,
  95, 112, 108, 101, 105, 110, 44, 36, 67, 111, 110, 116, 111, 117, 114, 95,
  99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114,
  44, 36, 82, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36,
  86, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 66, 95,
  67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 65, 95, 67, 69,
  95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 86, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 10, 45,
  97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 10, 80, 111, 115,
  105, 116, 105, 111, 110, 95, 88, 61, 123, 123, 114, 111, 117, 110, 100, 40,
  63, 40, 123, 36, 76, 97, 114, 103, 101, 117, 114, 95, 111, 114, 105, 103,
  105, 110, 101, 43, 123, 119, 125, 125, 41, 41, 125, 45, 123, 119, 125, 125,
  10, 80, 111, 115, 105, 116, 105, 111, 110, 95, 89, 61, 123, 123, 114, 111,
  117, 110, 100, 40, 63, 40, 123, 36, 72, 97, 117, 116, 101, 117, 114, 95,
  111, 114, 105, 103, 105, 110, 101, 43, 123, 104, 125, 125, 41, 41, 125, 45,
  123, 104, 125, 125, 10, 45, 105, 109, 97, 103, 101, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 88,
  44, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 89, 10, 45, 114, 109,
  91, 45, 49, 93, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 97, 108,
  112, 104, 97, 91, 45, 50, 44, 45, 49, 93, 10, 45, 100, 111, 110, 101,
  10, 45, 105, 102, 32, 123, 36, 69, 112, 97, 105, 115, 115, 101, 117, 114,
  62, 48, 125, 10, 45, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99,
  91, 45, 49, 93, 32, 36, 69, 112, 97, 105, 115, 115, 101, 117, 114, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93,
  32, 36, 70, 108, 111, 117, 95, 102, 108, 101, 117, 114, 10, 45, 115, 112,
  114, 101, 97, 100, 91, 45, 49, 93, 32, 36, 83, 112, 114, 101, 97, 100,
  95, 102, 108, 101, 117, 114, 10, 45, 100, 101, 102, 111, 114, 109, 91, 45,
  49, 93, 32, 36, 68, 101, 102, 111, 114, 109, 95, 102, 108, 101, 117, 114,
  10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44,
  45, 50, 93, 32, 36, 98, 108, 101, 110, 100, 44, 36, 111, 112, 97, 99,
  105, 116, 101, 44, 36, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101,
  114, 115, 10, 35, 64, 103, 105, 109, 112, 32, 82, 101, 109, 112, 108, 105,
  114, 32, 102, 108, 101, 117, 114, 115, 32, 50, 32, 58, 32, 82, 101, 109,
  112, 108, 105, 114, 95, 70, 108, 101, 117, 114, 115, 95, 50, 95, 115, 97,
  109, 106, 44, 32, 82, 101, 109, 112, 108, 105, 114, 95, 70, 108, 101, 117,
  114, 115, 95, 50, 95, 115, 97, 109, 106, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 70, 108, 101,
  117, 114, 115, 32, 47, 32, 70, 108, 111, 119, 101, 114, 115, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 109, 98, 114, 101, 32, 100, 101, 32, 102, 108, 101, 117, 114,
  115, 32, 61, 32, 105, 110, 116, 40, 57, 44, 49, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 83, 112, 105, 114, 97, 108, 101, 32, 47, 32, 83, 112, 105, 114, 97,
  108, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 84, 111, 117, 114, 115, 32, 47, 32, 116, 117, 114,
  110, 115, 32, 109, 105, 110, 46, 32, 61, 32, 105, 110, 116, 40, 49, 48,
  44, 49, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  84, 111, 117, 114, 115, 32, 47, 32, 116, 117, 114, 110, 115, 32, 109, 97,
  120, 46, 32, 61, 32, 105, 110, 116, 40, 49, 50, 44, 49, 44, 51, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 99, 114, 101,
  109, 101, 110, 116, 32, 97, 110, 103, 117, 108, 97, 105, 114, 101, 32, 47,
  32, 97, 110, 103, 117, 108, 97, 114, 32, 105, 110, 99, 114, 101, 109, 101,
  110, 116, 32, 109, 105, 110, 46, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 53, 44, 49, 44, 51, 53, 57, 46, 57, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 73, 110, 99, 114, 101, 109, 101, 110, 116, 32, 97,
  110, 103, 117, 108, 97, 105, 114, 101, 32, 47, 32, 97, 110, 103, 117, 108,
  97, 114, 32, 105, 110, 99, 114, 101, 109, 101, 110, 116, 32, 109, 97, 120,
  46, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 48, 44, 49, 44, 51,
  53, 57, 46, 57, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  111, 101, 102, 102, 46, 32, 97, 103, 114, 97, 110, 100, 105, 115, 115, 101,
  109, 101, 110, 116, 32, 47, 32, 101, 120, 112, 97, 110, 115, 105, 111, 110,
  32, 99, 111, 101, 102, 102, 105, 99, 105, 101, 110, 116, 32, 109, 105, 110,
  46, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 49, 44, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 101, 102, 102,
  46, 32, 97, 103, 114, 97, 110, 100, 105, 115, 115, 101, 109, 101, 110, 116,
  32, 47, 32, 101, 120, 112, 97, 110, 115, 105, 111, 110, 32, 99, 111, 101,
  102, 102, 105, 99, 105, 101, 110, 116, 32, 109, 97, 120, 46, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 51, 44, 49, 44, 49, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 110, 115, 32, 100, 101, 32, 114,
  111, 116, 97, 116, 105, 111, 110, 32, 47, 32, 100, 105, 114, 101, 99, 116,
  105, 111, 110, 32, 111, 102, 32, 114, 111, 116, 97, 116, 105, 111, 110, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 48, 34, 44, 34,
  82, 97, 110, 100, 111, 109, 32, 49, 34, 44, 34, 82, 97, 110, 100, 111,
  109, 32, 50, 34, 44, 34, 82, 97, 110, 100, 111, 109, 32, 51, 34, 44,
  34, 82, 97, 110, 100, 111, 109, 32, 52, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 70, 108, 101, 117,
  114, 32, 45, 32, 80, 92, 51, 48, 51, 92, 50, 53, 49, 116, 97, 108,
  101, 115, 32, 47, 32, 70, 108, 111, 119, 101, 114, 32, 45, 32, 80, 101,
  116, 97, 108, 115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 76, 111, 110, 103, 117, 101, 117, 114,
  32, 112, 92, 51, 48, 51, 92, 50, 53, 49, 116, 97, 108, 101, 115, 32,
  47, 32, 108, 101, 110, 103, 116, 104, 32, 112, 101, 116, 97, 108, 115, 32,
  109, 105, 110, 46, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 53, 44,
  49, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  76, 111, 110, 103, 117, 101, 117, 114, 32, 112, 92, 51, 48, 51, 92, 50,
  53, 49, 116, 97, 108, 101, 115, 32, 47, 32, 108, 101, 110, 103, 116, 104,
  32, 112, 101, 116, 97, 108, 115, 32, 109, 97, 120, 46, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 50, 48, 44, 49, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 76, 97, 114, 103, 101, 117, 114, 32,
  112, 92, 51, 48, 51, 92, 50, 53, 49, 116, 97, 108, 101, 115, 32, 47,
  32, 119, 105, 100, 116, 104, 32, 112, 101, 116, 97, 108, 115, 32, 40, 37,
  41, 32, 109, 105, 110, 46, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  53, 44, 49, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 76, 97, 114, 103, 101, 117, 114, 32, 112, 92, 51, 48, 51, 92,
  50, 53, 49, 116, 97, 108, 101, 115, 32, 47, 32, 119, 105, 100, 116, 104,
  32, 112, 101, 116, 97, 108, 115, 32, 40, 37, 41, 32, 109, 97, 120, 46,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 48, 44, 49, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 115, 112,
  97, 99, 101, 109, 101, 110, 116, 32, 100, 117, 32, 99, 101, 110, 116, 114,
  101, 32, 47, 32, 99, 101, 110, 116, 101, 114, 32, 115, 112, 97, 99, 105,
  110, 103, 32, 109, 105, 110, 46, 32, 61, 32, 105, 110, 116, 40, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  69, 115, 112, 97, 99, 101, 109, 101, 110, 116, 32, 100, 117, 32, 99, 101,
  110, 116, 114, 101, 32, 47, 32, 99, 101, 110, 116, 101, 114, 32, 115, 112,
  97, 99, 105, 110, 103, 32, 109, 97, 120, 46, 32, 61, 32, 105, 110, 116,
  40, 49, 53, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 86, 97, 114, 105, 97, 116, 105, 111, 110, 32, 108, 111,
  110, 103, 117, 101, 117, 114, 32, 47, 32, 108, 101, 110, 103, 116, 104, 32,
  118, 97, 114, 105, 97, 116, 105, 111, 110, 32, 40, 37, 41, 32, 109, 105,
  110, 46, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 114, 105, 97,
  116, 105, 111, 110, 32, 108, 111, 110, 103, 117, 101, 117, 114, 32, 47, 32,
  108, 101, 110, 103, 116, 104, 32, 118, 97, 114, 105, 97, 116, 105, 111, 110,
  32, 40, 37, 41, 32, 109, 97, 120, 46, 32, 61, 32, 105, 110, 116, 40,
  50, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 86, 97, 114, 105, 97, 116, 105, 111, 110, 32, 92, 51, 48,
  51, 92, 50, 53, 49, 112, 97, 105, 115, 115, 101, 117, 114, 32, 47, 32,
  116, 104, 105, 99, 107, 110, 101, 115, 115, 32, 118, 97, 114, 105, 97, 116,
  105, 111, 110, 32, 40, 37, 41, 32, 109, 105, 110, 46, 32, 61, 32, 105,
  110, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 86, 97, 114, 105, 97, 116, 105, 111, 110, 32, 92,
  51, 48, 51, 92, 50, 53, 49, 112, 97, 105, 115, 115, 101, 117, 114, 32,
  47, 32, 116, 104, 105, 99, 107, 110, 101, 115, 115, 32, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 32, 40, 37, 41, 32, 109, 97, 120, 46, 32, 61,
  32, 105, 110, 116, 40, 49, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 114, 105, 97, 116, 105, 111,
  110, 32, 97, 110, 103, 108, 101, 32, 40, 100, 101, 103, 46, 41, 32, 109,
  105, 110, 46, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 49, 56,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 114, 105,
  97, 116, 105, 111, 110, 32, 97, 110, 103, 108, 101, 32, 40, 100, 101, 103,
  46, 41, 32, 109, 97, 120, 46, 32, 61, 32, 105, 110, 116, 40, 51, 44,
  48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  65, 103, 114, 97, 110, 100, 105, 115, 115, 101, 109, 101, 110, 116, 32, 112,
  92, 51, 48, 51, 92, 50, 53, 49, 116, 97, 108, 101, 115, 32, 47, 32,
  101, 120, 112, 97, 110, 115, 105, 111, 110, 32, 112, 101, 116, 97, 108, 115,
  32, 109, 105, 110, 46, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  49, 44, 48, 46, 49, 44, 48, 46, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 65, 103, 114, 97, 110, 100, 105, 115, 115, 101, 109, 101,
  110, 116, 32, 112, 92, 51, 48, 51, 92, 50, 53, 49, 116, 97, 108, 101,
  115, 32, 47, 32, 101, 120, 112, 97, 110, 115, 105, 111, 110, 32, 112, 101,
  116, 97, 108, 115, 32, 109, 97, 120, 46, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 49, 53, 44, 48, 46, 49, 44, 48, 46, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114,
  32, 112, 92, 51, 48, 51, 92, 50, 53, 49, 116, 97, 108, 101, 115, 32,
  61, 32, 99, 111, 108, 111, 114, 40, 50, 52, 56, 44, 50, 52, 56, 44,
  49, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 99, 101, 114, 99, 108, 101, 115, 32,
  47, 32, 99, 105, 114, 99, 108, 101, 115, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117,
  108, 101, 117, 114, 32, 99, 101, 114, 99, 108, 101, 32, 105, 110, 116, 92,
  51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32, 61, 32, 99,
  111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110,
  116, 111, 117, 114, 115, 32, 61, 32, 99, 111, 108, 111, 114, 40, 55, 53,
  44, 55, 53, 44, 49, 55, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 82, 97, 121, 111, 110, 32, 99, 101, 114, 99,
  108, 101, 32, 49, 32, 47, 32, 114, 97, 100, 105, 117, 115, 32, 99, 105,
  114, 99, 108, 101, 32, 49, 32, 40, 37, 41, 32, 109, 105, 110, 46, 32,
  61, 32, 105, 110, 116, 40, 49, 48, 48, 44, 48, 44, 49, 48, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 121, 111, 110,
  32, 99, 101, 114, 99, 108, 101, 32, 49, 32, 47, 32, 114, 97, 100, 105,
  117, 115, 32, 99, 105, 114, 99, 108, 101, 32, 49, 32, 40, 37, 41, 32,
  109, 97, 120, 46, 32, 61, 32, 105, 110, 116, 40, 49, 53, 48, 44, 48,
  44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  82, 97, 121, 111, 110, 32, 99, 101, 114, 99, 108, 101, 32, 50, 32, 47,
  32, 114, 97, 100, 105, 117, 115, 32, 99, 105, 114, 99, 108, 101, 32, 50,
  32, 40, 37, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 56, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  86, 97, 114, 105, 97, 116, 105, 111, 110, 32, 100, 101, 32, 99, 111, 117,
  108, 101, 117, 114, 32, 47, 32, 99, 111, 108, 111, 114, 32, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  48, 44, 34, 80, 97, 115, 32, 100, 101, 32, 118, 97, 114, 105, 97, 116,
  105, 111, 110, 32, 47, 32, 78, 111, 32, 99, 104, 97, 110, 103, 101, 34,
  44, 34, 67, 111, 117, 108, 101, 117, 114, 115, 32, 97, 108, 101, 97, 116,
  111, 105, 114, 101, 115, 32, 47, 32, 82, 97, 110, 100, 111, 109, 32, 99,
  111, 108, 111, 114, 115, 34, 44, 34, 70, 97, 105, 98, 108, 101, 109, 101,
  110, 116, 32, 110, 117, 97, 110, 99, 101, 101, 32, 47, 32, 80, 111, 111,
  114, 108, 121, 32, 110, 117, 97, 110, 99, 101, 100, 34, 44, 34, 77, 111,
  121, 101, 110, 110, 101, 109, 101, 110, 116, 32, 110, 117, 97, 110, 99, 101,
  101, 32, 47, 32, 77, 111, 100, 101, 114, 97, 116, 101, 108, 121, 32, 110,
  117, 97, 110, 99, 101, 100, 34, 44, 34, 70, 111, 114, 116, 101, 109, 101,
  110, 116, 32, 110, 117, 97, 110, 99, 101, 101, 32, 47, 32, 72, 105, 103,
  104, 108, 121, 32, 110, 117, 97, 110, 99, 101, 100, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 70, 108, 101, 117, 114, 115, 47, 102, 108,
  111, 119, 101, 114, 115, 32, 58, 32, 99, 111, 117, 108, 101, 117, 114, 115,
  32, 97, 108, 92, 51, 48, 51, 92, 50, 53, 49, 97, 116, 111, 105, 114,
  101, 115, 32, 47, 32, 114, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111,
  114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 102, 97, 108, 115, 101, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 68, 105, 118, 101, 114, 115, 32, 47, 32, 70, 111, 111, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 70, 108, 111, 117, 32, 47, 32, 98, 108, 117, 114, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 114, 101, 97, 100, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 102, 111, 114, 109, 97, 116,
  105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 112, 97,
  105, 115, 115, 101, 117, 114, 32, 47, 32, 116, 104, 105, 99, 107, 110, 101,
  115, 115, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 54, 52, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 66, 108, 101, 110, 100, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 100, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 65, 100, 100, 34, 44,
  34, 65, 108, 112, 104, 97, 34, 44, 34, 65, 110, 100, 34, 44, 34, 65,
  118, 101, 114, 97, 103, 101, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34,
  66, 117, 114, 110, 34, 44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34,
  68, 105, 102, 102, 101, 114, 101, 110, 99, 101, 34, 44, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 34, 68, 105, 118, 105, 100, 101, 34, 44, 34,
  68, 111, 100, 103, 101, 34, 44, 34, 69, 120, 99, 108, 117, 115, 105, 111,
  110, 34, 44, 34, 70, 114, 101, 101, 122, 101, 34, 44, 34, 71, 114, 97,
  105, 110, 32, 101, 120, 116, 114, 97, 99, 116, 34, 44, 34, 71, 114, 97,
  105, 110, 32, 109, 101, 114, 103, 101, 34, 44, 34, 71, 114, 101, 101, 110,
  34, 44, 34, 72, 97, 114, 100, 32, 108, 105, 103, 104, 116, 34, 44, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 72, 97, 114, 100, 32, 109,
  105, 120, 34, 44, 34, 72, 117, 101, 34, 44, 34, 73, 110, 116, 101, 114,
  112, 111, 108, 97, 116, 105, 111, 110, 34, 44, 34, 76, 105, 103, 104, 116,
  101, 110, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44,
  34, 76, 105, 110, 101, 97, 114, 32, 98, 117, 114, 110, 34, 44, 34, 76,
  105, 110, 101, 97, 114, 32, 108, 105, 103, 104, 116, 34, 44, 34, 76, 117,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 34, 77, 117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 78,
  101, 103, 97, 116, 105, 111, 110, 34, 44, 34, 79, 114, 34, 44, 34, 79,
  118, 101, 114, 108, 97, 121, 34, 44, 34, 80, 105, 110, 32, 108, 105, 103,
  104, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 82, 101, 102, 108, 101,
  99, 116, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34,
  44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 83, 104, 97, 112,
  101, 32, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 83, 104, 97, 112,
  101, 32, 65, 118, 101, 114, 97, 103, 101, 48, 34, 44, 34, 83, 111, 102,
  116, 32, 98, 117, 114, 110, 34, 44, 34, 83, 111, 102, 116, 32, 100, 111,
  100, 103, 101, 34, 44, 34, 83, 111, 102, 116, 32, 108, 105, 103, 104, 116,
  34, 44, 34, 83, 99, 114, 101, 101, 110, 34, 44, 34, 83, 116, 97, 109,
  112, 34, 44, 34, 83, 117, 98, 116, 114, 97, 99, 116, 34, 44, 34, 86,
  97, 108, 117, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  34, 86, 105, 118, 105, 100, 32, 108, 105, 103, 104, 116, 34, 44, 34, 88,
  111, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112,
  97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44,
  48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101,
  118, 101, 114, 116, 32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111,
  111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 83, 97,
  109, 106, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62,
  50, 48, 49, 52, 47, 48, 49, 47, 49, 55, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 82, 101, 109, 112, 108, 105,
  114, 95, 70, 108, 101, 117, 114, 115, 95, 50, 95, 115, 97, 109, 106, 58,
  10, 78, 111, 109, 98, 114, 101, 95, 70, 108, 101, 117, 114, 115, 61, 36,
  49, 10, 84, 111, 117, 114, 115, 95, 109, 105, 110, 61, 36, 50, 10, 84,
  111, 117, 114, 115, 95, 109, 97, 120, 61, 36, 51, 10, 73, 110, 99, 114,
  101, 109, 101, 110, 116, 95, 97, 110, 103, 117, 108, 97, 105, 114, 101, 95,
  109, 105, 110, 61, 36, 52, 10, 73, 110, 99, 114, 101, 109, 101, 110, 116,
  95, 97, 110, 103, 117, 108, 97, 105, 114, 101, 95, 109, 97, 120, 61, 36,
  53, 10, 67, 111, 101, 102, 102, 95, 97, 103, 114, 97, 110, 100, 105, 115,
  115, 101, 109, 101, 110, 116, 95, 109, 105, 110, 61, 36, 54, 10, 67, 111,
  101, 102, 102, 95, 97, 103, 114, 97, 110, 100, 105, 115, 115, 101, 109, 101,
  110, 116, 95, 109, 97, 120, 61, 36, 55, 10, 83, 101, 110, 115, 95, 100,
  101, 95, 114, 111, 116, 97, 116, 105, 111, 110, 61, 36, 56, 10, 76, 111,
  110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109,
  105, 110, 61, 36, 57, 10, 76, 111, 110, 103, 117, 101, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 95, 109, 97, 120, 61, 36, 49, 48, 10, 76,
  97, 114, 103, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109,
  105, 110, 61, 36, 49, 49, 10, 76, 97, 114, 103, 101, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 95, 109, 97, 120, 61, 36, 49, 50, 10, 69,
  115, 112, 97, 99, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101, 110,
  116, 114, 101, 95, 109, 105, 110, 61, 36, 49, 51, 10, 69, 115, 112, 97,
  99, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101,
  95, 109, 97, 120, 61, 36, 49, 52, 10, 86, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 108, 111, 110, 103, 117, 101, 117, 114, 95, 109, 105, 110, 61,
  36, 49, 53, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 108, 111,
  110, 103, 117, 101, 117, 114, 95, 109, 97, 120, 61, 36, 49, 54, 10, 86,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 101, 112, 97, 105, 115, 115, 101,
  117, 114, 95, 109, 105, 110, 61, 36, 49, 55, 10, 86, 97, 114, 105, 97,
  116, 105, 111, 110, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114, 95, 109,
  97, 120, 61, 36, 49, 56, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 97, 110, 103, 108, 101, 95, 109, 105, 110, 61, 36, 49, 57, 10, 86,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 97, 110, 103, 108, 101, 95, 109,
  97, 120, 61, 36, 50, 48, 10, 65, 103, 114, 97, 110, 100, 105, 115, 115,
  101, 109, 101, 110, 116, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 105,
  110, 61, 36, 50, 49, 10, 65, 103, 114, 97, 110, 100, 105, 115, 115, 101,
  109, 101, 110, 116, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 97, 120,
  61, 36, 50, 50, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 61, 36, 50, 51, 10, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 50, 52,
  10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108,
  101, 115, 61, 36, 50, 53, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 50, 54, 10, 82, 95, 67,
  73, 95, 112, 108, 101, 105, 110, 61, 36, 50, 55, 10, 86, 95, 67, 73,
  95, 112, 108, 101, 105, 110, 61, 36, 50, 56, 10, 66, 95, 67, 73, 95,
  112, 108, 101, 105, 110, 61, 36, 50, 57, 10, 65, 95, 67, 73, 95, 112,
  108, 101, 105, 110, 61, 36, 51, 48, 10, 82, 95, 67, 73, 95, 99, 111,
  110, 116, 111, 117, 114, 61, 36, 51, 49, 10, 86, 95, 67, 73, 95, 99,
  111, 110, 116, 111, 117, 114, 61, 36, 51, 50, 10, 66, 95, 67, 73, 95,
  99, 111, 110, 116, 111, 117, 114, 61, 36, 51, 51, 10, 65, 95, 67, 73,
  95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 51, 52, 10, 82, 97, 121,
  111, 110, 95, 103, 114, 97, 110, 100, 95, 99, 101, 114, 99, 108, 101, 95,
  109, 105, 110, 61, 123, 36, 51, 53, 42, 36, 57, 47, 49, 48, 48, 125,
  10, 82, 97, 121, 111, 110, 95, 103, 114, 97, 110, 100, 95, 99, 101, 114,
  99, 108, 101, 95, 109, 97, 120, 61, 123, 36, 51, 54, 42, 36, 57, 47,
  49, 48, 48, 125, 10, 82, 97, 121, 111, 110, 95, 112, 101, 116, 105, 116,
  95, 99, 101, 114, 99, 108, 101, 61, 36, 51, 55, 10, 86, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114,
  61, 36, 51, 56, 10, 67, 111, 117, 108, 101, 117, 114, 115, 95, 97, 108,
  101, 97, 116, 111, 105, 114, 101, 115, 61, 36, 51, 57, 10, 70, 108, 111,
  117, 95, 102, 108, 101, 117, 114, 61, 36, 52, 48, 10, 83, 112, 114, 101,
  97, 100, 95, 102, 108, 101, 117, 114, 61, 36, 52, 49, 10, 68, 101, 102,
  111, 114, 109, 95, 102, 108, 101, 117, 114, 61, 36, 52, 50, 10, 69, 112,
  97, 105, 115, 115, 101, 117, 114, 61, 36, 52, 51, 10, 98, 108, 101, 110,
  100, 61, 36, 52, 52, 10, 111, 112, 97, 99, 105, 116, 101, 61, 36, 52,
  53, 10, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 61,
  36, 52, 54, 10, 35, 32, 86, 97, 114, 105, 97, 98, 108, 101, 115, 32,
  99, 97, 108, 99, 117, 108, -23, 101, 115, 10, 76, 97, 114, 103, 101, 117,
  114, 95, 111, 114, 105, 103, 105, 110, 101, 61, 123, 119, 125, 10, 72, 97,
  117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 61, 123, 104,
  125, 10, 82, 95, 67, 69, 95, 112, 108, 101, 105, 110, 61, 36, 82, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 10,
  86, 95, 67, 69, 95, 112, 108, 101, 105, 110, 61, 36, 86, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 10, 66, 95,
  67, 69, 95, 112, 108, 101, 105, 110, 61, 36, 66, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 10, 65, 95, 67, 69,
  95, 112, 108, 101, 105, 110, 61, 36, 65, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 112, 101, 116, 97, 108, 101, 115, 10, 45, 105, 102, 32, 123, 36,
  84, 111, 117, 114, 115, 95, 109, 105, 110, 62, 36, 84, 111, 117, 114, 115,
  95, 109, 97, 120, 125, 10, 109, 105, 110, 61, 36, 84, 111, 117, 114, 115,
  95, 109, 97, 120, 10, 84, 111, 117, 114, 115, 95, 109, 97, 120, 61, 36,
  84, 111, 117, 114, 115, 95, 109, 105, 110, 10, 84, 111, 117, 114, 115, 95,
  109, 105, 110, 61, 36, 109, 105, 110, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95,
  97, 110, 103, 117, 108, 97, 105, 114, 101, 95, 109, 105, 110, 62, 36, 73,
  110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 117, 108, 97, 105,
  114, 101, 95, 109, 97, 120, 125, 10, 109, 105, 110, 61, 36, 73, 110, 99,
  114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 117, 108, 97, 105, 114, 101,
  95, 109, 97, 120, 10, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97,
  110, 103, 117, 108, 97, 105, 114, 101, 95, 109, 97, 120, 61, 36, 73, 110,
  99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 117, 108, 97, 105, 114,
  101, 95, 109, 105, 110, 10, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95,
  97, 110, 103, 117, 108, 97, 105, 114, 101, 95, 109, 105, 110, 61, 36, 109,
  105, 110, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  67, 111, 101, 102, 102, 95, 97, 103, 114, 97, 110, 100, 105, 115, 115, 101,
  109, 101, 110, 116, 95, 109, 105, 110, 62, 36, 67, 111, 101, 102, 102, 95,
  97, 103, 114, 97, 110, 100, 105, 115, 115, 101, 109, 101, 110, 116, 95, 109,
  97, 120, 125, 10, 109, 105, 110, 61, 36, 67, 111, 101, 102, 102, 95, 97,
  103, 114, 97, 110, 100, 105, 115, 115, 101, 109, 101, 110, 116, 95, 109, 97,
  120, 10, 67, 111, 101, 102, 102, 95, 97, 103, 114, 97, 110, 100, 105, 115,
  115, 101, 109, 101, 110, 116, 95, 109, 97, 120, 61, 36, 67, 111, 101, 102,
  102, 95, 97, 103, 114, 97, 110, 100, 105, 115, 115, 101, 109, 101, 110, 116,
  95, 109, 105, 110, 10, 67, 111, 101, 102, 102, 95, 97, 103, 114, 97, 110,
  100, 105, 115, 115, 101, 109, 101, 110, 116, 95, 109, 105, 110, 61, 36, 109,
  105, 110, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  76, 111, 110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  95, 109, 105, 110, 62, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 95, 109, 97, 120, 125, 10, 109, 105, 110, 61,
  36, 76, 111, 110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101,
  115, 95, 109, 97, 120, 10, 76, 111, 110, 103, 117, 101, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 95, 109, 97, 120, 61, 36, 76, 111, 110, 103,
  117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 105, 110,
  10, 76, 111, 110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101,
  115, 95, 109, 105, 110, 61, 36, 109, 105, 110, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 76, 97, 114, 103, 101, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 95, 109, 105, 110, 62, 36, 76, 97, 114,
  103, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 97, 120,
  125, 10, 109, 105, 110, 61, 36, 76, 97, 114, 103, 101, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 95, 109, 97, 120, 10, 76, 97, 114, 103, 101,
  117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 97, 120, 61, 36,
  76, 97, 114, 103, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95,
  109, 105, 110, 10, 76, 97, 114, 103, 101, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 95, 109, 105, 110, 61, 36, 109, 105, 110, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 69, 115, 112, 97, 99, 101,
  109, 101, 110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101, 95, 109,
  105, 110, 62, 36, 69, 115, 112, 97, 99, 101, 109, 101, 110, 116, 95, 100,
  117, 95, 99, 101, 110, 116, 114, 101, 95, 109, 97, 120, 125, 10, 109, 105,
  110, 61, 36, 69, 115, 112, 97, 99, 101, 109, 101, 110, 116, 95, 100, 117,
  95, 99, 101, 110, 116, 114, 101, 95, 109, 97, 120, 10, 69, 115, 112, 97,
  99, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101,
  95, 109, 97, 120, 61, 36, 69, 115, 112, 97, 99, 101, 109, 101, 110, 116,
  95, 100, 117, 95, 99, 101, 110, 116, 114, 101, 95, 109, 105, 110, 10, 69,
  115, 112, 97, 99, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101, 110,
  116, 114, 101, 95, 109, 105, 110, 61, 36, 109, 105, 110, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 108, 111, 110, 103, 117, 101, 117, 114, 95, 109, 105, 110,
  62, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 108, 111, 110, 103,
  117, 101, 117, 114, 95, 109, 97, 120, 125, 10, 109, 105, 110, 61, 36, 86,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 108, 111, 110, 103, 117, 101, 117,
  114, 95, 109, 97, 120, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  108, 111, 110, 103, 117, 101, 117, 114, 95, 109, 97, 120, 61, 36, 86, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 108, 111, 110, 103, 117, 101, 117, 114,
  95, 109, 105, 110, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 108,
  111, 110, 103, 117, 101, 117, 114, 95, 109, 105, 110, 61, 36, 109, 105, 110,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 101, 112, 97, 105, 115, 115, 101, 117,
  114, 95, 109, 105, 110, 62, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 101, 112, 97, 105, 115, 115, 101, 117, 114, 95, 109, 97, 120, 125, 10,
  109, 105, 110, 61, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 101,
  112, 97, 105, 115, 115, 101, 117, 114, 95, 109, 97, 120, 10, 86, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114,
  95, 109, 97, 120, 61, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  101, 112, 97, 105, 115, 115, 101, 117, 114, 95, 109, 105, 110, 10, 86, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 101, 112, 97, 105, 115, 115, 101, 117,
  114, 95, 109, 105, 110, 61, 36, 109, 105, 110, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 97, 110, 103, 108, 101, 95, 109, 105, 110, 62, 36, 86, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 97, 110, 103, 108, 101, 95, 109, 97, 120,
  125, 10, 109, 105, 110, 61, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 97, 110, 103, 108, 101, 95, 109, 97, 120, 10, 86, 97, 114, 105, 97,
  116, 105, 111, 110, 95, 97, 110, 103, 108, 101, 95, 109, 97, 120, 61, 36,
  86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 97, 110, 103, 108, 101, 95,
  109, 105, 110, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 97, 110,
  103, 108, 101, 95, 109, 105, 110, 61, 36, 109, 105, 110, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 65, 103, 114, 97, 110, 100,
  105, 115, 115, 101, 109, 101, 110, 116, 95, 112, 101, 116, 97, 108, 101, 115,
  95, 109, 105, 110, 62, 36, 65, 103, 114, 97, 110, 100, 105, 115, 115, 101,
  109, 101, 110, 116, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 97, 120,
  125, 10, 109, 105, 110, 61, 36, 65, 103, 114, 97, 110, 100, 105, 115, 115,
  101, 109, 101, 110, 116, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 97,
  120, 10, 65, 103, 114, 97, 110, 100, 105, 115, 115, 101, 109, 101, 110, 116,
  95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 97, 120, 61, 36, 65, 103,
  114, 97, 110, 100, 105, 115, 115, 101, 109, 101, 110, 116, 95, 112, 101, 116,
  97, 108, 101, 115, 95, 109, 105, 110, 10, 65, 103, 114, 97, 110, 100, 105,
  115, 115, 101, 109, 101, 110, 116, 95, 112, 101, 116, 97, 108, 101, 115, 95,
  109, 105, 110, 61, 36, 109, 105, 110, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 82, 97, 121, 111, 110, 95, 103, 114, 97, 110,
  100, 95, 99, 101, 114, 99, 108, 101, 95, 109, 105, 110, 62, 36, 82, 97,
  121, 111, 110, 95, 103, 114, 97, 110, 100, 95, 99, 101, 114, 99, 108, 101,
  95, 109, 97, 120, 125, 10, 109, 105, 110, 61, 36, 82, 97, 121, 111, 110,
  95, 103, 114, 97, 110, 100, 95, 99, 101, 114, 99, 108, 101, 95, 109, 97,
  120, 10, 82, 97, 121, 111, 110, 95, 103, 114, 97, 110, 100, 95, 99, 101,
  114, 99, 108, 101, 95, 109, 97, 120, 61, 36, 82, 97, 121, 111, 110, 95,
  103, 114, 97, 110, 100, 95, 99, 101, 114, 99, 108, 101, 95, 109, 105, 110,
  10, 82, 97, 121, 111, 110, 95, 103, 114, 97, 110, 100, 95, 99, 101, 114,
  99, 108, 101, 95, 109, 105, 110, 61, 36, 109, 105, 110, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 116, 111, 95, 114, 103, 98, 97, 10, 36, 76, 97,
  114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 44, 36, 72,
  97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 44, 49,
  44, 52, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 78, 111, 109, 98,
  114, 101, 95, 70, 108, 101, 117, 114, 115, 10, 36, 76, 97, 114, 103, 101,
  117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 44, 36, 72, 97, 117, 116,
  101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 44, 49, 44, 52, 10,
  45, 105, 102, 32, 123, 36, 67, 111, 117, 108, 101, 117, 114, 115, 95, 97,
  108, 101, 97, 116, 111, 105, 114, 101, 115, 61, 61, 49, 125, 10, 82, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61,
  123, 114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 53, 53, 41, 41,
  125, 41, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 61, 123, 114, 111, 117, 110, 100, 40, 123, 40, 63,
  40, 50, 53, 53, 41, 41, 125, 41, 125, 10, 66, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 123, 114, 111, 117,
  110, 100, 40, 123, 40, 63, 40, 50, 53, 53, 41, 41, 125, 41, 125, 10,
  82, 95, 67, 73, 95, 112, 108, 101, 105, 110, 61, 123, 114, 111, 117, 110,
  100, 40, 123, 40, 63, 40, 50, 53, 53, 41, 41, 125, 41, 125, 10, 86,
  95, 67, 73, 95, 112, 108, 101, 105, 110, 61, 123, 114, 111, 117, 110, 100,
  40, 123, 40, 63, 40, 50, 53, 53, 41, 41, 125, 41, 125, 10, 66, 95,
  67, 73, 95, 112, 108, 101, 105, 110, 61, 123, 114, 111, 117, 110, 100, 40,
  123, 40, 63, 40, 50, 53, 53, 41, 41, 125, 41, 125, 10, 65, 95, 67,
  73, 95, 112, 108, 101, 105, 110, 61, 123, 123, 114, 111, 117, 110, 100, 40,
  123, 40, 63, 40, 50, 48, 48, 41, 41, 125, 41, 125, 43, 53, 53, 125,
  10, 65, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 61, 123, 123,
  114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 48, 48, 41, 41, 125,
  41, 125, 43, 53, 53, 125, 10, 82, 95, 67, 69, 95, 112, 108, 101, 105,
  110, 61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116,
  97, 108, 101, 115, 10, 86, 95, 67, 69, 95, 112, 108, 101, 105, 110, 61,
  36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108,
  101, 115, 10, 66, 95, 67, 69, 95, 112, 108, 101, 105, 110, 61, 36, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  10, 65, 95, 67, 69, 95, 112, 108, 101, 105, 110, 61, 36, 65, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 10, 45,
  101, 110, 100, 105, 102, 10, 116, 111, 117, 114, 115, 61, 123, 36, 84, 111,
  117, 114, 115, 95, 109, 105, 110, 43, 123, 114, 111, 117, 110, 100, 40, 63,
  40, 123, 36, 84, 111, 117, 114, 115, 95, 109, 97, 120, 45, 36, 84, 111,
  117, 114, 115, 95, 109, 105, 110, 125, 41, 41, 125, 125, 10, 105, 110, 99,
  114, 101, 109, 101, 110, 116, 95, 116, 104, 101, 116, 97, 61, 123, 36, 73,
  110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 117, 108, 97, 105,
  114, 101, 95, 109, 105, 110, 43, 123, 63, 40, 123, 36, 73, 110, 99, 114,
  101, 109, 101, 110, 116, 95, 97, 110, 103, 117, 108, 97, 105, 114, 101, 95,
  109, 97, 120, 45, 36, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97,
  110, 103, 117, 108, 97, 105, 114, 101, 95, 109, 105, 110, 125, 41, 125, 125,
  10, 99, 111, 101, 102, 102, 95, 100, 105, 109, 61, 123, 36, 67, 111, 101,
  102, 102, 95, 97, 103, 114, 97, 110, 100, 105, 115, 115, 101, 109, 101, 110,
  116, 95, 109, 105, 110, 43, 123, 63, 40, 123, 36, 67, 111, 101, 102, 102,
  95, 97, 103, 114, 97, 110, 100, 105, 115, 115, 101, 109, 101, 110, 116, 95,
  109, 97, 120, 45, 36, 67, 111, 101, 102, 102, 95, 97, 103, 114, 97, 110,
  100, 105, 115, 115, 101, 109, 101, 110, 116, 95, 109, 105, 110, 125, 41, 125,
  125, 10, 115, 101, 110, 115, 95, 114, 111, 116, 97, 116, 105, 111, 110, 61,
  123, 114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 36, 83, 101, 110, 115,
  95, 100, 101, 95, 114, 111, 116, 97, 116, 105, 111, 110, 41, 41, 125, 41,
  125, 10, 76, 111, 110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108,
  101, 115, 61, 123, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 95, 109, 105, 110, 43, 123, 63, 40, 123, 36, 76,
  111, 110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95,
  109, 97, 120, 45, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 95, 109, 105, 110, 125, 41, 125, 125, 10, 76, 97,
  114, 103, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 123, 36,
  76, 97, 114, 103, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95,
  109, 105, 110, 43, 123, 63, 40, 123, 36, 76, 97, 114, 103, 101, 117, 114,
  95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 97, 120, 45, 36, 76, 97,
  114, 103, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 105,
  110, 125, 41, 125, 125, 10, 69, 115, 112, 97, 99, 101, 109, 101, 110, 116,
  95, 100, 117, 95, 99, 101, 110, 116, 114, 101, 61, 123, 36, 69, 115, 112,
  97, 99, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114,
  101, 95, 109, 105, 110, 43, 123, 114, 111, 117, 110, 100, 40, 63, 40, 123,
  36, 69, 115, 112, 97, 99, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99,
  101, 110, 116, 114, 101, 95, 109, 97, 120, 45, 36, 69, 115, 112, 97, 99,
  101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101, 95,
  109, 105, 110, 125, 41, 41, 125, 125, 10, 86, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 108, 111, 110, 103, 117, 101, 117, 114, 61, 123, 36, 86, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 108, 111, 110, 103, 117, 101, 117, 114,
  95, 109, 105, 110, 43, 123, 114, 111, 117, 110, 100, 40, 63, 40, 123, 36,
  86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 108, 111, 110, 103, 117, 101,
  117, 114, 95, 109, 97, 120, 45, 36, 86, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 108, 111, 110, 103, 117, 101, 117, 114, 95, 109, 105, 110, 125, 41,
  41, 125, 125, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 101, 112,
  97, 105, 115, 115, 101, 117, 114, 61, 123, 36, 86, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114, 95, 109, 105,
  110, 43, 123, 114, 111, 117, 110, 100, 40, 63, 40, 123, 36, 86, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114,
  95, 109, 97, 120, 45, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  101, 112, 97, 105, 115, 115, 101, 117, 114, 95, 109, 105, 110, 125, 41, 41,
  125, 125, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 97, 110, 103,
  108, 101, 61, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 97,
  110, 103, 108, 101, 95, 109, 105, 110, 43, 123, 114, 111, 117, 110, 100, 40,
  63, 40, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 97, 110,
  103, 108, 101, 95, 109, 97, 120, 45, 36, 86, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 97, 110, 103, 108, 101, 95, 109, 105, 110, 125, 41, 41, 125,
  125, 10, 65, 103, 114, 97, 110, 100, 105, 115, 115, 101, 109, 101, 110, 116,
  95, 112, 101, 116, 97, 108, 101, 115, 61, 123, 36, 65, 103, 114, 97, 110,
  100, 105, 115, 115, 101, 109, 101, 110, 116, 95, 112, 101, 116, 97, 108, 101,
  115, 95, 109, 105, 110, 43, 123, 63, 40, 123, 36, 65, 103, 114, 97, 110,
  100, 105, 115, 115, 101, 109, 101, 110, 116, 95, 112, 101, 116, 97, 108, 101,
  115, 95, 109, 97, 120, 45, 36, 65, 103, 114, 97, 110, 100, 105, 115, 115,
  101, 109, 101, 110, 116, 95, 112, 101, 116, 97, 108, 101, 115, 95, 109, 105,
  110, 125, 41, 125, 125, 10, 82, 101, 109, 112, 108, 105, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 61, 49, 10, 67, 111, 110, 116, 111, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 61, 49, 10, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 61, 36, 82, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117,
  114, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116,
  111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 86, 95, 67,
  73, 95, 99, 111, 110, 116, 111, 117, 114, 10, 66, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 61, 36, 66, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117,
  114, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116,
  111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 65, 95, 67,
  73, 95, 99, 111, 110, 116, 111, 117, 114, 10, 82, 101, 109, 112, 108, 105,
  114, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101,
  117, 114, 61, 49, 10, 67, 111, 110, 116, 111, 117, 114, 95, 99, 101, 114,
  99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 49, 10,
  82, 101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108, 101, 95, 101,
  120, 116, 101, 114, 105, 101, 117, 114, 61, 49, 10, 67, 111, 110, 116, 111,
  117, 114, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105,
  101, 117, 114, 61, 48, 10, 82, 95, 67, 69, 95, 99, 111, 110, 116, 111,
  117, 114, 61, 48, 10, 86, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117,
  114, 61, 48, 10, 66, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114,
  61, 48, 10, 65, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 61,
  50, 53, 53, 10, 82, 97, 121, 111, 110, 95, 103, 114, 97, 110, 100, 95,
  99, 101, 114, 99, 108, 101, 61, 123, 36, 82, 97, 121, 111, 110, 95, 103,
  114, 97, 110, 100, 95, 99, 101, 114, 99, 108, 101, 95, 109, 105, 110, 43,
  123, 114, 111, 117, 110, 100, 40, 63, 40, 123, 36, 82, 97, 121, 111, 110,
  95, 103, 114, 97, 110, 100, 95, 99, 101, 114, 99, 108, 101, 95, 109, 97,
  120, 45, 36, 82, 97, 121, 111, 110, 95, 103, 114, 97, 110, 100, 95, 99,
  101, 114, 99, 108, 101, 95, 109, 105, 110, 125, 41, 41, 125, 125, 10, 45,
  102, 108, 111, 119, 101, 114, 95, 115, 112, 105, 114, 97, 108, 95, 112, 97,
  116, 116, 101, 114, 110, 95, 115, 97, 109, 106, 32, 36, 116, 111, 117, 114,
  115, 44, 36, 105, 110, 99, 114, 101, 109, 101, 110, 116, 95, 116, 104, 101,
  116, 97, 44, 36, 99, 111, 101, 102, 102, 95, 100, 105, 109, 44, 36, 115,
  101, 110, 115, 95, 114, 111, 116, 97, 116, 105, 111, 110, 44, 36, 76, 111,
  110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36,
  76, 97, 114, 103, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44,
  36, 69, 115, 112, 97, 99, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99,
  101, 110, 116, 114, 101, 44, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 108, 111, 110, 103, 117, 101, 117, 114, 44, 36, 86, 97, 114, 105, 97,
  116, 105, 111, 110, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114, 44, 36,
  86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 97, 110, 103, 108, 101, 44,
  36, 65, 103, 114, 97, 110, 100, 105, 115, 115, 101, 109, 101, 110, 116, 95,
  112, 101, 116, 97, 108, 101, 115, 44, 36, 82, 101, 109, 112, 108, 105, 114,
  95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 86, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101,
  115, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116,
  97, 108, 101, 115, 44, 36, 67, 111, 110, 116, 111, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116,
  111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101,
  115, 44, 36, 82, 101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108,
  101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 36, 82, 95, 67,
  73, 95, 112, 108, 101, 105, 110, 44, 36, 86, 95, 67, 73, 95, 112, 108,
  101, 105, 110, 44, 36, 66, 95, 67, 73, 95, 112, 108, 101, 105, 110, 44,
  36, 65, 95, 67, 73, 95, 112, 108, 101, 105, 110, 44, 36, 67, 111, 110,
  116, 111, 117, 114, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101,
  114, 105, 101, 117, 114, 44, 36, 82, 95, 67, 73, 95, 99, 111, 110, 116,
  111, 117, 114, 44, 36, 86, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117,
  114, 44, 36, 66, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 44,
  36, 65, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 82,
  101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120,
  116, 101, 114, 105, 101, 117, 114, 44, 36, 82, 95, 67, 69, 95, 112, 108,
  101, 105, 110, 44, 36, 86, 95, 67, 69, 95, 112, 108, 101, 105, 110, 44,
  36, 66, 95, 67, 69, 95, 112, 108, 101, 105, 110, 44, 36, 65, 95, 67,
  69, 95, 112, 108, 101, 105, 110, 44, 36, 67, 111, 110, 116, 111, 117, 114,
  95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117,
  114, 44, 36, 82, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 44,
  36, 86, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 66,
  95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 65, 95, 67,
  69, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 82, 97, 121, 111, 110,
  95, 103, 114, 97, 110, 100, 95, 99, 101, 114, 99, 108, 101, 44, 36, 82,
  97, 121, 111, 110, 95, 112, 101, 116, 105, 116, 95, 99, 101, 114, 99, 108,
  101, 44, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95,
  99, 111, 117, 108, 101, 117, 114, 10, 45, 97, 117, 116, 111, 99, 114, 111,
  112, 91, 45, 49, 93, 10, 80, 111, 115, 105, 116, 105, 111, 110, 95, 88,
  61, 123, 123, 114, 111, 117, 110, 100, 40, 63, 40, 123, 36, 76, 97, 114,
  103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 43, 123, 119, 125,
  125, 41, 41, 125, 45, 123, 119, 125, 125, 10, 80, 111, 115, 105, 116, 105,
  111, 110, 95, 89, 61, 123, 123, 114, 111, 117, 110, 100, 40, 63, 40, 123,
  36, 72, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101,
  43, 123, 104, 125, 125, 41, 41, 125, 45, 123, 104, 125, 125, 10, 45, 105,
  109, 97, 103, 101, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 80,
  111, 115, 105, 116, 105, 111, 110, 95, 88, 44, 36, 80, 111, 115, 105, 116,
  105, 111, 110, 95, 89, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 99,
  111, 109, 112, 111, 115, 101, 95, 97, 108, 112, 104, 97, 91, 45, 50, 44,
  45, 49, 93, 10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36,
  69, 112, 97, 105, 115, 115, 101, 117, 114, 62, 48, 125, 10, 45, 100, 105,
  108, 97, 116, 101, 95, 99, 105, 114, 99, 91, 45, 49, 93, 32, 36, 69,
  112, 97, 105, 115, 115, 101, 117, 114, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 70, 108, 111, 117, 95,
  102, 108, 101, 117, 114, 10, 45, 115, 112, 114, 101, 97, 100, 91, 45, 49,
  93, 32, 36, 83, 112, 114, 101, 97, 100, 95, 102, 108, 101, 117, 114, 10,
  45, 100, 101, 102, 111, 114, 109, 91, 45, 49, 93, 32, 36, 68, 101, 102,
  111, 114, 109, 95, 102, 108, 101, 117, 114, 10, 45, 103, 105, 109, 112, 95,
  98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 36, 98, 108,
  101, 110, 100, 44, 36, 111, 112, 97, 99, 105, 116, 101, 44, 36, 82, 101,
  118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 10, 35, 10, 35, 45,
  116, 101, 120, 116, 95, 111, 117, 116, 108, 105, 110, 101, 91, 48, 93, 32,
  36, 78, 111, 109, 98, 114, 101, 95, 70, 108, 101, 117, 114, 115, 44, 49,
  48, 44, 49, 48, 44, 54, 52, 44, 49, 44, 49, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 10, 35, 64, 103, 105, 109, 112, 32, 84,
  101, 115, 116, 32, 50, 32, 99, 97, 109, 111, 117, 102, 108, 97, 103, 101,
  32, 58, 32, 84, 101, 115, 116, 95, 67, 97, 109, 111, 117, 102, 108, 97,
  103, 101, 95, 50, 95, 115, 97, 109, 106, 44, 32, 84, 101, 115, 116, 95,
  67, 97, 109, 111, 117, 102, 108, 97, 103, 101, 95, 50, 95, 115, 97, 109,
  106, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 70, 111, 110, 100, 32, 47,
  32, 66, 97, 99, 107, 103, 114, 111, 117, 110, 100, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77,
  111, 116, 105, 102, 32, 47, 32, 112, 97, 116, 116, 101, 114, 110, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 77, 111, 116, 105, 102,
  32, 49, 34, 44, 34, 77, 111, 116, 105, 102, 32, 50, 32, 68, 101, 110,
  115, 101, 34, 44, 34, 77, 111, 116, 105, 102, 32, 51, 32, 76, 105, 103,
  110, 101, 115, 34, 44, 34, 77, 111, 116, 105, 102, 32, 52, 32, 66, 117,
  108, 108, 101, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  68, 105, 109, 101, 110, 115, 105, 111, 110, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 48, 44, 48, 44, 54, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 117, 105, 108, 32, 47, 32, 116, 104, 114,
  101, 115, 104, 111, 108, 100, 32, 61, 32, 105, 110, 116, 40, 52, 48, 44,
  49, 48, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 114, 109, 97, 108, 105, 122, 101, 32, 97, 32, 102, 111, 110,
  100, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 114, 109, 97, 108,
  105, 122, 101, 32, 98, 32, 102, 111, 110, 100, 32, 61, 32, 105, 110, 116,
  40, 49, 57, 50, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 101, 103, 97, 116, 105, 118, 101, 32, 61, 32,
  98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 82, 101, 110, 100, 117, 32, 47, 32,
  82, 101, 110, 100, 101, 114, 105, 110, 103, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 109,
  98, 114, 101, 32, 99, 111, 117, 108, 101, 117, 114, 115, 32, 47, 32, 110,
  117, 109, 98, 101, 114, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32, 105,
  110, 116, 40, 54, 52, 44, 50, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 86, 97, 114, 105, 97, 116, 105, 111, 110, 115,
  32, 99, 111, 117, 108, 101, 117, 114, 115, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 48, 44, 34, 86, 97, 114, 105, 97, 116, 105, 111, 110, 115,
  32, 49, 34, 44, 34, 86, 97, 114, 105, 97, 116, 105, 111, 110, 115, 32,
  50, 34, 44, 34, 86, 97, 114, 105, 97, 116, 105, 111, 110, 115, 32, 51,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 111, 114, 109,
  101, 115, 32, 61, 32, 105, 110, 116, 40, 52, 48, 44, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 84, 121, 112,
  101, 32, 49, 34, 44, 34, 84, 121, 112, 101, 32, 50, 32, 97, 118, 101,
  99, 32, 66, 108, 101, 110, 100, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  32, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 100,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 65, 100,
  100, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34, 65, 110, 100, 34,
  44, 34, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 66, 108, 117, 101,
  34, 44, 34, 66, 117, 114, 110, 34, 44, 34, 68, 97, 114, 107, 101, 110,
  34, 44, 34, 68, 105, 102, 102, 101, 114, 101, 110, 99, 101, 34, 44, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 68, 105, 118, 105, 100, 101,
  34, 44, 34, 68, 111, 100, 103, 101, 34, 44, 34, 69, 120, 99, 108, 117,
  115, 105, 111, 110, 34, 44, 34, 70, 114, 101, 101, 122, 101, 34, 44, 34,
  71, 114, 97, 105, 110, 32, 101, 120, 116, 114, 97, 99, 116, 34, 44, 34,
  71, 114, 97, 105, 110, 32, 109, 101, 114, 103, 101, 34, 44, 34, 71, 114,
  101, 101, 110, 34, 44, 34, 72, 97, 114, 100, 32, 108, 105, 103, 104, 116,
  34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 72, 97, 114,
  100, 32, 109, 105, 120, 34, 44, 34, 72, 117, 101, 34, 44, 34, 73, 110,
  116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 34, 44, 34, 76, 105,
  103, 104, 116, 101, 110, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115,
  115, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 98, 117, 114, 110, 34,
  44, 34, 76, 105, 110, 101, 97, 114, 32, 108, 105, 103, 104, 116, 34, 44,
  34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 34, 77, 117, 108, 116, 105, 112, 108, 121, 34,
  44, 34, 78, 101, 103, 97, 116, 105, 111, 110, 34, 44, 34, 79, 114, 34,
  44, 34, 79, 118, 101, 114, 108, 97, 121, 34, 44, 34, 80, 105, 110, 32,
  108, 105, 103, 104, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 82, 101,
  102, 108, 101, 99, 116, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105,
  111, 110, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 83,
  104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 83,
  104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101, 48, 34, 44, 34,
  83, 111, 102, 116, 32, 98, 117, 114, 110, 34, 44, 34, 83, 111, 102, 116,
  32, 100, 111, 100, 103, 101, 34, 44, 34, 83, 111, 102, 116, 32, 108, 105,
  103, 104, 116, 34, 44, 34, 83, 99, 114, 101, 101, 110, 34, 44, 34, 83,
  116, 97, 109, 112, 34, 44, 34, 83, 117, 98, 116, 114, 97, 99, 116, 34,
  44, 34, 86, 97, 108, 117, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 34, 86, 105, 118, 105, 100, 32, 108, 105, 103, 104, 116, 34,
  44, 34, 88, 111, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121, 101, 114, 115, 32, 61,
  32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 32,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 102, 111,
  114, 109, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 70, 108, 111, 117, 50, 32, 47, 32, 98, 108, 117, 114, 50, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 114, 101, 97, 100, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 116, 32, 97, 32, 61, 32,
  105, 110, 116, 40, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 117, 116, 32, 98, 32, 61, 32, 105, 110,
  116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 117, 114, 98, 101, 32, 47, 32, 99,
  117, 114, 118, 101, 32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 84, 101, 120, 116, 117, 114, 101, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 105, 110, 116,
  40, 51, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 70, 105, 98, 114, 111, 117, 115, 110, 101, 115, 115, 32,
  61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 69, 109, 98, 111, 115, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 54, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117,
  108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 101, 117, 114, 115, 32, 47,
  32, 65, 117, 116, 104, 111, 114, 115, 32, 58, 32, 60, 105, 62, 83, 97,
  109, 106, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62,
  50, 48, 49, 52, 47, 48, 49, 47, 49, 55, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 84, 101, 115, 116, 95, 67,
  97, 109, 111, 117, 102, 108, 97, 103, 101, 95, 50, 95, 115, 97, 109, 106,
  32, 58, 10, 77, 111, 116, 105, 102, 95, 70, 111, 110, 100, 61, 36, 49,
  10, 70, 108, 111, 117, 95, 49, 61, 36, 50, 10, 83, 101, 117, 105, 108,
  95, 111, 116, 115, 117, 61, 36, 51, 10, 78, 111, 114, 109, 97, 108, 105,
  122, 101, 95, 111, 116, 115, 117, 95, 65, 61, 36, 52, 10, 78, 111, 114,
  109, 97, 108, 105, 122, 101, 95, 111, 116, 115, 117, 95, 66, 61, 36, 53,
  10, 73, 110, 118, 101, 114, 115, 101, 114, 95, 67, 111, 117, 108, 101, 117,
  114, 115, 61, 36, 54, 10, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95,
  99, 111, 117, 108, 101, 117, 114, 115, 61, 36, 55, 10, 86, 97, 114, 105,
  97, 116, 105, 111, 110, 115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 61,
  36, 56, 10, 70, 111, 114, 109, 101, 115, 61, 36, 57, 10, 84, 121, 112,
  101, 95, 114, 101, 110, 100, 117, 61, 36, 49, 48, 10, 98, 108, 101, 110,
  100, 61, 36, 49, 49, 10, 111, 112, 97, 99, 105, 116, 101, 61, 36, 49,
  50, 10, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 61,
  36, 49, 51, 10, 68, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 61,
  36, 49, 52, 10, 70, 108, 111, 117, 95, 50, 61, 36, 49, 53, 10, 83,
  112, 114, 101, 97, 100, 95, 99, 97, 109, 111, 117, 102, 108, 97, 103, 101,
  61, 36, 49, 54, 10, 67, 117, 116, 95, 65, 61, 36, 49, 55, 10, 67,
  117, 116, 95, 66, 61, 36, 49, 56, 10, 67, 111, 117, 114, 98, 101, 61,
  36, 49, 57, 10, 78, 105, 118, 101, 97, 117, 95, 116, 101, 120, 116, 117,
  114, 101, 61, 36, 50, 48, 10, 70, 105, 98, 114, 111, 117, 115, 110, 101,
  115, 115, 95, 116, 101, 120, 116, 117, 114, 101, 61, 36, 50, 49, 10, 69,
  109, 98, 111, 115, 115, 95, 116, 101, 120, 116, 117, 114, 101, 61, 36, 50,
  50, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 76, 97, 114, 103, 101, 117, 114, 61, 123, 119, 125, 10,
  72, 97, 117, 116, 101, 117, 114, 61, 123, 104, 125, 10, 45, 116, 111, 95,
  114, 103, 98, 10, 45, 99, 111, 108, 111, 114, 109, 97, 112, 91, 45, 49,
  93, 32, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 99, 111, 117,
  108, 101, 117, 114, 115, 44, 48, 10, 45, 114, 101, 115, 105, 122, 101, 91,
  45, 49, 93, 32, 36, 76, 97, 114, 103, 101, 117, 114, 44, 36, 72, 97,
  117, 116, 101, 117, 114, 10, 45, 105, 102, 32, 123, 123, 36, 77, 111, 116,
  105, 102, 95, 70, 111, 110, 100, 61, 61, 48, 125, 124, 124, 123, 36, 77,
  111, 116, 105, 102, 95, 70, 111, 110, 100, 61, 61, 49, 125, 124, 124, 123,
  36, 77, 111, 116, 105, 102, 95, 70, 111, 110, 100, 61, 61, 51, 125, 125,
  10, 45, 116, 97, 113, 117, 105, 110, 91, 45, 49, 93, 32, 123, 123, 114,
  111, 117, 110, 100, 40, 123, 123, 36, 76, 97, 114, 103, 101, 117, 114, 43,
  36, 72, 97, 117, 116, 101, 117, 114, 125, 47, 49, 48, 48, 125, 41, 125,
  43, 49, 48, 125, 44, 123, 123, 114, 111, 117, 110, 100, 40, 123, 123, 36,
  76, 97, 114, 103, 101, 117, 114, 43, 36, 72, 97, 117, 116, 101, 117, 114,
  125, 47, 49, 48, 48, 125, 41, 125, 43, 49, 48, 125, 10, 45, 100, 101,
  102, 111, 114, 109, 91, 45, 49, 93, 32, 36, 70, 111, 114, 109, 101, 115,
  10, 45, 101, 108, 115, 101, 10, 45, 100, 101, 102, 111, 114, 109, 91, 45,
  49, 93, 32, 123, 114, 111, 117, 110, 100, 40, 123, 36, 70, 111, 114, 109,
  101, 115, 42, 48, 46, 55, 53, 125, 41, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 36, 76,
  97, 114, 103, 101, 117, 114, 44, 36, 72, 97, 117, 116, 101, 117, 114, 10,
  45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 50, 10, 75, 95, 105, 109,
  95, 73, 77, 61, 49, 54, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111,
  95, 110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 103, 105,
  109, 112, 95, 100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97,
  110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 50, 44, 48, 44, 49, 44,
  48, 32, 73, 77, 65, 88, 61, 123, 114, 111, 117, 110, 100, 40, 123, 123,
  105, 77, 125, 45, 36, 75, 95, 105, 109, 95, 73, 77, 125, 41, 125, 32,
  73, 77, 73, 78, 61, 123, 114, 111, 117, 110, 100, 40, 123, 123, 105, 109,
  125, 43, 36, 75, 95, 105, 109, 95, 73, 77, 125, 41, 125, 32, 45, 114,
  109, 91, 45, 49, 44, 45, 50, 44, 45, 51, 93, 10, 45, 105, 102, 32,
  123, 36, 73, 77, 65, 88, 62, 50, 53, 53, 125, 32, 73, 77, 65, 88,
  61, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 32, 45, 105, 102, 32,
  123, 36, 73, 77, 73, 78, 60, 48, 125, 32, 73, 77, 73, 78, 61, 48,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 97,
  114, 105, 97, 116, 105, 111, 110, 115, 95, 99, 111, 117, 108, 101, 117, 114,
  115, 61, 61, 49, 125, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  86, 97, 114, 105, 97, 116, 105, 111, 110, 115, 95, 99, 111, 117, 108, 101,
  117, 114, 115, 61, 61, 50, 125, 32, 45, 99, 91, 45, 49, 93, 32, 36,
  73, 77, 73, 78, 44, 36, 73, 77, 65, 88, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111,
  110, 115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 61, 61, 51, 125, 32,
  45, 110, 91, 45, 49, 93, 32, 36, 73, 77, 73, 78, 44, 36, 73, 77,
  65, 88, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  84, 121, 112, 101, 95, 114, 101, 110, 100, 117, 61, 61, 49, 125, 10, 45,
  45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103,
  91, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 123, 119, 125, 44,
  123, 104, 125, 44, 49, 44, 51, 10, 45, 105, 102, 32, 123, 36, 77, 111,
  116, 105, 102, 95, 70, 111, 110, 100, 61, 61, 48, 125, 10, 45, 114, 97,
  110, 100, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 98, 108,
  117, 114, 91, 45, 49, 93, 32, 36, 70, 108, 111, 117, 95, 49, 10, 45,
  111, 116, 115, 117, 91, 45, 49, 93, 32, 36, 83, 101, 117, 105, 108, 95,
  111, 116, 115, 117, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 77, 111, 116, 105, 102, 95, 70, 111, 110, 100, 61, 61, 49, 125,
  10, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 45, 48, 44, 50, 53,
  53, 10, 45, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 91, 45, 49,
  93, 32, 45, 49, 44, 49, 10, 45, 98, 108, 117, 114, 91, 45, 49, 44,
  45, 50, 44, 45, 51, 93, 32, 36, 70, 108, 111, 117, 95, 49, 10, 45,
  42, 91, 45, 49, 44, 45, 50, 93, 10, 45, 99, 91, 45, 49, 93, 32,
  45, 48, 46, 50, 53, 44, 48, 46, 55, 53, 10, 45, 110, 111, 114, 109,
  91, 45, 49, 93, 10, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 49,
  93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 77,
  111, 116, 105, 102, 95, 70, 111, 110, 100, 61, 61, 50, 125, 10, 45, 112,
  108, 97, 115, 109, 97, 91, 45, 49, 93, 32, 49, 48, 44, 51, 10, 45,
  45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 91, 45, 49, 93, 32, 45,
  48, 46, 56, 44, 49, 10, 45, 98, 108, 117, 114, 91, 45, 49, 44, 45,
  50, 93, 32, 36, 70, 108, 111, 117, 95, 49, 10, 45, 42, 91, 45, 49,
  44, 45, 50, 93, 10, 45, 99, 91, 45, 49, 93, 32, 45, 48, 46, 50,
  53, 44, 48, 46, 55, 53, 10, 45, 110, 111, 114, 109, 91, 45, 49, 93,
  10, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 49, 93, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 77, 111, 116, 105, 102,
  95, 70, 111, 110, 100, 61, 61, 51, 125, 10, 45, 114, 97, 110, 100, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 98, 108, 117, 114, 91,
  45, 49, 93, 32, 36, 70, 108, 111, 117, 95, 49, 10, 45, 111, 116, 115,
  117, 91, 45, 49, 93, 32, 123, 36, 83, 101, 117, 105, 108, 95, 111, 116,
  115, 117, 42, 52, 125, 10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44,
  51, 10, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 70, 108, 111,
  117, 95, 49, 10, 45, 111, 116, 115, 117, 91, 45, 49, 93, 32, 123, 36,
  83, 101, 117, 105, 108, 95, 111, 116, 115, 117, 42, 49, 48, 125, 10, 45,
  42, 91, 45, 49, 44, 45, 50, 93, 10, 45, 98, 108, 117, 114, 91, 45,
  49, 93, 32, 123, 123, 114, 111, 117, 110, 100, 40, 123, 123, 36, 76, 97,
  114, 103, 101, 117, 114, 43, 36, 72, 97, 117, 116, 101, 117, 114, 125, 47,
  49, 48, 48, 48, 125, 41, 125, 43, 48, 46, 49, 125, 10, 45, 100, 105,
  108, 97, 116, 101, 95, 99, 105, 114, 99, 91, 45, 49, 93, 32, 123, 123,
  114, 111, 117, 110, 100, 40, 123, 123, 36, 76, 97, 114, 103, 101, 117, 114,
  43, 36, 72, 97, 117, 116, 101, 117, 114, 125, 47, 49, 48, 48, 125, 41,
  125, 43, 49, 125, 10, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 49,
  93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 123, 36,
  78, 111, 114, 109, 97, 108, 105, 122, 101, 95, 111, 116, 115, 117, 95, 65,
  45, 36, 78, 111, 114, 109, 97, 108, 105, 122, 101, 95, 111, 116, 115, 117,
  95, 66, 125, 61, 61, 48, 125, 10, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 10, 45, 101, 108, 115, 101, 10, 45, 105, 102, 32, 123,
  36, 78, 111, 114, 109, 97, 108, 105, 122, 101, 95, 111, 116, 115, 117, 95,
  65, 62, 36, 78, 111, 114, 109, 97, 108, 105, 122, 101, 95, 111, 116, 115,
  117, 95, 66, 125, 10, 45, 110, 91, 45, 49, 93, 32, 36, 78, 111, 114,
  109, 97, 108, 105, 122, 101, 95, 111, 116, 115, 117, 95, 66, 44, 36, 78,
  111, 114, 109, 97, 108, 105, 122, 101, 95, 111, 116, 115, 117, 95, 65, 10,
  45, 101, 108, 115, 101, 10, 45, 110, 91, 45, 49, 93, 32, 36, 78, 111,
  114, 109, 97, 108, 105, 122, 101, 95, 111, 116, 115, 117, 95, 65, 44, 36,
  78, 111, 114, 109, 97, 108, 105, 122, 101, 95, 111, 116, 115, 117, 95, 66,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  116, 111, 95, 103, 114, 97, 121, 91, 45, 49, 93, 10, 45, 116, 111, 95,
  114, 103, 98, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 73, 110,
  118, 101, 114, 115, 101, 114, 95, 67, 111, 117, 108, 101, 117, 114, 115, 61,
  61, 49, 125, 10, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49,
  93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 100,
  101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 91, 45, 49, 44, 45, 50, 93, 32, 50, 44, 48, 44, 49, 44, 48,
  32, 45, 114, 101, 109, 111, 118, 101, 91, 45, 50, 44, 45, 51, 44, 45,
  52, 93, 32, 45, 103, 105, 109, 112, 95, 100, 101, 99, 111, 109, 112, 111,
  115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 44, 45,
  50, 44, 45, 51, 93, 32, 50, 44, 49, 44, 49, 44, 48, 10, 45, 105,
  102, 32, 123, 36, 84, 121, 112, 101, 95, 114, 101, 110, 100, 117, 61, 61,
  49, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 50, 93, 32, 55,
  44, 55, 44, 49, 44, 51, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45,
  50, 93, 32, 49, 50, 55, 44, 49, 50, 55, 44, 49, 44, 51, 10, 45,
  98, 108, 117, 114, 91, 45, 50, 93, 32, 49, 48, 10, 45, 114, 101, 115,
  105, 122, 101, 91, 45, 50, 93, 32, 36, 76, 97, 114, 103, 101, 117, 114,
  44, 36, 72, 97, 117, 116, 101, 117, 114, 44, 49, 44, 51, 10, 45, 99,
  91, 45, 50, 93, 32, 48, 44, 50, 53, 53, 10, 45, 98, 108, 117, 114,
  91, 45, 50, 93, 32, 123, 123, 36, 76, 97, 114, 103, 101, 117, 114, 43,
  36, 72, 97, 117, 116, 101, 117, 114, 125, 47, 53, 48, 125, 10, 45, 103,
  105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93,
  32, 36, 98, 108, 101, 110, 100, 44, 36, 111, 112, 97, 99, 105, 116, 101,
  44, 36, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 10,
  45, 101, 110, 100, 105, 102, 10, 35, 42, 42, 42, 32, 97, 112, 112, 108,
  105, 113, 117, 101, 114, 32, 115, 117, 114, 32, 116, 111, 117, 115, 32, 108,
  101, 115, 32, 99, 97, 108, 113, 117, 101, 115, 10, 45, 100, 101, 102, 111,
  114, 109, 32, 36, 68, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 10,
  45, 98, 108, 117, 114, 32, 36, 70, 108, 111, 117, 95, 50, 10, 45, 115,
  112, 114, 101, 97, 100, 32, 36, 83, 112, 114, 101, 97, 100, 95, 99, 97,
  109, 111, 117, 102, 108, 97, 103, 101, 10, 45, 105, 102, 32, 123, 36, 78,
  105, 118, 101, 97, 117, 95, 116, 101, 120, 116, 117, 114, 101, 62, 48, 125,
  10, 45, 116, 101, 120, 116, 117, 114, 105, 122, 101, 95, 99, 97, 110, 118,
  97, 115, 32, 36, 78, 105, 118, 101, 97, 117, 95, 116, 101, 120, 116, 117,
  114, 101, 44, 36, 70, 105, 98, 114, 111, 117, 115, 110, 101, 115, 115, 95,
  116, 101, 120, 116, 117, 114, 101, 44, 36, 69, 109, 98, 111, 115, 115, 95,
  116, 101, 120, 116, 117, 114, 101, 10, 45, 101, 110, 100, 105, 102, 10, 35,
  42, 42, 42, 32, 70, 73, 78, 32, 97, 112, 112, 108, 105, 113, 117, 101,
  114, 32, 115, 117, 114, 32, 116, 111, 117, 115, 32, 108, 101, 115, 32, 99,
  97, 108, 113, 117, 101, 115, 10, 45, 105, 102, 32, 123, 36, 67, 117, 116,
  95, 65, 62, 36, 67, 117, 116, 95, 66, 125, 10, 45, 99, 91, 45, 49,
  93, 32, 36, 67, 117, 116, 95, 66, 44, 36, 67, 117, 116, 95, 65, 10,
  45, 101, 108, 115, 101, 10, 45, 99, 91, 45, 49, 93, 32, 36, 67, 117,
  116, 95, 65, 44, 36, 67, 117, 116, 95, 66, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 67, 111, 117, 114, 98, 101, 33, 61,
  49, 50, 56, 125, 10, 45, 103, 105, 109, 112, 95, 97, 112, 112, 108, 121,
  95, 99, 117, 114, 118, 101, 91, 45, 49, 93, 32, 48, 44, 36, 67, 111,
  117, 114, 98, 101, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50, 56, 44,
  45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49,
  44, 49, 50, 56, 44, 50, 53, 53, 44, 49, 44, 48, 44, 48, 44, 48,
  44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 84, 101, 115, 116, 95, 67, 97, 109, 111, 117,
  102, 108, 97, 103, 101, 95, 50, 95, 115, 97, 109, 106, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 84, 101, 115,
  116, 95, 67, 97, 109, 111, 117, 102, 108, 97, 103, 101, 95, 50, 95, 115,
  97, 109, 106, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 84, 101, 115, 116, 32, 99, 97, 109,
  111, 117, 102, 108, 97, 103, 101, 32, 58, 32, 84, 101, 115, 116, 95, 67,
  97, 109, 111, 117, 102, 108, 97, 103, 101, 95, 115, 97, 109, 106, 44, 32,
  84, 101, 115, 116, 95, 67, 97, 109, 111, 117, 102, 108, 97, 103, 101, 95,
  115, 97, 109, 106, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 70, 111, 110,
  100, 32, 47, 32, 66, 97, 99, 107, 103, 114, 111, 117, 110, 100, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 77, 111, 116, 105, 102, 32, 47, 32, 112, 97, 116, 116, 101, 114,
  110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 77, 111,
  116, 105, 102, 32, 49, 34, 44, 34, 77, 111, 116, 105, 102, 32, 50, 32,
  68, 101, 110, 115, 101, 32, 67, 108, 97, 105, 114, 34, 44, 34, 77, 111,
  116, 105, 102, 32, 51, 32, 76, 105, 103, 110, 101, 115, 34, 44, 34, 77,
  111, 116, 105, 102, 32, 52, 32, 66, 117, 108, 108, 101, 115, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 105, 109, 101, 110, 115, 105,
  111, 110, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48,
  44, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  117, 105, 108, 32, 47, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32,
  61, 32, 105, 110, 116, 40, 52, 48, 44, 49, 48, 44, 50, 53, 54, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 116, 32, 97, 32,
  102, 111, 110, 100, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 116,
  32, 98, 32, 102, 111, 110, 100, 32, 61, 32, 105, 110, 116, 40, 49, 57,
  50, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 101, 103, 97, 116, 105, 118, 101, 32, 61, 32, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 82, 101, 110, 100, 117, 32, 47, 32, 82, 101, 110,
  100, 101, 114, 105, 110, 103, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 114, 105, 97, 116,
  105, 111, 110, 115, 32, 99, 111, 117, 108, 101, 117, 114, 115, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 86, 97, 114, 105, 97, 116,
  105, 111, 110, 115, 32, 49, 34, 44, 34, 86, 97, 114, 105, 97, 116, 105,
  111, 110, 115, 32, 50, 34, 44, 34, 86, 97, 114, 105, 97, 116, 105, 111,
  110, 115, 32, 51, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  84, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44,
  34, 84, 121, 112, 101, 32, 49, 34, 44, 34, 84, 121, 112, 101, 32, 50,
  32, 97, 118, 101, 99, 32, 66, 108, 101, 110, 100, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 32, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49,
  44, 34, 65, 100, 100, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34,
  65, 110, 100, 34, 44, 34, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34,
  66, 108, 117, 101, 34, 44, 34, 66, 117, 114, 110, 34, 44, 34, 68, 97,
  114, 107, 101, 110, 34, 44, 34, 68, 105, 102, 102, 101, 114, 101, 110, 99,
  101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 68, 105,
  118, 105, 100, 101, 34, 44, 34, 68, 111, 100, 103, 101, 34, 44, 34, 69,
  120, 99, 108, 117, 115, 105, 111, 110, 34, 44, 34, 70, 114, 101, 101, 122,
  101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 101, 120, 116, 114, 97, 99,
  116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 109, 101, 114, 103, 101, 34,
  44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 72, 97, 114, 100, 32, 108,
  105, 103, 104, 116, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44, 34, 72, 117, 101, 34,
  44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 34,
  44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44, 34, 76, 105, 103, 104,
  116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 98,
  117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 108, 105, 103,
  104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 77, 117, 108, 116, 105,
  112, 108, 121, 34, 44, 34, 78, 101, 103, 97, 116, 105, 111, 110, 34, 44,
  34, 79, 114, 34, 44, 34, 79, 118, 101, 114, 108, 97, 121, 34, 44, 34,
  80, 105, 110, 32, 108, 105, 103, 104, 116, 34, 44, 34, 82, 101, 100, 34,
  44, 34, 82, 101, 102, 108, 101, 99, 116, 34, 44, 34, 83, 97, 116, 117,
  114, 97, 116, 105, 111, 110, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101,
  34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101,
  48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117, 114, 110, 34, 44, 34,
  83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34, 44, 34, 83, 111, 102,
  116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83, 99, 114, 101, 101, 110,
  34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34, 83, 117, 98, 116, 114,
  97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 34, 86, 105, 118, 105, 100, 32, 108, 105,
  103, 104, 116, 34, 44, 34, 88, 111, 114, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121, 101,
  114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 32, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  68, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 70, 108, 111, 117, 50, 32, 47, 32, 98, 108, 117,
  114, 50, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 49, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 114, 101,
  97, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 116, 32,
  97, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 117, 116, 32, 98, 32,
  61, 32, 105, 110, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 114, 98, 101,
  32, 61, 32, 105, 110, 116, 40, 49, 50, 56, 44, 48, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 84, 101, 120, 116, 117, 114, 101, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112,
  108, 105, 116, 117, 100, 101, 32, 61, 32, 105, 110, 116, 40, 51, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  70, 105, 98, 114, 111, 117, 115, 110, 101, 115, 115, 32, 61, 32, 105, 110,
  116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 69, 109, 98, 111, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 54, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 101, 117, 114, 115, 32, 47, 32, 65, 117, 116,
  104, 111, 114, 115, 32, 58, 32, 60, 105, 62, 83, 97, 109, 106, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52,
  47, 48, 49, 47, 49, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 84, 101, 115, 116, 95, 67, 97, 109, 111, 117,
  102, 108, 97, 103, 101, 95, 115, 97, 109, 106, 32, 58, 10, 77, 111, 116,
  105, 102, 95, 70, 111, 110, 100, 61, 36, 49, 10, 70, 108, 111, 117, 95,
  49, 61, 36, 50, 10, 83, 101, 117, 105, 108, 95, 111, 116, 115, 117, 61,
  36, 51, 10, 78, 111, 114, 109, 97, 108, 105, 122, 101, 95, 111, 116, 115,
  117, 95, 65, 61, 36, 52, 10, 78, 111, 114, 109, 97, 108, 105, 122, 101,
  95, 111, 116, 115, 117, 95, 66, 61, 36, 53, 10, 73, 110, 118, 101, 114,
  115, 101, 114, 95, 67, 111, 117, 108, 101, 117, 114, 115, 61, 36, 54, 10,
  86, 97, 114, 105, 97, 116, 105, 111, 110, 115, 95, 99, 111, 117, 108, 101,
  117, 114, 115, 61, 36, 55, 10, 84, 121, 112, 101, 95, 114, 101, 110, 100,
  117, 61, 36, 56, 10, 98, 108, 101, 110, 100, 61, 36, 57, 10, 111, 112,
  97, 99, 105, 116, 101, 61, 36, 49, 48, 10, 82, 101, 118, 101, 114, 116,
  95, 108, 97, 121, 101, 114, 115, 61, 36, 49, 49, 10, 68, 101, 102, 111,
  114, 109, 97, 116, 105, 111, 110, 61, 36, 49, 50, 10, 70, 108, 111, 117,
  95, 50, 61, 36, 49, 51, 10, 83, 112, 114, 101, 97, 100, 95, 99, 97,
  109, 111, 117, 102, 108, 97, 103, 101, 61, 36, 49, 52, 10, 67, 117, 116,
  95, 65, 61, 36, 49, 53, 10, 67, 117, 116, 95, 66, 61, 36, 49, 54,
  10, 67, 111, 117, 114, 98, 101, 61, 36, 49, 55, 10, 78, 105, 118, 101,
  97, 117, 95, 116, 101, 120, 116, 117, 114, 101, 61, 36, 49, 56, 10, 70,
  105, 98, 114, 111, 117, 115, 110, 101, 115, 115, 95, 116, 101, 120, 116, 117,
  114, 101, 61, 36, 49, 57, 10, 69, 109, 98, 111, 115, 115, 95, 116, 101,
  120, 116, 117, 114, 101, 61, 36, 50, 48, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 76, 97, 114, 103,
  101, 117, 114, 61, 123, 119, 125, 10, 72, 97, 117, 116, 101, 117, 114, 61,
  123, 104, 125, 10, 45, 116, 111, 95, 114, 103, 98, 10, 45, 105, 102, 32,
  123, 123, 36, 77, 111, 116, 105, 102, 95, 70, 111, 110, 100, 61, 61, 48,
  125, 124, 124, 123, 36, 77, 111, 116, 105, 102, 95, 70, 111, 110, 100, 61,
  61, 49, 125, 124, 124, 123, 36, 77, 111, 116, 105, 102, 95, 70, 111, 110,
  100, 61, 61, 51, 125, 125, 10, 45, 116, 97, 113, 117, 105, 110, 91, 45,
  49, 93, 32, 123, 123, 114, 111, 117, 110, 100, 40, 123, 123, 36, 76, 97,
  114, 103, 101, 117, 114, 43, 36, 72, 97, 117, 116, 101, 117, 114, 125, 47,
  49, 48, 48, 125, 41, 125, 43, 49, 48, 125, 44, 123, 123, 114, 111, 117,
  110, 100, 40, 123, 123, 36, 76, 97, 114, 103, 101, 117, 114, 43, 36, 72,
  97, 117, 116, 101, 117, 114, 125, 47, 49, 48, 48, 125, 41, 125, 43, 49,
  48, 125, 10, 45, 97, 114, 114, 97, 121, 95, 109, 105, 114, 114, 111, 114,
  91, 45, 49, 93, 32, 49, 10, 45, 100, 101, 102, 111, 114, 109, 91, 45,
  49, 93, 32, 49, 48, 10, 45, 115, 112, 114, 101, 97, 100, 91, 45, 49,
  93, 32, 50, 48, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93,
  32, 36, 76, 97, 114, 103, 101, 117, 114, 44, 36, 72, 97, 117, 116, 101,
  117, 114, 10, 45, 101, 108, 115, 101, 10, 45, 103, 105, 109, 112, 95, 98,
  108, 117, 114, 95, 114, 97, 100, 105, 97, 108, 91, 45, 49, 93, 32, 50,
  48, 44, 48, 46, 53, 44, 49, 44, 49, 48, 48, 44, 48, 44, 49, 10,
  45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 36, 76, 97, 114,
  103, 101, 117, 114, 44, 123, 114, 111, 117, 110, 100, 40, 123, 49, 43, 123,
  36, 72, 97, 117, 116, 101, 117, 114, 47, 50, 53, 48, 125, 125, 41, 125,
  10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 36, 76, 97,
  114, 103, 101, 117, 114, 44, 36, 72, 97, 117, 116, 101, 117, 114, 10, 45,
  100, 101, 102, 111, 114, 109, 91, 45, 49, 93, 32, 52, 48, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95,
  114, 101, 110, 100, 117, 61, 61, 49, 125, 10, 45, 45, 103, 105, 109, 112,
  95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105,
  111, 110, 115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 61, 61, 48, 125,
  10, 45, 99, 91, 45, 49, 93, 32, 51, 50, 44, 50, 50, 51, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105,
  97, 116, 105, 111, 110, 115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 61,
  61, 49, 125, 10, 75, 95, 105, 109, 95, 73, 77, 61, 49, 10, 45, 45,
  103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91,
  45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 100, 101, 99, 111, 109, 112,
  111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93,
  32, 50, 44, 48, 44, 49, 44, 48, 32, 73, 77, 65, 88, 61, 123, 114,
  111, 117, 110, 100, 40, 123, 123, 105, 77, 125, 45, 36, 75, 95, 105, 109,
  95, 73, 77, 125, 41, 125, 32, 73, 77, 73, 78, 61, 123, 114, 111, 117,
  110, 100, 40, 123, 123, 105, 109, 125, 43, 36, 75, 95, 105, 109, 95, 73,
  77, 125, 41, 125, 32, 45, 114, 109, 91, 45, 49, 44, 45, 50, 44, 45,
  51, 93, 10, 45, 105, 102, 32, 123, 36, 73, 77, 65, 88, 62, 50, 53,
  53, 125, 32, 73, 77, 65, 88, 61, 50, 53, 53, 32, 45, 101, 110, 100,
  105, 102, 32, 45, 105, 102, 32, 123, 36, 73, 77, 73, 78, 60, 48, 125,
  32, 73, 77, 73, 78, 61, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  99, 91, 45, 49, 93, 32, 36, 73, 77, 73, 78, 44, 36, 73, 77, 65,
  88, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86,
  97, 114, 105, 97, 116, 105, 111, 110, 115, 95, 99, 111, 117, 108, 101, 117,
  114, 115, 61, 61, 51, 125, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 123, 119, 125, 44, 123,
  104, 125, 44, 49, 44, 51, 10, 45, 105, 102, 32, 123, 36, 77, 111, 116,
  105, 102, 95, 70, 111, 110, 100, 61, 61, 48, 125, 10, 45, 114, 97, 110,
  100, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 98, 108, 117,
  114, 91, 45, 49, 93, 32, 36, 70, 108, 111, 117, 95, 49, 10, 45, 111,
  116, 115, 117, 91, 45, 49, 93, 32, 36, 83, 101, 117, 105, 108, 95, 111,
  116, 115, 117, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 77, 111, 116, 105, 102, 95, 70, 111, 110, 100, 61, 61, 49, 125, 10,
  45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 45, 48, 44, 50, 53, 53,
  10, 45, 45, 110, 111, 114, 109, 97, 108, 105, 122, 101, 91, 45, 49, 93,
  32, 45, 49, 44, 49, 10, 45, 98, 108, 117, 114, 91, 45, 49, 44, 45,
  50, 44, 45, 51, 93, 32, 36, 70, 108, 111, 117, 95, 49, 10, 45, 42,
  91, 45, 49, 44, 45, 50, 93, 10, 45, 99, 91, 45, 49, 93, 32, 45,
  48, 46, 50, 53, 44, 48, 46, 55, 53, 10, 45, 110, 111, 114, 109, 91,
  45, 49, 93, 10, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 49, 93,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 77, 111,
  116, 105, 102, 95, 70, 111, 110, 100, 61, 61, 50, 125, 10, 45, 112, 108,
  97, 115, 109, 97, 91, 45, 49, 93, 32, 49, 48, 44, 51, 10, 45, 45,
  110, 111, 114, 109, 97, 108, 105, 122, 101, 91, 45, 49, 93, 32, 45, 48,
  46, 56, 44, 49, 10, 45, 98, 108, 117, 114, 91, 45, 49, 44, 45, 50,
  93, 32, 36, 70, 108, 111, 117, 95, 49, 10, 45, 42, 91, 45, 49, 44,
  45, 50, 93, 10, 45, 99, 91, 45, 49, 93, 32, 45, 48, 46, 50, 53,
  44, 48, 46, 55, 53, 10, 45, 110, 111, 114, 109, 91, 45, 49, 93, 10,
  45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 49, 93, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 77, 111, 116, 105, 102, 95,
  70, 111, 110, 100, 61, 61, 51, 125, 10, 45, 114, 97, 110, 100, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 98, 108, 117, 114, 91, 45,
  49, 93, 32, 36, 70, 108, 111, 117, 95, 49, 10, 45, 111, 116, 115, 117,
  91, 45, 49, 93, 32, 123, 36, 83, 101, 117, 105, 108, 95, 111, 116, 115,
  117, 42, 52, 125, 10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 51,
  10, 45, 114, 97, 110, 100, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 70, 108, 111, 117,
  95, 49, 10, 45, 111, 116, 115, 117, 91, 45, 49, 93, 32, 123, 36, 83,
  101, 117, 105, 108, 95, 111, 116, 115, 117, 42, 49, 48, 125, 10, 45, 42,
  91, 45, 49, 44, 45, 50, 93, 10, 45, 98, 108, 117, 114, 91, 45, 49,
  93, 32, 123, 123, 114, 111, 117, 110, 100, 40, 123, 123, 36, 76, 97, 114,
  103, 101, 117, 114, 43, 36, 72, 97, 117, 116, 101, 117, 114, 125, 47, 49,
  48, 48, 48, 125, 41, 125, 43, 48, 46, 49, 125, 10, 45, 100, 105, 108,
  97, 116, 101, 95, 99, 105, 114, 99, 91, 45, 49, 93, 32, 123, 123, 114,
  111, 117, 110, 100, 40, 123, 123, 36, 76, 97, 114, 103, 101, 117, 114, 43,
  36, 72, 97, 117, 116, 101, 117, 114, 125, 47, 49, 48, 48, 125, 41, 125,
  43, 49, 125, 10, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 49, 93,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 123, 36, 78,
  111, 114, 109, 97, 108, 105, 122, 101, 95, 111, 116, 115, 117, 95, 65, 45,
  36, 78, 111, 114, 109, 97, 108, 105, 122, 101, 95, 111, 116, 115, 117, 95,
  66, 125, 61, 61, 48, 125, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44,
  50, 53, 53, 10, 45, 101, 108, 115, 101, 10, 45, 105, 102, 32, 123, 36,
  78, 111, 114, 109, 97, 108, 105, 122, 101, 95, 111, 116, 115, 117, 95, 65,
  62, 36, 78, 111, 114, 109, 97, 108, 105, 122, 101, 95, 111, 116, 115, 117,
  95, 66, 125, 10, 45, 110, 91, 45, 49, 93, 32, 36, 78, 111, 114, 109,
  97, 108, 105, 122, 101, 95, 111, 116, 115, 117, 95, 66, 44, 36, 78, 111,
  114, 109, 97, 108, 105, 122, 101, 95, 111, 116, 115, 117, 95, 65, 10, 45,
  101, 108, 115, 101, 10, 45, 110, 91, 45, 49, 93, 32, 36, 78, 111, 114,
  109, 97, 108, 105, 122, 101, 95, 111, 116, 115, 117, 95, 65, 44, 36, 78,
  111, 114, 109, 97, 108, 105, 122, 101, 95, 111, 116, 115, 117, 95, 66, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 116,
  111, 95, 103, 114, 97, 121, 91, 45, 49, 93, 10, 45, 116, 111, 95, 114,
  103, 98, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 73, 110, 118,
  101, 114, 115, 101, 114, 95, 67, 111, 117, 108, 101, 117, 114, 115, 61, 61,
  49, 125, 10, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 49, 93,
  10, 45, 101, 110, 100, 105, 102, 10, 35, 45, 103, 105, 109, 112, 95, 100,
  101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108,
  115, 32, 50, 44, 48, 44, 49, 44, 48, 32, 45, 114, 101, 109, 111, 118,
  101, 91, 45, 50, 44, 45, 51, 44, 45, 52, 93, 32, 45, 103, 105, 109,
  112, 95, 100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110,
  110, 101, 108, 115, 32, 50, 44, 49, 44, 49, 44, 48, 10, 45, 103, 105,
  109, 112, 95, 100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97,
  110, 110, 101, 108, 115, 91, 45, 49, 44, 45, 50, 93, 32, 50, 44, 48,
  44, 49, 44, 48, 32, 45, 114, 101, 109, 111, 118, 101, 91, 45, 50, 44,
  45, 51, 44, 45, 52, 93, 32, 45, 103, 105, 109, 112, 95, 100, 101, 99,
  111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115, 91,
  45, 49, 44, 45, 50, 44, 45, 51, 93, 32, 50, 44, 49, 44, 49, 44,
  48, 10, 45, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95, 114, 101, 110,
  100, 117, 61, 61, 49, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45,
  50, 93, 32, 55, 44, 55, 44, 49, 44, 51, 10, 45, 114, 101, 115, 105,
  122, 101, 91, 45, 50, 93, 32, 49, 50, 55, 44, 49, 50, 55, 44, 49,
  44, 51, 10, 45, 98, 108, 117, 114, 91, 45, 50, 93, 32, 49, 48, 10,
  45, 114, 101, 115, 105, 122, 101, 91, 45, 50, 93, 32, 36, 76, 97, 114,
  103, 101, 117, 114, 44, 36, 72, 97, 117, 116, 101, 117, 114, 44, 49, 44,
  51, 10, 45, 99, 91, 45, 50, 93, 32, 48, 44, 50, 53, 53, 10, 45,
  98, 108, 117, 114, 91, 45, 50, 93, 32, 123, 123, 36, 76, 97, 114, 103,
  101, 117, 114, 43, 36, 72, 97, 117, 116, 101, 117, 114, 125, 47, 53, 48,
  125, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49,
  44, 45, 50, 93, 32, 36, 98, 108, 101, 110, 100, 44, 36, 111, 112, 97,
  99, 105, 116, 101, 44, 36, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121,
  101, 114, 115, 10, 45, 101, 110, 100, 105, 102, 10, 35, 42, 42, 42, 32,
  97, 112, 112, 108, 105, 113, 117, 101, 114, 32, 115, 117, 114, 32, 116, 111,
  117, 115, 32, 108, 101, 115, 32, 99, 97, 108, 113, 117, 101, 115, 10, 45,
  100, 101, 102, 111, 114, 109, 32, 36, 68, 101, 102, 111, 114, 109, 97, 116,
  105, 111, 110, 10, 45, 98, 108, 117, 114, 32, 36, 70, 108, 111, 117, 95,
  50, 10, 45, 115, 112, 114, 101, 97, 100, 32, 36, 83, 112, 114, 101, 97,
  100, 95, 99, 97, 109, 111, 117, 102, 108, 97, 103, 101, 10, 45, 105, 102,
  32, 123, 36, 78, 105, 118, 101, 97, 117, 95, 116, 101, 120, 116, 117, 114,
  101, 62, 48, 125, 10, 45, 116, 101, 120, 116, 117, 114, 105, 122, 101, 95,
  99, 97, 110, 118, 97, 115, 32, 36, 78, 105, 118, 101, 97, 117, 95, 116,
  101, 120, 116, 117, 114, 101, 44, 36, 70, 105, 98, 114, 111, 117, 115, 110,
  101, 115, 115, 95, 116, 101, 120, 116, 117, 114, 101, 44, 36, 69, 109, 98,
  111, 115, 115, 95, 116, 101, 120, 116, 117, 114, 101, 10, 45, 101, 110, 100,
  105, 102, 10, 35, 42, 42, 42, 32, 70, 73, 78, 32, 97, 112, 112, 108,
  105, 113, 117, 101, 114, 32, 115, 117, 114, 32, 116, 111, 117, 115, 32, 108,
  101, 115, 32, 99, 97, 108, 113, 117, 101, 115, 10, 45, 105, 102, 32, 123,
  36, 67, 117, 116, 95, 65, 62, 36, 67, 117, 116, 95, 66, 125, 10, 45,
  99, 91, 45, 49, 93, 32, 36, 67, 117, 116, 95, 66, 44, 36, 67, 117,
  116, 95, 65, 10, 45, 101, 108, 115, 101, 10, 45, 99, 91, 45, 49, 93,
  32, 36, 67, 117, 116, 95, 65, 44, 36, 67, 117, 116, 95, 66, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 67, 111, 117, 114,
  98, 101, 33, 61, 49, 50, 56, 125, 10, 45, 103, 105, 109, 112, 95, 97,
  112, 112, 108, 121, 95, 99, 117, 114, 118, 101, 91, 45, 49, 93, 32, 48,
  44, 36, 67, 111, 117, 114, 98, 101, 44, 49, 50, 56, 44, 45, 49, 44,
  49, 50, 56, 44, 45, 49, 44, 49, 50, 56, 44, 45, 49, 44, 49, 50,
  56, 44, 45, 49, 44, 49, 50, 56, 44, 50, 53, 53, 44, 49, 44, 48,
  44, 48, 44, 48, 44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 84, 101, 115, 116, 95, 67,
  97, 109, 111, 117, 102, 108, 97, 103, 101, 95, 115, 97, 109, 106, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115,
  112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 84,
  101, 115, 116, 95, 67, 97, 109, 111, 117, 102, 108, 97, 103, 101, 95, 115,
  97, 109, 106, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49,
  10, 35, 64, 103, 105, 109, 112, 32, 84, 101, 115, 116, 32, 112, 101, 114,
  105, 111, 100, 105, 99, 32, 100, 111, 116, 115, 32, 58, 32, 115, 97, 109,
  106, 95, 84, 101, 115, 116, 95, 80, 101, 114, 105, 111, 100, 105, 99, 95,
  68, 111, 116, 115, 44, 32, 115, 97, 109, 106, 95, 84, 101, 115, 116, 95,
  80, 101, 114, 105, 111, 100, 105, 99, 95, 68, 111, 116, 115, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112,
  97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111,
  114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108,
  62, 86, 97, 114, 105, 97, 116, 105, 111, 110, 115, 32, 97, 117, 116, 111,
  117, 114, 32, 100, 101, 32, 80, 101, 114, 105, 111, 100, 105, 99, 32, 68,
  111, 116, 115, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97,
  110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 98,
  32, 97, 110, 103, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 49, 50,
  44, 50, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 99, 97, 108, 101, 32, 61, 32, 105, 110, 116, 40, 49, 48, 44,
  50, 44, 50, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  116, 97, 114, 116, 32, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 53, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 114, 112, 101, 110, 32, 61,
  32, 105, 110, 116, 40, 48, 44, 48, 44, 53, 48, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 114, 101, 97, 100, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 70, 108, 111, 117, 32, 47, 32, 98,
  108, 117, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 102,
  111, 114, 109, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 100,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 65, 100,
  100, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34, 65, 110, 100, 34,
  44, 34, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 66, 108, 117, 101,
  34, 44, 34, 66, 117, 114, 110, 34, 44, 34, 68, 97, 114, 107, 101, 110,
  34, 44, 34, 68, 105, 102, 102, 101, 114, 101, 110, 99, 101, 34, 44, 34,
  68, 105, 118, 105, 100, 101, 34, 44, 34, 68, 111, 100, 103, 101, 34, 44,
  34, 69, 120, 99, 108, 117, 115, 105, 111, 110, 34, 44, 34, 70, 114, 101,
  101, 122, 101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 101, 120, 116, 114,
  97, 99, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 109, 101, 114, 103,
  101, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 72, 97, 114, 100,
  32, 108, 105, 103, 104, 116, 34, 44, 34, 72, 97, 114, 100, 32, 109, 105,
  120, 34, 44, 34, 72, 117, 101, 34, 44, 34, 73, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 105, 111, 110, 34, 44, 34, 76, 105, 103, 104, 116, 101,
  110, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34,
  76, 105, 110, 101, 97, 114, 32, 98, 117, 114, 110, 34, 44, 34, 76, 105,
  110, 101, 97, 114, 32, 108, 105, 103, 104, 116, 34, 44, 34, 76, 117, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 34, 77, 117, 108, 116, 105, 112, 108,
  121, 34, 44, 34, 78, 101, 103, 97, 116, 105, 111, 110, 34, 44, 34, 79,
  114, 34, 44, 34, 79, 118, 101, 114, 108, 97, 121, 34, 44, 34, 80, 105,
  110, 32, 108, 105, 103, 104, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34,
  82, 101, 102, 108, 101, 99, 116, 34, 44, 34, 83, 97, 116, 117, 114, 97,
  116, 105, 111, 110, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101,
  114, 97, 103, 101, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101,
  114, 97, 103, 101, 48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117, 114,
  110, 34, 44, 34, 83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34, 44,
  34, 83, 111, 102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83, 99,
  114, 101, 101, 110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34, 83,
  117, 98, 116, 114, 97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101, 34,
  44, 34, 86, 105, 118, 105, 100, 32, 108, 105, 103, 104, 116, 34, 44, 34,
  88, 111, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79,
  112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  101, 118, 101, 114, 116, 32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98,
  111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49,
  52, 47, 48, 49, 47, 48, 56, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 84, 101, 115, 116,
  95, 80, 101, 114, 105, 111, 100, 105, 99, 95, 68, 111, 116, 115, 32, 58,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 80, 101, 114, 105, 111, 100, 105, 99, 95, 68, 111, 116, 115,
  95, 110, 98, 95, 97, 110, 103, 108, 101, 115, 61, 36, 49, 10, 80, 101,
  114, 105, 111, 100, 105, 99, 95, 68, 111, 116, 115, 95, 115, 99, 97, 108,
  101, 61, 36, 50, 10, 80, 101, 114, 105, 111, 100, 105, 99, 95, 68, 111,
  116, 115, 95, 115, 116, 97, 114, 116, 95, 97, 110, 103, 108, 101, 61, 36,
  51, 10, 80, 101, 114, 105, 111, 100, 105, 99, 95, 68, 111, 116, 115, 95,
  115, 104, 97, 114, 112, 101, 110, 61, 36, 52, 10, 80, 101, 114, 105, 111,
  100, 105, 99, 95, 68, 111, 116, 115, 95, 118, 97, 108, 101, 117, 114, 95,
  115, 112, 114, 101, 97, 100, 61, 36, 53, 10, 80, 101, 114, 105, 111, 100,
  105, 99, 95, 68, 111, 116, 115, 95, 102, 108, 111, 117, 61, 36, 54, 10,
  80, 101, 114, 105, 111, 100, 105, 99, 95, 68, 111, 116, 115, 95, 100, 101,
  102, 111, 114, 109, 97, 116, 105, 111, 110, 61, 36, 55, 10, 77, 111, 100,
  101, 95, 77, 101, 108, 97, 110, 103, 101, 61, 36, 56, 10, 79, 112, 97,
  99, 105, 116, 121, 95, 77, 101, 108, 97, 110, 103, 101, 61, 36, 57, 10,
  82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 95, 77, 101,
  108, 97, 110, 103, 101, 61, 36, 49, 48, 10, 45, 103, 105, 109, 112, 95,
  100, 101, 99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101,
  108, 115, 91, 45, 49, 93, 32, 50, 44, 48, 44, 49, 44, 48, 10, 45,
  45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103,
  91, 45, 49, 93, 10, 45, 112, 101, 114, 105, 111, 100, 105, 99, 95, 100,
  111, 116, 115, 91, 45, 49, 93, 32, 36, 80, 101, 114, 105, 111, 100, 105,
  99, 95, 68, 111, 116, 115, 95, 110, 98, 95, 97, 110, 103, 108, 101, 115,
  44, 36, 80, 101, 114, 105, 111, 100, 105, 99, 95, 68, 111, 116, 115, 95,
  115, 99, 97, 108, 101, 44, 36, 80, 101, 114, 105, 111, 100, 105, 99, 95,
  68, 111, 116, 115, 95, 115, 116, 97, 114, 116, 95, 97, 110, 103, 108, 101,
  10, 45, 115, 104, 97, 114, 112, 101, 110, 91, 45, 49, 93, 32, 36, 80,
  101, 114, 105, 111, 100, 105, 99, 95, 68, 111, 116, 115, 95, 115, 104, 97,
  114, 112, 101, 110, 10, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93,
  10, 45, 115, 112, 114, 101, 97, 100, 91, 45, 49, 93, 32, 36, 80, 101,
  114, 105, 111, 100, 105, 99, 95, 68, 111, 116, 115, 95, 118, 97, 108, 101,
  117, 114, 95, 115, 112, 114, 101, 97, 100, 10, 45, 98, 108, 117, 114, 91,
  45, 49, 93, 32, 36, 80, 101, 114, 105, 111, 100, 105, 99, 95, 68, 111,
  116, 115, 95, 102, 108, 111, 117, 10, 45, 100, 101, 102, 111, 114, 109, 91,
  45, 49, 93, 32, 36, 80, 101, 114, 105, 111, 100, 105, 99, 95, 68, 111,
  116, 115, 95, 100, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 10, 45,
  103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50,
  93, 32, 36, 77, 111, 100, 101, 95, 77, 101, 108, 97, 110, 103, 101, 44,
  36, 79, 112, 97, 99, 105, 116, 121, 95, 77, 101, 108, 97, 110, 103, 101,
  44, 36, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 95,
  77, 101, 108, 97, 110, 103, 101, 10, 45, 103, 105, 109, 112, 95, 100, 101,
  99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  91, 45, 49, 44, 45, 50, 44, 45, 51, 93, 32, 50, 44, 49, 44, 49,
  44, 48, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115,
  97, 109, 106, 95, 84, 101, 115, 116, 95, 80, 101, 114, 105, 111, 100, 105,
  99, 95, 68, 111, 116, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 84, 101, 115, 116,
  95, 80, 101, 114, 105, 111, 100, 105, 99, 95, 68, 111, 116, 115, 32, 36,
  42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 84, 101,
  115, 116, 32, 119, 97, 114, 112, 32, 58, 32, 84, 101, 115, 116, 115, 95,
  87, 97, 114, 112, 95, 115, 97, 109, 106, 44, 32, 84, 101, 115, 116, 115,
  95, 87, 97, 114, 112, 95, 115, 97, 109, 106, 95, 112, 114, 101, 118, 105,
  101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 84, 101, 115, 116, 115, 32, 100,
  101, 32, 108, 97, 32, 102, 111, 110, 99, 116, 105, 111, 110, 32, 87, 97,
  114, 112, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 101, 115, 116, 115, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 84, 101, 115, 116, 32,
  49, 34, 44, 34, 84, 101, 115, 116, 32, 50, 34, 44, 34, 84, 101, 115,
  116, 32, 51, 34, 44, 34, 84, 101, 115, 116, 32, 52, 34, 44, 34, 84,
  101, 115, 116, 32, 53, 34, 44, 34, 84, 101, 115, 116, 32, 54, 34, 44,
  34, 84, 101, 115, 116, 32, 55, 34, 44, 34, 84, 101, 115, 116, 32, 56,
  34, 44, 34, 84, 101, 115, 116, 32, 57, 34, 44, 34, 84, 101, 115, 116,
  32, 49, 48, 34, 44, 34, 84, 101, 115, 116, 32, 49, 49, 34, 44, 34,
  84, 101, 115, 116, 32, 49, 50, 34, 44, 34, 84, 101, 115, 116, 32, 49,
  51, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 66, 108, 101, 110, 100, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 100,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 65, 100,
  100, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34, 65, 110, 100, 34,
  44, 34, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 66, 108, 117, 101,
  34, 44, 34, 66, 117, 114, 110, 34, 44, 34, 68, 97, 114, 107, 101, 110,
  34, 44, 34, 68, 105, 102, 102, 101, 114, 101, 110, 99, 101, 34, 44, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 68, 105, 118, 105, 100, 101,
  34, 44, 34, 68, 111, 100, 103, 101, 34, 44, 34, 69, 120, 99, 108, 117,
  115, 105, 111, 110, 34, 44, 34, 70, 114, 101, 101, 122, 101, 34, 44, 34,
  71, 114, 97, 105, 110, 32, 101, 120, 116, 114, 97, 99, 116, 34, 44, 34,
  71, 114, 97, 105, 110, 32, 109, 101, 114, 103, 101, 34, 44, 34, 71, 114,
  101, 101, 110, 34, 44, 34, 72, 97, 114, 100, 32, 108, 105, 103, 104, 116,
  34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 72, 97, 114,
  100, 32, 109, 105, 120, 34, 44, 34, 72, 117, 101, 34, 44, 34, 73, 110,
  116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 34, 44, 34, 76, 105,
  103, 104, 116, 101, 110, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115,
  115, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 98, 117, 114, 110, 34,
  44, 34, 76, 105, 110, 101, 97, 114, 32, 108, 105, 103, 104, 116, 34, 44,
  34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 34, 77, 117, 108, 116, 105, 112, 108, 121, 34,
  44, 34, 78, 101, 103, 97, 116, 105, 111, 110, 34, 44, 34, 79, 114, 34,
  44, 34, 79, 118, 101, 114, 108, 97, 121, 34, 44, 34, 80, 105, 110, 32,
  108, 105, 103, 104, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 82, 101,
  102, 108, 101, 99, 116, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105,
  111, 110, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 83,
  104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 83,
  104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101, 48, 34, 44, 34,
  83, 111, 102, 116, 32, 98, 117, 114, 110, 34, 44, 34, 83, 111, 102, 116,
  32, 100, 111, 100, 103, 101, 34, 44, 34, 83, 111, 102, 116, 32, 108, 105,
  103, 104, 116, 34, 44, 34, 83, 99, 114, 101, 101, 110, 34, 44, 34, 83,
  116, 97, 109, 112, 34, 44, 34, 83, 117, 98, 116, 114, 97, 99, 116, 34,
  44, 34, 86, 97, 108, 117, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 34, 86, 105, 118, 105, 100, 32, 108, 105, 103, 104, 116, 34,
  44, 34, 88, 111, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121, 101, 114, 115, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 101, 117, 114, 115, 32, 47, 32, 65, 117, 116, 104, 111, 114,
  115, 32, 58, 32, 60, 105, 62, 83, 97, 109, 106, 60, 47, 105, 62, 46,
  32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 49,
  47, 48, 49, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 84, 101, 115, 116, 115, 95, 87, 97, 114, 112, 95, 115, 97,
  109, 106, 32, 58, 10, 84, 101, 115, 116, 61, 36, 49, 10, 98, 108, 101,
  110, 100, 61, 36, 50, 10, 111, 112, 97, 99, 105, 116, 101, 61, 36, 51,
  10, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 61, 36,
  52, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93,
  10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105,
  110, 103, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 84, 101, 115,
  116, 61, 61, 48, 125, 10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44,
  52, 32, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49,
  93, 32, 48, 44, 48, 44, 48, 44, 50, 53, 53, 32, 45, 112, 111, 108,
  121, 103, 111, 110, 91, 45, 49, 93, 32, 51, 44, 123, 119, 125, 44, 48,
  44, 123, 119, 125, 44, 123, 104, 125, 44, 48, 44, 123, 104, 125, 44, 49,
  44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  32, 45, 119, 97, 114, 112, 91, 48, 93, 32, 91, 49, 93, 44, 49, 44,
  49, 44, 49, 32, 32, 45, 119, 97, 114, 112, 91, 48, 93, 32, 91, 49,
  93, 44, 49, 44, 49, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 84, 101, 115, 116, 61, 61, 49, 125, 10, 123, 119,
  125, 44, 123, 104, 125, 44, 49, 44, 52, 32, 45, 102, 105, 108, 108, 95,
  99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44,
  50, 53, 53, 32, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93,
  32, 52, 44, 123, 123, 119, 125, 47, 50, 125, 44, 48, 44, 123, 119, 125,
  44, 48, 44, 123, 119, 125, 44, 123, 104, 125, 44, 123, 123, 119, 125, 47,
  50, 125, 44, 123, 104, 125, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 119, 97, 114, 112, 91, 48,
  93, 32, 91, 49, 93, 44, 49, 44, 49, 44, 49, 32, 32, 45, 119, 97,
  114, 112, 91, 48, 93, 32, 91, 49, 93, 44, 49, 44, 49, 44, 49, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84, 101, 115,
  116, 61, 61, 50, 125, 10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44,
  52, 32, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49,
  93, 32, 48, 44, 48, 44, 48, 44, 50, 53, 53, 32, 45, 112, 111, 108,
  121, 103, 111, 110, 91, 45, 49, 93, 32, 52, 44, 123, 123, 119, 125, 47,
  50, 125, 44, 48, 44, 123, 119, 125, 44, 48, 44, 123, 119, 125, 44, 123,
  104, 125, 44, 123, 123, 119, 125, 47, 50, 125, 44, 123, 123, 104, 125, 47,
  50, 125, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 50, 53, 53, 32, 45, 119, 97, 114, 112, 91, 48, 93, 32, 91, 49,
  93, 44, 49, 44, 49, 44, 49, 32, 32, 45, 119, 97, 114, 112, 91, 48,
  93, 32, 91, 49, 93, 44, 49, 44, 49, 44, 49, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 84, 101, 115, 116, 61, 61, 51,
  125, 10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 52, 32, 45, 102,
  105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44,
  48, 44, 48, 44, 50, 53, 53, 32, 45, 101, 108, 108, 105, 112, 115, 101,
  91, 45, 49, 93, 32, 123, 119, 125, 44, 123, 123, 104, 125, 47, 50, 125,
  44, 123, 123, 119, 125, 47, 50, 125, 44, 123, 123, 104, 125, 47, 50, 125,
  44, 48, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 50, 53, 53, 32, 45, 119, 97, 114, 112, 91, 48, 93, 32, 91, 49,
  93, 44, 49, 44, 49, 44, 49, 32, 32, 45, 119, 97, 114, 112, 91, 48,
  93, 32, 91, 49, 93, 44, 49, 44, 49, 44, 49, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 84, 101, 115, 116, 61, 61, 52,
  125, 10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 52, 32, 45, 102,
  105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 103,
  105, 109, 112, 95, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 50, 48,
  48, 44, 48, 44, 48, 44, 48, 44, 48, 32, 45, 112, 111, 108, 121, 103,
  111, 110, 91, 45, 49, 93, 32, 51, 44, 48, 44, 48, 44, 123, 119, 125,
  44, 48, 44, 48, 44, 123, 104, 125, 44, 49, 44, 48, 44, 48, 44, 48,
  44, 50, 53, 53, 32, 45, 119, 97, 114, 112, 91, 48, 93, 32, 91, 49,
  93, 44, 49, 44, 49, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 84, 101, 115, 116, 61, 61, 53, 125, 10, 123, 119,
  125, 44, 123, 104, 125, 44, 49, 44, 52, 32, 45, 102, 105, 108, 108, 95,
  99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 103, 105, 109, 112, 95,
  110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 50, 48, 48, 44, 48, 44,
  48, 44, 48, 44, 48, 32, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45,
  49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32,
  45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 32, 45, 112, 111,
  108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 51, 44, 48, 44, 48, 44,
  123, 119, 125, 44, 48, 44, 48, 44, 123, 104, 125, 44, 49, 44, 48, 44,
  48, 44, 48, 44, 50, 53, 53, 32, 45, 119, 97, 114, 112, 91, 48, 93,
  32, 91, 49, 93, 44, 49, 44, 49, 44, 49, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 84, 101, 115, 116, 61, 61, 54, 125,
  10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 52, 32, 45, 102, 105,
  108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48,
  44, 48, 44, 50, 53, 53, 32, 45, 77, 97, 115, 113, 117, 101, 115, 95,
  103, 101, 111, 109, 101, 116, 114, 105, 113, 117, 101, 115, 95, 115, 97, 109,
  106, 91, 45, 49, 93, 32, 49, 54, 44, 56, 44, 49, 44, 49, 44, 54,
  48, 44, 54, 48, 44, 54, 48, 44, 50, 53, 53, 44, 54, 48, 44, 54,
  48, 44, 54, 48, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 50, 44, 48, 44, 48, 44, 48, 46, 55, 44, 48, 46, 51, 44, 48,
  46, 54, 44, 49, 46, 49, 44, 49, 53, 44, 56, 44, 48, 44, 48, 44,
  48, 32, 32, 45, 119, 97, 114, 112, 91, 48, 93, 32, 91, 49, 93, 44,
  49, 44, 49, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 84, 101, 115, 116, 61, 61, 55, 125, 10, 123, 119, 125, 44,
  123, 104, 125, 44, 49, 44, 52, 32, 45, 102, 105, 108, 108, 95, 99, 111,
  108, 111, 114, 91, 45, 49, 93, 32, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 32, 45, 103, 105, 109, 112, 95, 110, 111,
  105, 115, 101, 91, 45, 49, 93, 32, 50, 48, 48, 44, 48, 44, 48, 44,
  48, 44, 48, 32, 45, 119, 97, 114, 112, 91, 48, 93, 32, 91, 49, 93,
  44, 49, 44, 49, 44, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 84, 101, 115, 116, 61, 61, 56, 125, 10, 123, 119, 125,
  44, 123, 104, 125, 44, 49, 44, 52, 32, 45, 102, 105, 108, 108, 95, 99,
  111, 108, 111, 114, 91, 45, 49, 93, 32, 50, 53, 53, 44, 50, 53, 53,
  44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 103, 105, 109, 112, 95, 110,
  111, 105, 115, 101, 91, 45, 49, 93, 32, 50, 48, 48, 44, 48, 44, 48,
  44, 48, 44, 48, 32, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 49,
  93, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45,
  116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 32, 45, 119, 97, 114,
  112, 91, 48, 93, 32, 91, 49, 93, 44, 49, 44, 49, 44, 49, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84, 101, 115, 116,
  61, 61, 57, 125, 10, 69, 120, 112, 61, 123, 123, 123, 119, 125, 43, 123,
  104, 125, 125, 47, 56, 125, 10, 123, 119, 125, 44, 123, 104, 125, 44, 49,
  44, 52, 32, 45, 103, 105, 109, 112, 95, 110, 111, 105, 115, 101, 91, 45,
  49, 93, 32, 50, 48, 48, 44, 48, 44, 48, 44, 48, 44, 48, 32, 45,
  116, 111, 95, 103, 114, 97, 121, 91, 45, 49, 93, 32, 45, 110, 91, 45,
  49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 116, 111, 95, 114, 103, 98,
  97, 91, 45, 49, 93, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121,
  91, 45, 49, 44, 45, 50, 93, 32, 36, 69, 120, 112, 32, 45, 119, 97,
  114, 112, 91, 48, 93, 32, 91, 49, 93, 44, 49, 44, 49, 44, 49, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84, 101, 115,
  116, 61, 61, 49, 48, 125, 10, 87, 95, 111, 114, 105, 103, 105, 110, 101,
  61, 123, 119, 125, 10, 72, 95, 111, 114, 105, 103, 105, 110, 101, 61, 123,
  104, 125, 10, 69, 120, 112, 61, 123, 123, 123, 119, 125, 43, 123, 104, 125,
  125, 47, 56, 125, 10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 52,
  32, 45, 103, 105, 109, 112, 95, 110, 111, 105, 115, 101, 91, 45, 49, 93,
  32, 50, 48, 48, 44, 48, 44, 48, 44, 48, 44, 48, 32, 45, 116, 111,
  95, 103, 114, 97, 121, 91, 45, 49, 93, 32, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 32, 45, 116, 111, 95, 114, 103, 98, 97, 91,
  45, 49, 93, 32, 45, 101, 120, 112, 97, 110, 100, 95, 120, 121, 91, 45,
  49, 44, 45, 50, 93, 32, 36, 69, 120, 112, 32, 45, 119, 97, 114, 112,
  91, 48, 93, 32, 91, 49, 93, 44, 49, 44, 49, 44, 49, 32, 45, 99,
  114, 111, 112, 32, 36, 69, 120, 112, 44, 36, 69, 120, 112, 44, 123, 36,
  69, 120, 112, 43, 36, 87, 95, 111, 114, 105, 103, 105, 110, 101, 125, 44,
  123, 36, 69, 120, 112, 43, 36, 72, 95, 111, 114, 105, 103, 105, 110, 101,
  125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84,
  101, 115, 116, 61, 61, 49, 49, 125, 10, 69, 120, 112, 61, 123, 123, 123,
  119, 125, 43, 123, 104, 125, 125, 47, 56, 125, 10, 123, 119, 125, 44, 123,
  104, 125, 44, 49, 44, 52, 32, 45, 103, 105, 109, 112, 95, 110, 111, 105,
  115, 101, 91, 45, 49, 93, 32, 50, 48, 48, 44, 48, 44, 48, 44, 48,
  44, 48, 32, 45, 116, 111, 95, 103, 114, 97, 121, 91, 45, 49, 93, 32,
  45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 116, 111,
  95, 114, 103, 98, 97, 91, 45, 49, 93, 32, 45, 101, 120, 112, 97, 110,
  100, 95, 120, 121, 91, 45, 49, 44, 45, 50, 93, 32, 36, 69, 120, 112,
  44, 48, 32, 45, 119, 97, 114, 112, 91, 48, 93, 32, 91, 49, 93, 44,
  49, 44, 49, 44, 49, 32, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91,
  45, 49, 44, 45, 50, 93, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 84, 101, 115, 116, 61, 61, 49, 50, 125, 10, 69, 120,
  112, 61, 123, 123, 123, 119, 125, 43, 123, 104, 125, 125, 47, 56, 125, 10,
  123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 52, 32, 45, 103, 105, 109,
  112, 95, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 50, 48, 48, 44,
  48, 44, 48, 44, 48, 44, 48, 32, 45, 116, 111, 95, 103, 114, 97, 121,
  91, 45, 49, 93, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53,
  53, 32, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 32, 45,
  101, 120, 112, 97, 110, 100, 95, 120, 121, 91, 45, 49, 44, 45, 50, 93,
  32, 36, 69, 120, 112, 44, 50, 32, 45, 119, 97, 114, 112, 91, 48, 93,
  32, 91, 49, 93, 44, 49, 44, 49, 44, 49, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 97, 108, 112, 104, 97,
  91, 45, 51, 44, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 98, 108,
  101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 36, 98, 108, 101, 110,
  100, 44, 36, 111, 112, 97, 99, 105, 116, 101, 44, 36, 82, 101, 118, 101,
  114, 116, 95, 108, 97, 121, 101, 114, 115, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 84, 101, 115, 116, 115, 95, 87, 97, 114, 112,
  95, 115, 97, 109, 106, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 84, 101, 115, 116, 115, 95, 87, 97, 114, 112,
  95, 115, 97, 109, 106, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36,
  45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 84, 101, 120, 116, 117, 114,
  101, 32, 48, 48, 51, 32, 40, 97, 113, 117, 97, 114, 101, 108, 108, 101,
  32, 45, 32, 119, 97, 116, 101, 114, 99, 111, 108, 111, 114, 41, 32, 58,
  32, 115, 97, 109, 106, 95, 84, 101, 120, 116, 117, 114, 101, 95, 65, 113,
  117, 97, 114, 101, 108, 108, 101, 95, 49, 44, 32, 115, 97, 109, 106, 95,
  84, 101, 120, 116, 117, 114, 101, 95, 65, 113, 117, 97, 114, 101, 108, 108,
  101, 95, 49, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 84, 101, 120, 116,
  117, 114, 101, 32, 65, 113, 117, 97, 114, 101, 108, 108, 101, 32, 47, 32,
  87, 97, 116, 101, 114, 99, 111, 108, 111, 114, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 69, 110, 32,
  104, 111, 109, 97, 103, 101, 32, 38, 35, 50, 50, 52, 59, 32, 70, 114,
  38, 35, 50, 51, 51, 59, 100, 38, 35, 50, 51, 51, 59, 114, 105, 99,
  32, 66, 97, 99, 107, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  108, 105, 110, 107, 40, 34, 104, 116, 116, 112, 58, 47, 47, 102, 114, 46,
  119, 105, 107, 105, 112, 101, 100, 105, 97, 46, 111, 114, 103, 47, 119, 105,
  107, 105, 47, 70, 114, 37, 67, 51, 37, 65, 57, 100, 37, 67, 51, 37,
  65, 57, 114, 105, 99, 95, 66, 97, 99, 107, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110,
  107, 40, 34, 104, 116, 116, 112, 58, 47, 47, 101, 110, 46, 119, 105, 107,
  105, 112, 101, 100, 105, 97, 46, 111, 114, 103, 47, 119, 105, 107, 105, 47,
  70, 114, 37, 67, 51, 37, 65, 57, 100, 37, 67, 51, 37, 65, 57, 114,
  105, 99, 95, 66, 97, 99, 107, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 84, 101, 120, 116, 117, 114, 101, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112,
  108, 105, 116, 117, 100, 101, 32, 110, 111, 105, 115, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 48, 44, 53, 44, 50, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 110, 115, 105, 116, 121, 32,
  104, 97, 114, 100, 115, 107, 101, 116, 99, 104, 98, 119, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 48, 44, 53, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 114, 101, 97, 100, 32, 118,
  97, 114, 105, 97, 116, 105, 111, 110, 115, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 52, 44, 51, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 119, 97, 116,
  101, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 44, 50, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 67, 111, 117, 108, 101,
  117, 114, 32, 47, 32, 67, 111, 108, 111, 114, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111,
  117, 108, 101, 117, 114, 32, 47, 32, 99, 111, 108, 111, 114, 32, 61, 32,
  99, 111, 108, 111, 114, 40, 50, 53, 49, 44, 50, 51, 55, 44, 50, 48,
  54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99,
  105, 116, 92, 51, 48, 51, 92, 50, 53, 49, 32, 47, 32, 111, 112, 97,
  99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 45,
  49, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97, 109, 106,
  32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 49, 50, 47, 50, 55,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  115, 97, 109, 106, 95, 84, 101, 120, 116, 117, 114, 101, 95, 65, 113, 117,
  97, 114, 101, 108, 108, 101, 95, 49, 32, 58, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 65, 109, 112,
  108, 105, 116, 117, 100, 101, 95, 78, 111, 105, 115, 101, 61, 36, 49, 10,
  68, 101, 110, 115, 105, 116, 121, 95, 72, 97, 114, 100, 115, 107, 101, 116,
  99, 104, 98, 119, 61, 36, 50, 10, 83, 112, 114, 101, 97, 100, 95, 86,
  97, 114, 105, 97, 116, 105, 111, 110, 115, 61, 36, 51, 10, 65, 109, 112,
  108, 105, 116, 117, 100, 101, 95, 87, 97, 116, 101, 114, 61, 36, 52, 10,
  82, 51, 61, 36, 53, 10, 86, 51, 61, 36, 54, 10, 66, 51, 61, 36,
  55, 10, 79, 112, 97, 99, 105, 116, 101, 61, 36, 56, 10, 35, 35, 35,
  35, 32, 105, 109, 97, 103, 101, 32, 49, 10, 123, 119, 125, 44, 123, 104,
  125, 44, 49, 44, 51, 10, 45, 114, 109, 91, 45, 50, 93, 10, 45, 102,
  105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 116, 111, 95, 114, 103,
  98, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 110, 111, 105, 115,
  101, 91, 45, 49, 93, 32, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  95, 78, 111, 105, 115, 101, 44, 48, 44, 50, 44, 48, 10, 45, 103, 105,
  109, 112, 95, 104, 97, 114, 100, 115, 107, 101, 116, 99, 104, 98, 119, 91,
  45, 49, 93, 32, 51, 48, 48, 44, 36, 68, 101, 110, 115, 105, 116, 121,
  95, 72, 97, 114, 100, 115, 107, 101, 116, 99, 104, 98, 119, 44, 49, 44,
  48, 46, 49, 44, 50, 48, 44, 48, 44, 48, 10, 35, 35, 35, 35, 32,
  105, 109, 97, 103, 101, 32, 50, 10, 123, 119, 125, 44, 123, 104, 125, 44,
  49, 44, 51, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91,
  45, 49, 93, 32, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10,
  45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10, 45, 103, 105, 109,
  112, 95, 110, 111, 105, 115, 101, 91, 45, 49, 93, 32, 36, 65, 109, 112,
  108, 105, 116, 117, 100, 101, 95, 78, 111, 105, 115, 101, 44, 48, 44, 50,
  44, 48, 10, 45, 103, 105, 109, 112, 95, 104, 97, 114, 100, 115, 107, 101,
  116, 99, 104, 98, 119, 91, 45, 49, 93, 32, 51, 48, 48, 44, 36, 68,
  101, 110, 115, 105, 116, 121, 95, 72, 97, 114, 100, 115, 107, 101, 116, 99,
  104, 98, 119, 44, 49, 44, 48, 46, 49, 44, 50, 48, 44, 48, 44, 48,
  10, 45, 103, 105, 109, 112, 95, 115, 112, 114, 101, 97, 100, 91, 45, 49,
  93, 32, 36, 83, 112, 114, 101, 97, 100, 95, 86, 97, 114, 105, 97, 116,
  105, 111, 110, 115, 44, 36, 83, 112, 114, 101, 97, 100, 95, 86, 97, 114,
  105, 97, 116, 105, 111, 110, 115, 44, 48, 44, 48, 10, 45, 103, 105, 109,
  112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 51,
  44, 49, 44, 48, 10, 45, 119, 97, 116, 101, 114, 91, 45, 49, 93, 32,
  36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 95, 87, 97, 116, 101, 114,
  44, 48, 10, 35, 35, 35, 35, 32, 105, 109, 97, 103, 101, 32, 51, 32,
  99, 111, 117, 108, 101, 117, 114, 10, 123, 119, 125, 44, 123, 104, 125, 44,
  49, 44, 51, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91,
  45, 49, 93, 32, 36, 82, 51, 44, 36, 86, 51, 44, 36, 66, 51, 10,
  45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 10, 45, 105, 102, 32,
  123, 36, 79, 112, 97, 99, 105, 116, 101, 62, 61, 48, 125, 10, 45, 103,
  105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93,
  32, 50, 51, 44, 36, 79, 112, 97, 99, 105, 116, 101, 44, 48, 10, 45,
  101, 108, 115, 101, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100,
  91, 45, 49, 44, 45, 50, 93, 32, 50, 51, 44, 40, 49, 43, 36, 79,
  112, 97, 99, 105, 116, 101, 41, 44, 49, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115, 97, 109,
  106, 95, 84, 101, 120, 116, 117, 114, 101, 95, 65, 113, 117, 97, 114, 101,
  108, 108, 101, 95, 49, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 84, 101, 120, 116, 117,
  114, 101, 95, 65, 113, 117, 97, 114, 101, 108, 108, 101, 95, 49, 32, 36,
  42, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 87, 101,
  97, 118, 101, 32, 48, 48, 49, 32, 58, 32, 115, 97, 109, 106, 95, 119,
  101, 97, 118, 101, 95, 48, 48, 49, 44, 32, 115, 97, 109, 106, 95, 119,
  101, 97, 118, 101, 95, 48, 48, 49, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100,
  61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109,
  97, 108, 108, 62, 87, 101, 97, 118, 101, 32, 112, 97, 114, 32, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112,
  97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68,
  101, 110, 115, 105, 116, 121, 32, 61, 32, 105, 110, 116, 40, 51, 50, 44,
  49, 44, 49, 50, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  84, 104, 105, 99, 107, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 54, 53, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 104, 97, 100, 111, 119, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 104, 97, 100, 105, 110, 103, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44, 51, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 70, 105, 98, 101, 114, 115, 32, 97,
  109, 112, 108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 70, 105, 98, 101, 114, 115, 32, 115, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110,
  103, 108, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 48, 32,
  100, 101, 103, 46, 34, 44, 34, 50, 50, 46, 53, 32, 100, 101, 103, 46,
  34, 44, 34, 52, 53, 32, 100, 101, 103, 46, 34, 44, 34, 54, 55, 46,
  53, 32, 100, 101, 103, 46, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 45, 99, 117, 114, 118, 97, 116, 117, 114, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 89, 45, 99, 117, 114, 118, 97, 116, 117,
  114, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97,
  110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114,
  97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62,
  68, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 60, 47, 115, 109, 97,
  108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 101, 102, 111, 114, 109, 97, 116, 105, 111,
  110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 46,
  49, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111,
  115, 115, 105, 110, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105,
  101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44,
  34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 100, 101, 102, 111, 114,
  109, 97, 116, 105, 111, 110, 32, 115, 97, 109, 106, 32, 45, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105,
  62, 50, 48, 49, 52, 47, 48, 49, 47, 49, 49, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95,
  119, 101, 97, 118, 101, 95, 48, 48, 49, 58, 10, 45, 118, 32, 45, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 108, 91, 36, 62,
  93, 10, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121,
  10, 45, 108, 91, 48, 93, 10, 119, 61, 123, 114, 111, 117, 110, 100, 40,
  109, 97, 120, 40, 119, 44, 104, 41, 47, 36, 49, 44, 49, 44, 49, 41,
  125, 10, 104, 61, 36, 119, 32, 115, 61, 123, 40, 49, 48, 48, 45, 36,
  51, 41, 42, 50, 53, 53, 37, 125, 10, 112, 61, 123, 109, 97, 120, 40,
  48, 46, 48, 49, 44, 36, 52, 41, 125, 10, 49, 44, 36, 104, 32, 45,
  61, 91, 45, 49, 93, 32, 49, 44, 48, 44, 53, 48, 37, 32, 45, 100,
  105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 94,
  91, 45, 49, 93, 32, 36, 112, 32, 45, 99, 91, 45, 49, 93, 32, 53,
  48, 37, 44, 49, 48, 48, 37, 32, 45, 114, 91, 45, 49, 93, 32, 123,
  109, 97, 120, 40, 49, 44, 114, 111, 117, 110, 100, 40, 36, 50, 42, 36,
  119, 37, 41, 41, 125, 44, 49, 48, 48, 37, 10, 36, 119, 44, 49, 32,
  45, 61, 91, 45, 49, 93, 32, 49, 44, 53, 48, 37, 32, 45, 100, 105,
  115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45, 94, 91,
  45, 49, 93, 32, 36, 112, 32, 45, 99, 91, 45, 49, 93, 32, 53, 48,
  37, 44, 49, 48, 48, 37, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49,
  32, 45, 114, 91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 123, 109, 97,
  120, 40, 49, 44, 114, 111, 117, 110, 100, 40, 36, 50, 42, 36, 104, 37,
  41, 41, 125, 10, 45, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45,
  45, 42, 91, 45, 51, 93, 32, 45, 49, 32, 45, 110, 91, 45, 52, 44,
  45, 50, 93, 32, 48, 44, 36, 115, 32, 45, 110, 91, 45, 51, 44, 45,
  49, 93, 32, 36, 115, 44, 50, 53, 53, 10, 123, 119, 125, 44, 49, 32,
  49, 44, 91, 45, 51, 93, 32, 45, 114, 97, 110, 100, 91, 45, 50, 44,
  45, 49, 93, 32, 48, 44, 49, 32, 45, 98, 91, 45, 50, 44, 45, 49,
  93, 32, 36, 54, 37, 32, 45, 110, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 36, 53, 44, 36, 53, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45,
  52, 93, 32, 45, 43, 91, 45, 53, 93, 32, 91, 45, 49, 93, 32, 45,
  43, 91, 45, 52, 44, 45, 49, 93, 32, 45, 43, 91, 45, 53, 93, 32,
  91, 45, 49, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45,
  45, 102, 91, 45, 51, 93, 32, 50, 53, 53, 32, 45, 97, 91, 45, 52,
  44, 45, 49, 93, 32, 99, 32, 45, 45, 102, 91, 45, 49, 93, 32, 50,
  53, 53, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 97,
  109, 112, 95, 120, 61, 123, 36, 56, 42, 40, 36, 119, 45, 119, 41, 47,
  50, 125, 32, 97, 109, 112, 95, 121, 61, 123, 36, 57, 42, 40, 36, 119,
  45, 119, 41, 47, 50, 125, 10, 45, 114, 91, 45, 52, 45, 45, 49, 93,
  32, 36, 119, 44, 36, 104, 44, 49, 44, 49, 48, 48, 37, 44, 48, 44,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 102, 91, 45, 52, 93,
  32, 39, 105, 40, 120, 43, 36, 97, 109, 112, 95, 120, 42, 115, 105, 110,
  40, 121, 47, 104, 42, 112, 105, 41, 44, 121, 44, 48, 44, 99, 44, 49,
  44, 50, 41, 39, 32, 45, 102, 91, 45, 49, 93, 32, 39, 105, 40, 120,
  45, 36, 97, 109, 112, 95, 120, 42, 115, 105, 110, 40, 121, 47, 104, 42,
  112, 105, 41, 44, 121, 44, 48, 44, 99, 44, 49, 44, 50, 41, 39, 10,
  45, 102, 91, 45, 51, 93, 32, 39, 105, 40, 120, 44, 121, 43, 36, 97,
  109, 112, 95, 121, 42, 115, 105, 110, 40, 120, 47, 119, 42, 112, 105, 41,
  44, 48, 44, 99, 44, 49, 44, 50, 41, 39, 32, 45, 102, 91, 45, 50,
  93, 32, 39, 105, 40, 120, 44, 121, 45, 36, 97, 109, 112, 95, 121, 42,
  115, 105, 110, 40, 120, 47, 119, 42, 112, 105, 41, 44, 48, 44, 99, 44,
  49, 44, 50, 41, 39, 10, 45, 98, 108, 101, 110, 100, 91, 45, 52, 44,
  45, 51, 93, 32, 97, 108, 112, 104, 97, 32, 45, 98, 108, 101, 110, 100,
  91, 45, 50, 44, 45, 49, 93, 32, 97, 108, 112, 104, 97, 32, 45, 99,
  91, 45, 50, 44, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 47,
  91, 45, 50, 44, 45, 49, 93, 32, 50, 53, 53, 32, 91, 45, 49, 93,
  32, 91, 45, 51, 93, 32, 45, 97, 91, 45, 52, 44, 45, 50, 93, 32,
  120, 32, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 120, 32, 45, 97,
  91, 45, 50, 44, 45, 49, 93, 32, 121, 32, 45, 114, 111, 116, 97, 116,
  101, 95, 116, 105, 108, 101, 97, 98, 108, 101, 91, 45, 49, 93, 32, 123,
  36, 55, 42, 50, 50, 46, 53, 125, 32, 45, 114, 91, 45, 49, 93, 32,
  91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 49, 44, 49, 44, 48, 44,
  50, 10, 45, 105, 102, 32, 123, 36, 49, 49, 61, 61, 48, 125, 32, 45,
  103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 100, 101, 102, 111,
  114, 109, 97, 116, 105, 111, 110, 91, 45, 49, 93, 32, 99, 111, 115, 40,
  121, 42, 123, 36, 49, 48, 42, 123, 119, 43, 104, 125, 125, 47, 104, 41,
  44, 115, 105, 110, 40, 120, 42, 123, 36, 49, 48, 42, 123, 119, 43, 104,
  125, 125, 47, 119, 41, 44, 49, 44, 49, 44, 49, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 42, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 110,
  100, 108, 10, 45, 97, 32, 99, 10, 45, 101, 110, 100, 108, 10, 45, 105,
  102, 32, 123, 36, 49, 49, 61, 61, 49, 125, 32, 45, 103, 105, 109, 112,
  95, 99, 117, 115, 116, 111, 109, 95, 100, 101, 102, 111, 114, 109, 97, 116,
  105, 111, 110, 91, 45, 49, 93, 32, 99, 111, 115, 40, 121, 42, 123, 36,
  49, 48, 42, 123, 119, 43, 104, 125, 125, 47, 104, 41, 44, 115, 105, 110,
  40, 120, 42, 123, 36, 49, 48, 42, 123, 119, 43, 104, 125, 125, 47, 119,
  41, 44, 49, 44, 49, 44, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  100, 111, 110, 101, 10, 45, 118, 32, 43, 10, 115, 97, 109, 106, 95, 114,
  105, 101, 110, 95, 114, 101, 110, 100, 101, 114, 105, 110, 103, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103,
  91, 45, 49, 93, 10, 35, 64, 103, 105, 109, 112, 32, 95, 10, 35, 64,
  103, 105, 109, 112, 32, 60, 105, 62, 82, 101, 110, 100, 101, 114, 105, 110,
  103, 60, 47, 105, 62, 10, 35, 64, 103, 105, 109, 112, 32, 67, 111, 117,
  114, 98, 101, 115, 32, 102, 101, 114, 109, 101, 101, 115, 32, 32, 45, 32,
  99, 108, 111, 115, 101, 100, 32, 99, 117, 114, 118, 101, 115, 32, 40, 118,
  49, 41, 32, 58, 32, 115, 97, 109, 106, 95, 99, 111, 117, 114, 98, 101,
  115, 95, 102, 101, 114, 109, 101, 101, 115, 95, 86, 49, 44, 32, 115, 97,
  109, 106, 95, 99, 111, 117, 114, 98, 101, 115, 95, 102, 101, 114, 109, 101,
  101, 115, 95, 86, 49, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 67, 111,
  117, 114, 98, 101, 115, 32, 102, 101, 114, 109, 92, 51, 48, 51, 92, 50,
  53, 49, 101, 115, 32, 47, 32, 67, 108, 111, 115, 101, 100, 32, 99, 117,
  114, 118, 101, 115, 92, 114, 92, 110, 88, 45, 89, 32, 123, 80, 97, 114,
  97, 109, 101, 116, 114, 101, 49, 43, 123, 99, 111, 115, 45, 115, 105, 110,
  84, 42, 80, 97, 114, 97, 109, 101, 116, 114, 101, 50, 125, 42, 123, 80,
  97, 114, 97, 109, 101, 116, 114, 101, 52, 43, 123, 99, 111, 115, 45, 115,
  105, 110, 84, 42, 80, 97, 114, 97, 109, 101, 116, 114, 101, 51, 125, 125,
  125, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 101, 110, 116, 114, 101, 32, 47, 32, 99, 101,
  110, 116, 101, 114, 32, 120, 32, 40, 37, 41, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 101, 110, 116, 114, 101, 32, 47, 32, 99,
  101, 110, 116, 101, 114, 32, 121, 32, 40, 37, 41, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 51, 54, 48, 44, 48, 44, 51, 54, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 99, 114, 101, 109, 101,
  110, 116, 32, 97, 110, 103, 117, 108, 97, 105, 114, 101, 32, 47, 32, 97,
  110, 103, 117, 108, 97, 114, 32, 105, 110, 99, 114, 101, 109, 101, 110, 116,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 53, 48, 44, 48, 46,
  48, 49, 44, 49, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  68, 105, 109, 101, 110, 115, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 51, 48, 44, 49, 54, 44, 49, 48, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 80, 97, 114, 97, 109, 92, 51, 48, 51,
  92, 50, 53, 48, 116, 114, 101, 32, 49, 32, 47, 32, 112, 97, 114, 97,
  109, 101, 116, 101, 114, 32, 49, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  52, 44, 48, 44, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  80, 97, 114, 97, 109, 92, 51, 48, 51, 92, 50, 53, 48, 116, 114, 101,
  32, 50, 32, 47, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 32, 50,
  32, 61, 32, 105, 110, 116, 40, 51, 44, 48, 44, 56, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 80, 97, 114, 97, 109, 92, 51, 48, 51,
  92, 50, 53, 48, 116, 114, 101, 32, 51, 32, 47, 32, 112, 97, 114, 97,
  109, 101, 116, 101, 114, 32, 51, 32, 61, 32, 105, 110, 116, 40, 50, 44,
  49, 44, 49, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80,
  97, 114, 97, 109, 92, 51, 48, 51, 92, 50, 53, 48, 116, 114, 101, 32,
  52, 32, 47, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 32, 52, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 46, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 118, 101, 114, 115,
  105, 111, 110, 32, 40, 115, 105, 110, 47, 99, 111, 115, 41, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 83, 97, 110, 115, 32, 47, 32, 87,
  105, 116, 104, 111, 117, 116, 32, 45, 32, 84, 121, 112, 101, 32, 49, 34,
  44, 34, 65, 118, 101, 99, 32, 47, 32, 87, 105, 116, 104, 32, 45, 32,
  84, 121, 112, 101, 32, 49, 34, 44, 34, 83, 97, 110, 115, 32, 47, 32,
  87, 105, 116, 104, 111, 117, 116, 32, 45, 32, 84, 121, 112, 101, 32, 50,
  34, 44, 34, 65, 118, 101, 99, 32, 47, 32, 87, 105, 116, 104, 32, 45,
  32, 84, 121, 112, 101, 32, 50, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 84, 121, 112, 101, 32, 100, 101, 32, 114, 101, 110, 100, 117,
  32, 47, 32, 114, 101, 110, 100, 101, 114, 105, 110, 103, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 80, 111,
  105, 110, 116, 115, 34, 44, 34, 67, 101, 114, 99, 108, 101, 115, 32, 47,
  32, 67, 105, 114, 99, 108, 101, 115, 34, 44, 34, 76, 105, 103, 110, 101,
  115, 32, 47, 32, 76, 105, 110, 101, 115, 34, 44, 34, 83, 101, 103, 109,
  101, 110, 116, 115, 32, 99, 101, 110, 116, 114, 101, 32, 47, 32, 83, 101,
  103, 109, 101, 110, 116, 115, 32, 99, 101, 110, 116, 101, 114, 34, 44, 34,
  67, 101, 114, 99, 108, 101, 115, 32, 43, 32, 83, 101, 103, 109, 101, 110,
  116, 115, 32, 99, 101, 110, 116, 114, 101, 32, 47, 32, 67, 105, 114, 99,
  108, 101, 115, 32, 61, 32, 83, 101, 103, 109, 101, 110, 116, 115, 32, 99,
  101, 110, 116, 101, 114, 34, 44, 34, 67, 101, 114, 99, 108, 101, 115, 32,
  43, 32, 83, 101, 103, 109, 101, 110, 116, 115, 32, 99, 101, 110, 116, 114,
  101, 32, 50, 32, 47, 32, 67, 105, 114, 99, 108, 101, 115, 32, 43, 32,
  83, 101, 103, 109, 101, 110, 116, 115, 32, 99, 101, 110, 116, 101, 114, 32,
  50, 34, 44, 34, 67, 101, 114, 99, 108, 101, 115, 32, 43, 32, 76, 105,
  103, 110, 101, 115, 32, 47, 32, 67, 105, 114, 99, 108, 101, 115, 32, 43,
  32, 76, 105, 110, 101, 115, 34, 44, 34, 67, 101, 114, 99, 108, 101, 115,
  32, 43, 32, 76, 105, 103, 110, 101, 115, 32, 50, 32, 47, 32, 67, 105,
  114, 99, 108, 101, 115, 32, 43, 32, 76, 105, 110, 101, 115, 32, 50, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 101, 114, 109, 101,
  114, 32, 99, 111, 117, 114, 98, 101, 32, 47, 32, 99, 108, 111, 115, 101,
  32, 99, 117, 114, 118, 101, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 121, 111, 110, 32,
  32, 99, 101, 114, 99, 108, 101, 115, 32, 47, 32, 114, 97, 100, 105, 117,
  115, 32, 99, 105, 114, 99, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40,
  50, 44, 49, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 49, 32, 47, 32, 99, 111,
  108, 111, 114, 32, 49, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53,
  53, 44, 50, 53, 53, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 50, 32, 47, 32, 99,
  111, 108, 111, 114, 32, 50, 32, 61, 32, 99, 111, 108, 111, 114, 40, 51,
  50, 44, 51, 50, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 32,
  100, 101, 115, 32, 99, 111, 117, 108, 101, 117, 114, 115, 32, 47, 32, 99,
  111, 108, 111, 114, 32, 116, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99,
  121, 32, 61, 32, 105, 110, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 114, 105,
  97, 116, 105, 111, 110, 32, 100, 101, 32, 99, 111, 117, 108, 101, 117, 114,
  32, 47, 32, 99, 111, 108, 111, 114, 32, 118, 97, 114, 105, 97, 116, 105,
  111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 80, 97, 115,
  32, 100, 101, 32, 118, 97, 114, 105, 97, 116, 105, 111, 110, 32, 47, 32,
  78, 111, 32, 99, 104, 97, 110, 103, 101, 34, 44, 34, 67, 111, 117, 108,
  101, 117, 114, 115, 32, 97, 108, 101, 97, 116, 111, 105, 114, 101, 115, 32,
  47, 32, 82, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111, 114, 115, 34,
  44, 34, 70, 97, 105, 98, 108, 101, 109, 101, 110, 116, 32, 110, 117, 97,
  110, 99, 101, 101, 32, 47, 32, 80, 111, 111, 114, 108, 121, 32, 110, 117,
  97, 110, 99, 101, 100, 34, 44, 34, 77, 111, 121, 101, 110, 110, 101, 109,
  101, 110, 116, 32, 110, 117, 97, 110, 99, 101, 101, 32, 47, 32, 77, 111,
  100, 101, 114, 97, 116, 101, 108, 121, 32, 110, 117, 97, 110, 99, 101, 100,
  34, 44, 34, 70, 111, 114, 116, 101, 109, 101, 110, 116, 32, 110, 117, 97,
  110, 99, 101, 101, 32, 47, 32, 72, 105, 103, 104, 108, 121, 32, 110, 117,
  97, 110, 99, 101, 100, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 82, 111, 116, 97, 116, 105, 111, 110, 32, 40, 100, 101, 103, 46, 41,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 51, 54, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 105, 108, 97, 116,
  97, 116, 105, 111, 110, 32, 40, 92, 51, 48, 51, 92, 50, 53, 49, 112,
  97, 105, 115, 115, 101, 117, 114, 41, 32, 61, 32, 105, 110, 116, 40, 49,
  44, 49, 44, 52, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 112, 114, 101, 97, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  70, 108, 111, 117, 32, 47, 32, 98, 108, 117, 114, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 68, 101, 102, 111, 114, 109, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 66, 108, 101, 110,
  100, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 49, 44, 34, 65, 100, 100, 34, 44, 34, 65, 108, 112, 104,
  97, 34, 44, 34, 65, 110, 100, 34, 44, 34, 65, 118, 101, 114, 97, 103,
  101, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 66, 117, 114, 110, 34,
  44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 68, 105, 102, 102, 101,
  114, 101, 110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 34, 68, 105, 118, 105, 100, 101, 34, 44, 34, 68, 111, 100, 103, 101,
  34, 44, 34, 69, 120, 99, 108, 117, 115, 105, 111, 110, 34, 44, 34, 70,
  114, 101, 101, 122, 101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 101, 120,
  116, 114, 97, 99, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 109, 101,
  114, 103, 101, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 72, 97,
  114, 100, 32, 108, 105, 103, 104, 116, 34, 44, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44, 34,
  72, 117, 101, 34, 44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116,
  105, 111, 110, 34, 44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44, 34,
  76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110, 101,
  97, 114, 32, 98, 117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97, 114,
  32, 108, 105, 103, 104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110,
  99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 77,
  117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 78, 101, 103, 97, 116, 105,
  111, 110, 34, 44, 34, 79, 114, 34, 44, 34, 79, 118, 101, 114, 108, 97,
  121, 34, 44, 34, 80, 105, 110, 32, 108, 105, 103, 104, 116, 34, 44, 34,
  82, 101, 100, 34, 44, 34, 82, 101, 102, 108, 101, 99, 116, 34, 44, 34,
  83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101,
  114, 97, 103, 101, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101,
  114, 97, 103, 101, 48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117, 114,
  110, 34, 44, 34, 83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34, 44,
  34, 83, 111, 102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83, 99,
  114, 101, 101, 110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34, 83,
  117, 98, 116, 114, 97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101, 34,
  44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 86, 105, 118, 105,
  100, 32, 108, 105, 103, 104, 116, 34, 44, 34, 88, 111, 114, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32,
  108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101,
  118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116,
  104, 111, 114, 32, 58, 32, 60, 105, 62, 83, 97, 109, 106, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47,
  48, 49, 47, 49, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 99, 111, 117, 114, 98, 101,
  115, 95, 102, 101, 114, 109, 101, 101, 115, 95, 86, 49, 32, 58, 10, 99,
  101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 61,
  123, 36, 49, 47, 49, 48, 48, 42, 119, 125, 10, 99, 101, 110, 116, 114,
  101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 61, 123, 36, 50, 47,
  49, 48, 48, 42, 104, 125, 10, 97, 110, 103, 108, 101, 61, 36, 51, 10,
  105, 110, 99, 114, 101, 109, 101, 110, 116, 95, 116, 104, 101, 116, 97, 61,
  36, 52, 10, 100, 105, 109, 101, 110, 115, 105, 111, 110, 61, 36, 53, 10,
  80, 97, 114, 97, 109, 101, 116, 114, 101, 95, 49, 61, 36, 54, 10, 80,
  97, 114, 97, 109, 101, 116, 114, 101, 95, 50, 61, 36, 55, 10, 80, 97,
  114, 97, 109, 101, 116, 114, 101, 95, 51, 61, 36, 56, 10, 80, 97, 114,
  97, 109, 101, 116, 114, 101, 95, 52, 61, 36, 57, 10, 73, 110, 118, 101,
  114, 115, 105, 111, 110, 61, 36, 49, 48, 10, 84, 121, 112, 101, 95, 100,
  101, 95, 114, 101, 110, 100, 117, 61, 36, 49, 49, 10, 70, 101, 114, 109,
  101, 114, 95, 99, 111, 117, 114, 98, 101, 61, 36, 49, 50, 10, 82, 97,
  121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 115, 61, 36, 49, 51, 10,
  35, 35, 32, 65, 84, 84, 69, 78, 84, 73, 79, 78, 32, 118, 97, 114,
  105, 97, 98, 108, 101, 115, 32, 36, 49, 52, 44, 36, 49, 53, 44, 36,
  49, 54, 32, 117, 116, 105, 108, 105, 115, -23, 101, 115, 32, 43, 32, 108,
  111, 105, 110, 32, 100, 97, 110, 115, 32, 108, 101, 32, 115, 99, 114, 105,
  112, 116, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 61, 36,
  49, 52, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 61, 36,
  49, 53, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 61, 36,
  49, 54, 10, 35, 35, 32, 65, 84, 84, 69, 78, 84, 73, 79, 78, 32,
  118, 97, 114, 105, 97, 98, 108, 101, 115, 32, 36, 49, 55, 44, 36, 49,
  56, 44, 36, 49, 57, 32, 117, 116, 105, 108, 105, 115, -23, 101, 115, 32,
  43, 32, 108, 111, 105, 110, 32, 100, 97, 110, 115, 32, 108, 101, 32, 115,
  99, 114, 105, 112, 116, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  50, 61, 36, 49, 55, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  50, 61, 36, 49, 56, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  50, 61, 36, 49, 57, 10, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110,
  99, 101, 95, 100, 101, 115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 61,
  36, 50, 48, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101,
  95, 99, 111, 117, 108, 101, 117, 114, 61, 36, 50, 49, 10, 82, 111, 116,
  97, 116, 105, 111, 110, 61, 36, 50, 50, 10, 86, 97, 108, 101, 117, 114,
  95, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 61, 36, 50, 51,
  10, 115, 112, 114, 101, 97, 100, 95, 99, 111, 117, 114, 98, 101, 95, 102,
  101, 114, 109, 101, 101, 115, 95, 86, 49, 61, 36, 50, 52, 10, 102, 108,
  111, 117, 95, 99, 111, 117, 114, 98, 101, 95, 102, 101, 114, 109, 101, 101,
  115, 95, 86, 49, 61, 36, 50, 53, 10, 100, 101, 102, 111, 114, 109, 97,
  116, 105, 111, 110, 95, 99, 111, 117, 114, 98, 101, 95, 102, 101, 114, 109,
  101, 101, 115, 95, 86, 49, 61, 36, 50, 54, 10, 98, 108, 101, 110, 100,
  61, 36, 50, 55, 10, 111, 112, 97, 99, 105, 116, 101, 61, 36, 50, 56,
  10, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 61, 36,
  50, 57, 10, 116, 104, 101, 116, 97, 61, 48, 10, 88, 61, 36, 99, 101,
  110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 10, 89,
  61, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101,
  95, 89, 10, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 61, 36,
  99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88,
  10, 89, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 61, 36, 99, 101,
  110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 10, 99,
  111, 109, 112, 116, 101, 117, 114, 95, 98, 111, 117, 99, 108, 101, 61, 48,
  10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 52, 10, 45, 102, 105,
  108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48,
  44, 48, 44, 48, 10, 45, 100, 111, 10, 45, 105, 102, 32, 123, 36, 73,
  110, 118, 101, 114, 115, 105, 111, 110, 61, 61, 48, 125, 10, 88, 61, 123,
  36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95,
  88, 43, 123, 36, 100, 105, 109, 101, 110, 115, 105, 111, 110, 42, 123, 123,
  36, 80, 97, 114, 97, 109, 101, 116, 114, 101, 95, 49, 43, 123, 99, 111,
  115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 80, 97, 114, 97, 109, 101,
  116, 114, 101, 95, 50, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 42,
  123, 36, 80, 97, 114, 97, 109, 101, 116, 114, 101, 95, 52, 43, 123, 99,
  111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 80, 97, 114, 97, 109,
  101, 116, 114, 101, 95, 51, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125,
  125, 125, 125, 10, 89, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111,
  114, 105, 103, 105, 110, 101, 95, 89, 43, 123, 36, 100, 105, 109, 101, 110,
  115, 105, 111, 110, 42, 123, 123, 36, 80, 97, 114, 97, 109, 101, 116, 114,
  101, 95, 49, 43, 123, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48, 42,
  36, 80, 97, 114, 97, 109, 101, 116, 114, 101, 95, 50, 42, 36, 116, 104,
  101, 116, 97, 41, 125, 125, 42, 123, 36, 80, 97, 114, 97, 109, 101, 116,
  114, 101, 95, 52, 43, 123, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48,
  42, 36, 80, 97, 114, 97, 109, 101, 116, 114, 101, 95, 51, 42, 36, 116,
  104, 101, 116, 97, 41, 125, 125, 125, 125, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 73, 110, 118, 101, 114, 115, 105, 111,
  110, 61, 61, 49, 125, 10, 88, 61, 123, 36, 99, 101, 110, 116, 114, 101,
  95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 43, 123, 36, 100, 105, 109,
  101, 110, 115, 105, 111, 110, 42, 123, 123, 36, 80, 97, 114, 97, 109, 101,
  116, 114, 101, 95, 49, 43, 123, 99, 111, 115, 40, 112, 105, 47, 49, 56,
  48, 42, 36, 80, 97, 114, 97, 109, 101, 116, 114, 101, 95, 50, 42, 36,
  116, 104, 101, 116, 97, 41, 125, 125, 42, 123, 36, 80, 97, 114, 97, 109,
  101, 116, 114, 101, 95, 52, 43, 123, 115, 105, 110, 40, 112, 105, 47, 49,
  56, 48, 42, 36, 80, 97, 114, 97, 109, 101, 116, 114, 101, 95, 51, 42,
  36, 116, 104, 101, 116, 97, 41, 125, 125, 125, 125, 125, 10, 89, 61, 123,
  36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95,
  89, 43, 123, 36, 100, 105, 109, 101, 110, 115, 105, 111, 110, 42, 123, 123,
  36, 80, 97, 114, 97, 109, 101, 116, 114, 101, 95, 49, 43, 123, 99, 111,
  115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 80, 97, 114, 97, 109, 101,
  116, 114, 101, 95, 50, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 42,
  123, 36, 80, 97, 114, 97, 109, 101, 116, 114, 101, 95, 52, 43, 123, 99,
  111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 80, 97, 114, 97, 109,
  101, 116, 114, 101, 95, 51, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125,
  125, 125, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 73, 110, 118, 101, 114, 115, 105, 111, 110, 61, 61, 50, 125, 10, 88,
  61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110,
  101, 95, 88, 43, 123, 36, 100, 105, 109, 101, 110, 115, 105, 111, 110, 42,
  123, 123, 36, 80, 97, 114, 97, 109, 101, 116, 114, 101, 95, 49, 43, 123,
  99, 111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 80, 97, 114, 97,
  109, 101, 116, 114, 101, 95, 50, 42, 36, 116, 104, 101, 116, 97, 41, 125,
  125, 42, 123, 36, 80, 97, 114, 97, 109, 101, 116, 114, 101, 95, 52, 43,
  123, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 80, 97, 114,
  97, 109, 101, 116, 114, 101, 95, 51, 42, 36, 116, 104, 101, 116, 97, 41,
  125, 125, 125, 125, 125, 10, 89, 61, 123, 36, 99, 101, 110, 116, 114, 101,
  95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 43, 123, 36, 100, 105, 109,
  101, 110, 115, 105, 111, 110, 42, 123, 123, 36, 80, 97, 114, 97, 109, 101,
  116, 114, 101, 95, 49, 43, 123, 115, 105, 110, 40, 112, 105, 47, 49, 56,
  48, 42, 36, 80, 97, 114, 97, 109, 101, 116, 114, 101, 95, 50, 42, 36,
  116, 104, 101, 116, 97, 41, 125, 125, 42, 123, 36, 80, 97, 114, 97, 109,
  101, 116, 114, 101, 95, 52, 43, 123, 99, 111, 115, 40, 112, 105, 47, 49,
  56, 48, 42, 36, 80, 97, 114, 97, 109, 101, 116, 114, 101, 95, 51, 42,
  36, 116, 104, 101, 116, 97, 41, 125, 125, 125, 125, 125, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 73, 110, 118, 101, 114, 115,
  105, 111, 110, 61, 61, 51, 125, 10, 88, 61, 123, 36, 99, 101, 110, 116,
  114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 43, 123, 36, 100,
  105, 109, 101, 110, 115, 105, 111, 110, 42, 123, 123, 36, 80, 97, 114, 97,
  109, 101, 116, 114, 101, 95, 49, 43, 123, 115, 105, 110, 40, 112, 105, 47,
  49, 56, 48, 42, 36, 80, 97, 114, 97, 109, 101, 116, 114, 101, 95, 50,
  42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 42, 123, 36, 80, 97, 114,
  97, 109, 101, 116, 114, 101, 95, 52, 43, 123, 99, 111, 115, 40, 112, 105,
  47, 49, 56, 48, 42, 36, 80, 97, 114, 97, 109, 101, 116, 114, 101, 95,
  51, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 125, 125, 125, 10, 89,
  61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110,
  101, 95, 89, 43, 123, 36, 100, 105, 109, 101, 110, 115, 105, 111, 110, 42,
  123, 123, 36, 80, 97, 114, 97, 109, 101, 116, 114, 101, 95, 49, 43, 123,
  99, 111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 80, 97, 114, 97,
  109, 101, 116, 114, 101, 95, 50, 42, 36, 116, 104, 101, 116, 97, 41, 125,
  125, 42, 123, 36, 80, 97, 114, 97, 109, 101, 116, 114, 101, 95, 52, 43,
  123, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 80, 97, 114,
  97, 109, 101, 116, 114, 101, 95, 51, 42, 36, 116, 104, 101, 116, 97, 41,
  125, 125, 125, 125, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95,
  99, 111, 117, 108, 101, 117, 114, 61, 61, 49, 125, 10, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 49, 61, 123, 114, 111, 117, 110, 100, 40, 63,
  40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 49, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 50, 53, 53, 41, 41, 125, 10, 66, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 49, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50,
  53, 53, 41, 41, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  50, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53,
  41, 41, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 61,
  123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41,
  125, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 61, 123, 114,
  111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117,
  114, 62, 49, 125, 10, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 61, 49, 54,
  10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 61, 51, 125, 10,
  86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 99, 111, 117, 108, 101, 117, 114, 61, 51, 50, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 61, 52,
  125, 10, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 61, 54, 52, 10, 45, 101,
  110, 100, 105, 102, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49,
  61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 49, 52, 43, 123, 63, 40,
  45, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 44, 36, 86, 97, 108, 101,
  117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117,
  108, 101, 117, 114, 41, 125, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 62, 50, 53, 53, 125,
  10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 61, 36, 49, 52,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 49, 60, 48, 125, 10, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 49, 61, 36, 49, 52, 10, 45, 101, 110,
  100, 105, 102, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 61,
  123, 114, 111, 117, 110, 100, 40, 123, 36, 49, 53, 43, 123, 63, 40, 45,
  36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 99, 111, 117, 108, 101, 117, 114, 44, 36, 86, 97, 108, 101, 117,
  114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108,
  101, 117, 114, 41, 125, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 62, 50, 53, 53, 125, 10,
  86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 61, 36, 49, 53, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 49, 60, 48, 125, 10, 86, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 49, 61, 36, 49, 53, 10, 45, 101, 110, 100,
  105, 102, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 61, 123,
  114, 111, 117, 110, 100, 40, 123, 36, 49, 54, 43, 123, 63, 40, 45, 36,
  86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 99, 111, 117, 108, 101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114,
  95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101,
  117, 114, 41, 125, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 66, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 49, 62, 50, 53, 53, 125, 10, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 61, 36, 49, 54, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 49, 60, 48, 125, 10, 66, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 49, 61, 36, 49, 54, 10, 45, 101, 110, 100, 105,
  102, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 61, 123, 114,
  111, 117, 110, 100, 40, 123, 36, 49, 55, 43, 123, 63, 40, 45, 36, 86,
  97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  99, 111, 117, 108, 101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114, 95,
  118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117,
  114, 41, 125, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 50, 62, 50, 53, 53, 125, 10, 82, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 50, 61, 36, 49, 55, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 50, 60, 48, 125, 10, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 50, 61, 36, 49, 55, 10, 45, 101, 110, 100, 105, 102,
  10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 61, 123, 114, 111,
  117, 110, 100, 40, 123, 36, 49, 56, 43, 123, 63, 40, 45, 36, 86, 97,
  108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99,
  111, 117, 108, 101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114, 95, 118,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114,
  41, 125, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 86, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 50, 62, 50, 53, 53, 125, 10, 86, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 50, 61, 36, 49, 56, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 50, 60, 48, 125, 10, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 50, 61, 36, 49, 56, 10, 45, 101, 110, 100, 105, 102, 10,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 61, 123, 114, 111, 117,
  110, 100, 40, 123, 36, 49, 57, 43, 123, 63, 40, 45, 36, 86, 97, 108,
  101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111,
  117, 108, 101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41,
  125, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 66, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 50, 62, 50, 53, 53, 125, 10, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 50, 61, 36, 49, 57, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 50, 60, 48, 125, 10, 66, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 50, 61, 36, 49, 57, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 99, 111, 109, 112,
  116, 101, 117, 114, 95, 98, 111, 117, 99, 108, 101, 61, 61, 48, 125, 10,
  88, 95, 111, 114, 105, 103, 105, 110, 101, 61, 36, 88, 10, 89, 95, 111,
  114, 105, 103, 105, 110, 101, 61, 36, 89, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 99, 111, 109, 112, 116, 101, 117, 114, 95,
  98, 111, 117, 99, 108, 101, 61, 61, 49, 125, 10, 88, 95, 98, 111, 117,
  99, 108, 101, 95, 49, 61, 36, 88, 10, 89, 95, 98, 111, 117, 99, 108,
  101, 95, 49, 61, 36, 89, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 84, 121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100,
  117, 61, 61, 48, 125, 10, 45, 112, 111, 105, 110, 116, 91, 45, 49, 93,
  32, 36, 88, 44, 36, 89, 44, 48, 44, 49, 44, 36, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 49, 44, 36, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 49, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  49, 44, 36, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 95,
  100, 101, 115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95, 100,
  101, 95, 114, 101, 110, 100, 117, 61, 61, 49, 125, 10, 45, 101, 108, 108,
  105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 88, 44, 36, 89, 44, 36,
  82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 115, 44, 36, 82,
  97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 115, 44, 48, 44, 49,
  44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 44, 36, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 44, 36, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 49, 44, 36, 84, 114, 97, 110, 115, 112, 97,
  114, 101, 110, 99, 101, 95, 100, 101, 115, 95, 99, 111, 117, 108, 101, 117,
  114, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  84, 121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100, 117, 61, 61, 50,
  125, 10, 45, 105, 102, 32, 123, 36, 99, 111, 109, 112, 116, 101, 117, 114,
  95, 98, 111, 117, 99, 108, 101, 62, 48, 125, 10, 45, 108, 105, 110, 101,
  91, 45, 49, 93, 32, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110,
  116, 44, 36, 89, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36,
  88, 44, 36, 89, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 49, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49,
  44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 44, 36, 84,
  114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 95, 100, 101, 115, 95,
  99, 111, 117, 108, 101, 117, 114, 115, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84, 121, 112,
  101, 95, 100, 101, 95, 114, 101, 110, 100, 117, 61, 61, 51, 125, 10, 45,
  108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 99, 101, 110, 116, 114, 101,
  95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 44, 36, 99, 101, 110, 116,
  114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 44, 36, 88, 44,
  36, 89, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  50, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 44, 36,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 44, 36, 84, 114, 97,
  110, 115, 112, 97, 114, 101, 110, 99, 101, 95, 100, 101, 115, 95, 99, 111,
  117, 108, 101, 117, 114, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 84, 121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100,
  117, 61, 61, 52, 125, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45,
  49, 93, 32, 36, 88, 44, 36, 89, 44, 36, 82, 97, 121, 111, 110, 95,
  99, 101, 114, 99, 108, 101, 115, 44, 36, 82, 97, 121, 111, 110, 95, 99,
  101, 114, 99, 108, 101, 115, 44, 48, 44, 49, 44, 36, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 49, 44, 36, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 49, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  49, 44, 36, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 95,
  100, 101, 115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 10, 45, 108, 105,
  110, 101, 91, 45, 49, 93, 32, 36, 99, 101, 110, 116, 114, 101, 95, 111,
  114, 105, 103, 105, 110, 101, 95, 88, 44, 36, 99, 101, 110, 116, 114, 101,
  95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 44, 36, 88, 44, 36, 89,
  44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 44,
  36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 44, 36, 66, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 50, 44, 36, 84, 114, 97, 110, 115,
  112, 97, 114, 101, 110, 99, 101, 95, 100, 101, 115, 95, 99, 111, 117, 108,
  101, 117, 114, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 84, 121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100, 117, 61,
  61, 53, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 99,
  101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 44,
  36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95,
  89, 44, 36, 88, 44, 36, 89, 44, 49, 44, 36, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 50, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 50, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50,
  44, 36, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 95, 100,
  101, 115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 10, 45, 101, 108, 108,
  105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 88, 44, 36, 89, 44, 36,
  82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 115, 44, 36, 82,
  97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 115, 44, 48, 44, 49,
  44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 44, 36, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 44, 36, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 49, 44, 36, 84, 114, 97, 110, 115, 112, 97,
  114, 101, 110, 99, 101, 95, 100, 101, 115, 95, 99, 111, 117, 108, 101, 117,
  114, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  84, 121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100, 117, 61, 61, 54,
  125, 10, 45, 105, 102, 32, 123, 36, 99, 111, 109, 112, 116, 101, 117, 114,
  95, 98, 111, 117, 99, 108, 101, 62, 48, 125, 10, 45, 108, 105, 110, 101,
  91, 45, 49, 93, 32, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110,
  116, 44, 36, 89, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36,
  88, 44, 36, 89, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 50, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50,
  44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 44, 36, 84,
  114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 95, 100, 101, 115, 95,
  99, 111, 117, 108, 101, 117, 114, 115, 10, 45, 101, 108, 108, 105, 112, 115,
  101, 91, 45, 49, 93, 32, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101,
  110, 116, 44, 36, 89, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44,
  36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 115, 44, 36,
  82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 115, 44, 48, 44,
  49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 44, 36,
  86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 44, 36, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 49, 44, 36, 84, 114, 97, 110, 115, 112,
  97, 114, 101, 110, 99, 101, 95, 100, 101, 115, 95, 99, 111, 117, 108, 101,
  117, 114, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 108, 105,
  112, 115, 101, 91, 45, 49, 93, 32, 36, 88, 44, 36, 89, 44, 36, 82,
  97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 115, 44, 36, 82, 97,
  121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 115, 44, 48, 44, 49, 44,
  36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 44, 36, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 49, 44, 36, 66, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 49, 44, 36, 84, 114, 97, 110, 115, 112, 97, 114,
  101, 110, 99, 101, 95, 100, 101, 115, 95, 99, 111, 117, 108, 101, 117, 114,
  115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84,
  121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100, 117, 61, 61, 55, 125,
  10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 88,
  44, 36, 89, 44, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108,
  101, 115, 44, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101,
  115, 44, 48, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 49, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 44,
  36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 44, 36, 84, 114,
  97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 95, 100, 101, 115, 95, 99,
  111, 117, 108, 101, 117, 114, 115, 10, 45, 105, 102, 32, 123, 36, 99, 111,
  109, 112, 116, 101, 117, 114, 95, 98, 111, 117, 99, 108, 101, 62, 48, 125,
  10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 88, 95, 112, 114,
  101, 99, 101, 100, 101, 110, 116, 44, 36, 89, 95, 112, 114, 101, 99, 101,
  100, 101, 110, 116, 44, 36, 88, 44, 36, 89, 44, 49, 44, 36, 82, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 50, 44, 36, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 50, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 50, 44, 36, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99,
  101, 95, 100, 101, 115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 99, 111, 109,
  112, 116, 101, 117, 114, 95, 98, 111, 117, 99, 108, 101, 61, 123, 36, 99,
  111, 109, 112, 116, 101, 117, 114, 95, 98, 111, 117, 99, 108, 101, 43, 49,
  125, 10, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 61, 36, 88,
  10, 89, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 61, 36, 89, 10,
  116, 104, 101, 116, 97, 61, 123, 36, 116, 104, 101, 116, 97, 43, 36, 105,
  110, 99, 114, 101, 109, 101, 110, 116, 95, 116, 104, 101, 116, 97, 125, 10,
  45, 119, 104, 105, 108, 101, 32, 123, 36, 116, 104, 101, 116, 97, 60, 123,
  36, 97, 110, 103, 108, 101, 43, 36, 105, 110, 99, 114, 101, 109, 101, 110,
  116, 95, 116, 104, 101, 116, 97, 125, 125, 10, 45, 105, 102, 32, 123, 36,
  70, 101, 114, 109, 101, 114, 95, 99, 111, 117, 114, 98, 101, 61, 61, 49,
  125, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 61, 49, 125,
  10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 61, 123, 114, 111,
  117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 61, 123, 114, 111, 117, 110,
  100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 49, 61, 123, 114, 111, 117, 110, 100, 40,
  63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 50, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40,
  48, 44, 50, 53, 53, 41, 41, 125, 10, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 50, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44,
  50, 53, 53, 41, 41, 125, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 50, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53,
  53, 41, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99,
  111, 117, 108, 101, 117, 114, 62, 49, 125, 10, 86, 97, 108, 101, 117, 114,
  95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101,
  117, 114, 61, 49, 54, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114,
  61, 61, 51, 125, 10, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 61, 51, 50,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101,
  117, 114, 61, 61, 52, 125, 10, 86, 97, 108, 101, 117, 114, 95, 118, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 61,
  54, 52, 10, 45, 101, 110, 100, 105, 102, 10, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 49, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 49,
  52, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 44,
  36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10, 45,
  105, 102, 32, 123, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49,
  62, 50, 53, 53, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  49, 61, 36, 49, 52, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 82, 95, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 60,
  48, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 61, 36,
  49, 52, 10, 45, 101, 110, 100, 105, 102, 10, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 49, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 49,
  53, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 44,
  36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10, 45,
  105, 102, 32, 123, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49,
  62, 50, 53, 53, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  49, 61, 36, 49, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 60, 48,
  125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 61, 36, 49,
  53, 10, 45, 101, 110, 100, 105, 102, 10, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 49, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 49, 54,
  43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 44, 36,
  86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10, 45, 105,
  102, 32, 123, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 62,
  50, 53, 53, 125, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49,
  61, 36, 49, 54, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 60, 48, 125,
  10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 61, 36, 49, 54,
  10, 45, 101, 110, 100, 105, 102, 10, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 50, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 49, 55, 43,
  123, 63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 44, 36, 86,
  97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  99, 111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10, 45, 105, 102,
  32, 123, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 62, 50,
  53, 53, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 61,
  36, 49, 55, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 60, 48, 125, 10,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 61, 36, 49, 55, 10,
  45, 101, 110, 100, 105, 102, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 50, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 49, 56, 43, 123,
  63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97,
  116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 44, 36, 86, 97,
  108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99,
  111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10, 45, 105, 102, 32,
  123, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 62, 50, 53,
  53, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 61, 36,
  49, 56, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 60, 48, 125, 10, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 61, 36, 49, 56, 10, 45,
  101, 110, 100, 105, 102, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  50, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 49, 57, 43, 123, 63,
  40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 44, 36, 86, 97, 108,
  101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111,
  117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10, 45, 105, 102, 32, 123,
  36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 62, 50, 53, 53,
  125, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 61, 36, 49,
  57, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 60, 48, 125, 10, 66, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 50, 61, 36, 49, 57, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 84, 121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100, 117, 61,
  61, 50, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 88,
  44, 36, 89, 44, 36, 88, 95, 111, 114, 105, 103, 105, 110, 101, 44, 36,
  89, 95, 111, 114, 105, 103, 105, 110, 101, 44, 49, 44, 36, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 49, 44, 36, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 49, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 49, 44, 36, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101,
  95, 100, 101, 115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95,
  100, 101, 95, 114, 101, 110, 100, 117, 61, 61, 54, 125, 10, 45, 108, 105,
  110, 101, 91, 45, 49, 93, 32, 36, 88, 44, 36, 89, 44, 36, 88, 95,
  111, 114, 105, 103, 105, 110, 101, 44, 36, 89, 95, 111, 114, 105, 103, 105,
  110, 101, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  50, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 44, 36,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 44, 36, 84, 114, 97,
  110, 115, 112, 97, 114, 101, 110, 99, 101, 95, 100, 101, 115, 95, 99, 111,
  117, 108, 101, 117, 114, 115, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91,
  45, 49, 93, 32, 36, 88, 95, 111, 114, 105, 103, 105, 110, 101, 44, 36,
  89, 95, 111, 114, 105, 103, 105, 110, 101, 44, 36, 82, 97, 121, 111, 110,
  95, 99, 101, 114, 99, 108, 101, 115, 44, 36, 82, 97, 121, 111, 110, 95,
  99, 101, 114, 99, 108, 101, 115, 44, 48, 44, 49, 44, 36, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 49, 44, 36, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 49, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 49, 44, 36, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101,
  95, 100, 101, 115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 10, 45, 101,
  108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 88, 44, 36, 89,
  44, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 115, 44,
  36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 115, 44, 48,
  44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 44,
  36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 44, 36, 66, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 49, 44, 36, 84, 114, 97, 110, 115,
  112, 97, 114, 101, 110, 99, 101, 95, 100, 101, 115, 95, 99, 111, 117, 108,
  101, 117, 114, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 84, 121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100, 117, 61,
  61, 55, 125, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93,
  32, 36, 88, 95, 111, 114, 105, 103, 105, 110, 101, 44, 36, 89, 95, 111,
  114, 105, 103, 105, 110, 101, 44, 36, 82, 97, 121, 111, 110, 95, 99, 101,
  114, 99, 108, 101, 115, 44, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114,
  99, 108, 101, 115, 44, 48, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 49, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 49, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 49, 44,
  36, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 95, 100, 101,
  115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 10, 45, 108, 105, 110, 101,
  91, 45, 49, 93, 32, 36, 88, 44, 36, 89, 44, 36, 88, 95, 111, 114,
  105, 103, 105, 110, 101, 44, 36, 89, 95, 111, 114, 105, 103, 105, 110, 101,
  44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 44,
  36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 44, 36, 66, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 50, 44, 36, 84, 114, 97, 110, 115,
  112, 97, 114, 101, 110, 99, 101, 95, 100, 101, 115, 95, 99, 111, 117, 108,
  101, 117, 114, 115, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36,
  88, 95, 98, 111, 117, 99, 108, 101, 95, 49, 44, 36, 89, 95, 98, 111,
  117, 99, 108, 101, 95, 49, 44, 36, 88, 95, 111, 114, 105, 103, 105, 110,
  101, 44, 36, 89, 95, 111, 114, 105, 103, 105, 110, 101, 44, 49, 44, 36,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 50, 44, 36, 86, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 50, 44, 36, 66, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 50, 44, 36, 84, 114, 97, 110, 115, 112, 97, 114, 101,
  110, 99, 101, 95, 100, 101, 115, 95, 99, 111, 117, 108, 101, 117, 114, 115,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  114, 111, 116, 97, 116, 101, 91, 45, 49, 93, 32, 36, 82, 111, 116, 97,
  116, 105, 111, 110, 10, 45, 105, 102, 32, 123, 36, 86, 97, 108, 101, 117,
  114, 95, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 62, 49, 125,
  10, 45, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 91, 45, 49,
  93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 100, 105, 108, 97, 116, 101,
  95, 99, 105, 114, 99, 10, 45, 101, 110, 100, 105, 102, 10, 45, 98, 108,
  117, 114, 91, 45, 49, 93, 32, 36, 102, 108, 111, 117, 95, 99, 111, 117,
  114, 98, 101, 95, 102, 101, 114, 109, 101, 101, 115, 95, 86, 49, 10, 45,
  115, 112, 114, 101, 97, 100, 91, 45, 49, 93, 32, 36, 115, 112, 114, 101,
  97, 100, 95, 99, 111, 117, 114, 98, 101, 95, 102, 101, 114, 109, 101, 101,
  115, 95, 86, 49, 10, 45, 100, 101, 102, 111, 114, 109, 91, 45, 49, 93,
  32, 36, 100, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 95, 99, 111,
  117, 114, 98, 101, 95, 102, 101, 114, 109, 101, 101, 115, 95, 86, 49, 10,
  45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45,
  50, 93, 32, 36, 98, 108, 101, 110, 100, 44, 36, 111, 112, 97, 99, 105,
  116, 101, 44, 36, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114,
  115, 10, 115, 97, 109, 106, 95, 99, 111, 117, 114, 98, 101, 115, 95, 102,
  101, 114, 109, 101, 101, 115, 95, 86, 49, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 99,
  111, 117, 114, 98, 101, 115, 95, 102, 101, 114, 109, 101, 101, 115, 95, 86,
  49, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35,
  64, 103, 105, 109, 112, 32, 68, 101, 115, 115, 105, 110, 101, 114, 32, 117,
  110, 101, 32, 101, 116, 111, 105, 108, 101, 32, 45, 32, 100, 114, 97, 119,
  32, 97, 32, 115, 116, 97, 114, 32, 58, 32, 115, 97, 109, 106, 95, 100,
  101, 115, 115, 105, 110, 101, 114, 95, 117, 110, 101, 95, 101, 116, 111, 105,
  108, 101, 44, 32, 115, 97, 109, 106, 95, 100, 101, 115, 115, 105, 110, 101,
  114, 95, 117, 110, 101, 95, 101, 116, 111, 105, 108, 101, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  92, 51, 48, 51, 92, 50, 53, 49, 116, 111, 105, 108, 101, 115, 32, 47,
  32, 115, 116, 97, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 109, 98, 114, 101,
  32, 100, 101, 32, 115, 111, 109, 109, 101, 116, 115, 32, 61, 32, 105, 110,
  116, 40, 53, 44, 50, 44, 55, 50, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 80, 111, 115, 105, 116, 105, 111, 110, 32, 120, 32, 40,
  37, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 111,
  115, 105, 116, 105, 111, 110, 32, 121, 32, 40, 37, 41, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 105, 110,
  99, 108, 105, 110, 97, 105, 115, 111, 110, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 82, 97, 121, 111, 110, 32, 99, 101, 114, 99, 108, 101,
  32, 101, 120, 116, 92, 51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117,
  114, 32, 47, 32, 111, 117, 116, 101, 114, 32, 99, 105, 114, 99, 108, 101,
  32, 114, 97, 100, 105, 117, 115, 32, 61, 32, 105, 110, 116, 40, 49, 53,
  48, 44, 49, 54, 44, 50, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 82, 97, 121, 111, 110, 32, 99, 101, 114, 99, 108, 101,
  32, 105, 110, 116, 92, 51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117,
  114, 32, 47, 32, 105, 110, 110, 101, 114, 32, 99, 105, 114, 99, 108, 101,
  32, 114, 97, 100, 105, 117, 115, 32, 40, 37, 41, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 51, 57, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 69, 120, 99, 101, 110, 116, 114, 105, 99,
  105, 116, 92, 51, 48, 51, 92, 50, 53, 49, 32, 47, 32, 101, 99, 99,
  101, 110, 116, 114, 105, 99, 105, 116, 121, 32, 40, 37, 41, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 101, 120,
  99, 101, 110, 116, 114, 105, 99, 105, 116, 92, 51, 48, 51, 92, 50, 53,
  49, 32, 47, 32, 101, 99, 99, 101, 110, 116, 114, 105, 99, 105, 116, 121,
  32, 97, 110, 103, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 82, 101, 109, 112, 108, 105, 114, 32, 112, 111, 105, 110, 116, 101, 115,
  32, 47, 32, 102, 105, 108, 108, 32, 61, 32, 98, 111, 111, 108, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101,
  117, 114, 32, 112, 111, 105, 110, 116, 101, 115, 32, 61, 32, 99, 111, 108,
  111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116, 111, 117, 114, 32, 112,
  111, 105, 110, 116, 101, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101, 117,
  114, 32, 99, 111, 110, 116, 111, 117, 114, 32, 112, 111, 105, 110, 116, 101,
  115, 32, 61, 32, 99, 111, 108, 111, 114, 40, 48, 44, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 114, 105,
  97, 116, 105, 111, 110, 32, 100, 101, 32, 99, 111, 117, 108, 101, 117, 114,
  32, 47, 32, 99, 111, 108, 111, 114, 32, 118, 97, 114, 105, 97, 116, 105,
  111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 80, 97, 115,
  32, 100, 101, 32, 118, 97, 114, 105, 97, 116, 105, 111, 110, 32, 47, 32,
  78, 111, 32, 99, 104, 97, 110, 103, 101, 34, 44, 34, 67, 111, 117, 108,
  101, 117, 114, 115, 32, 97, 108, 101, 97, 116, 111, 105, 114, 101, 115, 32,
  47, 32, 82, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111, 114, 115, 34,
  44, 34, 70, 97, 105, 98, 108, 101, 109, 101, 110, 116, 32, 110, 117, 97,
  110, 99, 101, 101, 32, 47, 32, 80, 111, 111, 114, 108, 121, 32, 110, 117,
  97, 110, 99, 101, 100, 34, 44, 34, 77, 111, 121, 101, 110, 110, 101, 109,
  101, 110, 116, 32, 110, 117, 97, 110, 99, 101, 101, 32, 47, 32, 77, 111,
  100, 101, 114, 97, 116, 101, 108, 121, 32, 110, 117, 97, 110, 99, 101, 100,
  34, 44, 34, 70, 111, 114, 116, 101, 109, 101, 110, 116, 32, 110, 117, 97,
  110, 99, 101, 101, 32, 47, 32, 72, 105, 103, 104, 108, 121, 32, 110, 117,
  97, 110, 99, 101, 100, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 99, 101, 114, 99, 108, 101, 115, 32,
  47, 32, 99, 105, 114, 99, 108, 101, 115, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 109,
  112, 108, 105, 114, 32, 99, 101, 114, 99, 108, 101, 32, 105, 110, 116, 92,
  51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32, 47, 32, 102,
  105, 108, 108, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 99,
  101, 114, 99, 108, 101, 32, 105, 110, 116, 92, 51, 48, 51, 92, 50, 53,
  49, 114, 105, 101, 117, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50,
  53, 53, 44, 50, 53, 53, 44, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 111, 110, 116, 111, 117, 114, 32, 99, 101, 114, 99, 108,
  101, 32, 105, 110, 116, 92, 51, 48, 51, 92, 50, 53, 49, 114, 105, 101,
  117, 114, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 99, 111,
  110, 116, 111, 117, 114, 32, 99, 101, 114, 99, 108, 101, 32, 105, 110, 116,
  92, 51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32, 61, 32,
  99, 111, 108, 111, 114, 40, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 109, 112, 108, 105, 114, 32,
  99, 101, 114, 99, 108, 101, 32, 101, 120, 116, 92, 51, 48, 51, 92, 50,
  53, 49, 114, 105, 101, 117, 114, 32, 47, 32, 102, 105, 108, 108, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 99, 101, 114, 99, 108, 101,
  32, 101, 120, 116, 92, 51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117,
  114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 110, 116, 111, 117, 114, 32, 99, 101, 114, 99, 108, 101, 32, 101,
  120, 116, 92, 51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32,
  61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 99, 111, 110, 116, 111,
  117, 114, 32, 99, 101, 114, 99, 108, 101, 32, 101, 120, 116, 92, 51, 48,
  51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32, 61, 32, 99, 111, 108,
  111, 114, 40, 48, 44, 48, 44, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 84, 114, 97, 110, 115, 112,
  97, 114, 101, 110, 99, 101, 32, 47, 32, 84, 114, 97, 110, 115, 112, 97,
  114, 101, 110, 99, 121, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 105, 108, 97, 116, 97, 116,
  105, 111, 110, 32, 40, 92, 51, 48, 51, 92, 50, 53, 49, 112, 97, 105,
  115, 115, 101, 117, 114, 41, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49,
  44, 52, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 114,
  97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 32, 100, 101, 115, 32, 99,
  111, 117, 108, 101, 117, 114, 115, 32, 47, 32, 99, 111, 108, 111, 114, 32,
  116, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 121, 32, 61, 32, 105,
  110, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 68, 105,
  118, 101, 114, 115, 32, 47, 32, 70, 111, 111, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 108,
  111, 117, 32, 47, 32, 98, 108, 117, 114, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 112, 114, 101, 97, 100, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 68, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 50, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 66,
  108, 101, 110, 100, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 100, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 65, 100, 100, 34, 44, 34, 65, 108, 112,
  104, 97, 34, 44, 34, 65, 110, 100, 34, 44, 34, 65, 118, 101, 114, 97,
  103, 101, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 66, 117, 114, 110,
  34, 44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 68, 105, 102, 102,
  101, 114, 101, 110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 34, 68, 105, 118, 105, 100, 101, 34, 44, 34, 68, 111, 100, 103,
  101, 34, 44, 34, 69, 120, 99, 108, 117, 115, 105, 111, 110, 34, 44, 34,
  70, 114, 101, 101, 122, 101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 101,
  120, 116, 114, 97, 99, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 109,
  101, 114, 103, 101, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 72,
  97, 114, 100, 32, 108, 105, 103, 104, 116, 34, 44, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44,
  34, 72, 117, 101, 34, 44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97,
  116, 105, 111, 110, 34, 44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44,
  34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110,
  101, 97, 114, 32, 98, 117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97,
  114, 32, 108, 105, 103, 104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34,
  77, 117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 78, 101, 103, 97, 116,
  105, 111, 110, 34, 44, 34, 79, 114, 34, 44, 34, 79, 118, 101, 114, 108,
  97, 121, 34, 44, 34, 80, 105, 110, 32, 108, 105, 103, 104, 116, 34, 44,
  34, 82, 101, 100, 34, 44, 34, 82, 101, 102, 108, 101, 99, 116, 34, 44,
  34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 34, 83, 104, 97, 112, 101, 32, 65, 118,
  101, 114, 97, 103, 101, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118,
  101, 114, 97, 103, 101, 48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117,
  114, 110, 34, 44, 34, 83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34,
  44, 34, 83, 111, 102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83,
  99, 114, 101, 101, 110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34,
  83, 117, 98, 116, 114, 97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101,
  34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 86, 105, 118,
  105, 100, 32, 108, 105, 103, 104, 116, 34, 44, 34, 88, 111, 114, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116,
  121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116,
  32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 83, 97, 109, 106, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52,
  47, 48, 49, 47, 49, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 100, 101, 115, 115, 105,
  110, 101, 114, 95, 117, 110, 101, 95, 101, 116, 111, 105, 108, 101, 58, 10,
  80, 111, 115, 105, 116, 105, 111, 110, 95, 88, 61, 123, 123, 36, 50, 47,
  49, 48, 48, 42, 123, 119, 43, 36, 53, 125, 125, 45, 36, 53, 125, 10,
  80, 111, 115, 105, 116, 105, 111, 110, 95, 89, 61, 123, 123, 36, 51, 47,
  49, 48, 48, 42, 123, 104, 43, 36, 53, 125, 125, 45, 36, 53, 125, 10,
  86, 97, 108, 101, 117, 114, 95, 100, 105, 108, 97, 116, 101, 95, 99, 105,
  114, 99, 61, 36, 51, 52, 10, 70, 108, 111, 117, 95, 101, 116, 111, 105,
  108, 101, 61, 36, 51, 54, 10, 83, 112, 114, 101, 97, 100, 95, 101, 116,
  111, 105, 108, 101, 61, 36, 51, 55, 10, 68, 101, 102, 111, 114, 109, 95,
  101, 116, 111, 105, 108, 101, 61, 36, 51, 56, 10, 98, 108, 101, 110, 100,
  61, 36, 51, 57, 10, 111, 112, 97, 99, 105, 116, 101, 61, 36, 52, 48,
  10, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 61, 36,
  52, 49, 10, 35, 32, 86, 97, 114, 105, 97, 98, 108, 101, 115, 32, 102,
  111, 110, 99, 116, 105, 111, 110, 32, 45, 115, 116, 97, 114, 95, 112, 97,
  116, 116, 101, 114, 110, 95, 115, 97, 109, 106, 10, 76, 97, 114, 103, 101,
  117, 114, 95, 101, 110, 95, 112, 105, 120, 101, 108, 115, 61, 36, 53, 10,
  78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 115, 111, 109, 109, 101, 116,
  115, 61, 36, 49, 10, 80, 111, 117, 114, 99, 101, 110, 116, 97, 103, 101,
  95, 82, 97, 121, 111, 110, 95, 73, 110, 116, 101, 114, 105, 101, 117, 114,
  61, 36, 54, 10, 65, 110, 103, 108, 101, 95, 105, 110, 99, 108, 105, 110,
  97, 105, 115, 111, 110, 61, 36, 52, 10, 80, 111, 117, 114, 99, 101, 110,
  116, 97, 103, 101, 95, 101, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116,
  101, 61, 36, 55, 10, 65, 110, 103, 108, 101, 95, 101, 120, 99, 101, 110,
  116, 114, 105, 99, 105, 116, 101, 61, 36, 56, 10, 82, 101, 109, 112, 108,
  105, 114, 95, 112, 111, 105, 110, 116, 101, 115, 61, 36, 57, 10, 82, 95,
  112, 111, 105, 110, 116, 101, 115, 95, 112, 108, 101, 105, 110, 61, 36, 49,
  48, 10, 86, 95, 112, 111, 105, 110, 116, 101, 115, 95, 112, 108, 101, 105,
  110, 61, 36, 49, 49, 10, 66, 95, 112, 111, 105, 110, 116, 101, 115, 95,
  112, 108, 101, 105, 110, 61, 36, 49, 50, 10, 65, 95, 112, 111, 105, 110,
  116, 101, 115, 95, 112, 108, 101, 105, 110, 61, 36, 51, 53, 10, 67, 111,
  110, 116, 111, 117, 114, 95, 112, 111, 105, 110, 116, 101, 115, 61, 36, 49,
  51, 10, 82, 95, 112, 111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116,
  111, 117, 114, 61, 36, 49, 52, 10, 86, 95, 112, 111, 105, 110, 116, 101,
  115, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 49, 53, 10, 66, 95,
  112, 111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116, 111, 117, 114, 61,
  36, 49, 54, 10, 65, 95, 112, 111, 105, 110, 116, 101, 115, 95, 99, 111,
  110, 116, 111, 117, 114, 61, 36, 51, 53, 10, 82, 101, 109, 112, 108, 105,
  114, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101,
  117, 114, 61, 36, 49, 56, 10, 82, 95, 67, 73, 95, 112, 108, 101, 105,
  110, 61, 36, 49, 57, 10, 86, 95, 67, 73, 95, 112, 108, 101, 105, 110,
  61, 36, 50, 48, 10, 66, 95, 67, 73, 95, 112, 108, 101, 105, 110, 61,
  36, 50, 49, 10, 65, 95, 67, 73, 95, 112, 108, 101, 105, 110, 61, 36,
  51, 53, 10, 67, 111, 110, 116, 111, 117, 114, 95, 99, 101, 114, 99, 108,
  101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 36, 50, 50, 10,
  82, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 50, 51,
  10, 86, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 50,
  52, 10, 66, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36,
  50, 53, 10, 65, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 61,
  36, 51, 53, 10, 82, 101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99,
  108, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 61, 36, 50, 54,
  10, 82, 95, 67, 69, 95, 112, 108, 101, 105, 110, 61, 36, 50, 55, 10,
  86, 95, 67, 69, 95, 112, 108, 101, 105, 110, 61, 36, 50, 56, 10, 66,
  95, 67, 69, 95, 112, 108, 101, 105, 110, 61, 36, 50, 57, 10, 65, 95,
  67, 69, 95, 112, 108, 101, 105, 110, 61, 36, 51, 53, 10, 67, 111, 110,
  116, 111, 117, 114, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101,
  114, 105, 101, 117, 114, 61, 36, 51, 48, 10, 82, 95, 67, 69, 95, 99,
  111, 110, 116, 111, 117, 114, 61, 36, 51, 49, 10, 86, 95, 67, 69, 95,
  99, 111, 110, 116, 111, 117, 114, 61, 36, 51, 50, 10, 66, 95, 67, 69,
  95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 51, 51, 10, 65, 95, 67,
  69, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 51, 53, 10, 86, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101,
  117, 114, 61, 36, 49, 55, 10, 45, 116, 111, 95, 114, 103, 98, 97, 10,
  123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 52, 10, 45, 115, 116, 97,
  114, 95, 112, 97, 116, 116, 101, 114, 110, 95, 115, 97, 109, 106, 32, 36,
  76, 97, 114, 103, 101, 117, 114, 95, 101, 110, 95, 112, 105, 120, 101, 108,
  115, 44, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 115, 111, 109,
  109, 101, 116, 115, 44, 36, 80, 111, 117, 114, 99, 101, 110, 116, 97, 103,
  101, 95, 82, 97, 121, 111, 110, 95, 73, 110, 116, 101, 114, 105, 101, 117,
  114, 44, 36, 65, 110, 103, 108, 101, 95, 105, 110, 99, 108, 105, 110, 97,
  105, 115, 111, 110, 44, 36, 80, 111, 117, 114, 99, 101, 110, 116, 97, 103,
  101, 95, 101, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116, 101, 44, 36,
  65, 110, 103, 108, 101, 95, 101, 120, 99, 101, 110, 116, 114, 105, 99, 105,
  116, 101, 44, 36, 82, 101, 109, 112, 108, 105, 114, 95, 112, 111, 105, 110,
  116, 101, 115, 44, 36, 82, 95, 112, 111, 105, 110, 116, 101, 115, 95, 112,
  108, 101, 105, 110, 44, 36, 86, 95, 112, 111, 105, 110, 116, 101, 115, 95,
  112, 108, 101, 105, 110, 44, 36, 66, 95, 112, 111, 105, 110, 116, 101, 115,
  95, 112, 108, 101, 105, 110, 44, 36, 65, 95, 112, 111, 105, 110, 116, 101,
  115, 95, 112, 108, 101, 105, 110, 44, 36, 67, 111, 110, 116, 111, 117, 114,
  95, 112, 111, 105, 110, 116, 101, 115, 44, 36, 82, 95, 112, 111, 105, 110,
  116, 101, 115, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 86, 95, 112,
  111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36,
  66, 95, 112, 111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116, 111, 117,
  114, 44, 36, 65, 95, 112, 111, 105, 110, 116, 101, 115, 95, 99, 111, 110,
  116, 111, 117, 114, 44, 36, 82, 101, 109, 112, 108, 105, 114, 95, 99, 101,
  114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 36,
  82, 95, 67, 73, 95, 112, 108, 101, 105, 110, 44, 36, 86, 95, 67, 73,
  95, 112, 108, 101, 105, 110, 44, 36, 66, 95, 67, 73, 95, 112, 108, 101,
  105, 110, 44, 36, 65, 95, 67, 73, 95, 112, 108, 101, 105, 110, 44, 36,
  67, 111, 110, 116, 111, 117, 114, 95, 99, 101, 114, 99, 108, 101, 95, 105,
  110, 116, 101, 114, 105, 101, 117, 114, 44, 36, 82, 95, 67, 73, 95, 99,
  111, 110, 116, 111, 117, 114, 44, 36, 86, 95, 67, 73, 95, 99, 111, 110,
  116, 111, 117, 114, 44, 36, 66, 95, 67, 73, 95, 99, 111, 110, 116, 111,
  117, 114, 44, 36, 65, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114,
  44, 36, 82, 101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108, 101,
  95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 44, 36, 82, 95, 67, 69,
  95, 112, 108, 101, 105, 110, 44, 36, 86, 95, 67, 69, 95, 112, 108, 101,
  105, 110, 44, 36, 66, 95, 67, 69, 95, 112, 108, 101, 105, 110, 44, 36,
  65, 95, 67, 69, 95, 112, 108, 101, 105, 110, 44, 36, 67, 111, 110, 116,
  111, 117, 114, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114,
  105, 101, 117, 114, 44, 36, 82, 95, 67, 69, 95, 99, 111, 110, 116, 111,
  117, 114, 44, 36, 86, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114,
  44, 36, 66, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36,
  65, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 86, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101,
  117, 114, 10, 45, 105, 109, 97, 103, 101, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 44, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 88, 44, 36,
  80, 111, 115, 105, 116, 105, 111, 110, 95, 89, 10, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 105, 102, 32, 123, 36, 86, 97, 108, 101, 117, 114, 95,
  100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 62, 49, 125, 10, 45,
  100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 91, 45, 49, 93, 32,
  36, 86, 97, 108, 101, 117, 114, 95, 100, 105, 108, 97, 116, 101, 95, 99,
  105, 114, 99, 10, 45, 101, 110, 100, 105, 102, 10, 45, 98, 108, 117, 114,
  91, 45, 49, 93, 32, 36, 70, 108, 111, 117, 95, 101, 116, 111, 105, 108,
  101, 10, 45, 115, 112, 114, 101, 97, 100, 91, 45, 49, 93, 32, 36, 83,
  112, 114, 101, 97, 100, 95, 101, 116, 111, 105, 108, 101, 10, 45, 100, 101,
  102, 111, 114, 109, 91, 45, 49, 93, 32, 36, 68, 101, 102, 111, 114, 109,
  95, 101, 116, 111, 105, 108, 101, 10, 45, 103, 105, 109, 112, 95, 98, 108,
  101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 36, 98, 108, 101, 110,
  100, 44, 36, 111, 112, 97, 99, 105, 116, 101, 44, 36, 82, 101, 118, 101,
  114, 116, 95, 108, 97, 121, 101, 114, 115, 10, 35, 64, 103, 105, 109, 112,
  32, 68, 101, 115, 115, 105, 110, 101, 114, 32, 117, 110, 101, 32, 102, 108,
  101, 117, 114, 32, 45, 32, 100, 114, 97, 119, 32, 97, 32, 102, 108, 111,
  119, 101, 114, 32, 58, 32, 115, 97, 109, 106, 95, 100, 101, 115, 115, 105,
  110, 101, 114, 95, 117, 110, 101, 95, 102, 108, 101, 117, 114, 44, 32, 115,
  97, 109, 106, 95, 100, 101, 115, 115, 105, 110, 101, 114, 95, 117, 110, 101,
  95, 102, 108, 101, 117, 114, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 70, 108, 101, 117, 114, 32,
  45, 32, 80, 92, 51, 48, 51, 92, 50, 53, 49, 116, 97, 108, 101, 115,
  32, 47, 32, 70, 108, 111, 119, 101, 114, 32, 45, 32, 80, 101, 116, 97,
  108, 115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 109, 98, 114, 101, 32, 100, 101, 32,
  112, 92, 51, 48, 51, 92, 50, 53, 49, 116, 97, 108, 101, 115, 32, 47,
  32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 112, 101, 116, 97, 108,
  115, 32, 61, 32, 105, 110, 116, 40, 51, 48, 44, 50, 44, 51, 54, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 111, 115, 105, 116,
  105, 111, 110, 32, 120, 32, 40, 37, 41, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 80, 111, 115, 105, 116, 105, 111, 110, 32, 121, 32,
  40, 37, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  110, 103, 108, 101, 32, 105, 110, 99, 108, 105, 110, 97, 105, 115, 111, 110,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 56, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 39, 114, 97, 121, 111,
  110, 39, 32, 100, 101, 32, 108, 97, 32, 102, 108, 101, 117, 114, 32, 47,
  32, 102, 108, 111, 119, 101, 114, 32, 39, 114, 97, 100, 105, 117, 115, 39,
  32, 61, 32, 105, 110, 116, 40, 52, 48, 48, 44, 49, 54, 44, 50, 48,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 121,
  111, 110, 32, 99, 101, 114, 99, 108, 101, 32, 49, 32, 47, 32, 114, 97,
  100, 105, 117, 115, 32, 99, 105, 114, 99, 108, 101, 32, 49, 32, 40, 37,
  41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 121,
  111, 110, 32, 99, 101, 114, 99, 108, 101, 32, 50, 32, 47, 32, 114, 97,
  100, 105, 117, 115, 32, 99, 105, 114, 99, 108, 101, 32, 50, 32, 40, 37,
  41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 54, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 111, 110,
  103, 117, 101, 117, 114, 32, 112, 92, 51, 48, 51, 92, 50, 53, 49, 116,
  97, 108, 101, 115, 32, 47, 32, 108, 101, 110, 103, 116, 104, 32, 112, 101,
  116, 97, 108, 115, 32, 40, 37, 41, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 76, 97, 114, 103, 101, 117, 114, 32, 112, 92, 51, 48,
  51, 92, 50, 53, 49, 116, 97, 108, 101, 115, 32, 47, 32, 119, 105, 100,
  116, 104, 32, 112, 101, 116, 97, 108, 115, 32, 40, 37, 41, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 115, 112, 97, 99, 101, 109,
  101, 110, 116, 32, 100, 117, 32, 99, 101, 110, 116, 114, 101, 32, 47, 32,
  99, 101, 110, 116, 101, 114, 32, 115, 112, 97, 99, 105, 110, 103, 32, 40,
  37, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 48, 44, 49, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97,
  114, 105, 97, 116, 105, 111, 110, 32, 108, 111, 110, 103, 117, 101, 117, 114,
  32, 47, 32, 108, 101, 110, 103, 116, 104, 32, 118, 97, 114, 105, 97, 116,
  105, 111, 110, 32, 40, 37, 41, 32, 61, 32, 105, 110, 116, 40, 48, 44,
  48, 44, 49, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86,
  97, 114, 105, 97, 116, 105, 111, 110, 32, 92, 51, 48, 51, 92, 50, 53,
  49, 112, 97, 105, 115, 115, 101, 117, 114, 32, 47, 32, 116, 104, 105, 99,
  107, 110, 101, 115, 115, 32, 118, 97, 114, 105, 97, 116, 105, 111, 110, 32,
  40, 37, 41, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 114, 105,
  97, 116, 105, 111, 110, 32, 97, 110, 103, 108, 101, 32, 40, 100, 101, 103,
  46, 41, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 109, 112, 108, 105, 114,
  32, 112, 92, 51, 48, 51, 92, 50, 53, 49, 116, 97, 108, 101, 115, 32,
  47, 32, 102, 105, 108, 108, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101, 117,
  114, 32, 112, 92, 51, 48, 51, 92, 50, 53, 49, 116, 97, 108, 101, 115,
  32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53,
  44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 114,
  105, 97, 116, 105, 111, 110, 32, 100, 101, 32, 99, 111, 117, 108, 101, 117,
  114, 32, 47, 32, 99, 111, 108, 111, 114, 32, 118, 97, 114, 105, 97, 116,
  105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 80, 97,
  115, 32, 100, 101, 32, 118, 97, 114, 105, 97, 116, 105, 111, 110, 32, 47,
  32, 78, 111, 32, 99, 104, 97, 110, 103, 101, 34, 44, 34, 67, 111, 117,
  108, 101, 117, 114, 115, 32, 97, 108, 101, 97, 116, 111, 105, 114, 101, 115,
  32, 47, 32, 82, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111, 114, 115,
  34, 44, 34, 70, 97, 105, 98, 108, 101, 109, 101, 110, 116, 32, 110, 117,
  97, 110, 99, 101, 101, 32, 47, 32, 80, 111, 111, 114, 108, 121, 32, 110,
  117, 97, 110, 99, 101, 100, 34, 44, 34, 77, 111, 121, 101, 110, 110, 101,
  109, 101, 110, 116, 32, 110, 117, 97, 110, 99, 101, 101, 32, 47, 32, 77,
  111, 100, 101, 114, 97, 116, 101, 108, 121, 32, 110, 117, 97, 110, 99, 101,
  100, 34, 44, 34, 70, 111, 114, 116, 101, 109, 101, 110, 116, 32, 110, 117,
  97, 110, 99, 101, 101, 32, 47, 32, 72, 105, 103, 104, 108, 121, 32, 110,
  117, 97, 110, 99, 101, 100, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 111, 110, 116, 111, 117, 114, 32, 112, 92, 51, 48, 51, 92,
  50, 53, 49, 116, 97, 108, 101, 115, 32, 61, 32, 98, 111, 111, 108, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108,
  101, 117, 114, 32, 99, 111, 110, 116, 111, 117, 114, 32, 112, 92, 51, 48,
  51, 92, 50, 53, 49, 116, 97, 108, 101, 115, 32, 61, 32, 99, 111, 108,
  111, 114, 40, 50, 48, 48, 44, 49, 48, 48, 44, 53, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 99,
  101, 114, 99, 108, 101, 115, 32, 47, 32, 99, 105, 114, 99, 108, 101, 115,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 82, 101, 109, 112, 108, 105, 114, 32, 99, 101, 114, 99,
  108, 101, 32, 105, 110, 116, 92, 51, 48, 51, 92, 50, 53, 49, 114, 105,
  101, 117, 114, 32, 47, 32, 102, 105, 108, 108, 32, 61, 32, 98, 111, 111,
  108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111,
  117, 108, 101, 117, 114, 32, 99, 101, 114, 99, 108, 101, 32, 105, 110, 116,
  92, 51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32, 61, 32,
  99, 111, 108, 111, 114, 40, 49, 48, 48, 44, 49, 48, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116,
  111, 117, 114, 32, 99, 101, 114, 99, 108, 101, 32, 105, 110, 116, 92, 51,
  48, 51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32, 61, 32, 98, 111,
  111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  111, 117, 108, 101, 117, 114, 32, 99, 111, 110, 116, 111, 117, 114, 32, 99,
  101, 114, 99, 108, 101, 32, 105, 110, 116, 92, 51, 48, 51, 92, 50, 53,
  49, 114, 105, 101, 117, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50,
  53, 53, 44, 50, 53, 53, 44, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 82, 101, 109, 112, 108, 105, 114, 32, 99, 101, 114, 99, 108,
  101, 32, 101, 120, 116, 92, 51, 48, 51, 92, 50, 53, 49, 114, 105, 101,
  117, 114, 32, 47, 32, 102, 105, 108, 108, 32, 61, 32, 98, 111, 111, 108,
  40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117,
  108, 101, 117, 114, 32, 99, 101, 114, 99, 108, 101, 32, 101, 120, 116, 92,
  51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32, 61, 32, 99,
  111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116, 111,
  117, 114, 32, 99, 101, 114, 99, 108, 101, 32, 101, 120, 116, 92, 51, 48,
  51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32, 61, 32, 98, 111, 111,
  108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111,
  117, 108, 101, 117, 114, 32, 99, 111, 110, 116, 111, 117, 114, 32, 99, 101,
  114, 99, 108, 101, 32, 101, 120, 116, 92, 51, 48, 51, 92, 50, 53, 49,
  114, 105, 101, 117, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 49, 48,
  48, 44, 49, 48, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 68, 105, 108, 97, 116, 97, 116, 105, 111, 110, 32, 40,
  92, 51, 48, 51, 92, 50, 53, 49, 112, 97, 105, 115, 115, 101, 117, 114,
  41, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49, 44, 52, 56, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 32, 47, 32, 84,
  114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 121, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84,
  114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 32, 100, 101, 115, 32,
  99, 111, 117, 108, 101, 117, 114, 115, 32, 47, 32, 99, 111, 108, 111, 114,
  32, 116, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 121, 32, 61, 32,
  105, 110, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 68,
  105, 118, 101, 114, 115, 32, 47, 32, 70, 111, 111, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70,
  108, 111, 117, 32, 47, 32, 98, 108, 117, 114, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 112, 114, 101, 97, 100, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 68, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 50, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  66, 108, 101, 110, 100, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 100, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 65, 100, 100, 34, 44, 34,
  65, 108, 112, 104, 97, 34, 44, 34, 65, 110, 100, 34, 44, 34, 65, 118,
  101, 114, 97, 103, 101, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 66,
  117, 114, 110, 34, 44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 68,
  105, 102, 102, 101, 114, 101, 110, 99, 101, 34, 44, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 34, 68, 105, 118, 105, 100, 101, 34, 44, 34, 68,
  111, 100, 103, 101, 34, 44, 34, 69, 120, 99, 108, 117, 115, 105, 111, 110,
  34, 44, 34, 70, 114, 101, 101, 122, 101, 34, 44, 34, 71, 114, 97, 105,
  110, 32, 101, 120, 116, 114, 97, 99, 116, 34, 44, 34, 71, 114, 97, 105,
  110, 32, 109, 101, 114, 103, 101, 34, 44, 34, 71, 114, 101, 101, 110, 34,
  44, 34, 72, 97, 114, 100, 32, 108, 105, 103, 104, 116, 34, 44, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 34, 72, 97, 114, 100, 32, 109, 105,
  120, 34, 44, 34, 72, 117, 101, 34, 44, 34, 73, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 105, 111, 110, 34, 44, 34, 76, 105, 103, 104, 116, 101,
  110, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34,
  76, 105, 110, 101, 97, 114, 32, 98, 117, 114, 110, 34, 44, 34, 76, 105,
  110, 101, 97, 114, 32, 108, 105, 103, 104, 116, 34, 44, 34, 76, 117, 109,
  105, 110, 97, 110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 34, 77, 117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 78, 101,
  103, 97, 116, 105, 111, 110, 34, 44, 34, 79, 114, 34, 44, 34, 79, 118,
  101, 114, 108, 97, 121, 34, 44, 34, 80, 105, 110, 32, 108, 105, 103, 104,
  116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 82, 101, 102, 108, 101, 99,
  116, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 83, 104, 97, 112, 101,
  32, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 83, 104, 97, 112, 101,
  32, 65, 118, 101, 114, 97, 103, 101, 48, 34, 44, 34, 83, 111, 102, 116,
  32, 98, 117, 114, 110, 34, 44, 34, 83, 111, 102, 116, 32, 100, 111, 100,
  103, 101, 34, 44, 34, 83, 111, 102, 116, 32, 108, 105, 103, 104, 116, 34,
  44, 34, 83, 99, 114, 101, 101, 110, 34, 44, 34, 83, 116, 97, 109, 112,
  34, 44, 34, 83, 117, 98, 116, 114, 97, 99, 116, 34, 44, 34, 86, 97,
  108, 117, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34,
  86, 105, 118, 105, 100, 32, 108, 105, 103, 104, 116, 34, 44, 34, 88, 111,
  114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97,
  99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118,
  101, 114, 116, 32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111,
  108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 83, 97, 109,
  106, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50,
  48, 49, 52, 47, 48, 49, 47, 49, 55, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 100, 101,
  115, 115, 105, 110, 101, 114, 95, 117, 110, 101, 95, 102, 108, 101, 117, 114,
  58, 10, 35, 35, 32, 118, 97, 114, 105, 97, 98, 108, 101, 115, 10, 88,
  95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 115, 61,
  123, 36, 50, 47, 49, 48, 48, 42, 119, 125, 10, 89, 95, 99, 101, 110,
  116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 115, 61, 123, 36, 51, 47,
  49, 48, 48, 42, 104, 125, 10, 86, 97, 108, 101, 117, 114, 95, 100, 105,
  108, 97, 116, 101, 95, 99, 105, 114, 99, 61, 36, 51, 57, 10, 70, 108,
  111, 117, 95, 102, 108, 101, 117, 114, 61, 36, 52, 49, 10, 83, 112, 114,
  101, 97, 100, 95, 102, 108, 101, 117, 114, 61, 36, 52, 50, 10, 68, 101,
  102, 111, 114, 109, 95, 102, 108, 101, 117, 114, 61, 36, 52, 51, 10, 98,
  108, 101, 110, 100, 61, 36, 52, 52, 10, 111, 112, 97, 99, 105, 116, 101,
  61, 36, 52, 53, 10, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101,
  114, 115, 61, 36, 52, 54, 10, 35, 35, 32, 118, 97, 114, 105, 97, 98,
  108, 101, 115, 32, 102, 111, 110, 99, 116, 105, 111, 110, 32, 45, 102, 108,
  111, 119, 101, 114, 95, 112, 97, 116, 116, 101, 114, 110, 95, 115, 97, 109,
  106, 10, 76, 97, 114, 103, 101, 117, 114, 95, 101, 110, 95, 112, 105, 120,
  101, 108, 115, 61, 123, 50, 42, 36, 53, 125, 10, 78, 111, 109, 98, 114,
  101, 95, 100, 101, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 49, 10,
  65, 110, 103, 108, 101, 95, 105, 110, 99, 108, 105, 110, 97, 105, 115, 111,
  110, 61, 36, 52, 10, 82, 97, 121, 111, 110, 95, 103, 114, 97, 110, 100,
  95, 99, 101, 114, 99, 108, 101, 61, 36, 54, 10, 82, 97, 121, 111, 110,
  95, 112, 101, 116, 105, 116, 95, 99, 101, 114, 99, 108, 101, 61, 36, 55,
  10, 76, 111, 110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101,
  115, 61, 36, 56, 10, 76, 97, 114, 103, 101, 117, 114, 95, 112, 101, 116,
  97, 108, 101, 115, 61, 36, 57, 10, 69, 115, 112, 97, 99, 101, 109, 101,
  110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101, 61, 36, 49, 48,
  10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 108, 111, 110, 103, 117,
  101, 117, 114, 61, 36, 49, 49, 10, 86, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114, 61, 36, 49, 50, 10,
  86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 97, 110, 103, 108, 101, 61,
  36, 49, 51, 10, 82, 101, 109, 112, 108, 105, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 61, 36, 49, 52, 10, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 49, 53, 10, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61,
  36, 49, 54, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 61, 36, 49, 55, 10, 65, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 52, 48, 10,
  67, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61,
  36, 49, 57, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111,
  110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 50,
  48, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116,
  111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 50, 49, 10,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117,
  114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 50, 50, 10, 65, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 61, 36, 52, 48, 10, 82, 101, 109, 112,
  108, 105, 114, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114,
  105, 101, 117, 114, 61, 36, 50, 51, 10, 82, 95, 67, 73, 95, 112, 108,
  101, 105, 110, 61, 36, 50, 52, 10, 86, 95, 67, 73, 95, 112, 108, 101,
  105, 110, 61, 36, 50, 53, 10, 66, 95, 67, 73, 95, 112, 108, 101, 105,
  110, 61, 36, 50, 54, 10, 65, 95, 67, 73, 95, 112, 108, 101, 105, 110,
  61, 36, 52, 48, 10, 67, 111, 110, 116, 111, 117, 114, 95, 99, 101, 114,
  99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 36, 50,
  55, 10, 82, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36,
  50, 56, 10, 86, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 61,
  36, 50, 57, 10, 66, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114,
  61, 36, 51, 48, 10, 65, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117,
  114, 61, 36, 52, 48, 10, 82, 101, 109, 112, 108, 105, 114, 95, 99, 101,
  114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 61, 36,
  51, 49, 10, 82, 95, 67, 69, 95, 112, 108, 101, 105, 110, 61, 36, 51,
  50, 10, 86, 95, 67, 69, 95, 112, 108, 101, 105, 110, 61, 36, 51, 51,
  10, 66, 95, 67, 69, 95, 112, 108, 101, 105, 110, 61, 36, 51, 52, 10,
  65, 95, 67, 69, 95, 112, 108, 101, 105, 110, 61, 36, 52, 48, 10, 67,
  111, 110, 116, 111, 117, 114, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120,
  116, 101, 114, 105, 101, 117, 114, 61, 36, 51, 53, 10, 82, 95, 67, 69,
  95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 51, 54, 10, 86, 95, 67,
  69, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 51, 55, 10, 66, 95,
  67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 51, 56, 10, 65,
  95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 52, 48, 10,
  86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117,
  108, 101, 117, 114, 61, 36, 49, 56, 10, 35, 35, 10, 45, 116, 111, 95,
  114, 103, 98, 97, 91, 45, 49, 93, 10, 123, 119, 125, 44, 123, 104, 125,
  44, 49, 44, 52, 10, 45, 102, 108, 111, 119, 101, 114, 95, 112, 97, 116,
  116, 101, 114, 110, 95, 115, 97, 109, 106, 32, 36, 76, 97, 114, 103, 101,
  117, 114, 95, 101, 110, 95, 112, 105, 120, 101, 108, 115, 44, 36, 78, 111,
  109, 98, 114, 101, 95, 100, 101, 95, 112, 101, 116, 97, 108, 101, 115, 44,
  36, 65, 110, 103, 108, 101, 95, 105, 110, 99, 108, 105, 110, 97, 105, 115,
  111, 110, 44, 36, 82, 97, 121, 111, 110, 95, 103, 114, 97, 110, 100, 95,
  99, 101, 114, 99, 108, 101, 44, 36, 82, 97, 121, 111, 110, 95, 112, 101,
  116, 105, 116, 95, 99, 101, 114, 99, 108, 101, 44, 36, 76, 111, 110, 103,
  117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 76, 97,
  114, 103, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 69,
  115, 112, 97, 99, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101, 110,
  116, 114, 101, 44, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 108,
  111, 110, 103, 117, 101, 117, 114, 44, 36, 86, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114, 44, 36, 86, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 97, 110, 103, 108, 101, 44, 36, 82,
  101, 109, 112, 108, 105, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101,
  115, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116,
  97, 108, 101, 115, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 44, 36, 65, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 67, 111, 110, 116,
  111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101,
  115, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110,
  116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 65, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 44, 36, 82, 101, 109, 112, 108, 105, 114,
  95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117,
  114, 44, 36, 82, 95, 67, 73, 95, 112, 108, 101, 105, 110, 44, 36, 86,
  95, 67, 73, 95, 112, 108, 101, 105, 110, 44, 36, 66, 95, 67, 73, 95,
  112, 108, 101, 105, 110, 44, 36, 65, 95, 67, 73, 95, 112, 108, 101, 105,
  110, 44, 36, 67, 111, 110, 116, 111, 117, 114, 95, 99, 101, 114, 99, 108,
  101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 36, 82, 95, 67,
  73, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 86, 95, 67, 73, 95,
  99, 111, 110, 116, 111, 117, 114, 44, 36, 66, 95, 67, 73, 95, 99, 111,
  110, 116, 111, 117, 114, 44, 36, 65, 95, 67, 73, 95, 99, 111, 110, 116,
  111, 117, 114, 44, 36, 82, 101, 109, 112, 108, 105, 114, 95, 99, 101, 114,
  99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 44, 36, 82,
  95, 67, 69, 95, 112, 108, 101, 105, 110, 44, 36, 86, 95, 67, 69, 95,
  112, 108, 101, 105, 110, 44, 36, 66, 95, 67, 69, 95, 112, 108, 101, 105,
  110, 44, 36, 65, 95, 67, 69, 95, 112, 108, 101, 105, 110, 44, 36, 67,
  111, 110, 116, 111, 117, 114, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120,
  116, 101, 114, 105, 101, 117, 114, 44, 36, 82, 95, 67, 69, 95, 99, 111,
  110, 116, 111, 117, 114, 44, 36, 86, 95, 67, 69, 95, 99, 111, 110, 116,
  111, 117, 114, 44, 36, 66, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117,
  114, 44, 36, 65, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 44,
  36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111,
  117, 108, 101, 117, 114, 10, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91,
  45, 49, 93, 10, 88, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114,
  99, 108, 101, 115, 61, 123, 36, 88, 95, 99, 101, 110, 116, 114, 101, 95,
  99, 101, 114, 99, 108, 101, 115, 45, 123, 119, 47, 50, 125, 125, 10, 89,
  95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 115, 61,
  123, 36, 89, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108,
  101, 115, 45, 123, 104, 47, 50, 125, 125, 10, 45, 105, 109, 97, 103, 101,
  91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 88, 95, 99, 101, 110,
  116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 115, 44, 36, 89, 95, 99,
  101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 115, 10, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 86, 97, 108, 101,
  117, 114, 95, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 62, 49,
  125, 10, 45, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 91, 45,
  49, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 100, 105, 108, 97, 116,
  101, 95, 99, 105, 114, 99, 10, 45, 101, 110, 100, 105, 102, 10, 45, 98,
  108, 117, 114, 91, 45, 49, 93, 32, 36, 70, 108, 111, 117, 95, 102, 108,
  101, 117, 114, 10, 45, 115, 112, 114, 101, 97, 100, 91, 45, 49, 93, 32,
  36, 83, 112, 114, 101, 97, 100, 95, 102, 108, 101, 117, 114, 10, 45, 100,
  101, 102, 111, 114, 109, 91, 45, 49, 93, 32, 36, 68, 101, 102, 111, 114,
  109, 95, 102, 108, 101, 117, 114, 10, 45, 103, 105, 109, 112, 95, 98, 108,
  101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 36, 98, 108, 101, 110,
  100, 44, 36, 111, 112, 97, 99, 105, 116, 101, 44, 36, 82, 101, 118, 101,
  114, 116, 95, 108, 97, 121, 101, 114, 115, 10, 35, 64, 103, 105, 109, 112,
  32, 68, 101, 115, 115, 105, 110, 101, 114, 32, 117, 110, 101, 32, 102, 108,
  101, 117, 114, 32, 50, 32, 45, 32, 100, 114, 97, 119, 32, 97, 32, 102,
  108, 111, 119, 101, 114, 32, 50, 32, 58, 32, 115, 97, 109, 106, 95, 100,
  101, 115, 115, 105, 110, 101, 114, 95, 117, 110, 101, 95, 102, 108, 101, 117,
  114, 95, 50, 44, 32, 115, 97, 109, 106, 95, 100, 101, 115, 115, 105, 110,
  101, 114, 95, 117, 110, 101, 95, 102, 108, 101, 117, 114, 95, 50, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 83, 112, 105, 114, 97, 108, 101, 32, 47, 32, 83, 112, 105, 114,
  97, 108, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 101, 110, 116, 114, 101, 32, 47, 32, 99,
  101, 110, 116, 101, 114, 32, 120, 32, 40, 37, 41, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 101, 110, 116, 114, 101, 32, 47, 32,
  99, 101, 110, 116, 101, 114, 32, 121, 32, 40, 37, 41, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 84, 111, 117, 114, 115, 32, 47, 32,
  116, 117, 114, 110, 115, 32, 61, 32, 105, 110, 116, 40, 49, 48, 44, 49,
  44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 110,
  99, 114, 101, 109, 101, 110, 116, 32, 97, 110, 103, 117, 108, 97, 105, 114,
  101, 32, 47, 32, 97, 110, 103, 117, 108, 97, 114, 32, 105, 110, 99, 114,
  101, 109, 101, 110, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 54,
  46, 48, 56, 44, 49, 44, 51, 53, 57, 46, 57, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 101, 102, 102, 46, 32, 97, 103, 114,
  97, 110, 100, 105, 115, 115, 101, 109, 101, 110, 116, 32, 47, 32, 101, 120,
  112, 97, 110, 115, 105, 111, 110, 32, 99, 111, 101, 102, 102, 105, 99, 105,
  101, 110, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 46, 53, 44,
  49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 110, 115, 32, 100, 101, 32, 114, 111, 116, 97, 116, 105, 111, 110, 32,
  47, 32, 100, 105, 114, 101, 99, 116, 105, 111, 110, 32, 111, 102, 32, 114,
  111, 116, 97, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 48, 44, 34, 73, 110, 116, 46, 32, 77, 111, 100, 101, 32, 49, 34,
  44, 34, 69, 120, 116, 46, 32, 77, 111, 100, 101, 32, 49, 34, 44, 34,
  73, 110, 116, 46, 32, 77, 111, 100, 101, 32, 50, 34, 44, 34, 69, 120,
  116, 46, 32, 77, 111, 100, 101, 32, 50, 34, 44, 34, 73, 110, 116, 46,
  32, 77, 111, 100, 101, 32, 51, 34, 44, 34, 69, 120, 116, 46, 32, 77,
  111, 100, 101, 32, 51, 34, 44, 34, 73, 110, 116, 46, 32, 77, 111, 100,
  101, 32, 52, 34, 44, 34, 69, 120, 116, 46, 32, 77, 111, 100, 101, 32,
  52, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 70, 108, 101, 117, 114, 32, 45, 32, 80, 92, 51, 48,
  51, 92, 50, 53, 49, 116, 97, 108, 101, 115, 32, 47, 32, 70, 108, 111,
  119, 101, 114, 32, 45, 32, 80, 101, 116, 97, 108, 115, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  76, 111, 110, 103, 117, 101, 117, 114, 32, 112, 92, 51, 48, 51, 92, 50,
  53, 49, 116, 97, 108, 101, 115, 32, 47, 32, 108, 101, 110, 103, 116, 104,
  32, 112, 101, 116, 97, 108, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  51, 48, 44, 49, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 76, 97, 114, 103, 101, 117, 114, 32, 112, 92, 51, 48, 51,
  92, 50, 53, 49, 116, 97, 108, 101, 115, 32, 47, 32, 119, 105, 100, 116,
  104, 32, 112, 101, 116, 97, 108, 115, 32, 40, 37, 41, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 53, 48, 44, 49, 44, 49, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 69, 115, 112, 97, 99, 101, 109, 101,
  110, 116, 32, 100, 117, 32, 99, 101, 110, 116, 114, 101, 32, 47, 32, 99,
  101, 110, 116, 101, 114, 32, 115, 112, 97, 99, 105, 110, 103, 32, 61, 32,
  105, 110, 116, 40, 49, 53, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 86, 97, 114, 105, 97, 116, 105, 111, 110,
  32, 108, 111, 110, 103, 117, 101, 117, 114, 32, 47, 32, 108, 101, 110, 103,
  116, 104, 32, 118, 97, 114, 105, 97, 116, 105, 111, 110, 32, 40, 37, 41,
  32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 114, 105, 97, 116, 105,
  111, 110, 32, 92, 51, 48, 51, 92, 50, 53, 49, 112, 97, 105, 115, 115,
  101, 117, 114, 32, 47, 32, 116, 104, 105, 99, 107, 110, 101, 115, 115, 32,
  118, 97, 114, 105, 97, 116, 105, 111, 110, 32, 40, 37, 41, 32, 61, 32,
  105, 110, 116, 40, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 86, 97, 114, 105, 97, 116, 105, 111, 110, 32,
  97, 110, 103, 108, 101, 32, 40, 100, 101, 103, 46, 41, 32, 61, 32, 105,
  110, 116, 40, 48, 44, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 103, 114, 97, 110, 100, 105, 115, 115, 101, 109,
  101, 110, 116, 32, 112, 92, 51, 48, 51, 92, 50, 53, 49, 116, 97, 108,
  101, 115, 32, 47, 32, 101, 120, 112, 97, 110, 115, 105, 111, 110, 32, 112,
  101, 116, 97, 108, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  49, 44, 48, 46, 49, 44, 48, 46, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 82, 101, 109, 112, 108, 105, 114, 32, 112, 92, 51, 48,
  51, 92, 50, 53, 49, 116, 97, 108, 101, 115, 32, 47, 32, 102, 105, 108,
  108, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 112, 92, 51,
  48, 51, 92, 50, 53, 49, 116, 97, 108, 101, 115, 32, 61, 32, 99, 111,
  108, 111, 114, 40, 50, 51, 48, 44, 50, 51, 54, 44, 50, 50, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110,
  116, 111, 117, 114, 32, 112, 92, 51, 48, 51, 92, 50, 53, 49, 116, 97,
  108, 101, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 99,
  111, 110, 116, 111, 117, 114, 32, 112, 92, 51, 48, 51, 92, 50, 53, 49,
  116, 97, 108, 101, 115, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 48,
  48, 44, 49, 48, 48, 44, 53, 48, 44, 50, 53, 53, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 99, 101,
  114, 99, 108, 101, 115, 32, 47, 32, 99, 105, 114, 99, 108, 101, 115, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 82, 101, 109, 112, 108, 105, 114, 32, 99, 101, 114, 99, 108,
  101, 32, 105, 110, 116, 92, 51, 48, 51, 92, 50, 53, 49, 114, 105, 101,
  117, 114, 32, 47, 32, 102, 105, 108, 108, 32, 61, 32, 98, 111, 111, 108,
  40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117,
  108, 101, 117, 114, 32, 99, 101, 114, 99, 108, 101, 32, 105, 110, 116, 92,
  51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32, 61, 32, 99,
  111, 108, 111, 114, 40, 50, 50, 52, 44, 50, 48, 56, 44, 51, 54, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111,
  110, 116, 111, 117, 114, 32, 99, 101, 114, 99, 108, 101, 32, 105, 110, 116,
  92, 51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32, 61, 32,
  98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 111, 117, 108, 101, 117, 114, 32, 99, 111, 110, 116, 111, 117, 114,
  32, 99, 101, 114, 99, 108, 101, 32, 105, 110, 116, 92, 51, 48, 51, 92,
  50, 53, 49, 114, 105, 101, 117, 114, 32, 61, 32, 99, 111, 108, 111, 114,
  40, 50, 48, 48, 44, 49, 48, 48, 44, 53, 48, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 109, 112, 108, 105,
  114, 32, 99, 101, 114, 99, 108, 101, 32, 101, 120, 116, 92, 51, 48, 51,
  92, 50, 53, 49, 114, 105, 101, 117, 114, 32, 47, 32, 102, 105, 108, 108,
  32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 99, 101, 114, 99,
  108, 101, 32, 101, 120, 116, 92, 51, 48, 51, 92, 50, 53, 49, 114, 105,
  101, 117, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 50, 52, 44,
  50, 48, 56, 44, 51, 54, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 111, 110, 116, 111, 117, 114, 32, 99, 101, 114,
  99, 108, 101, 32, 101, 120, 116, 92, 51, 48, 51, 92, 50, 53, 49, 114,
  105, 101, 117, 114, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32,
  99, 111, 110, 116, 111, 117, 114, 32, 99, 101, 114, 99, 108, 101, 32, 101,
  120, 116, 92, 51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32,
  61, 32, 99, 111, 108, 111, 114, 40, 50, 48, 48, 44, 49, 48, 48, 44,
  53, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 82, 97, 121, 111, 110, 32, 99, 101, 114, 99, 108, 101, 32, 49, 32,
  47, 32, 114, 97, 100, 105, 117, 115, 32, 99, 105, 114, 99, 108, 101, 32,
  49, 32, 61, 32, 105, 110, 116, 40, 52, 48, 44, 48, 44, 49, 48, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 97, 121, 111,
  110, 32, 99, 101, 114, 99, 108, 101, 32, 50, 32, 47, 32, 114, 97, 100,
  105, 117, 115, 32, 99, 105, 114, 99, 108, 101, 32, 50, 32, 40, 37, 41,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 54, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 114, 105,
  97, 116, 105, 111, 110, 32, 100, 101, 32, 99, 111, 117, 108, 101, 117, 114,
  32, 47, 32, 99, 111, 108, 111, 114, 32, 118, 97, 114, 105, 97, 116, 105,
  111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 80,
  97, 115, 32, 100, 101, 32, 118, 97, 114, 105, 97, 116, 105, 111, 110, 32,
  47, 32, 78, 111, 32, 99, 104, 97, 110, 103, 101, 34, 44, 34, 67, 111,
  117, 108, 101, 117, 114, 115, 32, 97, 108, 101, 97, 116, 111, 105, 114, 101,
  115, 32, 47, 32, 82, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111, 114,
  115, 34, 44, 34, 70, 97, 105, 98, 108, 101, 109, 101, 110, 116, 32, 110,
  117, 97, 110, 99, 101, 101, 32, 47, 32, 80, 111, 111, 114, 108, 121, 32,
  110, 117, 97, 110, 99, 101, 100, 34, 44, 34, 77, 111, 121, 101, 110, 110,
  101, 109, 101, 110, 116, 32, 110, 117, 97, 110, 99, 101, 101, 32, 47, 32,
  77, 111, 100, 101, 114, 97, 116, 101, 108, 121, 32, 110, 117, 97, 110, 99,
  101, 100, 34, 44, 34, 70, 111, 114, 116, 101, 109, 101, 110, 116, 32, 110,
  117, 97, 110, 99, 101, 101, 32, 47, 32, 72, 105, 103, 104, 108, 121, 32,
  110, 117, 97, 110, 99, 101, 100, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 68, 105, 118, 101, 114, 115,
  32, 47, 32, 70, 111, 111, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 108, 111, 117, 32, 47,
  32, 98, 108, 117, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  112, 114, 101, 97, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68,
  101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 66, 108, 101, 110, 100,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 49, 44, 34, 65, 100, 100, 34, 44, 34, 65, 108, 112, 104, 97,
  34, 44, 34, 65, 110, 100, 34, 44, 34, 65, 118, 101, 114, 97, 103, 101,
  34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 66, 117, 114, 110, 34, 44,
  34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 68, 105, 102, 102, 101, 114,
  101, 110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  34, 68, 105, 118, 105, 100, 101, 34, 44, 34, 68, 111, 100, 103, 101, 34,
  44, 34, 69, 120, 99, 108, 117, 115, 105, 111, 110, 34, 44, 34, 70, 114,
  101, 101, 122, 101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 101, 120, 116,
  114, 97, 99, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 109, 101, 114,
  103, 101, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 72, 97, 114,
  100, 32, 108, 105, 103, 104, 116, 34, 44, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44, 34, 72,
  117, 101, 34, 44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105,
  111, 110, 34, 44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44, 34, 76,
  105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110, 101, 97,
  114, 32, 98, 117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32,
  108, 105, 103, 104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 77, 117,
  108, 116, 105, 112, 108, 121, 34, 44, 34, 78, 101, 103, 97, 116, 105, 111,
  110, 34, 44, 34, 79, 114, 34, 44, 34, 79, 118, 101, 114, 108, 97, 121,
  34, 44, 34, 80, 105, 110, 32, 108, 105, 103, 104, 116, 34, 44, 34, 82,
  101, 100, 34, 44, 34, 82, 101, 102, 108, 101, 99, 116, 34, 44, 34, 83,
  97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114,
  97, 103, 101, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114,
  97, 103, 101, 48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117, 114, 110,
  34, 44, 34, 83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34, 44, 34,
  83, 111, 102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83, 99, 114,
  101, 101, 110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34, 83, 117,
  98, 116, 114, 97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 86, 105, 118, 105, 100,
  32, 108, 105, 103, 104, 116, 34, 44, 34, 88, 111, 114, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108,
  97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 32, 58, 32, 60, 105, 62, 83, 97, 109, 106, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48,
  49, 47, 49, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 115, 97, 109, 106, 95, 100, 101, 115, 115, 105, 110, 101,
  114, 95, 117, 110, 101, 95, 102, 108, 101, 117, 114, 95, 50, 32, 58, 10,
  35, 35, 32, 86, 97, 114, 105, 97, 98, 108, 101, 115, 10, 99, 101, 110,
  116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 61, 123, 36,
  49, 47, 49, 48, 48, 42, 119, 125, 10, 99, 101, 110, 116, 114, 101, 95,
  111, 114, 105, 103, 105, 110, 101, 95, 89, 61, 123, 36, 50, 47, 49, 48,
  48, 42, 104, 125, 10, 35, 32, 86, 97, 114, 105, 97, 98, 108, 101, 115,
  32, 102, 111, 110, 99, 116, 105, 111, 110, 32, 45, 102, 108, 111, 119, 101,
  114, 95, 115, 112, 105, 114, 97, 108, 95, 112, 97, 116, 116, 101, 114, 110,
  95, 115, 97, 109, 106, 10, 116, 111, 117, 114, 115, 61, 36, 51, 10, 105,
  110, 99, 114, 101, 109, 101, 110, 116, 95, 116, 104, 101, 116, 97, 61, 36,
  52, 10, 99, 111, 101, 102, 102, 95, 100, 105, 109, 61, 36, 53, 10, 115,
  101, 110, 115, 95, 114, 111, 116, 97, 116, 105, 111, 110, 61, 36, 54, 10,
  76, 111, 110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  61, 36, 55, 10, 76, 97, 114, 103, 101, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 61, 36, 56, 10, 69, 115, 112, 97, 99, 101, 109, 101, 110,
  116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101, 61, 36, 57, 10, 86,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 108, 111, 110, 103, 117, 101, 117,
  114, 61, 36, 49, 48, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  101, 112, 97, 105, 115, 115, 101, 117, 114, 61, 36, 49, 49, 10, 86, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 97, 110, 103, 108, 101, 61, 36, 49,
  50, 10, 65, 103, 114, 97, 110, 100, 105, 115, 115, 101, 109, 101, 110, 116,
  95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 49, 51, 10, 82, 101, 109,
  112, 108, 105, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 49, 52,
  10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108,
  101, 115, 61, 36, 49, 53, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 49, 54, 10, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36,
  49, 55, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116,
  97, 108, 101, 115, 61, 36, 49, 56, 10, 67, 111, 110, 116, 111, 117, 114,
  95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 49, 57, 10, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 61, 36, 50, 48, 10, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116,
  97, 108, 101, 115, 61, 36, 50, 49, 10, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108,
  101, 115, 61, 36, 50, 50, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  61, 36, 50, 51, 10, 82, 101, 109, 112, 108, 105, 114, 95, 99, 101, 114,
  99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 36, 50,
  52, 10, 82, 95, 67, 73, 95, 112, 108, 101, 105, 110, 61, 36, 50, 53,
  10, 86, 95, 67, 73, 95, 112, 108, 101, 105, 110, 61, 36, 50, 54, 10,
  66, 95, 67, 73, 95, 112, 108, 101, 105, 110, 61, 36, 50, 55, 10, 65,
  95, 67, 73, 95, 112, 108, 101, 105, 110, 61, 36, 50, 56, 10, 67, 111,
  110, 116, 111, 117, 114, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116,
  101, 114, 105, 101, 117, 114, 61, 36, 50, 57, 10, 82, 95, 67, 73, 95,
  99, 111, 110, 116, 111, 117, 114, 61, 36, 51, 48, 10, 86, 95, 67, 73,
  95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 51, 49, 10, 66, 95, 67,
  73, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 51, 50, 10, 65, 95,
  67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 51, 51, 10, 82,
  101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120,
  116, 101, 114, 105, 101, 117, 114, 61, 36, 51, 52, 10, 82, 95, 67, 69,
  95, 112, 108, 101, 105, 110, 61, 36, 51, 53, 10, 86, 95, 67, 69, 95,
  112, 108, 101, 105, 110, 61, 36, 51, 54, 10, 66, 95, 67, 69, 95, 112,
  108, 101, 105, 110, 61, 36, 51, 55, 10, 65, 95, 67, 69, 95, 112, 108,
  101, 105, 110, 61, 36, 51, 56, 10, 67, 111, 110, 116, 111, 117, 114, 95,
  99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114,
  61, 36, 51, 57, 10, 82, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117,
  114, 61, 36, 52, 48, 10, 86, 95, 67, 69, 95, 99, 111, 110, 116, 111,
  117, 114, 61, 36, 52, 49, 10, 66, 95, 67, 69, 95, 99, 111, 110, 116,
  111, 117, 114, 61, 36, 52, 50, 10, 65, 95, 67, 69, 95, 99, 111, 110,
  116, 111, 117, 114, 61, 36, 52, 51, 10, 82, 97, 121, 111, 110, 95, 103,
  114, 97, 110, 100, 95, 99, 101, 114, 99, 108, 101, 61, 36, 52, 52, 10,
  82, 97, 121, 111, 110, 95, 112, 101, 116, 105, 116, 95, 99, 101, 114, 99,
  108, 101, 61, 36, 52, 53, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 36, 52, 54, 10,
  35, 32, 86, 97, 114, 105, 97, 98, 108, 101, 115, 32, 100, 105, 118, 101,
  114, 115, 10, 70, 108, 111, 117, 95, 102, 108, 101, 117, 114, 95, 50, 61,
  36, 52, 55, 10, 83, 112, 114, 101, 97, 100, 95, 102, 108, 101, 117, 114,
  95, 50, 61, 36, 52, 56, 10, 68, 101, 102, 111, 114, 109, 95, 102, 108,
  101, 117, 114, 95, 50, 61, 36, 52, 57, 10, 98, 108, 101, 110, 100, 61,
  36, 53, 48, 10, 111, 112, 97, 99, 105, 116, 101, 61, 36, 53, 49, 10,
  82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 61, 36, 53,
  50, 10, 35, 35, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49,
  93, 10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 52, 10, 45, 102,
  108, 111, 119, 101, 114, 95, 115, 112, 105, 114, 97, 108, 95, 112, 97, 116,
  116, 101, 114, 110, 95, 115, 97, 109, 106, 32, 36, 116, 111, 117, 114, 115,
  44, 36, 105, 110, 99, 114, 101, 109, 101, 110, 116, 95, 116, 104, 101, 116,
  97, 44, 36, 99, 111, 101, 102, 102, 95, 100, 105, 109, 44, 36, 115, 101,
  110, 115, 95, 114, 111, 116, 97, 116, 105, 111, 110, 44, 36, 76, 111, 110,
  103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 76,
  97, 114, 103, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36,
  69, 115, 112, 97, 99, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101,
  110, 116, 114, 101, 44, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  108, 111, 110, 103, 117, 101, 117, 114, 44, 36, 86, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114, 44, 36, 86,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 97, 110, 103, 108, 101, 44, 36,
  65, 103, 114, 97, 110, 100, 105, 115, 115, 101, 109, 101, 110, 116, 95, 112,
  101, 116, 97, 108, 101, 115, 44, 36, 82, 101, 109, 112, 108, 105, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 44, 36, 82, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 86, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 44, 36, 67, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116,
  97, 108, 101, 115, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44,
  36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111,
  117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  44, 36, 82, 101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108, 101,
  95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 36, 82, 95, 67, 73,
  95, 112, 108, 101, 105, 110, 44, 36, 86, 95, 67, 73, 95, 112, 108, 101,
  105, 110, 44, 36, 66, 95, 67, 73, 95, 112, 108, 101, 105, 110, 44, 36,
  65, 95, 67, 73, 95, 112, 108, 101, 105, 110, 44, 36, 67, 111, 110, 116,
  111, 117, 114, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114,
  105, 101, 117, 114, 44, 36, 82, 95, 67, 73, 95, 99, 111, 110, 116, 111,
  117, 114, 44, 36, 86, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114,
  44, 36, 66, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36,
  65, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 82, 101,
  109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116,
  101, 114, 105, 101, 117, 114, 44, 36, 82, 95, 67, 69, 95, 112, 108, 101,
  105, 110, 44, 36, 86, 95, 67, 69, 95, 112, 108, 101, 105, 110, 44, 36,
  66, 95, 67, 69, 95, 112, 108, 101, 105, 110, 44, 36, 65, 95, 67, 69,
  95, 112, 108, 101, 105, 110, 44, 36, 67, 111, 110, 116, 111, 117, 114, 95,
  99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114,
  44, 36, 82, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36,
  86, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 66, 95,
  67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 65, 95, 67, 69,
  95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 82, 97, 121, 111, 110, 95,
  103, 114, 97, 110, 100, 95, 99, 101, 114, 99, 108, 101, 44, 36, 82, 97,
  121, 111, 110, 95, 112, 101, 116, 105, 116, 95, 99, 101, 114, 99, 108, 101,
  44, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99,
  111, 117, 108, 101, 117, 114, 10, 99, 101, 110, 116, 114, 101, 95, 111, 114,
  105, 103, 105, 110, 101, 95, 88, 61, 123, 36, 99, 101, 110, 116, 114, 101,
  95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 45, 123, 119, 47, 50, 125,
  125, 10, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101,
  95, 89, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103,
  105, 110, 101, 95, 89, 45, 123, 104, 47, 50, 125, 125, 10, 45, 105, 109,
  97, 103, 101, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 99, 101,
  110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 44, 36,
  99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89,
  10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 98, 108, 117, 114, 91, 45,
  49, 93, 32, 36, 70, 108, 111, 117, 95, 102, 108, 101, 117, 114, 95, 50,
  10, 45, 115, 112, 114, 101, 97, 100, 91, 45, 49, 93, 32, 36, 83, 112,
  114, 101, 97, 100, 95, 102, 108, 101, 117, 114, 95, 50, 10, 45, 100, 101,
  102, 111, 114, 109, 91, 45, 49, 93, 32, 36, 68, 101, 102, 111, 114, 109,
  95, 102, 108, 101, 117, 114, 95, 50, 10, 45, 103, 105, 109, 112, 95, 98,
  108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 36, 98, 108, 101,
  110, 100, 44, 36, 111, 112, 97, 99, 105, 116, 101, 44, 36, 82, 101, 118,
  101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 10, 35, 64, 103, 105, 109,
  112, 32, 68, 101, 115, 115, 105, 110, 101, 114, 32, 117, 110, 32, 112, 111,
  108, 121, 103, 111, 110, 101, 32, 45, 32, 100, 114, 97, 119, 32, 97, 32,
  112, 111, 108, 121, 103, 111, 110, 32, 58, 32, 115, 97, 109, 106, 95, 100,
  101, 115, 115, 105, 110, 101, 114, 95, 117, 110, 95, 112, 111, 108, 121, 103,
  111, 110, 101, 44, 32, 115, 97, 109, 106, 95, 100, 101, 115, 115, 105, 110,
  101, 114, 95, 117, 110, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 112,
  114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 80, 111, 108, 121, 103, 111, 110, 101, 32,
  47, 32, 80, 111, 108, 121, 103, 111, 110, 101, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111,
  109, 98, 114, 101, 32, 100, 101, 32, 99, 92, 51, 48, 51, 92, 50, 54,
  52, 116, 92, 51, 48, 51, 92, 50, 53, 49, 115, 32, 47, 32, 110, 117,
  109, 98, 101, 114, 32, 111, 102, 32, 115, 105, 100, 101, 115, 32, 61, 32,
  105, 110, 116, 40, 53, 44, 51, 44, 57, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 80, 111, 115, 105, 116, 105, 111, 110, 32, 120, 32,
  40, 37, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80,
  111, 115, 105, 116, 105, 111, 110, 32, 121, 32, 40, 37, 41, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 105,
  110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 49, 50, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 82, 97, 121, 111, 110, 32, 99, 101, 114, 99, 108,
  101, 32, 99, 105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 32, 47, 32,
  99, 105, 114, 99, 117, 109, 99, 105, 114, 99, 108, 101, 32, 114, 97, 100,
  105, 117, 115, 32, 61, 32, 105, 110, 116, 40, 49, 53, 48, 44, 49, 54,
  44, 50, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  82, 97, 121, 111, 110, 32, 99, 101, 114, 99, 108, 101, 32, 105, 110, 116,
  92, 51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32, 47, 32,
  105, 110, 110, 101, 114, 32, 99, 105, 114, 99, 108, 101, 32, 114, 97, 100,
  105, 117, 115, 32, 40, 37, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 82, 101, 109, 112, 108, 105, 114, 32, 112, 111, 108, 121, 103,
  111, 110, 101, 32, 101, 120, 116, 92, 51, 48, 51, 92, 50, 53, 49, 114,
  105, 101, 117, 114, 32, 47, 32, 102, 105, 108, 108, 32, 61, 32, 98, 111,
  111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  111, 117, 108, 101, 117, 114, 32, 112, 111, 108, 121, 103, 111, 110, 101, 32,
  101, 120, 116, 92, 51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117, 114,
  32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53,
  44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110,
  116, 111, 117, 114, 32, 112, 111, 108, 121, 103, 111, 110, 101, 32, 101, 120,
  116, 92, 51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 99, 111, 110, 116, 111, 117,
  114, 32, 112, 111, 108, 121, 103, 111, 110, 101, 32, 101, 120, 116, 92, 51,
  48, 51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32, 61, 32, 99, 111,
  108, 111, 114, 40, 48, 44, 48, 44, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 82, 101, 109, 112, 108, 105, 114, 32, 112, 111, 108, 121,
  103, 111, 110, 101, 32, 105, 110, 116, 92, 51, 48, 51, 92, 50, 53, 49,
  114, 105, 101, 117, 114, 32, 47, 32, 102, 105, 108, 108, 32, 61, 32, 98,
  111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 117, 108, 101, 117, 114, 32, 112, 111, 108, 121, 103, 111, 110, 101,
  32, 105, 110, 116, 92, 51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117,
  114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 48, 44, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116,
  111, 117, 114, 32, 112, 111, 108, 121, 103, 111, 110, 101, 32, 105, 110, 116,
  92, 51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32, 61, 32,
  98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 111, 117, 108, 101, 117, 114, 32, 99, 111, 110, 116, 111, 117, 114,
  32, 112, 111, 108, 121, 103, 111, 110, 101, 32, 105, 110, 116, 92, 51, 48,
  51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32, 61, 32, 99, 111, 108,
  111, 114, 40, 48, 44, 50, 53, 53, 44, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 86, 97, 114, 105, 97, 116, 105, 111, 110, 32, 100,
  101, 32, 99, 111, 117, 108, 101, 117, 114, 32, 47, 32, 99, 111, 108, 111,
  114, 32, 118, 97, 114, 105, 97, 116, 105, 111, 110, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 80, 97, 115, 32, 100, 101, 32, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 32, 47, 32, 78, 111, 32, 99, 104, 97, 110,
  103, 101, 34, 44, 34, 67, 111, 117, 108, 101, 117, 114, 115, 32, 97, 108,
  101, 97, 116, 111, 105, 114, 101, 115, 32, 47, 32, 82, 97, 110, 100, 111,
  109, 32, 99, 111, 108, 111, 114, 115, 34, 44, 34, 70, 97, 105, 98, 108,
  101, 109, 101, 110, 116, 32, 110, 117, 97, 110, 99, 101, 101, 32, 47, 32,
  80, 111, 111, 114, 108, 121, 32, 110, 117, 97, 110, 99, 101, 100, 34, 44,
  34, 77, 111, 121, 101, 110, 110, 101, 109, 101, 110, 116, 32, 110, 117, 97,
  110, 99, 101, 101, 32, 47, 32, 77, 111, 100, 101, 114, 97, 116, 101, 108,
  121, 32, 110, 117, 97, 110, 99, 101, 100, 34, 44, 34, 70, 111, 114, 116,
  101, 109, 101, 110, 116, 32, 110, 117, 97, 110, 99, 101, 101, 32, 47, 32,
  72, 105, 103, 104, 108, 121, 32, 110, 117, 97, 110, 99, 101, 100, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 99, 101, 114, 99, 108, 101, 115, 32, 47, 32, 99, 105, 114, 99, 108,
  101, 115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 82, 101, 109, 112, 108, 105, 114, 32, 99, 101,
  114, 99, 108, 101, 32, 105, 110, 116, 92, 51, 48, 51, 92, 50, 53, 49,
  114, 105, 101, 117, 114, 32, 47, 32, 102, 105, 108, 108, 32, 61, 32, 98,
  111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 117, 108, 101, 117, 114, 32, 99, 101, 114, 99, 108, 101, 32, 105,
  110, 116, 92, 51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32,
  61, 32, 99, 111, 108, 111, 114, 40, 49, 50, 55, 44, 49, 50, 55, 44,
  49, 50, 55, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111,
  110, 116, 111, 117, 114, 32, 99, 101, 114, 99, 108, 101, 32, 105, 110, 116,
  92, 51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32, 61, 32,
  98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 111, 117, 108, 101, 117, 114, 32, 99, 111, 110, 116, 111, 117, 114,
  32, 99, 101, 114, 99, 108, 101, 32, 105, 110, 116, 92, 51, 48, 51, 92,
  50, 53, 49, 114, 105, 101, 117, 114, 32, 61, 32, 99, 111, 108, 111, 114,
  40, 48, 44, 48, 44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 82, 101, 109, 112, 108, 105, 114, 32, 99, 101, 114, 99, 108, 101, 32,
  101, 120, 116, 92, 51, 48, 51, 92, 50, 53, 49, 114, 105, 101, 117, 114,
  32, 47, 32, 102, 105, 108, 108, 32, 61, 32, 98, 111, 111, 108, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101,
  117, 114, 32, 99, 101, 114, 99, 108, 101, 32, 101, 120, 116, 92, 51, 48,
  51, 92, 50, 53, 49, 114, 105, 101, 117, 114, 32, 61, 32, 99, 111, 108,
  111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 110, 116, 111, 117, 114,
  32, 99, 101, 114, 99, 108, 101, 32, 101, 120, 116, 92, 51, 48, 51, 92,
  50, 53, 49, 114, 105, 101, 117, 114, 32, 61, 32, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108,
  101, 117, 114, 32, 99, 111, 110, 116, 111, 117, 114, 32, 99, 101, 114, 99,
  108, 101, 32, 101, 120, 116, 92, 51, 48, 51, 92, 50, 53, 49, 114, 105,
  101, 117, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 48, 44, 48, 44,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 105, 108, 97,
  116, 97, 116, 105, 111, 110, 32, 40, 92, 51, 48, 51, 92, 50, 53, 49,
  112, 97, 105, 115, 115, 101, 117, 114, 41, 32, 61, 32, 105, 110, 116, 40,
  49, 44, 49, 44, 52, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 84, 114, 97, 110, 115, 112, 97, 114,
  101, 110, 99, 101, 32, 47, 32, 84, 114, 97, 110, 115, 112, 97, 114, 101,
  110, 99, 121, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 84, 114, 97, 110, 115, 112, 97, 114, 101,
  110, 99, 101, 32, 100, 101, 115, 32, 99, 111, 117, 108, 101, 117, 114, 115,
  32, 47, 32, 99, 111, 108, 111, 114, 32, 116, 114, 97, 110, 115, 112, 97,
  114, 101, 110, 99, 121, 32, 61, 32, 105, 110, 116, 40, 50, 53, 53, 44,
  48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 68, 105, 118, 101, 114, 115, 32, 47, 32,
  70, 111, 111, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 70, 108, 111, 117, 32, 47, 32, 98, 108,
  117, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 114, 101,
  97, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 102, 111,
  114, 109, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 66, 108, 101, 110, 100, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49,
  44, 34, 65, 100, 100, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34,
  65, 110, 100, 34, 44, 34, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34,
  66, 108, 117, 101, 34, 44, 34, 66, 117, 114, 110, 34, 44, 34, 68, 97,
  114, 107, 101, 110, 34, 44, 34, 68, 105, 102, 102, 101, 114, 101, 110, 99,
  101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 68, 105,
  118, 105, 100, 101, 34, 44, 34, 68, 111, 100, 103, 101, 34, 44, 34, 69,
  120, 99, 108, 117, 115, 105, 111, 110, 34, 44, 34, 70, 114, 101, 101, 122,
  101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 101, 120, 116, 114, 97, 99,
  116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 109, 101, 114, 103, 101, 34,
  44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 72, 97, 114, 100, 32, 108,
  105, 103, 104, 116, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44, 34, 72, 117, 101, 34,
  44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 34,
  44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44, 34, 76, 105, 103, 104,
  116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 98,
  117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 108, 105, 103,
  104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 77, 117, 108, 116, 105,
  112, 108, 121, 34, 44, 34, 78, 101, 103, 97, 116, 105, 111, 110, 34, 44,
  34, 79, 114, 34, 44, 34, 79, 118, 101, 114, 108, 97, 121, 34, 44, 34,
  80, 105, 110, 32, 108, 105, 103, 104, 116, 34, 44, 34, 82, 101, 100, 34,
  44, 34, 82, 101, 102, 108, 101, 99, 116, 34, 44, 34, 83, 97, 116, 117,
  114, 97, 116, 105, 111, 110, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101,
  34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101,
  48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117, 114, 110, 34, 44, 34,
  83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34, 44, 34, 83, 111, 102,
  116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83, 99, 114, 101, 101, 110,
  34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34, 83, 117, 98, 116, 114,
  97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 34, 86, 105, 118, 105, 100, 32, 108, 105,
  103, 104, 116, 34, 44, 34, 88, 111, 114, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121, 101,
  114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32,
  58, 32, 60, 105, 62, 83, 97, 109, 106, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 49,
  55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 115, 97, 109, 106, 95, 100, 101, 115, 115, 105, 110, 101, 114, 95, 117,
  110, 95, 112, 111, 108, 121, 103, 111, 110, 101, 58, 10, 78, 111, 109, 98,
  114, 101, 95, 100, 101, 95, 99, 111, 116, 101, 115, 61, 36, 49, 10, 88,
  95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99,
  105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 61, 123, 36, 50, 47, 49,
  48, 48, 42, 119, 125, 10, 89, 95, 99, 101, 110, 116, 114, 101, 95, 99,
  101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115, 99, 114, 105,
  116, 61, 123, 36, 51, 47, 49, 48, 48, 42, 104, 125, 10, 65, 110, 103,
  108, 101, 95, 105, 110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 61, 36,
  52, 10, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 99,
  105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 61, 36, 53, 10, 82, 97,
  121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114,
  105, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82, 97,
  121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111,
  110, 115, 99, 114, 105, 116, 47, 49, 48, 48, 42, 36, 54, 125, 41, 125,
  10, 82, 101, 109, 112, 108, 105, 114, 95, 112, 111, 108, 121, 103, 111, 110,
  101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 61, 36, 55, 10, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110,
  101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 61, 36, 56, 10, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110,
  101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 61, 36, 57, 10, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110,
  101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 61, 36, 49, 48, 10,
  67, 111, 110, 116, 111, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101,
  95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 61, 36, 49, 49, 10, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114,
  95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 101, 120, 116, 101, 114, 105,
  101, 117, 114, 61, 36, 49, 50, 10, 86, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 111, 108, 121, 103, 111,
  110, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 61, 36, 49, 51,
  10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111,
  117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 101, 120, 116, 101,
  114, 105, 101, 117, 114, 61, 36, 49, 52, 10, 82, 101, 109, 112, 108, 105,
  114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 105, 110, 116, 101, 114,
  105, 101, 117, 114, 61, 36, 49, 53, 10, 82, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 105, 110, 116, 101,
  114, 105, 101, 117, 114, 61, 36, 49, 54, 10, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 105, 110, 116,
  101, 114, 105, 101, 117, 114, 61, 36, 49, 55, 10, 66, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 105, 110,
  116, 101, 114, 105, 101, 117, 114, 61, 36, 49, 56, 10, 67, 111, 110, 116,
  111, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 105, 110, 116,
  101, 114, 105, 101, 117, 114, 61, 36, 49, 57, 10, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 111, 108,
  121, 103, 111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 61,
  36, 50, 48, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111,
  110, 116, 111, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 105,
  110, 116, 101, 114, 105, 101, 117, 114, 61, 36, 50, 49, 10, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112,
  111, 108, 121, 103, 111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117,
  114, 61, 36, 50, 50, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 36, 50, 51, 10, 82,
  101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110,
  116, 101, 114, 105, 101, 117, 114, 61, 36, 50, 52, 10, 82, 95, 67, 73,
  95, 112, 108, 101, 105, 110, 61, 36, 50, 53, 10, 86, 95, 67, 73, 95,
  112, 108, 101, 105, 110, 61, 36, 50, 54, 10, 66, 95, 67, 73, 95, 112,
  108, 101, 105, 110, 61, 36, 50, 55, 10, 67, 111, 110, 116, 111, 117, 114,
  95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117,
  114, 61, 36, 50, 56, 10, 82, 95, 67, 73, 95, 99, 111, 110, 116, 111,
  117, 114, 61, 36, 50, 57, 10, 86, 95, 67, 73, 95, 99, 111, 110, 116,
  111, 117, 114, 61, 36, 51, 48, 10, 66, 95, 67, 73, 95, 99, 111, 110,
  116, 111, 117, 114, 61, 36, 51, 49, 10, 82, 101, 109, 112, 108, 105, 114,
  95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117,
  114, 61, 36, 51, 50, 10, 82, 95, 67, 69, 95, 112, 108, 101, 105, 110,
  61, 36, 51, 51, 10, 86, 95, 67, 69, 95, 112, 108, 101, 105, 110, 61,
  36, 51, 52, 10, 66, 95, 67, 69, 95, 112, 108, 101, 105, 110, 61, 36,
  51, 53, 10, 67, 111, 110, 116, 111, 117, 114, 95, 99, 101, 114, 99, 108,
  101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 61, 36, 51, 54, 10,
  82, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 51, 55,
  10, 86, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 51,
  56, 10, 66, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36,
  51, 57, 10, 86, 97, 108, 101, 117, 114, 95, 100, 105, 108, 97, 116, 101,
  95, 99, 105, 114, 99, 61, 36, 52, 48, 10, 84, 114, 97, 110, 115, 112,
  97, 114, 101, 110, 99, 101, 95, 100, 101, 115, 95, 99, 111, 117, 108, 101,
  117, 114, 115, 61, 36, 52, 49, 10, 70, 108, 111, 117, 95, 112, 111, 108,
  121, 103, 111, 110, 101, 61, 36, 52, 50, 10, 83, 112, 114, 101, 97, 100,
  95, 112, 111, 108, 121, 103, 111, 110, 101, 61, 36, 52, 51, 10, 68, 101,
  102, 111, 114, 109, 95, 112, 111, 108, 121, 103, 111, 110, 101, 61, 36, 52,
  52, 10, 98, 108, 101, 110, 100, 61, 36, 52, 53, 10, 111, 112, 97, 99,
  105, 116, 101, 61, 36, 52, 54, 10, 82, 101, 118, 101, 114, 116, 95, 108,
  97, 121, 101, 114, 115, 61, 36, 52, 55, 10, 123, 119, 125, 44, 123, 104,
  125, 44, 49, 44, 52, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111,
  114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 10, 45, 105,
  102, 32, 123, 36, 82, 101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99,
  108, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 61, 61, 49, 125,
  10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 88,
  95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99,
  105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 44, 36, 89, 95, 99, 101,
  110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99,
  111, 110, 115, 99, 114, 105, 116, 44, 36, 82, 97, 121, 111, 110, 95, 99,
  101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115, 99, 114, 105,
  116, 44, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95,
  99, 105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 44, 48, 44, 49, 44,
  36, 82, 95, 67, 69, 95, 112, 108, 101, 105, 110, 44, 36, 86, 95, 67,
  69, 95, 112, 108, 101, 105, 110, 44, 36, 66, 95, 67, 69, 95, 112, 108,
  101, 105, 110, 44, 36, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99,
  101, 95, 100, 101, 115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 67, 111, 110, 116,
  111, 117, 114, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114,
  105, 101, 117, 114, 61, 61, 49, 125, 10, 45, 101, 108, 108, 105, 112, 115,
  101, 91, 45, 49, 93, 32, 36, 88, 95, 99, 101, 110, 116, 114, 101, 95,
  99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115, 99, 114,
  105, 116, 44, 36, 89, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114,
  99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 44,
  36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105,
  114, 99, 111, 110, 115, 99, 114, 105, 116, 44, 36, 82, 97, 121, 111, 110,
  95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115, 99,
  114, 105, 116, 44, 48, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70,
  44, 36, 82, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36,
  86, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 66, 95,
  67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 84, 114, 97, 110,
  115, 112, 97, 114, 101, 110, 99, 101, 95, 100, 101, 115, 95, 99, 111, 117,
  108, 101, 117, 114, 115, 10, 45, 101, 110, 100, 105, 102, 10, 73, 110, 99,
  114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 108, 101, 61, 123, 51, 54,
  48, 47, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 99, 111, 116,
  101, 115, 125, 10, 78, 98, 95, 98, 111, 117, 99, 108, 101, 61, 36, 78,
  111, 109, 98, 114, 101, 95, 100, 101, 95, 99, 111, 116, 101, 115, 10, 45,
  100, 111, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 61, 48,
  125, 10, 88, 95, 112, 111, 105, 110, 116, 95, 101, 120, 116, 101, 114, 105,
  101, 117, 114, 61, 123, 36, 88, 95, 99, 101, 110, 116, 114, 101, 95, 99,
  101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115, 99, 114, 105,
  116, 43, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82, 97, 121, 111, 110,
  95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115, 99,
  114, 105, 116, 42, 123, 99, 111, 115, 40, 123, 112, 105, 47, 49, 56, 48,
  42, 123, 36, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103,
  108, 101, 43, 36, 65, 110, 103, 108, 101, 95, 105, 110, 99, 108, 105, 110,
  97, 105, 115, 111, 110, 43, 123, 51, 54, 48, 47, 36, 78, 111, 109, 98,
  114, 101, 95, 100, 101, 95, 99, 111, 116, 101, 115, 125, 125, 125, 41, 125,
  125, 41, 125, 125, 10, 89, 95, 112, 111, 105, 110, 116, 95, 101, 120, 116,
  101, 114, 105, 101, 117, 114, 61, 123, 36, 89, 95, 99, 101, 110, 116, 114,
  101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115,
  99, 114, 105, 116, 43, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82, 97,
  121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111,
  110, 115, 99, 114, 105, 116, 42, 123, 115, 105, 110, 40, 123, 112, 105, 47,
  49, 56, 48, 42, 123, 36, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95,
  97, 110, 103, 108, 101, 43, 36, 65, 110, 103, 108, 101, 95, 105, 110, 99,
  108, 105, 110, 97, 105, 115, 111, 110, 43, 123, 51, 54, 48, 47, 36, 78,
  111, 109, 98, 114, 101, 95, 100, 101, 95, 99, 111, 116, 101, 115, 125, 125,
  125, 41, 125, 125, 41, 125, 125, 10, 88, 95, 112, 111, 105, 110, 116, 95,
  105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 123, 36, 88, 95, 99, 101,
  110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99,
  111, 110, 115, 99, 114, 105, 116, 43, 123, 114, 111, 117, 110, 100, 40, 123,
  36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110,
  116, 101, 114, 105, 101, 117, 114, 42, 123, 99, 111, 115, 40, 123, 112, 105,
  47, 49, 56, 48, 42, 123, 36, 73, 110, 99, 114, 101, 109, 101, 110, 116,
  95, 97, 110, 103, 108, 101, 43, 36, 65, 110, 103, 108, 101, 95, 105, 110,
  99, 108, 105, 110, 97, 105, 115, 111, 110, 43, 123, 51, 54, 48, 47, 36,
  78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 99, 111, 116, 101, 115, 125,
  125, 125, 41, 125, 125, 41, 125, 125, 10, 89, 95, 112, 111, 105, 110, 116,
  95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 123, 36, 89, 95, 99,
  101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114,
  99, 111, 110, 115, 99, 114, 105, 116, 43, 123, 114, 111, 117, 110, 100, 40,
  123, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 105,
  110, 116, 101, 114, 105, 101, 117, 114, 42, 123, 115, 105, 110, 40, 123, 112,
  105, 47, 49, 56, 48, 42, 123, 36, 73, 110, 99, 114, 101, 109, 101, 110,
  116, 95, 97, 110, 103, 108, 101, 43, 36, 65, 110, 103, 108, 101, 95, 105,
  110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 43, 123, 51, 54, 48, 47,
  36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 99, 111, 116, 101, 115,
  125, 125, 125, 41, 125, 125, 41, 125, 125, 10, 45, 105, 102, 32, 123, 36,
  78, 98, 95, 98, 111, 117, 99, 108, 101, 61, 61, 36, 78, 111, 109, 98,
  114, 101, 95, 100, 101, 95, 99, 111, 116, 101, 115, 125, 10, 80, 111, 105,
  110, 116, 115, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 101, 120, 116,
  101, 114, 105, 101, 117, 114, 61, 36, 88, 95, 112, 111, 105, 110, 116, 95,
  101, 120, 116, 101, 114, 105, 101, 117, 114, 44, 36, 89, 95, 112, 111, 105,
  110, 116, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 10, 80, 111, 105,
  110, 116, 115, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 105, 110, 116,
  101, 114, 105, 101, 117, 114, 61, 36, 88, 95, 112, 111, 105, 110, 116, 95,
  105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 36, 89, 95, 112, 111, 105,
  110, 116, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 10, 45, 101, 108,
  115, 101, 10, 80, 111, 105, 110, 116, 115, 95, 112, 111, 108, 121, 103, 111,
  110, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 61, 36, 80, 111,
  105, 110, 116, 115, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 101, 120,
  116, 101, 114, 105, 101, 117, 114, 44, 36, 88, 95, 112, 111, 105, 110, 116,
  95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 44, 36, 89, 95, 112, 111,
  105, 110, 116, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 10, 80, 111,
  105, 110, 116, 115, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 105, 110,
  116, 101, 114, 105, 101, 117, 114, 61, 36, 80, 111, 105, 110, 116, 115, 95,
  112, 111, 108, 121, 103, 111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101,
  117, 114, 44, 36, 88, 95, 112, 111, 105, 110, 116, 95, 105, 110, 116, 101,
  114, 105, 101, 117, 114, 44, 36, 89, 95, 112, 111, 105, 110, 116, 95, 105,
  110, 116, 101, 114, 105, 101, 117, 114, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 78, 98, 95, 98, 111, 117, 99, 108, 101, 61,
  61, 49, 125, 10, 45, 105, 102, 32, 123, 36, 82, 101, 109, 112, 108, 105,
  114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 101, 120, 116, 101, 114,
  105, 101, 117, 114, 61, 61, 49, 125, 10, 45, 112, 111, 108, 121, 103, 111,
  110, 91, 45, 49, 93, 32, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101,
  95, 99, 111, 116, 101, 115, 44, 36, 80, 111, 105, 110, 116, 115, 95, 112,
  111, 108, 121, 103, 111, 110, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117,
  114, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112,
  111, 108, 121, 103, 111, 110, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117,
  114, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 111, 108,
  121, 103, 111, 110, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 44,
  36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 111, 108, 121, 103,
  111, 110, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 44, 36, 84,
  114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 95, 100, 101, 115, 95,
  99, 111, 117, 108, 101, 117, 114, 115, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 67, 111, 110, 116, 111, 117, 114, 95, 112, 111,
  108, 121, 103, 111, 110, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114,
  61, 61, 49, 125, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49,
  93, 32, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 99, 111, 116,
  101, 115, 44, 36, 80, 111, 105, 110, 116, 115, 95, 112, 111, 108, 121, 103,
  111, 110, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 44, 49, 44,
  48, 120, 70, 70, 70, 70, 70, 70, 44, 36, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 111, 108, 121,
  103, 111, 110, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 44, 36,
  86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117,
  114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 101, 120, 116, 101, 114,
  105, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  99, 111, 110, 116, 111, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101,
  95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 44, 36, 84, 114, 97, 110,
  115, 112, 97, 114, 101, 110, 99, 101, 95, 100, 101, 115, 95, 99, 111, 117,
  108, 101, 117, 114, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 82, 101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108,
  101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 61, 49, 125, 10,
  45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 88, 95,
  99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105,
  114, 99, 111, 110, 115, 99, 114, 105, 116, 44, 36, 89, 95, 99, 101, 110,
  116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111,
  110, 115, 99, 114, 105, 116, 44, 36, 82, 97, 121, 111, 110, 95, 99, 101,
  114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 36,
  82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116,
  101, 114, 105, 101, 117, 114, 44, 48, 44, 49, 44, 36, 82, 95, 67, 73,
  95, 112, 108, 101, 105, 110, 44, 36, 86, 95, 67, 73, 95, 112, 108, 101,
  105, 110, 44, 36, 66, 95, 67, 73, 95, 112, 108, 101, 105, 110, 44, 36,
  84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 95, 100, 101, 115,
  95, 99, 111, 117, 108, 101, 117, 114, 115, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 67, 111, 110, 116, 111, 117, 114, 95, 99,
  101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 61,
  61, 49, 125, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93,
  32, 36, 88, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108,
  101, 95, 99, 105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 44, 36, 89,
  95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99,
  105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 44, 36, 82, 97, 121, 111,
  110, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101,
  117, 114, 44, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101,
  95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 48, 44, 49, 44, 48,
  120, 70, 70, 70, 70, 70, 70, 44, 36, 82, 95, 67, 73, 95, 99, 111,
  110, 116, 111, 117, 114, 44, 36, 86, 95, 67, 73, 95, 99, 111, 110, 116,
  111, 117, 114, 44, 36, 66, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117,
  114, 44, 36, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 95,
  100, 101, 115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 101, 109, 112, 108, 105,
  114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 105, 110, 116, 101, 114,
  105, 101, 117, 114, 61, 61, 49, 125, 10, 45, 112, 111, 108, 121, 103, 111,
  110, 91, 45, 49, 93, 32, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101,
  95, 99, 111, 116, 101, 115, 44, 36, 80, 111, 105, 110, 116, 115, 95, 112,
  111, 108, 121, 103, 111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117,
  114, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112,
  111, 108, 121, 103, 111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117,
  114, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 111, 108,
  121, 103, 111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 44,
  36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 111, 108, 121, 103,
  111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 36, 84,
  114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 95, 100, 101, 115, 95,
  99, 111, 117, 108, 101, 117, 114, 115, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 67, 111, 110, 116, 111, 117, 114, 95, 112, 111,
  108, 121, 103, 111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114,
  61, 61, 49, 125, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49,
  93, 32, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 99, 111, 116,
  101, 115, 44, 36, 80, 111, 105, 110, 116, 115, 95, 112, 111, 108, 121, 103,
  111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 49, 44,
  48, 120, 70, 70, 70, 70, 70, 70, 44, 36, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 111, 108, 121,
  103, 111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 36,
  86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117,
  114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 105, 110, 116, 101, 114,
  105, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  99, 111, 110, 116, 111, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101,
  95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 36, 84, 114, 97, 110,
  115, 112, 97, 114, 101, 110, 99, 101, 95, 100, 101, 115, 95, 99, 111, 117,
  108, 101, 117, 114, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111,
  117, 108, 101, 117, 114, 61, 61, 49, 125, 10, 88, 95, 112, 111, 105, 110,
  116, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 95, 49, 61, 123, 36,
  88, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95,
  99, 105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 43, 123, 114, 111, 117,
  110, 100, 40, 123, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108,
  101, 95, 99, 105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 42, 123, 99,
  111, 115, 40, 123, 112, 105, 47, 49, 56, 48, 42, 123, 36, 73, 110, 99,
  114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 108, 101, 43, 36, 65, 110,
  103, 108, 101, 95, 105, 110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 43,
  123, 49, 56, 48, 47, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95,
  99, 111, 116, 101, 115, 125, 125, 125, 41, 125, 125, 41, 125, 125, 10, 89,
  95, 112, 111, 105, 110, 116, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114,
  95, 49, 61, 123, 36, 89, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101,
  114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115, 99, 114, 105, 116,
  43, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82, 97, 121, 111, 110, 95,
  99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115, 99, 114,
  105, 116, 42, 123, 115, 105, 110, 40, 123, 112, 105, 47, 49, 56, 48, 42,
  123, 36, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 108,
  101, 43, 36, 65, 110, 103, 108, 101, 95, 105, 110, 99, 108, 105, 110, 97,
  105, 115, 111, 110, 43, 123, 49, 56, 48, 47, 36, 78, 111, 109, 98, 114,
  101, 95, 100, 101, 95, 99, 111, 116, 101, 115, 125, 125, 125, 41, 125, 125,
  41, 125, 125, 10, 88, 95, 112, 111, 105, 110, 116, 95, 101, 120, 116, 101,
  114, 105, 101, 117, 114, 95, 50, 61, 123, 36, 88, 95, 99, 101, 110, 116,
  114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110,
  115, 99, 114, 105, 116, 43, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82,
  97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99,
  111, 110, 115, 99, 114, 105, 116, 42, 123, 99, 111, 115, 40, 123, 112, 105,
  47, 49, 56, 48, 42, 123, 36, 73, 110, 99, 114, 101, 109, 101, 110, 116,
  95, 97, 110, 103, 108, 101, 43, 36, 65, 110, 103, 108, 101, 95, 105, 110,
  99, 108, 105, 110, 97, 105, 115, 111, 110, 45, 123, 49, 56, 48, 47, 36,
  78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 99, 111, 116, 101, 115, 125,
  125, 125, 41, 125, 125, 41, 125, 125, 10, 89, 95, 112, 111, 105, 110, 116,
  95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 95, 50, 61, 123, 36, 89,
  95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99,
  105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 43, 123, 114, 111, 117, 110,
  100, 40, 123, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101,
  95, 99, 105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 42, 123, 115, 105,
  110, 40, 123, 112, 105, 47, 49, 56, 48, 42, 123, 36, 73, 110, 99, 114,
  101, 109, 101, 110, 116, 95, 97, 110, 103, 108, 101, 43, 36, 65, 110, 103,
  108, 101, 95, 105, 110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 45, 123,
  49, 56, 48, 47, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 99,
  111, 116, 101, 115, 125, 125, 125, 41, 125, 125, 41, 125, 125, 10, 45, 105,
  102, 32, 123, 36, 82, 101, 109, 112, 108, 105, 114, 95, 112, 111, 108, 121,
  103, 111, 110, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 61, 61,
  49, 125, 10, 35, 35, 32, 112, 108, 101, 105, 110, 10, 45, 112, 111, 108,
  121, 103, 111, 110, 91, 45, 49, 93, 32, 51, 44, 36, 88, 95, 99, 101,
  110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99,
  111, 110, 115, 99, 114, 105, 116, 44, 36, 89, 95, 99, 101, 110, 116, 114,
  101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115,
  99, 114, 105, 116, 44, 36, 88, 95, 112, 111, 105, 110, 116, 95, 101, 120,
  116, 101, 114, 105, 101, 117, 114, 95, 49, 44, 36, 89, 95, 112, 111, 105,
  110, 116, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 95, 49, 44, 36,
  88, 95, 112, 111, 105, 110, 116, 95, 101, 120, 116, 101, 114, 105, 101, 117,
  114, 95, 50, 44, 36, 89, 95, 112, 111, 105, 110, 116, 95, 101, 120, 116,
  101, 114, 105, 101, 117, 114, 95, 50, 44, 49, 44, 123, 114, 111, 117, 110,
  100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 44, 123, 114, 111,
  117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 44, 123,
  114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125,
  44, 36, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 95, 100,
  101, 115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 67, 111, 110, 116, 111, 117, 114,
  95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 101, 120, 116, 101, 114, 105,
  101, 117, 114, 61, 61, 49, 125, 10, 35, 35, 32, 99, 111, 110, 116, 111,
  117, 114, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32,
  51, 44, 36, 88, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99,
  108, 101, 95, 99, 105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 44, 36,
  89, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95,
  99, 105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 44, 36, 88, 95, 112,
  111, 105, 110, 116, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 95, 49,
  44, 36, 89, 95, 112, 111, 105, 110, 116, 95, 101, 120, 116, 101, 114, 105,
  101, 117, 114, 95, 49, 44, 36, 88, 95, 112, 111, 105, 110, 116, 95, 101,
  120, 116, 101, 114, 105, 101, 117, 114, 95, 50, 44, 36, 89, 95, 112, 111,
  105, 110, 116, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 95, 50, 44,
  49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 44, 123, 114, 111, 117, 110,
  100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 44, 123, 114, 111,
  117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 44, 123,
  114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125,
  44, 36, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 95, 100,
  101, 115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 10, 45, 101, 110, 100,
  105, 102, 10, 88, 95, 112, 111, 105, 110, 116, 95, 105, 110, 116, 101, 114,
  105, 101, 117, 114, 95, 49, 61, 123, 36, 88, 95, 99, 101, 110, 116, 114,
  101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115,
  99, 114, 105, 116, 43, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82, 97,
  121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114,
  105, 101, 117, 114, 42, 123, 99, 111, 115, 40, 123, 112, 105, 47, 49, 56,
  48, 42, 123, 36, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110,
  103, 108, 101, 43, 36, 65, 110, 103, 108, 101, 95, 105, 110, 99, 108, 105,
  110, 97, 105, 115, 111, 110, 43, 123, 49, 56, 48, 47, 36, 78, 111, 109,
  98, 114, 101, 95, 100, 101, 95, 99, 111, 116, 101, 115, 125, 125, 125, 41,
  125, 125, 41, 125, 125, 10, 89, 95, 112, 111, 105, 110, 116, 95, 105, 110,
  116, 101, 114, 105, 101, 117, 114, 95, 49, 61, 123, 36, 89, 95, 99, 101,
  110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99,
  111, 110, 115, 99, 114, 105, 116, 43, 123, 114, 111, 117, 110, 100, 40, 123,
  36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110,
  116, 101, 114, 105, 101, 117, 114, 42, 123, 115, 105, 110, 40, 123, 112, 105,
  47, 49, 56, 48, 42, 123, 36, 73, 110, 99, 114, 101, 109, 101, 110, 116,
  95, 97, 110, 103, 108, 101, 43, 36, 65, 110, 103, 108, 101, 95, 105, 110,
  99, 108, 105, 110, 97, 105, 115, 111, 110, 43, 123, 49, 56, 48, 47, 36,
  78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 99, 111, 116, 101, 115, 125,
  125, 125, 41, 125, 125, 41, 125, 125, 10, 88, 95, 112, 111, 105, 110, 116,
  95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 50, 61, 123, 36, 88,
  95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99,
  105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 43, 123, 114, 111, 117, 110,
  100, 40, 123, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101,
  95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 42, 123, 99, 111, 115, 40,
  123, 112, 105, 47, 49, 56, 48, 42, 123, 36, 73, 110, 99, 114, 101, 109,
  101, 110, 116, 95, 97, 110, 103, 108, 101, 43, 36, 65, 110, 103, 108, 101,
  95, 105, 110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 45, 123, 49, 56,
  48, 47, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 99, 111, 116,
  101, 115, 125, 125, 125, 41, 125, 125, 41, 125, 125, 10, 89, 95, 112, 111,
  105, 110, 116, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 50, 61,
  123, 36, 89, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108,
  101, 95, 99, 105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 43, 123, 114,
  111, 117, 110, 100, 40, 123, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114,
  99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 42, 123, 115,
  105, 110, 40, 123, 112, 105, 47, 49, 56, 48, 42, 123, 36, 73, 110, 99,
  114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 108, 101, 43, 36, 65, 110,
  103, 108, 101, 95, 105, 110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 45,
  123, 49, 56, 48, 47, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95,
  99, 111, 116, 101, 115, 125, 125, 125, 41, 125, 125, 41, 125, 125, 10, 45,
  105, 102, 32, 123, 36, 82, 101, 109, 112, 108, 105, 114, 95, 112, 111, 108,
  121, 103, 111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 61,
  61, 49, 125, 10, 35, 35, 32, 112, 108, 101, 105, 110, 10, 45, 112, 111,
  108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 51, 44, 36, 88, 95, 99,
  101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114,
  99, 111, 110, 115, 99, 114, 105, 116, 44, 36, 89, 95, 99, 101, 110, 116,
  114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110,
  115, 99, 114, 105, 116, 44, 36, 88, 95, 112, 111, 105, 110, 116, 95, 105,
  110, 116, 101, 114, 105, 101, 117, 114, 95, 49, 44, 36, 89, 95, 112, 111,
  105, 110, 116, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 49, 44,
  36, 88, 95, 112, 111, 105, 110, 116, 95, 105, 110, 116, 101, 114, 105, 101,
  117, 114, 95, 50, 44, 36, 89, 95, 112, 111, 105, 110, 116, 95, 105, 110,
  116, 101, 114, 105, 101, 117, 114, 95, 50, 44, 49, 44, 123, 114, 111, 117,
  110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 44, 123, 114,
  111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 44,
  123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41,
  125, 44, 36, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 95,
  100, 101, 115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 67, 111, 110, 116, 111, 117,
  114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 105, 110, 116, 101, 114,
  105, 101, 117, 114, 61, 61, 49, 125, 10, 35, 35, 32, 99, 111, 110, 116,
  111, 117, 114, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93,
  32, 51, 44, 36, 88, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114,
  99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 44,
  36, 89, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101,
  95, 99, 105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 44, 36, 88, 95,
  112, 111, 105, 110, 116, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95,
  49, 44, 36, 89, 95, 112, 111, 105, 110, 116, 95, 105, 110, 116, 101, 114,
  105, 101, 117, 114, 95, 49, 44, 36, 88, 95, 112, 111, 105, 110, 116, 95,
  105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 50, 44, 36, 89, 95, 112,
  111, 105, 110, 116, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 50,
  44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 44, 123, 114, 111, 117,
  110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 44, 123, 114,
  111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 44,
  123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41,
  125, 44, 36, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 95,
  100, 101, 115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 78, 98, 95, 98, 111, 117,
  99, 108, 101, 61, 61, 49, 125, 10, 45, 105, 102, 32, 123, 36, 82, 101,
  109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116,
  101, 114, 105, 101, 117, 114, 61, 61, 49, 125, 10, 45, 101, 108, 108, 105,
  112, 115, 101, 91, 45, 49, 93, 32, 36, 88, 95, 99, 101, 110, 116, 114,
  101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115,
  99, 114, 105, 116, 44, 36, 89, 95, 99, 101, 110, 116, 114, 101, 95, 99,
  101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115, 99, 114, 105,
  116, 44, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95,
  105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 36, 82, 97, 121, 111, 110,
  95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117,
  114, 44, 48, 44, 49, 44, 36, 82, 95, 67, 73, 95, 112, 108, 101, 105,
  110, 44, 36, 86, 95, 67, 73, 95, 112, 108, 101, 105, 110, 44, 36, 66,
  95, 67, 73, 95, 112, 108, 101, 105, 110, 44, 36, 84, 114, 97, 110, 115,
  112, 97, 114, 101, 110, 99, 101, 95, 100, 101, 115, 95, 99, 111, 117, 108,
  101, 117, 114, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 67, 111, 110, 116, 111, 117, 114, 95, 99, 101, 114, 99, 108, 101,
  95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 61, 49, 125, 10, 45,
  101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 88, 95, 99,
  101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114,
  99, 111, 110, 115, 99, 114, 105, 116, 44, 36, 89, 95, 99, 101, 110, 116,
  114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110,
  115, 99, 114, 105, 116, 44, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114,
  99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 36, 82,
  97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101,
  114, 105, 101, 117, 114, 44, 48, 44, 49, 44, 48, 120, 70, 70, 70, 70,
  70, 70, 44, 36, 82, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114,
  44, 36, 86, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36,
  66, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 84, 114,
  97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 95, 100, 101, 115, 95, 99,
  111, 117, 108, 101, 117, 114, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95,
  99, 111, 117, 108, 101, 117, 114, 62, 49, 125, 10, 86, 97, 108, 101, 117,
  114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108,
  101, 117, 114, 61, 49, 54, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117,
  114, 61, 61, 51, 125, 10, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 61, 51,
  50, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108,
  101, 117, 114, 61, 61, 52, 125, 10, 86, 97, 108, 101, 117, 114, 95, 118,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114,
  61, 54, 52, 10, 45, 101, 110, 100, 105, 102, 10, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 101, 120,
  116, 101, 114, 105, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 123,
  36, 56, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114,
  44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10,
  45, 105, 102, 32, 123, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  112, 111, 108, 121, 103, 111, 110, 101, 95, 101, 120, 116, 101, 114, 105, 101,
  117, 114, 62, 50, 53, 53, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 101, 120, 116, 101, 114,
  105, 101, 117, 114, 61, 36, 56, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112,
  111, 108, 121, 103, 111, 110, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117,
  114, 60, 48, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112,
  111, 108, 121, 103, 111, 110, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117,
  114, 61, 36, 56, 10, 45, 101, 110, 100, 105, 102, 10, 86, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 101,
  120, 116, 101, 114, 105, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40,
  123, 36, 57, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95,
  118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117,
  114, 44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125,
  10, 45, 105, 102, 32, 123, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 101, 120, 116, 101, 114, 105,
  101, 117, 114, 62, 50, 53, 53, 125, 10, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 101, 120, 116, 101,
  114, 105, 101, 117, 114, 61, 36, 57, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  112, 111, 108, 121, 103, 111, 110, 101, 95, 101, 120, 116, 101, 114, 105, 101,
  117, 114, 60, 48, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  112, 111, 108, 121, 103, 111, 110, 101, 95, 101, 120, 116, 101, 114, 105, 101,
  117, 114, 61, 36, 57, 10, 45, 101, 110, 100, 105, 102, 10, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95,
  101, 120, 116, 101, 114, 105, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100,
  40, 123, 36, 49, 48, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117,
  114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108,
  101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125,
  41, 125, 10, 45, 105, 102, 32, 123, 36, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 101, 120, 116, 101,
  114, 105, 101, 117, 114, 62, 50, 53, 53, 125, 10, 66, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 101, 120,
  116, 101, 114, 105, 101, 117, 114, 61, 36, 49, 48, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 101, 120, 116, 101,
  114, 105, 101, 117, 114, 60, 48, 125, 10, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 101, 120, 116, 101,
  114, 105, 101, 117, 114, 61, 36, 49, 48, 10, 45, 101, 110, 100, 105, 102,
  10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 111, 108, 121, 103,
  111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 123, 114,
  111, 117, 110, 100, 40, 123, 36, 49, 54, 43, 123, 63, 40, 45, 36, 86,
  97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  99, 111, 117, 108, 101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114, 95,
  118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117,
  114, 41, 125, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95,
  105, 110, 116, 101, 114, 105, 101, 117, 114, 62, 50, 53, 53, 125, 10, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110,
  101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 36, 49, 54, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95,
  105, 110, 116, 101, 114, 105, 101, 117, 114, 60, 48, 125, 10, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95,
  105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 36, 49, 54, 10, 45, 101,
  110, 100, 105, 102, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112,
  111, 108, 121, 103, 111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117,
  114, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 49, 55, 43, 123, 63,
  40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 44, 36, 86, 97, 108,
  101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111,
  117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10, 45, 105, 102, 32, 123,
  36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 111, 108, 121, 103,
  111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 62, 50, 53,
  53, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 111, 108,
  121, 103, 111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 61,
  36, 49, 55, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 111, 108, 121, 103,
  111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 60, 48, 125,
  10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 111, 108, 121, 103,
  111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 36, 49,
  55, 10, 45, 101, 110, 100, 105, 102, 10, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 105, 110, 116, 101,
  114, 105, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 49,
  56, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 44,
  36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10, 45,
  105, 102, 32, 123, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112,
  111, 108, 121, 103, 111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117,
  114, 62, 50, 53, 53, 125, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 105, 110, 116, 101, 114, 105,
  101, 117, 114, 61, 36, 49, 56, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112,
  111, 108, 121, 103, 111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117,
  114, 60, 48, 125, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112,
  111, 108, 121, 103, 111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117,
  114, 61, 36, 49, 56, 10, 45, 101, 110, 100, 105, 102, 10, 88, 95, 112,
  111, 105, 110, 116, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 95, 49,
  61, 123, 36, 88, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99,
  108, 101, 95, 99, 105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 43, 123,
  114, 111, 117, 110, 100, 40, 123, 36, 82, 97, 121, 111, 110, 95, 99, 101,
  114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115, 99, 114, 105, 116,
  42, 123, 99, 111, 115, 40, 123, 112, 105, 47, 49, 56, 48, 42, 123, 36,
  73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 108, 101, 43,
  36, 65, 110, 103, 108, 101, 95, 105, 110, 99, 108, 105, 110, 97, 105, 115,
  111, 110, 43, 123, 49, 56, 48, 47, 36, 78, 111, 109, 98, 114, 101, 95,
  100, 101, 95, 99, 111, 116, 101, 115, 125, 125, 125, 41, 125, 125, 41, 125,
  125, 10, 89, 95, 112, 111, 105, 110, 116, 95, 101, 120, 116, 101, 114, 105,
  101, 117, 114, 95, 49, 61, 123, 36, 89, 95, 99, 101, 110, 116, 114, 101,
  95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115, 99,
  114, 105, 116, 43, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82, 97, 121,
  111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110,
  115, 99, 114, 105, 116, 42, 123, 115, 105, 110, 40, 123, 112, 105, 47, 49,
  56, 48, 42, 123, 36, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97,
  110, 103, 108, 101, 43, 36, 65, 110, 103, 108, 101, 95, 105, 110, 99, 108,
  105, 110, 97, 105, 115, 111, 110, 43, 123, 49, 56, 48, 47, 36, 78, 111,
  109, 98, 114, 101, 95, 100, 101, 95, 99, 111, 116, 101, 115, 125, 125, 125,
  41, 125, 125, 41, 125, 125, 10, 88, 95, 112, 111, 105, 110, 116, 95, 101,
  120, 116, 101, 114, 105, 101, 117, 114, 95, 50, 61, 123, 36, 88, 95, 99,
  101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114,
  99, 111, 110, 115, 99, 114, 105, 116, 43, 123, 114, 111, 117, 110, 100, 40,
  123, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 99,
  105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 42, 123, 99, 111, 115, 40,
  123, 112, 105, 47, 49, 56, 48, 42, 123, 36, 73, 110, 99, 114, 101, 109,
  101, 110, 116, 95, 97, 110, 103, 108, 101, 43, 36, 65, 110, 103, 108, 101,
  95, 105, 110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 45, 123, 49, 56,
  48, 47, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 99, 111, 116,
  101, 115, 125, 125, 125, 41, 125, 125, 41, 125, 125, 10, 89, 95, 112, 111,
  105, 110, 116, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 95, 50, 61,
  123, 36, 89, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108,
  101, 95, 99, 105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 43, 123, 114,
  111, 117, 110, 100, 40, 123, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114,
  99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 42,
  123, 115, 105, 110, 40, 123, 112, 105, 47, 49, 56, 48, 42, 123, 36, 73,
  110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 108, 101, 43, 36,
  65, 110, 103, 108, 101, 95, 105, 110, 99, 108, 105, 110, 97, 105, 115, 111,
  110, 45, 123, 49, 56, 48, 47, 36, 78, 111, 109, 98, 114, 101, 95, 100,
  101, 95, 99, 111, 116, 101, 115, 125, 125, 125, 41, 125, 125, 41, 125, 125,
  10, 45, 105, 102, 32, 123, 36, 82, 101, 109, 112, 108, 105, 114, 95, 112,
  111, 108, 121, 103, 111, 110, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117,
  114, 61, 61, 49, 125, 10, 35, 35, 32, 112, 108, 101, 105, 110, 10, 45,
  112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 51, 44, 36, 88,
  95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99,
  105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 44, 36, 89, 95, 99, 101,
  110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99,
  111, 110, 115, 99, 114, 105, 116, 44, 36, 88, 95, 112, 111, 105, 110, 116,
  95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 95, 49, 44, 36, 89, 95,
  112, 111, 105, 110, 116, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 95,
  49, 44, 36, 88, 95, 112, 111, 105, 110, 116, 95, 101, 120, 116, 101, 114,
  105, 101, 117, 114, 95, 50, 44, 36, 89, 95, 112, 111, 105, 110, 116, 95,
  101, 120, 116, 101, 114, 105, 101, 117, 114, 95, 50, 44, 49, 44, 36, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110,
  101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 44, 36, 86, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95,
  101, 120, 116, 101, 114, 105, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 101, 120,
  116, 101, 114, 105, 101, 117, 114, 44, 36, 84, 114, 97, 110, 115, 112, 97,
  114, 101, 110, 99, 101, 95, 100, 101, 115, 95, 99, 111, 117, 108, 101, 117,
  114, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  67, 111, 110, 116, 111, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101,
  95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 61, 61, 49, 125, 10, 35,
  35, 32, 99, 111, 110, 116, 111, 117, 114, 10, 45, 112, 111, 108, 121, 103,
  111, 110, 91, 45, 49, 93, 32, 51, 44, 36, 88, 95, 99, 101, 110, 116,
  114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110,
  115, 99, 114, 105, 116, 44, 36, 89, 95, 99, 101, 110, 116, 114, 101, 95,
  99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115, 99, 114,
  105, 116, 44, 36, 88, 95, 112, 111, 105, 110, 116, 95, 101, 120, 116, 101,
  114, 105, 101, 117, 114, 95, 49, 44, 36, 89, 95, 112, 111, 105, 110, 116,
  95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 95, 49, 44, 36, 88, 95,
  112, 111, 105, 110, 116, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 95,
  50, 44, 36, 89, 95, 112, 111, 105, 110, 116, 95, 101, 120, 116, 101, 114,
  105, 101, 117, 114, 95, 50, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70,
  70, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110,
  116, 111, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 101, 120,
  116, 101, 114, 105, 101, 117, 114, 44, 36, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 111, 108, 121, 103,
  111, 110, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 44, 36, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114,
  95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 101, 120, 116, 101, 114, 105,
  101, 117, 114, 44, 36, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99,
  101, 95, 100, 101, 115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 10, 45,
  101, 110, 100, 105, 102, 10, 88, 95, 112, 111, 105, 110, 116, 95, 105, 110,
  116, 101, 114, 105, 101, 117, 114, 95, 49, 61, 123, 36, 88, 95, 99, 101,
  110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99,
  111, 110, 115, 99, 114, 105, 116, 43, 123, 114, 111, 117, 110, 100, 40, 123,
  36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110,
  116, 101, 114, 105, 101, 117, 114, 42, 123, 99, 111, 115, 40, 123, 112, 105,
  47, 49, 56, 48, 42, 123, 36, 73, 110, 99, 114, 101, 109, 101, 110, 116,
  95, 97, 110, 103, 108, 101, 43, 36, 65, 110, 103, 108, 101, 95, 105, 110,
  99, 108, 105, 110, 97, 105, 115, 111, 110, 43, 123, 49, 56, 48, 47, 36,
  78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 99, 111, 116, 101, 115, 125,
  125, 125, 41, 125, 125, 41, 125, 125, 10, 89, 95, 112, 111, 105, 110, 116,
  95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 49, 61, 123, 36, 89,
  95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99,
  105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 43, 123, 114, 111, 117, 110,
  100, 40, 123, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101,
  95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 42, 123, 115, 105, 110, 40,
  123, 112, 105, 47, 49, 56, 48, 42, 123, 36, 73, 110, 99, 114, 101, 109,
  101, 110, 116, 95, 97, 110, 103, 108, 101, 43, 36, 65, 110, 103, 108, 101,
  95, 105, 110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 43, 123, 49, 56,
  48, 47, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 99, 111, 116,
  101, 115, 125, 125, 125, 41, 125, 125, 41, 125, 125, 10, 88, 95, 112, 111,
  105, 110, 116, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 50, 61,
  123, 36, 88, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108,
  101, 95, 99, 105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 43, 123, 114,
  111, 117, 110, 100, 40, 123, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114,
  99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 42, 123, 99,
  111, 115, 40, 123, 112, 105, 47, 49, 56, 48, 42, 123, 36, 73, 110, 99,
  114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 108, 101, 43, 36, 65, 110,
  103, 108, 101, 95, 105, 110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 45,
  123, 49, 56, 48, 47, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95,
  99, 111, 116, 101, 115, 125, 125, 125, 41, 125, 125, 41, 125, 125, 10, 89,
  95, 112, 111, 105, 110, 116, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114,
  95, 50, 61, 123, 36, 89, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101,
  114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115, 99, 114, 105, 116,
  43, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82, 97, 121, 111, 110, 95,
  99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114,
  42, 123, 115, 105, 110, 40, 123, 112, 105, 47, 49, 56, 48, 42, 123, 36,
  73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 108, 101, 43,
  36, 65, 110, 103, 108, 101, 95, 105, 110, 99, 108, 105, 110, 97, 105, 115,
  111, 110, 45, 123, 49, 56, 48, 47, 36, 78, 111, 109, 98, 114, 101, 95,
  100, 101, 95, 99, 111, 116, 101, 115, 125, 125, 125, 41, 125, 125, 41, 125,
  125, 10, 45, 105, 102, 32, 123, 36, 82, 101, 109, 112, 108, 105, 114, 95,
  112, 111, 108, 121, 103, 111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101,
  117, 114, 61, 61, 49, 125, 10, 35, 35, 32, 112, 108, 101, 105, 110, 10,
  45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 51, 44, 36,
  88, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95,
  99, 105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 44, 36, 89, 95, 99,
  101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114,
  99, 111, 110, 115, 99, 114, 105, 116, 44, 36, 88, 95, 112, 111, 105, 110,
  116, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 49, 44, 36, 89,
  95, 112, 111, 105, 110, 116, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114,
  95, 49, 44, 36, 88, 95, 112, 111, 105, 110, 116, 95, 105, 110, 116, 101,
  114, 105, 101, 117, 114, 95, 50, 44, 36, 89, 95, 112, 111, 105, 110, 116,
  95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 50, 44, 49, 44, 36,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 111, 108, 121, 103, 111,
  110, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 36, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101,
  95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 36, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 105,
  110, 116, 101, 114, 105, 101, 117, 114, 44, 36, 84, 114, 97, 110, 115, 112,
  97, 114, 101, 110, 99, 101, 95, 100, 101, 115, 95, 99, 111, 117, 108, 101,
  117, 114, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 67, 111, 110, 116, 111, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110,
  101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 61, 49, 125, 10,
  35, 35, 32, 99, 111, 110, 116, 111, 117, 114, 10, 45, 112, 111, 108, 121,
  103, 111, 110, 91, 45, 49, 93, 32, 51, 44, 36, 88, 95, 99, 101, 110,
  116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111,
  110, 115, 99, 114, 105, 116, 44, 36, 89, 95, 99, 101, 110, 116, 114, 101,
  95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115, 99,
  114, 105, 116, 44, 36, 88, 95, 112, 111, 105, 110, 116, 95, 105, 110, 116,
  101, 114, 105, 101, 117, 114, 95, 49, 44, 36, 89, 95, 112, 111, 105, 110,
  116, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 49, 44, 36, 88,
  95, 112, 111, 105, 110, 116, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114,
  95, 50, 44, 36, 89, 95, 112, 111, 105, 110, 116, 95, 105, 110, 116, 101,
  114, 105, 101, 117, 114, 95, 50, 44, 49, 44, 48, 120, 70, 70, 70, 70,
  70, 70, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111,
  110, 116, 111, 117, 114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 105,
  110, 116, 101, 114, 105, 101, 117, 114, 44, 36, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 111, 108, 121,
  103, 111, 110, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 36,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117,
  114, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95, 105, 110, 116, 101, 114,
  105, 101, 117, 114, 44, 36, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110,
  99, 101, 95, 100, 101, 115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 78, 98, 95,
  98, 111, 117, 99, 108, 101, 61, 61, 49, 125, 10, 45, 105, 102, 32, 123,
  36, 82, 101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108, 101, 95,
  105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 61, 49, 125, 10, 45, 101,
  108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 88, 95, 99, 101,
  110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99,
  111, 110, 115, 99, 114, 105, 116, 44, 36, 89, 95, 99, 101, 110, 116, 114,
  101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114, 99, 111, 110, 115,
  99, 114, 105, 116, 44, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99,
  108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 36, 82, 97,
  121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114,
  105, 101, 117, 114, 44, 48, 44, 49, 44, 36, 82, 95, 67, 73, 95, 112,
  108, 101, 105, 110, 44, 36, 86, 95, 67, 73, 95, 112, 108, 101, 105, 110,
  44, 36, 66, 95, 67, 73, 95, 112, 108, 101, 105, 110, 44, 36, 84, 114,
  97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 95, 100, 101, 115, 95, 99,
  111, 117, 108, 101, 117, 114, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 67, 111, 110, 116, 111, 117, 114, 95, 99, 101, 114,
  99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 61, 49,
  125, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36,
  88, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95,
  99, 105, 114, 99, 111, 110, 115, 99, 114, 105, 116, 44, 36, 89, 95, 99,
  101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 99, 105, 114,
  99, 111, 110, 115, 99, 114, 105, 116, 44, 36, 82, 97, 121, 111, 110, 95,
  99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114,
  44, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 105,
  110, 116, 101, 114, 105, 101, 117, 114, 44, 48, 44, 49, 44, 48, 120, 70,
  70, 70, 70, 70, 70, 44, 36, 82, 95, 67, 73, 95, 99, 111, 110, 116,
  111, 117, 114, 44, 36, 86, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117,
  114, 44, 36, 66, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 44,
  36, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 95, 100, 101,
  115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10,
  73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 108, 101, 61,
  123, 36, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 108,
  101, 43, 123, 51, 54, 48, 47, 36, 78, 111, 109, 98, 114, 101, 95, 100,
  101, 95, 99, 111, 116, 101, 115, 125, 125, 10, 78, 98, 95, 98, 111, 117,
  99, 108, 101, 61, 123, 36, 78, 98, 95, 98, 111, 117, 99, 108, 101, 45,
  49, 125, 10, 45, 119, 104, 105, 108, 101, 32, 123, 36, 78, 98, 95, 98,
  111, 117, 99, 108, 101, 62, 48, 125, 10, 45, 105, 102, 32, 123, 36, 86,
  97, 108, 101, 117, 114, 95, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114,
  99, 62, 49, 125, 10, 45, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114,
  99, 91, 45, 49, 93, 32, 36, 86, 97, 108, 101, 117, 114, 95, 100, 105,
  108, 97, 116, 101, 95, 99, 105, 114, 99, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 70, 108, 111, 117,
  95, 112, 111, 108, 121, 103, 111, 110, 101, 10, 45, 115, 112, 114, 101, 97,
  100, 91, 45, 49, 93, 32, 36, 83, 112, 114, 101, 97, 100, 95, 112, 111,
  108, 121, 103, 111, 110, 101, 10, 45, 100, 101, 102, 111, 114, 109, 91, 45,
  49, 93, 32, 36, 68, 101, 102, 111, 114, 109, 95, 112, 111, 108, 121, 103,
  111, 110, 101, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91,
  45, 49, 44, 45, 50, 93, 32, 36, 98, 108, 101, 110, 100, 44, 36, 111,
  112, 97, 99, 105, 116, 101, 44, 36, 82, 101, 118, 101, 114, 116, 95, 108,
  97, 121, 101, 114, 115, 10, 115, 97, 109, 106, 95, 100, 101, 115, 115, 105,
  110, 101, 114, 95, 117, 110, 95, 112, 111, 108, 121, 103, 111, 110, 101, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  115, 97, 109, 106, 95, 100, 101, 115, 115, 105, 110, 101, 114, 95, 117, 110,
  95, 112, 111, 108, 121, 103, 111, 110, 101, 32, 36, 123, 49, 45, 45, 50,
  125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 69, 116,
  111, 105, 108, 101, 32, 100, 101, 32, 112, 111, 109, 112, 101, 105, 32, 58,
  32, 101, 116, 111, 105, 108, 101, 95, 100, 101, 95, 112, 111, 109, 112, 101,
  105, 95, 115, 97, 109, 106, 44, 32, 101, 116, 111, 105, 108, 101, 95, 100,
  101, 95, 112, 111, 109, 112, 101, 105, 95, 115, 97, 109, 106, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 82, 101, 110, 100, 117, 32, 45, 32, 82, 101, 110, 100, 101, 114, 105,
  110, 103, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 80, 111, 115, 105, 116, 105, 111, 110, 32, 120,
  32, 40, 37, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  80, 111, 115, 105, 116, 105, 111, 110, 32, 121, 32, 40, 37, 41, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32,
  105, 110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 51, 48, 44, 48, 44, 54, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110, 32,
  61, 32, 105, 110, 116, 40, 54, 52, 44, 49, 54, 44, 50, 48, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101,
  117, 114, 32, 47, 32, 99, 111, 108, 111, 114, 32, 32, 49, 32, 61, 32,
  99, 111, 108, 111, 114, 40, 49, 51, 53, 44, 49, 49, 56, 44, 49, 48,
  48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 117, 108, 101, 117, 114, 32, 47, 32, 99, 111, 108, 111, 114, 32,
  32, 50, 32, 61, 32, 99, 111, 108, 111, 114, 40, 49, 56, 49, 44, 49,
  51, 53, 44, 57, 57, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 47, 32, 99, 111,
  108, 111, 114, 32, 32, 51, 32, 61, 32, 99, 111, 108, 111, 114, 40, 49,
  56, 51, 44, 49, 52, 48, 44, 49, 48, 53, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114,
  32, 47, 32, 99, 111, 108, 111, 114, 32, 32, 52, 32, 61, 32, 99, 111,
  108, 111, 114, 40, 49, 52, 52, 44, 49, 50, 52, 44, 49, 48, 48, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111,
  117, 108, 101, 117, 114, 115, 32, 97, 108, 92, 51, 48, 51, 92, 50, 53,
  49, 97, 116, 111, 105, 114, 101, 115, 32, 47, 32, 114, 97, 110, 100, 111,
  109, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 78, 111, 110, 32, 47, 32, 78, 111, 34, 44, 34, 82, 86,
  66, 32, 47, 32, 82, 71, 66, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 82, 101, 109, 112, 108, 105, 114, 32, 99, 101, 114, 99, 108,
  101, 32, 47, 32, 102, 105, 108, 108, 32, 99, 105, 114, 99, 108, 101, 32,
  61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 70, 105, 108, 116, 114, 101,
  115, 32, 45, 32, 70, 105, 108, 116, 101, 114, 115, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  112, 114, 101, 97, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70,
  108, 111, 117, 32, 47, 32, 98, 108, 117, 114, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 68, 101, 102, 111, 114, 109, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 69, 112, 97, 105, 115, 115, 101, 117, 114, 32, 47, 32,
  116, 104, 105, 99, 107, 110, 101, 115, 115, 32, 61, 32, 105, 110, 116, 40,
  48, 44, 48, 44, 54, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 66, 108, 101, 110, 100, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49,
  44, 34, 65, 100, 100, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34,
  65, 110, 100, 34, 44, 34, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34,
  66, 108, 117, 101, 34, 44, 34, 66, 117, 114, 110, 34, 44, 34, 68, 97,
  114, 107, 101, 110, 34, 44, 34, 68, 105, 102, 102, 101, 114, 101, 110, 99,
  101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 68, 105,
  118, 105, 100, 101, 34, 44, 34, 68, 111, 100, 103, 101, 34, 44, 34, 69,
  120, 99, 108, 117, 115, 105, 111, 110, 34, 44, 34, 70, 114, 101, 101, 122,
  101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 101, 120, 116, 114, 97, 99,
  116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 109, 101, 114, 103, 101, 34,
  44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 72, 97, 114, 100, 32, 108,
  105, 103, 104, 116, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44, 34, 72, 117, 101, 34,
  44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 34,
  44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44, 34, 76, 105, 103, 104,
  116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 98,
  117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 108, 105, 103,
  104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 77, 117, 108, 116, 105,
  112, 108, 121, 34, 44, 34, 78, 101, 103, 97, 116, 105, 111, 110, 34, 44,
  34, 79, 114, 34, 44, 34, 79, 118, 101, 114, 108, 97, 121, 34, 44, 34,
  80, 105, 110, 32, 108, 105, 103, 104, 116, 34, 44, 34, 82, 101, 100, 34,
  44, 34, 82, 101, 102, 108, 101, 99, 116, 34, 44, 34, 83, 97, 116, 117,
  114, 97, 116, 105, 111, 110, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101,
  34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101,
  48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117, 114, 110, 34, 44, 34,
  83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34, 44, 34, 83, 111, 102,
  116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83, 99, 114, 101, 101, 110,
  34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34, 83, 117, 98, 116, 114,
  97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 34, 86, 105, 118, 105, 100, 32, 108, 105,
  103, 104, 116, 34, 44, 34, 88, 111, 114, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121, 101,
  114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101,
  32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111,
  110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 65, 117, 116, 101, 117, 114, 115, 32, 47, 32, 65, 117,
  116, 104, 111, 114, 115, 32, 58, 32, 60, 105, 62, 83, 97, 109, 106, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49,
  51, 47, 48, 49, 47, 50, 53, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 101, 116, 111, 105, 108, 101, 95, 100, 101,
  95, 112, 111, 109, 112, 101, 105, 95, 115, 97, 109, 106, 32, 58, 10, 88,
  61, 123, 114, 111, 117, 110, 100, 40, 123, 123, 119, 125, 42, 123, 36, 49,
  47, 49, 48, 48, 125, 125, 41, 125, 10, 89, 61, 123, 114, 111, 117, 110,
  100, 40, 123, 123, 104, 125, 42, 123, 36, 50, 47, 49, 48, 48, 125, 125,
  41, 125, 10, 65, 110, 103, 108, 101, 95, 105, 110, 99, 108, 105, 110, 97,
  105, 115, 111, 110, 61, 36, 51, 10, 68, 105, 109, 101, 110, 115, 105, 111,
  110, 61, 36, 52, 10, 35, 99, 97, 114, 114, -23, 115, 10, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 49, 61, 36, 53, 10, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 49, 61, 36, 54, 10, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 49, 61, 36, 55, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114,
  49, 61, 36, 56, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 50, 61,
  36, 57, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 50, 61, 36, 49,
  48, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 50, 61, 36, 49, 49,
  10, 65, 95, 67, 111, 117, 108, 101, 117, 114, 50, 61, 36, 49, 50, 10,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 51, 61, 36, 49, 51, 10, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 51, 61, 36, 49, 52, 10, 66, 95,
  67, 111, 117, 108, 101, 117, 114, 51, 61, 36, 49, 53, 10, 65, 95, 67,
  111, 117, 108, 101, 117, 114, 51, 61, 36, 49, 54, 10, 35, 99, 101, 114,
  99, 108, 101, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 52, 61, 36,
  49, 55, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 52, 61, 36, 49,
  56, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 52, 61, 36, 49, 57,
  10, 65, 95, 67, 111, 117, 108, 101, 117, 114, 52, 61, 36, 50, 48, 10,
  67, 111, 117, 108, 101, 117, 114, 115, 95, 97, 108, 101, 97, 116, 111, 105,
  114, 101, 115, 61, 36, 50, 49, 10, 82, 101, 109, 112, 108, 105, 114, 95,
  99, 101, 114, 99, 108, 101, 61, 36, 50, 50, 10, 118, 97, 108, 101, 117,
  114, 95, 115, 112, 114, 101, 97, 100, 61, 36, 50, 51, 10, 102, 108, 111,
  117, 61, 36, 50, 52, 10, 100, 101, 102, 111, 114, 109, 97, 116, 105, 111,
  110, 61, 36, 50, 53, 10, 69, 112, 97, 105, 115, 115, 101, 117, 114, 61,
  36, 50, 54, 10, 35, 35, 66, 108, 101, 110, 100, 10, 98, 108, 101, 110,
  100, 61, 36, 50, 55, 10, 111, 112, 97, 99, 105, 116, 101, 61, 36, 50,
  56, 10, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 61,
  36, 50, 57, 10, 108, 97, 114, 103, 101, 117, 114, 95, 111, 114, 105, 103,
  105, 110, 101, 61, 123, 119, 125, 10, 104, 97, 117, 116, 101, 117, 114, 95,
  111, 114, 105, 103, 105, 110, 101, 61, 123, 104, 125, 10, 82, 97, 121, 111,
  110, 95, 67, 101, 114, 99, 108, 101, 95, 49, 61, 36, 68, 105, 109, 101,
  110, 115, 105, 111, 110, 10, 82, 97, 121, 111, 110, 95, 67, 101, 114, 99,
  108, 101, 95, 50, 61, 123, 123, 123, 50, 42, 36, 68, 105, 109, 101, 110,
  115, 105, 111, 110, 42, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 125,
  45, 123, 50, 42, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 42, 36,
  68, 105, 109, 101, 110, 115, 105, 111, 110, 42, 123, 99, 111, 115, 40, 112,
  105, 47, 49, 56, 48, 42, 49, 53, 48, 41, 125, 125, 125, 94, 48, 46,
  53, 125, 10, 82, 97, 121, 111, 110, 95, 67, 101, 114, 99, 108, 101, 95,
  51, 61, 123, 36, 68, 105, 109, 101, 110, 115, 105, 111, 110, 43, 123, 36,
  68, 105, 109, 101, 110, 115, 105, 111, 110, 42, 123, 51, 94, 48, 46, 53,
  125, 125, 125, 10, 35, 97, 110, 103, 108, 101, 115, 32, 100, 101, 103, 114,
  -23, 115, 10, 100, 101, 112, 104, 97, 115, 97, 103, 101, 95, 112, 111, 105,
  110, 116, 49, 95, 99, 97, 114, 114, 101, 61, 123, 48, 43, 36, 65, 110,
  103, 108, 101, 95, 105, 110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 125,
  10, 100, 101, 112, 104, 97, 115, 97, 103, 101, 95, 112, 111, 105, 110, 116,
  50, 95, 99, 97, 114, 114, 101, 61, 123, 54, 48, 43, 36, 65, 110, 103,
  108, 101, 95, 105, 110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 125, 10,
  100, 101, 112, 104, 97, 115, 97, 103, 101, 95, 112, 111, 105, 110, 116, 51,
  95, 99, 97, 114, 114, 101, 61, 123, 52, 53, 43, 36, 65, 110, 103, 108,
  101, 95, 105, 110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 125, 10, 100,
  101, 112, 104, 97, 115, 97, 103, 101, 95, 112, 111, 105, 110, 116, 52, 95,
  99, 97, 114, 114, 101, 61, 123, 49, 53, 43, 36, 65, 110, 103, 108, 101,
  95, 105, 110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 125, 10, 100, 101,
  112, 104, 97, 115, 97, 103, 101, 95, 112, 111, 105, 110, 116, 53, 95, 116,
  114, 105, 97, 110, 103, 108, 101, 61, 123, 51, 48, 43, 36, 65, 110, 103,
  108, 101, 95, 105, 110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 125, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62,
  93, 10, 36, 108, 97, 114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105,
  110, 101, 44, 36, 104, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103,
  105, 110, 101, 44, 49, 44, 52, 10, 45, 105, 102, 32, 123, 36, 67, 111,
  117, 108, 101, 117, 114, 115, 95, 97, 108, 101, 97, 116, 111, 105, 114, 101,
  115, 61, 61, 49, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 51,
  61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41,
  41, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 51, 61, 123, 114,
  111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 51, 61, 123, 114, 111, 117, 110,
  100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 52, 61, 123, 114, 111, 117, 110, 100, 40, 63,
  40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 52, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44,
  50, 53, 53, 41, 41, 125, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114,
  52, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53,
  41, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 82, 101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108, 101, 61,
  61, 49, 125, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93,
  32, 36, 88, 44, 36, 89, 44, 36, 82, 97, 121, 111, 110, 95, 67, 101,
  114, 99, 108, 101, 95, 51, 44, 36, 82, 97, 121, 111, 110, 95, 67, 101,
  114, 99, 108, 101, 95, 51, 44, 48, 44, 49, 44, 36, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 52, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117,
  114, 52, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 52, 44, 36,
  65, 95, 67, 111, 117, 108, 101, 117, 114, 52, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36,
  88, 44, 36, 89, 44, 36, 82, 97, 121, 111, 110, 95, 67, 101, 114, 99,
  108, 101, 95, 49, 44, 36, 82, 97, 121, 111, 110, 95, 67, 101, 114, 99,
  108, 101, 95, 49, 44, 48, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 51, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 51,
  44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 51, 44, 36, 65, 95,
  67, 111, 117, 108, 101, 117, 114, 51, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 54, 10, 45, 105, 102, 32, 123, 36, 67, 111, 117, 108, 101, 117, 114,
  115, 95, 97, 108, 101, 97, 116, 111, 105, 114, 101, 115, 61, 61, 49, 125,
  10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 49, 61, 123, 114, 111, 117,
  110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 49, 61, 123, 114, 111, 117, 110, 100, 40,
  63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 66, 95, 67, 111, 117,
  108, 101, 117, 114, 49, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 50, 53, 53, 41, 41, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 50, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53,
  53, 41, 41, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 50, 61,
  123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41,
  125, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 50, 61, 123, 114, 111,
  117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 51, 61, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 86, 95, 67, 111,
  117, 108, 101, 117, 114, 51, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40,
  48, 44, 50, 53, 53, 41, 41, 125, 10, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 51, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50,
  53, 53, 41, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10, 112, 111, 105,
  110, 116, 49, 95, 88, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82,
  97, 121, 111, 110, 95, 67, 101, 114, 99, 108, 101, 95, 49, 42, 123, 99,
  111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 100, 101, 112, 104, 97,
  115, 97, 103, 101, 95, 112, 111, 105, 110, 116, 49, 95, 99, 97, 114, 114,
  101, 41, 125, 125, 41, 125, 10, 112, 111, 105, 110, 116, 49, 95, 89, 61,
  123, 114, 111, 117, 110, 100, 40, 123, 36, 82, 97, 121, 111, 110, 95, 67,
  101, 114, 99, 108, 101, 95, 49, 42, 123, 115, 105, 110, 40, 112, 105, 47,
  49, 56, 48, 42, 36, 100, 101, 112, 104, 97, 115, 97, 103, 101, 95, 112,
  111, 105, 110, 116, 49, 95, 99, 97, 114, 114, 101, 41, 125, 125, 41, 125,
  10, 112, 111, 105, 110, 116, 50, 95, 88, 61, 123, 114, 111, 117, 110, 100,
  40, 123, 36, 82, 97, 121, 111, 110, 95, 67, 101, 114, 99, 108, 101, 95,
  49, 42, 123, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 123, 36,
  100, 101, 112, 104, 97, 115, 97, 103, 101, 95, 112, 111, 105, 110, 116, 50,
  95, 99, 97, 114, 114, 101, 125, 41, 125, 125, 41, 125, 10, 112, 111, 105,
  110, 116, 50, 95, 89, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82,
  97, 121, 111, 110, 95, 67, 101, 114, 99, 108, 101, 95, 49, 42, 123, 115,
  105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 123, 36, 100, 101, 112, 104,
  97, 115, 97, 103, 101, 95, 112, 111, 105, 110, 116, 50, 95, 99, 97, 114,
  114, 101, 125, 41, 125, 125, 41, 125, 10, 112, 111, 105, 110, 116, 51, 95,
  88, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82, 97, 121, 111, 110,
  95, 67, 101, 114, 99, 108, 101, 95, 50, 42, 123, 99, 111, 115, 40, 112,
  105, 47, 49, 56, 48, 42, 123, 36, 100, 101, 112, 104, 97, 115, 97, 103,
  101, 95, 112, 111, 105, 110, 116, 51, 95, 99, 97, 114, 114, 101, 125, 41,
  125, 125, 41, 125, 10, 112, 111, 105, 110, 116, 51, 95, 89, 61, 123, 114,
  111, 117, 110, 100, 40, 123, 36, 82, 97, 121, 111, 110, 95, 67, 101, 114,
  99, 108, 101, 95, 50, 42, 123, 115, 105, 110, 40, 112, 105, 47, 49, 56,
  48, 42, 123, 36, 100, 101, 112, 104, 97, 115, 97, 103, 101, 95, 112, 111,
  105, 110, 116, 51, 95, 99, 97, 114, 114, 101, 125, 41, 125, 125, 41, 125,
  10, 112, 111, 105, 110, 116, 52, 95, 88, 61, 123, 114, 111, 117, 110, 100,
  40, 123, 36, 82, 97, 121, 111, 110, 95, 67, 101, 114, 99, 108, 101, 95,
  50, 42, 123, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 123, 36,
  100, 101, 112, 104, 97, 115, 97, 103, 101, 95, 112, 111, 105, 110, 116, 52,
  95, 99, 97, 114, 114, 101, 125, 41, 125, 125, 41, 125, 10, 112, 111, 105,
  110, 116, 52, 95, 89, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82,
  97, 121, 111, 110, 95, 67, 101, 114, 99, 108, 101, 95, 50, 42, 123, 115,
  105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 123, 36, 100, 101, 112, 104,
  97, 115, 97, 103, 101, 95, 112, 111, 105, 110, 116, 52, 95, 99, 97, 114,
  114, 101, 125, 41, 125, 125, 41, 125, 10, 45, 112, 111, 108, 121, 103, 111,
  110, 91, 45, 49, 93, 32, 52, 44, 123, 36, 88, 43, 36, 112, 111, 105,
  110, 116, 49, 95, 88, 125, 44, 123, 36, 89, 43, 36, 112, 111, 105, 110,
  116, 49, 95, 89, 125, 44, 123, 36, 88, 43, 36, 112, 111, 105, 110, 116,
  50, 95, 88, 125, 44, 123, 36, 89, 43, 36, 112, 111, 105, 110, 116, 50,
  95, 89, 125, 44, 123, 36, 88, 43, 36, 112, 111, 105, 110, 116, 51, 95,
  88, 125, 44, 123, 36, 89, 43, 36, 112, 111, 105, 110, 116, 51, 95, 89,
  125, 44, 123, 36, 88, 43, 36, 112, 111, 105, 110, 116, 52, 95, 88, 125,
  44, 123, 36, 89, 43, 36, 112, 111, 105, 110, 116, 52, 95, 89, 125, 44,
  49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 49, 44, 36, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 49, 44, 36, 66, 95, 67, 111, 117,
  108, 101, 117, 114, 49, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114,
  49, 10, 112, 111, 105, 110, 116, 53, 95, 88, 61, 123, 114, 111, 117, 110,
  100, 40, 123, 36, 82, 97, 121, 111, 110, 95, 67, 101, 114, 99, 108, 101,
  95, 51, 42, 123, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 123,
  36, 100, 101, 112, 104, 97, 115, 97, 103, 101, 95, 112, 111, 105, 110, 116,
  53, 95, 116, 114, 105, 97, 110, 103, 108, 101, 125, 41, 125, 125, 41, 125,
  10, 112, 111, 105, 110, 116, 53, 95, 89, 61, 123, 114, 111, 117, 110, 100,
  40, 123, 36, 82, 97, 121, 111, 110, 95, 67, 101, 114, 99, 108, 101, 95,
  51, 42, 123, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 123, 36,
  100, 101, 112, 104, 97, 115, 97, 103, 101, 95, 112, 111, 105, 110, 116, 53,
  95, 116, 114, 105, 97, 110, 103, 108, 101, 125, 41, 125, 125, 41, 125, 10,
  45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 51, 44, 123,
  36, 88, 43, 36, 112, 111, 105, 110, 116, 51, 95, 88, 125, 44, 123, 36,
  89, 43, 36, 112, 111, 105, 110, 116, 51, 95, 89, 125, 44, 123, 36, 88,
  43, 36, 112, 111, 105, 110, 116, 52, 95, 88, 125, 44, 123, 36, 89, 43,
  36, 112, 111, 105, 110, 116, 52, 95, 89, 125, 44, 123, 36, 88, 43, 36,
  112, 111, 105, 110, 116, 53, 95, 88, 125, 44, 123, 36, 89, 43, 36, 112,
  111, 105, 110, 116, 53, 95, 89, 125, 44, 49, 44, 36, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 50, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117,
  114, 50, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 50, 44, 36,
  65, 95, 67, 111, 117, 108, 101, 117, 114, 50, 10, 112, 111, 105, 110, 116,
  54, 95, 88, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82, 97, 121,
  111, 110, 95, 67, 101, 114, 99, 108, 101, 95, 51, 42, 123, 99, 111, 115,
  40, 112, 105, 47, 49, 56, 48, 42, 123, 36, 100, 101, 112, 104, 97, 115,
  97, 103, 101, 95, 112, 111, 105, 110, 116, 50, 95, 99, 97, 114, 114, 101,
  125, 41, 125, 125, 41, 125, 10, 112, 111, 105, 110, 116, 54, 95, 89, 61,
  123, 114, 111, 117, 110, 100, 40, 123, 36, 82, 97, 121, 111, 110, 95, 67,
  101, 114, 99, 108, 101, 95, 51, 42, 123, 115, 105, 110, 40, 112, 105, 47,
  49, 56, 48, 42, 123, 36, 100, 101, 112, 104, 97, 115, 97, 103, 101, 95,
  112, 111, 105, 110, 116, 50, 95, 99, 97, 114, 114, 101, 125, 41, 125, 125,
  41, 125, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32,
  51, 44, 123, 36, 88, 43, 36, 112, 111, 105, 110, 116, 50, 95, 88, 125,
  44, 123, 36, 89, 43, 36, 112, 111, 105, 110, 116, 50, 95, 89, 125, 44,
  123, 36, 88, 43, 36, 112, 111, 105, 110, 116, 51, 95, 88, 125, 44, 123,
  36, 89, 43, 36, 112, 111, 105, 110, 116, 51, 95, 89, 125, 44, 123, 36,
  88, 43, 36, 112, 111, 105, 110, 116, 54, 95, 88, 125, 44, 123, 36, 89,
  43, 36, 112, 111, 105, 110, 116, 54, 95, 89, 125, 44, 49, 44, 36, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 51, 44, 36, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 51, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114,
  51, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 51, 10, 112, 111,
  105, 110, 116, 55, 95, 88, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36,
  82, 97, 121, 111, 110, 95, 67, 101, 114, 99, 108, 101, 95, 51, 42, 123,
  99, 111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 123, 36, 100, 101, 112,
  104, 97, 115, 97, 103, 101, 95, 112, 111, 105, 110, 116, 49, 95, 99, 97,
  114, 114, 101, 125, 41, 125, 125, 41, 125, 10, 112, 111, 105, 110, 116, 55,
  95, 89, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82, 97, 121, 111,
  110, 95, 67, 101, 114, 99, 108, 101, 95, 51, 42, 123, 115, 105, 110, 40,
  112, 105, 47, 49, 56, 48, 42, 123, 36, 100, 101, 112, 104, 97, 115, 97,
  103, 101, 95, 112, 111, 105, 110, 116, 49, 95, 99, 97, 114, 114, 101, 125,
  41, 125, 125, 41, 125, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45,
  49, 93, 32, 51, 44, 123, 36, 88, 43, 36, 112, 111, 105, 110, 116, 49,
  95, 88, 125, 44, 123, 36, 89, 43, 36, 112, 111, 105, 110, 116, 49, 95,
  89, 125, 44, 123, 36, 88, 43, 36, 112, 111, 105, 110, 116, 52, 95, 88,
  125, 44, 123, 36, 89, 43, 36, 112, 111, 105, 110, 116, 52, 95, 89, 125,
  44, 123, 36, 88, 43, 36, 112, 111, 105, 110, 116, 55, 95, 88, 125, 44,
  123, 36, 89, 43, 36, 112, 111, 105, 110, 116, 55, 95, 89, 125, 44, 49,
  44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 51, 44, 36, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 51, 44, 36, 66, 95, 67, 111, 117, 108,
  101, 117, 114, 51, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 51,
  10, 100, 101, 112, 104, 97, 115, 97, 103, 101, 95, 112, 111, 105, 110, 116,
  49, 95, 99, 97, 114, 114, 101, 61, 123, 36, 100, 101, 112, 104, 97, 115,
  97, 103, 101, 95, 112, 111, 105, 110, 116, 49, 95, 99, 97, 114, 114, 101,
  43, 54, 48, 125, 10, 100, 101, 112, 104, 97, 115, 97, 103, 101, 95, 112,
  111, 105, 110, 116, 50, 95, 99, 97, 114, 114, 101, 61, 123, 36, 100, 101,
  112, 104, 97, 115, 97, 103, 101, 95, 112, 111, 105, 110, 116, 50, 95, 99,
  97, 114, 114, 101, 43, 54, 48, 125, 10, 100, 101, 112, 104, 97, 115, 97,
  103, 101, 95, 112, 111, 105, 110, 116, 51, 95, 99, 97, 114, 114, 101, 61,
  123, 36, 100, 101, 112, 104, 97, 115, 97, 103, 101, 95, 112, 111, 105, 110,
  116, 51, 95, 99, 97, 114, 114, 101, 43, 54, 48, 125, 10, 100, 101, 112,
  104, 97, 115, 97, 103, 101, 95, 112, 111, 105, 110, 116, 52, 95, 99, 97,
  114, 114, 101, 61, 123, 36, 100, 101, 112, 104, 97, 115, 97, 103, 101, 95,
  112, 111, 105, 110, 116, 52, 95, 99, 97, 114, 114, 101, 43, 54, 48, 125,
  10, 100, 101, 112, 104, 97, 115, 97, 103, 101, 95, 112, 111, 105, 110, 116,
  53, 95, 116, 114, 105, 97, 110, 103, 108, 101, 61, 123, 36, 100, 101, 112,
  104, 97, 115, 97, 103, 101, 95, 112, 111, 105, 110, 116, 53, 95, 116, 114,
  105, 97, 110, 103, 108, 101, 43, 54, 48, 125, 10, 45, 100, 111, 110, 101,
  10, 45, 105, 102, 32, 123, 36, 69, 112, 97, 105, 115, 115, 101, 117, 114,
  62, 48, 125, 10, 45, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99,
  91, 45, 49, 93, 32, 36, 69, 112, 97, 105, 115, 115, 101, 117, 114, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 115, 112, 114, 101, 97, 100, 91, 45,
  49, 93, 32, 36, 118, 97, 108, 101, 117, 114, 95, 115, 112, 114, 101, 97,
  100, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 102, 108, 111,
  117, 10, 45, 100, 101, 102, 111, 114, 109, 91, 45, 49, 93, 32, 36, 100,
  101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 10, 45, 103, 105, 109, 112,
  95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 36, 98,
  108, 101, 110, 100, 44, 36, 111, 112, 97, 99, 105, 116, 101, 44, 36, 82,
  101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 10, 35, 10, 35,
  35, 45, 116, 101, 120, 116, 95, 111, 117, 116, 108, 105, 110, 101, 91, 45,
  49, 93, 32, 36, 82, 97, 121, 111, 110, 95, 67, 101, 114, 99, 108, 101,
  95, 51, 44, 49, 44, 48, 44, 49, 51, 44, 49, 44, 49, 44, 50, 53,
  53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64,
  103, 105, 109, 112, 32, 70, 114, 111, 109, 32, 115, 99, 114, 97, 116, 99,
  104, 32, 99, 104, 97, 108, 108, 101, 110, 103, 101, 32, 58, 32, 115, 97,
  109, 106, 95, 70, 114, 111, 109, 95, 83, 99, 114, 97, 116, 99, 104, 95,
  67, 104, 97, 108, 108, 101, 110, 103, 101, 44, 32, 115, 97, 109, 106, 95,
  70, 114, 111, 109, 95, 83, 99, 114, 97, 116, 99, 104, 95, 67, 104, 97,
  108, 108, 101, 110, 103, 101, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 71,
  105, 109, 112, 32, 67, 104, 97, 116, 32, 70, 111, 114, 117, 109, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 104,
  116, 116, 112, 115, 58, 47, 47, 112, 108, 117, 115, 46, 103, 111, 111, 103,
  108, 101, 46, 99, 111, 109, 47, 49, 49, 55, 52, 52, 49, 50, 51, 55,
  57, 56, 50, 50, 56, 51, 48, 49, 49, 51, 49, 56, 47, 112, 111, 115,
  116, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32,
  108, 105, 110, 107, 40, 34, 65, 108, 98, 117, 109, 34, 44, 34, 104, 116,
  116, 112, 115, 58, 47, 47, 112, 108, 117, 115, 46, 103, 111, 111, 103, 108,
  101, 46, 99, 111, 109, 47, 112, 104, 111, 116, 111, 115, 47, 49, 49, 55,
  52, 52, 49, 50, 51, 55, 57, 56, 50, 50, 56, 51, 48, 49, 49, 51,
  49, 56, 47, 97, 108, 98, 117, 109, 115, 47, 53, 57, 53, 54, 52, 55,
  51, 51, 52, 51, 49, 50, 52, 50, 53, 50, 48, 48, 49, 47, 53, 57,
  53, 54, 52, 55, 51, 51, 52, 54, 48, 53, 51, 49, 54, 53, 51, 54,
  50, 34, 41, 59, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 111, 105, 99, 101, 32,
  111, 102, 32, 105, 109, 97, 103, 101, 32, 116, 111, 32, 99, 114, 101, 97,
  116, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 69,
  120, 105, 116, 34, 44, 34, 115, 97, 109, 106, 32, 49, 32, 45, 32, 82,
  97, 121, 115, 32, 79, 102, 32, 67, 111, 108, 111, 114, 115, 34, 44, 34,
  115, 97, 109, 106, 32, 50, 32, 45, 32, 70, 114, 111, 109, 32, 83, 99,
  114, 97, 116, 99, 104, 34, 44, 34, 115, 97, 109, 106, 32, 51, 32, 45,
  32, 67, 101, 114, 99, 108, 101, 115, 32, 51, 68, 34, 44, 34, 115, 97,
  109, 106, 32, 52, 32, 45, 32, 67, 117, 112, 105, 100, 34, 44, 34, 115,
  97, 109, 106, 32, 53, 32, 45, 32, 71, 101, 111, 34, 44, 34, 115, 97,
  109, 106, 32, 54, 32, 45, 32, 66, 108, 97, 110, 99, 34, 44, 34, 115,
  97, 109, 106, 32, 55, 32, 45, 32, 67, 104, 114, 105, 115, 116, 109, 97,
  115, 32, 71, 104, 111, 115, 116, 34, 44, 34, 115, 97, 109, 106, 32, 56,
  32, 45, 32, 68, 101, 103, 114, 97, 100, 97, 116, 105, 111, 110, 34, 44,
  34, 115, 97, 109, 106, 32, 57, 32, 45, 32, 71, 101, 111, 109, 101, 116,
  114, 105, 113, 117, 101, 34, 44, 34, 115, 97, 109, 106, 32, 49, 48, 32,
  45, 32, 79, 32, 34, 44, 34, 115, 97, 109, 106, 32, 49, 49, 32, 45,
  32, 49, 46, 53, 46, 56, 46, 49, 32, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49,
  51, 47, 49, 50, 47, 49, 54, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 70, 114, 111, 109,
  95, 83, 99, 114, 97, 116, 99, 104, 95, 67, 104, 97, 108, 108, 101, 110,
  103, 101, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61,
  48, 125, 10, 35, 35, 35, 35, 32, 69, 120, 105, 116, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 10, 45, 114, 101, 115, 105,
  122, 101, 91, 45, 49, 93, 32, 53, 49, 50, 44, 53, 49, 50, 32, 53,
  49, 50, 44, 53, 49, 50, 44, 49, 44, 51, 32, 45, 116, 111, 95, 114,
  103, 98, 91, 45, 49, 44, 45, 50, 93, 32, 45, 102, 105, 108, 108, 95,
  99, 111, 108, 111, 114, 91, 45, 49, 44, 45, 50, 93, 32, 48, 44, 48,
  44, 48, 32, 45, 115, 97, 109, 106, 95, 82, 97, 121, 115, 95, 79, 102,
  95, 67, 111, 108, 111, 114, 115, 91, 45, 49, 93, 32, 51, 48, 48, 44,
  56, 44, 52, 48, 44, 49, 54, 44, 51, 56, 44, 49, 32, 45, 103, 105,
  109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32,
  48, 44, 49, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61,
  61, 50, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32,
  54, 52, 48, 44, 52, 48, 48, 32, 54, 52, 48, 44, 52, 48, 48, 44,
  49, 44, 51, 32, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 44, 45,
  50, 93, 32, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45,
  49, 44, 45, 50, 93, 32, 48, 44, 48, 44, 48, 32, 45, 119, 97, 114,
  104, 111, 108, 91, 45, 49, 93, 32, 49, 48, 44, 49, 48, 44, 49, 48,
  44, 54, 48, 32, 45, 103, 105, 109, 112, 95, 108, 111, 99, 97, 108, 95,
  111, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 91, 45, 49, 93, 32,
  53, 44, 48, 44, 49, 48, 48, 44, 48, 44, 48, 44, 48, 32, 45, 103,
  105, 109, 112, 95, 115, 121, 109, 109, 101, 116, 114, 105, 122, 111, 115, 99,
  111, 112, 101, 91, 45, 49, 93, 32, 52, 44, 50, 55, 48, 44, 50, 44,
  48, 32, 45, 103, 105, 109, 112, 95, 109, 97, 112, 95, 115, 112, 104, 101,
  114, 101, 91, 45, 49, 93, 32, 54, 52, 48, 44, 52, 48, 48, 44, 57,
  48, 44, 48, 46, 53, 44, 48, 44, 48, 44, 50, 48, 44, 48, 44, 49,
  44, 49, 48, 48, 44, 50, 46, 51, 54, 48, 48, 57, 32, 45, 103, 105,
  109, 112, 95, 99, 111, 108, 111, 114, 109, 97, 112, 91, 45, 49, 93, 32,
  57, 44, 49, 44, 50, 44, 50, 44, 48, 44, 48, 44, 48, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44,
  48, 44, 48, 44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48, 44, 50, 53, 53, 44,
  48, 44, 50, 53, 53, 44, 48, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  48, 32, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 50,
  44, 45, 49, 93, 32, 48, 44, 49, 44, 48, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 61, 61, 51, 125, 10, 45, 114, 101, 115, 105, 122, 101,
  91, 45, 49, 93, 32, 53, 49, 50, 44, 53, 49, 50, 32, 53, 49, 50,
  44, 53, 49, 50, 44, 49, 44, 51, 32, 45, 116, 111, 95, 114, 103, 98,
  91, 45, 49, 44, 45, 50, 93, 32, 45, 102, 105, 108, 108, 95, 99, 111,
  108, 111, 114, 91, 45, 49, 44, 45, 50, 93, 32, 48, 44, 48, 44, 48,
  32, 45, 103, 105, 109, 112, 95, 99, 104, 101, 115, 115, 98, 111, 97, 114,
  100, 91, 45, 49, 93, 32, 54, 48, 44, 54, 48, 44, 48, 44, 48, 44,
  52, 53, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 48,
  32, 45, 103, 105, 109, 112, 95, 99, 105, 114, 99, 108, 101, 95, 116, 114,
  97, 110, 115, 102, 111, 114, 109, 91, 45, 49, 93, 32, 48, 46, 53, 44,
  48, 46, 53, 44, 49, 44, 49, 46, 52, 44, 48, 46, 53, 44, 49, 44,
  49, 44, 49, 44, 49, 32, 45, 103, 105, 109, 112, 95, 98, 108, 117, 114,
  95, 97, 110, 103, 117, 108, 97, 114, 91, 45, 49, 93, 32, 51, 46, 56,
  56, 50, 55, 56, 44, 48, 46, 53, 44, 48, 46, 53, 44, 49, 48, 48,
  46, 55, 51, 51, 44, 48, 44, 48, 32, 45, 99, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 32, 45, 103, 105, 109, 112, 95, 97, 110, 105, 115,
  111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105, 110,
  103, 91, 45, 49, 93, 32, 54, 48, 44, 48, 46, 55, 44, 48, 46, 51,
  44, 48, 46, 54, 44, 49, 46, 49, 44, 48, 46, 56, 44, 51, 48, 44,
  50, 44, 48, 44, 48, 44, 49, 48, 44, 50, 44, 48, 44, 50, 52, 44,
  48, 32, 45, 103, 105, 109, 112, 95, 115, 101, 112, 105, 97, 91, 45, 49,
  93, 32, 48, 44, 49, 44, 48, 44, 48, 32, 45, 103, 105, 109, 112, 95,
  98, 108, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 48, 44, 49,
  44, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 52, 125,
  10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 54, 52, 48,
  44, 52, 48, 48, 32, 54, 52, 48, 44, 52, 48, 48, 44, 49, 44, 51,
  32, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 44, 45, 50, 93, 32,
  45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 50, 93, 32,
  48, 44, 48, 44, 48, 32, 45, 103, 105, 109, 112, 95, 110, 111, 105, 115,
  101, 91, 45, 49, 93, 32, 50, 48, 48, 44, 48, 44, 48, 44, 48, 44,
  48, 32, 45, 103, 105, 109, 112, 95, 119, 105, 110, 100, 91, 45, 49, 93,
  32, 51, 48, 44, 48, 44, 48, 46, 55, 44, 50, 48, 44, 49, 44, 48,
  44, 48, 32, 45, 119, 97, 116, 101, 114, 91, 45, 49, 93, 32, 53, 44,
  49, 32, 45, 103, 105, 109, 112, 95, 119, 97, 116, 101, 114, 99, 111, 108,
  111, 114, 91, 45, 49, 93, 32, 49, 46, 56, 44, 48, 46, 49, 44, 49,
  44, 56, 48, 44, 48, 44, 48, 46, 53, 44, 48, 44, 48, 44, 48, 44,
  50, 44, 48, 44, 50, 44, 52, 44, 50, 44, 48, 44, 51, 44, 51, 44,
  50, 44, 48, 44, 52, 44, 50, 44, 48, 44, 48, 44, 48, 44, 48, 44,
  48, 32, 45, 103, 105, 109, 112, 95, 99, 117, 112, 105, 100, 91, 45, 49,
  93, 32, 48, 44, 49, 57, 50, 44, 49, 57, 50, 44, 49, 57, 50, 44,
  50, 53, 53, 32, 45, 103, 105, 109, 112, 95, 100, 114, 101, 97, 109, 115,
  109, 111, 111, 116, 104, 91, 45, 49, 93, 32, 51, 44, 49, 44, 49, 44,
  48, 46, 56, 44, 48, 44, 48, 46, 50, 44, 49, 44, 50, 52, 44, 48,
  32, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 50, 44,
  45, 49, 93, 32, 48, 44, 49, 44, 48, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 49, 61, 61, 53, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91,
  45, 49, 93, 32, 53, 49, 50, 44, 53, 49, 50, 32, 53, 49, 50, 44,
  53, 49, 50, 44, 49, 44, 51, 32, 45, 116, 111, 95, 114, 103, 98, 91,
  45, 49, 44, 45, 50, 93, 32, 45, 102, 105, 108, 108, 95, 99, 111, 108,
  111, 114, 91, 45, 49, 44, 45, 50, 93, 32, 48, 44, 48, 44, 48, 32,
  45, 103, 105, 109, 112, 95, 112, 108, 97, 115, 109, 97, 91, 45, 49, 93,
  32, 48, 46, 53, 44, 48, 44, 56, 44, 48, 44, 48, 32, 45, 103, 105,
  109, 112, 95, 99, 105, 114, 99, 108, 101, 95, 116, 114, 97, 110, 115, 102,
  111, 114, 109, 91, 45, 49, 93, 32, 48, 46, 53, 44, 48, 46, 53, 44,
  52, 44, 54, 44, 49, 44, 48, 44, 48, 44, 50, 44, 49, 32, 45, 103,
  105, 109, 112, 95, 103, 114, 97, 100, 105, 101, 110, 116, 95, 110, 111, 114,
  109, 91, 45, 49, 93, 32, 50, 44, 48, 46, 53, 44, 48, 44, 49, 48,
  48, 44, 48, 44, 48, 32, 45, 103, 105, 109, 112, 95, 103, 114, 97, 100,
  105, 101, 110, 116, 50, 114, 103, 98, 91, 45, 49, 93, 32, 48, 44, 48,
  44, 49, 48, 48, 44, 48, 44, 48, 44, 48, 32, 45, 103, 105, 109, 112,
  95, 116, 107, 95, 100, 114, 105, 91, 45, 49, 93, 32, 48, 44, 49, 44,
  48, 44, 49, 44, 48, 46, 53, 44, 49, 44, 49, 44, 48, 32, 45, 103,
  105, 109, 112, 95, 97, 114, 114, 97, 121, 95, 102, 97, 100, 101, 91, 45,
  49, 93, 32, 50, 44, 50, 44, 48, 44, 48, 44, 56, 48, 44, 57, 48,
  44, 48, 44, 48, 32, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100,
  91, 45, 50, 44, 45, 49, 93, 32, 48, 44, 49, 44, 48, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 49, 61, 61, 54, 125, 10, 54, 52, 48, 44,
  52, 48, 48, 44, 49, 44, 51, 32, 45, 116, 111, 95, 114, 103, 98, 91,
  45, 49, 93, 32, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91,
  45, 49, 93, 32, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32,
  45, 103, 105, 109, 112, 95, 114, 111, 116, 97, 116, 101, 95, 116, 105, 108,
  101, 115, 91, 45, 49, 93, 32, 55, 44, 55, 44, 49, 53, 44, 51, 44,
  51, 44, 49, 46, 56, 32, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95,
  110, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 32, 45, 103, 105, 109,
  112, 95, 99, 105, 114, 99, 108, 101, 95, 116, 114, 97, 110, 115, 102, 111,
  114, 109, 91, 45, 50, 93, 32, 48, 46, 53, 44, 48, 46, 53, 44, 45,
  50, 44, 45, 50, 44, 48, 46, 50, 44, 48, 44, 49, 44, 49, 44, 49,
  32, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 50, 44,
  45, 49, 93, 32, 49, 44, 49, 44, 48, 32, 45, 103, 105, 109, 112, 95,
  97, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111,
  116, 104, 105, 110, 103, 91, 45, 49, 93, 32, 54, 48, 44, 48, 46, 55,
  44, 48, 46, 51, 44, 48, 46, 54, 44, 49, 46, 49, 44, 48, 46, 56,
  44, 51, 48, 44, 50, 44, 48, 44, 49, 44, 49, 44, 50, 49, 44, 49,
  44, 50, 52, 44, 48, 32, 45, 103, 105, 109, 112, 95, 102, 114, 97, 109,
  101, 95, 112, 97, 105, 110, 116, 105, 110, 103, 91, 45, 49, 93, 32, 52,
  44, 48, 46, 52, 44, 54, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 50, 44, 52, 48, 48, 44, 53, 48, 44, 49, 48, 44, 49,
  44, 48, 46, 53, 44, 49, 50, 51, 52, 53, 54, 44, 48, 32, 45, 114,
  109, 91, 45, 50, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61,
  61, 55, 125, 10, 54, 52, 48, 44, 52, 48, 48, 44, 49, 44, 51, 32,
  45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 32, 45, 102, 105, 108,
  108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44,
  48, 32, 45, 103, 105, 109, 112, 95, 114, 111, 116, 97, 116, 101, 95, 116,
  105, 108, 101, 115, 91, 45, 49, 93, 32, 49, 44, 49, 44, 49, 53, 44,
  51, 44, 51, 44, 49, 46, 56, 32, 45, 103, 105, 109, 112, 95, 99, 105,
  114, 99, 108, 101, 95, 116, 114, 97, 110, 115, 102, 111, 114, 109, 91, 45,
  49, 93, 32, 48, 46, 53, 44, 48, 46, 52, 56, 51, 49, 52, 54, 44,
  45, 56, 46, 54, 49, 49, 50, 52, 44, 45, 49, 46, 52, 57, 56, 49,
  51, 44, 48, 46, 49, 51, 52, 56, 51, 49, 44, 48, 44, 49, 44, 49,
  44, 49, 32, 45, 103, 105, 109, 112, 95, 99, 105, 114, 99, 108, 101, 95,
  116, 114, 97, 110, 115, 102, 111, 114, 109, 91, 45, 49, 93, 32, 48, 46,
  53, 44, 48, 46, 52, 56, 51, 49, 52, 54, 44, 45, 56, 46, 54, 49,
  49, 50, 52, 44, 45, 49, 46, 52, 57, 56, 49, 51, 44, 48, 46, 49,
  51, 52, 56, 51, 49, 44, 48, 44, 49, 44, 49, 44, 49, 32, 45, 45,
  103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91,
  45, 49, 93, 32, 45, 103, 105, 109, 112, 95, 116, 101, 120, 116, 117, 114,
  101, 100, 95, 103, 108, 97, 115, 115, 91, 45, 49, 93, 32, 52, 48, 44,
  52, 48, 44, 49, 44, 49, 44, 48, 44, 50, 44, 48, 44, 48, 32, 45,
  103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50,
  93, 32, 49, 44, 49, 44, 48, 32, 45, 103, 105, 109, 112, 95, 103, 114,
  97, 100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 91, 45, 49, 93, 32,
  48, 44, 48, 46, 53, 44, 48, 44, 49, 48, 48, 44, 48, 44, 48, 32,
  45, 103, 105, 109, 112, 95, 103, 114, 97, 100, 105, 101, 110, 116, 50, 114,
  103, 98, 91, 45, 49, 93, 32, 48, 44, 48, 44, 49, 48, 48, 44, 48,
  44, 48, 44, 48, 32, 45, 103, 105, 109, 112, 95, 116, 107, 95, 109, 101,
  116, 97, 108, 108, 105, 99, 91, 45, 49, 93, 32, 49, 44, 48, 44, 49,
  44, 48, 32, 45, 103, 105, 109, 112, 95, 116, 107, 95, 109, 101, 116, 97,
  108, 108, 105, 99, 91, 45, 49, 93, 32, 49, 44, 48, 44, 52, 44, 48,
  32, 45, 103, 105, 109, 112, 95, 102, 114, 97, 109, 101, 95, 112, 97, 105,
  110, 116, 105, 110, 103, 91, 45, 49, 93, 32, 52, 44, 49, 44, 48, 44,
  54, 52, 44, 54, 52, 44, 54, 52, 44, 48, 44, 52, 48, 48, 44, 56,
  50, 46, 55, 50, 52, 57, 44, 53, 48, 46, 50, 49, 56, 51, 44, 49,
  44, 48, 46, 55, 56, 54, 48, 50, 54, 44, 49, 50, 51, 52, 53, 54,
  44, 48, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 49, 61, 61, 56, 125, 10, 54, 52, 48, 44, 52, 48, 48,
  44, 49, 44, 51, 32, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93,
  32, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93,
  32, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 103, 105,
  109, 112, 95, 115, 117, 112, 101, 114, 102, 111, 114, 109, 117, 108, 97, 91,
  45, 49, 93, 32, 49, 54, 54, 57, 44, 48, 46, 52, 50, 57, 49, 49,
  57, 44, 48, 46, 54, 57, 55, 51, 49, 56, 44, 49, 50, 44, 45, 50,
  52, 44, 50, 52, 44, 51, 50, 44, 48, 44, 48, 44, 49, 53, 44, 54,
  44, 49, 50, 56, 44, 49, 50, 56, 44, 49, 50, 56, 44, 50, 53, 53,
  32, 45, 103, 105, 109, 112, 95, 115, 117, 112, 101, 114, 102, 111, 114, 109,
  117, 108, 97, 91, 45, 49, 93, 32, 50, 44, 48, 44, 48, 44, 56, 44,
  49, 44, 53, 44, 56, 44, 48, 44, 48, 44, 48, 44, 49, 51, 46, 57,
  56, 52, 55, 44, 49, 57, 50, 44, 49, 57, 50, 44, 54, 52, 44, 50,
  53, 53, 32, 45, 116, 119, 105, 114, 108, 91, 45, 49, 93, 32, 49, 44,
  48, 46, 53, 44, 48, 46, 53, 44, 49, 32, 45, 115, 97, 109, 106, 95,
  99, 104, 97, 108, 107, 105, 116, 117, 112, 91, 45, 49, 93, 32, 53, 44,
  50, 46, 53, 44, 49, 46, 53, 44, 53, 48, 44, 49, 44, 53, 44, 53,
  44, 48, 44, 48, 44, 50, 44, 48, 46, 56, 44, 49, 46, 57, 44, 48,
  44, 48, 32, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116,
  104, 105, 110, 103, 91, 45, 49, 93, 32, 45, 103, 105, 109, 112, 95, 116,
  101, 120, 116, 117, 114, 101, 100, 95, 103, 108, 97, 115, 115, 91, 45, 50,
  93, 32, 52, 48, 46, 56, 49, 54, 51, 44, 52, 48, 44, 49, 44, 49,
  44, 48, 44, 52, 46, 49, 50, 50, 52, 53, 44, 51, 44, 48, 32, 45,
  103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 95, 102, 97, 100, 101, 91,
  45, 49, 44, 45, 50, 93, 32, 49, 44, 45, 48, 46, 49, 48, 50, 53,
  54, 52, 44, 48, 44, 53, 44, 48, 44, 48, 44, 48, 44, 48, 44, 48,
  44, 48, 44, 34, 99, 111, 115, 40, 52, 42, 112, 105, 42, 120, 47, 119,
  41, 32, 42, 32, 115, 105, 110, 40, 52, 42, 112, 105, 42, 121, 47, 104,
  41, 34, 32, 45, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97, 108, 105,
  122, 101, 95, 108, 111, 99, 97, 108, 91, 45, 49, 93, 32, 50, 44, 54,
  44, 53, 44, 50, 48, 44, 49, 44, 49, 57, 44, 48, 32, 45, 103, 105,
  109, 112, 95, 102, 114, 97, 109, 101, 95, 112, 97, 105, 110, 116, 105, 110,
  103, 91, 45, 49, 93, 32, 49, 48, 44, 48, 46, 52, 44, 54, 44, 49,
  48, 56, 44, 50, 51, 44, 50, 48, 44, 50, 44, 52, 48, 48, 44, 53,
  48, 44, 49, 48, 44, 49, 44, 48, 46, 53, 44, 49, 50, 51, 52, 53,
  54, 44, 48, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 49, 61, 61, 57, 125, 10, 53, 49, 50, 44, 53, 49,
  50, 44, 49, 44, 51, 32, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49,
  93, 32, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49,
  93, 32, 48, 44, 48, 44, 48, 32, 45, 103, 105, 109, 112, 95, 102, 114,
  97, 109, 101, 95, 102, 117, 122, 122, 121, 91, 45, 49, 93, 32, 50, 48,
  44, 50, 48, 44, 52, 48, 44, 48, 44, 49, 50, 55, 44, 49, 50, 55,
  44, 49, 50, 55, 44, 50, 53, 53, 32, 45, 103, 105, 109, 112, 95, 102,
  114, 97, 109, 101, 91, 45, 49, 93, 32, 48, 44, 49, 48, 48, 44, 48,
  44, 49, 48, 48, 44, 56, 44, 56, 44, 54, 52, 44, 54, 52, 44, 54,
  52, 44, 50, 53, 53, 44, 49, 44, 49, 57, 50, 44, 49, 57, 50, 44,
  49, 57, 50, 44, 50, 53, 53, 32, 45, 103, 105, 109, 112, 95, 102, 114,
  97, 109, 101, 95, 112, 97, 116, 116, 101, 114, 110, 91, 45, 49, 93, 32,
  56, 44, 49, 44, 49, 44, 49, 32, 45, 103, 105, 109, 112, 95, 97, 114,
  114, 97, 121, 95, 102, 97, 100, 101, 91, 45, 49, 93, 32, 50, 44, 50,
  44, 48, 44, 48, 44, 56, 48, 44, 57, 48, 44, 51, 44, 49, 32, 45,
  103, 105, 109, 112, 95, 100, 114, 111, 115, 116, 101, 91, 45, 49, 93, 32,
  48, 44, 48, 44, 49, 48, 48, 44, 48, 44, 49, 48, 48, 44, 49, 48,
  48, 44, 48, 44, 49, 48, 48, 44, 49, 44, 48, 44, 48, 44, 52, 53,
  44, 48, 46, 56, 44, 48, 44, 49, 44, 48, 44, 48, 32, 45, 103, 99,
  100, 95, 104, 115, 108, 91, 45, 49, 93, 32, 49, 44, 48, 44, 48, 44,
  50, 55, 48, 44, 48, 46, 53, 44, 48, 44, 49, 44, 49, 44, 48, 32,
  45, 103, 105, 109, 112, 95, 102, 114, 97, 109, 101, 91, 45, 49, 93, 32,
  48, 44, 49, 48, 48, 44, 48, 44, 49, 48, 48, 44, 49, 44, 49, 44,
  57, 49, 44, 54, 57, 44, 49, 49, 50, 44, 50, 53, 53, 44, 50, 44,
  49, 52, 53, 44, 49, 49, 50, 44, 49, 57, 50, 44, 50, 53, 53, 32,
  45, 114, 109, 91, 45, 50, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  49, 61, 61, 49, 48, 125, 10, 54, 52, 48, 44, 52, 48, 48, 44, 49,
  44, 51, 32, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93, 32, 45,
  102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 32, 45, 103, 105, 109, 112,
  95, 109, 97, 110, 100, 101, 108, 98, 114, 111, 116, 91, 45, 49, 93, 32,
  48, 44, 48, 44, 48, 44, 51, 44, 49, 44, 34, 48, 46, 50, 53, 34,
  44, 34, 48, 46, 48, 48, 34, 44, 54, 52, 44, 54, 52, 44, 54, 52,
  44, 49, 50, 56, 44, 49, 50, 56, 44, 49, 50, 56, 44, 49, 57, 50,
  44, 49, 57, 50, 44, 49, 57, 50, 44, 50, 53, 53, 44, 50, 53, 53,
  44, 50, 53, 53, 32, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110,
  111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 32, 45, 103, 105, 109, 112,
  95, 114, 111, 116, 111, 105, 100, 111, 115, 99, 111, 112, 101, 91, 45, 49,
  93, 32, 48, 46, 53, 44, 48, 46, 53, 44, 52, 44, 53, 44, 48, 32,
  45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45,
  50, 93, 32, 49, 57, 44, 49, 44, 49, 32, 45, 103, 105, 109, 112, 95,
  97, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111,
  116, 104, 105, 110, 103, 91, 45, 49, 93, 32, 54, 48, 44, 48, 46, 55,
  44, 48, 46, 51, 44, 48, 46, 54, 44, 49, 46, 49, 44, 48, 46, 56,
  44, 51, 48, 44, 50, 44, 48, 44, 49, 44, 49, 48, 44, 48, 44, 49,
  44, 50, 52, 44, 48, 32, 45, 103, 105, 109, 112, 95, 97, 110, 105, 115,
  111, 116, 114, 111, 112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105, 110,
  103, 91, 45, 49, 93, 32, 54, 48, 44, 48, 46, 55, 44, 48, 46, 51,
  44, 48, 46, 54, 44, 49, 46, 49, 44, 48, 46, 56, 44, 51, 48, 44,
  50, 44, 48, 44, 49, 44, 49, 48, 44, 48, 44, 49, 44, 50, 52, 44,
  48, 32, 45, 103, 105, 109, 112, 95, 97, 110, 105, 115, 111, 116, 114, 111,
  112, 105, 99, 95, 115, 109, 111, 111, 116, 104, 105, 110, 103, 91, 45, 49,
  93, 32, 54, 48, 44, 48, 46, 55, 44, 48, 46, 51, 44, 48, 46, 54,
  44, 49, 46, 49, 44, 48, 46, 56, 44, 51, 48, 44, 50, 44, 48, 44,
  49, 44, 49, 48, 44, 48, 44, 49, 44, 50, 52, 44, 48, 32, 45, 103,
  105, 109, 112, 95, 97, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 95,
  115, 109, 111, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 32, 54, 48,
  44, 48, 46, 55, 44, 48, 46, 51, 44, 48, 46, 54, 44, 49, 46, 49,
  44, 48, 46, 56, 44, 51, 48, 44, 50, 44, 48, 44, 49, 44, 49, 48,
  44, 48, 44, 49, 44, 50, 52, 44, 48, 32, 45, 103, 105, 109, 112, 95,
  115, 101, 112, 105, 97, 91, 45, 49, 93, 32, 48, 46, 48, 51, 53, 56,
  50, 48, 57, 44, 50, 46, 50, 53, 51, 55, 51, 44, 45, 51, 52, 46,
  50, 53, 51, 55, 44, 48, 32, 45, 103, 105, 109, 112, 95, 102, 114, 97,
  109, 101, 95, 112, 97, 116, 116, 101, 114, 110, 91, 45, 49, 93, 32, 51,
  48, 44, 49, 44, 49, 44, 48, 32, 45, 114, 109, 91, 45, 50, 93, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 49, 125, 10, 53,
  49, 50, 44, 53, 49, 50, 44, 49, 44, 51, 32, 45, 116, 111, 95, 114,
  103, 98, 91, 45, 49, 93, 32, 45, 102, 105, 108, 108, 95, 99, 111, 108,
  111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 32, 45, 103, 105,
  109, 112, 95, 114, 97, 110, 100, 111, 109, 51, 100, 91, 45, 49, 93, 32,
  51, 44, 51, 48, 48, 44, 49, 52, 46, 49, 49, 55, 50, 44, 49, 56,
  48, 44, 50, 50, 46, 57, 55, 48, 55, 44, 48, 44, 48, 44, 45, 49,
  48, 48, 44, 48, 46, 53, 44, 48, 46, 55, 44, 51, 44, 49, 32, 45,
  103, 105, 109, 112, 95, 101, 113, 117, 97, 108, 105, 122, 101, 95, 100, 101,
  116, 97, 105, 108, 115, 91, 45, 49, 93, 32, 32, 48, 44, 48, 44, 50,
  44, 48, 44, 48, 44, 48, 44, 50, 44, 48, 44, 48, 44, 48, 44, 50,
  44, 48, 44, 48, 44, 51, 44, 50, 44, 48, 44, 49, 44, 51, 50, 44,
  48, 44, 48, 32, 45, 102, 114, 97, 109, 101, 95, 99, 117, 98, 101, 91,
  45, 49, 93, 32, 48, 46, 49, 44, 48, 44, 48, 44, 48, 44, 48, 44,
  48, 44, 48, 32, 45, 114, 109, 91, 45, 50, 93, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115,
  97, 109, 106, 95, 70, 114, 111, 109, 95, 83, 99, 114, 97, 116, 99, 104,
  95, 67, 104, 97, 108, 108, 101, 110, 103, 101, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116,
  95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95,
  70, 114, 111, 109, 95, 83, 99, 114, 97, 116, 99, 104, 95, 67, 104, 97,
  108, 108, 101, 110, 103, 101, 32, 36, 42, 34, 44, 36, 45, 49, 10, 35,
  64, 103, 105, 109, 112, 32, 72, 97, 114, 109, 111, 110, 111, 103, 114, 97,
  112, 104, 32, 58, 32, 72, 97, 114, 109, 111, 110, 111, 103, 114, 97, 112,
  104, 95, 115, 97, 109, 106, 44, 32, 72, 97, 114, 109, 111, 110, 111, 103,
  114, 97, 112, 104, 95, 115, 97, 109, 106, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110,
  107, 40, 34, 104, 116, 116, 112, 58, 47, 47, 101, 110, 46, 119, 105, 107,
  105, 112, 101, 100, 105, 97, 46, 111, 114, 103, 47, 119, 105, 107, 105, 47,
  72, 97, 114, 109, 111, 110, 111, 103, 114, 97, 112, 104, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 67,
  101, 110, 116, 114, 101, 32, 47, 32, 67, 101, 110, 116, 101, 114, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 101, 110, 116, 114, 101, 32, 47, 32, 99, 101, 110, 116, 101,
  114, 32, 120, 32, 40, 37, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 101, 110, 116, 114, 101, 32, 47, 32, 99, 101, 110, 116,
  101, 114, 32, 121, 32, 40, 37, 41, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 72, 97, 114, 109, 111,
  110, 111, 103, 114, 97, 112, 104, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 116, 121, 108, 111,
  32, 47, 32, 112, 101, 110, 32, 40, 99, 111, 117, 108, 101, 117, 114, 47,
  99, 111, 108, 111, 114, 41, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50,
  53, 53, 44, 49, 50, 56, 44, 54, 52, 44, 50, 53, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 116, 121, 108, 111, 32, 47, 32,
  112, 101, 110, 32, 40, 118, 97, 114, 105, 97, 116, 105, 111, 110, 32, 100,
  101, 32, 99, 111, 117, 108, 101, 117, 114, 47, 99, 111, 108, 111, 114, 32,
  118, 97, 114, 105, 97, 116, 105, 111, 110, 41, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 80, 97, 115, 32, 100, 101, 32, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 32, 47, 32, 78, 111, 32, 99, 104, 97, 110, 103,
  101, 34, 44, 34, 67, 111, 117, 108, 101, 117, 114, 115, 32, 97, 108, 101,
  97, 116, 111, 105, 114, 101, 115, 32, 47, 32, 82, 97, 110, 100, 111, 109,
  32, 99, 111, 108, 111, 114, 115, 34, 44, 34, 70, 97, 105, 98, 108, 101,
  109, 101, 110, 116, 32, 110, 117, 97, 110, 99, 101, 101, 32, 47, 32, 80,
  111, 111, 114, 108, 121, 32, 110, 117, 97, 110, 99, 101, 100, 34, 44, 34,
  77, 111, 121, 101, 110, 110, 101, 109, 101, 110, 116, 32, 110, 117, 97, 110,
  99, 101, 101, 32, 47, 32, 77, 111, 100, 101, 114, 97, 116, 101, 108, 121,
  32, 110, 117, 97, 110, 99, 101, 100, 34, 44, 34, 70, 111, 114, 116, 101,
  109, 101, 110, 116, 32, 110, 117, 97, 110, 99, 101, 101, 32, 47, 32, 72,
  105, 103, 104, 108, 121, 32, 110, 117, 97, 110, 99, 101, 100, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 116, 121, 108, 111, 32, 47,
  32, 112, 101, 110, 32, 40, 100, 105, 108, 97, 116, 101, 32, 112, 105, 120,
  101, 108, 115, 41, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 51,
  50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 73, 116, 92, 51,
  48, 51, 92, 50, 53, 49, 114, 97, 116, 105, 111, 110, 115, 32, 61, 32,
  105, 110, 116, 40, 49, 48, 48, 48, 44, 50, 44, 51, 48, 48, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 117, 108, 116, 105,
  112, 108, 105, 101, 114, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48,
  44, 34, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 42, 32, 49,
  34, 44, 34, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 42, 32,
  53, 32, 76, 69, 78, 84, 32, 47, 32, 83, 76, 79, 87, 34, 44, 34,
  73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 32, 42, 32, 49, 48, 32,
  84, 82, 69, 83, 32, 76, 69, 78, 84, 32, 47, 32, 86, 69, 82, 89,
  32, 83, 76, 79, 87, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 73, 110, 99, 114, 101, 109, 101, 110, 116, 32, 116, 101, 109, 112, 115,
  32, 47, 32, 116, 105, 109, 101, 32, 105, 110, 99, 114, 101, 109, 101, 110,
  116, 32, 91, 42, 49, 48, 48, 48, 48, 93, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 52, 48, 48, 44, 49, 48, 44, 53, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65,
  109, 112, 108, 105, 116, 117, 100, 101, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108,
  105, 116, 117, 100, 101, 49, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53,
  48, 44, 48, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 50, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 53, 48, 44, 48, 44, 49, 48, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105,
  116, 117, 100, 101, 51, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 48,
  48, 44, 48, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 52, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 50, 48, 48, 44, 48, 44, 49, 48, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 70, 114, 92, 51, 48, 51, 92, 50, 53, 49, 113, 117, 101, 110,
  99, 101, 32, 47, 32, 70, 114, 101, 113, 117, 101, 110, 99, 121, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 70, 114, 101, 113, 117, 101, 110, 99, 101, 49, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 52, 44, 48, 44, 49, 54, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 70, 114, 101, 113, 117, 101, 110, 99, 101, 50,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 54, 44, 48, 44, 49, 54, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 114, 101, 113, 117, 101,
  110, 99, 101, 51, 32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48,
  44, 49, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 114,
  101, 113, 117, 101, 110, 99, 101, 52, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 50, 44, 48, 44, 49, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 80, 104, 97, 115, 101, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 80, 104, 97, 115, 101, 49, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 53, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 80, 104, 97, 115, 101, 50, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 50, 55, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 80, 104, 97, 115, 101, 51, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 55, 53, 44, 48, 44, 51, 54, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 104, 97, 115, 101, 52, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 54, 48, 44, 48, 44, 51, 54, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 109, 111, 114, 116, 105, 115, 115, 101, 109, 101, 110, 116, 32,
  47, 32, 68, 97, 109, 112, 105, 110, 103, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 111,
  114, 116, 49, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 48, 52,
  44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65,
  109, 111, 114, 116, 50, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  48, 52, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 65, 109, 111, 114, 116, 51, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 48, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 109, 111, 114, 116, 52, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 46, 48, 54, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 68, 105, 118, 101,
  114, 115, 32, 47, 32, 70, 111, 111, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 108, 111, 117,
  32, 47, 32, 98, 108, 117, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 112, 114, 101, 97, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 68, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 66, 108, 101,
  110, 100, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 49, 44, 34, 65, 100, 100, 34, 44, 34, 65, 108, 112,
  104, 97, 34, 44, 34, 65, 110, 100, 34, 44, 34, 65, 118, 101, 114, 97,
  103, 101, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 66, 117, 114, 110,
  34, 44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 68, 105, 102, 102,
  101, 114, 101, 110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 34, 68, 105, 118, 105, 100, 101, 34, 44, 34, 68, 111, 100, 103,
  101, 34, 44, 34, 69, 120, 99, 108, 117, 115, 105, 111, 110, 34, 44, 34,
  70, 114, 101, 101, 122, 101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 101,
  120, 116, 114, 97, 99, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 109,
  101, 114, 103, 101, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 72,
  97, 114, 100, 32, 108, 105, 103, 104, 116, 34, 44, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44,
  34, 72, 117, 101, 34, 44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97,
  116, 105, 111, 110, 34, 44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44,
  34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110,
  101, 97, 114, 32, 98, 117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97,
  114, 32, 108, 105, 103, 104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34,
  77, 117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 78, 101, 103, 97, 116,
  105, 111, 110, 34, 44, 34, 79, 114, 34, 44, 34, 79, 118, 101, 114, 108,
  97, 121, 34, 44, 34, 80, 105, 110, 32, 108, 105, 103, 104, 116, 34, 44,
  34, 82, 101, 100, 34, 44, 34, 82, 101, 102, 108, 101, 99, 116, 34, 44,
  34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 34, 83, 104, 97, 112, 101, 32, 65, 118,
  101, 114, 97, 103, 101, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118,
  101, 114, 97, 103, 101, 48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117,
  114, 110, 34, 44, 34, 83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34,
  44, 34, 83, 111, 102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83,
  99, 114, 101, 101, 110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34,
  83, 117, 98, 116, 114, 97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101,
  34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 86, 105, 118,
  105, 100, 32, 108, 105, 103, 104, 116, 34, 44, 34, 88, 111, 114, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116,
  121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116,
  32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 83, 97, 109, 106, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52,
  47, 48, 49, 47, 49, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 72, 97, 114, 109, 111, 110, 111, 103, 114, 97,
  112, 104, 95, 115, 97, 109, 106, 32, 58, 10, 99, 101, 110, 116, 114, 101,
  95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 61, 123, 36, 49, 47, 49,
  48, 48, 42, 119, 125, 10, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105,
  103, 105, 110, 101, 95, 89, 61, 123, 36, 50, 47, 49, 48, 48, 42, 104,
  125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108,
  111, 61, 36, 51, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83,
  116, 121, 108, 111, 61, 36, 52, 10, 66, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 83, 116, 121, 108, 111, 61, 36, 53, 10, 65, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 36, 54, 10, 86, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101,
  117, 114, 61, 36, 55, 10, 68, 105, 108, 97, 116, 101, 95, 83, 116, 121,
  108, 111, 61, 36, 56, 10, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115,
  61, 36, 57, 10, 77, 117, 108, 116, 105, 112, 108, 105, 101, 114, 95, 73,
  116, 101, 114, 97, 116, 105, 111, 110, 115, 61, 36, 49, 48, 10, 73, 110,
  99, 114, 101, 109, 101, 110, 116, 95, 116, 101, 109, 112, 115, 61, 36, 49,
  49, 10, 65, 109, 112, 108, 105, 116, 117, 100, 101, 49, 61, 36, 49, 50,
  10, 65, 109, 112, 108, 105, 116, 117, 100, 101, 50, 61, 36, 49, 51, 10,
  65, 109, 112, 108, 105, 116, 117, 100, 101, 51, 61, 36, 49, 52, 10, 65,
  109, 112, 108, 105, 116, 117, 100, 101, 52, 61, 36, 49, 53, 10, 70, 114,
  101, 113, 117, 101, 110, 99, 101, 49, 61, 36, 49, 54, 10, 70, 114, 101,
  113, 117, 101, 110, 99, 101, 50, 61, 36, 49, 55, 10, 70, 114, 101, 113,
  117, 101, 110, 99, 101, 51, 61, 36, 49, 56, 10, 70, 114, 101, 113, 117,
  101, 110, 99, 101, 52, 61, 36, 49, 57, 10, 80, 104, 97, 115, 101, 49,
  61, 36, 50, 48, 10, 80, 104, 97, 115, 101, 50, 61, 36, 50, 49, 10,
  80, 104, 97, 115, 101, 51, 61, 36, 50, 50, 10, 80, 104, 97, 115, 101,
  52, 61, 36, 50, 51, 10, 65, 109, 111, 114, 116, 49, 61, 36, 50, 52,
  10, 65, 109, 111, 114, 116, 50, 61, 36, 50, 53, 10, 65, 109, 111, 114,
  116, 51, 61, 36, 50, 54, 10, 65, 109, 111, 114, 116, 52, 61, 36, 50,
  55, 10, 70, 108, 111, 117, 95, 72, 97, 114, 109, 111, 110, 111, 103, 114,
  97, 112, 104, 61, 36, 50, 56, 10, 83, 112, 114, 101, 97, 100, 95, 72,
  97, 114, 109, 111, 110, 111, 103, 114, 97, 112, 104, 61, 36, 50, 57, 10,
  68, 101, 102, 111, 114, 109, 95, 72, 97, 114, 109, 111, 110, 111, 103, 114,
  97, 112, 104, 61, 36, 51, 48, 10, 98, 108, 101, 110, 100, 61, 36, 51,
  49, 10, 111, 112, 97, 99, 105, 116, 101, 61, 36, 51, 50, 10, 82, 101,
  118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 61, 36, 51, 51, 10,
  45, 116, 111, 95, 114, 103, 98, 97, 10, 123, 119, 125, 44, 123, 104, 125,
  44, 49, 44, 52, 10, 78, 98, 95, 66, 111, 117, 99, 108, 101, 61, 49,
  10, 116, 101, 109, 112, 115, 61, 48, 10, 65, 110, 99, 105, 101, 110, 95,
  112, 111, 105, 110, 116, 95, 88, 61, 48, 10, 78, 111, 117, 118, 101, 97,
  117, 95, 112, 111, 105, 110, 116, 95, 88, 61, 48, 10, 65, 110, 99, 105,
  101, 110, 95, 112, 111, 105, 110, 116, 95, 89, 61, 48, 10, 78, 111, 117,
  118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 89, 61, 48, 10, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101,
  61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108,
  111, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103,
  105, 110, 101, 61, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83,
  116, 121, 108, 111, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111,
  114, 105, 103, 105, 110, 101, 61, 36, 66, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 83, 116, 121, 108, 111, 10, 65, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 111, 114, 105, 103, 105, 110, 101, 61, 36, 65, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 10, 73, 110, 99, 114, 101,
  109, 101, 110, 116, 95, 116, 101, 109, 112, 115, 61, 123, 36, 73, 110, 99,
  114, 101, 109, 101, 110, 116, 95, 116, 101, 109, 112, 115, 47, 49, 48, 48,
  48, 48, 125, 10, 80, 104, 97, 115, 101, 49, 61, 123, 36, 80, 104, 97,
  115, 101, 49, 47, 49, 56, 48, 42, 123, 112, 105, 125, 125, 10, 80, 104,
  97, 115, 101, 50, 61, 123, 36, 80, 104, 97, 115, 101, 50, 47, 49, 56,
  48, 42, 123, 112, 105, 125, 125, 10, 80, 104, 97, 115, 101, 51, 61, 123,
  36, 80, 104, 97, 115, 101, 51, 47, 49, 56, 48, 42, 123, 112, 105, 125,
  125, 10, 80, 104, 97, 115, 101, 52, 61, 123, 36, 80, 104, 97, 115, 101,
  52, 47, 49, 56, 48, 42, 123, 112, 105, 125, 125, 10, 45, 105, 102, 32,
  123, 36, 77, 117, 108, 116, 105, 112, 108, 105, 101, 114, 95, 73, 116, 101,
  114, 97, 116, 105, 111, 110, 115, 62, 48, 125, 10, 73, 116, 101, 114, 97,
  116, 105, 111, 110, 115, 61, 123, 36, 73, 116, 101, 114, 97, 116, 105, 111,
  110, 115, 42, 36, 77, 117, 108, 116, 105, 112, 108, 105, 101, 114, 95, 73,
  116, 101, 114, 97, 116, 105, 111, 110, 115, 42, 53, 125, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 73, 116, 101,
  114, 97, 116, 105, 111, 110, 115, 10, 45, 105, 102, 32, 123, 36, 86, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101,
  117, 114, 61, 61, 49, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 83, 116, 121, 108, 111, 61, 123, 114, 111, 117, 110, 100, 40, 123, 40,
  63, 40, 50, 53, 53, 41, 41, 125, 41, 125, 10, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 123, 114, 111, 117, 110,
  100, 40, 123, 40, 63, 40, 50, 53, 53, 41, 41, 125, 41, 125, 10, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 123,
  114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 53, 53, 41, 41, 125,
  41, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117,
  108, 101, 117, 114, 62, 49, 125, 10, 86, 97, 108, 101, 117, 114, 95, 118,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114,
  61, 49, 54, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 61,
  51, 125, 10, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 61, 51, 50, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114,
  61, 61, 52, 125, 10, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 61, 54, 52,
  10, 45, 101, 110, 100, 105, 102, 10, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 83, 116, 121, 108, 111, 61, 123, 114, 111, 117, 110, 100, 40, 123,
  36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105,
  110, 101, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114,
  44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10,
  45, 105, 102, 32, 123, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  83, 116, 121, 108, 111, 62, 50, 53, 53, 125, 10, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 36, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 60, 48, 125, 10, 82, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 36, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101,
  10, 45, 101, 110, 100, 105, 102, 10, 86, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 83, 116, 121, 108, 111, 61, 123, 114, 111, 117, 110, 100, 40, 123,
  36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105,
  110, 101, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114,
  44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10,
  45, 105, 102, 32, 123, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  83, 116, 121, 108, 111, 62, 50, 53, 53, 125, 10, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 36, 86, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 60, 48, 125, 10, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 36, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101,
  10, 45, 101, 110, 100, 105, 102, 10, 66, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 83, 116, 121, 108, 111, 61, 123, 114, 111, 117, 110, 100, 40, 123,
  36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105,
  110, 101, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114,
  44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10,
  45, 105, 102, 32, 123, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  83, 116, 121, 108, 111, 62, 50, 53, 53, 125, 10, 66, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 36, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 66, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 60, 48, 125, 10, 66, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 36, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 78,
  111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 88, 61, 123,
  36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95,
  88, 43, 123, 123, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 49, 42,
  123, 115, 105, 110, 40, 123, 123, 36, 70, 114, 101, 113, 117, 101, 110, 99,
  101, 49, 42, 36, 116, 101, 109, 112, 115, 125, 43, 36, 80, 104, 97, 115,
  101, 49, 125, 41, 125, 42, 123, 101, 120, 112, 40, 123, 45, 36, 65, 109,
  111, 114, 116, 49, 42, 36, 116, 101, 109, 112, 115, 125, 41, 125, 125, 43,
  123, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 50, 42, 123, 115, 105,
  110, 40, 123, 123, 36, 70, 114, 101, 113, 117, 101, 110, 99, 101, 50, 42,
  36, 116, 101, 109, 112, 115, 125, 43, 36, 80, 104, 97, 115, 101, 50, 125,
  41, 125, 42, 123, 101, 120, 112, 40, 123, 45, 36, 65, 109, 111, 114, 116,
  50, 42, 36, 116, 101, 109, 112, 115, 125, 41, 125, 125, 125, 125, 10, 78,
  111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 89, 61, 123,
  36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95,
  89, 43, 123, 123, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 51, 42,
  123, 115, 105, 110, 40, 123, 123, 36, 70, 114, 101, 113, 117, 101, 110, 99,
  101, 51, 42, 36, 116, 101, 109, 112, 115, 125, 43, 36, 80, 104, 97, 115,
  101, 51, 125, 41, 125, 42, 123, 101, 120, 112, 40, 123, 45, 36, 65, 109,
  111, 114, 116, 51, 42, 36, 116, 101, 109, 112, 115, 125, 41, 125, 125, 43,
  123, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101, 52, 42, 123, 115, 105,
  110, 40, 123, 123, 36, 70, 114, 101, 113, 117, 101, 110, 99, 101, 52, 42,
  36, 116, 101, 109, 112, 115, 125, 43, 36, 80, 104, 97, 115, 101, 52, 125,
  41, 125, 42, 123, 101, 120, 112, 40, 123, 45, 36, 65, 109, 111, 114, 116,
  52, 42, 36, 116, 101, 109, 112, 115, 125, 41, 125, 125, 125, 125, 10, 45,
  105, 102, 32, 123, 36, 78, 98, 95, 66, 111, 117, 99, 108, 101, 62, 49,
  125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 65, 110, 99,
  105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 88, 44, 36, 65, 110, 99,
  105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 89, 44, 36, 78, 111, 117,
  118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 88, 44, 36, 78, 111,
  117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 89, 44, 49, 44,
  36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111,
  44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108,
  111, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121,
  108, 111, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116,
  121, 108, 111, 10, 45, 101, 110, 100, 105, 102, 10, 65, 110, 99, 105, 101,
  110, 95, 112, 111, 105, 110, 116, 95, 88, 61, 36, 78, 111, 117, 118, 101,
  97, 117, 95, 112, 111, 105, 110, 116, 95, 88, 10, 65, 110, 99, 105, 101,
  110, 95, 112, 111, 105, 110, 116, 95, 89, 61, 36, 78, 111, 117, 118, 101,
  97, 117, 95, 112, 111, 105, 110, 116, 95, 89, 10, 116, 101, 109, 112, 115,
  61, 123, 36, 116, 101, 109, 112, 115, 43, 36, 73, 110, 99, 114, 101, 109,
  101, 110, 116, 95, 116, 101, 109, 112, 115, 125, 10, 78, 98, 95, 66, 111,
  117, 99, 108, 101, 61, 123, 36, 78, 98, 95, 66, 111, 117, 99, 108, 101,
  43, 49, 125, 10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36,
  68, 105, 108, 97, 116, 101, 95, 83, 116, 121, 108, 111, 62, 48, 125, 32,
  45, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 91, 45, 49, 93,
  32, 36, 68, 105, 108, 97, 116, 101, 95, 83, 116, 121, 108, 111, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32,
  36, 70, 108, 111, 117, 95, 72, 97, 114, 109, 111, 110, 111, 103, 114, 97,
  112, 104, 10, 45, 115, 112, 114, 101, 97, 100, 91, 45, 49, 93, 32, 36,
  83, 112, 114, 101, 97, 100, 95, 72, 97, 114, 109, 111, 110, 111, 103, 114,
  97, 112, 104, 10, 45, 100, 101, 102, 111, 114, 109, 91, 45, 49, 93, 32,
  36, 68, 101, 102, 111, 114, 109, 95, 72, 97, 114, 109, 111, 110, 111, 103,
  114, 97, 112, 104, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100,
  91, 45, 49, 44, 45, 50, 93, 32, 36, 98, 108, 101, 110, 100, 44, 36,
  111, 112, 97, 99, 105, 116, 101, 44, 36, 82, 101, 118, 101, 114, 116, 95,
  108, 97, 121, 101, 114, 115, 10, 35, 10, 35, 45, 116, 101, 120, 116, 95,
  111, 117, 116, 108, 105, 110, 101, 91, 48, 93, 32, 36, 65, 109, 112, 108,
  105, 116, 117, 100, 101, 49, 44, 49, 48, 44, 49, 48, 44, 54, 52, 44,
  49, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10,
  35, 64, 103, 105, 109, 112, 32, 80, 105, 110, 116, 111, 103, 114, 97, 112,
  104, 32, 58, 32, 80, 105, 110, 116, 111, 103, 114, 97, 112, 104, 95, 115,
  97, 109, 106, 44, 32, 80, 105, 110, 116, 111, 103, 114, 97, 112, 104, 95,
  115, 97, 109, 106, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 104, 116,
  116, 112, 58, 47, 47, 101, 110, 46, 119, 105, 107, 105, 112, 101, 100, 105,
  97, 46, 111, 114, 103, 47, 119, 105, 107, 105, 47, 80, 105, 110, 116, 111,
  103, 114, 97, 112, 104, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 67, 101, 110, 116, 114, 101, 32, 47,
  32, 67, 101, 110, 116, 101, 114, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 101, 110, 116, 114,
  101, 32, 47, 32, 99, 101, 110, 116, 101, 114, 32, 120, 32, 40, 37, 41,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 101, 110, 116,
  114, 101, 32, 47, 32, 99, 101, 110, 116, 101, 114, 32, 121, 32, 40, 37,
  41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 80, 105, 110, 116, 111, 103, 114, 97, 112, 104, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 116, 121, 108, 111, 32, 47, 32, 112, 101, 110, 32, 40, 99,
  111, 117, 108, 101, 117, 114, 47, 99, 111, 108, 111, 114, 41, 32, 61, 32,
  99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 49, 50, 56, 44, 54, 52,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  116, 121, 108, 111, 32, 47, 32, 112, 101, 110, 32, 40, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 32, 100, 101, 32, 99, 111, 117, 108, 101, 117, 114,
  47, 99, 111, 108, 111, 114, 32, 118, 97, 114, 105, 97, 116, 105, 111, 110,
  41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 80, 97, 115, 32,
  100, 101, 32, 118, 97, 114, 105, 97, 116, 105, 111, 110, 32, 47, 32, 78,
  111, 32, 99, 104, 97, 110, 103, 101, 34, 44, 34, 67, 111, 117, 108, 101,
  117, 114, 115, 32, 97, 108, 101, 97, 116, 111, 105, 114, 101, 115, 32, 47,
  32, 82, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111, 114, 115, 34, 44,
  34, 70, 97, 105, 98, 108, 101, 109, 101, 110, 116, 32, 110, 117, 97, 110,
  99, 101, 101, 32, 47, 32, 80, 111, 111, 114, 108, 121, 32, 110, 117, 97,
  110, 99, 101, 100, 34, 44, 34, 77, 111, 121, 101, 110, 110, 101, 109, 101,
  110, 116, 32, 110, 117, 97, 110, 99, 101, 101, 32, 47, 32, 77, 111, 100,
  101, 114, 97, 116, 101, 108, 121, 32, 110, 117, 97, 110, 99, 101, 100, 34,
  44, 34, 70, 111, 114, 116, 101, 109, 101, 110, 116, 32, 110, 117, 97, 110,
  99, 101, 101, 32, 47, 32, 72, 105, 103, 104, 108, 121, 32, 110, 117, 97,
  110, 99, 101, 100, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 116, 121, 108, 111, 32, 47, 32, 112, 101, 110, 32, 40, 100, 105, 108,
  97, 116, 101, 32, 112, 105, 120, 101, 108, 115, 41, 32, 61, 32, 105, 110,
  116, 40, 48, 44, 48, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 73, 116, 92, 51, 48, 51, 92, 50, 53, 49, 114, 97, 116,
  105, 111, 110, 115, 32, 61, 32, 105, 110, 116, 40, 49, 48, 48, 48, 44,
  50, 44, 51, 48, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 77, 117, 108, 116, 105, 112, 108, 105, 101, 114, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 48, 44, 34, 73, 116, 101, 114, 97, 116, 105,
  111, 110, 115, 32, 42, 32, 49, 34, 44, 34, 73, 116, 101, 114, 97, 116,
  105, 111, 110, 115, 32, 42, 32, 53, 32, 76, 69, 78, 84, 32, 47, 32,
  83, 76, 79, 87, 34, 44, 34, 73, 116, 101, 114, 97, 116, 105, 111, 110,
  115, 32, 42, 32, 49, 48, 32, 84, 82, 69, 83, 32, 76, 69, 78, 84,
  32, 47, 32, 86, 69, 82, 89, 32, 83, 76, 79, 87, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 73, 110, 99, 114, 101, 109, 101, 110,
  116, 32, 116, 101, 109, 112, 115, 32, 47, 32, 116, 105, 109, 101, 32, 105,
  110, 99, 114, 101, 109, 101, 110, 116, 32, 91, 42, 49, 48, 48, 48, 48,
  93, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 48, 48, 44, 49, 48,
  44, 53, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 109, 112, 108, 105, 116, 117, 100, 101, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 49, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116,
  117, 100, 101, 50, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 53, 48,
  44, 48, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 51, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 48, 48, 44, 48, 44, 49, 48, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116,
  117, 100, 101, 52, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44,
  48, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 70, 114, 92, 51, 48, 51, 92, 50,
  53, 49, 113, 117, 101, 110, 99, 101, 32, 47, 32, 70, 114, 101, 113, 117,
  101, 110, 99, 121, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 70, 114, 101, 113, 117, 101, 110, 99,
  101, 49, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 46, 48, 48, 44,
  48, 44, 49, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70,
  114, 101, 113, 117, 101, 110, 99, 101, 50, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 52, 46, 48, 53, 44, 48, 44, 49, 54, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 70, 114, 101, 113, 117, 101, 110, 99, 101, 51,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 46, 49, 54, 44, 48, 44,
  49, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 114, 101,
  113, 117, 101, 110, 99, 101, 52, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  52, 46, 51, 50, 44, 48, 44, 49, 54, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 80, 104, 97, 115, 101,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 80, 104, 97, 115, 101, 49, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 55, 53, 44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 80, 104, 97, 115, 101, 50, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 49, 53, 48, 44, 48, 44, 51, 54, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 104, 97, 115, 101, 51, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 55, 53, 44, 48, 44, 51, 54, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 104, 97, 115, 101,
  52, 32, 61, 32, 102, 108, 111, 97, 116, 40, 54, 48, 44, 48, 44, 51,
  54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 68, 105, 118, 101, 114, 115, 32, 47, 32, 70, 111, 111,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 70, 108, 111, 117, 32, 47, 32, 98, 108, 117, 114, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 114, 101, 97, 100, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 102, 111, 114, 109, 97,
  116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 66, 108, 101, 110, 100, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111,
  100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 65,
  100, 100, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34, 65, 110, 100,
  34, 44, 34, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 66, 108, 117,
  101, 34, 44, 34, 66, 117, 114, 110, 34, 44, 34, 68, 97, 114, 107, 101,
  110, 34, 44, 34, 68, 105, 102, 102, 101, 114, 101, 110, 99, 101, 34, 44,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 68, 105, 118, 105, 100,
  101, 34, 44, 34, 68, 111, 100, 103, 101, 34, 44, 34, 69, 120, 99, 108,
  117, 115, 105, 111, 110, 34, 44, 34, 70, 114, 101, 101, 122, 101, 34, 44,
  34, 71, 114, 97, 105, 110, 32, 101, 120, 116, 114, 97, 99, 116, 34, 44,
  34, 71, 114, 97, 105, 110, 32, 109, 101, 114, 103, 101, 34, 44, 34, 71,
  114, 101, 101, 110, 34, 44, 34, 72, 97, 114, 100, 32, 108, 105, 103, 104,
  116, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 72, 97,
  114, 100, 32, 109, 105, 120, 34, 44, 34, 72, 117, 101, 34, 44, 34, 73,
  110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 34, 44, 34, 76,
  105, 103, 104, 116, 101, 110, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101,
  115, 115, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 98, 117, 114, 110,
  34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 108, 105, 103, 104, 116, 34,
  44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 34, 77, 117, 108, 116, 105, 112, 108, 121,
  34, 44, 34, 78, 101, 103, 97, 116, 105, 111, 110, 34, 44, 34, 79, 114,
  34, 44, 34, 79, 118, 101, 114, 108, 97, 121, 34, 44, 34, 80, 105, 110,
  32, 108, 105, 103, 104, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 82,
  101, 102, 108, 101, 99, 116, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116,
  105, 111, 110, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34,
  83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34,
  83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101, 48, 34, 44,
  34, 83, 111, 102, 116, 32, 98, 117, 114, 110, 34, 44, 34, 83, 111, 102,
  116, 32, 100, 111, 100, 103, 101, 34, 44, 34, 83, 111, 102, 116, 32, 108,
  105, 103, 104, 116, 34, 44, 34, 83, 99, 114, 101, 101, 110, 34, 44, 34,
  83, 116, 97, 109, 112, 34, 44, 34, 83, 117, 98, 116, 114, 97, 99, 116,
  34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 34, 86, 105, 118, 105, 100, 32, 108, 105, 103, 104, 116,
  34, 44, 34, 88, 111, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121, 101, 114, 115, 32,
  61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121,
  112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60,
  105, 62, 83, 97, 109, 106, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58,
  32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 49, 55, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 80, 105,
  110, 116, 111, 103, 114, 97, 112, 104, 95, 115, 97, 109, 106, 32, 58, 10,
  99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88,
  61, 123, 36, 49, 47, 49, 48, 48, 42, 119, 125, 10, 99, 101, 110, 116,
  114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 61, 123, 36, 50,
  47, 49, 48, 48, 42, 104, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 83, 116, 121, 108, 111, 61, 36, 51, 10, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 36, 52, 10, 66, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 36, 53,
  10, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111,
  61, 36, 54, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101,
  95, 99, 111, 117, 108, 101, 117, 114, 61, 36, 55, 10, 68, 105, 108, 97,
  116, 101, 95, 83, 116, 121, 108, 111, 61, 36, 56, 10, 73, 116, 101, 114,
  97, 116, 105, 111, 110, 115, 61, 36, 57, 10, 77, 117, 108, 116, 105, 112,
  108, 105, 101, 114, 95, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 61,
  36, 49, 48, 10, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 116, 101,
  109, 112, 115, 61, 36, 49, 49, 10, 65, 109, 112, 108, 105, 116, 117, 100,
  101, 49, 61, 36, 49, 50, 10, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  50, 61, 36, 49, 51, 10, 65, 109, 112, 108, 105, 116, 117, 100, 101, 51,
  61, 36, 49, 52, 10, 65, 109, 112, 108, 105, 116, 117, 100, 101, 52, 61,
  36, 49, 53, 10, 70, 114, 101, 113, 117, 101, 110, 99, 101, 49, 61, 36,
  49, 54, 10, 70, 114, 101, 113, 117, 101, 110, 99, 101, 50, 61, 36, 49,
  55, 10, 70, 114, 101, 113, 117, 101, 110, 99, 101, 51, 61, 36, 49, 56,
  10, 70, 114, 101, 113, 117, 101, 110, 99, 101, 52, 61, 36, 49, 57, 10,
  80, 104, 97, 115, 101, 49, 61, 36, 50, 48, 10, 80, 104, 97, 115, 101,
  50, 61, 36, 50, 49, 10, 80, 104, 97, 115, 101, 51, 61, 36, 50, 50,
  10, 80, 104, 97, 115, 101, 52, 61, 36, 50, 51, 10, 70, 108, 111, 117,
  95, 80, 105, 110, 116, 111, 103, 114, 97, 112, 104, 61, 36, 50, 52, 10,
  83, 112, 114, 101, 97, 100, 95, 80, 105, 110, 116, 111, 103, 114, 97, 112,
  104, 61, 36, 50, 53, 10, 68, 101, 102, 111, 114, 109, 95, 80, 105, 110,
  116, 111, 103, 114, 97, 112, 104, 61, 36, 50, 54, 10, 98, 108, 101, 110,
  100, 61, 36, 50, 55, 10, 111, 112, 97, 99, 105, 116, 101, 61, 36, 50,
  56, 10, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 61,
  36, 50, 57, 10, 45, 116, 111, 95, 114, 103, 98, 97, 10, 123, 119, 125,
  44, 123, 104, 125, 44, 49, 44, 52, 10, 78, 98, 95, 66, 111, 117, 99,
  108, 101, 61, 49, 10, 116, 101, 109, 112, 115, 61, 48, 10, 65, 110, 99,
  105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 88, 61, 48, 10, 78, 111,
  117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 88, 61, 48, 10,
  65, 110, 99, 105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 89, 61, 48,
  10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 89,
  61, 48, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105,
  103, 105, 110, 101, 61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  83, 116, 121, 108, 111, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  111, 114, 105, 103, 105, 110, 101, 61, 36, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 83, 116, 121, 108, 111, 10, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 61, 36, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 10, 65, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 61, 36, 65,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 10, 73,
  110, 99, 114, 101, 109, 101, 110, 116, 95, 116, 101, 109, 112, 115, 61, 123,
  36, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 116, 101, 109, 112, 115,
  47, 49, 48, 48, 48, 48, 125, 10, 80, 104, 97, 115, 101, 49, 61, 123,
  36, 80, 104, 97, 115, 101, 49, 47, 49, 56, 48, 42, 123, 112, 105, 125,
  125, 10, 80, 104, 97, 115, 101, 50, 61, 123, 36, 80, 104, 97, 115, 101,
  50, 47, 49, 56, 48, 42, 123, 112, 105, 125, 125, 10, 80, 104, 97, 115,
  101, 51, 61, 123, 36, 80, 104, 97, 115, 101, 51, 47, 49, 56, 48, 42,
  123, 112, 105, 125, 125, 10, 80, 104, 97, 115, 101, 52, 61, 123, 36, 80,
  104, 97, 115, 101, 52, 47, 49, 56, 48, 42, 123, 112, 105, 125, 125, 10,
  45, 105, 102, 32, 123, 36, 77, 117, 108, 116, 105, 112, 108, 105, 101, 114,
  95, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 62, 48, 125, 10, 73,
  116, 101, 114, 97, 116, 105, 111, 110, 115, 61, 123, 36, 73, 116, 101, 114,
  97, 116, 105, 111, 110, 115, 42, 36, 77, 117, 108, 116, 105, 112, 108, 105,
  101, 114, 95, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 42, 53, 125,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  36, 73, 116, 101, 114, 97, 116, 105, 111, 110, 115, 10, 45, 105, 102, 32,
  123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99,
  111, 117, 108, 101, 117, 114, 61, 61, 49, 125, 10, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 123, 114, 111, 117, 110,
  100, 40, 123, 40, 63, 40, 50, 53, 53, 41, 41, 125, 41, 125, 10, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 123,
  114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 53, 53, 41, 41, 125,
  41, 125, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121,
  108, 111, 61, 123, 114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 53,
  53, 41, 41, 125, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101,
  95, 99, 111, 117, 108, 101, 117, 114, 62, 49, 125, 10, 86, 97, 108, 101,
  117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117,
  108, 101, 117, 114, 61, 49, 54, 10, 45, 105, 102, 32, 123, 36, 86, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101,
  117, 114, 61, 61, 51, 125, 10, 86, 97, 108, 101, 117, 114, 95, 118, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 61,
  51, 50, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117,
  108, 101, 117, 114, 61, 61, 52, 125, 10, 86, 97, 108, 101, 117, 114, 95,
  118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117,
  114, 61, 54, 52, 10, 45, 101, 110, 100, 105, 102, 10, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 123, 114, 111, 117,
  110, 100, 40, 123, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111,
  114, 105, 103, 105, 110, 101, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101,
  117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117,
  108, 101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125,
  125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 83, 116, 121, 108, 111, 62, 50, 53, 53, 125, 10, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 36,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110,
  101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 60, 48,
  125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108,
  111, 61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105,
  103, 105, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 86, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 123, 114, 111, 117,
  110, 100, 40, 123, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111,
  114, 105, 103, 105, 110, 101, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101,
  117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117,
  108, 101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125,
  125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 83, 116, 121, 108, 111, 62, 50, 53, 53, 125, 10, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 36,
  86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110,
  101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 60, 48,
  125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108,
  111, 61, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105,
  103, 105, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 123, 114, 111, 117,
  110, 100, 40, 123, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111,
  114, 105, 103, 105, 110, 101, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101,
  117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117,
  108, 101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125,
  125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 66, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 83, 116, 121, 108, 111, 62, 50, 53, 53, 125, 10, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 36,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110,
  101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 60, 48,
  125, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108,
  111, 61, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105,
  103, 105, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  105, 102, 10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116,
  95, 88, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103,
  105, 110, 101, 95, 88, 43, 123, 123, 36, 65, 109, 112, 108, 105, 116, 117,
  100, 101, 49, 42, 123, 115, 105, 110, 40, 123, 123, 36, 70, 114, 101, 113,
  117, 101, 110, 99, 101, 49, 42, 36, 116, 101, 109, 112, 115, 125, 43, 36,
  80, 104, 97, 115, 101, 49, 125, 41, 125, 125, 43, 123, 36, 65, 109, 112,
  108, 105, 116, 117, 100, 101, 50, 42, 123, 115, 105, 110, 40, 123, 123, 36,
  70, 114, 101, 113, 117, 101, 110, 99, 101, 50, 42, 36, 116, 101, 109, 112,
  115, 125, 43, 36, 80, 104, 97, 115, 101, 50, 125, 41, 125, 125, 125, 125,
  10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 89,
  61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110,
  101, 95, 89, 43, 123, 123, 36, 65, 109, 112, 108, 105, 116, 117, 100, 101,
  51, 42, 123, 115, 105, 110, 40, 123, 123, 36, 70, 114, 101, 113, 117, 101,
  110, 99, 101, 51, 42, 36, 116, 101, 109, 112, 115, 125, 43, 36, 80, 104,
  97, 115, 101, 51, 125, 41, 125, 125, 43, 123, 36, 65, 109, 112, 108, 105,
  116, 117, 100, 101, 52, 42, 123, 115, 105, 110, 40, 123, 123, 36, 70, 114,
  101, 113, 117, 101, 110, 99, 101, 52, 42, 36, 116, 101, 109, 112, 115, 125,
  43, 36, 80, 104, 97, 115, 101, 52, 125, 41, 125, 125, 125, 125, 10, 45,
  105, 102, 32, 123, 36, 78, 98, 95, 66, 111, 117, 99, 108, 101, 62, 49,
  125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 65, 110, 99,
  105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 88, 44, 36, 65, 110, 99,
  105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 89, 44, 36, 78, 111, 117,
  118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 88, 44, 36, 78, 111,
  117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 89, 44, 49, 44,
  36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111,
  44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108,
  111, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121,
  108, 111, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116,
  121, 108, 111, 10, 45, 101, 110, 100, 105, 102, 10, 65, 110, 99, 105, 101,
  110, 95, 112, 111, 105, 110, 116, 95, 88, 61, 36, 78, 111, 117, 118, 101,
  97, 117, 95, 112, 111, 105, 110, 116, 95, 88, 10, 65, 110, 99, 105, 101,
  110, 95, 112, 111, 105, 110, 116, 95, 89, 61, 36, 78, 111, 117, 118, 101,
  97, 117, 95, 112, 111, 105, 110, 116, 95, 89, 10, 116, 101, 109, 112, 115,
  61, 123, 36, 116, 101, 109, 112, 115, 43, 36, 73, 110, 99, 114, 101, 109,
  101, 110, 116, 95, 116, 101, 109, 112, 115, 125, 10, 78, 98, 95, 66, 111,
  117, 99, 108, 101, 61, 123, 36, 78, 98, 95, 66, 111, 117, 99, 108, 101,
  43, 49, 125, 10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36,
  68, 105, 108, 97, 116, 101, 95, 83, 116, 121, 108, 111, 62, 48, 125, 32,
  45, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 91, 45, 49, 93,
  32, 36, 68, 105, 108, 97, 116, 101, 95, 83, 116, 121, 108, 111, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32,
  36, 70, 108, 111, 117, 95, 80, 105, 110, 116, 111, 103, 114, 97, 112, 104,
  10, 45, 115, 112, 114, 101, 97, 100, 91, 45, 49, 93, 32, 36, 83, 112,
  114, 101, 97, 100, 95, 80, 105, 110, 116, 111, 103, 114, 97, 112, 104, 10,
  45, 100, 101, 102, 111, 114, 109, 91, 45, 49, 93, 32, 36, 68, 101, 102,
  111, 114, 109, 95, 80, 105, 110, 116, 111, 103, 114, 97, 112, 104, 10, 45,
  103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50,
  93, 32, 36, 98, 108, 101, 110, 100, 44, 36, 111, 112, 97, 99, 105, 116,
  101, 44, 36, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115,
  10, 35, 64, 103, 105, 109, 112, 32, 82, 97, 121, 115, 32, 111, 102, 32,
  99, 111, 108, 111, 114, 115, 32, 58, 32, 115, 97, 109, 106, 95, 82, 97,
  121, 115, 95, 79, 102, 95, 67, 111, 108, 111, 114, 115, 44, 32, 115, 97,
  109, 106, 95, 82, 97, 121, 115, 95, 79, 102, 95, 67, 111, 108, 111, 114,
  115, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 111, 108, 111, 114, 32, 105, 110, 116, 101,
  110, 115, 105, 116, 121, 32, 61, 32, 105, 110, 116, 40, 51, 48, 48, 44,
  49, 44, 56, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 108, 111, 114, 32, 100, 101, 110, 115, 105, 116, 121, 32, 61, 32,
  105, 110, 116, 40, 56, 44, 50, 44, 50, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 82, 97, 100, 105, 117, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 52, 48, 44, 48, 44, 52, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 66, 111, 114, 100, 101, 114, 32, 115, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 54, 44, 48, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 66, 111, 114, 100, 101, 114, 32, 119, 105, 100, 116, 104,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 56, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 101, 114, 103,
  101, 32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101,
  119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97, 109, 106, 32, 45,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58,
  32, 60, 105, 62, 50, 48, 49, 51, 47, 49, 50, 47, 49, 49, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97,
  109, 106, 95, 82, 97, 121, 115, 95, 79, 102, 95, 67, 111, 108, 111, 114,
  115, 32, 58, 10, 67, 111, 108, 111, 114, 95, 73, 110, 116, 101, 110, 115,
  105, 116, 121, 61, 36, 49, 10, 67, 111, 108, 111, 114, 95, 68, 101, 110,
  115, 105, 116, 121, 61, 40, 36, 50, 47, 53, 49, 50, 42, 123, 119, 125,
  41, 10, 82, 97, 100, 105, 117, 115, 61, 36, 51, 10, 66, 111, 114, 100,
  101, 114, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 36, 52,
  10, 66, 111, 114, 100, 101, 114, 95, 119, 105, 100, 116, 104, 61, 36, 53,
  10, 77, 101, 114, 103, 101, 95, 76, 97, 121, 101, 114, 115, 61, 36, 54,
  10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36,
  62, 93, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116,
  104, 105, 110, 103, 10, 45, 116, 111, 95, 114, 103, 98, 91, 45, 49, 93,
  10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93,
  32, 48, 44, 48, 44, 48, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36,
  67, 111, 108, 111, 114, 95, 73, 110, 116, 101, 110, 115, 105, 116, 121, 10,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 86, 95, 67, 111,
  117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 50, 53, 53, 41, 41, 125, 10, 66, 95, 67, 111, 117, 108, 101, 117,
  114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53,
  41, 41, 125, 10, 88, 95, 112, 111, 105, 110, 116, 61, 123, 114, 111, 117,
  110, 100, 40, 63, 40, 48, 44, 123, 119, 125, 41, 41, 125, 10, 89, 95,
  112, 111, 105, 110, 116, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 123, 104, 125, 41, 41, 125, 10, 45, 112, 111, 108, 121, 103, 111, 110,
  91, 45, 49, 93, 32, 52, 44, 36, 88, 95, 112, 111, 105, 110, 116, 44,
  36, 89, 95, 112, 111, 105, 110, 116, 44, 36, 88, 95, 112, 111, 105, 110,
  116, 44, 123, 36, 89, 95, 112, 111, 105, 110, 116, 43, 36, 67, 111, 108,
  111, 114, 95, 68, 101, 110, 115, 105, 116, 121, 125, 44, 123, 36, 88, 95,
  112, 111, 105, 110, 116, 43, 36, 67, 111, 108, 111, 114, 95, 68, 101, 110,
  115, 105, 116, 121, 125, 44, 123, 36, 89, 95, 112, 111, 105, 110, 116, 43,
  36, 67, 111, 108, 111, 114, 95, 68, 101, 110, 115, 105, 116, 121, 125, 44,
  123, 36, 88, 95, 112, 111, 105, 110, 116, 43, 36, 67, 111, 108, 111, 114,
  95, 68, 101, 110, 115, 105, 116, 121, 125, 44, 36, 89, 95, 112, 111, 105,
  110, 116, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 44,
  36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 44, 50, 53, 53, 10, 45, 100, 111, 110, 101, 10,
  45, 103, 105, 109, 112, 95, 116, 101, 120, 116, 117, 114, 101, 100, 95, 103,
  108, 97, 115, 115, 91, 45, 49, 93, 32, 52, 48, 44, 52, 48, 44, 49,
  44, 49, 44, 48, 44, 50, 44, 48, 10, 45, 103, 105, 109, 112, 95, 109,
  97, 112, 95, 115, 112, 104, 101, 114, 101, 91, 45, 49, 93, 32, 123, 119,
  125, 44, 123, 104, 125, 44, 36, 82, 97, 100, 105, 117, 115, 44, 48, 46,
  53, 44, 48, 44, 36, 66, 111, 114, 100, 101, 114, 95, 115, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 44, 36, 66, 111, 114, 100, 101, 114, 95, 119,
  105, 100, 116, 104, 44, 48, 44, 48, 44, 49, 48, 48, 44, 51, 10, 35,
  35, 35, 35, 35, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114,
  91, 45, 50, 93, 32, 48, 44, 48, 44, 48, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 36, 67, 111, 108, 111, 114, 95, 73, 110, 116, 101, 110, 115,
  105, 116, 121, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114,
  111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10,
  86, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 50, 53, 53, 41, 41, 125, 10, 88, 95, 112, 111, 105, 110, 116, 61,
  123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 123, 119, 125, 41, 41,
  125, 10, 89, 95, 112, 111, 105, 110, 116, 61, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 48, 44, 123, 104, 125, 41, 41, 125, 10, 45, 112, 111, 108,
  121, 103, 111, 110, 91, 45, 50, 93, 32, 52, 44, 36, 88, 95, 112, 111,
  105, 110, 116, 44, 36, 89, 95, 112, 111, 105, 110, 116, 44, 36, 88, 95,
  112, 111, 105, 110, 116, 44, 123, 36, 89, 95, 112, 111, 105, 110, 116, 43,
  36, 67, 111, 108, 111, 114, 95, 68, 101, 110, 115, 105, 116, 121, 125, 44,
  123, 36, 88, 95, 112, 111, 105, 110, 116, 43, 36, 67, 111, 108, 111, 114,
  95, 68, 101, 110, 115, 105, 116, 121, 125, 44, 123, 36, 89, 95, 112, 111,
  105, 110, 116, 43, 36, 67, 111, 108, 111, 114, 95, 68, 101, 110, 115, 105,
  116, 121, 125, 44, 123, 36, 88, 95, 112, 111, 105, 110, 116, 43, 36, 67,
  111, 108, 111, 114, 95, 68, 101, 110, 115, 105, 116, 121, 125, 44, 36, 89,
  95, 112, 111, 105, 110, 116, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 44, 50, 53, 53, 10, 45, 100,
  111, 110, 101, 10, 45, 103, 105, 109, 112, 95, 116, 101, 120, 116, 117, 114,
  101, 100, 95, 103, 108, 97, 115, 115, 91, 45, 50, 93, 32, 52, 48, 44,
  52, 48, 44, 49, 44, 49, 44, 48, 44, 50, 44, 48, 10, 45, 103, 105,
  109, 112, 95, 109, 97, 112, 95, 115, 112, 104, 101, 114, 101, 91, 45, 50,
  93, 32, 123, 119, 125, 44, 123, 104, 125, 44, 36, 82, 97, 100, 105, 117,
  115, 44, 48, 46, 53, 44, 48, 44, 36, 66, 111, 114, 100, 101, 114, 95,
  115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 44, 36, 66, 111, 114, 100,
  101, 114, 95, 119, 105, 100, 116, 104, 44, 48, 44, 48, 44, 49, 48, 48,
  44, 51, 10, 45, 105, 102, 32, 123, 36, 77, 101, 114, 103, 101, 95, 76,
  97, 121, 101, 114, 115, 61, 61, 49, 125, 10, 45, 103, 105, 109, 112, 95,
  98, 108, 101, 110, 100, 91, 45, 50, 44, 45, 49, 93, 32, 48, 44, 49,
  44, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 115, 97, 109, 106, 95, 82, 97, 121, 115, 95,
  79, 102, 95, 67, 111, 108, 111, 114, 115, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 82,
  97, 121, 115, 95, 79, 102, 95, 67, 111, 108, 111, 114, 115, 32, 36, 42,
  34, 44, 36, 45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 83, 112, 97,
  114, 107, 108, 121, 32, 58, 32, 83, 112, 97, 114, 107, 108, 121, 95, 115,
  97, 109, 106, 44, 32, 83, 112, 97, 114, 107, 108, 121, 95, 115, 97, 109,
  106, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 82, 101, 110, 100, 117, 32,
  45, 32, 82, 101, 110, 100, 101, 114, 105, 110, 103, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 109, 98, 114, 101, 32, 92, 51, 48, 51, 92, 50, 53, 49, 98, 108,
  111, 117, 105, 115, 115, 101, 109, 101, 110, 116, 115, 32, 47, 32, 110, 117,
  109, 98, 101, 114, 32, 111, 102, 32, 102, 108, 97, 115, 104, 101, 115, 32,
  61, 32, 105, 110, 116, 40, 49, 48, 48, 44, 49, 44, 53, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 112, 97, 105, 115, 115,
  101, 117, 114, 32, 47, 32, 116, 104, 105, 99, 107, 110, 101, 115, 115, 32,
  40, 112, 105, 120, 101, 108, 115, 41, 32, 61, 32, 105, 110, 116, 40, 50,
  44, 49, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 117, 108, 101, 117, 114, 32, 47, 32, 99, 111, 108, 111, 114, 32,
  61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 111, 117, 108, 101, 117, 114, 115, 32, 97, 108, 92, 51, 48,
  51, 92, 50, 53, 49, 97, 116, 111, 105, 114, 101, 115, 32, 47, 32, 114,
  97, 110, 100, 111, 109, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 78, 111, 110, 32, 47, 32, 78, 111, 34,
  44, 34, 82, 86, 66, 32, 47, 32, 82, 71, 66, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 77, 111, 100, 101, 32, 97, 108, 101, 97,
  116, 111, 105, 114, 101, 32, 47, 32, 114, 97, 110, 100, 111, 109, 32, 109,
  111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34,
  77, 111, 100, 101, 32, 49, 34, 44, 34, 77, 111, 100, 101, 32, 50, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 80, 97, 114, 97, 109, 92, 51, 48, 51, 92, 50, 53, 48, 116,
  114, 101, 115, 32, 70, 105, 108, 116, 114, 101, 32, 87, 105, 110, 100, 32,
  45, 32, 87, 105, 110, 100, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114,
  115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 65, 109, 112, 108, 105, 116, 117, 100, 101, 32, 61,
  32, 105, 110, 116, 40, 56, 48, 44, 48, 44, 53, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 51, 54, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 65, 116, 116, 101, 110, 117, 97, 116,
  105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 44,
  48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104,
  114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  50, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 80, 97, 114, 97, 109, 92,
  51, 48, 51, 92, 50, 53, 48, 116, 114, 101, 115, 32, 70, 105, 108, 116,
  114, 101, 32, 66, 108, 117, 114, 32, 45, 32, 66, 108, 117, 114, 32, 112,
  97, 114, 97, 109, 101, 116, 101, 114, 115, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 108, 111,
  117, 32, 47, 32, 98, 108, 117, 114, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 46, 50, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 80, 97, 114, 97, 109,
  92, 51, 48, 51, 92, 50, 53, 48, 116, 114, 101, 115, 32, 70, 105, 108,
  116, 114, 101, 32, 83, 112, 114, 101, 97, 100, 32, 45, 32, 83, 112, 114,
  101, 97, 100, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 45, 118, 97, 114, 105, 97, 116, 105, 111, 110, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 53, 48, 44, 53, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 45, 53, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66,
  65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108,
  117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97,
  98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44,
  34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97,
  108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 65, 108, 112, 104,
  97, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34,
  82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108,
  117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 56, 32, 114,
  97, 121, 111, 110, 115, 32, 45, 32, 56, 32, 114, 97, 121, 115, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 84, 121, 112, 101, 32, 56, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 78, 111, 110, 32, 47, 32, 78, 111, 34, 44, 34, 49, 48,
  37, 34, 44, 34, 50, 48, 37, 34, 44, 34, 51, 48, 37, 34, 44, 34,
  52, 48, 37, 34, 44, 34, 53, 48, 37, 34, 44, 34, 54, 48, 37, 34,
  44, 34, 55, 48, 37, 34, 44, 34, 56, 48, 37, 34, 44, 34, 57, 48,
  37, 34, 44, 34, 49, 48, 48, 37, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 80, 97, 114, 97, 109,
  92, 51, 48, 51, 92, 50, 53, 48, 116, 114, 101, 115, 32, 70, 105, 108,
  116, 114, 101, 32, 73, 115, 111, 112, 104, 111, 116, 101, 115, 32, 45, 32,
  73, 115, 111, 112, 104, 111, 116, 101, 115, 32, 112, 97, 114, 97, 109, 101,
  116, 101, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 76, 101, 118, 101, 108, 115, 32, 61,
  32, 105, 110, 116, 40, 51, 44, 51, 44, 50, 53, 54, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 80, 97,
  114, 97, 109, 92, 51, 48, 51, 92, 50, 53, 48, 116, 114, 101, 115, 32,
  70, 105, 108, 116, 114, 101, 32, 78, 111, 105, 115, 101, 32, 72, 117, 114,
  108, 32, 45, 32, 78, 111, 105, 115, 101, 32, 72, 117, 114, 108, 32, 112,
  97, 114, 97, 109, 101, 116, 101, 114, 115, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112,
  108, 105, 116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 46, 48, 48, 44, 49, 48, 46, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 66, 108, 101,
  110, 100, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 49, 44, 34, 65, 100, 100, 34, 44, 34, 65, 108, 112,
  104, 97, 34, 44, 34, 65, 110, 100, 34, 44, 34, 65, 118, 101, 114, 97,
  103, 101, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 66, 117, 114, 110,
  34, 44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 68, 105, 102, 102,
  101, 114, 101, 110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 34, 68, 105, 118, 105, 100, 101, 34, 44, 34, 68, 111, 100, 103,
  101, 34, 44, 34, 69, 120, 99, 108, 117, 115, 105, 111, 110, 34, 44, 34,
  70, 114, 101, 101, 122, 101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 101,
  120, 116, 114, 97, 99, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 109,
  101, 114, 103, 101, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 72,
  97, 114, 100, 32, 108, 105, 103, 104, 116, 34, 44, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44,
  34, 72, 117, 101, 34, 44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97,
  116, 105, 111, 110, 34, 44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44,
  34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110,
  101, 97, 114, 32, 98, 117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97,
  114, 32, 108, 105, 103, 104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34,
  77, 117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 78, 101, 103, 97, 116,
  105, 111, 110, 34, 44, 34, 79, 114, 34, 44, 34, 79, 118, 101, 114, 108,
  97, 121, 34, 44, 34, 80, 105, 110, 32, 108, 105, 103, 104, 116, 34, 44,
  34, 82, 101, 100, 34, 44, 34, 82, 101, 102, 108, 101, 99, 116, 34, 44,
  34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 34, 83, 104, 97, 112, 101, 32, 65, 118,
  101, 114, 97, 103, 101, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118,
  101, 114, 97, 103, 101, 48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117,
  114, 110, 34, 44, 34, 83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34,
  44, 34, 83, 111, 102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83,
  99, 114, 101, 101, 110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34,
  83, 117, 98, 116, 114, 97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101,
  34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 86, 105, 118,
  105, 100, 32, 108, 105, 103, 104, 116, 34, 44, 34, 88, 111, 114, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116,
  121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116,
  32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 101, 117, 114, 115, 32, 47, 32, 65, 117, 116, 104, 111, 114, 115, 32,
  58, 32, 60, 105, 62, 83, 97, 109, 106, 60, 47, 105, 62, 46, 32, 32,
  32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116,
  101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 51, 47, 48, 49, 47, 50,
  53, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 83, 112, 97, 114, 107, 108, 121, 95, 115, 97, 109, 106, 32, 58, 10,
  110, 111, 109, 98, 114, 101, 95, 101, 98, 108, 111, 117, 105, 115, 115, 101,
  109, 101, 110, 116, 115, 61, 36, 49, 10, 100, 105, 109, 95, 99, 101, 110,
  116, 114, 101, 61, 36, 50, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114,
  61, 36, 51, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 52,
  10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 53, 10, 84, 114,
  97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 95, 100, 101, 115, 95, 99,
  111, 117, 108, 101, 117, 114, 115, 61, 36, 54, 10, 67, 111, 117, 108, 101,
  117, 114, 115, 95, 97, 108, 101, 97, 116, 111, 105, 114, 101, 115, 61, 36,
  55, 10, 77, 111, 100, 101, 95, 97, 108, 101, 97, 116, 111, 105, 114, 101,
  61, 36, 56, 10, 97, 109, 112, 108, 105, 116, 117, 100, 101, 95, 119, 105,
  110, 100, 61, 36, 57, 10, 97, 110, 103, 108, 101, 95, 119, 105, 110, 100,
  61, 36, 49, 48, 10, 97, 116, 116, 101, 110, 117, 97, 116, 105, 111, 110,
  95, 119, 105, 110, 100, 61, 36, 49, 49, 10, 116, 104, 114, 101, 115, 104,
  111, 108, 100, 95, 119, 105, 110, 100, 61, 36, 49, 50, 10, 118, 97, 108,
  101, 117, 114, 95, 98, 108, 117, 114, 61, 36, 49, 51, 10, 35, 103, 105,
  109, 112, 95, 115, 112, 114, 101, 97, 100, 10, 88, 95, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 115, 61, 36, 49, 52, 10, 89, 95, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 115, 61, 36, 49, 53, 10, 67, 104, 97, 110,
  110, 101, 108, 95, 115, 112, 114, 101, 97, 100, 61, 36, 49, 54, 10, 84,
  121, 112, 101, 95, 104, 117, 105, 116, 95, 98, 114, 97, 115, 61, 36, 49,
  55, 10, 76, 101, 118, 101, 108, 115, 95, 105, 115, 111, 112, 104, 111, 116,
  101, 115, 61, 36, 49, 56, 10, 78, 111, 105, 115, 101, 95, 72, 117, 114,
  108, 61, 36, 49, 57, 10, 98, 108, 101, 110, 100, 61, 36, 50, 48, 10,
  111, 112, 97, 99, 105, 116, 101, 61, 36, 50, 49, 10, 82, 101, 118, 101,
  114, 116, 95, 108, 97, 121, 101, 114, 115, 61, 36, 50, 50, 10, 108, 97,
  114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 61, 123, 119,
  125, 10, 104, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110,
  101, 61, 123, 104, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 116, 101, 109, 112, 115, 49, 61, 64,
  124, 10, 36, 108, 97, 114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105,
  110, 101, 44, 36, 104, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103,
  105, 110, 101, 44, 49, 44, 52, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  36, 110, 111, 109, 98, 114, 101, 95, 101, 98, 108, 111, 117, 105, 115, 115,
  101, 109, 101, 110, 116, 115, 10, 45, 105, 102, 32, 123, 36, 67, 111, 117,
  108, 101, 117, 114, 115, 95, 97, 108, 101, 97, 116, 111, 105, 114, 101, 115,
  61, 61, 49, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123,
  114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125,
  10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110,
  100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40,
  48, 44, 50, 53, 53, 41, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 77, 111, 100, 101, 95, 97, 108, 101, 97, 116,
  111, 105, 114, 101, 61, 61, 49, 125, 10, 88, 95, 112, 111, 105, 110, 116,
  61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 36, 108, 97, 114,
  103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 41, 41, 125, 10,
  89, 95, 112, 111, 105, 110, 116, 61, 123, 114, 111, 117, 110, 100, 40, 63,
  40, 48, 44, 36, 104, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103,
  105, 110, 101, 41, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 77, 111, 100, 101, 95, 97, 108, 101, 97, 116, 111, 105,
  114, 101, 61, 61, 48, 125, 10, 116, 101, 109, 112, 115, 50, 61, 64, 124,
  10, 97, 108, 101, 97, 61, 123, 123, 97, 98, 115, 40, 103, 41, 125, 43,
  49, 43, 123, 123, 123, 36, 116, 101, 109, 112, 115, 50, 45, 36, 116, 101,
  109, 112, 115, 49, 125, 43, 63, 40, 48, 44, 49, 41, 125, 42, 49, 48,
  125, 125, 10, 45, 100, 111, 10, 97, 108, 101, 97, 61, 123, 36, 97, 108,
  101, 97, 45, 49, 125, 10, 45, 119, 104, 105, 108, 101, 32, 123, 36, 97,
  108, 101, 97, 62, 49, 125, 10, 88, 95, 112, 111, 105, 110, 116, 61, 123,
  114, 111, 117, 110, 100, 40, 123, 36, 108, 97, 114, 103, 101, 117, 114, 95,
  111, 114, 105, 103, 105, 110, 101, 42, 36, 97, 108, 101, 97, 125, 41, 125,
  10, 116, 101, 109, 112, 115, 51, 61, 64, 124, 10, 97, 108, 101, 97, 61,
  123, 123, 97, 98, 115, 40, 103, 41, 125, 43, 49, 43, 123, 123, 123, 36,
  116, 101, 109, 112, 115, 51, 45, 36, 116, 101, 109, 112, 115, 49, 125, 43,
  63, 40, 48, 44, 49, 41, 125, 42, 49, 48, 125, 125, 10, 45, 100, 111,
  10, 97, 108, 101, 97, 61, 123, 36, 97, 108, 101, 97, 45, 49, 125, 10,
  45, 119, 104, 105, 108, 101, 32, 123, 36, 97, 108, 101, 97, 62, 49, 125,
  10, 89, 95, 112, 111, 105, 110, 116, 61, 123, 114, 111, 117, 110, 100, 40,
  123, 36, 104, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110,
  101, 42, 36, 97, 108, 101, 97, 125, 41, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 52,
  44, 36, 88, 95, 112, 111, 105, 110, 116, 44, 36, 89, 95, 112, 111, 105,
  110, 116, 44, 36, 88, 95, 112, 111, 105, 110, 116, 44, 123, 36, 89, 95,
  112, 111, 105, 110, 116, 43, 36, 100, 105, 109, 95, 99, 101, 110, 116, 114,
  101, 125, 44, 123, 36, 88, 95, 112, 111, 105, 110, 116, 43, 36, 100, 105,
  109, 95, 99, 101, 110, 116, 114, 101, 125, 44, 123, 36, 89, 95, 112, 111,
  105, 110, 116, 43, 36, 100, 105, 109, 95, 99, 101, 110, 116, 114, 101, 125,
  44, 123, 36, 88, 95, 112, 111, 105, 110, 116, 43, 36, 100, 105, 109, 95,
  99, 101, 110, 116, 114, 101, 125, 44, 36, 89, 95, 112, 111, 105, 110, 116,
  44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117, 108,
  101, 117, 114, 44, 36, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99,
  101, 95, 100, 101, 115, 95, 99, 111, 117, 108, 101, 117, 114, 115, 10, 45,
  100, 111, 110, 101, 10, 45, 45, 119, 105, 110, 100, 91, 45, 49, 93, 32,
  36, 97, 109, 112, 108, 105, 116, 117, 100, 101, 95, 119, 105, 110, 100, 44,
  36, 97, 110, 103, 108, 101, 95, 119, 105, 110, 100, 44, 36, 97, 116, 116,
  101, 110, 117, 97, 116, 105, 111, 110, 95, 119, 105, 110, 100, 44, 36, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 95, 119, 105, 110, 100, 10, 97, 110,
  103, 108, 101, 95, 119, 105, 110, 100, 61, 123, 36, 97, 110, 103, 108, 101,
  95, 119, 105, 110, 100, 43, 57, 48, 125, 10, 45, 45, 119, 105, 110, 100,
  91, 45, 50, 93, 32, 36, 97, 109, 112, 108, 105, 116, 117, 100, 101, 95,
  119, 105, 110, 100, 44, 36, 97, 110, 103, 108, 101, 95, 119, 105, 110, 100,
  44, 36, 97, 116, 116, 101, 110, 117, 97, 116, 105, 111, 110, 95, 119, 105,
  110, 100, 44, 36, 116, 104, 114, 101, 115, 104, 111, 108, 100, 95, 119, 105,
  110, 100, 10, 45, 97, 100, 100, 91, 45, 49, 44, 45, 50, 93, 10, 97,
  110, 103, 108, 101, 95, 119, 105, 110, 100, 61, 123, 36, 97, 110, 103, 108,
  101, 95, 119, 105, 110, 100, 43, 57, 48, 125, 10, 45, 45, 119, 105, 110,
  100, 91, 45, 50, 93, 32, 36, 97, 109, 112, 108, 105, 116, 117, 100, 101,
  95, 119, 105, 110, 100, 44, 36, 97, 110, 103, 108, 101, 95, 119, 105, 110,
  100, 44, 36, 97, 116, 116, 101, 110, 117, 97, 116, 105, 111, 110, 95, 119,
  105, 110, 100, 44, 36, 116, 104, 114, 101, 115, 104, 111, 108, 100, 95, 119,
  105, 110, 100, 10, 45, 97, 100, 100, 91, 45, 49, 44, 45, 50, 93, 10,
  97, 110, 103, 108, 101, 95, 119, 105, 110, 100, 61, 123, 36, 97, 110, 103,
  108, 101, 95, 119, 105, 110, 100, 43, 57, 48, 125, 10, 45, 45, 119, 105,
  110, 100, 91, 45, 50, 93, 32, 36, 97, 109, 112, 108, 105, 116, 117, 100,
  101, 95, 119, 105, 110, 100, 44, 36, 97, 110, 103, 108, 101, 95, 119, 105,
  110, 100, 44, 36, 97, 116, 116, 101, 110, 117, 97, 116, 105, 111, 110, 95,
  119, 105, 110, 100, 44, 36, 116, 104, 114, 101, 115, 104, 111, 108, 100, 95,
  119, 105, 110, 100, 10, 45, 97, 100, 100, 91, 45, 49, 44, 45, 50, 93,
  10, 45, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95, 104, 117, 105, 116,
  95, 98, 114, 97, 115, 62, 48, 125, 10, 97, 110, 103, 108, 101, 95, 119,
  105, 110, 100, 61, 123, 36, 97, 110, 103, 108, 101, 95, 119, 105, 110, 100,
  43, 52, 53, 125, 10, 45, 45, 119, 105, 110, 100, 91, 45, 50, 93, 32,
  123, 114, 111, 117, 110, 100, 40, 123, 123, 36, 97, 109, 112, 108, 105, 116,
  117, 100, 101, 95, 119, 105, 110, 100, 42, 36, 84, 121, 112, 101, 95, 104,
  117, 105, 116, 95, 98, 114, 97, 115, 125, 47, 49, 48, 125, 41, 125, 44,
  36, 97, 110, 103, 108, 101, 95, 119, 105, 110, 100, 44, 36, 97, 116, 116,
  101, 110, 117, 97, 116, 105, 111, 110, 95, 119, 105, 110, 100, 44, 36, 116,
  104, 114, 101, 115, 104, 111, 108, 100, 95, 119, 105, 110, 100, 10, 45, 97,
  100, 100, 91, 45, 49, 44, 45, 50, 93, 10, 97, 110, 103, 108, 101, 95,
  119, 105, 110, 100, 61, 123, 36, 97, 110, 103, 108, 101, 95, 119, 105, 110,
  100, 43, 57, 48, 125, 10, 45, 45, 119, 105, 110, 100, 91, 45, 50, 93,
  32, 123, 114, 111, 117, 110, 100, 40, 123, 123, 36, 97, 109, 112, 108, 105,
  116, 117, 100, 101, 95, 119, 105, 110, 100, 42, 36, 84, 121, 112, 101, 95,
  104, 117, 105, 116, 95, 98, 114, 97, 115, 125, 47, 49, 48, 125, 41, 125,
  44, 36, 97, 110, 103, 108, 101, 95, 119, 105, 110, 100, 44, 36, 97, 116,
  116, 101, 110, 117, 97, 116, 105, 111, 110, 95, 119, 105, 110, 100, 44, 36,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 95, 119, 105, 110, 100, 10, 45,
  97, 100, 100, 91, 45, 49, 44, 45, 50, 93, 10, 97, 110, 103, 108, 101,
  95, 119, 105, 110, 100, 61, 123, 36, 97, 110, 103, 108, 101, 95, 119, 105,
  110, 100, 43, 57, 48, 125, 10, 45, 45, 119, 105, 110, 100, 91, 45, 50,
  93, 32, 123, 114, 111, 117, 110, 100, 40, 123, 123, 36, 97, 109, 112, 108,
  105, 116, 117, 100, 101, 95, 119, 105, 110, 100, 42, 36, 84, 121, 112, 101,
  95, 104, 117, 105, 116, 95, 98, 114, 97, 115, 125, 47, 49, 48, 125, 41,
  125, 44, 36, 97, 110, 103, 108, 101, 95, 119, 105, 110, 100, 44, 36, 97,
  116, 116, 101, 110, 117, 97, 116, 105, 111, 110, 95, 119, 105, 110, 100, 44,
  36, 116, 104, 114, 101, 115, 104, 111, 108, 100, 95, 119, 105, 110, 100, 10,
  45, 97, 100, 100, 91, 45, 49, 44, 45, 50, 93, 10, 97, 110, 103, 108,
  101, 95, 119, 105, 110, 100, 61, 123, 36, 97, 110, 103, 108, 101, 95, 119,
  105, 110, 100, 43, 57, 48, 125, 10, 45, 45, 119, 105, 110, 100, 91, 45,
  50, 93, 32, 123, 114, 111, 117, 110, 100, 40, 123, 123, 36, 97, 109, 112,
  108, 105, 116, 117, 100, 101, 95, 119, 105, 110, 100, 42, 36, 84, 121, 112,
  101, 95, 104, 117, 105, 116, 95, 98, 114, 97, 115, 125, 47, 49, 48, 125,
  41, 125, 44, 36, 97, 110, 103, 108, 101, 95, 119, 105, 110, 100, 44, 36,
  97, 116, 116, 101, 110, 117, 97, 116, 105, 111, 110, 95, 119, 105, 110, 100,
  44, 36, 116, 104, 114, 101, 115, 104, 111, 108, 100, 95, 119, 105, 110, 100,
  10, 45, 97, 100, 100, 91, 45, 49, 44, 45, 50, 93, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 103, 105, 109, 112, 95, 115, 112, 114, 101, 97, 100,
  91, 45, 50, 93, 32, 36, 88, 95, 118, 97, 114, 105, 97, 116, 105, 111,
  110, 115, 44, 36, 89, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 115,
  44, 36, 67, 104, 97, 110, 110, 101, 108, 95, 115, 112, 114, 101, 97, 100,
  10, 45, 97, 100, 100, 91, 45, 49, 44, 45, 50, 93, 10, 45, 98, 108,
  117, 114, 91, 45, 49, 93, 32, 36, 118, 97, 108, 101, 117, 114, 95, 98,
  108, 117, 114, 10, 45, 105, 102, 32, 123, 36, 76, 101, 118, 101, 108, 115,
  95, 105, 115, 111, 112, 104, 111, 116, 101, 115, 62, 51, 125, 10, 45, 105,
  115, 111, 112, 104, 111, 116, 101, 115, 91, 45, 49, 93, 32, 36, 49, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 78, 111, 105,
  115, 101, 95, 72, 117, 114, 108, 62, 48, 125, 10, 45, 110, 111, 105, 115,
  101, 95, 104, 117, 114, 108, 91, 45, 49, 93, 32, 36, 78, 111, 105, 115,
  101, 95, 72, 117, 114, 108, 10, 45, 101, 110, 100, 105, 102, 10, 45, 103,
  105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93,
  32, 36, 98, 108, 101, 110, 100, 44, 36, 111, 112, 97, 99, 105, 116, 101,
  44, 36, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 83, 112, 97, 114,
  107, 108, 121, 95, 115, 97, 109, 106, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 34, 45, 83, 112, 97, 114, 107, 108, 121,
  95, 115, 97, 109, 106, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36,
  45, 49, 10, 35, 64, 103, 105, 109, 112, 32, 83, 112, 105, 114, 97, 108,
  101, 32, 49, 32, 45, 32, 115, 112, 105, 114, 97, 108, 32, 49, 32, 58,
  32, 115, 97, 109, 106, 95, 115, 112, 105, 95, 103, 105, 109, 112, 44, 32,
  115, 97, 109, 106, 95, 115, 112, 105, 95, 103, 105, 109, 112, 95, 112, 114,
  101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 83, 112, 105, 114, 97, 108, 101, 32, 47, 32,
  83, 112, 105, 114, 97, 108, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 101, 110, 116, 114, 101,
  32, 47, 32, 99, 101, 110, 116, 101, 114, 32, 120, 32, 40, 37, 41, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 101, 110, 116, 114,
  101, 32, 47, 32, 99, 101, 110, 116, 101, 114, 32, 121, 32, 40, 37, 41,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 111, 117, 114,
  115, 32, 47, 32, 116, 117, 114, 110, 115, 32, 61, 32, 105, 110, 116, 40,
  49, 48, 44, 49, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 73, 110, 99, 114, 101, 109, 101, 110, 116, 32, 97, 110, 103,
  117, 108, 97, 105, 114, 101, 32, 47, 32, 97, 110, 103, 117, 108, 97, 114,
  32, 105, 110, 99, 114, 101, 109, 101, 110, 116, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 54, 44, 48, 46, 53, 44, 51, 53, 57, 46, 57, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 101, 102, 102, 46, 32,
  97, 103, 114, 97, 110, 100, 105, 115, 115, 101, 109, 101, 110, 116, 32, 47,
  32, 101, 120, 112, 97, 110, 115, 105, 111, 110, 32, 99, 111, 101, 102, 102,
  105, 99, 105, 101, 110, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  46, 48, 53, 44, 48, 46, 48, 50, 44, 50, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 84, 121, 112, 101, 32, 100, 101, 32, 114, 101, 110,
  100, 117, 32, 47, 32, 114, 101, 110, 100, 101, 114, 105, 110, 103, 32, 116,
  121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 80, 111,
  105, 110, 116, 115, 34, 44, 34, 67, 101, 114, 99, 108, 101, 115, 32, 47,
  32, 67, 105, 114, 99, 108, 101, 115, 34, 44, 34, 80, 111, 108, 121, 103,
  111, 110, 101, 115, 32, 99, 111, 117, 108, 101, 117, 114, 115, 32, 97, 108,
  101, 97, 116, 111, 105, 114, 101, 115, 32, 47, 32, 80, 111, 108, 121, 103,
  111, 110, 115, 32, 114, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111, 114,
  115, 34, 44, 34, 76, 105, 103, 110, 101, 115, 32, 99, 111, 117, 108, 101,
  117, 114, 115, 32, 97, 108, 101, 97, 116, 111, 105, 114, 101, 115, 32, 47,
  32, 76, 105, 110, 101, 115, 32, 114, 97, 110, 100, 111, 109, 32, 99, 111,
  108, 111, 114, 115, 34, 44, 34, 83, 101, 103, 109, 101, 110, 116, 115, 32,
  99, 111, 117, 108, 101, 117, 114, 115, 32, 97, 108, 101, 97, 116, 111, 105,
  114, 101, 115, 32, 47, 32, 83, 101, 103, 109, 101, 110, 116, 115, 32, 114,
  97, 110, 100, 111, 109, 32, 99, 111, 108, 111, 114, 115, 34, 44, 34, 76,
  105, 103, 110, 101, 115, 32, 99, 111, 117, 108, 101, 117, 114, 32, 47, 32,
  76, 105, 110, 101, 115, 32, 99, 111, 108, 111, 114, 34, 44, 34, 83, 101,
  103, 109, 101, 110, 116, 115, 32, 99, 111, 117, 108, 101, 117, 114, 32, 47,
  32, 83, 101, 103, 109, 101, 110, 116, 115, 32, 99, 111, 108, 111, 114, 34,
  44, 34, 80, 111, 108, 121, 103, 111, 110, 101, 115, 32, 50, 32, 99, 111,
  117, 108, 101, 117, 114, 115, 32, 47, 32, 80, 111, 108, 121, 103, 111, 110,
  115, 32, 50, 32, 99, 111, 108, 111, 114, 115, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 105, 109, 101, 110, 115, 105, 111, 110, 32,
  114, 101, 110, 100, 117, 32, 47, 32, 100, 105, 109, 101, 110, 115, 105, 111,
  110, 97, 108, 32, 114, 101, 110, 100, 101, 114, 105, 110, 103, 32, 61, 32,
  105, 110, 116, 40, 50, 44, 48, 44, 51, 50, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 47, 32, 99,
  111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53,
  44, 50, 53, 53, 44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 110, 115, 32, 100, 101, 32, 114, 111, 116, 97, 116, 105, 111,
  110, 32, 47, 32, 100, 105, 114, 101, 99, 116, 105, 111, 110, 32, 111, 102,
  32, 114, 111, 116, 97, 116, 105, 111, 110, 32, 61, 32, 105, 110, 116, 40,
  48, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  68, 105, 108, 97, 116, 97, 116, 105, 111, 110, 32, 40, 92, 51, 48, 51,
  92, 50, 53, 49, 112, 97, 105, 115, 115, 101, 117, 114, 41, 32, 61, 32,
  105, 110, 116, 40, 49, 44, 49, 44, 52, 56, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32,
  116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70,
  117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58,
  32, 60, 105, 62, 83, 97, 109, 106, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 49, 55,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  115, 97, 109, 106, 95, 115, 112, 105, 95, 103, 105, 109, 112, 32, 58, 10,
  99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88,
  61, 123, 36, 49, 47, 49, 48, 48, 42, 119, 125, 10, 99, 101, 110, 116,
  114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 61, 123, 36, 50,
  47, 49, 48, 48, 42, 104, 125, 10, 116, 111, 117, 114, 115, 61, 36, 51,
  10, 105, 110, 99, 114, 101, 109, 101, 110, 116, 95, 116, 104, 101, 116, 97,
  61, 36, 52, 10, 99, 111, 101, 102, 102, 95, 100, 105, 109, 61, 36, 53,
  10, 114, 101, 110, 100, 117, 61, 36, 54, 10, 100, 105, 109, 101, 110, 115,
  105, 111, 110, 95, 114, 101, 110, 100, 117, 61, 36, 55, 10, 114, 95, 114,
  101, 110, 100, 117, 61, 36, 56, 10, 118, 95, 114, 101, 110, 100, 117, 61,
  36, 57, 10, 98, 95, 114, 101, 110, 100, 117, 61, 36, 49, 48, 10, 115,
  101, 110, 115, 95, 114, 111, 116, 97, 116, 105, 111, 110, 61, 36, 49, 49,
  10, 86, 97, 108, 101, 117, 114, 95, 100, 105, 108, 97, 116, 101, 95, 99,
  105, 114, 99, 61, 36, 49, 50, 10, 116, 104, 101, 116, 97, 61, 123, 36,
  116, 111, 117, 114, 115, 42, 51, 54, 48, 125, 10, 88, 95, 112, 114, 101,
  99, 101, 100, 101, 110, 116, 61, 36, 99, 101, 110, 116, 114, 101, 95, 111,
  114, 105, 103, 105, 110, 101, 95, 88, 10, 89, 95, 112, 114, 101, 99, 101,
  100, 101, 110, 116, 61, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105,
  103, 105, 110, 101, 95, 89, 10, 99, 111, 109, 112, 116, 101, 117, 114, 95,
  98, 111, 117, 99, 108, 101, 61, 48, 10, 99, 104, 97, 110, 103, 101, 109,
  101, 110, 116, 95, 99, 111, 117, 108, 101, 117, 114, 61, 49, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 52, 10, 45, 102, 105, 108,
  108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44,
  48, 44, 48, 10, 45, 100, 111, 10, 45, 105, 102, 32, 123, 36, 115, 101,
  110, 115, 95, 114, 111, 116, 97, 116, 105, 111, 110, 61, 61, 48, 125, 10,
  88, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105,
  110, 101, 95, 88, 43, 123, 36, 99, 111, 101, 102, 102, 95, 100, 105, 109,
  42, 114, 111, 117, 110, 100, 40, 99, 111, 115, 40, 112, 105, 47, 49, 56,
  48, 42, 36, 116, 104, 101, 116, 97, 41, 43, 123, 36, 116, 104, 101, 116,
  97, 42, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104,
  101, 116, 97, 41, 125, 41, 125, 125, 10, 89, 61, 123, 36, 99, 101, 110,
  116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 43, 123, 36,
  99, 111, 101, 102, 102, 95, 100, 105, 109, 42, 114, 111, 117, 110, 100, 40,
  115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116,
  97, 41, 43, 123, 36, 116, 104, 101, 116, 97, 42, 99, 111, 115, 40, 112,
  105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 41, 125,
  125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 115,
  101, 110, 115, 95, 114, 111, 116, 97, 116, 105, 111, 110, 61, 61, 49, 125,
  10, 88, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103,
  105, 110, 101, 95, 88, 43, 123, 36, 99, 111, 101, 102, 102, 95, 100, 105,
  109, 42, 45, 114, 111, 117, 110, 100, 40, 99, 111, 115, 40, 112, 105, 47,
  49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 43, 123, 36, 116, 104,
  101, 116, 97, 42, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36,
  116, 104, 101, 116, 97, 41, 125, 41, 125, 125, 10, 89, 61, 123, 36, 99,
  101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 43,
  123, 36, 99, 111, 101, 102, 102, 95, 100, 105, 109, 42, 45, 114, 111, 117,
  110, 100, 40, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116,
  104, 101, 116, 97, 41, 43, 123, 36, 116, 104, 101, 116, 97, 42, 99, 111,
  115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41,
  125, 41, 125, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 115, 101, 110, 115, 95, 114, 111, 116, 97, 116, 105, 111, 110, 61,
  61, 50, 125, 10, 88, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111,
  114, 105, 103, 105, 110, 101, 95, 88, 43, 123, 36, 99, 111, 101, 102, 102,
  95, 100, 105, 109, 42, 114, 111, 117, 110, 100, 40, 115, 105, 110, 40, 112,
  105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 43, 123, 36,
  116, 104, 101, 116, 97, 42, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48,
  42, 36, 116, 104, 101, 116, 97, 41, 125, 41, 125, 125, 10, 89, 61, 123,
  36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95,
  89, 43, 123, 36, 99, 111, 101, 102, 102, 95, 100, 105, 109, 42, 114, 111,
  117, 110, 100, 40, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36,
  116, 104, 101, 116, 97, 41, 43, 123, 36, 116, 104, 101, 116, 97, 42, 115,
  105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97,
  41, 125, 41, 125, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 115, 101, 110, 115, 95, 114, 111, 116, 97, 116, 105, 111, 110,
  61, 61, 51, 125, 10, 88, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95,
  111, 114, 105, 103, 105, 110, 101, 95, 88, 43, 123, 36, 99, 111, 101, 102,
  102, 95, 100, 105, 109, 42, 45, 114, 111, 117, 110, 100, 40, 115, 105, 110,
  40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 43,
  123, 36, 116, 104, 101, 116, 97, 42, 99, 111, 115, 40, 112, 105, 47, 49,
  56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 41, 125, 125, 10, 89,
  61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110,
  101, 95, 89, 43, 123, 36, 99, 111, 101, 102, 102, 95, 100, 105, 109, 42,
  45, 114, 111, 117, 110, 100, 40, 99, 111, 115, 40, 112, 105, 47, 49, 56,
  48, 42, 36, 116, 104, 101, 116, 97, 41, 43, 123, 36, 116, 104, 101, 116,
  97, 42, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104,
  101, 116, 97, 41, 125, 41, 125, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 114, 101, 110, 100, 117, 61, 61, 48, 125, 10,
  45, 112, 111, 105, 110, 116, 91, 45, 49, 93, 32, 36, 88, 44, 36, 89,
  44, 48, 44, 49, 44, 36, 114, 95, 114, 101, 110, 100, 117, 44, 36, 118,
  95, 114, 101, 110, 100, 117, 44, 36, 98, 95, 114, 101, 110, 100, 117, 44,
  50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 114, 101, 110, 100, 117, 61, 61, 49, 125, 10, 45, 101, 108, 108, 105,
  112, 115, 101, 91, 45, 49, 93, 32, 36, 88, 44, 36, 89, 44, 36, 100,
  105, 109, 101, 110, 115, 105, 111, 110, 95, 114, 101, 110, 100, 117, 44, 36,
  100, 105, 109, 101, 110, 115, 105, 111, 110, 95, 114, 101, 110, 100, 117, 44,
  48, 44, 49, 44, 36, 114, 95, 114, 101, 110, 100, 117, 44, 36, 118, 95,
  114, 101, 110, 100, 117, 44, 36, 98, 95, 114, 101, 110, 100, 117, 44, 50,
  53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  114, 101, 110, 100, 117, 61, 61, 50, 125, 10, 45, 112, 111, 108, 121, 103,
  111, 110, 91, 45, 49, 93, 32, 51, 44, 36, 99, 101, 110, 116, 114, 101,
  95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 44, 36, 99, 101, 110, 116,
  114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 44, 36, 88, 95,
  112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 89, 95, 112, 114, 101,
  99, 101, 100, 101, 110, 116, 44, 36, 88, 44, 36, 89, 44, 49, 44, 123,
  114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125,
  44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41,
  41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53,
  53, 41, 41, 125, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 114, 101, 110, 100, 117, 61, 61, 51, 125, 10,
  45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 99, 101, 110, 116, 114,
  101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 44, 36, 99, 101, 110,
  116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 44, 36, 88,
  44, 36, 89, 44, 49, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 50, 53, 53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63,
  40, 48, 44, 50, 53, 53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 44, 50, 53, 53, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 114, 101, 110,
  100, 117, 61, 61, 52, 125, 10, 45, 105, 102, 32, 123, 36, 99, 111, 109,
  112, 116, 101, 117, 114, 95, 98, 111, 117, 99, 108, 101, 62, 48, 125, 10,
  45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 88, 95, 112, 114, 101,
  99, 101, 100, 101, 110, 116, 44, 36, 89, 95, 112, 114, 101, 99, 101, 100,
  101, 110, 116, 44, 36, 88, 44, 36, 89, 44, 49, 44, 123, 114, 111, 117,
  110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 44, 123, 114,
  111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 44,
  123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41,
  125, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 114, 101, 110, 100, 117, 61,
  61, 53, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 99,
  101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 44,
  36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95,
  89, 44, 36, 88, 44, 36, 89, 44, 49, 44, 36, 114, 95, 114, 101, 110,
  100, 117, 44, 36, 118, 95, 114, 101, 110, 100, 117, 44, 36, 98, 95, 114,
  101, 110, 100, 117, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 114, 101, 110, 100, 117, 61, 61, 54, 125, 10,
  45, 105, 102, 32, 123, 36, 99, 111, 109, 112, 116, 101, 117, 114, 95, 98,
  111, 117, 99, 108, 101, 62, 48, 125, 10, 45, 108, 105, 110, 101, 91, 45,
  49, 93, 32, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44,
  36, 89, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 88, 44,
  36, 89, 44, 49, 44, 36, 114, 95, 114, 101, 110, 100, 117, 44, 36, 118,
  95, 114, 101, 110, 100, 117, 44, 36, 98, 95, 114, 101, 110, 100, 117, 44,
  50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 114, 101, 110, 100, 117, 61, 61, 55,
  125, 10, 45, 105, 102, 32, 123, 36, 99, 104, 97, 110, 103, 101, 109, 101,
  110, 116, 95, 99, 111, 117, 108, 101, 117, 114, 61, 61, 49, 125, 10, 45,
  112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 51, 44, 36, 99,
  101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 44,
  36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95,
  89, 44, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36,
  89, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 88, 44, 36,
  89, 44, 49, 44, 36, 114, 95, 114, 101, 110, 100, 117, 44, 36, 118, 95,
  114, 101, 110, 100, 117, 44, 36, 98, 95, 114, 101, 110, 100, 117, 44, 50,
  53, 53, 10, 99, 104, 97, 110, 103, 101, 109, 101, 110, 116, 95, 99, 111,
  117, 108, 101, 117, 114, 61, 48, 10, 45, 101, 108, 115, 101, 10, 45, 112,
  111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 51, 44, 36, 99, 101,
  110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 44, 36,
  99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89,
  44, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 89,
  95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 88, 44, 36, 89,
  44, 49, 44, 123, 50, 53, 53, 45, 36, 114, 95, 114, 101, 110, 100, 117,
  125, 44, 123, 50, 53, 53, 45, 36, 118, 95, 114, 101, 110, 100, 117, 125,
  44, 123, 50, 53, 53, 45, 36, 98, 95, 114, 101, 110, 100, 117, 125, 44,
  50, 53, 53, 10, 99, 104, 97, 110, 103, 101, 109, 101, 110, 116, 95, 99,
  111, 117, 108, 101, 117, 114, 61, 49, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 105, 102, 10, 88, 95, 112, 114, 101, 99, 101, 100, 101,
  110, 116, 61, 36, 88, 10, 89, 95, 112, 114, 101, 99, 101, 100, 101, 110,
  116, 61, 36, 89, 10, 99, 111, 109, 112, 116, 101, 117, 114, 95, 98, 111,
  117, 99, 108, 101, 61, 123, 36, 99, 111, 109, 112, 116, 101, 117, 114, 95,
  98, 111, 117, 99, 108, 101, 43, 49, 125, 10, 116, 104, 101, 116, 97, 61,
  123, 36, 116, 104, 101, 116, 97, 45, 36, 105, 110, 99, 114, 101, 109, 101,
  110, 116, 95, 116, 104, 101, 116, 97, 125, 10, 45, 119, 104, 105, 108, 101,
  32, 123, 36, 116, 104, 101, 116, 97, 62, 48, 125, 10, 45, 105, 102, 32,
  123, 36, 86, 97, 108, 101, 117, 114, 95, 100, 105, 108, 97, 116, 101, 95,
  99, 105, 114, 99, 62, 49, 125, 10, 45, 100, 105, 108, 97, 116, 101, 95,
  99, 105, 114, 99, 91, 45, 49, 93, 32, 36, 86, 97, 108, 101, 117, 114,
  95, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 97, 108, 112,
  104, 97, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 115, 97, 109, 106, 95, 115, 112, 105, 95, 103,
  105, 109, 112, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103,
  105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 34, 45, 115, 97, 109, 106, 95, 115, 112, 105, 95, 103, 105, 109,
  112, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35,
  64, 103, 105, 109, 112, 32, 83, 112, 105, 114, 97, 108, 101, 32, 50, 32,
  45, 32, 115, 112, 105, 114, 97, 108, 32, 50, 32, 58, 32, 115, 97, 109,
  106, 95, 115, 112, 105, 50, 95, 103, 105, 109, 112, 44, 32, 115, 97, 109,
  106, 95, 115, 112, 105, 50, 95, 103, 105, 109, 112, 95, 112, 114, 101, 118,
  105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109,
  97, 108, 108, 62, 83, 112, 105, 114, 97, 108, 101, 32, 47, 32, 83, 112,
  105, 114, 97, 108, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 67, 101, 110, 116, 114, 101, 32, 47,
  32, 99, 101, 110, 116, 101, 114, 32, 120, 32, 40, 37, 41, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 101, 110, 116, 114, 101, 32,
  47, 32, 99, 101, 110, 116, 101, 114, 32, 121, 32, 40, 37, 41, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 111, 117, 114, 115, 32,
  47, 32, 116, 117, 114, 110, 115, 32, 61, 32, 105, 110, 116, 40, 49, 48,
  44, 49, 44, 50, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 73, 110, 99, 114, 101, 109, 101, 110, 116, 32, 97, 110, 103, 117, 108,
  97, 105, 114, 101, 32, 47, 32, 97, 110, 103, 117, 108, 97, 114, 32, 105,
  110, 99, 114, 101, 109, 101, 110, 116, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 54, 44, 48, 46, 53, 44, 51, 53, 57, 46, 57, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 111, 101, 102, 102, 46, 32, 97, 103,
  114, 97, 110, 100, 105, 115, 115, 101, 109, 101, 110, 116, 32, 47, 32, 101,
  120, 112, 97, 110, 115, 105, 111, 110, 32, 99, 111, 101, 102, 102, 105, 99,
  105, 101, 110, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 48,
  53, 44, 48, 46, 48, 50, 44, 50, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 84, 121, 112, 101, 32, 100, 101, 32, 114, 101, 110, 100, 117,
  32, 47, 32, 114, 101, 110, 100, 101, 114, 105, 110, 103, 32, 116, 121, 112,
  101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 80, 111, 105, 110,
  116, 115, 34, 44, 34, 67, 101, 114, 99, 108, 101, 115, 32, 47, 32, 67,
  105, 114, 99, 108, 101, 115, 34, 44, 34, 80, 111, 108, 121, 103, 111, 110,
  101, 115, 32, 99, 111, 117, 108, 101, 117, 114, 115, 32, 97, 108, 101, 97,
  116, 111, 105, 114, 101, 115, 32, 47, 32, 80, 111, 108, 121, 103, 111, 110,
  115, 32, 114, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111, 114, 115, 34,
  44, 34, 76, 105, 103, 110, 101, 115, 32, 99, 111, 117, 108, 101, 117, 114,
  115, 32, 97, 108, 101, 97, 116, 111, 105, 114, 101, 115, 32, 47, 32, 76,
  105, 110, 101, 115, 32, 114, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111,
  114, 115, 34, 44, 34, 83, 101, 103, 109, 101, 110, 116, 115, 32, 99, 111,
  117, 108, 101, 117, 114, 115, 32, 97, 108, 101, 97, 116, 111, 105, 114, 101,
  115, 32, 47, 32, 83, 101, 103, 109, 101, 110, 116, 115, 32, 114, 97, 110,
  100, 111, 109, 32, 99, 111, 108, 111, 114, 115, 34, 44, 34, 67, 101, 114,
  99, 108, 101, 115, 32, 99, 111, 117, 108, 101, 117, 114, 115, 32, 97, 108,
  101, 97, 116, 111, 105, 114, 101, 115, 32, 47, 32, 67, 105, 114, 99, 108,
  101, 115, 32, 114, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111, 114, 115,
  34, 44, 34, 80, 111, 105, 110, 116, 115, 32, 99, 111, 117, 108, 101, 117,
  114, 115, 32, 97, 108, 101, 97, 116, 111, 105, 114, 101, 115, 32, 47, 32,
  80, 111, 105, 110, 116, 115, 32, 114, 97, 110, 100, 111, 109, 32, 99, 111,
  108, 111, 114, 115, 34, 44, 34, 84, 114, 105, 97, 110, 103, 108, 101, 115,
  32, 49, 34, 44, 34, 84, 114, 105, 97, 110, 103, 108, 101, 115, 32, 50,
  34, 44, 34, 84, 114, 105, 97, 110, 103, 108, 101, 115, 32, 49, 32, 99,
  111, 117, 108, 101, 117, 114, 115, 32, 97, 108, 101, 97, 116, 111, 105, 114,
  101, 115, 32, 47, 32, 114, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111,
  114, 115, 34, 44, 34, 84, 114, 105, 97, 110, 103, 108, 101, 115, 32, 50,
  32, 99, 111, 117, 108, 101, 117, 114, 115, 32, 97, 108, 101, 97, 116, 111,
  105, 114, 101, 115, 32, 47, 32, 114, 97, 110, 100, 111, 109, 32, 99, 111,
  108, 111, 114, 115, 34, 44, 34, 82, 101, 99, 116, 97, 110, 103, 108, 101,
  115, 34, 44, 34, 82, 101, 99, 116, 97, 110, 103, 108, 101, 115, 32, 99,
  111, 117, 108, 101, 117, 114, 115, 32, 97, 108, 101, 97, 116, 111, 105, 114,
  101, 115, 32, 47, 32, 114, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111,
  114, 115, 34, 44, 34, 83, 112, 108, 105, 110, 101, 115, 34, 44, 34, 83,
  112, 108, 105, 110, 101, 115, 32, 99, 111, 117, 108, 101, 117, 114, 115, 32,
  97, 108, 101, 97, 116, 111, 105, 114, 101, 115, 32, 47, 32, 114, 97, 110,
  100, 111, 109, 32, 99, 111, 108, 111, 114, 115, 34, 44, 34, 76, 105, 103,
  110, 101, 115, 32, 99, 111, 117, 108, 101, 117, 114, 32, 47, 32, 76, 105,
  110, 101, 115, 32, 99, 111, 108, 111, 114, 34, 44, 34, 83, 101, 103, 109,
  101, 110, 116, 115, 32, 99, 111, 117, 108, 101, 117, 114, 32, 47, 32, 83,
  101, 103, 109, 101, 110, 116, 115, 32, 99, 111, 108, 111, 114, 34, 44, 34,
  80, 111, 108, 121, 103, 111, 110, 101, 115, 32, 50, 32, 99, 111, 117, 108,
  101, 117, 114, 115, 32, 47, 32, 80, 111, 108, 121, 103, 111, 110, 115, 32,
  50, 32, 99, 111, 108, 111, 114, 115, 34, 44, 34, 84, 114, 105, 97, 110,
  103, 108, 101, 115, 32, 49, 32, 98, 105, 115, 34, 44, 34, 84, 114, 105,
  97, 110, 103, 108, 101, 115, 32, 50, 32, 98, 105, 115, 34, 44, 34, 82,
  101, 99, 116, 97, 110, 103, 108, 101, 115, 32, 98, 105, 115, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 105, 109, 101, 110, 115, 105,
  111, 110, 32, 114, 101, 110, 100, 117, 32, 47, 32, 100, 105, 109, 101, 110,
  115, 105, 111, 110, 97, 108, 32, 114, 101, 110, 100, 101, 114, 105, 110, 103,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 50, 44, 48, 44, 52, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101,
  117, 114, 32, 47, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108,
  111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 110, 115, 32, 100, 101, 32, 114,
  111, 116, 97, 116, 105, 111, 110, 32, 47, 32, 100, 105, 114, 101, 99, 116,
  105, 111, 110, 32, 111, 102, 32, 114, 111, 116, 97, 116, 105, 111, 110, 32,
  61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 51, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 105, 108, 97, 116, 97, 116, 105, 111, 110,
  32, 40, 92, 51, 48, 51, 92, 50, 53, 49, 112, 97, 105, 115, 115, 101,
  117, 114, 41, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49, 44, 52, 56,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 114, 101, 97,
  100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 108, 111, 117, 32,
  47, 32, 98, 108, 117, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  68, 101, 102, 111, 114, 109, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 83,
  97, 109, 106, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105,
  62, 50, 48, 49, 50, 47, 48, 56, 47, 50, 52, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95,
  115, 112, 105, 50, 95, 103, 105, 109, 112, 32, 58, 10, 99, 101, 110, 116,
  114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 61, 123, 36, 49,
  47, 49, 48, 48, 42, 119, 125, 10, 99, 101, 110, 116, 114, 101, 95, 111,
  114, 105, 103, 105, 110, 101, 95, 89, 61, 123, 36, 50, 47, 49, 48, 48,
  42, 104, 125, 10, 116, 111, 117, 114, 115, 61, 36, 51, 10, 105, 110, 99,
  114, 101, 109, 101, 110, 116, 95, 116, 104, 101, 116, 97, 61, 36, 52, 10,
  99, 111, 101, 102, 102, 95, 100, 105, 109, 61, 36, 53, 10, 114, 101, 110,
  100, 117, 61, 36, 54, 10, 100, 105, 109, 101, 110, 115, 105, 111, 110, 95,
  114, 101, 110, 100, 117, 61, 36, 55, 10, 114, 95, 114, 101, 110, 100, 117,
  61, 36, 56, 10, 118, 95, 114, 101, 110, 100, 117, 61, 36, 57, 10, 98,
  95, 114, 101, 110, 100, 117, 61, 36, 49, 48, 10, 115, 101, 110, 115, 95,
  114, 111, 116, 97, 116, 105, 111, 110, 61, 36, 49, 49, 10, 86, 97, 108,
  101, 117, 114, 95, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 61,
  36, 49, 50, 10, 118, 97, 108, 101, 117, 114, 95, 115, 112, 114, 101, 97,
  100, 61, 36, 49, 51, 10, 102, 108, 111, 117, 61, 36, 49, 52, 10, 100,
  101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 61, 36, 49, 53, 10, 116,
  104, 101, 116, 97, 61, 123, 36, 116, 111, 117, 114, 115, 42, 51, 54, 48,
  125, 10, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 61, 36, 99,
  101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 10,
  89, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 61, 36, 99, 101, 110,
  116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 10, 99, 111,
  109, 112, 116, 101, 117, 114, 95, 98, 111, 117, 99, 108, 101, 61, 48, 10,
  99, 104, 97, 110, 103, 101, 109, 101, 110, 116, 95, 99, 111, 117, 108, 101,
  117, 114, 61, 49, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 123, 119, 125, 44, 123, 104, 125, 44, 49,
  44, 52, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45,
  49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 10, 45, 100, 111, 10, 45,
  105, 102, 32, 123, 36, 115, 101, 110, 115, 95, 114, 111, 116, 97, 116, 105,
  111, 110, 61, 61, 48, 125, 10, 88, 61, 123, 36, 99, 101, 110, 116, 114,
  101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 43, 123, 36, 99, 111,
  101, 102, 102, 95, 100, 105, 109, 42, 114, 111, 117, 110, 100, 40, 99, 111,
  115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41,
  43, 123, 36, 116, 104, 101, 116, 97, 42, 115, 105, 110, 40, 112, 105, 47,
  49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 41, 125, 125, 10,
  89, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105,
  110, 101, 95, 89, 43, 123, 36, 99, 111, 101, 102, 102, 95, 100, 105, 109,
  42, 114, 111, 117, 110, 100, 40, 115, 105, 110, 40, 112, 105, 47, 49, 56,
  48, 42, 36, 116, 104, 101, 116, 97, 41, 43, 123, 36, 116, 104, 101, 116,
  97, 42, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104,
  101, 116, 97, 41, 125, 41, 125, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 115, 101, 110, 115, 95, 114, 111, 116, 97, 116,
  105, 111, 110, 61, 61, 49, 125, 10, 88, 61, 123, 36, 99, 101, 110, 116,
  114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 43, 123, 36, 99,
  111, 101, 102, 102, 95, 100, 105, 109, 42, 45, 114, 111, 117, 110, 100, 40,
  99, 111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116,
  97, 41, 43, 123, 36, 116, 104, 101, 116, 97, 42, 115, 105, 110, 40, 112,
  105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 41, 125,
  125, 10, 89, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105,
  103, 105, 110, 101, 95, 89, 43, 123, 36, 99, 111, 101, 102, 102, 95, 100,
  105, 109, 42, 45, 114, 111, 117, 110, 100, 40, 115, 105, 110, 40, 112, 105,
  47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 43, 123, 36, 116,
  104, 101, 116, 97, 42, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48, 42,
  36, 116, 104, 101, 116, 97, 41, 125, 41, 125, 125, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 115, 101, 110, 115, 95, 114, 111,
  116, 97, 116, 105, 111, 110, 61, 61, 50, 125, 10, 88, 61, 123, 36, 99,
  101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 43,
  123, 36, 99, 111, 101, 102, 102, 95, 100, 105, 109, 42, 114, 111, 117, 110,
  100, 40, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104,
  101, 116, 97, 41, 43, 123, 36, 116, 104, 101, 116, 97, 42, 99, 111, 115,
  40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125,
  41, 125, 125, 10, 89, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111,
  114, 105, 103, 105, 110, 101, 95, 89, 43, 123, 36, 99, 111, 101, 102, 102,
  95, 100, 105, 109, 42, 114, 111, 117, 110, 100, 40, 99, 111, 115, 40, 112,
  105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 43, 123, 36,
  116, 104, 101, 116, 97, 42, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48,
  42, 36, 116, 104, 101, 116, 97, 41, 125, 41, 125, 125, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 115, 101, 110, 115, 95, 114,
  111, 116, 97, 116, 105, 111, 110, 61, 61, 51, 125, 10, 88, 61, 123, 36,
  99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88,
  43, 123, 36, 99, 111, 101, 102, 102, 95, 100, 105, 109, 42, 45, 114, 111,
  117, 110, 100, 40, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36,
  116, 104, 101, 116, 97, 41, 43, 123, 36, 116, 104, 101, 116, 97, 42, 99,
  111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97,
  41, 125, 41, 125, 125, 10, 89, 61, 123, 36, 99, 101, 110, 116, 114, 101,
  95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 43, 123, 36, 99, 111, 101,
  102, 102, 95, 100, 105, 109, 42, 45, 114, 111, 117, 110, 100, 40, 99, 111,
  115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41,
  43, 123, 36, 116, 104, 101, 116, 97, 42, 115, 105, 110, 40, 112, 105, 47,
  49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 41, 125, 125, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 114, 101, 110,
  100, 117, 61, 61, 48, 125, 10, 45, 112, 111, 105, 110, 116, 91, 45, 49,
  93, 32, 36, 88, 44, 36, 89, 44, 48, 44, 49, 44, 36, 114, 95, 114,
  101, 110, 100, 117, 44, 36, 118, 95, 114, 101, 110, 100, 117, 44, 36, 98,
  95, 114, 101, 110, 100, 117, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 114, 101, 110, 100, 117, 61, 61, 49,
  125, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36,
  88, 44, 36, 89, 44, 36, 100, 105, 109, 101, 110, 115, 105, 111, 110, 95,
  114, 101, 110, 100, 117, 44, 36, 100, 105, 109, 101, 110, 115, 105, 111, 110,
  95, 114, 101, 110, 100, 117, 44, 48, 44, 49, 44, 36, 114, 95, 114, 101,
  110, 100, 117, 44, 36, 118, 95, 114, 101, 110, 100, 117, 44, 36, 98, 95,
  114, 101, 110, 100, 117, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 114, 101, 110, 100, 117, 61, 61, 50, 125,
  10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 51, 44,
  36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95,
  88, 44, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110,
  101, 95, 89, 44, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116,
  44, 36, 89, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 88,
  44, 36, 89, 44, 49, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 50, 53, 53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63,
  40, 48, 44, 50, 53, 53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 44, 50, 53, 53, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 114, 101, 110,
  100, 117, 61, 61, 51, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93,
  32, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101,
  95, 88, 44, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105,
  110, 101, 95, 89, 44, 36, 88, 44, 36, 89, 44, 49, 44, 123, 114, 111,
  117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 44, 123,
  114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125,
  44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41,
  41, 125, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 114, 101, 110, 100, 117, 61, 61, 52, 125, 10, 45, 105,
  102, 32, 123, 36, 99, 111, 109, 112, 116, 101, 117, 114, 95, 98, 111, 117,
  99, 108, 101, 62, 48, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93,
  32, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 89,
  95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 88, 44, 36, 89,
  44, 49, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53,
  53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44,
  50, 53, 53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40,
  48, 44, 50, 53, 53, 41, 41, 125, 44, 50, 53, 53, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 114, 101, 110, 100, 117, 61, 61, 53, 125, 10, 45, 101, 108, 108, 105,
  112, 115, 101, 91, 45, 49, 93, 32, 36, 88, 44, 36, 89, 44, 36, 100,
  105, 109, 101, 110, 115, 105, 111, 110, 95, 114, 101, 110, 100, 117, 44, 36,
  100, 105, 109, 101, 110, 115, 105, 111, 110, 95, 114, 101, 110, 100, 117, 44,
  48, 44, 49, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50,
  53, 53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 50, 53, 53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63,
  40, 48, 44, 50, 53, 53, 41, 41, 125, 44, 50, 53, 53, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 114, 101, 110, 100, 117,
  61, 61, 54, 125, 10, 45, 112, 111, 105, 110, 116, 91, 45, 49, 93, 32,
  36, 88, 44, 36, 89, 44, 48, 44, 49, 44, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 44, 123, 114, 111, 117,
  110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 44, 123, 114,
  111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 44,
  50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 114, 101, 110, 100, 117, 61, 61, 55, 125, 10, 45, 105, 102, 32, 123,
  36, 99, 111, 109, 112, 116, 101, 117, 114, 95, 98, 111, 117, 99, 108, 101,
  62, 48, 125, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93,
  32, 51, 44, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44,
  36, 89, 44, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44,
  36, 89, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 88, 44,
  36, 89, 44, 49, 44, 36, 114, 95, 114, 101, 110, 100, 117, 44, 36, 118,
  95, 114, 101, 110, 100, 117, 44, 36, 98, 95, 114, 101, 110, 100, 117, 44,
  50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 114, 101, 110, 100, 117, 61, 61, 56,
  125, 10, 45, 105, 102, 32, 123, 36, 99, 111, 109, 112, 116, 101, 117, 114,
  95, 98, 111, 117, 99, 108, 101, 62, 48, 125, 10, 45, 112, 111, 108, 121,
  103, 111, 110, 91, 45, 49, 93, 32, 51, 44, 36, 88, 44, 36, 89, 95,
  112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 88, 95, 112, 114, 101,
  99, 101, 100, 101, 110, 116, 44, 36, 89, 95, 112, 114, 101, 99, 101, 100,
  101, 110, 116, 44, 36, 88, 44, 36, 89, 44, 49, 44, 36, 114, 95, 114,
  101, 110, 100, 117, 44, 36, 118, 95, 114, 101, 110, 100, 117, 44, 36, 98,
  95, 114, 101, 110, 100, 117, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 114,
  101, 110, 100, 117, 61, 61, 57, 125, 10, 45, 105, 102, 32, 123, 36, 99,
  111, 109, 112, 116, 101, 117, 114, 95, 98, 111, 117, 99, 108, 101, 62, 48,
  125, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 51,
  44, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 89,
  44, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 89,
  95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 88, 44, 36, 89,
  44, 49, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53,
  53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44,
  50, 53, 53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40,
  48, 44, 50, 53, 53, 41, 41, 125, 44, 50, 53, 53, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 114, 101, 110, 100, 117, 61, 61, 49, 48, 125, 10, 45, 105, 102, 32,
  123, 36, 99, 111, 109, 112, 116, 101, 117, 114, 95, 98, 111, 117, 99, 108,
  101, 62, 48, 125, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49,
  93, 32, 51, 44, 36, 88, 44, 36, 89, 95, 112, 114, 101, 99, 101, 100,
  101, 110, 116, 44, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116,
  44, 36, 89, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 88,
  44, 36, 89, 44, 49, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 50, 53, 53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63,
  40, 48, 44, 50, 53, 53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 44, 50, 53, 53, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 114, 101, 110, 100, 117, 61, 61, 49, 49, 125, 10, 45,
  105, 102, 32, 123, 36, 99, 111, 109, 112, 116, 101, 117, 114, 95, 98, 111,
  117, 99, 108, 101, 62, 48, 125, 10, 45, 112, 111, 108, 121, 103, 111, 110,
  91, 45, 49, 93, 32, 52, 44, 36, 88, 95, 112, 114, 101, 99, 101, 100,
  101, 110, 116, 44, 36, 89, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116,
  44, 36, 88, 44, 36, 89, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116,
  44, 36, 88, 44, 36, 89, 44, 36, 88, 95, 112, 114, 101, 99, 101, 100,
  101, 110, 116, 44, 36, 89, 44, 49, 44, 36, 114, 95, 114, 101, 110, 100,
  117, 44, 36, 118, 95, 114, 101, 110, 100, 117, 44, 36, 98, 95, 114, 101,
  110, 100, 117, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 114, 101, 110, 100,
  117, 61, 61, 49, 50, 125, 10, 45, 105, 102, 32, 123, 36, 99, 111, 109,
  112, 116, 101, 117, 114, 95, 98, 111, 117, 99, 108, 101, 62, 48, 125, 10,
  45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 52, 44, 36,
  88, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 89, 95, 112,
  114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 88, 44, 36, 89, 95, 112,
  114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 88, 44, 36, 89, 44, 36,
  88, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 89, 44, 49,
  44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41,
  41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53,
  53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44,
  50, 53, 53, 41, 41, 125, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 114,
  101, 110, 100, 117, 61, 61, 49, 51, 125, 10, 45, 105, 102, 32, 123, 36,
  99, 111, 109, 112, 116, 101, 117, 114, 95, 98, 111, 117, 99, 108, 101, 62,
  48, 125, 10, 45, 115, 112, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36,
  88, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 89, 95, 112,
  114, 101, 99, 101, 100, 101, 110, 116, 44, 123, 36, 100, 105, 109, 101, 110,
  115, 105, 111, 110, 95, 114, 101, 110, 100, 117, 42, 99, 111, 115, 40, 112,
  105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 44, 123,
  36, 100, 105, 109, 101, 110, 115, 105, 111, 110, 95, 114, 101, 110, 100, 117,
  42, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101,
  116, 97, 41, 125, 44, 36, 88, 44, 36, 89, 44, 123, 45, 36, 100, 105,
  109, 101, 110, 115, 105, 111, 110, 95, 114, 101, 110, 100, 117, 42, 99, 111,
  115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41,
  125, 44, 123, 45, 36, 100, 105, 109, 101, 110, 115, 105, 111, 110, 95, 114,
  101, 110, 100, 117, 42, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42,
  36, 116, 104, 101, 116, 97, 41, 125, 44, 49, 44, 36, 114, 95, 114, 101,
  110, 100, 117, 44, 36, 118, 95, 114, 101, 110, 100, 117, 44, 36, 98, 95,
  114, 101, 110, 100, 117, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 114, 101,
  110, 100, 117, 61, 61, 49, 52, 125, 10, 45, 105, 102, 32, 123, 36, 99,
  111, 109, 112, 116, 101, 117, 114, 95, 98, 111, 117, 99, 108, 101, 62, 48,
  125, 10, 45, 115, 112, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 88,
  95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 89, 95, 112, 114,
  101, 99, 101, 100, 101, 110, 116, 44, 123, 36, 100, 105, 109, 101, 110, 115,
  105, 111, 110, 95, 114, 101, 110, 100, 117, 42, 99, 111, 115, 40, 112, 105,
  47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 44, 123, 36,
  100, 105, 109, 101, 110, 115, 105, 111, 110, 95, 114, 101, 110, 100, 117, 42,
  115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116,
  97, 41, 125, 44, 36, 88, 44, 36, 89, 44, 123, 45, 36, 100, 105, 109,
  101, 110, 115, 105, 111, 110, 95, 114, 101, 110, 100, 117, 42, 99, 111, 115,
  40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125,
  44, 123, 45, 36, 100, 105, 109, 101, 110, 115, 105, 111, 110, 95, 114, 101,
  110, 100, 117, 42, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36,
  116, 104, 101, 116, 97, 41, 125, 44, 49, 44, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 44, 123, 114, 111, 117,
  110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 44, 123, 114,
  111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 44,
  50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 114, 101, 110, 100, 117, 61, 61, 49,
  53, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 99, 101,
  110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 44, 36,
  99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89,
  44, 36, 88, 44, 36, 89, 44, 49, 44, 36, 114, 95, 114, 101, 110, 100,
  117, 44, 36, 118, 95, 114, 101, 110, 100, 117, 44, 36, 98, 95, 114, 101,
  110, 100, 117, 44, 50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 114, 101, 110, 100, 117, 61, 61, 49, 54, 125, 10,
  45, 105, 102, 32, 123, 36, 99, 111, 109, 112, 116, 101, 117, 114, 95, 98,
  111, 117, 99, 108, 101, 62, 48, 125, 10, 45, 108, 105, 110, 101, 91, 45,
  49, 93, 32, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44,
  36, 89, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 88, 44,
  36, 89, 44, 49, 44, 36, 114, 95, 114, 101, 110, 100, 117, 44, 36, 118,
  95, 114, 101, 110, 100, 117, 44, 36, 98, 95, 114, 101, 110, 100, 117, 44,
  50, 53, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 114, 101, 110, 100, 117, 61, 61, 49,
  55, 125, 10, 45, 105, 102, 32, 123, 36, 99, 104, 97, 110, 103, 101, 109,
  101, 110, 116, 95, 99, 111, 117, 108, 101, 117, 114, 61, 61, 49, 125, 10,
  45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 51, 44, 36,
  99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88,
  44, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101,
  95, 89, 44, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44,
  36, 89, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 88, 44,
  36, 89, 44, 49, 44, 36, 114, 95, 114, 101, 110, 100, 117, 44, 36, 118,
  95, 114, 101, 110, 100, 117, 44, 36, 98, 95, 114, 101, 110, 100, 117, 44,
  50, 53, 53, 10, 99, 104, 97, 110, 103, 101, 109, 101, 110, 116, 95, 99,
  111, 117, 108, 101, 117, 114, 61, 48, 10, 45, 101, 108, 115, 101, 10, 45,
  112, 111, 108, 121, 103, 111, 110, 32, 51, 44, 36, 99, 101, 110, 116, 114,
  101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 44, 36, 99, 101, 110,
  116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 44, 36, 88,
  95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 89, 95, 112, 114,
  101, 99, 101, 100, 101, 110, 116, 44, 36, 88, 44, 36, 89, 44, 49, 44,
  123, 50, 53, 53, 45, 36, 114, 95, 114, 101, 110, 100, 117, 125, 44, 123,
  50, 53, 53, 45, 36, 118, 95, 114, 101, 110, 100, 117, 125, 44, 123, 50,
  53, 53, 45, 36, 98, 95, 114, 101, 110, 100, 117, 125, 44, 50, 53, 53,
  10, 99, 104, 97, 110, 103, 101, 109, 101, 110, 116, 95, 99, 111, 117, 108,
  101, 117, 114, 61, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 114, 101, 110, 100, 117, 61,
  61, 49, 56, 125, 10, 45, 105, 102, 32, 123, 36, 99, 111, 109, 112, 116,
  101, 117, 114, 95, 98, 111, 117, 99, 108, 101, 62, 48, 125, 10, 45, 105,
  102, 32, 123, 36, 99, 104, 97, 110, 103, 101, 109, 101, 110, 116, 95, 99,
  111, 117, 108, 101, 117, 114, 61, 61, 49, 125, 10, 45, 112, 111, 108, 121,
  103, 111, 110, 91, 45, 49, 93, 32, 51, 44, 36, 88, 95, 112, 114, 101,
  99, 101, 100, 101, 110, 116, 44, 36, 89, 44, 36, 88, 95, 112, 114, 101,
  99, 101, 100, 101, 110, 116, 44, 36, 89, 95, 112, 114, 101, 99, 101, 100,
  101, 110, 116, 44, 36, 88, 44, 36, 89, 44, 49, 44, 36, 114, 95, 114,
  101, 110, 100, 117, 44, 36, 118, 95, 114, 101, 110, 100, 117, 44, 36, 98,
  95, 114, 101, 110, 100, 117, 44, 50, 53, 53, 10, 99, 104, 97, 110, 103,
  101, 109, 101, 110, 116, 95, 99, 111, 117, 108, 101, 117, 114, 61, 48, 10,
  45, 101, 108, 115, 101, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45,
  49, 93, 32, 51, 44, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110,
  116, 44, 36, 89, 44, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110,
  116, 44, 36, 89, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36,
  88, 44, 36, 89, 44, 49, 44, 123, 50, 53, 53, 45, 36, 114, 95, 114,
  101, 110, 100, 117, 125, 44, 123, 50, 53, 53, 45, 36, 118, 95, 114, 101,
  110, 100, 117, 125, 44, 123, 50, 53, 53, 45, 36, 98, 95, 114, 101, 110,
  100, 117, 125, 44, 50, 53, 53, 10, 99, 104, 97, 110, 103, 101, 109, 101,
  110, 116, 95, 99, 111, 117, 108, 101, 117, 114, 61, 49, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 114, 101, 110, 100, 117, 61, 61, 49,
  57, 125, 10, 45, 105, 102, 32, 123, 36, 99, 111, 109, 112, 116, 101, 117,
  114, 95, 98, 111, 117, 99, 108, 101, 62, 48, 125, 10, 45, 105, 102, 32,
  123, 36, 99, 104, 97, 110, 103, 101, 109, 101, 110, 116, 95, 99, 111, 117,
  108, 101, 117, 114, 61, 61, 49, 125, 10, 45, 112, 111, 108, 121, 103, 111,
  110, 91, 45, 49, 93, 32, 51, 44, 36, 88, 44, 36, 89, 95, 112, 114,
  101, 99, 101, 100, 101, 110, 116, 44, 36, 88, 95, 112, 114, 101, 99, 101,
  100, 101, 110, 116, 44, 36, 89, 95, 112, 114, 101, 99, 101, 100, 101, 110,
  116, 44, 36, 88, 44, 36, 89, 44, 49, 44, 36, 114, 95, 114, 101, 110,
  100, 117, 44, 36, 118, 95, 114, 101, 110, 100, 117, 44, 36, 98, 95, 114,
  101, 110, 100, 117, 44, 50, 53, 53, 10, 99, 104, 97, 110, 103, 101, 109,
  101, 110, 116, 95, 99, 111, 117, 108, 101, 117, 114, 61, 48, 10, 45, 101,
  108, 115, 101, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93,
  32, 51, 44, 36, 88, 44, 36, 89, 95, 112, 114, 101, 99, 101, 100, 101,
  110, 116, 44, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44,
  36, 89, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 88, 44,
  36, 89, 44, 49, 44, 123, 50, 53, 53, 45, 36, 114, 95, 114, 101, 110,
  100, 117, 125, 44, 123, 50, 53, 53, 45, 36, 118, 95, 114, 101, 110, 100,
  117, 125, 44, 123, 50, 53, 53, 45, 36, 98, 95, 114, 101, 110, 100, 117,
  125, 44, 50, 53, 53, 10, 99, 104, 97, 110, 103, 101, 109, 101, 110, 116,
  95, 99, 111, 117, 108, 101, 117, 114, 61, 49, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 114, 101, 110, 100, 117, 61, 61, 50, 48, 125,
  10, 45, 105, 102, 32, 123, 36, 99, 111, 109, 112, 116, 101, 117, 114, 95,
  98, 111, 117, 99, 108, 101, 62, 48, 125, 10, 45, 105, 102, 32, 123, 36,
  99, 104, 97, 110, 103, 101, 109, 101, 110, 116, 95, 99, 111, 117, 108, 101,
  117, 114, 61, 61, 49, 125, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91,
  45, 49, 93, 32, 52, 44, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101,
  110, 116, 44, 36, 89, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44,
  36, 88, 44, 36, 89, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44,
  36, 88, 44, 36, 89, 44, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101,
  110, 116, 44, 36, 89, 44, 49, 44, 36, 114, 95, 114, 101, 110, 100, 117,
  44, 36, 118, 95, 114, 101, 110, 100, 117, 44, 36, 98, 95, 114, 101, 110,
  100, 117, 44, 50, 53, 53, 10, 99, 104, 97, 110, 103, 101, 109, 101, 110,
  116, 95, 99, 111, 117, 108, 101, 117, 114, 61, 48, 10, 45, 101, 108, 115,
  101, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 52,
  44, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 89,
  95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 88, 44, 36, 89,
  95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 88, 44, 36, 89,
  44, 36, 88, 95, 112, 114, 101, 99, 101, 100, 101, 110, 116, 44, 36, 89,
  44, 49, 44, 123, 50, 53, 53, 45, 36, 114, 95, 114, 101, 110, 100, 117,
  125, 44, 123, 50, 53, 53, 45, 36, 118, 95, 114, 101, 110, 100, 117, 125,
  44, 123, 50, 53, 53, 45, 36, 98, 95, 114, 101, 110, 100, 117, 125, 44,
  50, 53, 53, 10, 99, 104, 97, 110, 103, 101, 109, 101, 110, 116, 95, 99,
  111, 117, 108, 101, 117, 114, 61, 49, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 88, 95,
  112, 114, 101, 99, 101, 100, 101, 110, 116, 61, 36, 88, 10, 89, 95, 112,
  114, 101, 99, 101, 100, 101, 110, 116, 61, 36, 89, 10, 99, 111, 109, 112,
  116, 101, 117, 114, 95, 98, 111, 117, 99, 108, 101, 61, 123, 36, 99, 111,
  109, 112, 116, 101, 117, 114, 95, 98, 111, 117, 99, 108, 101, 43, 49, 125,
  10, 116, 104, 101, 116, 97, 61, 123, 36, 116, 104, 101, 116, 97, 45, 36,
  105, 110, 99, 114, 101, 109, 101, 110, 116, 95, 116, 104, 101, 116, 97, 125,
  10, 45, 119, 104, 105, 108, 101, 32, 123, 36, 116, 104, 101, 116, 97, 62,
  48, 125, 10, 45, 105, 102, 32, 123, 36, 86, 97, 108, 101, 117, 114, 95,
  100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 62, 49, 125, 10, 45,
  100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 91, 45, 49, 93, 32,
  36, 86, 97, 108, 101, 117, 114, 95, 100, 105, 108, 97, 116, 101, 95, 99,
  105, 114, 99, 10, 45, 101, 110, 100, 105, 102, 10, 45, 115, 112, 114, 101,
  97, 100, 91, 45, 49, 93, 32, 36, 118, 97, 108, 101, 117, 114, 95, 115,
  112, 114, 101, 97, 100, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32,
  36, 102, 108, 111, 117, 10, 45, 100, 101, 102, 111, 114, 109, 91, 45, 49,
  93, 32, 36, 100, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 10, 45,
  99, 111, 109, 112, 111, 115, 101, 95, 97, 108, 112, 104, 97, 91, 45, 50,
  44, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  10, 115, 97, 109, 106, 95, 115, 112, 105, 50, 95, 103, 105, 109, 112, 95,
  112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95,
  115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45,
  115, 97, 109, 106, 95, 115, 112, 105, 50, 95, 103, 105, 109, 112, 32, 36,
  123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35, 64, 103, 105,
  109, 112, 32, 83, 112, 105, 114, 111, 103, 114, 97, 112, 104, 101, 32, 115,
  97, 109, 106, 32, 58, 32, 83, 112, 105, 114, 111, 103, 114, 97, 112, 104,
  101, 95, 115, 97, 109, 106, 44, 32, 83, 112, 105, 114, 111, 103, 114, 97,
  112, 104, 101, 95, 115, 97, 109, 106, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 67, 101, 110, 116,
  114, 101, 32, 47, 32, 67, 101, 110, 116, 101, 114, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  101, 110, 116, 114, 101, 32, 47, 32, 99, 101, 110, 116, 101, 114, 32, 120,
  32, 40, 37, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 101, 110, 116, 114, 101, 32, 47, 32, 99, 101, 110, 116, 101, 114, 32,
  121, 32, 40, 37, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48,
  44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 83, 112, 105, 114, 111, 103, 114, 97,
  112, 104, 101, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 97, 121, 111, 110, 47, 114, 97, 100,
  105, 117, 115, 32, 114, 32, 61, 32, 105, 110, 116, 40, 50, 48, 44, 45,
  49, 48, 48, 48, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 82, 97, 121, 111, 110, 47, 114, 97, 100, 105, 117, 115,
  32, 114, 32, 61, 32, 105, 110, 116, 40, 51, 48, 44, 45, 49, 48, 48,
  48, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 116, 121, 108, 111, 32, 47, 32, 112, 101, 110, 32, 40, 112, 111,
  115, 105, 116, 105, 111, 110, 41, 32, 61, 32, 105, 110, 116, 40, 49, 53,
  44, 45, 49, 48, 48, 48, 44, 49, 48, 48, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 116, 121, 108, 111, 32, 47, 32, 112, 101,
  110, 32, 40, 99, 111, 117, 108, 101, 117, 114, 47, 99, 111, 108, 111, 114,
  41, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 49, 50,
  56, 44, 54, 52, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 116, 121, 108, 111, 32, 47, 32, 112, 101, 110, 32, 40,
  118, 97, 114, 105, 97, 116, 105, 111, 110, 32, 100, 101, 32, 99, 111, 117,
  108, 101, 117, 114, 47, 99, 111, 108, 111, 114, 32, 118, 97, 114, 105, 97,
  116, 105, 111, 110, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  80, 97, 115, 32, 100, 101, 32, 118, 97, 114, 105, 97, 116, 105, 111, 110,
  32, 47, 32, 78, 111, 32, 99, 104, 97, 110, 103, 101, 34, 44, 34, 67,
  111, 117, 108, 101, 117, 114, 115, 32, 97, 108, 101, 97, 116, 111, 105, 114,
  101, 115, 32, 47, 32, 82, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111,
  114, 115, 34, 44, 34, 70, 97, 105, 98, 108, 101, 109, 101, 110, 116, 32,
  110, 117, 97, 110, 99, 101, 101, 32, 47, 32, 80, 111, 111, 114, 108, 121,
  32, 110, 117, 97, 110, 99, 101, 100, 34, 44, 34, 77, 111, 121, 101, 110,
  110, 101, 109, 101, 110, 116, 32, 110, 117, 97, 110, 99, 101, 101, 32, 47,
  32, 77, 111, 100, 101, 114, 97, 116, 101, 108, 121, 32, 110, 117, 97, 110,
  99, 101, 100, 34, 44, 34, 70, 111, 114, 116, 101, 109, 101, 110, 116, 32,
  110, 117, 97, 110, 99, 101, 101, 32, 47, 32, 72, 105, 103, 104, 108, 121,
  32, 110, 117, 97, 110, 99, 101, 100, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 116, 121, 108, 111, 32, 47, 32, 112, 101, 110, 32,
  40, 100, 105, 108, 97, 116, 101, 32, 112, 105, 120, 101, 108, 115, 41, 32,
  61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 51, 50, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 109, 98, 114, 101, 32, 100, 101,
  32, 116, 111, 117, 114, 115, 32, 47, 32, 110, 117, 109, 98, 101, 114, 32,
  111, 102, 32, 116, 117, 114, 110, 115, 32, 61, 32, 105, 110, 116, 40, 51,
  44, 49, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  77, 117, 108, 116, 105, 112, 108, 105, 101, 114, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 48, 44, 34, 84, 111, 117, 114, 115, 32, 47, 32, 84,
  117, 114, 110, 115, 32, 42, 32, 49, 34, 44, 34, 84, 111, 117, 114, 115,
  32, 47, 32, 84, 117, 114, 110, 115, 32, 42, 32, 49, 48, 32, 76, 69,
  78, 84, 32, 47, 32, 83, 76, 79, 87, 34, 44, 34, 84, 111, 117, 114,
  115, 32, 47, 32, 84, 117, 114, 110, 115, 32, 42, 32, 49, 48, 48, 32,
  84, 82, 69, 83, 32, 76, 69, 78, 84, 32, 47, 32, 86, 69, 82, 89,
  32, 83, 76, 79, 87, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 73, 110, 99, 114, 101, 109, 101, 110, 116, 32, 97, 110, 103, 117, 108,
  97, 105, 114, 101, 32, 47, 32, 97, 110, 103, 117, 108, 97, 114, 32, 105,
  110, 99, 114, 101, 109, 101, 110, 116, 32, 40, 100, 101, 103, 114, 92, 51,
  48, 51, 92, 50, 53, 49, 115, 41, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 44, 49, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 68, 105, 118, 105, 115, 101, 114, 32, 47, 32, 100, 105, 118,
  105, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34,
  73, 110, 99, 114, 101, 109, 101, 110, 116, 32, 97, 110, 103, 117, 108, 97,
  105, 114, 101, 45, 65, 110, 103, 117, 108, 97, 114, 32, 105, 110, 99, 114,
  101, 109, 101, 110, 116, 32, 47, 32, 49, 34, 44, 34, 73, 110, 99, 114,
  101, 109, 101, 110, 116, 32, 97, 110, 103, 117, 108, 97, 105, 114, 101, 45,
  65, 110, 103, 117, 108, 97, 114, 32, 105, 110, 99, 114, 101, 109, 101, 110,
  116, 32, 47, 49, 48, 32, 76, 69, 78, 84, 32, 47, 32, 83, 76, 79,
  87, 34, 44, 34, 73, 110, 99, 114, 101, 109, 101, 110, 116, 32, 97, 110,
  103, 117, 108, 97, 105, 114, 101, 45, 65, 110, 103, 117, 108, 97, 114, 32,
  105, 110, 99, 114, 101, 109, 101, 110, 116, 32, 47, 49, 48, 48, 32, 84,
  82, 69, 83, 32, 76, 69, 78, 84, 32, 47, 32, 86, 69, 82, 89, 32,
  83, 76, 79, 87, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  84, 121, 112, 101, 32, 100, 101, 32, 114, 101, 110, 100, 117, 32, 47, 32,
  114, 101, 110, 100, 101, 114, 105, 110, 103, 32, 116, 121, 112, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 111, 114, 109, 117, 108, 101,
  47, 70, 111, 114, 109, 117, 108, 97, 32, 49, 34, 44, 34, 70, 111, 114,
  109, 117, 108, 101, 47, 70, 111, 114, 109, 117, 108, 97, 32, 50, 34, 44,
  34, 70, 111, 114, 109, 117, 108, 101, 47, 70, 111, 114, 109, 117, 108, 97,
  32, 51, 34, 44, 34, 70, 111, 114, 109, 117, 108, 101, 47, 70, 111, 114,
  109, 117, 108, 97, 32, 52, 34, 44, 34, 70, 111, 114, 109, 117, 108, 101,
  47, 70, 111, 114, 109, 117, 108, 97, 32, 53, 34, 44, 34, 70, 111, 114,
  109, 117, 108, 101, 47, 70, 111, 114, 109, 117, 108, 97, 32, 54, 34, 44,
  34, 70, 111, 114, 109, 117, 108, 101, 47, 70, 111, 114, 109, 117, 108, 97,
  32, 55, 34, 44, 34, 70, 111, 114, 109, 117, 108, 101, 47, 70, 111, 114,
  109, 117, 108, 97, 32, 56, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 80, 111, 105, 110, 116, 115, 32, 40, 114, 97, 121, 111, 110, 47,
  114, 97, 100, 105, 117, 115, 41, 32, 61, 32, 105, 110, 116, 40, 48, 44,
  48, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80,
  111, 105, 110, 116, 115, 32, 40, 99, 111, 117, 108, 101, 117, 114, 47, 99,
  111, 108, 111, 114, 41, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50, 53,
  53, 44, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 76, 105, 103, 110, 101, 115, 32, 40, 101, 112, 97, 105,
  115, 115, 101, 117, 114, 47, 116, 104, 105, 99, 107, 110, 101, 115, 115, 41,
  32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 51, 50, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 76, 105, 103, 110, 101, 115, 32, 40,
  99, 111, 117, 108, 101, 117, 114, 47, 99, 111, 108, 111, 114, 41, 32, 61,
  32, 99, 111, 108, 111, 114, 40, 50, 53, 53, 44, 50, 53, 53, 44, 48,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 68, 105, 118, 101, 114, 115, 32, 47, 32, 70,
  111, 111, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 70, 108, 111, 117, 32, 47, 32, 98, 108, 117,
  114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 114, 101, 97,
  100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101, 102, 111, 114,
  109, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 66, 108, 101, 110, 100, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  77, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 49, 44,
  34, 65, 100, 100, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34, 65,
  110, 100, 34, 44, 34, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 66,
  108, 117, 101, 34, 44, 34, 66, 117, 114, 110, 34, 44, 34, 68, 97, 114,
  107, 101, 110, 34, 44, 34, 68, 105, 102, 102, 101, 114, 101, 110, 99, 101,
  34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 68, 105, 118,
  105, 100, 101, 34, 44, 34, 68, 111, 100, 103, 101, 34, 44, 34, 69, 120,
  99, 108, 117, 115, 105, 111, 110, 34, 44, 34, 70, 114, 101, 101, 122, 101,
  34, 44, 34, 71, 114, 97, 105, 110, 32, 101, 120, 116, 114, 97, 99, 116,
  34, 44, 34, 71, 114, 97, 105, 110, 32, 109, 101, 114, 103, 101, 34, 44,
  34, 71, 114, 101, 101, 110, 34, 44, 34, 72, 97, 114, 100, 32, 108, 105,
  103, 104, 116, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34,
  72, 97, 114, 100, 32, 109, 105, 120, 34, 44, 34, 72, 117, 101, 34, 44,
  34, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 34, 44,
  34, 76, 105, 103, 104, 116, 101, 110, 34, 44, 34, 76, 105, 103, 104, 116,
  110, 101, 115, 115, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 98, 117,
  114, 110, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 108, 105, 103, 104,
  116, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 77, 117, 108, 116, 105, 112,
  108, 121, 34, 44, 34, 78, 101, 103, 97, 116, 105, 111, 110, 34, 44, 34,
  79, 114, 34, 44, 34, 79, 118, 101, 114, 108, 97, 121, 34, 44, 34, 80,
  105, 110, 32, 108, 105, 103, 104, 116, 34, 44, 34, 82, 101, 100, 34, 44,
  34, 82, 101, 102, 108, 101, 99, 116, 34, 44, 34, 83, 97, 116, 117, 114,
  97, 116, 105, 111, 110, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101, 34,
  44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101, 48,
  34, 44, 34, 83, 111, 102, 116, 32, 98, 117, 114, 110, 34, 44, 34, 83,
  111, 102, 116, 32, 100, 111, 100, 103, 101, 34, 44, 34, 83, 111, 102, 116,
  32, 108, 105, 103, 104, 116, 34, 44, 34, 83, 99, 114, 101, 101, 110, 34,
  44, 34, 83, 116, 97, 109, 112, 34, 44, 34, 83, 117, 98, 116, 114, 97,
  99, 116, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 34, 86, 105, 118, 105, 100, 32, 108, 105, 103,
  104, 116, 34, 44, 34, 88, 111, 114, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121, 101, 114,
  115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32,
  116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70,
  117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58,
  32, 60, 105, 62, 83, 97, 109, 106, 60, 47, 105, 62, 46, 32, 32, 32,
  32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 49, 55,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  83, 112, 105, 114, 111, 103, 114, 97, 112, 104, 101, 95, 115, 97, 109, 106,
  32, 58, 10, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110,
  101, 95, 88, 61, 123, 36, 49, 47, 49, 48, 48, 42, 119, 125, 10, 99,
  101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 61,
  123, 36, 50, 47, 49, 48, 48, 42, 104, 125, 10, 82, 97, 121, 111, 110,
  95, 49, 61, 36, 51, 10, 82, 97, 121, 111, 110, 95, 50, 61, 36, 52,
  10, 80, 111, 115, 105, 116, 105, 111, 110, 95, 83, 116, 121, 108, 111, 61,
  36, 53, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121,
  108, 111, 61, 36, 54, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  83, 116, 121, 108, 111, 61, 36, 55, 10, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 83, 116, 121, 108, 111, 61, 36, 56, 10, 65, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 36, 57, 10, 86,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108,
  101, 117, 114, 61, 36, 49, 48, 10, 68, 105, 108, 97, 116, 101, 95, 83,
  116, 121, 108, 111, 61, 36, 49, 49, 10, 78, 111, 109, 98, 114, 101, 95,
  100, 101, 95, 116, 111, 117, 114, 115, 61, 36, 49, 50, 10, 77, 117, 108,
  116, 105, 112, 108, 105, 101, 114, 95, 116, 111, 117, 114, 115, 61, 36, 49,
  51, 10, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 117,
  108, 97, 105, 114, 101, 61, 36, 49, 52, 10, 68, 105, 118, 105, 115, 101,
  114, 95, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 117,
  108, 97, 105, 114, 101, 61, 36, 49, 53, 10, 84, 121, 112, 101, 95, 100,
  101, 95, 114, 101, 110, 100, 117, 61, 36, 49, 54, 10, 80, 111, 105, 110,
  116, 115, 95, 82, 97, 121, 111, 110, 61, 36, 49, 55, 10, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 80, 111, 105, 110, 116, 115, 61, 36, 49,
  56, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 80, 111, 105, 110,
  116, 115, 61, 36, 49, 57, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 80, 111, 105, 110, 116, 115, 61, 36, 50, 48, 10, 65, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 80, 111, 105, 110, 116, 115, 61, 36, 50, 49,
  10, 76, 105, 103, 110, 101, 115, 95, 101, 112, 97, 105, 115, 115, 101, 117,
  114, 61, 36, 50, 50, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  76, 105, 103, 110, 101, 115, 61, 36, 50, 51, 10, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 76, 105, 103, 110, 101, 115, 61, 36, 50, 52, 10,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 76, 105, 103, 110, 101, 115,
  61, 36, 50, 53, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 76,
  105, 103, 110, 101, 115, 61, 36, 50, 54, 10, 70, 108, 111, 117, 95, 83,
  112, 105, 114, 111, 103, 114, 97, 112, 104, 101, 61, 36, 50, 55, 10, 83,
  112, 114, 101, 97, 100, 95, 83, 112, 105, 114, 111, 103, 114, 97, 112, 104,
  101, 61, 36, 50, 56, 10, 68, 101, 102, 111, 114, 109, 95, 83, 112, 105,
  114, 111, 103, 114, 97, 112, 104, 101, 61, 36, 50, 57, 10, 98, 108, 101,
  110, 100, 61, 36, 51, 48, 10, 111, 112, 97, 99, 105, 116, 101, 61, 36,
  51, 49, 10, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115,
  61, 36, 51, 50, 10, 45, 116, 111, 95, 114, 103, 98, 97, 10, 123, 119,
  125, 44, 123, 104, 125, 44, 49, 44, 52, 10, 78, 98, 95, 66, 111, 117,
  99, 108, 101, 61, 49, 10, 116, 104, 101, 116, 97, 61, 48, 10, 65, 110,
  99, 105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 88, 61, 48, 10, 78,
  111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 88, 61, 48,
  10, 65, 110, 99, 105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 89, 61,
  48, 10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95,
  89, 61, 48, 10, 45, 105, 102, 32, 123, 36, 82, 97, 121, 111, 110, 95,
  50, 61, 61, 48, 125, 10, 82, 97, 121, 111, 110, 95, 50, 61, 49, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 77, 117, 108,
  116, 105, 112, 108, 105, 101, 114, 95, 116, 111, 117, 114, 115, 61, 61, 49,
  125, 10, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 116, 111, 117, 114,
  115, 61, 123, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 116, 111,
  117, 114, 115, 42, 49, 48, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 77, 117, 108, 116, 105, 112, 108, 105, 101, 114, 95,
  116, 111, 117, 114, 115, 61, 61, 50, 125, 10, 78, 111, 109, 98, 114, 101,
  95, 100, 101, 95, 116, 111, 117, 114, 115, 61, 123, 36, 78, 111, 109, 98,
  114, 101, 95, 100, 101, 95, 116, 111, 117, 114, 115, 42, 49, 48, 48, 125,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 68, 105,
  118, 105, 115, 101, 114, 95, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95,
  97, 110, 103, 117, 108, 97, 105, 114, 101, 61, 61, 49, 125, 10, 73, 110,
  99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 117, 108, 97, 105, 114,
  101, 61, 123, 36, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110,
  103, 117, 108, 97, 105, 114, 101, 47, 49, 48, 125, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 68, 105, 118, 105, 115, 101, 114,
  95, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 117, 108,
  97, 105, 114, 101, 61, 61, 50, 125, 10, 73, 110, 99, 114, 101, 109, 101,
  110, 116, 95, 97, 110, 103, 117, 108, 97, 105, 114, 101, 61, 123, 36, 73,
  110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 117, 108, 97, 105,
  114, 101, 47, 49, 48, 48, 125, 10, 45, 101, 110, 100, 105, 102, 10, 78,
  111, 109, 98, 114, 101, 95, 100, 101, 95, 116, 111, 117, 114, 115, 61, 123,
  36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 116, 111, 117, 114, 115,
  47, 36, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 117,
  108, 97, 105, 114, 101, 42, 51, 54, 48, 125, 10, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 61, 36, 82, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 10, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 61,
  36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111,
  10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105,
  110, 101, 61, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116,
  121, 108, 111, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114,
  105, 103, 105, 110, 101, 61, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 83, 116, 121, 108, 111, 10, 45, 105, 102, 32, 123, 36, 68, 105, 108,
  97, 116, 101, 95, 83, 116, 121, 108, 111, 62, 48, 125, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95,
  116, 111, 117, 114, 115, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114,
  61, 61, 49, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83,
  116, 121, 108, 111, 61, 123, 114, 111, 117, 110, 100, 40, 123, 40, 63, 40,
  50, 53, 53, 41, 41, 125, 41, 125, 10, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 83, 116, 121, 108, 111, 61, 123, 114, 111, 117, 110, 100, 40,
  123, 40, 63, 40, 50, 53, 53, 41, 41, 125, 41, 125, 10, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 123, 114, 111,
  117, 110, 100, 40, 123, 40, 63, 40, 50, 53, 53, 41, 41, 125, 41, 125,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101,
  117, 114, 62, 49, 125, 10, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 61, 49,
  54, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 61, 51, 125,
  10, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 99, 111, 117, 108, 101, 117, 114, 61, 51, 50, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 61,
  52, 125, 10, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 61, 54, 52, 10, 45,
  101, 110, 100, 105, 102, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  83, 116, 121, 108, 111, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101,
  43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 44, 36,
  86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10, 45, 105,
  102, 32, 123, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116,
  121, 108, 111, 62, 50, 53, 53, 125, 10, 82, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 83, 116, 121, 108, 111, 61, 36, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 83, 116, 121, 108, 111, 60, 48, 125, 10, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 36, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 10, 45,
  101, 110, 100, 105, 102, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  83, 116, 121, 108, 111, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101,
  43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 44, 36,
  86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10, 45, 105,
  102, 32, 123, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116,
  121, 108, 111, 62, 50, 53, 53, 125, 10, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 83, 116, 121, 108, 111, 61, 36, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 83, 116, 121, 108, 111, 60, 48, 125, 10, 86, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 36, 86, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 10, 45,
  101, 110, 100, 105, 102, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  83, 116, 121, 108, 111, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101,
  43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 44, 36,
  86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10, 45, 105,
  102, 32, 123, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116,
  121, 108, 111, 62, 50, 53, 53, 125, 10, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 83, 116, 121, 108, 111, 61, 36, 66, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 83, 116, 121, 108, 111, 60, 48, 125, 10, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 36, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 84, 121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100, 117,
  61, 61, 48, 125, 10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105,
  110, 116, 95, 88, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114,
  105, 103, 105, 110, 101, 95, 88, 43, 123, 123, 123, 36, 82, 97, 121, 111,
  110, 95, 49, 43, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 99,
  111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97,
  41, 125, 125, 45, 123, 123, 36, 82, 97, 121, 111, 110, 95, 50, 43, 36,
  80, 111, 115, 105, 116, 105, 111, 110, 95, 83, 116, 121, 108, 111, 125, 42,
  123, 99, 111, 115, 40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 43,
  36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111, 110,
  95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101,
  116, 97, 125, 41, 125, 125, 125, 125, 10, 78, 111, 117, 118, 101, 97, 117,
  95, 112, 111, 105, 110, 116, 95, 89, 61, 123, 36, 99, 101, 110, 116, 114,
  101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 43, 123, 123, 123, 36,
  82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97, 121, 111, 110, 95, 50,
  125, 42, 123, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116,
  104, 101, 116, 97, 41, 125, 125, 45, 123, 123, 36, 82, 97, 121, 111, 110,
  95, 50, 43, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 83, 116, 121,
  108, 111, 125, 42, 123, 115, 105, 110, 40, 123, 123, 36, 82, 97, 121, 111,
  110, 95, 49, 43, 36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36, 82,
  97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48, 42,
  36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125, 125, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95, 100,
  101, 95, 114, 101, 110, 100, 117, 61, 61, 49, 125, 10, 78, 111, 117, 118,
  101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 88, 61, 123, 36, 99, 101,
  110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 43, 123,
  123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97, 121, 111,
  110, 95, 50, 125, 42, 123, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48,
  42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 45, 123, 36, 80, 111, 115,
  105, 116, 105, 111, 110, 95, 83, 116, 121, 108, 111, 42, 123, 99, 111, 115,
  40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97, 121,
  111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42,
  123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125, 41,
  125, 125, 125, 125, 10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105,
  110, 116, 95, 89, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114,
  105, 103, 105, 110, 101, 95, 89, 43, 123, 123, 123, 36, 82, 97, 121, 111,
  110, 95, 49, 43, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 115,
  105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97,
  41, 125, 125, 45, 123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 83,
  116, 121, 108, 111, 42, 123, 115, 105, 110, 40, 123, 123, 36, 82, 97, 121,
  111, 110, 95, 49, 43, 36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36,
  82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48,
  42, 36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125, 125, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95,
  100, 101, 95, 114, 101, 110, 100, 117, 61, 61, 50, 125, 10, 78, 111, 117,
  118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 88, 61, 123, 36, 99,
  101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 43,
  123, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97, 121,
  111, 110, 95, 50, 125, 42, 123, 99, 111, 115, 40, 112, 105, 47, 49, 56,
  48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 45, 123, 123, 36, 82,
  97, 121, 111, 110, 95, 50, 43, 36, 80, 111, 115, 105, 116, 105, 111, 110,
  95, 83, 116, 121, 108, 111, 125, 42, 123, 99, 111, 115, 40, 123, 123, 36,
  82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97, 121, 111, 110, 95, 50,
  125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105, 47,
  49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125, 125,
  10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 89,
  61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110,
  101, 95, 89, 43, 123, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 43,
  36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 115, 105, 110, 40, 112,
  105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 45,
  123, 123, 36, 82, 97, 121, 111, 110, 95, 50, 43, 36, 80, 111, 115, 105,
  116, 105, 111, 110, 95, 83, 116, 121, 108, 111, 125, 42, 123, 115, 105, 110,
  40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97, 121,
  111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42,
  123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125, 41,
  125, 125, 125, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 84, 121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100, 117, 61,
  61, 51, 125, 10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110,
  116, 95, 88, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105,
  103, 105, 110, 101, 95, 88, 43, 123, 123, 123, 36, 82, 97, 121, 111, 110,
  95, 49, 43, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 99, 111,
  115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41,
  125, 125, 45, 123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 83, 116,
  121, 108, 111, 42, 123, 99, 111, 115, 40, 123, 123, 36, 82, 97, 121, 111,
  110, 95, 49, 45, 36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36, 82,
  97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48, 42,
  36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125, 125, 10, 78, 111, 117,
  118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 89, 61, 123, 36, 99,
  101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 43,
  123, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97, 121,
  111, 110, 95, 50, 125, 42, 123, 115, 105, 110, 40, 112, 105, 47, 49, 56,
  48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 45, 123, 36, 80, 111,
  115, 105, 116, 105, 111, 110, 95, 83, 116, 121, 108, 111, 42, 123, 115, 105,
  110, 40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97,
  121, 111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125,
  42, 123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125,
  41, 125, 125, 125, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 84, 121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100, 117,
  61, 61, 52, 125, 10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105,
  110, 116, 95, 88, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114,
  105, 103, 105, 110, 101, 95, 88, 43, 123, 123, 123, 36, 82, 97, 121, 111,
  110, 95, 49, 45, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 99,
  111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97,
  41, 125, 125, 45, 123, 123, 36, 82, 97, 121, 111, 110, 95, 50, 43, 36,
  80, 111, 115, 105, 116, 105, 111, 110, 95, 83, 116, 121, 108, 111, 125, 42,
  123, 99, 111, 115, 40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 45,
  36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111, 110,
  95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101,
  116, 97, 125, 41, 125, 125, 125, 125, 10, 78, 111, 117, 118, 101, 97, 117,
  95, 112, 111, 105, 110, 116, 95, 89, 61, 123, 36, 99, 101, 110, 116, 114,
  101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 43, 123, 123, 123, 36,
  82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97, 121, 111, 110, 95, 50,
  125, 42, 123, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116,
  104, 101, 116, 97, 41, 125, 125, 45, 123, 123, 36, 82, 97, 121, 111, 110,
  95, 50, 43, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 83, 116, 121,
  108, 111, 125, 42, 123, 115, 105, 110, 40, 123, 123, 36, 82, 97, 121, 111,
  110, 95, 49, 45, 36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36, 82,
  97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48, 42,
  36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125, 125, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95, 100,
  101, 95, 114, 101, 110, 100, 117, 61, 61, 53, 125, 10, 78, 111, 117, 118,
  101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 88, 61, 123, 36, 99, 101,
  110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 43, 123,
  123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97, 121, 111,
  110, 95, 50, 125, 42, 123, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48,
  42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 45, 123, 36, 80, 111, 115,
  105, 116, 105, 111, 110, 95, 83, 116, 121, 108, 111, 42, 123, 99, 111, 115,
  40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97, 121,
  111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42,
  123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125, 41,
  125, 125, 125, 125, 10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105,
  110, 116, 95, 89, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114,
  105, 103, 105, 110, 101, 95, 89, 43, 123, 123, 123, 36, 82, 97, 121, 111,
  110, 95, 49, 45, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 115,
  105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97,
  41, 125, 125, 45, 123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 83,
  116, 121, 108, 111, 42, 123, 115, 105, 110, 40, 123, 123, 36, 82, 97, 121,
  111, 110, 95, 49, 45, 36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36,
  82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48,
  42, 36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125, 125, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95,
  100, 101, 95, 114, 101, 110, 100, 117, 61, 61, 54, 125, 10, 78, 111, 117,
  118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 88, 61, 123, 36, 99,
  101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 43,
  123, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97, 121,
  111, 110, 95, 50, 125, 42, 123, 99, 111, 115, 40, 112, 105, 47, 49, 56,
  48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 45, 123, 123, 36, 82,
  97, 121, 111, 110, 95, 50, 43, 36, 80, 111, 115, 105, 116, 105, 111, 110,
  95, 83, 116, 121, 108, 111, 125, 42, 123, 99, 111, 115, 40, 123, 123, 36,
  82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97, 121, 111, 110, 95, 50,
  125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105, 47,
  49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125, 125,
  10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 89,
  61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110,
  101, 95, 89, 43, 123, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 45,
  36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 115, 105, 110, 40, 112,
  105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 45,
  123, 123, 36, 82, 97, 121, 111, 110, 95, 50, 43, 36, 80, 111, 115, 105,
  116, 105, 111, 110, 95, 83, 116, 121, 108, 111, 125, 42, 123, 115, 105, 110,
  40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97, 121,
  111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42,
  123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125, 41,
  125, 125, 125, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 84, 121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100, 117, 61,
  61, 55, 125, 10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110,
  116, 95, 88, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105,
  103, 105, 110, 101, 95, 88, 43, 123, 123, 123, 36, 82, 97, 121, 111, 110,
  95, 49, 45, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 99, 111,
  115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41,
  125, 125, 45, 123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 83, 116,
  121, 108, 111, 42, 123, 99, 111, 115, 40, 123, 123, 36, 82, 97, 121, 111,
  110, 95, 49, 43, 36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36, 82,
  97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48, 42,
  36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125, 125, 10, 78, 111, 117,
  118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 89, 61, 123, 36, 99,
  101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 43,
  123, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97, 121,
  111, 110, 95, 50, 125, 42, 123, 115, 105, 110, 40, 112, 105, 47, 49, 56,
  48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 45, 123, 36, 80, 111,
  115, 105, 116, 105, 111, 110, 95, 83, 116, 121, 108, 111, 42, 123, 115, 105,
  110, 40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97,
  121, 111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125,
  42, 123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125,
  41, 125, 125, 125, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 78, 98, 95, 66, 111, 117, 99, 108, 101, 62, 49, 125, 10,
  45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 65, 110, 99, 105, 101,
  110, 95, 112, 111, 105, 110, 116, 95, 88, 44, 36, 65, 110, 99, 105, 101,
  110, 95, 112, 111, 105, 110, 116, 95, 89, 44, 36, 78, 111, 117, 118, 101,
  97, 117, 95, 112, 111, 105, 110, 116, 95, 88, 44, 36, 78, 111, 117, 118,
  101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 89, 44, 49, 44, 36, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 44, 36,
  86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 44,
  36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111,
  44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108,
  111, 10, 45, 101, 110, 100, 105, 102, 10, 65, 110, 99, 105, 101, 110, 95,
  112, 111, 105, 110, 116, 95, 88, 61, 36, 78, 111, 117, 118, 101, 97, 117,
  95, 112, 111, 105, 110, 116, 95, 88, 10, 65, 110, 99, 105, 101, 110, 95,
  112, 111, 105, 110, 116, 95, 89, 61, 36, 78, 111, 117, 118, 101, 97, 117,
  95, 112, 111, 105, 110, 116, 95, 89, 10, 116, 104, 101, 116, 97, 61, 123,
  36, 116, 104, 101, 116, 97, 43, 36, 73, 110, 99, 114, 101, 109, 101, 110,
  116, 95, 97, 110, 103, 117, 108, 97, 105, 114, 101, 125, 10, 78, 98, 95,
  66, 111, 117, 99, 108, 101, 61, 123, 36, 78, 98, 95, 66, 111, 117, 99,
  108, 101, 43, 49, 125, 10, 45, 100, 111, 110, 101, 10, 45, 100, 105, 108,
  97, 116, 101, 95, 99, 105, 114, 99, 91, 45, 49, 93, 32, 36, 68, 105,
  108, 97, 116, 101, 95, 83, 116, 121, 108, 111, 10, 78, 98, 95, 66, 111,
  117, 99, 108, 101, 61, 49, 10, 116, 104, 101, 116, 97, 61, 48, 10, 65,
  110, 99, 105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 88, 61, 48, 10,
  78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 88, 61,
  48, 10, 65, 110, 99, 105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 89,
  61, 48, 10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116,
  95, 89, 61, 48, 10, 45, 105, 102, 32, 123, 123, 36, 76, 105, 103, 110,
  101, 115, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114, 62, 48, 125, 124,
  124, 123, 36, 80, 111, 105, 110, 116, 115, 95, 82, 97, 121, 111, 110, 62,
  48, 125, 125, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 78, 111, 109,
  98, 114, 101, 95, 100, 101, 95, 116, 111, 117, 114, 115, 10, 45, 105, 102,
  32, 123, 36, 84, 121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100, 117,
  61, 61, 48, 125, 10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105,
  110, 116, 95, 88, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114,
  105, 103, 105, 110, 101, 95, 88, 43, 123, 123, 123, 36, 82, 97, 121, 111,
  110, 95, 49, 43, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 99,
  111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97,
  41, 125, 125, 45, 123, 123, 36, 82, 97, 121, 111, 110, 95, 50, 43, 36,
  80, 111, 115, 105, 116, 105, 111, 110, 95, 83, 116, 121, 108, 111, 125, 42,
  123, 99, 111, 115, 40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 43,
  36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111, 110,
  95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101,
  116, 97, 125, 41, 125, 125, 125, 125, 10, 78, 111, 117, 118, 101, 97, 117,
  95, 112, 111, 105, 110, 116, 95, 89, 61, 123, 36, 99, 101, 110, 116, 114,
  101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 43, 123, 123, 123, 36,
  82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97, 121, 111, 110, 95, 50,
  125, 42, 123, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116,
  104, 101, 116, 97, 41, 125, 125, 45, 123, 123, 36, 82, 97, 121, 111, 110,
  95, 50, 43, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 83, 116, 121,
  108, 111, 125, 42, 123, 115, 105, 110, 40, 123, 123, 36, 82, 97, 121, 111,
  110, 95, 49, 43, 36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36, 82,
  97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48, 42,
  36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125, 125, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95, 100,
  101, 95, 114, 101, 110, 100, 117, 61, 61, 49, 125, 10, 78, 111, 117, 118,
  101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 88, 61, 123, 36, 99, 101,
  110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 43, 123,
  123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97, 121, 111,
  110, 95, 50, 125, 42, 123, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48,
  42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 45, 123, 36, 80, 111, 115,
  105, 116, 105, 111, 110, 95, 83, 116, 121, 108, 111, 42, 123, 99, 111, 115,
  40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97, 121,
  111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42,
  123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125, 41,
  125, 125, 125, 125, 10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105,
  110, 116, 95, 89, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114,
  105, 103, 105, 110, 101, 95, 89, 43, 123, 123, 123, 36, 82, 97, 121, 111,
  110, 95, 49, 43, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 115,
  105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97,
  41, 125, 125, 45, 123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 83,
  116, 121, 108, 111, 42, 123, 115, 105, 110, 40, 123, 123, 36, 82, 97, 121,
  111, 110, 95, 49, 43, 36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36,
  82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48,
  42, 36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125, 125, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95,
  100, 101, 95, 114, 101, 110, 100, 117, 61, 61, 50, 125, 10, 78, 111, 117,
  118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 88, 61, 123, 36, 99,
  101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 43,
  123, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97, 121,
  111, 110, 95, 50, 125, 42, 123, 99, 111, 115, 40, 112, 105, 47, 49, 56,
  48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 45, 123, 123, 36, 82,
  97, 121, 111, 110, 95, 50, 43, 36, 80, 111, 115, 105, 116, 105, 111, 110,
  95, 83, 116, 121, 108, 111, 125, 42, 123, 99, 111, 115, 40, 123, 123, 36,
  82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97, 121, 111, 110, 95, 50,
  125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105, 47,
  49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125, 125,
  10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 89,
  61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110,
  101, 95, 89, 43, 123, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 43,
  36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 115, 105, 110, 40, 112,
  105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 45,
  123, 123, 36, 82, 97, 121, 111, 110, 95, 50, 43, 36, 80, 111, 115, 105,
  116, 105, 111, 110, 95, 83, 116, 121, 108, 111, 125, 42, 123, 115, 105, 110,
  40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97, 121,
  111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42,
  123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125, 41,
  125, 125, 125, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 84, 121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100, 117, 61,
  61, 51, 125, 10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110,
  116, 95, 88, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105,
  103, 105, 110, 101, 95, 88, 43, 123, 123, 123, 36, 82, 97, 121, 111, 110,
  95, 49, 43, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 99, 111,
  115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41,
  125, 125, 45, 123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 83, 116,
  121, 108, 111, 42, 123, 99, 111, 115, 40, 123, 123, 36, 82, 97, 121, 111,
  110, 95, 49, 45, 36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36, 82,
  97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48, 42,
  36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125, 125, 10, 78, 111, 117,
  118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 89, 61, 123, 36, 99,
  101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 43,
  123, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97, 121,
  111, 110, 95, 50, 125, 42, 123, 115, 105, 110, 40, 112, 105, 47, 49, 56,
  48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 45, 123, 36, 80, 111,
  115, 105, 116, 105, 111, 110, 95, 83, 116, 121, 108, 111, 42, 123, 115, 105,
  110, 40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97,
  121, 111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125,
  42, 123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125,
  41, 125, 125, 125, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 84, 121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100, 117,
  61, 61, 52, 125, 10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105,
  110, 116, 95, 88, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114,
  105, 103, 105, 110, 101, 95, 88, 43, 123, 123, 123, 36, 82, 97, 121, 111,
  110, 95, 49, 45, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 99,
  111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97,
  41, 125, 125, 45, 123, 123, 36, 82, 97, 121, 111, 110, 95, 50, 43, 36,
  80, 111, 115, 105, 116, 105, 111, 110, 95, 83, 116, 121, 108, 111, 125, 42,
  123, 99, 111, 115, 40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 45,
  36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111, 110,
  95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101,
  116, 97, 125, 41, 125, 125, 125, 125, 10, 78, 111, 117, 118, 101, 97, 117,
  95, 112, 111, 105, 110, 116, 95, 89, 61, 123, 36, 99, 101, 110, 116, 114,
  101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 43, 123, 123, 123, 36,
  82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97, 121, 111, 110, 95, 50,
  125, 42, 123, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116,
  104, 101, 116, 97, 41, 125, 125, 45, 123, 123, 36, 82, 97, 121, 111, 110,
  95, 50, 43, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 83, 116, 121,
  108, 111, 125, 42, 123, 115, 105, 110, 40, 123, 123, 36, 82, 97, 121, 111,
  110, 95, 49, 45, 36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36, 82,
  97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48, 42,
  36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125, 125, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95, 100,
  101, 95, 114, 101, 110, 100, 117, 61, 61, 53, 125, 10, 78, 111, 117, 118,
  101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 88, 61, 123, 36, 99, 101,
  110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 43, 123,
  123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97, 121, 111,
  110, 95, 50, 125, 42, 123, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48,
  42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 45, 123, 36, 80, 111, 115,
  105, 116, 105, 111, 110, 95, 83, 116, 121, 108, 111, 42, 123, 99, 111, 115,
  40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97, 121,
  111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42,
  123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125, 41,
  125, 125, 125, 125, 10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105,
  110, 116, 95, 89, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114,
  105, 103, 105, 110, 101, 95, 89, 43, 123, 123, 123, 36, 82, 97, 121, 111,
  110, 95, 49, 45, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 115,
  105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97,
  41, 125, 125, 45, 123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 83,
  116, 121, 108, 111, 42, 123, 115, 105, 110, 40, 123, 123, 36, 82, 97, 121,
  111, 110, 95, 49, 45, 36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36,
  82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48,
  42, 36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125, 125, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95,
  100, 101, 95, 114, 101, 110, 100, 117, 61, 61, 54, 125, 10, 78, 111, 117,
  118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 88, 61, 123, 36, 99,
  101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 43,
  123, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97, 121,
  111, 110, 95, 50, 125, 42, 123, 99, 111, 115, 40, 112, 105, 47, 49, 56,
  48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 45, 123, 123, 36, 82,
  97, 121, 111, 110, 95, 50, 43, 36, 80, 111, 115, 105, 116, 105, 111, 110,
  95, 83, 116, 121, 108, 111, 125, 42, 123, 99, 111, 115, 40, 123, 123, 36,
  82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97, 121, 111, 110, 95, 50,
  125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105, 47,
  49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125, 125,
  10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 89,
  61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110,
  101, 95, 89, 43, 123, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 45,
  36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 115, 105, 110, 40, 112,
  105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 45,
  123, 123, 36, 82, 97, 121, 111, 110, 95, 50, 43, 36, 80, 111, 115, 105,
  116, 105, 111, 110, 95, 83, 116, 121, 108, 111, 125, 42, 123, 115, 105, 110,
  40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97, 121,
  111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42,
  123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125, 41,
  125, 125, 125, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 84, 121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100, 117, 61,
  61, 55, 125, 10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110,
  116, 95, 88, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105,
  103, 105, 110, 101, 95, 88, 43, 123, 123, 123, 36, 82, 97, 121, 111, 110,
  95, 49, 45, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 99, 111,
  115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41,
  125, 125, 45, 123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 83, 116,
  121, 108, 111, 42, 123, 99, 111, 115, 40, 123, 123, 36, 82, 97, 121, 111,
  110, 95, 49, 43, 36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36, 82,
  97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48, 42,
  36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125, 125, 10, 78, 111, 117,
  118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 89, 61, 123, 36, 99,
  101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 43,
  123, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97, 121,
  111, 110, 95, 50, 125, 42, 123, 115, 105, 110, 40, 112, 105, 47, 49, 56,
  48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 45, 123, 36, 80, 111,
  115, 105, 116, 105, 111, 110, 95, 83, 116, 121, 108, 111, 42, 123, 115, 105,
  110, 40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97,
  121, 111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125,
  42, 123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125,
  41, 125, 125, 125, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 78, 98, 95, 66, 111, 117, 99, 108, 101, 62, 49, 125, 10,
  45, 105, 102, 32, 123, 36, 76, 105, 103, 110, 101, 115, 95, 101, 112, 97,
  105, 115, 115, 101, 117, 114, 62, 48, 125, 10, 45, 105, 102, 32, 123, 36,
  80, 111, 105, 110, 116, 115, 95, 82, 97, 121, 111, 110, 62, 48, 125, 10,
  45, 99, 105, 114, 99, 108, 101, 91, 45, 49, 93, 32, 36, 65, 110, 99,
  105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 88, 44, 36, 65, 110, 99,
  105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 89, 44, 36, 80, 111, 105,
  110, 116, 115, 95, 82, 97, 121, 111, 110, 44, 49, 44, 36, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 80, 111, 105, 110, 116, 115, 44, 36, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 80, 111, 105, 110, 116, 115, 44,
  36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 80, 111, 105, 110, 116,
  115, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 80, 111, 105,
  110, 116, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 116, 114, 97, 105,
  116, 95, 101, 112, 97, 105, 115, 95, 115, 97, 109, 106, 32, 36, 65, 110,
  99, 105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 88, 44, 36, 65, 110,
  99, 105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 89, 44, 36, 78, 111,
  117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 88, 44, 36, 78,
  111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 89, 44, 36,
  76, 105, 103, 110, 101, 115, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114,
  44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 76, 105,
  103, 110, 101, 115, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  76, 105, 103, 110, 101, 115, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 76, 105, 103, 110, 101, 115, 44, 36, 65, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 76, 105, 103, 110, 101, 115, 10, 45, 105, 102, 32, 123,
  36, 80, 111, 105, 110, 116, 115, 95, 82, 97, 121, 111, 110, 62, 48, 125,
  10, 45, 99, 105, 114, 99, 108, 101, 91, 45, 49, 93, 32, 36, 78, 111,
  117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 88, 44, 36, 78,
  111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 89, 44, 36,
  80, 111, 105, 110, 116, 115, 95, 82, 97, 121, 111, 110, 44, 49, 44, 36,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 80, 111, 105, 110, 116, 115,
  44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 80, 111, 105, 110,
  116, 115, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 80, 111,
  105, 110, 116, 115, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  80, 111, 105, 110, 116, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 80, 111, 105, 110, 116,
  115, 95, 82, 97, 121, 111, 110, 62, 48, 125, 10, 45, 105, 102, 32, 123,
  36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111,
  117, 108, 101, 117, 114, 61, 61, 49, 125, 10, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 80, 111, 105, 110, 116, 115, 61, 123, 114, 111, 117, 110,
  100, 40, 123, 40, 63, 40, 50, 53, 53, 41, 41, 125, 41, 125, 10, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 80, 111, 105, 110, 116, 115, 61,
  123, 114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 53, 53, 41, 41,
  125, 41, 125, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 80, 111,
  105, 110, 116, 115, 61, 123, 114, 111, 117, 110, 100, 40, 123, 40, 63, 40,
  50, 53, 53, 41, 41, 125, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 99, 105, 114, 99, 108, 101, 91, 45, 49, 93, 32, 36, 65, 110, 99,
  105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 88, 44, 36, 65, 110, 99,
  105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 89, 44, 36, 80, 111, 105,
  110, 116, 115, 95, 82, 97, 121, 111, 110, 44, 49, 44, 36, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 80, 111, 105, 110, 116, 115, 44, 36, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 80, 111, 105, 110, 116, 115, 44,
  36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 80, 111, 105, 110, 116,
  115, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 80, 111, 105,
  110, 116, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105,
  102, 10, 65, 110, 99, 105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 88,
  61, 36, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95,
  88, 10, 65, 110, 99, 105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 89,
  61, 36, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95,
  89, 10, 116, 104, 101, 116, 97, 61, 123, 36, 116, 104, 101, 116, 97, 43,
  36, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 117, 108,
  97, 105, 114, 101, 125, 10, 78, 98, 95, 66, 111, 117, 99, 108, 101, 61,
  123, 36, 78, 98, 95, 66, 111, 117, 99, 108, 101, 43, 49, 125, 10, 45,
  100, 111, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 108, 115,
  101, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 78, 111, 109, 98, 114,
  101, 95, 100, 101, 95, 116, 111, 117, 114, 115, 10, 45, 105, 102, 32, 123,
  36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111,
  117, 108, 101, 117, 114, 61, 61, 49, 125, 10, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 123, 114, 111, 117, 110, 100,
  40, 123, 40, 63, 40, 50, 53, 53, 41, 41, 125, 41, 125, 10, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 123, 114,
  111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 53, 53, 41, 41, 125, 41,
  125, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108,
  111, 61, 123, 114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 53, 53,
  41, 41, 125, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95,
  99, 111, 117, 108, 101, 117, 114, 62, 49, 125, 10, 86, 97, 108, 101, 117,
  114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108,
  101, 117, 114, 61, 49, 54, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117,
  114, 61, 61, 51, 125, 10, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 61, 51,
  50, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108,
  101, 117, 114, 61, 61, 52, 125, 10, 86, 97, 108, 101, 117, 114, 95, 118,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114,
  61, 54, 52, 10, 45, 101, 110, 100, 105, 102, 10, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 123, 114, 111, 117, 110,
  100, 40, 123, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114,
  105, 103, 105, 110, 101, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117,
  114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108,
  101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125,
  41, 125, 10, 45, 105, 102, 32, 123, 36, 82, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 83, 116, 121, 108, 111, 62, 50, 53, 53, 125, 10, 82, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 36, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 60, 48, 125,
  10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111,
  61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103,
  105, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 123, 114, 111, 117, 110,
  100, 40, 123, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114,
  105, 103, 105, 110, 101, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117,
  114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108,
  101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125,
  41, 125, 10, 45, 105, 102, 32, 123, 36, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 83, 116, 121, 108, 111, 62, 50, 53, 53, 125, 10, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 36, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 60, 48, 125,
  10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111,
  61, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103,
  105, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 66, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 123, 114, 111, 117, 110,
  100, 40, 123, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114,
  105, 103, 105, 110, 101, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117,
  114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108,
  101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125,
  41, 125, 10, 45, 105, 102, 32, 123, 36, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 83, 116, 121, 108, 111, 62, 50, 53, 53, 125, 10, 66, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 61, 36, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 66, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111, 60, 48, 125,
  10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121, 108, 111,
  61, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103,
  105, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95, 100, 101, 95,
  114, 101, 110, 100, 117, 61, 61, 48, 125, 10, 78, 111, 117, 118, 101, 97,
  117, 95, 112, 111, 105, 110, 116, 95, 88, 61, 123, 36, 99, 101, 110, 116,
  114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 43, 123, 123, 123,
  36, 82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97, 121, 111, 110, 95,
  50, 125, 42, 123, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36,
  116, 104, 101, 116, 97, 41, 125, 125, 45, 123, 123, 36, 82, 97, 121, 111,
  110, 95, 50, 43, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 83, 116,
  121, 108, 111, 125, 42, 123, 99, 111, 115, 40, 123, 123, 36, 82, 97, 121,
  111, 110, 95, 49, 43, 36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36,
  82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48,
  42, 36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125, 125, 10, 78, 111,
  117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 89, 61, 123, 36,
  99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89,
  43, 123, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97,
  121, 111, 110, 95, 50, 125, 42, 123, 115, 105, 110, 40, 112, 105, 47, 49,
  56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 45, 123, 123, 36,
  82, 97, 121, 111, 110, 95, 50, 43, 36, 80, 111, 115, 105, 116, 105, 111,
  110, 95, 83, 116, 121, 108, 111, 125, 42, 123, 115, 105, 110, 40, 123, 123,
  36, 82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97, 121, 111, 110, 95,
  50, 125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105,
  47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125,
  125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84,
  121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100, 117, 61, 61, 49, 125,
  10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 88,
  61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110,
  101, 95, 88, 43, 123, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 43,
  36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 99, 111, 115, 40, 112,
  105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 45,
  123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 83, 116, 121, 108, 111,
  42, 123, 99, 111, 115, 40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49,
  43, 36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111,
  110, 95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104,
  101, 116, 97, 125, 41, 125, 125, 125, 125, 10, 78, 111, 117, 118, 101, 97,
  117, 95, 112, 111, 105, 110, 116, 95, 89, 61, 123, 36, 99, 101, 110, 116,
  114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 43, 123, 123, 123,
  36, 82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97, 121, 111, 110, 95,
  50, 125, 42, 123, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36,
  116, 104, 101, 116, 97, 41, 125, 125, 45, 123, 36, 80, 111, 115, 105, 116,
  105, 111, 110, 95, 83, 116, 121, 108, 111, 42, 123, 115, 105, 110, 40, 123,
  123, 36, 82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97, 121, 111, 110,
  95, 50, 125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 112,
  105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125, 41, 125, 125,
  125, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  84, 121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100, 117, 61, 61, 50,
  125, 10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95,
  88, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105,
  110, 101, 95, 88, 43, 123, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49,
  43, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 99, 111, 115, 40,
  112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125,
  45, 123, 123, 36, 82, 97, 121, 111, 110, 95, 50, 43, 36, 80, 111, 115,
  105, 116, 105, 111, 110, 95, 83, 116, 121, 108, 111, 125, 42, 123, 99, 111,
  115, 40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97,
  121, 111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125,
  42, 123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125,
  41, 125, 125, 125, 125, 10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111,
  105, 110, 116, 95, 89, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111,
  114, 105, 103, 105, 110, 101, 95, 89, 43, 123, 123, 123, 36, 82, 97, 121,
  111, 110, 95, 49, 43, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123,
  115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116,
  97, 41, 125, 125, 45, 123, 123, 36, 82, 97, 121, 111, 110, 95, 50, 43,
  36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 83, 116, 121, 108, 111, 125,
  42, 123, 115, 105, 110, 40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49,
  45, 36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111,
  110, 95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104,
  101, 116, 97, 125, 41, 125, 125, 125, 125, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95, 100, 101, 95, 114,
  101, 110, 100, 117, 61, 61, 51, 125, 10, 78, 111, 117, 118, 101, 97, 117,
  95, 112, 111, 105, 110, 116, 95, 88, 61, 123, 36, 99, 101, 110, 116, 114,
  101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 43, 123, 123, 123, 36,
  82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97, 121, 111, 110, 95, 50,
  125, 42, 123, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116,
  104, 101, 116, 97, 41, 125, 125, 45, 123, 36, 80, 111, 115, 105, 116, 105,
  111, 110, 95, 83, 116, 121, 108, 111, 42, 123, 99, 111, 115, 40, 123, 123,
  36, 82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97, 121, 111, 110, 95,
  50, 125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105,
  47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125,
  125, 10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95,
  89, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105,
  110, 101, 95, 89, 43, 123, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49,
  43, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 115, 105, 110, 40,
  112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125,
  45, 123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 83, 116, 121, 108,
  111, 42, 123, 115, 105, 110, 40, 123, 123, 36, 82, 97, 121, 111, 110, 95,
  49, 45, 36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36, 82, 97, 121,
  111, 110, 95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48, 42, 36, 116,
  104, 101, 116, 97, 125, 41, 125, 125, 125, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95, 100, 101, 95,
  114, 101, 110, 100, 117, 61, 61, 52, 125, 10, 78, 111, 117, 118, 101, 97,
  117, 95, 112, 111, 105, 110, 116, 95, 88, 61, 123, 36, 99, 101, 110, 116,
  114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 43, 123, 123, 123,
  36, 82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97, 121, 111, 110, 95,
  50, 125, 42, 123, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36,
  116, 104, 101, 116, 97, 41, 125, 125, 45, 123, 123, 36, 82, 97, 121, 111,
  110, 95, 50, 43, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 83, 116,
  121, 108, 111, 125, 42, 123, 99, 111, 115, 40, 123, 123, 36, 82, 97, 121,
  111, 110, 95, 49, 45, 36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36,
  82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48,
  42, 36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125, 125, 10, 78, 111,
  117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 89, 61, 123, 36,
  99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89,
  43, 123, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97,
  121, 111, 110, 95, 50, 125, 42, 123, 115, 105, 110, 40, 112, 105, 47, 49,
  56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 45, 123, 123, 36,
  82, 97, 121, 111, 110, 95, 50, 43, 36, 80, 111, 115, 105, 116, 105, 111,
  110, 95, 83, 116, 121, 108, 111, 125, 42, 123, 115, 105, 110, 40, 123, 123,
  36, 82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97, 121, 111, 110, 95,
  50, 125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105,
  47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125,
  125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 84,
  121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100, 117, 61, 61, 53, 125,
  10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 88,
  61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110,
  101, 95, 88, 43, 123, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 45,
  36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 99, 111, 115, 40, 112,
  105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125, 45,
  123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 83, 116, 121, 108, 111,
  42, 123, 99, 111, 115, 40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49,
  45, 36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111,
  110, 95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104,
  101, 116, 97, 125, 41, 125, 125, 125, 125, 10, 78, 111, 117, 118, 101, 97,
  117, 95, 112, 111, 105, 110, 116, 95, 89, 61, 123, 36, 99, 101, 110, 116,
  114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 43, 123, 123, 123,
  36, 82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97, 121, 111, 110, 95,
  50, 125, 42, 123, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36,
  116, 104, 101, 116, 97, 41, 125, 125, 45, 123, 36, 80, 111, 115, 105, 116,
  105, 111, 110, 95, 83, 116, 121, 108, 111, 42, 123, 115, 105, 110, 40, 123,
  123, 36, 82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97, 121, 111, 110,
  95, 50, 125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 112,
  105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125, 41, 125, 125,
  125, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  84, 121, 112, 101, 95, 100, 101, 95, 114, 101, 110, 100, 117, 61, 61, 54,
  125, 10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95,
  88, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105,
  110, 101, 95, 88, 43, 123, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49,
  45, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 99, 111, 115, 40,
  112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125,
  45, 123, 123, 36, 82, 97, 121, 111, 110, 95, 50, 43, 36, 80, 111, 115,
  105, 116, 105, 111, 110, 95, 83, 116, 121, 108, 111, 125, 42, 123, 99, 111,
  115, 40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97,
  121, 111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125,
  42, 123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125,
  41, 125, 125, 125, 125, 10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111,
  105, 110, 116, 95, 89, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111,
  114, 105, 103, 105, 110, 101, 95, 89, 43, 123, 123, 123, 36, 82, 97, 121,
  111, 110, 95, 49, 45, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123,
  115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116,
  97, 41, 125, 125, 45, 123, 123, 36, 82, 97, 121, 111, 110, 95, 50, 43,
  36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 83, 116, 121, 108, 111, 125,
  42, 123, 115, 105, 110, 40, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49,
  43, 36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36, 82, 97, 121, 111,
  110, 95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104,
  101, 116, 97, 125, 41, 125, 125, 125, 125, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 84, 121, 112, 101, 95, 100, 101, 95, 114,
  101, 110, 100, 117, 61, 61, 55, 125, 10, 78, 111, 117, 118, 101, 97, 117,
  95, 112, 111, 105, 110, 116, 95, 88, 61, 123, 36, 99, 101, 110, 116, 114,
  101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 43, 123, 123, 123, 36,
  82, 97, 121, 111, 110, 95, 49, 45, 36, 82, 97, 121, 111, 110, 95, 50,
  125, 42, 123, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116,
  104, 101, 116, 97, 41, 125, 125, 45, 123, 36, 80, 111, 115, 105, 116, 105,
  111, 110, 95, 83, 116, 121, 108, 111, 42, 123, 99, 111, 115, 40, 123, 123,
  36, 82, 97, 121, 111, 110, 95, 49, 43, 36, 82, 97, 121, 111, 110, 95,
  50, 125, 47, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 112, 105,
  47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 125, 41, 125, 125, 125,
  125, 10, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95,
  89, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105,
  110, 101, 95, 89, 43, 123, 123, 123, 36, 82, 97, 121, 111, 110, 95, 49,
  45, 36, 82, 97, 121, 111, 110, 95, 50, 125, 42, 123, 115, 105, 110, 40,
  112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 125,
  45, 123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 83, 116, 121, 108,
  111, 42, 123, 115, 105, 110, 40, 123, 123, 36, 82, 97, 121, 111, 110, 95,
  49, 43, 36, 82, 97, 121, 111, 110, 95, 50, 125, 47, 36, 82, 97, 121,
  111, 110, 95, 50, 125, 42, 123, 112, 105, 47, 49, 56, 48, 42, 36, 116,
  104, 101, 116, 97, 125, 41, 125, 125, 125, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 78, 98, 95, 66, 111, 117, 99, 108,
  101, 62, 49, 125, 10, 45, 105, 102, 32, 123, 36, 76, 105, 103, 110, 101,
  115, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114, 62, 48, 125, 10, 45,
  105, 102, 32, 123, 36, 80, 111, 105, 110, 116, 115, 95, 82, 97, 121, 111,
  110, 62, 48, 125, 10, 45, 99, 105, 114, 99, 108, 101, 91, 45, 49, 93,
  32, 36, 65, 110, 99, 105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 88,
  44, 36, 65, 110, 99, 105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 89,
  44, 36, 80, 111, 105, 110, 116, 115, 95, 82, 97, 121, 111, 110, 44, 49,
  44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 80, 111, 105, 110,
  116, 115, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 80, 111,
  105, 110, 116, 115, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  80, 111, 105, 110, 116, 115, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 80, 111, 105, 110, 116, 115, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 116, 114, 97, 105, 116, 95, 101, 112, 97, 105, 115, 95, 115, 97, 109,
  106, 32, 36, 65, 110, 99, 105, 101, 110, 95, 112, 111, 105, 110, 116, 95,
  88, 44, 36, 65, 110, 99, 105, 101, 110, 95, 112, 111, 105, 110, 116, 95,
  89, 44, 36, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116,
  95, 88, 44, 36, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110,
  116, 95, 89, 44, 36, 76, 105, 103, 110, 101, 115, 95, 101, 112, 97, 105,
  115, 115, 101, 117, 114, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 76, 105, 103, 110, 101, 115, 44, 36, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 76, 105, 103, 110, 101, 115, 44, 36, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 76, 105, 103, 110, 101, 115, 44, 36, 65,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 76, 105, 103, 110, 101, 115, 10,
  45, 105, 102, 32, 123, 36, 80, 111, 105, 110, 116, 115, 95, 82, 97, 121,
  111, 110, 62, 48, 125, 10, 45, 99, 105, 114, 99, 108, 101, 91, 45, 49,
  93, 32, 36, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116,
  95, 88, 44, 36, 78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110,
  116, 95, 89, 44, 36, 80, 111, 105, 110, 116, 115, 95, 82, 97, 121, 111,
  110, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 80,
  111, 105, 110, 116, 115, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 80, 111, 105, 110, 116, 115, 44, 36, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 80, 111, 105, 110, 116, 115, 44, 36, 65, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 80, 111, 105, 110, 116, 115, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  76, 105, 103, 110, 101, 115, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114,
  60, 49, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 65,
  110, 99, 105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 88, 44, 36, 65,
  110, 99, 105, 101, 110, 95, 112, 111, 105, 110, 116, 95, 89, 44, 36, 78,
  111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 88, 44, 36,
  78, 111, 117, 118, 101, 97, 117, 95, 112, 111, 105, 110, 116, 95, 89, 44,
  49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116, 121,
  108, 111, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83, 116,
  121, 108, 111, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 83,
  116, 121, 108, 111, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  83, 116, 121, 108, 111, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 80, 111, 105, 110, 116, 115, 95, 82, 97, 121, 111, 110, 62,
  48, 125, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 61, 49,
  125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 80, 111, 105, 110,
  116, 115, 61, 123, 114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 53,
  53, 41, 41, 125, 41, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 80, 111, 105, 110, 116, 115, 61, 123, 114, 111, 117, 110, 100, 40, 123,
  40, 63, 40, 50, 53, 53, 41, 41, 125, 41, 125, 10, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 80, 111, 105, 110, 116, 115, 61, 123, 114, 111,
  117, 110, 100, 40, 123, 40, 63, 40, 50, 53, 53, 41, 41, 125, 41, 125,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 99, 105, 114, 99, 108, 101, 91,
  45, 49, 93, 32, 36, 65, 110, 99, 105, 101, 110, 95, 112, 111, 105, 110,
  116, 95, 88, 44, 36, 65, 110, 99, 105, 101, 110, 95, 112, 111, 105, 110,
  116, 95, 89, 44, 36, 80, 111, 105, 110, 116, 115, 95, 82, 97, 121, 111,
  110, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 80,
  111, 105, 110, 116, 115, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 80, 111, 105, 110, 116, 115, 44, 36, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 80, 111, 105, 110, 116, 115, 44, 36, 65, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 80, 111, 105, 110, 116, 115, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 65, 110, 99, 105, 101, 110,
  95, 112, 111, 105, 110, 116, 95, 88, 61, 36, 78, 111, 117, 118, 101, 97,
  117, 95, 112, 111, 105, 110, 116, 95, 88, 10, 65, 110, 99, 105, 101, 110,
  95, 112, 111, 105, 110, 116, 95, 89, 61, 36, 78, 111, 117, 118, 101, 97,
  117, 95, 112, 111, 105, 110, 116, 95, 89, 10, 116, 104, 101, 116, 97, 61,
  123, 36, 116, 104, 101, 116, 97, 43, 36, 73, 110, 99, 114, 101, 109, 101,
  110, 116, 95, 97, 110, 103, 117, 108, 97, 105, 114, 101, 125, 10, 78, 98,
  95, 66, 111, 117, 99, 108, 101, 61, 123, 36, 78, 98, 95, 66, 111, 117,
  99, 108, 101, 43, 49, 125, 10, 45, 100, 111, 110, 101, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 70,
  108, 111, 117, 95, 83, 112, 105, 114, 111, 103, 114, 97, 112, 104, 101, 10,
  45, 115, 112, 114, 101, 97, 100, 91, 45, 49, 93, 32, 36, 83, 112, 114,
  101, 97, 100, 95, 83, 112, 105, 114, 111, 103, 114, 97, 112, 104, 101, 10,
  45, 100, 101, 102, 111, 114, 109, 91, 45, 49, 93, 32, 36, 68, 101, 102,
  111, 114, 109, 95, 83, 112, 105, 114, 111, 103, 114, 97, 112, 104, 101, 10,
  45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45,
  50, 93, 32, 36, 98, 108, 101, 110, 100, 44, 36, 111, 112, 97, 99, 105,
  116, 101, 44, 36, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114,
  115, 10, 35, 64, 103, 105, 109, 112, 32, 84, 101, 115, 116, 32, 99, 105,
  114, 99, 108, 101, 115, 51, 100, 32, 58, 32, 115, 97, 109, 106, 95, 84,
  101, 115, 116, 95, 67, 105, 114, 99, 108, 101, 115, 51, 68, 44, 32, 115,
  97, 109, 106, 95, 84, 101, 115, 116, 95, 67, 105, 114, 99, 108, 101, 115,
  51, 68, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61,
  34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97,
  108, 108, 62, 51, 68, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115,
  112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  82, 97, 100, 105, 117, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  44, 48, 46, 50, 44, 50, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49,
  53, 44, 49, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 53, 44, 49,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97,
  110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114,
  97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62,
  67, 111, 117, 108, 101, 117, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62,
  60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 47, 32, 99, 111, 108,
  111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 48, 44, 48, 44, 48,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77,
  111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34,
  65, 100, 100, 34, 44, 34, 65, 108, 112, 104, 97, 34, 44, 34, 65, 110,
  100, 34, 44, 34, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 66, 108,
  117, 101, 34, 44, 34, 66, 117, 114, 110, 34, 44, 34, 68, 97, 114, 107,
  101, 110, 34, 44, 34, 68, 105, 102, 102, 101, 114, 101, 110, 99, 101, 34,
  44, 34, 68, 105, 118, 105, 100, 101, 34, 44, 34, 68, 111, 100, 103, 101,
  34, 44, 34, 69, 120, 99, 108, 117, 115, 105, 111, 110, 34, 44, 34, 70,
  114, 101, 101, 122, 101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 101, 120,
  116, 114, 97, 99, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 109, 101,
  114, 103, 101, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 72, 97,
  114, 100, 32, 108, 105, 103, 104, 116, 34, 44, 34, 72, 97, 114, 100, 32,
  109, 105, 120, 34, 44, 34, 72, 117, 101, 34, 44, 34, 73, 110, 116, 101,
  114, 112, 111, 108, 97, 116, 105, 111, 110, 34, 44, 34, 76, 105, 103, 104,
  116, 101, 110, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34,
  44, 34, 76, 105, 110, 101, 97, 114, 32, 98, 117, 114, 110, 34, 44, 34,
  76, 105, 110, 101, 97, 114, 32, 108, 105, 103, 104, 116, 34, 44, 34, 76,
  117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 77, 117, 108, 116, 105,
  112, 108, 121, 34, 44, 34, 78, 101, 103, 97, 116, 105, 111, 110, 34, 44,
  34, 79, 114, 34, 44, 34, 79, 118, 101, 114, 108, 97, 121, 34, 44, 34,
  80, 105, 110, 32, 108, 105, 103, 104, 116, 34, 44, 34, 82, 101, 100, 34,
  44, 34, 82, 101, 102, 108, 101, 99, 116, 34, 44, 34, 83, 97, 116, 117,
  114, 97, 116, 105, 111, 110, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65,
  118, 101, 114, 97, 103, 101, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65,
  118, 101, 114, 97, 103, 101, 48, 34, 44, 34, 83, 111, 102, 116, 32, 98,
  117, 114, 110, 34, 44, 34, 83, 111, 102, 116, 32, 100, 111, 100, 103, 101,
  34, 44, 34, 83, 111, 102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34,
  83, 99, 114, 101, 101, 110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44,
  34, 83, 117, 98, 116, 114, 97, 99, 116, 34, 44, 34, 86, 97, 108, 117,
  101, 34, 44, 34, 86, 105, 118, 105, 100, 32, 108, 105, 103, 104, 116, 34,
  44, 34, 88, 111, 114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 79, 112, 97, 99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 82, 101, 118, 101, 114, 116, 32, 108, 97, 121, 101, 114, 115, 32, 61,
  32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 97, 110, 115, 32, 102, 111, 110, 100, 32, 47, 32, 119, 105,
  116, 104, 111, 117, 116, 32, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 66, 111, 111, 115, 116, 32, 61, 32, 98, 111, 111, 108,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111,
  114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108,
  34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48,
  49, 47, 48, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 115, 97, 109, 106, 95, 84, 101, 115, 116, 95, 67, 105,
  114, 99, 108, 101, 115, 51, 68, 32, 58, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 82, 97, 100, 105,
  117, 115, 95, 99, 105, 114, 99, 108, 101, 115, 51, 100, 61, 36, 49, 10,
  88, 95, 97, 110, 103, 108, 101, 61, 36, 50, 10, 89, 95, 97, 110, 103,
  108, 101, 61, 36, 51, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61,
  36, 52, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 53, 10,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 54, 10, 65, 95, 67,
  111, 117, 108, 101, 117, 114, 61, 36, 55, 10, 77, 111, 100, 101, 95, 77,
  101, 108, 97, 110, 103, 101, 61, 36, 56, 10, 79, 112, 97, 99, 105, 116,
  121, 95, 77, 101, 108, 97, 110, 103, 101, 61, 36, 57, 10, 82, 101, 118,
  101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 95, 77, 101, 108, 97, 110,
  103, 101, 61, 36, 49, 48, 10, 83, 97, 110, 115, 95, 70, 111, 110, 100,
  61, 36, 49, 49, 10, 66, 111, 111, 115, 116, 61, 36, 49, 50, 10, 76,
  97, 114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 61, 123,
  119, 125, 10, 72, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105,
  110, 101, 61, 123, 104, 125, 10, 71, 114, 97, 110, 100, 101, 95, 68, 105,
  109, 101, 110, 115, 105, 111, 110, 61, 123, 109, 97, 120, 40, 36, 76, 97,
  114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 44, 36, 72,
  97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 41, 125,
  10, 86, 97, 108, 101, 117, 114, 95, 84, 101, 115, 116, 61, 52, 10, 45,
  105, 102, 32, 123, 36, 71, 114, 97, 110, 100, 101, 95, 68, 105, 109, 101,
  110, 115, 105, 111, 110, 62, 49, 48, 50, 52, 125, 10, 73, 109, 97, 103,
  101, 95, 84, 114, 111, 112, 95, 71, 114, 97, 110, 100, 101, 61, 123, 36,
  71, 114, 97, 110, 100, 101, 95, 68, 105, 109, 101, 110, 115, 105, 111, 110,
  47, 49, 48, 50, 52, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45,
  49, 93, 32, 123, 36, 76, 97, 114, 103, 101, 117, 114, 95, 111, 114, 105,
  103, 105, 110, 101, 47, 123, 36, 86, 97, 108, 101, 117, 114, 95, 84, 101,
  115, 116, 42, 36, 73, 109, 97, 103, 101, 95, 84, 114, 111, 112, 95, 71,
  114, 97, 110, 100, 101, 125, 125, 44, 123, 36, 72, 97, 117, 116, 101, 117,
  114, 95, 111, 114, 105, 103, 105, 110, 101, 47, 123, 36, 86, 97, 108, 101,
  117, 114, 95, 84, 101, 115, 116, 42, 36, 73, 109, 97, 103, 101, 95, 84,
  114, 111, 112, 95, 71, 114, 97, 110, 100, 101, 125, 125, 44, 49, 44, 52,
  44, 53, 10, 45, 101, 108, 115, 101, 10, 73, 109, 97, 103, 101, 95, 84,
  114, 111, 112, 95, 71, 114, 97, 110, 100, 101, 61, 49, 10, 45, 114, 101,
  115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 76, 97, 114, 103, 101,
  117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 47, 36, 86, 97, 108, 101,
  117, 114, 95, 84, 101, 115, 116, 125, 44, 123, 36, 72, 97, 117, 116, 101,
  117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 47, 36, 86, 97, 108, 101,
  117, 114, 95, 84, 101, 115, 116, 125, 44, 49, 44, 52, 44, 53, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50,
  53, 53, 10, 45, 101, 108, 101, 118, 97, 116, 105, 111, 110, 51, 100, 91,
  45, 49, 93, 32, 48, 46, 50, 10, 45, 99, 105, 114, 99, 108, 101, 115,
  51, 100, 91, 45, 49, 93, 32, 36, 82, 97, 100, 105, 117, 115, 95, 99,
  105, 114, 99, 108, 101, 115, 51, 100, 10, 45, 103, 105, 109, 112, 95, 114,
  101, 110, 100, 101, 114, 51, 100, 91, 45, 49, 93, 32, 123, 36, 71, 114,
  97, 110, 100, 101, 95, 68, 105, 109, 101, 110, 115, 105, 111, 110, 47, 36,
  73, 109, 97, 103, 101, 95, 84, 114, 111, 112, 95, 71, 114, 97, 110, 100,
  101, 125, 44, 123, 36, 71, 114, 97, 110, 100, 101, 95, 68, 105, 109, 101,
  110, 115, 105, 111, 110, 47, 36, 73, 109, 97, 103, 101, 95, 84, 114, 111,
  112, 95, 71, 114, 97, 110, 100, 101, 125, 44, 48, 46, 56, 44, 36, 88,
  95, 97, 110, 103, 108, 101, 44, 36, 89, 95, 97, 110, 103, 108, 101, 44,
  48, 44, 52, 53, 44, 48, 44, 48, 44, 45, 49, 48, 48, 44, 48, 46,
  53, 44, 48, 46, 55, 44, 50, 10, 45, 99, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 10, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45,
  49, 93, 32, 48, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93,
  32, 36, 76, 97, 114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110,
  101, 44, 36, 72, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105,
  110, 101, 44, 49, 44, 52, 44, 53, 10, 45, 110, 91, 45, 49, 93, 32,
  48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36, 66, 111, 111, 115,
  116, 61, 61, 49, 125, 10, 45, 103, 105, 109, 112, 95, 110, 111, 114, 109,
  97, 108, 105, 122, 101, 95, 108, 111, 99, 97, 108, 91, 45, 49, 93, 32,
  50, 44, 54, 44, 53, 44, 50, 48, 44, 49, 44, 51, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93,
  10, 36, 76, 97, 114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110,
  101, 44, 36, 72, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105,
  110, 101, 44, 49, 44, 52, 10, 45, 105, 102, 32, 123, 36, 83, 97, 110,
  115, 95, 70, 111, 110, 100, 61, 61, 48, 125, 10, 45, 102, 105, 108, 108,
  95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 36, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 65, 95, 67,
  111, 117, 108, 101, 117, 114, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101,
  110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 32, 36, 77, 111, 100, 101,
  95, 77, 101, 108, 97, 110, 103, 101, 44, 36, 79, 112, 97, 99, 105, 116,
  121, 95, 77, 101, 108, 97, 110, 103, 101, 44, 36, 82, 101, 118, 101, 114,
  116, 95, 108, 97, 121, 101, 114, 115, 95, 77, 101, 108, 97, 110, 103, 101,
  10, 45, 101, 108, 115, 101, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108,
  111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 10, 45,
  99, 111, 109, 112, 111, 115, 101, 95, 97, 108, 112, 104, 97, 91, 45, 50,
  44, 45, 49, 93, 10, 45, 101, 110, 100, 105, 102, 10, 35, 32, 45, 116,
  101, 120, 116, 95, 111, 117, 116, 108, 105, 110, 101, 91, 45, 49, 93, 32,
  36, 71, 114, 97, 110, 100, 101, 95, 68, 105, 109, 101, 110, 115, 105, 111,
  110, 44, 49, 48, 44, 49, 49, 48, 44, 54, 52, 44, 49, 44, 49, 44,
  50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 84,
  101, 115, 116, 32, 101, 108, 101, 118, 97, 116, 105, 111, 110, 51, 100, 32,
  58, 32, 115, 97, 109, 106, 95, 84, 101, 115, 116, 95, 69, 108, 101, 118,
  97, 116, 105, 111, 110, 51, 68, 44, 32, 115, 97, 109, 106, 95, 84, 101,
  115, 116, 95, 69, 108, 101, 118, 97, 116, 105, 111, 110, 51, 68, 40, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110,
  32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97,
  110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 51,
  68, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 32, 102, 97,
  99, 116, 111, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 50,
  44, 45, 48, 46, 53, 44, 48, 46, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 88, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  45, 49, 56, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 89, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45,
  49, 56, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 90, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49,
  56, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 70, 111, 118, 32, 61, 32, 102, 108, 111, 97, 116, 40, 52, 53, 44,
  49, 44, 57, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88,
  45, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 89, 45, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 45, 108, 105, 103, 104, 116,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 45, 49, 48, 48, 44, 45, 49,
  48, 48, 44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  112, 101, 99, 117, 108, 97, 114, 32, 108, 105, 103, 104, 116, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48, 44,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 101, 99,
  117, 108, 97, 114, 32, 115, 104, 105, 110, 105, 110, 101, 115, 115, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 44, 48, 44, 51, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 110, 100, 101, 114, 105,
  110, 103, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 52, 44, 34, 68,
  111, 116, 115, 34, 44, 34, 87, 105, 114, 101, 102, 114, 97, 109, 101, 34,
  44, 34, 70, 108, 97, 116, 34, 44, 34, 70, 108, 97, 116, 32, 115, 104,
  97, 100, 101, 100, 34, 44, 34, 71, 111, 117, 114, 97, 117, 100, 34, 44,
  34, 80, 104, 111, 110, 103, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117,
  110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60,
  115, 109, 97, 108, 108, 62, 67, 111, 117, 108, 101, 117, 114, 115, 60, 47,
  115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114,
  32, 47, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114,
  40, 48, 44, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105,
  99, 101, 40, 48, 44, 34, 65, 100, 100, 34, 44, 34, 65, 108, 112, 104,
  97, 34, 44, 34, 65, 110, 100, 34, 44, 34, 65, 118, 101, 114, 97, 103,
  101, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 66, 117, 114, 110, 34,
  44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 68, 105, 102, 102, 101,
  114, 101, 110, 99, 101, 34, 44, 34, 68, 105, 118, 105, 100, 101, 34, 44,
  34, 68, 111, 100, 103, 101, 34, 44, 34, 69, 120, 99, 108, 117, 115, 105,
  111, 110, 34, 44, 34, 70, 114, 101, 101, 122, 101, 34, 44, 34, 71, 114,
  97, 105, 110, 32, 101, 120, 116, 114, 97, 99, 116, 34, 44, 34, 71, 114,
  97, 105, 110, 32, 109, 101, 114, 103, 101, 34, 44, 34, 71, 114, 101, 101,
  110, 34, 44, 34, 72, 97, 114, 100, 32, 108, 105, 103, 104, 116, 34, 44,
  34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44, 34, 72, 117, 101, 34,
  44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 34,
  44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44, 34, 76, 105, 103, 104,
  116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 98,
  117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 108, 105, 103,
  104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 77, 117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 78, 101, 103, 97,
  116, 105, 111, 110, 34, 44, 34, 79, 114, 34, 44, 34, 79, 118, 101, 114,
  108, 97, 121, 34, 44, 34, 80, 105, 110, 32, 108, 105, 103, 104, 116, 34,
  44, 34, 82, 101, 100, 34, 44, 34, 82, 101, 102, 108, 101, 99, 116, 34,
  44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 83,
  104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 83,
  104, 97, 112, 101, 32, 65, 118, 101, 114, 97, 103, 101, 48, 34, 44, 34,
  83, 111, 102, 116, 32, 98, 117, 114, 110, 34, 44, 34, 83, 111, 102, 116,
  32, 100, 111, 100, 103, 101, 34, 44, 34, 83, 111, 102, 116, 32, 108, 105,
  103, 104, 116, 34, 44, 34, 83, 99, 114, 101, 101, 110, 34, 44, 34, 83,
  116, 97, 109, 112, 34, 44, 34, 83, 117, 98, 116, 114, 97, 99, 116, 34,
  44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 86, 105, 118, 105, 100, 32,
  108, 105, 103, 104, 116, 34, 44, 34, 88, 111, 114, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97,
  121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 97, 110, 115, 32, 102, 111, 110,
  100, 32, 47, 32, 119, 105, 116, 104, 111, 117, 116, 32, 98, 97, 99, 107,
  103, 114, 111, 117, 110, 100, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 66, 111, 111, 115, 116, 32,
  61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121,
  112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 115, 97, 109, 106, 32, 45, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62,
  50, 48, 49, 52, 47, 48, 49, 47, 48, 55, 60, 47, 105, 62, 46, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 84,
  101, 115, 116, 95, 69, 108, 101, 118, 97, 116, 105, 111, 110, 51, 68, 32,
  58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 90, 95, 102, 97, 99, 116, 111, 114, 95, 101, 108, 101,
  118, 97, 116, 105, 111, 110, 51, 100, 61, 36, 49, 10, 88, 95, 97, 110,
  103, 108, 101, 61, 36, 50, 10, 89, 95, 97, 110, 103, 108, 101, 61, 36,
  51, 10, 90, 95, 97, 110, 103, 108, 101, 61, 36, 52, 10, 82, 51, 68,
  95, 70, 79, 86, 61, 36, 53, 10, 82, 51, 68, 95, 88, 95, 108, 105,
  103, 104, 116, 61, 36, 54, 10, 82, 51, 68, 95, 89, 95, 108, 105, 103,
  104, 116, 61, 36, 55, 10, 82, 51, 68, 95, 90, 95, 108, 105, 103, 104,
  116, 61, 36, 56, 10, 82, 51, 68, 95, 83, 112, 101, 99, 117, 108, 97,
  114, 95, 108, 105, 103, 104, 116, 110, 101, 115, 115, 61, 36, 57, 10, 82,
  51, 68, 95, 83, 112, 101, 99, 117, 108, 97, 114, 95, 115, 104, 105, 110,
  105, 110, 101, 115, 115, 61, 36, 49, 48, 10, 82, 51, 68, 95, 82, 101,
  110, 100, 101, 114, 105, 110, 103, 95, 109, 111, 100, 101, 61, 36, 49, 49,
  10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 49, 50, 10, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 49, 51, 10, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 61, 36, 49, 52, 10, 65, 95, 67, 111, 117,
  108, 101, 117, 114, 61, 36, 49, 53, 10, 77, 111, 100, 101, 95, 77, 101,
  108, 97, 110, 103, 101, 61, 36, 49, 54, 10, 79, 112, 97, 99, 105, 116,
  121, 95, 77, 101, 108, 97, 110, 103, 101, 61, 36, 49, 55, 10, 82, 101,
  118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 95, 77, 101, 108, 97,
  110, 103, 101, 61, 36, 49, 56, 10, 83, 97, 110, 115, 95, 70, 111, 110,
  100, 61, 36, 49, 57, 10, 66, 111, 111, 115, 116, 61, 36, 50, 48, 10,
  76, 97, 114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 61,
  123, 119, 125, 10, 72, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103,
  105, 110, 101, 61, 123, 104, 125, 10, 71, 114, 97, 110, 100, 101, 95, 68,
  105, 109, 101, 110, 115, 105, 111, 110, 61, 123, 109, 97, 120, 40, 36, 76,
  97, 114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 44, 36,
  72, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 41,
  125, 10, 86, 97, 108, 101, 117, 114, 95, 84, 101, 115, 116, 61, 49, 46,
  50, 53, 10, 45, 105, 102, 32, 123, 36, 71, 114, 97, 110, 100, 101, 95,
  68, 105, 109, 101, 110, 115, 105, 111, 110, 62, 49, 48, 50, 52, 125, 10,
  73, 109, 97, 103, 101, 95, 84, 114, 111, 112, 95, 71, 114, 97, 110, 100,
  101, 61, 123, 36, 71, 114, 97, 110, 100, 101, 95, 68, 105, 109, 101, 110,
  115, 105, 111, 110, 47, 49, 48, 50, 52, 125, 10, 45, 114, 101, 115, 105,
  122, 101, 91, 45, 49, 93, 32, 123, 36, 76, 97, 114, 103, 101, 117, 114,
  95, 111, 114, 105, 103, 105, 110, 101, 47, 123, 36, 86, 97, 108, 101, 117,
  114, 95, 84, 101, 115, 116, 42, 36, 73, 109, 97, 103, 101, 95, 84, 114,
  111, 112, 95, 71, 114, 97, 110, 100, 101, 125, 125, 44, 123, 36, 72, 97,
  117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 47, 123, 36,
  86, 97, 108, 101, 117, 114, 95, 84, 101, 115, 116, 42, 36, 73, 109, 97,
  103, 101, 95, 84, 114, 111, 112, 95, 71, 114, 97, 110, 100, 101, 125, 125,
  44, 49, 44, 52, 44, 53, 10, 45, 101, 108, 115, 101, 10, 73, 109, 97,
  103, 101, 95, 84, 114, 111, 112, 95, 71, 114, 97, 110, 100, 101, 61, 49,
  10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 76,
  97, 114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 47, 36,
  86, 97, 108, 101, 117, 114, 95, 84, 101, 115, 116, 125, 44, 123, 36, 72,
  97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 47, 36,
  86, 97, 108, 101, 117, 114, 95, 84, 101, 115, 116, 125, 44, 49, 44, 52,
  44, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 110, 91, 45, 49, 93,
  32, 48, 44, 50, 53, 53, 10, 45, 101, 108, 101, 118, 97, 116, 105, 111,
  110, 51, 100, 91, 45, 49, 93, 32, 36, 90, 95, 102, 97, 99, 116, 111,
  114, 95, 101, 108, 101, 118, 97, 116, 105, 111, 110, 51, 100, 10, 45, 103,
  105, 109, 112, 95, 114, 101, 110, 100, 101, 114, 51, 100, 91, 45, 49, 93,
  32, 123, 36, 71, 114, 97, 110, 100, 101, 95, 68, 105, 109, 101, 110, 115,
  105, 111, 110, 47, 36, 73, 109, 97, 103, 101, 95, 84, 114, 111, 112, 95,
  71, 114, 97, 110, 100, 101, 125, 44, 123, 36, 71, 114, 97, 110, 100, 101,
  95, 68, 105, 109, 101, 110, 115, 105, 111, 110, 47, 36, 73, 109, 97, 103,
  101, 95, 84, 114, 111, 112, 95, 71, 114, 97, 110, 100, 101, 125, 44, 48,
  46, 56, 44, 36, 88, 95, 97, 110, 103, 108, 101, 44, 36, 89, 95, 97,
  110, 103, 108, 101, 44, 36, 90, 95, 97, 110, 103, 108, 101, 44, 36, 82,
  51, 68, 95, 70, 79, 86, 44, 36, 82, 51, 68, 95, 88, 95, 108, 105,
  103, 104, 116, 44, 36, 82, 51, 68, 95, 89, 95, 108, 105, 103, 104, 116,
  44, 36, 82, 51, 68, 95, 90, 95, 108, 105, 103, 104, 116, 44, 36, 82,
  51, 68, 95, 83, 112, 101, 99, 117, 108, 97, 114, 95, 108, 105, 103, 104,
  116, 110, 101, 115, 115, 44, 36, 82, 51, 68, 95, 83, 112, 101, 99, 117,
  108, 97, 114, 95, 115, 104, 105, 110, 105, 110, 101, 115, 115, 44, 36, 82,
  51, 68, 95, 82, 101, 110, 100, 101, 114, 105, 110, 103, 95, 109, 111, 100,
  101, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45,
  97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 48, 10, 45,
  114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 36, 76, 97, 114, 103,
  101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 44, 36, 72, 97, 117,
  116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 44, 49, 44, 52,
  44, 53, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10,
  45, 105, 102, 32, 123, 36, 66, 111, 111, 115, 116, 61, 61, 49, 125, 10,
  45, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101, 95,
  108, 111, 99, 97, 108, 91, 45, 49, 93, 32, 50, 44, 54, 44, 53, 44,
  50, 48, 44, 49, 44, 51, 10, 45, 101, 110, 100, 105, 102, 10, 45, 116,
  111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 10, 36, 76, 97, 114, 103,
  101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 44, 36, 72, 97, 117,
  116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 44, 49, 44, 52,
  10, 45, 105, 102, 32, 123, 36, 83, 97, 110, 115, 95, 70, 111, 110, 100,
  61, 61, 48, 125, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114,
  91, 45, 49, 93, 32, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 44,
  36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114,
  10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44,
  45, 50, 93, 32, 32, 36, 77, 111, 100, 101, 95, 77, 101, 108, 97, 110,
  103, 101, 44, 36, 79, 112, 97, 99, 105, 116, 121, 95, 77, 101, 108, 97,
  110, 103, 101, 44, 36, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101,
  114, 115, 95, 77, 101, 108, 97, 110, 103, 101, 10, 45, 101, 108, 115, 101,
  10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93,
  32, 48, 44, 48, 44, 48, 44, 48, 10, 45, 99, 111, 109, 112, 111, 115,
  101, 95, 97, 108, 112, 104, 97, 91, 45, 50, 44, 45, 49, 93, 10, 45,
  101, 110, 100, 105, 102, 10, 35, 32, 45, 116, 101, 120, 116, 95, 111, 117,
  116, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 71, 114, 97, 110, 100,
  101, 95, 68, 105, 109, 101, 110, 115, 105, 111, 110, 44, 49, 48, 44, 49,
  49, 48, 44, 54, 52, 44, 49, 44, 49, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 35, 64, 103, 105, 109, 112, 32, 84, 101, 115, 116, 32, 101, 120,
  101, 109, 112, 108, 101, 115, 32, 109, 97, 110, 117, 101, 108, 32, 51, 100,
  32, 58, 32, 115, 97, 109, 106, 95, 84, 101, 115, 116, 95, 69, 120, 101,
  109, 112, 108, 101, 115, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 44,
  32, 115, 97, 109, 106, 95, 84, 101, 115, 116, 95, 69, 120, 101, 109, 112,
  108, 101, 115, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 95, 112, 114,
  101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117,
  110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60,
  115, 109, 97, 108, 108, 62, 69, 120, 101, 109, 112, 108, 101, 115, 32, 51,
  68, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97,
  110, 32, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 61, 34, 119, 104,
  105, 116, 101, 34, 62, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103,
  114, 111, 117, 110, 100, 61, 34, 114, 101, 100, 34, 62, 60, 98, 62, 69,
  120, 101, 109, 112, 108, 101, 115, 32, 60, 47, 98, 62, 32, 48, 61, 82,
  105, 101, 110, 47, 78, 111, 116, 104, 105, 110, 103, 32, 49, 61, 105, 109,
  97, 103, 101, 112, 108, 97, 110, 101, 51, 100, 32, 50, 61, 115, 112, 104,
  101, 114, 101, 51, 100, 32, 51, 61, 116, 111, 114, 117, 115, 51, 100, 32,
  52, 61, 98, 111, 120, 51, 100, 32, 53, 61, 99, 111, 110, 101, 51, 100,
  32, 54, 61, 99, 117, 112, 51, 100, 32, 55, 61, 99, 121, 108, 105, 110,
  100, 101, 114, 51, 100, 32, 56, 61, 103, 109, 105, 99, 51, 100, 32, 57,
  61, 103, 121, 114, 111, 105, 100, 51, 100, 32, 49, 48, 61, 105, 109, 97,
  103, 101, 99, 117, 98, 101, 51, 100, 32, 49, 49, 61, 105, 109, 97, 103,
  101, 112, 121, 114, 97, 109, 105, 100, 51, 100, 32, 49, 50, 61, 109, 97,
  103, 101, 114, 117, 98, 105, 107, 51, 100, 32, 49, 51, 61, 105, 109, 97,
  103, 101, 115, 112, 104, 101, 114, 101, 51, 100, 32, 49, 52, 61, 105, 115,
  111, 108, 105, 110, 101, 51, 100, 32, 49, 53, 61, 108, 97, 98, 101, 108,
  95, 112, 111, 105, 110, 116, 115, 51, 100, 32, 49, 54, 61, 108, 105, 110,
  101, 51, 100, 32, 49, 55, 61, 99, 111, 108, 111, 114, 99, 117, 98, 101,
  51, 100, 32, 49, 56, 61, 99, 117, 98, 101, 115, 51, 100, 32, 49, 57,
  61, 100, 105, 115, 116, 114, 105, 98, 117, 116, 105, 111, 110, 51, 100, 32,
  50, 48, 61, 104, 105, 115, 116, 111, 103, 114, 97, 109, 51, 100, 32, 50,
  49, 61, 113, 117, 97, 100, 114, 97, 110, 103, 108, 101, 51, 100, 32, 50,
  50, 61, 115, 105, 101, 114, 112, 105, 110, 115, 107, 105, 51, 100, 32, 50,
  51, 61, 115, 112, 104, 101, 114, 105, 99, 97, 108, 51, 100, 32, 50, 52,
  61, 115, 112, 114, 105, 116, 101, 51, 100, 32, 50, 53, 61, 115, 116, 97,
  114, 51, 100, 32, 50, 54, 61, 116, 101, 120, 116, 95, 112, 111, 105, 110,
  116, 99, 108, 111, 117, 100, 51, 100, 32, 50, 55, 61, 116, 101, 120, 116,
  117, 114, 105, 122, 101, 51, 100, 32, 50, 56, 61, 119, 101, 105, 114, 100,
  51, 100, 32, 50, 57, 61, 105, 115, 111, 115, 117, 114, 102, 97, 99, 101,
  51, 100, 60, 47, 115, 112, 97, 110, 62, 60, 47, 115, 112, 97, 110, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 120, 101, 109,
  112, 108, 101, 115, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 50,
  57, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108,
  101, 117, 114, 32, 47, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111,
  108, 111, 114, 40, 54, 52, 44, 49, 50, 56, 44, 49, 57, 50, 44, 50,
  53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32,
  110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112,
  97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111,
  114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108,
  62, 82, 101, 110, 100, 101, 114, 32, 51, 68, 60, 47, 115, 109, 97, 108,
  108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 88, 32, 61, 32, 102, 108, 111, 97, 116, 40, 45,
  52, 48, 44, 45, 49, 56, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 89, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 45, 49, 56, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 90, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 45, 49, 56, 48, 44, 49, 56, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 70, 111, 118, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  52, 53, 44, 49, 44, 57, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 88, 45, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 89, 45, 108, 105, 103, 104, 116, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 48, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 45, 108, 105,
  103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 45, 49, 48, 48,
  44, 45, 49, 48, 48, 44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 112, 101, 99, 117, 108, 97, 114, 32, 108, 105, 103, 104, 116,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53,
  44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  112, 101, 99, 117, 108, 97, 114, 32, 115, 104, 105, 110, 105, 110, 101, 115,
  115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55, 44, 48, 44,
  51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 110, 100,
  101, 114, 105, 110, 103, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 52,
  44, 34, 68, 111, 116, 115, 34, 44, 34, 87, 105, 114, 101, 102, 114, 97,
  109, 101, 34, 44, 34, 70, 108, 97, 116, 34, 44, 34, 70, 108, 97, 116,
  32, 115, 104, 97, 100, 101, 100, 34, 44, 34, 71, 111, 117, 114, 97, 117,
  100, 34, 44, 34, 80, 104, 111, 110, 103, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32,
  116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70,
  117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 115, 97, 109, 106, 32, 45, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60,
  105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 49, 48, 60, 47, 105, 62,
  46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 115, 97, 109, 106,
  95, 84, 101, 115, 116, 95, 69, 120, 101, 109, 112, 108, 101, 115, 95, 77,
  97, 110, 117, 101, 108, 95, 51, 68, 58, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 69, 120, 101, 109,
  112, 108, 101, 95, 67, 104, 111, 105, 115, 105, 61, 36, 49, 10, 82, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51,
  68, 61, 36, 50, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77,
  97, 110, 117, 101, 108, 95, 51, 68, 61, 36, 51, 10, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 61,
  36, 52, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97, 110,
  117, 101, 108, 95, 51, 68, 61, 36, 53, 10, 88, 95, 97, 110, 103, 108,
  101, 61, 36, 54, 10, 89, 95, 97, 110, 103, 108, 101, 61, 36, 55, 10,
  90, 95, 97, 110, 103, 108, 101, 61, 36, 56, 10, 82, 51, 68, 95, 70,
  79, 86, 61, 36, 57, 10, 82, 51, 68, 95, 88, 95, 108, 105, 103, 104,
  116, 61, 36, 49, 48, 10, 82, 51, 68, 95, 89, 95, 108, 105, 103, 104,
  116, 61, 36, 49, 49, 10, 82, 51, 68, 95, 90, 95, 108, 105, 103, 104,
  116, 61, 36, 49, 50, 10, 82, 51, 68, 95, 83, 112, 101, 99, 117, 108,
  97, 114, 95, 108, 105, 103, 104, 116, 110, 101, 115, 115, 61, 36, 49, 51,
  10, 82, 51, 68, 95, 83, 112, 101, 99, 117, 108, 97, 114, 95, 115, 104,
  105, 110, 105, 110, 101, 115, 115, 61, 36, 49, 52, 10, 82, 51, 68, 95,
  82, 101, 110, 100, 101, 114, 105, 110, 103, 95, 109, 111, 100, 101, 61, 36,
  49, 53, 10, 77, 97, 120, 95, 68, 105, 109, 101, 110, 115, 105, 111, 110,
  61, 49, 48, 50, 52, 10, 73, 109, 97, 103, 101, 95, 84, 114, 111, 112,
  95, 71, 114, 97, 110, 100, 101, 61, 49, 10, 86, 97, 108, 101, 117, 114,
  95, 84, 101, 115, 116, 61, 49, 10, 82, 51, 68, 95, 79, 98, 106, 101,
  99, 116, 95, 115, 105, 122, 101, 61, 48, 46, 54, 10, 76, 97, 114, 103,
  101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 61, 123, 119, 125, 10,
  72, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 61,
  123, 104, 125, 10, 71, 114, 97, 110, 100, 101, 95, 68, 105, 109, 101, 110,
  115, 105, 111, 110, 61, 123, 109, 97, 120, 40, 36, 76, 97, 114, 103, 101,
  117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 44, 36, 72, 97, 117, 116,
  101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 41, 125, 10, 45, 105,
  102, 32, 123, 36, 69, 120, 101, 109, 112, 108, 101, 95, 67, 104, 111, 105,
  115, 105, 62, 48, 125, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109,
  111, 100, 101, 91, 45, 49, 93, 32, 52, 10, 45, 114, 101, 115, 105, 122,
  101, 91, 45, 49, 93, 32, 123, 36, 76, 97, 114, 103, 101, 117, 114, 95,
  111, 114, 105, 103, 105, 110, 101, 47, 36, 86, 97, 108, 101, 117, 114, 95,
  84, 101, 115, 116, 125, 44, 123, 36, 72, 97, 117, 116, 101, 117, 114, 95,
  111, 114, 105, 103, 105, 110, 101, 47, 36, 86, 97, 108, 101, 117, 114, 95,
  84, 101, 115, 116, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 69, 120, 101, 109, 112, 108, 101, 95, 67, 104, 111, 105, 115,
  105, 61, 61, 49, 125, 10, 82, 51, 68, 95, 79, 98, 106, 101, 99, 116,
  95, 115, 105, 122, 101, 61, 48, 46, 52, 32, 45, 105, 109, 97, 103, 101,
  112, 108, 97, 110, 101, 51, 100, 91, 45, 49, 93, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 69, 120, 101, 109, 112, 108, 101, 95, 67, 104, 111, 105,
  115, 105, 61, 61, 50, 125, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45,
  115, 112, 104, 101, 114, 101, 51, 100, 32, 49, 32, 45, 99, 111, 108, 51,
  100, 91, 45, 49, 93, 32, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 44, 36, 86, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 44,
  36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97, 110, 117, 101,
  108, 95, 51, 68, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  77, 97, 110, 117, 101, 108, 95, 51, 68, 10, 45, 101, 108, 105, 102, 32,
  123, 36, 69, 120, 101, 109, 112, 108, 101, 95, 67, 104, 111, 105, 115, 105,
  61, 61, 51, 125, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 116, 111,
  114, 117, 115, 51, 100, 32, 49, 44, 48, 46, 52, 32, 45, 99, 111, 108,
  51, 100, 91, 45, 49, 93, 32, 36, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 44, 36, 86, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68,
  44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97, 110, 117,
  101, 108, 95, 51, 68, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 69, 120, 101, 109, 112, 108, 101, 95, 67, 104, 111, 105, 115,
  105, 61, 61, 52, 125, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 98,
  111, 120, 51, 100, 32, 49, 44, 48, 46, 52, 44, 48, 46, 51, 32, 45,
  99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 36, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 44, 36,
  86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108,
  95, 51, 68, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77,
  97, 110, 117, 101, 108, 95, 51, 68, 44, 36, 65, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 69, 120, 101, 109, 112, 108, 101, 95, 67, 104,
  111, 105, 115, 105, 61, 61, 53, 125, 10, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 99, 111, 110, 101, 51, 100, 32, 48, 46, 50, 44, 48, 46, 53,
  32, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 36, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68,
  44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97, 110, 117,
  101, 108, 95, 51, 68, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 44, 36, 65, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 69, 120, 101, 109, 112, 108, 101, 95,
  67, 104, 111, 105, 115, 105, 61, 61, 54, 125, 10, 45, 114, 109, 91, 45,
  49, 93, 32, 45, 99, 117, 112, 51, 100, 32, 49, 50, 56, 32, 45, 99,
  111, 108, 51, 100, 91, 45, 49, 93, 32, 36, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 44, 36, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95,
  51, 68, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97,
  110, 117, 101, 108, 95, 51, 68, 44, 36, 65, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 69, 120, 101, 109, 112, 108, 101, 95, 67, 104, 111,
  105, 115, 105, 61, 61, 55, 125, 10, 45, 114, 109, 91, 45, 49, 93, 32,
  45, 99, 121, 108, 105, 110, 100, 101, 114, 51, 100, 32, 48, 46, 49, 44,
  48, 46, 52, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 36,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108,
  95, 51, 68, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77,
  97, 110, 117, 101, 108, 95, 51, 68, 44, 36, 66, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 44, 36, 65,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95,
  51, 68, 10, 45, 101, 108, 105, 102, 32, 123, 36, 69, 120, 101, 109, 112,
  108, 101, 95, 67, 104, 111, 105, 115, 105, 61, 61, 56, 125, 10, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 103, 109, 105, 99, 51, 100, 32, 45, 99,
  111, 108, 51, 100, 91, 45, 49, 93, 32, 36, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 44, 36, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95,
  51, 68, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97,
  110, 117, 101, 108, 95, 51, 68, 44, 36, 65, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 69, 120, 101, 109, 112, 108, 101, 95, 67, 104, 111,
  105, 115, 105, 61, 61, 57, 125, 10, 45, 114, 109, 91, 45, 49, 93, 32,
  82, 51, 68, 95, 79, 98, 106, 101, 99, 116, 95, 115, 105, 122, 101, 61,
  48, 46, 52, 32, 45, 103, 121, 114, 111, 105, 100, 51, 100, 32, 52, 56,
  44, 55, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 36, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95,
  51, 68, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97,
  110, 117, 101, 108, 95, 51, 68, 44, 36, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 44, 36, 65, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51,
  68, 10, 45, 101, 108, 105, 102, 32, 123, 36, 69, 120, 101, 109, 112, 108,
  101, 95, 67, 104, 111, 105, 115, 105, 61, 61, 49, 48, 125, 10, 82, 51,
  68, 95, 79, 98, 106, 101, 99, 116, 95, 115, 105, 122, 101, 61, 48, 46,
  52, 32, 45, 105, 109, 97, 103, 101, 99, 117, 98, 101, 51, 100, 91, 45,
  49, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 69, 120, 101, 109, 112,
  108, 101, 95, 67, 104, 111, 105, 115, 105, 61, 61, 49, 49, 125, 10, 82,
  51, 68, 95, 79, 98, 106, 101, 99, 116, 95, 115, 105, 122, 101, 61, 48,
  46, 52, 32, 45, 105, 109, 97, 103, 101, 112, 121, 114, 97, 109, 105, 100,
  51, 100, 91, 45, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 69,
  120, 101, 109, 112, 108, 101, 95, 67, 104, 111, 105, 115, 105, 61, 61, 49,
  50, 125, 10, 82, 51, 68, 95, 79, 98, 106, 101, 99, 116, 95, 115, 105,
  122, 101, 61, 48, 46, 52, 32, 45, 105, 109, 97, 103, 101, 114, 117, 98,
  105, 107, 51, 100, 91, 45, 49, 93, 32, 51, 44, 51, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 69, 120, 101, 109, 112, 108, 101, 95, 67, 104, 111,
  105, 115, 105, 61, 61, 49, 51, 125, 10, 82, 51, 68, 95, 79, 98, 106,
  101, 99, 116, 95, 115, 105, 122, 101, 61, 48, 46, 52, 32, 45, 105, 109,
  97, 103, 101, 115, 112, 104, 101, 114, 101, 51, 100, 91, 45, 49, 93, 32,
  51, 50, 44, 49, 54, 10, 45, 101, 108, 105, 102, 32, 123, 36, 69, 120,
  101, 109, 112, 108, 101, 95, 67, 104, 111, 105, 115, 105, 61, 61, 49, 52,
  125, 10, 82, 51, 68, 95, 79, 98, 106, 101, 99, 116, 95, 115, 105, 122,
  101, 61, 48, 46, 57, 32, 45, 105, 115, 111, 108, 105, 110, 101, 51, 100,
  91, 45, 49, 93, 32, 53, 48, 37, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 69, 120, 101, 109, 112, 108, 101, 95, 67, 104, 111, 105, 115, 105, 61,
  61, 49, 53, 125, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 116, 111,
  114, 117, 115, 51, 100, 32, 49, 44, 48, 46, 52, 44, 52, 44, 52, 32,
  45, 108, 97, 98, 101, 108, 95, 112, 111, 105, 110, 116, 115, 51, 100, 91,
  45, 49, 93, 32, 53, 48, 44, 49, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 69, 120, 101, 109, 112, 108, 101, 95, 67, 104, 111, 105, 115, 105, 61,
  61, 49, 54, 125, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 49, 48, 48, 32, 97, 61, 123, 36, 62, 42, 112,
  105, 47, 53, 48, 125, 32, 45, 108, 105, 110, 101, 51, 100, 32, 48, 44,
  48, 44, 48, 44, 123, 99, 111, 115, 40, 51, 42, 36, 97, 41, 125, 44,
  123, 115, 105, 110, 40, 50, 42, 36, 97, 41, 125, 44, 48, 32, 45, 99,
  111, 108, 111, 114, 51, 100, 91, 45, 49, 93, 32, 64, 123, 45, 82, 71,
  66, 125, 32, 45, 100, 111, 110, 101, 32, 45, 97, 100, 100, 51, 100, 10,
  45, 101, 108, 105, 102, 32, 123, 36, 69, 120, 101, 109, 112, 108, 101, 95,
  67, 104, 111, 105, 115, 105, 61, 61, 49, 55, 125, 10, 45, 114, 109, 91,
  45, 49, 93, 32, 82, 51, 68, 95, 79, 98, 106, 101, 99, 116, 95, 115,
  105, 122, 101, 61, 48, 46, 52, 32, 45, 99, 111, 108, 111, 114, 99, 117,
  98, 101, 51, 100, 32, 45, 108, 97, 98, 101, 108, 95, 112, 111, 105, 110,
  116, 115, 51, 100, 91, 45, 49, 93, 32, 53, 48, 44, 49, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 69, 120, 101, 109, 112, 108, 101, 95, 67, 104,
  111, 105, 115, 105, 61, 61, 49, 56, 125, 10, 82, 51, 68, 95, 79, 98,
  106, 101, 99, 116, 95, 115, 105, 122, 101, 61, 48, 46, 54, 32, 45, 108,
  117, 109, 105, 110, 97, 110, 99, 101, 91, 45, 49, 93, 32, 45, 114, 101,
  115, 105, 122, 101, 50, 100, 121, 91, 45, 49, 93, 32, 52, 48, 32, 45,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 91, 45, 49, 93, 32, 53, 48,
  37, 32, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 112, 111,
  105, 110, 116, 99, 108, 111, 117, 100, 51, 100, 91, 45, 49, 93, 32, 45,
  99, 111, 108, 111, 114, 51, 100, 91, 45, 49, 93, 32, 50, 53, 53, 44,
  50, 53, 53, 44, 50, 53, 53, 32, 45, 99, 117, 98, 101, 115, 51, 100,
  91, 45, 49, 93, 32, 49, 10, 45, 101, 108, 105, 102, 32, 123, 36, 69,
  120, 101, 109, 112, 108, 101, 95, 67, 104, 111, 105, 115, 105, 61, 61, 49,
  57, 125, 10, 82, 51, 68, 95, 79, 98, 106, 101, 99, 116, 95, 115, 105,
  122, 101, 61, 48, 46, 52, 32, 45, 100, 105, 115, 116, 114, 105, 98, 117,
  116, 105, 111, 110, 51, 100, 32, 45, 99, 111, 108, 111, 114, 99, 117, 98,
  101, 51, 100, 32, 45, 112, 114, 105, 109, 105, 116, 105, 118, 101, 115, 51,
  100, 91, 45, 49, 93, 32, 49, 32, 45, 97, 100, 100, 51, 100, 10, 45,
  101, 108, 105, 102, 32, 123, 36, 69, 120, 101, 109, 112, 108, 101, 95, 67,
  104, 111, 105, 115, 105, 61, 61, 50, 48, 125, 10, 82, 51, 68, 95, 79,
  98, 106, 101, 99, 116, 95, 115, 105, 122, 101, 61, 48, 46, 52, 32, 45,
  104, 105, 115, 116, 111, 103, 114, 97, 109, 51, 100, 32, 45, 99, 111, 108,
  111, 114, 99, 117, 98, 101, 51, 100, 32, 45, 112, 114, 105, 109, 105, 116,
  105, 118, 101, 115, 51, 100, 91, 45, 49, 93, 32, 49, 32, 45, 97, 100,
  100, 51, 100, 10, 45, 101, 108, 105, 102, 32, 123, 36, 69, 120, 101, 109,
  112, 108, 101, 95, 67, 104, 111, 105, 115, 105, 61, 61, 50, 49, 125, 10,
  45, 114, 109, 91, 45, 49, 93, 32, 82, 51, 68, 95, 79, 98, 106, 101,
  99, 116, 95, 115, 105, 122, 101, 61, 48, 46, 54, 32, 45, 113, 117, 97,
  100, 114, 97, 110, 103, 108, 101, 51, 100, 32, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 45, 50, 53, 44, 50, 53, 41, 41, 125, 44, 123, 114, 111,
  117, 110, 100, 40, 63, 40, 45, 50, 53, 44, 50, 53, 41, 41, 125, 44,
  123, 114, 111, 117, 110, 100, 40, 63, 40, 45, 50, 53, 44, 50, 53, 41,
  41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 45, 50, 53, 44,
  50, 53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 45,
  50, 53, 44, 50, 53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40,
  63, 40, 45, 50, 53, 44, 50, 53, 41, 41, 125, 44, 123, 114, 111, 117,
  110, 100, 40, 63, 40, 45, 50, 53, 44, 50, 53, 41, 41, 125, 44, 123,
  114, 111, 117, 110, 100, 40, 63, 40, 45, 50, 53, 44, 50, 53, 41, 41,
  125, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 45, 50, 53, 44, 50,
  53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 45, 50,
  53, 44, 50, 53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63,
  40, 45, 50, 53, 44, 50, 53, 41, 41, 125, 44, 123, 114, 111, 117, 110,
  100, 40, 63, 40, 45, 50, 53, 44, 50, 53, 41, 41, 125, 32, 45, 99,
  111, 108, 51, 100, 91, 45, 49, 93, 32, 36, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 44, 36, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95,
  51, 68, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97,
  110, 117, 101, 108, 95, 51, 68, 44, 36, 65, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 10, 45, 101, 108,
  105, 102, 32, 123, 36, 69, 120, 101, 109, 112, 108, 101, 95, 67, 104, 111,
  105, 115, 105, 61, 61, 50, 50, 125, 10, 45, 114, 109, 91, 45, 49, 93,
  32, 82, 51, 68, 95, 79, 98, 106, 101, 99, 116, 95, 115, 105, 122, 101,
  61, 48, 46, 53, 32, 45, 115, 105, 101, 114, 112, 105, 110, 115, 107, 105,
  51, 100, 32, 52, 32, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32,
  36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97, 110, 117, 101,
  108, 95, 51, 68, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  77, 97, 110, 117, 101, 108, 95, 51, 68, 44, 36, 66, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 44, 36,
  65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108,
  95, 51, 68, 10, 45, 101, 108, 105, 102, 32, 123, 36, 69, 120, 101, 109,
  112, 108, 101, 95, 67, 104, 111, 105, 115, 105, 61, 61, 50, 51, 125, 10,
  45, 114, 109, 91, 45, 49, 93, 32, 82, 51, 68, 95, 79, 98, 106, 101,
  99, 116, 95, 115, 105, 122, 101, 61, 48, 46, 53, 32, 45, 115, 112, 104,
  101, 114, 105, 99, 97, 108, 51, 100, 32, 54, 52, 32, 45, 99, 111, 108,
  51, 100, 91, 45, 49, 93, 32, 36, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 44, 36, 86, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68,
  44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97, 110, 117,
  101, 108, 95, 51, 68, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 10, 45, 101, 108, 105, 102,
  32, 123, 36, 69, 120, 101, 109, 112, 108, 101, 95, 67, 104, 111, 105, 115,
  105, 61, 61, 50, 52, 125, 10, 82, 51, 68, 95, 79, 98, 106, 101, 99,
  116, 95, 115, 105, 122, 101, 61, 48, 46, 53, 32, 45, 115, 112, 114, 105,
  116, 101, 51, 100, 91, 45, 49, 93, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 69, 120, 101, 109, 112, 108, 101, 95, 67, 104, 111, 105, 115, 105, 61,
  61, 50, 53, 125, 10, 45, 114, 109, 91, 45, 49, 93, 32, 82, 51, 68,
  95, 79, 98, 106, 101, 99, 116, 95, 115, 105, 122, 101, 61, 48, 46, 53,
  32, 45, 115, 116, 97, 114, 51, 100, 32, 56, 44, 48, 46, 51, 32, 45,
  99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 36, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 44, 36,
  86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108,
  95, 51, 68, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77,
  97, 110, 117, 101, 108, 95, 51, 68, 44, 36, 65, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 10, 45, 101,
  108, 105, 102, 32, 123, 36, 69, 120, 101, 109, 112, 108, 101, 95, 67, 104,
  111, 105, 115, 105, 61, 61, 50, 54, 125, 10, 45, 114, 109, 91, 45, 49,
  93, 32, 88, 95, 97, 110, 103, 108, 101, 61, 123, 36, 88, 95, 97, 110,
  103, 108, 101, 43, 52, 48, 125, 32, 82, 51, 68, 95, 79, 98, 106, 101,
  99, 116, 95, 115, 105, 122, 101, 61, 48, 46, 57, 32, 45, 116, 101, 120,
  116, 95, 112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 51, 100, 32, 34,
  65, 66, 34, 44, 44, 48, 46, 53, 32, 45, 99, 111, 108, 51, 100, 91,
  45, 49, 93, 32, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77,
  97, 110, 117, 101, 108, 95, 51, 68, 44, 36, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 44, 36, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95,
  51, 68, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97,
  110, 117, 101, 108, 95, 51, 68, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  69, 120, 101, 109, 112, 108, 101, 95, 67, 104, 111, 105, 115, 105, 61, 61,
  50, 55, 125, 10, 82, 51, 68, 95, 79, 98, 106, 101, 99, 116, 95, 115,
  105, 122, 101, 61, 48, 46, 54, 32, 45, 115, 105, 101, 114, 112, 105, 110,
  115, 107, 105, 51, 100, 32, 51, 32, 45, 116, 101, 120, 116, 117, 114, 105,
  122, 101, 51, 100, 91, 45, 49, 93, 32, 91, 45, 50, 93, 32, 45, 114,
  109, 91, 45, 50, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 69, 120,
  101, 109, 112, 108, 101, 95, 67, 104, 111, 105, 115, 105, 61, 61, 50, 56,
  125, 10, 45, 114, 109, 91, 45, 49, 93, 32, 82, 51, 68, 95, 79, 98,
  106, 101, 99, 116, 95, 115, 105, 122, 101, 61, 48, 46, 53, 32, 45, 119,
  101, 105, 114, 100, 51, 100, 32, 52, 56, 32, 45, 99, 111, 108, 51, 100,
  91, 45, 49, 93, 32, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  77, 97, 110, 117, 101, 108, 95, 51, 68, 44, 36, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 44, 36,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77, 97, 110, 117, 101, 108,
  95, 51, 68, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 77,
  97, 110, 117, 101, 108, 95, 51, 68, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 69, 120, 101, 109, 112, 108, 101, 95, 67, 104, 111, 105, 115, 105, 61,
  61, 50, 57, 125, 10, 45, 114, 101, 115, 105, 122, 101, 50, 100, 121, 32,
  50, 53, 54, 32, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 45,
  101, 120, 112, 97, 110, 100, 95, 122, 32, 50, 44, 48, 32, 45, 98, 108,
  117, 114, 32, 49, 32, 45, 105, 115, 111, 115, 117, 114, 102, 97, 99, 101,
  51, 100, 32, 53, 48, 37, 32, 45, 109, 117, 108, 51, 100, 32, 49, 44,
  49, 44, 51, 48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 69, 120, 101, 109, 112, 108, 101, 95, 67, 104, 111, 105, 115, 105,
  62, 48, 125, 10, 45, 103, 105, 109, 112, 95, 114, 101, 110, 100, 101, 114,
  51, 100, 91, 45, 49, 93, 32, 123, 36, 77, 97, 120, 95, 68, 105, 109,
  101, 110, 115, 105, 111, 110, 47, 36, 73, 109, 97, 103, 101, 95, 84, 114,
  111, 112, 95, 71, 114, 97, 110, 100, 101, 125, 44, 123, 36, 77, 97, 120,
  95, 68, 105, 109, 101, 110, 115, 105, 111, 110, 47, 36, 73, 109, 97, 103,
  101, 95, 84, 114, 111, 112, 95, 71, 114, 97, 110, 100, 101, 125, 44, 36,
  82, 51, 68, 95, 79, 98, 106, 101, 99, 116, 95, 115, 105, 122, 101, 44,
  36, 88, 95, 97, 110, 103, 108, 101, 44, 36, 89, 95, 97, 110, 103, 108,
  101, 44, 36, 90, 95, 97, 110, 103, 108, 101, 44, 36, 82, 51, 68, 95,
  70, 79, 86, 44, 36, 82, 51, 68, 95, 88, 95, 108, 105, 103, 104, 116,
  44, 36, 82, 51, 68, 95, 89, 95, 108, 105, 103, 104, 116, 44, 36, 82,
  51, 68, 95, 90, 95, 108, 105, 103, 104, 116, 44, 36, 82, 51, 68, 95,
  83, 112, 101, 99, 117, 108, 97, 114, 95, 108, 105, 103, 104, 116, 110, 101,
  115, 115, 44, 36, 82, 51, 68, 95, 83, 112, 101, 99, 117, 108, 97, 114,
  95, 115, 104, 105, 110, 105, 110, 101, 115, 115, 44, 36, 82, 51, 68, 95,
  82, 101, 110, 100, 101, 114, 105, 110, 103, 95, 109, 111, 100, 101, 10, 45,
  99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 115,
  97, 109, 106, 95, 84, 101, 115, 116, 95, 69, 120, 101, 109, 112, 108, 101,
  115, 95, 77, 97, 110, 117, 101, 108, 95, 51, 68, 95, 112, 114, 101, 118,
  105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105,
  116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106,
  95, 84, 101, 115, 116, 95, 69, 120, 101, 109, 112, 108, 101, 115, 95, 77,
  97, 110, 117, 101, 108, 95, 51, 68, 32, 36, 42, 34, 44, 36, 45, 49,
  10, 115, 97, 109, 106, 95, 114, 105, 101, 110, 95, 114, 101, 112, 97, 105,
  114, 32, 58, 10, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116,
  104, 105, 110, 103, 91, 45, 49, 93, 10, 115, 97, 109, 106, 95, 114, 105,
  101, 110, 95, 115, 101, 113, 117, 101, 110, 99, 101, 115, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 91,
  45, 49, 93, 10, 35, 64, 103, 105, 109, 112, 32, 84, 101, 115, 116, 32,
  101, 120, 116, 114, 117, 100, 101, 51, 100, 32, 58, 32, 115, 97, 109, 106,
  95, 84, 101, 115, 116, 95, 69, 120, 116, 114, 117, 100, 101, 51, 68, 44,
  32, 115, 97, 109, 106, 95, 84, 101, 115, 116, 95, 69, 120, 116, 114, 117,
  100, 101, 51, 68, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110,
  100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115,
  109, 97, 108, 108, 62, 51, 68, 60, 47, 115, 109, 97, 108, 108, 62, 60,
  47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 68, 101, 112, 116, 104, 32, 101, 120, 116, 114, 117, 100, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 49, 48, 44, 48, 46, 48, 49, 44,
  49, 48, 50, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  101, 115, 111, 108, 117, 116, 105, 111, 110, 32, 101, 120, 116, 114, 117, 100,
  101, 32, 61, 32, 105, 110, 116, 40, 53, 49, 50, 44, 49, 44, 49, 48,
  50, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111,
  111, 116, 104, 110, 101, 115, 115, 32, 101, 120, 116, 114, 117, 100, 101, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 54, 44, 48, 44, 51, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 49, 56, 48, 44, 49, 56, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 45, 49, 56, 48, 44, 49, 56, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 90, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 45, 49, 56, 48, 44, 49, 56, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 70, 111, 118, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 52, 53, 44, 49, 44, 57, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 88, 45, 108, 105, 103, 104, 116, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 108, 105, 103, 104,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 48, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90,
  45, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 45,
  49, 48, 48, 44, 45, 49, 48, 48, 44, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 112, 101, 99, 117, 108, 97, 114, 32, 108, 105,
  103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 112, 101, 99, 117, 108, 97, 114, 32, 115, 104, 105, 110, 105,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55,
  44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  101, 110, 100, 101, 114, 105, 110, 103, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 52, 44, 34, 68, 111, 116, 115, 34, 44, 34, 87, 105, 114, 101,
  102, 114, 97, 109, 101, 34, 44, 34, 70, 108, 97, 116, 34, 44, 34, 70,
  108, 97, 116, 32, 115, 104, 97, 100, 101, 100, 34, 44, 34, 71, 111, 117,
  114, 97, 117, 100, 34, 44, 34, 80, 104, 111, 110, 103, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111,
  114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101,
  114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 76, 111, 99, 97,
  108, 32, 79, 114, 105, 101, 110, 116, 97, 116, 105, 111, 110, 60, 47, 115,
  109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 77, 105, 110, 32, 116, 104, 114, 101,
  115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  77, 97, 120, 32, 116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 49, 48, 48, 44, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 101, 103, 97, 116, 105,
  118, 101, 32, 99, 111, 108, 111, 114, 115, 32, 61, 32, 98, 111, 111, 108,
  40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 108, 111,
  117, 32, 47, 32, 98, 108, 117, 114, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 48, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110,
  100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115,
  109, 97, 108, 108, 62, 67, 111, 108, 111, 114, 105, 115, 97, 116, 105, 111,
  110, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111, 117, 108,
  101, 117, 114, 32, 47, 32, 99, 111, 108, 111, 114, 32, 61, 32, 99, 111,
  108, 111, 114, 40, 49, 50, 55, 44, 49, 50, 55, 44, 49, 50, 55, 44,
  50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111,
  108, 111, 114, 105, 115, 97, 116, 105, 111, 110, 32, 61, 32, 98, 111, 111,
  108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116,
  105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99,
  107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108,
  62, 115, 97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47,
  48, 49, 47, 48, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 115, 97, 109, 106, 95, 84, 101, 115, 116, 95, 69,
  120, 116, 114, 117, 100, 101, 51, 68, 32, 58, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 68, 101, 112,
  116, 104, 95, 69, 120, 116, 114, 117, 100, 101, 51, 68, 61, 36, 49, 10,
  82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 95, 69, 120, 116, 114, 117,
  100, 101, 51, 68, 61, 36, 50, 10, 83, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 95, 69, 120, 116, 114, 117, 100, 101, 51, 68, 61, 36, 51, 10,
  88, 95, 97, 110, 103, 108, 101, 61, 36, 52, 10, 89, 95, 97, 110, 103,
  108, 101, 61, 36, 53, 10, 90, 95, 97, 110, 103, 108, 101, 61, 36, 54,
  10, 82, 51, 68, 95, 70, 79, 86, 61, 36, 55, 10, 82, 51, 68, 95,
  88, 95, 108, 105, 103, 104, 116, 61, 36, 56, 10, 82, 51, 68, 95, 89,
  95, 108, 105, 103, 104, 116, 61, 36, 57, 10, 82, 51, 68, 95, 90, 95,
  108, 105, 103, 104, 116, 61, 36, 49, 48, 10, 82, 51, 68, 95, 83, 112,
  101, 99, 117, 108, 97, 114, 95, 108, 105, 103, 104, 116, 110, 101, 115, 115,
  61, 36, 49, 49, 10, 82, 51, 68, 95, 83, 112, 101, 99, 117, 108, 97,
  114, 95, 115, 104, 105, 110, 105, 110, 101, 115, 115, 61, 36, 49, 50, 10,
  82, 51, 68, 95, 82, 101, 110, 100, 101, 114, 105, 110, 103, 95, 109, 111,
  100, 101, 61, 36, 49, 51, 10, 77, 105, 110, 95, 116, 104, 114, 101, 115,
  104, 111, 108, 100, 95, 76, 79, 61, 36, 49, 52, 10, 77, 97, 120, 95,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 95, 76, 79, 61, 36, 49, 53,
  10, 78, 101, 103, 97, 116, 105, 118, 101, 95, 99, 111, 108, 111, 114, 115,
  95, 76, 79, 61, 36, 49, 54, 10, 70, 108, 111, 117, 61, 36, 49, 55,
  10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 49, 56, 10, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 49, 57, 10, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 61, 36, 50, 48, 10, 65, 95, 67, 111, 117,
  108, 101, 117, 114, 61, 36, 50, 49, 10, 67, 111, 108, 111, 114, 105, 115,
  97, 116, 105, 111, 110, 61, 36, 50, 50, 10, 83, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 95, 76, 79, 61, 48, 10, 76, 97, 114, 103, 101, 117,
  114, 95, 111, 114, 105, 103, 105, 110, 101, 61, 123, 119, 125, 10, 72, 97,
  117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 61, 123, 104,
  125, 10, 71, 114, 97, 110, 100, 101, 95, 68, 105, 109, 101, 110, 115, 105,
  111, 110, 61, 123, 109, 97, 120, 40, 36, 76, 97, 114, 103, 101, 117, 114,
  95, 111, 114, 105, 103, 105, 110, 101, 44, 36, 72, 97, 117, 116, 101, 117,
  114, 95, 111, 114, 105, 103, 105, 110, 101, 41, 125, 10, 86, 97, 108, 101,
  117, 114, 95, 84, 101, 115, 116, 61, 49, 46, 50, 53, 10, 45, 105, 102,
  32, 123, 36, 71, 114, 97, 110, 100, 101, 95, 68, 105, 109, 101, 110, 115,
  105, 111, 110, 62, 49, 48, 50, 52, 125, 10, 73, 109, 97, 103, 101, 95,
  84, 114, 111, 112, 95, 71, 114, 97, 110, 100, 101, 61, 123, 36, 71, 114,
  97, 110, 100, 101, 95, 68, 105, 109, 101, 110, 115, 105, 111, 110, 47, 49,
  48, 50, 52, 125, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93,
  32, 123, 36, 76, 97, 114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105,
  110, 101, 47, 123, 36, 86, 97, 108, 101, 117, 114, 95, 84, 101, 115, 116,
  42, 36, 73, 109, 97, 103, 101, 95, 84, 114, 111, 112, 95, 71, 114, 97,
  110, 100, 101, 125, 125, 44, 123, 36, 72, 97, 117, 116, 101, 117, 114, 95,
  111, 114, 105, 103, 105, 110, 101, 47, 123, 36, 86, 97, 108, 101, 117, 114,
  95, 84, 101, 115, 116, 42, 36, 73, 109, 97, 103, 101, 95, 84, 114, 111,
  112, 95, 71, 114, 97, 110, 100, 101, 125, 125, 44, 49, 44, 52, 44, 53,
  10, 45, 101, 108, 115, 101, 10, 73, 109, 97, 103, 101, 95, 84, 114, 111,
  112, 95, 71, 114, 97, 110, 100, 101, 61, 49, 10, 45, 114, 101, 115, 105,
  122, 101, 91, 45, 49, 93, 32, 123, 36, 76, 97, 114, 103, 101, 117, 114,
  95, 111, 114, 105, 103, 105, 110, 101, 47, 36, 86, 97, 108, 101, 117, 114,
  95, 84, 101, 115, 116, 125, 44, 123, 36, 72, 97, 117, 116, 101, 117, 114,
  95, 111, 114, 105, 103, 105, 110, 101, 47, 36, 86, 97, 108, 101, 117, 114,
  95, 84, 101, 115, 116, 125, 44, 49, 44, 52, 44, 53, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  10, 45, 101, 120, 116, 114, 117, 100, 101, 51, 100, 91, 45, 49, 93, 32,
  36, 68, 101, 112, 116, 104, 95, 69, 120, 116, 114, 117, 100, 101, 51, 68,
  44, 36, 82, 101, 115, 111, 108, 117, 116, 105, 111, 110, 95, 69, 120, 116,
  114, 117, 100, 101, 51, 68, 44, 36, 83, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 95, 69, 120, 116, 114, 117, 100, 101, 51, 68, 37, 10, 45, 103,
  105, 109, 112, 95, 114, 101, 110, 100, 101, 114, 51, 100, 91, 45, 49, 93,
  32, 123, 36, 71, 114, 97, 110, 100, 101, 95, 68, 105, 109, 101, 110, 115,
  105, 111, 110, 47, 36, 73, 109, 97, 103, 101, 95, 84, 114, 111, 112, 95,
  71, 114, 97, 110, 100, 101, 125, 44, 123, 36, 71, 114, 97, 110, 100, 101,
  95, 68, 105, 109, 101, 110, 115, 105, 111, 110, 47, 36, 73, 109, 97, 103,
  101, 95, 84, 114, 111, 112, 95, 71, 114, 97, 110, 100, 101, 125, 44, 48,
  46, 56, 44, 36, 88, 95, 97, 110, 103, 108, 101, 44, 36, 89, 95, 97,
  110, 103, 108, 101, 44, 36, 90, 95, 97, 110, 103, 108, 101, 44, 36, 82,
  51, 68, 95, 70, 79, 86, 44, 36, 82, 51, 68, 95, 88, 95, 108, 105,
  103, 104, 116, 44, 36, 82, 51, 68, 95, 89, 95, 108, 105, 103, 104, 116,
  44, 36, 82, 51, 68, 95, 90, 95, 108, 105, 103, 104, 116, 44, 36, 82,
  51, 68, 95, 83, 112, 101, 99, 117, 108, 97, 114, 95, 108, 105, 103, 104,
  116, 110, 101, 115, 115, 44, 36, 82, 51, 68, 95, 83, 112, 101, 99, 117,
  108, 97, 114, 95, 115, 104, 105, 110, 105, 110, 101, 115, 115, 44, 36, 82,
  51, 68, 95, 82, 101, 110, 100, 101, 114, 105, 110, 103, 95, 109, 111, 100,
  101, 10, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32,
  48, 10, 45, 108, 117, 109, 105, 110, 97, 110, 99, 101, 91, 45, 49, 93,
  10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 36, 76, 97,
  114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 44, 36, 72,
  97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 44, 49,
  44, 52, 44, 53, 10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110,
  111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 45, 103, 105, 109, 112,
  95, 108, 111, 99, 97, 108, 95, 111, 114, 105, 101, 110, 116, 97, 116, 105,
  111, 110, 91, 45, 49, 93, 32, 36, 83, 109, 111, 111, 116, 104, 110, 101,
  115, 115, 95, 76, 79, 44, 36, 77, 105, 110, 95, 116, 104, 114, 101, 115,
  104, 111, 108, 100, 95, 76, 79, 44, 36, 77, 97, 120, 95, 116, 104, 114,
  101, 115, 104, 111, 108, 100, 95, 76, 79, 44, 36, 78, 101, 103, 97, 116,
  105, 118, 101, 95, 99, 111, 108, 111, 114, 115, 95, 76, 79, 44, 49, 10,
  45, 99, 111, 109, 112, 111, 115, 101, 95, 97, 108, 112, 104, 97, 91, 45,
  50, 44, 45, 49, 93, 10, 45, 103, 105, 109, 112, 95, 103, 97, 117, 115,
  115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 70,
  108, 111, 117, 44, 48, 44, 48, 44, 49, 44, 50, 44, 49, 44, 48, 10,
  45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 10, 45, 110, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36,
  67, 111, 108, 111, 114, 105, 115, 97, 116, 105, 111, 110, 61, 61, 49, 125,
  10, 36, 76, 97, 114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110,
  101, 44, 36, 72, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105,
  110, 101, 44, 49, 44, 52, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108,
  111, 114, 91, 45, 49, 93, 32, 36, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 66, 95,
  67, 111, 117, 108, 101, 117, 114, 44, 36, 65, 95, 67, 111, 117, 108, 101,
  117, 114, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45,
  49, 44, 45, 50, 93, 32, 50, 55, 44, 49, 44, 48, 10, 45, 101, 110,
  100, 105, 102, 10, 35, 32, 45, 116, 101, 120, 116, 95, 111, 117, 116, 108,
  105, 110, 101, 91, 45, 49, 93, 32, 36, 71, 114, 97, 110, 100, 101, 95,
  68, 105, 109, 101, 110, 115, 105, 111, 110, 44, 49, 48, 44, 49, 49, 48,
  44, 54, 52, 44, 49, 44, 49, 44, 50, 53, 53, 44, 50, 53, 53, 44,
  50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  35, 64, 103, 105, 109, 112, 32, 84, 101, 115, 116, 32, 105, 109, 97, 103,
  101, 112, 108, 97, 110, 101, 32, 51, 100, 32, 58, 32, 115, 97, 109, 106,
  95, 84, 101, 115, 116, 95, 73, 109, 97, 103, 101, 80, 108, 97, 110, 101,
  95, 51, 68, 44, 32, 115, 97, 109, 106, 95, 84, 101, 115, 116, 95, 73,
  109, 97, 103, 101, 80, 108, 97, 110, 101, 95, 51, 68, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102,
  111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103,
  101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 51, 68, 60,
  47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 48, 44, 45, 49, 56, 48, 44, 49, 56, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 44, 45, 49, 56, 48, 44, 49, 56, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 90, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 45, 49, 56, 48, 44, 49, 56, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 70, 111, 118, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 52, 53, 44, 49, 44, 57, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 88, 45, 108, 105, 103, 104, 116, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 45, 49, 48, 48, 44, 49, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 108, 105, 103, 104,
  116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 48, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90,
  45, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 45,
  49, 48, 48, 44, 45, 49, 48, 48, 44, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 112, 101, 99, 117, 108, 97, 114, 32, 108, 105,
  103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 112, 101, 99, 117, 108, 97, 114, 32, 115, 104, 105, 110, 105,
  110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55,
  44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82,
  101, 110, 100, 101, 114, 105, 110, 103, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 52, 44, 34, 68, 111, 116, 115, 34, 44, 34, 87, 105, 114, 101,
  102, 114, 97, 109, 101, 34, 44, 34, 70, 108, 97, 116, 34, 44, 34, 70,
  108, 97, 116, 32, 115, 104, 97, 100, 101, 100, 34, 44, 34, 71, 111, 117,
  114, 97, 117, 100, 34, 44, 34, 80, 104, 111, 110, 103, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111,
  114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101,
  114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 67, 111, 117, 108,
  101, 117, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112,
  97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  111, 117, 108, 101, 117, 114, 32, 47, 32, 99, 111, 108, 111, 114, 32, 61,
  32, 99, 111, 108, 111, 114, 40, 48, 44, 48, 44, 48, 44, 50, 53, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 100, 101, 32,
  61, 32, 99, 104, 111, 105, 99, 101, 40, 48, 44, 34, 65, 100, 100, 34,
  44, 34, 65, 108, 112, 104, 97, 34, 44, 34, 65, 110, 100, 34, 44, 34,
  65, 118, 101, 114, 97, 103, 101, 34, 44, 34, 66, 108, 117, 101, 34, 44,
  34, 66, 117, 114, 110, 34, 44, 34, 68, 97, 114, 107, 101, 110, 34, 44,
  34, 68, 105, 102, 102, 101, 114, 101, 110, 99, 101, 34, 44, 34, 68, 105,
  118, 105, 100, 101, 34, 44, 34, 68, 111, 100, 103, 101, 34, 44, 34, 69,
  120, 99, 108, 117, 115, 105, 111, 110, 34, 44, 34, 70, 114, 101, 101, 122,
  101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 101, 120, 116, 114, 97, 99,
  116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 109, 101, 114, 103, 101, 34,
  44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 72, 97, 114, 100, 32, 108,
  105, 103, 104, 116, 34, 44, 34, 72, 97, 114, 100, 32, 109, 105, 120, 34,
  44, 34, 72, 117, 101, 34, 44, 34, 73, 110, 116, 101, 114, 112, 111, 108,
  97, 116, 105, 111, 110, 34, 44, 34, 76, 105, 103, 104, 116, 101, 110, 34,
  44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 76, 105,
  110, 101, 97, 114, 32, 98, 117, 114, 110, 34, 44, 34, 76, 105, 110, 101,
  97, 114, 32, 108, 105, 103, 104, 116, 34, 44, 34, 76, 117, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 77, 117, 108, 116, 105, 112, 108, 121, 34,
  44, 34, 78, 101, 103, 97, 116, 105, 111, 110, 34, 44, 34, 79, 114, 34,
  44, 34, 79, 118, 101, 114, 108, 97, 121, 34, 44, 34, 80, 105, 110, 32,
  108, 105, 103, 104, 116, 34, 44, 34, 82, 101, 100, 34, 44, 34, 82, 101,
  102, 108, 101, 99, 116, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105,
  111, 110, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97,
  103, 101, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97,
  103, 101, 48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117, 114, 110, 34,
  44, 34, 83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34, 44, 34, 83,
  111, 102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83, 99, 114, 101,
  101, 110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34, 83, 117, 98,
  116, 114, 97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34,
  86, 105, 118, 105, 100, 32, 108, 105, 103, 104, 116, 34, 44, 34, 88, 111,
  114, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97,
  99, 105, 116, 121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118,
  101, 114, 116, 32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111,
  108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 97,
  110, 115, 32, 102, 111, 110, 100, 32, 47, 32, 119, 105, 116, 104, 111, 117,
  116, 32, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 32, 61, 32, 98,
  111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  66, 111, 111, 115, 116, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97, 109, 106,
  32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 48, 57,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  115, 97, 109, 106, 95, 84, 101, 115, 116, 95, 73, 109, 97, 103, 101, 80,
  108, 97, 110, 101, 95, 51, 68, 58, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 88, 95, 97, 110, 103,
  108, 101, 61, 36, 49, 10, 89, 95, 97, 110, 103, 108, 101, 61, 36, 50,
  10, 90, 95, 97, 110, 103, 108, 101, 61, 36, 51, 10, 82, 51, 68, 95,
  70, 79, 86, 61, 36, 52, 10, 82, 51, 68, 95, 88, 95, 108, 105, 103,
  104, 116, 61, 36, 53, 10, 82, 51, 68, 95, 89, 95, 108, 105, 103, 104,
  116, 61, 36, 54, 10, 82, 51, 68, 95, 90, 95, 108, 105, 103, 104, 116,
  61, 36, 55, 10, 82, 51, 68, 95, 83, 112, 101, 99, 117, 108, 97, 114,
  95, 108, 105, 103, 104, 116, 110, 101, 115, 115, 61, 36, 56, 10, 82, 51,
  68, 95, 83, 112, 101, 99, 117, 108, 97, 114, 95, 115, 104, 105, 110, 105,
  110, 101, 115, 115, 61, 36, 57, 10, 82, 51, 68, 95, 82, 101, 110, 100,
  101, 114, 105, 110, 103, 95, 109, 111, 100, 101, 61, 36, 49, 48, 10, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 49, 49, 10, 86, 95, 67,
  111, 117, 108, 101, 117, 114, 61, 36, 49, 49, 10, 66, 95, 67, 111, 117,
  108, 101, 117, 114, 61, 36, 49, 51, 10, 65, 95, 67, 111, 117, 108, 101,
  117, 114, 61, 36, 49, 52, 10, 77, 111, 100, 101, 95, 77, 101, 108, 97,
  110, 103, 101, 61, 36, 49, 53, 10, 79, 112, 97, 99, 105, 116, 121, 95,
  77, 101, 108, 97, 110, 103, 101, 61, 36, 49, 54, 10, 82, 101, 118, 101,
  114, 116, 95, 108, 97, 121, 101, 114, 115, 95, 77, 101, 108, 97, 110, 103,
  101, 61, 36, 49, 55, 10, 83, 97, 110, 115, 95, 70, 111, 110, 100, 61,
  36, 49, 56, 10, 66, 111, 111, 115, 116, 61, 36, 49, 57, 10, 88, 95,
  97, 110, 103, 108, 101, 61, 123, 36, 88, 95, 97, 110, 103, 108, 101, 45,
  49, 56, 48, 125, 10, 89, 95, 97, 110, 103, 108, 101, 61, 123, 36, 89,
  95, 97, 110, 103, 108, 101, 45, 49, 56, 48, 125, 10, 90, 95, 97, 110,
  103, 108, 101, 61, 123, 36, 90, 95, 97, 110, 103, 108, 101, 45, 49, 56,
  48, 125, 10, 76, 97, 114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105,
  110, 101, 61, 123, 119, 125, 10, 72, 97, 117, 116, 101, 117, 114, 95, 111,
  114, 105, 103, 105, 110, 101, 61, 123, 104, 125, 10, 71, 114, 97, 110, 100,
  101, 95, 68, 105, 109, 101, 110, 115, 105, 111, 110, 61, 123, 109, 97, 120,
  40, 36, 76, 97, 114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110,
  101, 44, 36, 72, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105,
  110, 101, 41, 125, 10, 86, 97, 108, 101, 117, 114, 95, 84, 101, 115, 116,
  61, 49, 46, 50, 53, 10, 45, 105, 102, 32, 123, 36, 71, 114, 97, 110,
  100, 101, 95, 68, 105, 109, 101, 110, 115, 105, 111, 110, 62, 49, 48, 50,
  52, 125, 10, 73, 109, 97, 103, 101, 95, 84, 114, 111, 112, 95, 71, 114,
  97, 110, 100, 101, 61, 123, 36, 71, 114, 97, 110, 100, 101, 95, 68, 105,
  109, 101, 110, 115, 105, 111, 110, 47, 49, 48, 50, 52, 125, 10, 45, 114,
  101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 123, 36, 76, 97, 114, 103,
  101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 47, 123, 36, 86, 97,
  108, 101, 117, 114, 95, 84, 101, 115, 116, 42, 36, 73, 109, 97, 103, 101,
  95, 84, 114, 111, 112, 95, 71, 114, 97, 110, 100, 101, 125, 125, 44, 123,
  36, 72, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101,
  47, 123, 36, 86, 97, 108, 101, 117, 114, 95, 84, 101, 115, 116, 42, 36,
  73, 109, 97, 103, 101, 95, 84, 114, 111, 112, 95, 71, 114, 97, 110, 100,
  101, 125, 125, 44, 49, 44, 52, 44, 53, 10, 45, 101, 108, 115, 101, 10,
  73, 109, 97, 103, 101, 95, 84, 114, 111, 112, 95, 71, 114, 97, 110, 100,
  101, 61, 49, 10, 45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32,
  123, 36, 76, 97, 114, 103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110,
  101, 47, 36, 86, 97, 108, 101, 117, 114, 95, 84, 101, 115, 116, 125, 44,
  123, 36, 72, 97, 117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110,
  101, 47, 36, 86, 97, 108, 101, 117, 114, 95, 84, 101, 115, 116, 125, 44,
  49, 44, 52, 44, 53, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 109,
  97, 103, 101, 112, 108, 97, 110, 101, 51, 100, 91, 45, 49, 93, 10, 45,
  103, 105, 109, 112, 95, 114, 101, 110, 100, 101, 114, 51, 100, 91, 45, 49,
  93, 32, 123, 36, 71, 114, 97, 110, 100, 101, 95, 68, 105, 109, 101, 110,
  115, 105, 111, 110, 47, 36, 73, 109, 97, 103, 101, 95, 84, 114, 111, 112,
  95, 71, 114, 97, 110, 100, 101, 125, 44, 123, 36, 71, 114, 97, 110, 100,
  101, 95, 68, 105, 109, 101, 110, 115, 105, 111, 110, 47, 36, 73, 109, 97,
  103, 101, 95, 84, 114, 111, 112, 95, 71, 114, 97, 110, 100, 101, 125, 44,
  48, 46, 56, 44, 36, 88, 95, 97, 110, 103, 108, 101, 44, 36, 89, 95,
  97, 110, 103, 108, 101, 44, 36, 90, 95, 97, 110, 103, 108, 101, 44, 36,
  82, 51, 68, 95, 70, 79, 86, 44, 36, 82, 51, 68, 95, 88, 95, 108,
  105, 103, 104, 116, 44, 36, 82, 51, 68, 95, 89, 95, 108, 105, 103, 104,
  116, 44, 36, 82, 51, 68, 95, 90, 95, 108, 105, 103, 104, 116, 44, 36,
  82, 51, 68, 95, 83, 112, 101, 99, 117, 108, 97, 114, 95, 108, 105, 103,
  104, 116, 110, 101, 115, 115, 44, 36, 82, 51, 68, 95, 83, 112, 101, 99,
  117, 108, 97, 114, 95, 115, 104, 105, 110, 105, 110, 101, 115, 115, 44, 36,
  82, 51, 68, 95, 82, 101, 110, 100, 101, 114, 105, 110, 103, 95, 109, 111,
  100, 101, 10, 45, 99, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 10,
  45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 32, 48, 10,
  45, 114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 36, 76, 97, 114,
  103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 44, 36, 72, 97,
  117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 44, 49, 44,
  52, 44, 53, 10, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53,
  10, 45, 105, 102, 32, 123, 36, 66, 111, 111, 115, 116, 61, 61, 49, 125,
  10, 45, 103, 105, 109, 112, 95, 110, 111, 114, 109, 97, 108, 105, 122, 101,
  95, 108, 111, 99, 97, 108, 91, 45, 49, 93, 32, 50, 44, 54, 44, 53,
  44, 50, 48, 44, 49, 44, 51, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 10, 36, 76, 97, 114,
  103, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 44, 36, 72, 97,
  117, 116, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 44, 49, 44,
  52, 10, 45, 105, 102, 32, 123, 36, 83, 97, 110, 115, 95, 70, 111, 110,
  100, 61, 61, 48, 125, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111,
  114, 91, 45, 49, 93, 32, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114,
  44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117,
  114, 10, 45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49,
  44, 45, 50, 93, 32, 32, 36, 77, 111, 100, 101, 95, 77, 101, 108, 97,
  110, 103, 101, 44, 36, 79, 112, 97, 99, 105, 116, 121, 95, 77, 101, 108,
  97, 110, 103, 101, 44, 36, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121,
  101, 114, 115, 95, 77, 101, 108, 97, 110, 103, 101, 10, 45, 101, 108, 115,
  101, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49,
  93, 32, 48, 44, 48, 44, 48, 44, 48, 10, 45, 99, 111, 109, 112, 111,
  115, 101, 95, 97, 108, 112, 104, 97, 91, 45, 50, 44, 45, 49, 93, 10,
  45, 101, 110, 100, 105, 102, 10, 35, 32, 45, 116, 101, 120, 116, 95, 111,
  117, 116, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 71, 114, 97, 110,
  100, 101, 95, 68, 105, 109, 101, 110, 115, 105, 111, 110, 44, 49, 48, 44,
  49, 49, 48, 44, 54, 52, 44, 49, 44, 49, 44, 50, 53, 53, 44, 50,
  53, 53, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 84, 101, 115, 116, 32, 116,
  101, 120, 116, 32, 50, 32, 51, 100, 32, 58, 32, 115, 97, 109, 106, 95,
  84, 101, 115, 116, 95, 84, 101, 120, 116, 95, 50, 95, 51, 68, 44, 32,
  115, 97, 109, 106, 95, 84, 101, 115, 116, 95, 84, 101, 120, 116, 95, 50,
  95, 51, 68, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100,
  61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109,
  97, 108, 108, 62, 77, 97, 120, 46, 32, 68, 105, 109, 101, 110, 115, 105,
  111, 110, 115, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97,
  110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 105,
  120, 101, 108, 115, 32, 61, 32, 105, 110, 116, 40, 50, 48, 52, 56, 44,
  49, 48, 50, 52, 44, 52, 48, 57, 54, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97,
  116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114,
  111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34,
  62, 60, 115, 109, 97, 108, 108, 62, 84, 101, 120, 116, 51, 68, 60, 47,
  115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 101, 120, 116, 32, 61, 32,
  116, 101, 120, 116, 123, 34, 92, 102, 92, 102, 92, 102, 92, 102, 66, 111,
  110, 106, 111, 117, 114, 33, 92, 114, 92, 110, 84, 101, 115, 116, 92, 102,
  50, 92, 98, 84, 101, 120, 116, 101, 92, 102, 51, 68, 92, 102, 34, 125,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 111, 110, 116, 32, 104,
  101, 105, 103, 104, 116, 32, 61, 32, 105, 110, 116, 40, 49, 53, 48, 44,
  53, 48, 44, 50, 53, 54, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 68, 101, 112, 116, 104, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49,
  44, 52, 56, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109,
  111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 49, 46, 53, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 67, 111, 117, 108, 101, 117, 114, 32, 47, 32, 99, 111,
  108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 54, 52, 44, 49,
  50, 56, 44, 49, 57, 50, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103,
  114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100,
  34, 62, 60, 115, 109, 97, 108, 108, 62, 82, 101, 110, 100, 101, 114, 32,
  51, 68, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 56, 48, 44, 49, 56,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 56, 48, 44, 49, 56, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 90, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 45, 49, 56, 48, 44, 49, 56, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 111, 118, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 52, 53, 44, 49, 44, 57, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 88, 45, 108, 105, 103, 104, 116, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 48, 48, 44, 49,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 108,
  105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45,
  49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 90, 45, 108, 105, 103, 104, 116, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 45, 49, 48, 48, 44, 45, 49, 48, 48, 44, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 101, 99, 117, 108, 97, 114,
  32, 108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 48, 46, 53, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 112, 101, 99, 117, 108, 97, 114, 32, 115, 104,
  105, 110, 105, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 46, 55, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 82, 101, 110, 100, 101, 114, 105, 110, 103, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 52, 44, 34, 68, 111, 116, 115, 34, 44, 34, 87,
  105, 114, 101, 102, 114, 97, 109, 101, 34, 44, 34, 70, 108, 97, 116, 34,
  44, 34, 70, 108, 97, 116, 32, 115, 104, 97, 100, 101, 100, 34, 44, 34,
  71, 111, 117, 114, 97, 117, 100, 34, 44, 34, 80, 104, 111, 110, 103, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97,
  109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47,
  48, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 115, 97, 109, 106, 95, 84, 101, 115, 116, 95, 84, 101, 120, 116,
  95, 50, 95, 51, 68, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64,
  35, 32, 45, 108, 91, 36, 62, 93, 10, 77, 97, 120, 95, 68, 105, 109,
  101, 110, 115, 105, 111, 110, 61, 36, 49, 10, 116, 101, 120, 116, 51, 100,
  95, 116, 101, 120, 116, 61, 36, 50, 10, 116, 101, 120, 116, 51, 100, 95,
  102, 111, 110, 116, 95, 104, 101, 105, 103, 104, 116, 61, 36, 51, 10, 116,
  101, 120, 116, 51, 100, 95, 100, 101, 112, 116, 104, 61, 36, 52, 10, 116,
  101, 120, 116, 51, 100, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  61, 36, 53, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 84, 101,
  120, 116, 101, 61, 36, 54, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 84, 101, 120, 116, 101, 61, 36, 55, 10, 66, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 84, 101, 120, 116, 101, 61, 36, 56, 10, 65, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 84, 101, 120, 116, 101, 61, 36, 57, 10,
  88, 95, 97, 110, 103, 108, 101, 61, 36, 49, 48, 10, 89, 95, 97, 110,
  103, 108, 101, 61, 36, 49, 49, 10, 90, 95, 97, 110, 103, 108, 101, 61,
  36, 49, 50, 10, 82, 51, 68, 95, 70, 79, 86, 61, 36, 49, 51, 10,
  82, 51, 68, 95, 88, 95, 108, 105, 103, 104, 116, 61, 36, 49, 52, 10,
  82, 51, 68, 95, 89, 95, 108, 105, 103, 104, 116, 61, 36, 49, 53, 10,
  82, 51, 68, 95, 90, 95, 108, 105, 103, 104, 116, 61, 36, 49, 54, 10,
  82, 51, 68, 95, 83, 112, 101, 99, 117, 108, 97, 114, 95, 108, 105, 103,
  104, 116, 110, 101, 115, 115, 61, 36, 49, 55, 10, 82, 51, 68, 95, 83,
  112, 101, 99, 117, 108, 97, 114, 95, 115, 104, 105, 110, 105, 110, 101, 115,
  115, 61, 36, 49, 56, 10, 82, 51, 68, 95, 82, 101, 110, 100, 101, 114,
  105, 110, 103, 95, 109, 111, 100, 101, 61, 36, 49, 57, 10, 73, 109, 97,
  103, 101, 95, 84, 114, 111, 112, 95, 71, 114, 97, 110, 100, 101, 61, 49,
  10, 36, 77, 97, 120, 95, 68, 105, 109, 101, 110, 115, 105, 111, 110, 44,
  36, 77, 97, 120, 95, 68, 105, 109, 101, 110, 115, 105, 111, 110, 44, 49,
  44, 52, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45,
  49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 10, 45, 114, 109, 91, 45,
  50, 93, 10, 45, 116, 101, 120, 116, 51, 100, 32, 36, 116, 101, 120, 116,
  51, 100, 95, 116, 101, 120, 116, 44, 36, 116, 101, 120, 116, 51, 100, 95,
  102, 111, 110, 116, 95, 104, 101, 105, 103, 104, 116, 44, 36, 116, 101, 120,
  116, 51, 100, 95, 100, 101, 112, 116, 104, 44, 36, 116, 101, 120, 116, 51,
  100, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 10, 45, 99, 111,
  108, 51, 100, 91, 45, 49, 93, 32, 32, 36, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 84, 101, 120, 116, 101, 44, 36, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 84, 101, 120, 116, 101, 44, 36, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 84, 101, 120, 116, 101, 44, 36, 65, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 84, 101, 120, 116, 101, 10, 45, 103, 105,
  109, 112, 95, 114, 101, 110, 100, 101, 114, 51, 100, 91, 45, 49, 93, 32,
  123, 36, 77, 97, 120, 95, 68, 105, 109, 101, 110, 115, 105, 111, 110, 47,
  36, 73, 109, 97, 103, 101, 95, 84, 114, 111, 112, 95, 71, 114, 97, 110,
  100, 101, 125, 44, 123, 36, 77, 97, 120, 95, 68, 105, 109, 101, 110, 115,
  105, 111, 110, 47, 36, 73, 109, 97, 103, 101, 95, 84, 114, 111, 112, 95,
  71, 114, 97, 110, 100, 101, 125, 44, 48, 46, 56, 44, 36, 88, 95, 97,
  110, 103, 108, 101, 44, 36, 89, 95, 97, 110, 103, 108, 101, 44, 36, 90,
  95, 97, 110, 103, 108, 101, 44, 36, 82, 51, 68, 95, 70, 79, 86, 44,
  36, 82, 51, 68, 95, 88, 95, 108, 105, 103, 104, 116, 44, 36, 82, 51,
  68, 95, 89, 95, 108, 105, 103, 104, 116, 44, 36, 82, 51, 68, 95, 90,
  95, 108, 105, 103, 104, 116, 44, 36, 82, 51, 68, 95, 83, 112, 101, 99,
  117, 108, 97, 114, 95, 108, 105, 103, 104, 116, 110, 101, 115, 115, 44, 36,
  82, 51, 68, 95, 83, 112, 101, 99, 117, 108, 97, 114, 95, 115, 104, 105,
  110, 105, 110, 101, 115, 115, 44, 36, 82, 51, 68, 95, 82, 101, 110, 100,
  101, 114, 105, 110, 103, 95, 109, 111, 100, 101, 10, 45, 99, 111, 109, 112,
  111, 115, 101, 95, 97, 108, 112, 104, 97, 91, 45, 49, 44, 45, 50, 93,
  10, 45, 97, 117, 116, 111, 99, 114, 111, 112, 91, 45, 49, 93, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109,
  112, 32, 84, 101, 115, 116, 32, 116, 101, 120, 116, 32, 51, 100, 32, 58,
  32, 115, 97, 109, 106, 95, 84, 101, 115, 116, 95, 84, 101, 120, 116, 95,
  51, 68, 44, 32, 115, 97, 109, 106, 95, 84, 101, 115, 116, 95, 84, 101,
  120, 116, 95, 51, 68, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117,
  110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60,
  115, 109, 97, 108, 108, 62, 77, 97, 120, 46, 32, 68, 105, 109, 101, 110,
  115, 105, 111, 110, 115, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115,
  112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  80, 105, 120, 101, 108, 115, 32, 61, 32, 105, 110, 116, 40, 50, 48, 52,
  56, 44, 49, 48, 50, 52, 44, 52, 48, 57, 54, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101,
  103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101,
  100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 84, 101, 120, 116, 51, 68,
  60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 101, 120, 116, 32,
  61, 32, 116, 101, 120, 116, 123, 34, 92, 102, 92, 102, 92, 102, 66, 111,
  110, 106, 111, 117, 114, 33, 92, 114, 92, 110, 84, 101, 115, 116, 92, 98,
  84, 101, 120, 116, 101, 92, 102, 51, 68, 92, 102, 34, 125, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 70, 111, 110, 116, 32, 104, 101, 105, 103,
  104, 116, 32, 61, 32, 105, 110, 116, 40, 49, 53, 48, 44, 53, 48, 44,
  52, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101,
  112, 116, 104, 32, 61, 32, 105, 110, 116, 40, 49, 44, 49, 44, 50, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46,
  53, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 111, 117, 108, 101, 117, 114, 32, 47, 32, 99, 111, 108, 111, 114,
  32, 61, 32, 99, 111, 108, 111, 114, 40, 54, 52, 44, 49, 50, 56, 44,
  49, 57, 50, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117,
  110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60,
  115, 109, 97, 108, 108, 62, 79, 98, 106, 101, 99, 116, 32, 51, 68, 60,
  47, 115, 109, 97, 108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108, 105, 100, 97,
  116, 105, 111, 110, 32, 112, 97, 114, 97, 109, 101, 116, 114, 101, 115, 32,
  61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 79, 98, 106, 51, 100, 32, 105, 115, 32, 100, 111, 117, 98,
  108, 101, 32, 115, 105, 100, 101, 100, 32, 61, 32, 98, 111, 111, 108, 40,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 98, 106, 51,
  100, 32, 105, 115, 32, 122, 32, 98, 117, 102, 102, 101, 114, 32, 61, 32,
  98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 79, 98, 106, 51, 100, 32, 102, 111, 99, 97, 108, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 52, 53, 44, 49, 44, 57, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 79, 98, 106, 51, 100, 32, 108, 105,
  103, 104, 116, 32, 120, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44,
  45, 49, 48, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 79, 98, 106, 51, 100, 32, 108, 105, 103, 104, 116, 32, 121,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 45, 49, 48, 48, 44,
  49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 98,
  106, 51, 100, 32, 108, 105, 103, 104, 116, 32, 122, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 45, 49, 48, 48, 44, 45, 49, 48, 48, 44, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 98, 106, 51, 100, 32,
  115, 112, 101, 99, 117, 108, 97, 114, 32, 108, 105, 103, 104, 116, 110, 101,
  115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 53, 44, 48,
  44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 98, 106,
  51, 100, 32, 115, 112, 101, 99, 117, 108, 97, 114, 32, 115, 104, 105, 110,
  105, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  55, 44, 48, 44, 51, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100,
  61, 34, 111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109,
  97, 108, 108, 62, 70, 111, 110, 100, 32, 47, 32, 66, 97, 99, 107, 103,
  114, 111, 117, 110, 100, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47, 115,
  112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  67, 111, 117, 108, 101, 117, 114, 32, 47, 32, 99, 111, 108, 111, 114, 32,
  61, 32, 99, 111, 108, 111, 114, 40, 48, 44, 48, 44, 48, 44, 50, 53,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97,
  110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114,
  97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62,
  69, 102, 102, 101, 116, 115, 60, 47, 115, 109, 97, 108, 108, 62, 60, 47,
  115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 69, 102, 102, 101, 116, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  49, 44, 34, 83, 97, 110, 115, 34, 44, 34, 68, 101, 99, 97, 108, 97,
  103, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 112,
  97, 105, 115, 115, 101, 117, 114, 32, 47, 32, 116, 104, 105, 99, 107, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  52, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80,
  114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111,
  114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115,
  97, 109, 106, 32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100,
  97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49,
  47, 48, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 115, 97, 109, 106, 95, 84, 101, 115, 116, 95, 84, 101, 120,
  116, 95, 51, 68, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 77, 97, 120, 95, 68, 105, 109, 101,
  110, 115, 105, 111, 110, 61, 36, 49, 10, 116, 101, 120, 116, 51, 100, 95,
  116, 101, 120, 116, 61, 36, 50, 10, 116, 101, 120, 116, 51, 100, 95, 102,
  111, 110, 116, 95, 104, 101, 105, 103, 104, 116, 61, 36, 51, 10, 116, 101,
  120, 116, 51, 100, 95, 100, 101, 112, 116, 104, 61, 36, 52, 10, 116, 101,
  120, 116, 51, 100, 95, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61,
  36, 53, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 84, 101, 120,
  116, 101, 61, 36, 54, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  84, 101, 120, 116, 101, 61, 36, 55, 10, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 84, 101, 120, 116, 101, 61, 36, 56, 10, 65, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 84, 101, 120, 116, 101, 61, 36, 57, 10, 86,
  97, 108, 105, 100, 97, 116, 105, 111, 110, 95, 80, 97, 114, 97, 109, 95,
  79, 98, 106, 51, 68, 61, 36, 49, 48, 10, 79, 98, 106, 51, 68, 95,
  105, 115, 95, 100, 111, 117, 98, 108, 101, 95, 115, 105, 100, 101, 100, 61,
  36, 49, 49, 10, 79, 98, 106, 51, 68, 95, 105, 115, 95, 122, 98, 117,
  102, 102, 101, 114, 61, 36, 49, 50, 10, 79, 98, 106, 51, 68, 95, 102,
  111, 99, 97, 108, 101, 61, 36, 49, 51, 10, 79, 98, 106, 51, 68, 95,
  108, 105, 103, 104, 116, 95, 120, 61, 36, 49, 52, 10, 79, 98, 106, 51,
  68, 95, 108, 105, 103, 104, 116, 95, 121, 61, 36, 49, 53, 10, 79, 98,
  106, 51, 68, 95, 108, 105, 103, 104, 116, 95, 122, 61, 36, 49, 54, 10,
  79, 98, 106, 51, 68, 95, 115, 112, 101, 99, 117, 108, 97, 114, 95, 108,
  105, 103, 104, 116, 110, 101, 115, 115, 61, 36, 49, 55, 10, 79, 98, 106,
  51, 68, 95, 115, 112, 101, 99, 117, 108, 97, 114, 95, 115, 104, 105, 110,
  105, 110, 101, 115, 115, 61, 36, 49, 56, 10, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 70, 111, 110, 100, 61, 36, 49, 57, 10, 86, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 70, 111, 110, 100, 61, 36, 50, 48, 10,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 70, 111, 110, 100, 61, 36,
  50, 49, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 70, 111, 110,
  100, 61, 36, 50, 50, 10, 69, 102, 102, 101, 116, 95, 67, 104, 111, 105,
  115, 105, 61, 36, 50, 51, 10, 69, 112, 97, 105, 115, 115, 101, 117, 114,
  61, 36, 50, 52, 10, 79, 98, 106, 51, 68, 95, 120, 61, 48, 10, 79,
  98, 106, 51, 68, 95, 121, 61, 48, 10, 79, 98, 106, 51, 68, 95, 122,
  61, 48, 10, 79, 98, 106, 51, 68, 95, 111, 112, 97, 99, 105, 116, 121,
  61, 49, 10, 79, 98, 106, 51, 68, 95, 114, 101, 110, 100, 101, 114, 105,
  110, 103, 95, 109, 111, 100, 101, 61, 53, 10, 68, 101, 99, 97, 108, 97,
  103, 101, 61, 123, 36, 116, 101, 120, 116, 51, 100, 95, 102, 111, 110, 116,
  95, 104, 101, 105, 103, 104, 116, 47, 50, 48, 125, 10, 36, 77, 97, 120,
  95, 68, 105, 109, 101, 110, 115, 105, 111, 110, 44, 36, 77, 97, 120, 95,
  68, 105, 109, 101, 110, 115, 105, 111, 110, 44, 49, 44, 52, 10, 45, 102,
  105, 108, 108, 95, 99, 111, 108, 111, 114, 91, 45, 49, 44, 45, 50, 93,
  32, 32, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 70, 111, 110,
  100, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 70, 111, 110,
  100, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 70, 111, 110,
  100, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 70, 111, 110,
  100, 10, 45, 114, 109, 91, 45, 50, 93, 10, 45, 116, 101, 120, 116, 51,
  100, 32, 36, 116, 101, 120, 116, 51, 100, 95, 116, 101, 120, 116, 44, 36,
  116, 101, 120, 116, 51, 100, 95, 102, 111, 110, 116, 95, 104, 101, 105, 103,
  104, 116, 44, 36, 116, 101, 120, 116, 51, 100, 95, 100, 101, 112, 116, 104,
  44, 36, 116, 101, 120, 116, 51, 100, 95, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 10, 45, 99, 111, 108, 51, 100, 91, 45, 49, 93, 32, 32,
  36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 84, 101, 120, 116, 101,
  44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 84, 101, 120, 116,
  101, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 84, 101, 120,
  116, 101, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 84, 101,
  120, 116, 101, 10, 45, 105, 102, 32, 123, 36, 86, 97, 108, 105, 100, 97,
  116, 105, 111, 110, 95, 80, 97, 114, 97, 109, 95, 79, 98, 106, 51, 68,
  61, 61, 49, 125, 10, 45, 105, 102, 32, 123, 36, 69, 102, 102, 101, 116,
  95, 67, 104, 111, 105, 115, 105, 61, 61, 48, 125, 10, 45, 111, 98, 106,
  101, 99, 116, 51, 100, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36,
  79, 98, 106, 51, 68, 95, 120, 44, 36, 79, 98, 106, 51, 68, 95, 121,
  44, 36, 79, 98, 106, 51, 68, 95, 122, 44, 36, 79, 98, 106, 51, 68,
  95, 111, 112, 97, 99, 105, 116, 121, 44, 36, 79, 98, 106, 51, 68, 95,
  114, 101, 110, 100, 101, 114, 105, 110, 103, 95, 109, 111, 100, 101, 44, 36,
  79, 98, 106, 51, 68, 95, 105, 115, 95, 100, 111, 117, 98, 108, 101, 95,
  115, 105, 100, 101, 100, 44, 36, 79, 98, 106, 51, 68, 95, 105, 115, 95,
  122, 98, 117, 102, 102, 101, 114, 44, 36, 79, 98, 106, 51, 68, 95, 102,
  111, 99, 97, 108, 101, 44, 36, 79, 98, 106, 51, 68, 95, 108, 105, 103,
  104, 116, 95, 120, 44, 36, 79, 98, 106, 51, 68, 95, 108, 105, 103, 104,
  116, 95, 121, 44, 36, 79, 98, 106, 51, 68, 95, 108, 105, 103, 104, 116,
  95, 122, 44, 36, 79, 98, 106, 51, 68, 95, 115, 112, 101, 99, 117, 108,
  97, 114, 95, 108, 105, 103, 104, 116, 110, 101, 115, 115, 44, 36, 79, 98,
  106, 51, 68, 95, 115, 112, 101, 99, 117, 108, 97, 114, 95, 115, 104, 105,
  110, 105, 110, 101, 115, 115, 10, 45, 101, 108, 105, 102, 32, 123, 36, 69,
  102, 102, 101, 116, 95, 67, 104, 111, 105, 115, 105, 61, 61, 49, 125, 10,
  45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 50, 93, 32, 91, 45,
  49, 93, 44, 36, 79, 98, 106, 51, 68, 95, 120, 44, 36, 79, 98, 106,
  51, 68, 95, 121, 44, 36, 79, 98, 106, 51, 68, 95, 122, 44, 36, 79,
  98, 106, 51, 68, 95, 111, 112, 97, 99, 105, 116, 121, 44, 36, 79, 98,
  106, 51, 68, 95, 114, 101, 110, 100, 101, 114, 105, 110, 103, 95, 109, 111,
  100, 101, 44, 36, 79, 98, 106, 51, 68, 95, 105, 115, 95, 100, 111, 117,
  98, 108, 101, 95, 115, 105, 100, 101, 100, 44, 36, 79, 98, 106, 51, 68,
  95, 105, 115, 95, 122, 98, 117, 102, 102, 101, 114, 44, 36, 79, 98, 106,
  51, 68, 95, 102, 111, 99, 97, 108, 101, 44, 36, 79, 98, 106, 51, 68,
  95, 108, 105, 103, 104, 116, 95, 120, 44, 36, 79, 98, 106, 51, 68, 95,
  108, 105, 103, 104, 116, 95, 121, 44, 36, 79, 98, 106, 51, 68, 95, 108,
  105, 103, 104, 116, 95, 122, 44, 36, 79, 98, 106, 51, 68, 95, 115, 112,
  101, 99, 117, 108, 97, 114, 95, 108, 105, 103, 104, 116, 110, 101, 115, 115,
  44, 36, 79, 98, 106, 51, 68, 95, 115, 112, 101, 99, 117, 108, 97, 114,
  95, 115, 104, 105, 110, 105, 110, 101, 115, 115, 10, 45, 111, 98, 106, 101,
  99, 116, 51, 100, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 123, 36,
  68, 101, 99, 97, 108, 97, 103, 101, 43, 36, 79, 98, 106, 51, 68, 95,
  120, 125, 44, 123, 36, 68, 101, 99, 97, 108, 97, 103, 101, 43, 36, 79,
  98, 106, 51, 68, 95, 121, 125, 44, 36, 79, 98, 106, 51, 68, 95, 122,
  44, 36, 79, 98, 106, 51, 68, 95, 111, 112, 97, 99, 105, 116, 121, 44,
  36, 79, 98, 106, 51, 68, 95, 114, 101, 110, 100, 101, 114, 105, 110, 103,
  95, 109, 111, 100, 101, 44, 36, 79, 98, 106, 51, 68, 95, 105, 115, 95,
  100, 111, 117, 98, 108, 101, 95, 115, 105, 100, 101, 100, 44, 36, 79, 98,
  106, 51, 68, 95, 105, 115, 95, 122, 98, 117, 102, 102, 101, 114, 44, 36,
  79, 98, 106, 51, 68, 95, 102, 111, 99, 97, 108, 101, 44, 36, 79, 98,
  106, 51, 68, 95, 108, 105, 103, 104, 116, 95, 120, 44, 36, 79, 98, 106,
  51, 68, 95, 108, 105, 103, 104, 116, 95, 121, 44, 36, 79, 98, 106, 51,
  68, 95, 108, 105, 103, 104, 116, 95, 122, 44, 36, 79, 98, 106, 51, 68,
  95, 115, 112, 101, 99, 117, 108, 97, 114, 95, 108, 105, 103, 104, 116, 110,
  101, 115, 115, 44, 36, 79, 98, 106, 51, 68, 95, 115, 112, 101, 99, 117,
  108, 97, 114, 95, 115, 104, 105, 110, 105, 110, 101, 115, 115, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 108, 115, 101, 10, 45, 105, 102, 32, 123,
  36, 69, 102, 102, 101, 116, 95, 67, 104, 111, 105, 115, 105, 61, 61, 48,
  125, 10, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 48, 44, 48, 10, 45, 101, 108, 105, 102, 32, 123,
  36, 69, 102, 102, 101, 116, 95, 67, 104, 111, 105, 115, 105, 61, 61, 49,
  125, 10, 45, 111, 98, 106, 101, 99, 116, 51, 100, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 44, 48, 44, 48, 10, 45, 111, 98, 106, 101, 99, 116,
  51, 100, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 68, 101, 99,
  97, 108, 97, 103, 101, 44, 36, 68, 101, 99, 97, 108, 97, 103, 101, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 105, 102, 32, 123, 36, 69, 112, 97, 105,
  115, 115, 101, 117, 114, 62, 48, 125, 10, 45, 100, 105, 108, 97, 116, 101,
  95, 99, 105, 114, 99, 91, 45, 49, 93, 32, 123, 114, 111, 117, 110, 100,
  40, 36, 116, 101, 120, 116, 51, 100, 95, 102, 111, 110, 116, 95, 104, 101,
  105, 103, 104, 116, 42, 36, 69, 112, 97, 105, 115, 115, 101, 117, 114, 47,
  49, 48, 48, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 99, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 105, 102, 32, 123, 36,
  65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 70, 111, 110, 100, 61, 61,
  50, 53, 53, 125, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111,
  100, 101, 91, 45, 49, 93, 32, 51, 10, 45, 101, 108, 115, 101, 10, 45,
  116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 91, 45, 49, 93,
  32, 52, 10, 45, 101, 110, 100, 105, 102, 10, 35, 45, 102, 105, 108, 108,
  95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48,
  44, 50, 53, 53, 10, 35, 45, 116, 101, 120, 116, 95, 111, 117, 116, 108,
  105, 110, 101, 91, 45, 49, 93, 32, 123, 119, 125, 92, 110, 123, 104, 125,
  44, 49, 48, 44, 49, 48, 44, 54, 52, 44, 49, 44, 49, 44, 50, 53,
  53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 84, 101, 115,
  116, 32, 116, 119, 105, 114, 108, 32, 49, 32, 58, 32, 84, 101, 115, 116,
  95, 84, 119, 105, 114, 108, 95, 115, 97, 109, 106, 44, 32, 84, 101, 115,
  116, 95, 84, 119, 105, 114, 108, 95, 115, 97, 109, 106, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  79, 114, 105, 103, 105, 110, 101, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 111, 115, 105, 116,
  105, 111, 110, 32, 120, 32, 40, 37, 41, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 80, 111, 115, 105, 116, 105, 111, 110, 32, 121, 32,
  40, 37, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 80, 97, 114, 97, 109, 92, 51, 48, 51, 92,
  50, 53, 48, 116, 114, 101, 115, 32, 70, 105, 108, 116, 114, 101, 32, 84,
  119, 105, 114, 108, 32, 45, 32, 84, 119, 105, 114, 108, 32, 112, 97, 114,
  97, 109, 101, 116, 101, 114, 115, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 108, 105,
  116, 117, 100, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 55,
  53, 44, 45, 50, 53, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 66, 111, 114, 100, 101, 114, 115, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 49, 44, 34, 66, 108, 97, 99, 107, 34, 44, 34, 78,
  101, 97, 114, 101, 115, 116, 34, 44, 34, 82, 101, 112, 101, 97, 116, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 84, 114, 97, 105, 116, 115, 32, 47, 32, 83, 116, 114, 111, 107,
  101, 115, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 76, 111, 110, 103, 117, 101, 117, 114, 32, 47,
  32, 108, 101, 110, 103, 116, 104, 32, 40, 112, 105, 120, 101, 108, 115, 41,
  32, 61, 32, 105, 110, 116, 40, 49, 53, 48, 44, 49, 44, 52, 48, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 114, 105,
  97, 116, 105, 111, 110, 115, 32, 37, 32, 40, 108, 111, 110, 103, 117, 101,
  117, 114, 47, 108, 101, 110, 103, 116, 104, 41, 32, 61, 32, 102, 108, 111,
  97, 116, 40, 49, 48, 48, 44, 48, 44, 49, 48, 48, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 100, 101, 32, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 115, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 48, 44, 34, 78, 111, 110, 32, 47, 32, 78, 111, 34, 44, 34, 80,
  108, 117, 115, 32, 47, 32, 77, 111, 114, 101, 34, 44, 34, 77, 111, 105,
  110, 115, 32, 47, 32, 76, 101, 115, 115, 34, 44, 34, 80, 108, 117, 115,
  32, 47, 32, 77, 111, 114, 101, 32, 91, 109, 105, 108, 105, 101, 117, 45,
  109, 105, 100, 100, 108, 101, 93, 34, 44, 34, 77, 111, 105, 110, 115, 32,
  47, 32, 76, 101, 115, 115, 32, 91, 109, 105, 108, 105, 101, 117, 45, 109,
  105, 100, 100, 108, 101, 93, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 69, 108, 111, 105, 103, 110, 101, 109, 101, 110, 116, 32, 100, 117,
  32, 99, 101, 110, 116, 114, 101, 32, 40, 112, 105, 120, 101, 108, 115, 41,
  32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 50, 48, 48, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 109, 98, 114, 101,
  32, 100, 101, 32, 116, 114, 97, 105, 116, 115, 32, 47, 32, 110, 117, 109,
  98, 101, 114, 32, 111, 102, 32, 115, 116, 114, 111, 107, 101, 115, 32, 61,
  32, 105, 110, 116, 40, 49, 54, 44, 49, 44, 50, 49, 54, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 40,
  100, 92, 51, 48, 51, 92, 50, 53, 49, 112, 97, 114, 116, 32, 47, 32,
  115, 116, 97, 114, 116, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 65, 110, 103, 108, 101, 32, 40, 102, 105, 110, 32, 47, 32, 101, 110,
  100, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 54, 48, 44, 48,
  44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  111, 117, 108, 101, 117, 114, 47, 32, 99, 111, 108, 111, 114, 32, 61, 32,
  99, 111, 108, 111, 114, 40, 50, 52, 48, 44, 54, 48, 44, 49, 50, 48,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86,
  97, 114, 105, 97, 116, 105, 111, 110, 32, 100, 101, 32, 99, 111, 117, 108,
  101, 117, 114, 32, 47, 32, 99, 111, 108, 111, 114, 32, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  80, 97, 115, 32, 100, 101, 32, 118, 97, 114, 105, 97, 116, 105, 111, 110,
  32, 47, 32, 78, 111, 32, 99, 104, 97, 110, 103, 101, 34, 44, 34, 67,
  111, 117, 108, 101, 117, 114, 115, 32, 97, 108, 101, 97, 116, 111, 105, 114,
  101, 115, 32, 47, 32, 82, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111,
  114, 115, 34, 44, 34, 70, 97, 105, 98, 108, 101, 109, 101, 110, 116, 32,
  110, 117, 97, 110, 99, 101, 101, 32, 47, 32, 80, 111, 111, 114, 108, 121,
  32, 110, 117, 97, 110, 99, 101, 100, 34, 44, 34, 77, 111, 121, 101, 110,
  110, 101, 109, 101, 110, 116, 32, 110, 117, 97, 110, 99, 101, 101, 32, 47,
  32, 77, 111, 100, 101, 114, 97, 116, 101, 108, 121, 32, 110, 117, 97, 110,
  99, 101, 100, 34, 44, 34, 70, 111, 114, 116, 101, 109, 101, 110, 116, 32,
  110, 117, 97, 110, 99, 101, 101, 32, 47, 32, 72, 105, 103, 104, 108, 121,
  32, 110, 117, 97, 110, 99, 101, 100, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 69, 112, 97, 105, 115, 115, 101, 117, 114, 32, 47, 32,
  116, 104, 105, 99, 107, 110, 101, 115, 115, 32, 61, 32, 105, 110, 116, 40,
  50, 48, 44, 48, 44, 54, 52, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 68, 105, 118, 101, 114, 115, 32,
  47, 32, 70, 111, 111, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 108, 111, 117, 32, 47, 32,
  98, 108, 117, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 112,
  114, 101, 97, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48,
  44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 101,
  102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 48, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 66, 108, 101, 110, 100, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 49, 44, 34, 65, 100, 100, 34, 44, 34, 65, 108, 112, 104, 97, 34,
  44, 34, 65, 110, 100, 34, 44, 34, 65, 118, 101, 114, 97, 103, 101, 34,
  44, 34, 66, 108, 117, 101, 34, 44, 34, 66, 117, 114, 110, 34, 44, 34,
  68, 97, 114, 107, 101, 110, 34, 44, 34, 68, 105, 102, 102, 101, 114, 101,
  110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34,
  68, 105, 118, 105, 100, 101, 34, 44, 34, 68, 111, 100, 103, 101, 34, 44,
  34, 69, 120, 99, 108, 117, 115, 105, 111, 110, 34, 44, 34, 70, 114, 101,
  101, 122, 101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 101, 120, 116, 114,
  97, 99, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 109, 101, 114, 103,
  101, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 72, 97, 114, 100,
  32, 108, 105, 103, 104, 116, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44, 34, 72, 117,
  101, 34, 44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111,
  110, 34, 44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44, 34, 76, 105,
  103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110, 101, 97, 114,
  32, 98, 117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97, 114, 32, 108,
  105, 103, 104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97, 110, 99, 101,
  34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 77, 117, 108,
  116, 105, 112, 108, 121, 34, 44, 34, 78, 101, 103, 97, 116, 105, 111, 110,
  34, 44, 34, 79, 114, 34, 44, 34, 79, 118, 101, 114, 108, 97, 121, 34,
  44, 34, 80, 105, 110, 32, 108, 105, 103, 104, 116, 34, 44, 34, 82, 101,
  100, 34, 44, 34, 82, 101, 102, 108, 101, 99, 116, 34, 44, 34, 83, 97,
  116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97,
  103, 101, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118, 101, 114, 97,
  103, 101, 48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117, 114, 110, 34,
  44, 34, 83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34, 44, 34, 83,
  111, 102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83, 99, 114, 101,
  101, 110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34, 83, 117, 98,
  116, 114, 97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 86, 105, 118, 105, 100, 32,
  108, 105, 103, 104, 116, 34, 44, 34, 88, 111, 114, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116, 121, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116, 32, 108, 97,
  121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121,
  112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108,
  108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105,
  122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107,
  119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105,
  99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 101, 117, 114, 115, 32, 47, 32,
  65, 117, 116, 104, 111, 114, 115, 32, 58, 32, 60, 105, 62, 83, 97, 109,
  106, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50,
  48, 49, 52, 47, 48, 49, 47, 49, 55, 60, 47, 105, 62, 46, 60, 47,
  115, 109, 97, 108, 108, 62, 34, 41, 10, 84, 101, 115, 116, 95, 84, 119,
  105, 114, 108, 95, 115, 97, 109, 106, 32, 58, 10, 75, 95, 88, 61, 36,
  49, 10, 75, 95, 89, 61, 36, 50, 10, 35, 35, 32, 102, 105, 108, 116,
  114, 101, 32, 84, 119, 105, 114, 108, 10, 65, 109, 112, 108, 105, 116, 117,
  100, 101, 61, 36, 51, 10, 66, 111, 114, 100, 101, 114, 115, 61, 36, 52,
  10, 76, 111, 110, 103, 117, 101, 117, 114, 61, 36, 53, 10, 86, 97, 114,
  105, 97, 116, 105, 111, 110, 115, 95, 76, 111, 110, 103, 117, 101, 117, 114,
  61, 36, 54, 10, 77, 111, 100, 101, 95, 118, 97, 114, 105, 97, 116, 105,
  111, 110, 115, 61, 36, 55, 10, 69, 108, 111, 105, 103, 110, 101, 109, 101,
  110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101, 61, 36, 56, 10,
  78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 116, 114, 97, 105, 116, 115,
  61, 36, 57, 10, 65, 110, 103, 108, 101, 95, 68, 101, 112, 97, 114, 116,
  61, 36, 49, 48, 10, 65, 110, 103, 108, 101, 95, 70, 105, 110, 61, 36,
  49, 49, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 49, 50,
  10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 49, 51, 10, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 49, 52, 10, 65, 95, 67,
  111, 117, 108, 101, 117, 114, 61, 36, 49, 53, 10, 86, 97, 114, 105, 97,
  116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61,
  36, 49, 54, 10, 69, 112, 97, 105, 115, 115, 101, 117, 114, 61, 36, 49,
  55, 10, 70, 108, 111, 117, 95, 116, 114, 97, 105, 116, 115, 61, 36, 49,
  56, 10, 83, 112, 114, 101, 97, 100, 95, 116, 114, 97, 105, 116, 115, 61,
  36, 49, 57, 10, 68, 101, 102, 111, 114, 109, 95, 116, 114, 97, 105, 116,
  115, 61, 36, 50, 48, 10, 98, 108, 101, 110, 100, 61, 36, 50, 49, 10,
  111, 112, 97, 99, 105, 116, 101, 61, 36, 50, 50, 10, 82, 101, 118, 101,
  114, 116, 95, 108, 97, 121, 101, 114, 115, 61, 36, 50, 51, 10, 80, 111,
  115, 105, 116, 105, 111, 110, 95, 88, 61, 123, 114, 111, 117, 110, 100, 40,
  123, 123, 119, 125, 42, 123, 36, 75, 95, 88, 47, 49, 48, 48, 125, 125,
  41, 125, 10, 80, 111, 115, 105, 116, 105, 111, 110, 95, 89, 61, 123, 114,
  111, 117, 110, 100, 40, 123, 123, 104, 125, 42, 123, 36, 75, 95, 89, 47,
  49, 48, 48, 125, 125, 41, 125, 10, 45, 116, 111, 95, 114, 103, 98, 97,
  10, 123, 119, 125, 44, 123, 104, 125, 44, 49, 44, 52, 10, 65, 110, 103,
  108, 101, 61, 36, 65, 110, 103, 108, 101, 95, 68, 101, 112, 97, 114, 116,
  10, 45, 105, 102, 32, 123, 36, 65, 110, 103, 108, 101, 95, 68, 101, 112,
  97, 114, 116, 62, 36, 65, 110, 103, 108, 101, 95, 70, 105, 110, 125, 10,
  65, 110, 103, 108, 101, 95, 70, 105, 110, 61, 123, 36, 65, 110, 103, 108,
  101, 95, 70, 105, 110, 43, 51, 54, 48, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 105, 110, 99, 114, 101, 109, 101, 110, 116, 95, 116, 104, 101, 116,
  97, 61, 123, 123, 36, 65, 110, 103, 108, 101, 95, 70, 105, 110, 45, 36,
  65, 110, 103, 108, 101, 95, 68, 101, 112, 97, 114, 116, 125, 47, 36, 78,
  111, 109, 98, 114, 101, 95, 100, 101, 95, 116, 114, 97, 105, 116, 115, 125,
  10, 45, 105, 102, 32, 123, 36, 77, 111, 100, 101, 95, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 115, 61, 61, 49, 125, 10, 86, 97, 114, 105, 97,
  116, 105, 111, 110, 61, 123, 123, 36, 76, 111, 110, 103, 117, 101, 117, 114,
  47, 49, 48, 48, 42, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 115,
  95, 76, 111, 110, 103, 117, 101, 117, 114, 125, 47, 36, 78, 111, 109, 98,
  114, 101, 95, 100, 101, 95, 116, 114, 97, 105, 116, 115, 125, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 77, 111, 100, 101, 95,
  118, 97, 114, 105, 97, 116, 105, 111, 110, 115, 61, 61, 50, 125, 10, 86,
  97, 114, 105, 97, 116, 105, 111, 110, 61, 123, 123, 45, 36, 76, 111, 110,
  103, 117, 101, 117, 114, 47, 49, 48, 48, 48, 42, 36, 86, 97, 114, 105,
  97, 116, 105, 111, 110, 115, 95, 76, 111, 110, 103, 117, 101, 117, 114, 125,
  47, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 116, 114, 97, 105,
  116, 115, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123,
  36, 77, 111, 100, 101, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 115,
  61, 61, 51, 125, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 61, 123,
  123, 36, 76, 111, 110, 103, 117, 101, 117, 114, 47, 49, 48, 48, 42, 36,
  86, 97, 114, 105, 97, 116, 105, 111, 110, 115, 95, 76, 111, 110, 103, 117,
  101, 117, 114, 125, 47, 123, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101,
  95, 116, 114, 97, 105, 116, 115, 47, 50, 125, 125, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 77, 111, 100, 101, 95, 118, 97,
  114, 105, 97, 116, 105, 111, 110, 115, 61, 61, 52, 125, 10, 86, 97, 114,
  105, 97, 116, 105, 111, 110, 61, 123, 123, 45, 36, 76, 111, 110, 103, 117,
  101, 117, 114, 47, 49, 48, 48, 48, 42, 36, 86, 97, 114, 105, 97, 116,
  105, 111, 110, 115, 95, 76, 111, 110, 103, 117, 101, 117, 114, 125, 47, 123,
  36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 116, 114, 97, 105, 116,
  115, 47, 50, 125, 125, 10, 45, 101, 110, 100, 105, 102, 10, 76, 111, 110,
  103, 117, 101, 117, 114, 95, 99, 97, 108, 99, 117, 108, 101, 101, 61, 36,
  76, 111, 110, 103, 117, 101, 117, 114, 10, 78, 98, 95, 66, 111, 117, 99,
  108, 101, 61, 49, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111,
  114, 105, 103, 105, 110, 101, 61, 36, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103,
  105, 110, 101, 61, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 10, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101,
  61, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 10, 65, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 61, 36, 65,
  95, 67, 111, 117, 108, 101, 117, 114, 10, 45, 114, 101, 112, 101, 97, 116,
  32, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 116, 114, 97, 105,
  116, 115, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 61, 49,
  125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114, 111, 117,
  110, 100, 40, 123, 40, 63, 40, 50, 53, 53, 41, 41, 125, 41, 125, 10,
  86, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100,
  40, 123, 40, 63, 40, 50, 53, 53, 41, 41, 125, 41, 125, 10, 66, 95,
  67, 111, 117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 123,
  40, 63, 40, 50, 53, 53, 41, 41, 125, 41, 125, 10, 65, 95, 67, 111,
  117, 108, 101, 117, 114, 61, 123, 123, 114, 111, 117, 110, 100, 40, 123, 40,
  63, 40, 50, 48, 48, 41, 41, 125, 41, 125, 43, 53, 53, 125, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114,
  62, 49, 125, 10, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97,
  116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 61, 49, 54, 10,
  45, 105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 61, 51, 125, 10, 86,
  97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  99, 111, 117, 108, 101, 117, 114, 61, 51, 50, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 61, 52, 125,
  10, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 99, 111, 117, 108, 101, 117, 114, 61, 54, 52, 10, 45, 101, 110,
  100, 105, 102, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114,
  111, 117, 110, 100, 40, 123, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 111, 114, 105, 103, 105, 110, 101, 43, 123, 63, 40, 45, 36, 86, 97,
  108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99,
  111, 117, 108, 101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114, 95, 118,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114,
  41, 125, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 62, 50, 53, 53, 125, 10, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  111, 114, 105, 103, 105, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 60, 48,
  125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 10, 45,
  101, 110, 100, 105, 102, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 61,
  123, 114, 111, 117, 110, 100, 40, 123, 36, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 43, 123, 63, 40, 45, 36,
  86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 99, 111, 117, 108, 101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114,
  95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101,
  117, 114, 41, 125, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 62, 50, 53, 53, 125, 10, 86, 95, 67,
  111, 117, 108, 101, 117, 114, 61, 36, 86, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 111, 114, 105, 103, 105, 110, 101, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  60, 48, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101,
  10, 45, 101, 110, 100, 105, 102, 10, 66, 95, 67, 111, 117, 108, 101, 117,
  114, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 66, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 43, 123, 63, 40,
  45, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 44, 36, 86, 97, 108, 101,
  117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117,
  108, 101, 117, 114, 41, 125, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 62, 50, 53, 53, 125, 10, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 66, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 60, 48, 125, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 61,
  36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105,
  110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102,
  10, 68, 101, 98, 117, 116, 95, 88, 61, 123, 36, 80, 111, 115, 105, 116,
  105, 111, 110, 95, 88, 43, 123, 114, 111, 117, 110, 100, 40, 99, 111, 115,
  40, 112, 105, 47, 49, 56, 48, 42, 36, 65, 110, 103, 108, 101, 41, 42,
  36, 69, 108, 111, 105, 103, 110, 101, 109, 101, 110, 116, 95, 100, 117, 95,
  99, 101, 110, 116, 114, 101, 41, 125, 125, 10, 68, 101, 98, 117, 116, 95,
  89, 61, 123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 89, 43, 123,
  114, 111, 117, 110, 100, 40, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48,
  42, 36, 65, 110, 103, 108, 101, 41, 42, 36, 69, 108, 111, 105, 103, 110,
  101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101, 41,
  125, 125, 10, 69, 120, 116, 114, 101, 109, 105, 116, 101, 95, 88, 61, 123,
  36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 88, 43, 123, 114, 111, 117,
  110, 100, 40, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 65,
  110, 103, 108, 101, 41, 42, 123, 36, 76, 111, 110, 103, 117, 101, 117, 114,
  95, 99, 97, 108, 99, 117, 108, 101, 101, 43, 36, 69, 108, 111, 105, 103,
  110, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101,
  125, 41, 125, 125, 10, 69, 120, 116, 114, 101, 109, 105, 116, 101, 95, 89,
  61, 123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 89, 43, 123, 114,
  111, 117, 110, 100, 40, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42,
  36, 65, 110, 103, 108, 101, 41, 42, 123, 36, 76, 111, 110, 103, 117, 101,
  117, 114, 95, 99, 97, 108, 99, 117, 108, 101, 101, 43, 36, 69, 108, 111,
  105, 103, 110, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101, 110, 116,
  114, 101, 125, 41, 125, 125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93,
  32, 36, 68, 101, 98, 117, 116, 95, 88, 44, 36, 68, 101, 98, 117, 116,
  95, 89, 44, 36, 69, 120, 116, 114, 101, 109, 105, 116, 101, 95, 88, 44,
  36, 69, 120, 116, 114, 101, 109, 105, 116, 101, 95, 89, 44, 49, 44, 36,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 44,
  36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 10, 65, 110, 103, 108, 101,
  61, 123, 36, 65, 110, 103, 108, 101, 43, 36, 105, 110, 99, 114, 101, 109,
  101, 110, 116, 95, 116, 104, 101, 116, 97, 125, 10, 45, 105, 102, 32, 123,
  123, 36, 77, 111, 100, 101, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110,
  115, 61, 61, 49, 125, 124, 124, 123, 36, 77, 111, 100, 101, 95, 118, 97,
  114, 105, 97, 116, 105, 111, 110, 115, 61, 61, 50, 125, 125, 10, 76, 111,
  110, 103, 117, 101, 117, 114, 95, 99, 97, 108, 99, 117, 108, 101, 101, 61,
  123, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95, 99, 97, 108, 99, 117,
  108, 101, 101, 43, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 125, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 123, 36, 77, 111,
  100, 101, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 115, 61, 61, 51,
  125, 124, 124, 123, 36, 77, 111, 100, 101, 95, 118, 97, 114, 105, 97, 116,
  105, 111, 110, 115, 61, 61, 52, 125, 125, 10, 45, 105, 102, 32, 123, 36,
  78, 98, 95, 66, 111, 117, 99, 108, 101, 60, 123, 36, 78, 111, 109, 98,
  114, 101, 95, 100, 101, 95, 116, 114, 97, 105, 116, 115, 47, 50, 125, 125,
  10, 76, 111, 110, 103, 117, 101, 117, 114, 95, 99, 97, 108, 99, 117, 108,
  101, 101, 61, 123, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95, 99, 97,
  108, 99, 117, 108, 101, 101, 43, 36, 86, 97, 114, 105, 97, 116, 105, 111,
  110, 125, 10, 45, 101, 108, 115, 101, 10, 76, 111, 110, 103, 117, 101, 117,
  114, 95, 99, 97, 108, 99, 117, 108, 101, 101, 61, 123, 36, 76, 111, 110,
  103, 117, 101, 117, 114, 95, 99, 97, 108, 99, 117, 108, 101, 101, 45, 36,
  86, 97, 114, 105, 97, 116, 105, 111, 110, 125, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 105, 102, 10, 78, 98, 95, 66, 111, 117, 99,
  108, 101, 61, 123, 36, 78, 98, 95, 66, 111, 117, 99, 108, 101, 43, 49,
  125, 10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 69, 112,
  97, 105, 115, 115, 101, 117, 114, 62, 48, 125, 10, 45, 100, 105, 108, 97,
  116, 101, 95, 99, 105, 114, 99, 91, 45, 49, 93, 32, 36, 69, 112, 97,
  105, 115, 115, 101, 117, 114, 10, 45, 101, 110, 100, 105, 102, 10, 45, 116,
  119, 105, 114, 108, 91, 45, 49, 93, 32, 36, 65, 109, 112, 108, 105, 116,
  117, 100, 101, 44, 123, 36, 75, 95, 88, 47, 49, 48, 48, 125, 44, 123,
  36, 75, 95, 89, 47, 49, 48, 48, 125, 44, 36, 66, 111, 114, 100, 101,
  114, 115, 10, 45, 98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 70, 108,
  111, 117, 95, 116, 114, 97, 105, 116, 115, 10, 45, 115, 112, 114, 101, 97,
  100, 91, 45, 49, 93, 32, 36, 83, 112, 114, 101, 97, 100, 95, 116, 114,
  97, 105, 116, 115, 10, 45, 100, 101, 102, 111, 114, 109, 91, 45, 49, 93,
  32, 36, 68, 101, 102, 111, 114, 109, 95, 116, 114, 97, 105, 116, 115, 10,
  45, 103, 105, 109, 112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45,
  50, 93, 32, 36, 98, 108, 101, 110, 100, 44, 36, 111, 112, 97, 99, 105,
  116, 101, 44, 36, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114,
  115, 10, 35, 64, 103, 105, 109, 112, 32, 84, 114, 97, 105, 116, 115, 32,
  115, 116, 114, 111, 107, 101, 115, 32, 58, 32, 84, 114, 97, 105, 116, 115,
  95, 83, 116, 114, 111, 107, 101, 115, 95, 115, 97, 109, 106, 44, 32, 84,
  114, 97, 105, 116, 115, 95, 83, 116, 114, 111, 107, 101, 115, 95, 115, 97,
  109, 106, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 79, 114, 105, 103, 105, 110, 101, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 80, 111, 115, 105, 116, 105, 111, 110, 32, 120, 32, 40, 37, 41, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 53, 48, 44, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 111, 115, 105, 116,
  105, 111, 110, 32, 121, 32, 40, 37, 41, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 53, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 84, 114, 97, 105,
  116, 115, 32, 47, 32, 83, 116, 114, 111, 107, 101, 115, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  76, 32, 111, 32, 110, 32, 103, 32, 117, 32, 101, 32, 117, 32, 114, 32,
  47, 32, 108, 101, 110, 103, 116, 104, 32, 40, 112, 105, 120, 101, 108, 115,
  41, 32, 61, 32, 105, 110, 116, 40, 49, 53, 48, 44, 49, 44, 52, 48,
  48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 114,
  105, 97, 116, 105, 111, 110, 115, 32, 37, 32, 40, 108, 111, 110, 103, 117,
  101, 117, 114, 47, 108, 101, 110, 103, 116, 104, 41, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 49, 48, 48, 44, 48, 44, 49, 48, 48, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 100, 101, 32, 118, 97,
  114, 105, 97, 116, 105, 111, 110, 115, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 48, 44, 34, 78, 111, 110, 32, 47, 32, 78, 111, 34, 44, 34,
  80, 108, 117, 115, 32, 47, 32, 77, 111, 114, 101, 34, 44, 34, 77, 111,
  105, 110, 115, 32, 47, 32, 76, 101, 115, 115, 34, 44, 34, 80, 108, 117,
  115, 32, 47, 32, 77, 111, 114, 101, 32, 91, 109, 105, 108, 105, 101, 117,
  45, 109, 105, 100, 100, 108, 101, 93, 34, 44, 34, 77, 111, 105, 110, 115,
  32, 47, 32, 76, 101, 115, 115, 32, 91, 109, 105, 108, 105, 101, 117, 45,
  109, 105, 100, 100, 108, 101, 93, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 69, 108, 111, 105, 103, 110, 101, 109, 101, 110, 116, 32, 100,
  117, 32, 99, 101, 110, 116, 114, 101, 32, 40, 112, 105, 120, 101, 108, 115,
  41, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 50, 48, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 32, 111, 32, 109,
  32, 98, 32, 114, 32, 101, 32, 32, 32, 100, 32, 101, 32, 32, 32, 116,
  32, 114, 32, 97, 32, 105, 32, 116, 32, 115, 32, 47, 32, 110, 117, 109,
  98, 101, 114, 32, 111, 102, 32, 115, 116, 114, 111, 107, 101, 115, 32, 61,
  32, 105, 110, 116, 40, 51, 48, 44, 49, 44, 50, 49, 54, 48, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101, 32, 40,
  100, 92, 51, 48, 51, 92, 50, 53, 49, 112, 97, 114, 116, 32, 47, 32,
  115, 116, 97, 114, 116, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48,
  44, 48, 44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 65, 110, 103, 108, 101, 32, 40, 102, 105, 110, 32, 47, 32, 101, 110,
  100, 41, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 54, 48, 44, 48,
  44, 51, 54, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67,
  111, 117, 108, 101, 117, 114, 47, 32, 99, 111, 108, 111, 114, 32, 61, 32,
  99, 111, 108, 111, 114, 40, 50, 52, 48, 44, 54, 48, 44, 49, 50, 48,
  44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 86,
  97, 114, 105, 97, 116, 105, 111, 110, 32, 100, 101, 32, 99, 111, 117, 108,
  101, 117, 114, 32, 47, 32, 99, 111, 108, 111, 114, 32, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  80, 97, 115, 32, 100, 101, 32, 118, 97, 114, 105, 97, 116, 105, 111, 110,
  32, 47, 32, 78, 111, 32, 99, 104, 97, 110, 103, 101, 34, 44, 34, 67,
  111, 117, 108, 101, 117, 114, 115, 32, 97, 108, 101, 97, 116, 111, 105, 114,
  101, 115, 32, 47, 32, 82, 97, 110, 100, 111, 109, 32, 99, 111, 108, 111,
  114, 115, 34, 44, 34, 70, 97, 105, 98, 108, 101, 109, 101, 110, 116, 32,
  110, 117, 97, 110, 99, 101, 101, 32, 47, 32, 80, 111, 111, 114, 108, 121,
  32, 110, 117, 97, 110, 99, 101, 100, 34, 44, 34, 77, 111, 121, 101, 110,
  110, 101, 109, 101, 110, 116, 32, 110, 117, 97, 110, 99, 101, 101, 32, 47,
  32, 77, 111, 100, 101, 114, 97, 116, 101, 108, 121, 32, 110, 117, 97, 110,
  99, 101, 100, 34, 44, 34, 70, 111, 114, 116, 101, 109, 101, 110, 116, 32,
  110, 117, 97, 110, 99, 101, 101, 32, 47, 32, 72, 105, 103, 104, 108, 121,
  32, 110, 117, 97, 110, 99, 101, 100, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 69, 112, 97, 105, 115, 115, 101, 117, 114, 32, 47, 32,
  116, 104, 105, 99, 107, 110, 101, 115, 115, 32, 61, 32, 105, 110, 116, 40,
  48, 44, 48, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40,
  34, 60, 115, 109, 97, 108, 108, 62, 83, 121, 109, 92, 51, 48, 51, 92,
  50, 53, 49, 116, 114, 105, 101, 32, 47, 32, 83, 121, 109, 109, 101, 116,
  114, 121, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 121, 109, 92, 51, 48, 51, 92, 50, 53,
  49, 116, 114, 105, 101, 32, 47, 32, 115, 121, 109, 109, 101, 116, 114, 121,
  32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 76, 111, 110, 103, 117, 101, 117, 114, 32, 47, 32, 108,
  101, 110, 103, 116, 104, 32, 40, 37, 41, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 50, 48, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 68, 105, 118, 101,
  114, 115, 32, 47, 32, 70, 111, 111, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 108, 111, 117,
  32, 47, 32, 98, 108, 117, 114, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 112, 114, 101, 97, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  48, 44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 68, 101, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 48, 44, 48, 44, 50, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 66, 108, 101,
  110, 100, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 77, 111, 100, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 49, 44, 34, 65, 100, 100, 34, 44, 34, 65, 108, 112,
  104, 97, 34, 44, 34, 65, 110, 100, 34, 44, 34, 65, 118, 101, 114, 97,
  103, 101, 34, 44, 34, 66, 108, 117, 101, 34, 44, 34, 66, 117, 114, 110,
  34, 44, 34, 68, 97, 114, 107, 101, 110, 34, 44, 34, 68, 105, 102, 102,
  101, 114, 101, 110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 34, 68, 105, 118, 105, 100, 101, 34, 44, 34, 68, 111, 100, 103,
  101, 34, 44, 34, 69, 120, 99, 108, 117, 115, 105, 111, 110, 34, 44, 34,
  70, 114, 101, 101, 122, 101, 34, 44, 34, 71, 114, 97, 105, 110, 32, 101,
  120, 116, 114, 97, 99, 116, 34, 44, 34, 71, 114, 97, 105, 110, 32, 109,
  101, 114, 103, 101, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 72,
  97, 114, 100, 32, 108, 105, 103, 104, 116, 34, 44, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 34, 72, 97, 114, 100, 32, 109, 105, 120, 34, 44,
  34, 72, 117, 101, 34, 44, 34, 73, 110, 116, 101, 114, 112, 111, 108, 97,
  116, 105, 111, 110, 34, 44, 34, 76, 105, 103, 104, 116, 101, 110, 34, 44,
  34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 76, 105, 110,
  101, 97, 114, 32, 98, 117, 114, 110, 34, 44, 34, 76, 105, 110, 101, 97,
  114, 32, 108, 105, 103, 104, 116, 34, 44, 34, 76, 117, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34,
  77, 117, 108, 116, 105, 112, 108, 121, 34, 44, 34, 78, 101, 103, 97, 116,
  105, 111, 110, 34, 44, 34, 79, 114, 34, 44, 34, 79, 118, 101, 114, 108,
  97, 121, 34, 44, 34, 80, 105, 110, 32, 108, 105, 103, 104, 116, 34, 44,
  34, 82, 101, 100, 34, 44, 34, 82, 101, 102, 108, 101, 99, 116, 34, 44,
  34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 34, 83, 104, 97, 112, 101, 32, 65, 118,
  101, 114, 97, 103, 101, 34, 44, 34, 83, 104, 97, 112, 101, 32, 65, 118,
  101, 114, 97, 103, 101, 48, 34, 44, 34, 83, 111, 102, 116, 32, 98, 117,
  114, 110, 34, 44, 34, 83, 111, 102, 116, 32, 100, 111, 100, 103, 101, 34,
  44, 34, 83, 111, 102, 116, 32, 108, 105, 103, 104, 116, 34, 44, 34, 83,
  99, 114, 101, 101, 110, 34, 44, 34, 83, 116, 97, 109, 112, 34, 44, 34,
  83, 117, 98, 116, 114, 97, 99, 116, 34, 44, 34, 86, 97, 108, 117, 101,
  34, 44, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 86, 105, 118,
  105, 100, 32, 108, 105, 103, 104, 116, 34, 44, 34, 88, 111, 114, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79, 112, 97, 99, 105, 116,
  121, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 118, 101, 114, 116,
  32, 108, 97, 121, 101, 114, 115, 32, 61, 32, 98, 111, 111, 108, 40, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114,
  101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44,
  34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97,
  108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114,
  105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97,
  114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 83, 97, 109, 106, 60, 47,
  105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32,
  117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52,
  47, 48, 49, 47, 49, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 84, 114, 97, 105, 116, 115, 95, 83, 116, 114,
  111, 107, 101, 115, 95, 115, 97, 109, 106, 58, 10, 80, 111, 115, 105, 116,
  105, 111, 110, 95, 88, 61, 123, 114, 111, 117, 110, 100, 40, 123, 123, 119,
  125, 42, 123, 36, 49, 47, 49, 48, 48, 125, 125, 41, 125, 10, 80, 111,
  115, 105, 116, 105, 111, 110, 95, 89, 61, 123, 114, 111, 117, 110, 100, 40,
  123, 123, 104, 125, 42, 123, 36, 50, 47, 49, 48, 48, 125, 125, 41, 125,
  10, 76, 111, 110, 103, 117, 101, 117, 114, 61, 36, 51, 10, 86, 97, 114,
  105, 97, 116, 105, 111, 110, 115, 95, 76, 111, 110, 103, 117, 101, 117, 114,
  61, 36, 52, 10, 77, 111, 100, 101, 95, 118, 97, 114, 105, 97, 116, 105,
  111, 110, 115, 61, 36, 53, 10, 69, 108, 111, 105, 103, 110, 101, 109, 101,
  110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101, 61, 36, 54, 10,
  78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 116, 114, 97, 105, 116, 115,
  61, 36, 55, 10, 65, 110, 103, 108, 101, 95, 68, 101, 112, 97, 114, 116,
  61, 36, 56, 10, 65, 110, 103, 108, 101, 95, 70, 105, 110, 61, 36, 57,
  10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 49, 48, 10, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 49, 49, 10, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 61, 36, 49, 50, 10, 65, 95, 67, 111, 117,
  108, 101, 117, 114, 61, 36, 49, 51, 10, 86, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 36, 49,
  52, 10, 69, 112, 97, 105, 115, 115, 101, 117, 114, 61, 36, 49, 53, 10,
  83, 121, 109, 101, 116, 114, 105, 101, 61, 36, 49, 54, 10, 80, 111, 117,
  114, 99, 101, 110, 116, 95, 76, 111, 110, 103, 117, 101, 117, 114, 95, 83,
  121, 109, 61, 36, 49, 55, 10, 70, 108, 111, 117, 95, 116, 114, 97, 105,
  116, 115, 61, 36, 49, 56, 10, 83, 112, 114, 101, 97, 100, 95, 116, 114,
  97, 105, 116, 115, 61, 36, 49, 57, 10, 68, 101, 102, 111, 114, 109, 95,
  116, 114, 97, 105, 116, 115, 61, 36, 50, 48, 10, 98, 108, 101, 110, 100,
  61, 36, 50, 49, 10, 111, 112, 97, 99, 105, 116, 101, 61, 36, 50, 50,
  10, 82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 61, 36,
  50, 51, 10, 45, 116, 111, 95, 114, 103, 98, 97, 10, 123, 119, 125, 44,
  123, 104, 125, 44, 49, 44, 52, 10, 65, 110, 103, 108, 101, 61, 36, 65,
  110, 103, 108, 101, 95, 68, 101, 112, 97, 114, 116, 10, 45, 105, 102, 32,
  123, 36, 65, 110, 103, 108, 101, 95, 68, 101, 112, 97, 114, 116, 62, 36,
  65, 110, 103, 108, 101, 95, 70, 105, 110, 125, 10, 65, 110, 103, 108, 101,
  95, 70, 105, 110, 61, 123, 36, 65, 110, 103, 108, 101, 95, 70, 105, 110,
  43, 51, 54, 48, 125, 10, 45, 101, 110, 100, 105, 102, 10, 105, 110, 99,
  114, 101, 109, 101, 110, 116, 95, 116, 104, 101, 116, 97, 61, 123, 123, 36,
  65, 110, 103, 108, 101, 95, 70, 105, 110, 45, 36, 65, 110, 103, 108, 101,
  95, 68, 101, 112, 97, 114, 116, 125, 47, 36, 78, 111, 109, 98, 114, 101,
  95, 100, 101, 95, 116, 114, 97, 105, 116, 115, 125, 10, 45, 105, 102, 32,
  123, 36, 77, 111, 100, 101, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110,
  115, 61, 61, 49, 125, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 61,
  123, 123, 36, 76, 111, 110, 103, 117, 101, 117, 114, 47, 49, 48, 48, 42,
  36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 115, 95, 76, 111, 110, 103,
  117, 101, 117, 114, 125, 47, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101,
  95, 116, 114, 97, 105, 116, 115, 125, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 77, 111, 100, 101, 95, 118, 97, 114, 105, 97,
  116, 105, 111, 110, 115, 61, 61, 50, 125, 10, 86, 97, 114, 105, 97, 116,
  105, 111, 110, 61, 123, 123, 45, 36, 76, 111, 110, 103, 117, 101, 117, 114,
  47, 49, 48, 48, 48, 42, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110,
  115, 95, 76, 111, 110, 103, 117, 101, 117, 114, 125, 47, 36, 78, 111, 109,
  98, 114, 101, 95, 100, 101, 95, 116, 114, 97, 105, 116, 115, 125, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 77, 111, 100, 101,
  95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 115, 61, 61, 51, 125, 10,
  86, 97, 114, 105, 97, 116, 105, 111, 110, 61, 123, 123, 36, 76, 111, 110,
  103, 117, 101, 117, 114, 47, 49, 48, 48, 42, 36, 86, 97, 114, 105, 97,
  116, 105, 111, 110, 115, 95, 76, 111, 110, 103, 117, 101, 117, 114, 125, 47,
  123, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 116, 114, 97, 105,
  116, 115, 47, 50, 125, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 77, 111, 100, 101, 95, 118, 97, 114, 105, 97, 116, 105,
  111, 110, 115, 61, 61, 52, 125, 10, 86, 97, 114, 105, 97, 116, 105, 111,
  110, 61, 123, 123, 45, 36, 76, 111, 110, 103, 117, 101, 117, 114, 47, 49,
  48, 48, 48, 42, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 115, 95,
  76, 111, 110, 103, 117, 101, 117, 114, 125, 47, 123, 36, 78, 111, 109, 98,
  114, 101, 95, 100, 101, 95, 116, 114, 97, 105, 116, 115, 47, 50, 125, 125,
  10, 45, 101, 110, 100, 105, 102, 10, 76, 111, 110, 103, 117, 101, 117, 114,
  95, 99, 97, 108, 99, 117, 108, 101, 101, 61, 36, 76, 111, 110, 103, 117,
  101, 117, 114, 10, 78, 98, 95, 66, 111, 117, 99, 108, 101, 61, 49, 10,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110,
  101, 61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 10, 86, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 61, 36,
  86, 95, 67, 111, 117, 108, 101, 117, 114, 10, 66, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 61, 36, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 111, 114, 105, 103, 105, 110, 101, 61, 36, 65, 95, 67, 111, 117, 108,
  101, 117, 114, 10, 45, 114, 101, 112, 101, 97, 116, 32, 36, 78, 111, 109,
  98, 114, 101, 95, 100, 101, 95, 116, 114, 97, 105, 116, 115, 10, 45, 105,
  102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101,
  95, 99, 111, 117, 108, 101, 117, 114, 61, 61, 49, 125, 10, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 123, 40,
  63, 40, 50, 53, 53, 41, 41, 125, 41, 125, 10, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 123, 40, 63, 40,
  50, 53, 53, 41, 41, 125, 41, 125, 10, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 53,
  53, 41, 41, 125, 41, 125, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114,
  61, 123, 123, 114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 48, 48,
  41, 41, 125, 41, 125, 43, 53, 53, 125, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 62, 49, 125, 10, 86,
  97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  99, 111, 117, 108, 101, 117, 114, 61, 49, 54, 10, 45, 105, 102, 32, 123,
  36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111,
  117, 108, 101, 117, 114, 61, 61, 51, 125, 10, 86, 97, 108, 101, 117, 114,
  95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101,
  117, 114, 61, 51, 50, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95,
  99, 111, 117, 108, 101, 117, 114, 61, 61, 52, 125, 10, 86, 97, 108, 101,
  117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117,
  108, 101, 117, 114, 61, 54, 52, 10, 45, 101, 110, 100, 105, 102, 10, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40,
  123, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103,
  105, 110, 101, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95,
  118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117,
  114, 44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125,
  10, 45, 105, 102, 32, 123, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114,
  62, 50, 53, 53, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 61,
  36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105,
  110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 60, 48, 125, 10, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 61, 36, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 111, 114, 105, 103, 105, 110, 101, 10, 45, 101, 110, 100, 105, 102,
  10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110,
  100, 40, 123, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114,
  105, 103, 105, 110, 101, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117,
  114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108,
  101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125,
  41, 125, 10, 45, 105, 102, 32, 123, 36, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 62, 50, 53, 53, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117,
  114, 61, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111, 114, 105,
  103, 105, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 60, 48, 125, 10, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 10, 45, 101, 110, 100,
  105, 102, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 61, 123, 114, 111,
  117, 110, 100, 40, 123, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  111, 114, 105, 103, 105, 110, 101, 43, 123, 63, 40, 45, 36, 86, 97, 108,
  101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111,
  117, 108, 101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41,
  125, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 66, 95, 67, 111, 117,
  108, 101, 117, 114, 62, 50, 53, 53, 125, 10, 66, 95, 67, 111, 117, 108,
  101, 117, 114, 61, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 111,
  114, 105, 103, 105, 110, 101, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 60, 48, 125,
  10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 61, 36, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 111, 114, 105, 103, 105, 110, 101, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 68, 101, 98, 117,
  116, 95, 88, 61, 123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 88,
  43, 123, 114, 111, 117, 110, 100, 40, 99, 111, 115, 40, 112, 105, 47, 49,
  56, 48, 42, 36, 65, 110, 103, 108, 101, 41, 42, 36, 69, 108, 111, 105,
  103, 110, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114,
  101, 41, 125, 125, 10, 68, 101, 98, 117, 116, 95, 89, 61, 123, 36, 80,
  111, 115, 105, 116, 105, 111, 110, 95, 89, 43, 123, 114, 111, 117, 110, 100,
  40, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 65, 110, 103,
  108, 101, 41, 42, 36, 69, 108, 111, 105, 103, 110, 101, 109, 101, 110, 116,
  95, 100, 117, 95, 99, 101, 110, 116, 114, 101, 41, 125, 125, 10, 69, 120,
  116, 114, 101, 109, 105, 116, 101, 95, 88, 61, 123, 36, 80, 111, 115, 105,
  116, 105, 111, 110, 95, 88, 43, 123, 114, 111, 117, 110, 100, 40, 99, 111,
  115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 65, 110, 103, 108, 101, 41,
  42, 123, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95, 99, 97, 108, 99,
  117, 108, 101, 101, 43, 36, 69, 108, 111, 105, 103, 110, 101, 109, 101, 110,
  116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101, 125, 41, 125, 125, 10,
  69, 120, 116, 114, 101, 109, 105, 116, 101, 95, 89, 61, 123, 36, 80, 111,
  115, 105, 116, 105, 111, 110, 95, 89, 43, 123, 114, 111, 117, 110, 100, 40,
  115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 65, 110, 103, 108,
  101, 41, 42, 123, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95, 99, 97,
  108, 99, 117, 108, 101, 101, 43, 36, 69, 108, 111, 105, 103, 110, 101, 109,
  101, 110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101, 125, 41, 125,
  125, 10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 68, 101, 98,
  117, 116, 95, 88, 44, 36, 68, 101, 98, 117, 116, 95, 89, 44, 36, 69,
  120, 116, 114, 101, 109, 105, 116, 101, 95, 88, 44, 36, 69, 120, 116, 114,
  101, 109, 105, 116, 101, 95, 89, 44, 49, 44, 36, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 44,
  36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 65, 95, 67, 111,
  117, 108, 101, 117, 114, 10, 45, 105, 102, 32, 123, 36, 83, 121, 109, 101,
  116, 114, 105, 101, 61, 61, 49, 125, 10, 68, 101, 98, 117, 116, 95, 88,
  61, 123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 88, 43, 123, 114,
  111, 117, 110, 100, 40, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48, 42,
  123, 36, 65, 110, 103, 108, 101, 43, 49, 56, 48, 125, 41, 42, 36, 69,
  108, 111, 105, 103, 110, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101,
  110, 116, 114, 101, 41, 125, 125, 10, 68, 101, 98, 117, 116, 95, 89, 61,
  123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 89, 43, 123, 114, 111,
  117, 110, 100, 40, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 123,
  36, 65, 110, 103, 108, 101, 43, 49, 56, 48, 125, 41, 42, 36, 69, 108,
  111, 105, 103, 110, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101, 110,
  116, 114, 101, 41, 125, 125, 10, 69, 120, 116, 114, 101, 109, 105, 116, 101,
  95, 88, 61, 123, 36, 80, 111, 115, 105, 116, 105, 111, 110, 95, 88, 43,
  123, 114, 111, 117, 110, 100, 40, 99, 111, 115, 40, 112, 105, 47, 49, 56,
  48, 42, 123, 36, 65, 110, 103, 108, 101, 43, 49, 56, 48, 125, 41, 42,
  123, 123, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95, 99, 97, 108, 99,
  117, 108, 101, 101, 47, 49, 48, 48, 42, 36, 80, 111, 117, 114, 99, 101,
  110, 116, 95, 76, 111, 110, 103, 117, 101, 117, 114, 95, 83, 121, 109, 125,
  43, 36, 69, 108, 111, 105, 103, 110, 101, 109, 101, 110, 116, 95, 100, 117,
  95, 99, 101, 110, 116, 114, 101, 125, 41, 125, 125, 10, 69, 120, 116, 114,
  101, 109, 105, 116, 101, 95, 89, 61, 123, 36, 80, 111, 115, 105, 116, 105,
  111, 110, 95, 89, 43, 123, 114, 111, 117, 110, 100, 40, 115, 105, 110, 40,
  112, 105, 47, 49, 56, 48, 42, 123, 36, 65, 110, 103, 108, 101, 43, 49,
  56, 48, 125, 41, 42, 123, 123, 36, 76, 111, 110, 103, 117, 101, 117, 114,
  95, 99, 97, 108, 99, 117, 108, 101, 101, 47, 49, 48, 48, 42, 36, 80,
  111, 117, 114, 99, 101, 110, 116, 95, 76, 111, 110, 103, 117, 101, 117, 114,
  95, 83, 121, 109, 125, 43, 36, 69, 108, 111, 105, 103, 110, 101, 109, 101,
  110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101, 125, 41, 125, 125,
  10, 45, 108, 105, 110, 101, 91, 45, 49, 93, 32, 36, 68, 101, 98, 117,
  116, 95, 88, 44, 36, 68, 101, 98, 117, 116, 95, 89, 44, 36, 69, 120,
  116, 114, 101, 109, 105, 116, 101, 95, 88, 44, 36, 69, 120, 116, 114, 101,
  109, 105, 116, 101, 95, 89, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 44, 36, 65, 95, 67, 111, 117,
  108, 101, 117, 114, 10, 45, 101, 110, 100, 105, 102, 10, 65, 110, 103, 108,
  101, 61, 123, 36, 65, 110, 103, 108, 101, 43, 36, 105, 110, 99, 114, 101,
  109, 101, 110, 116, 95, 116, 104, 101, 116, 97, 125, 10, 45, 105, 102, 32,
  123, 123, 36, 77, 111, 100, 101, 95, 118, 97, 114, 105, 97, 116, 105, 111,
  110, 115, 61, 61, 49, 125, 124, 124, 123, 36, 77, 111, 100, 101, 95, 118,
  97, 114, 105, 97, 116, 105, 111, 110, 115, 61, 61, 50, 125, 125, 10, 76,
  111, 110, 103, 117, 101, 117, 114, 95, 99, 97, 108, 99, 117, 108, 101, 101,
  61, 123, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95, 99, 97, 108, 99,
  117, 108, 101, 101, 43, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 125,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 123, 36, 77,
  111, 100, 101, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 115, 61, 61,
  51, 125, 124, 124, 123, 36, 77, 111, 100, 101, 95, 118, 97, 114, 105, 97,
  116, 105, 111, 110, 115, 61, 61, 52, 125, 125, 10, 45, 105, 102, 32, 123,
  36, 78, 98, 95, 66, 111, 117, 99, 108, 101, 60, 123, 36, 78, 111, 109,
  98, 114, 101, 95, 100, 101, 95, 116, 114, 97, 105, 116, 115, 47, 50, 125,
  125, 10, 76, 111, 110, 103, 117, 101, 117, 114, 95, 99, 97, 108, 99, 117,
  108, 101, 101, 61, 123, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95, 99,
  97, 108, 99, 117, 108, 101, 101, 43, 36, 86, 97, 114, 105, 97, 116, 105,
  111, 110, 125, 10, 45, 101, 108, 115, 101, 10, 76, 111, 110, 103, 117, 101,
  117, 114, 95, 99, 97, 108, 99, 117, 108, 101, 101, 61, 123, 36, 76, 111,
  110, 103, 117, 101, 117, 114, 95, 99, 97, 108, 99, 117, 108, 101, 101, 45,
  36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 125, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 78, 98, 95, 66, 111, 117,
  99, 108, 101, 61, 123, 36, 78, 98, 95, 66, 111, 117, 99, 108, 101, 43,
  49, 125, 10, 45, 100, 111, 110, 101, 10, 45, 105, 102, 32, 123, 36, 69,
  112, 97, 105, 115, 115, 101, 117, 114, 62, 48, 125, 10, 45, 100, 105, 108,
  97, 116, 101, 95, 99, 105, 114, 99, 91, 45, 49, 93, 32, 36, 69, 112,
  97, 105, 115, 115, 101, 117, 114, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 70, 108, 111, 117, 95, 116,
  114, 97, 105, 116, 115, 10, 45, 115, 112, 114, 101, 97, 100, 91, 45, 49,
  93, 32, 36, 83, 112, 114, 101, 97, 100, 95, 116, 114, 97, 105, 116, 115,
  10, 45, 100, 101, 102, 111, 114, 109, 91, 45, 49, 93, 32, 36, 68, 101,
  102, 111, 114, 109, 95, 116, 114, 97, 105, 116, 115, 10, 45, 103, 105, 109,
  112, 95, 98, 108, 101, 110, 100, 91, 45, 49, 44, 45, 50, 93, 32, 36,
  98, 108, 101, 110, 100, 44, 36, 111, 112, 97, 99, 105, 116, 101, 44, 36,
  82, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 10, 35, 64,
  103, 105, 109, 112, 32, 95, 10, 35, 64, 103, 105, 109, 112, 32, 60, 105,
  62, 83, 101, 113, 117, 101, 110, 99, 101, 115, 60, 47, 105, 62, 10, 35,
  64, 103, 105, 109, 112, 32, 67, 104, 97, 108, 107, 32, 105, 116, 32, 117,
  112, 32, 115, 101, 113, 117, 101, 110, 99, 101, 115, 32, 58, 32, 115, 97,
  109, 106, 95, 99, 104, 97, 108, 107, 105, 116, 117, 112, 95, 115, 101, 113,
  117, 101, 110, 99, 101, 115, 44, 32, 115, 97, 109, 106, 95, 99, 104, 97,
  108, 107, 105, 116, 117, 112, 95, 115, 101, 113, 117, 101, 110, 99, 101, 115,
  95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 73,
  110, 115, 112, 105, 114, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 116,
  117, 116, 111, 114, 105, 97, 108, 32, 112, 114, 111, 112, 111, 115, 101, 100,
  32, 98, 121, 32, 76, 121, 108, 101, 106, 107, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110,
  107, 40, 34, 104, 116, 116, 112, 58, 47, 47, 106, 117, 115, 116, 112, 97,
  115, 116, 101, 46, 105, 116, 47, 99, 104, 97, 108, 107, 95, 105, 116, 95,
  117, 112, 34, 44, 34, 104, 116, 116, 112, 58, 47, 47, 106, 117, 115, 116,
  112, 97, 115, 116, 101, 46, 105, 116, 47, 99, 104, 97, 108, 107, 95, 105,
  116, 95, 117, 112, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40,
  41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34,
  60, 115, 109, 97, 108, 108, 62, 65, 110, 105, 109, 97, 116, 105, 111, 110,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 70, 114, 97, 109, 101, 115, 32, 61, 32, 105, 110, 116,
  40, 50, 44, 50, 44, 51, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 82, 101, 110, 100, 117, 32, 61, 32, 99, 104, 111, 105, 99, 101,
  40, 49, 44, 34, 65, 115, 32, 70, 114, 97, 109, 101, 115, 32, 97, 110,
  100, 32, 70, 105, 108, 101, 115, 34, 44, 34, 65, 115, 32, 70, 114, 97,
  109, 101, 115, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 79,
  117, 116, 112, 117, 116, 32, 102, 111, 108, 100, 101, 114, 32, 61, 32, 95,
  102, 111, 108, 100, 101, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 77, 111, 114, 112, 104, 111, 32,
  112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 99,
  116, 105, 111, 110, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 53, 44,
  34, 69, 114, 111, 115, 105, 111, 110, 34, 44, 34, 68, 105, 108, 97, 116,
  105, 111, 110, 34, 44, 34, 79, 112, 101, 110, 105, 110, 103, 34, 44, 34,
  67, 108, 111, 115, 105, 110, 103, 34, 44, 34, 79, 114, 105, 103, 105, 110,
  97, 108, 32, 45, 32, 69, 114, 111, 115, 105, 111, 110, 34, 44, 34, 68,
  105, 108, 97, 116, 105, 111, 110, 32, 45, 32, 79, 114, 105, 103, 105, 110,
  97, 108, 34, 44, 34, 79, 114, 105, 103, 105, 110, 97, 108, 32, 45, 32,
  79, 112, 101, 110, 105, 110, 103, 34, 44, 34, 67, 108, 111, 115, 105, 110,
  103, 32, 45, 32, 79, 114, 105, 103, 105, 110, 97, 108, 34, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 105, 122, 101, 32, 61, 32, 105,
  110, 116, 40, 53, 44, 48, 44, 51, 50, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 73, 110, 118, 101, 114, 116, 32, 99, 111, 108, 111, 114,
  115, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 104, 97, 112, 101, 32, 61, 32, 105, 110, 116,
  40, 48, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99, 104,
  111, 105, 99, 101, 40, 50, 44, 34, 65, 108, 108, 34, 44, 34, 82, 71,
  66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32,
  99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66,
  108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34,
  44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34,
  97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34,
  97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34,
  44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86,
  97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 65, 108, 112,
  104, 97, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66,
  108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 83, 112,
  114, 101, 97, 100, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 60,
  47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 88, 45, 118, 97, 114, 105, 97, 116, 105, 111, 110, 115, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 56, 44, 45, 53, 44, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 45, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40,
  49, 46, 57, 44, 45, 53, 44, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71,
  66, 65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32,
  99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66,
  108, 117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34,
  44, 34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34,
  97, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34,
  97, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34,
  44, 34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86,
  97, 108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 65, 108, 112,
  104, 97, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44,
  34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66,
  108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101,
  119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40,
  34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32,
  104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114,
  119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34,
  66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110,
  116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118,
  101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114,
  32, 58, 32, 60, 105, 62, 83, 97, 109, 106, 60, 47, 105, 62, 46, 32,
  32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97,
  116, 101, 32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47,
  49, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34,
  41, 10, 115, 97, 109, 106, 95, 99, 104, 97, 108, 107, 105, 116, 117, 112,
  95, 115, 101, 113, 117, 101, 110, 99, 101, 115, 32, 58, 10, 35, 35, 65,
  98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 61, 53, 10, 35, 35, 68,
  101, 116, 97, 105, 108, 115, 95, 115, 99, 97, 108, 101, 61, 50, 46, 53,
  10, 35, 35, 67, 111, 108, 111, 114, 61, 49, 46, 53, 10, 35, 35, 83,
  109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 53, 48, 10, 35, 35, 83,
  104, 97, 114, 112, 101, 110, 95, 115, 104, 97, 100, 101, 115, 61, 49, 10,
  35, 103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111, 10, 65, 99, 116,
  105, 111, 110, 61, 36, 52, 10, 83, 105, 122, 101, 61, 36, 53, 10, 73,
  110, 118, 101, 114, 116, 95, 99, 111, 108, 111, 114, 115, 61, 36, 54, 10,
  83, 104, 97, 112, 101, 61, 36, 55, 10, 67, 104, 97, 110, 110, 101, 108,
  95, 109, 111, 114, 112, 104, 111, 61, 36, 56, 10, 35, 103, 105, 109, 112,
  95, 115, 112, 114, 101, 97, 100, 10, 88, 95, 118, 97, 114, 105, 97, 116,
  105, 111, 110, 115, 61, 36, 57, 10, 89, 95, 118, 97, 114, 105, 97, 116,
  105, 111, 110, 115, 61, 36, 49, 48, 10, 67, 104, 97, 110, 110, 101, 108,
  95, 115, 112, 114, 101, 97, 100, 61, 36, 49, 49, 10, 45, 114, 101, 109,
  111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 91, 45, 49, 93, 10,
  45, 105, 102, 32, 36, 50, 10, 45, 97, 110, 105, 109, 97, 116, 101, 91,
  45, 49, 93, 32, 103, 105, 109, 112, 95, 112, 97, 105, 110, 116, 105, 110,
  103, 44, 34, 49, 44, 48, 44, 49, 44, 48, 44, 49, 34, 44, 34, 49,
  48, 44, 49, 48, 44, 53, 44, 50, 48, 48, 44, 49, 34, 44, 36, 49,
  10, 45, 103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111, 91, 45, 49,
  93, 32, 36, 65, 99, 116, 105, 111, 110, 44, 36, 83, 105, 122, 101, 44,
  36, 73, 110, 118, 101, 114, 116, 95, 99, 111, 108, 111, 114, 115, 44, 36,
  83, 104, 97, 112, 101, 44, 36, 67, 104, 97, 110, 110, 101, 108, 95, 109,
  111, 114, 112, 104, 111, 44, 48, 10, 45, 103, 105, 109, 112, 95, 115, 112,
  114, 101, 97, 100, 91, 45, 49, 93, 32, 36, 88, 95, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 115, 44, 36, 89, 95, 118, 97, 114, 105, 97, 116,
  105, 111, 110, 115, 44, 36, 67, 104, 97, 110, 110, 101, 108, 95, 115, 112,
  114, 101, 97, 100, 10, 45, 101, 108, 115, 101, 10, 102, 105, 108, 101, 110,
  97, 109, 101, 61, 34, 36, 51, 47, 115, 97, 109, 106, 95, 99, 104, 97,
  108, 107, 105, 116, 117, 112, 95, 115, 101, 113, 117, 101, 110, 99, 101, 115,
  46, 112, 110, 103, 34, 10, 45, 97, 110, 105, 109, 97, 116, 101, 91, 45,
  49, 93, 32, 103, 105, 109, 112, 95, 112, 97, 105, 110, 116, 105, 110, 103,
  44, 34, 49, 44, 48, 44, 49, 44, 48, 44, 49, 34, 44, 34, 49, 48,
  44, 49, 48, 44, 53, 44, 50, 48, 48, 44, 49, 34, 44, 36, 49, 10,
  45, 103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111, 91, 45, 49, 93,
  32, 36, 65, 99, 116, 105, 111, 110, 44, 36, 83, 105, 122, 101, 44, 36,
  73, 110, 118, 101, 114, 116, 95, 99, 111, 108, 111, 114, 115, 44, 36, 83,
  104, 97, 112, 101, 44, 36, 67, 104, 97, 110, 110, 101, 108, 95, 109, 111,
  114, 112, 104, 111, 44, 48, 10, 45, 103, 105, 109, 112, 95, 115, 112, 114,
  101, 97, 100, 91, 45, 49, 93, 32, 36, 88, 95, 118, 97, 114, 105, 97,
  116, 105, 111, 110, 115, 44, 36, 89, 95, 118, 97, 114, 105, 97, 116, 105,
  111, 110, 115, 44, 36, 67, 104, 97, 110, 110, 101, 108, 95, 115, 112, 114,
  101, 97, 100, 10, 45, 111, 91, 45, 49, 93, 32, 36, 102, 105, 108, 101,
  110, 97, 109, 101, 10, 45, 101, 110, 100, 105, 102, 10, 115, 97, 109, 106,
  95, 99, 104, 97, 108, 107, 105, 116, 117, 112, 95, 115, 101, 113, 117, 101,
  110, 99, 101, 115, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 65,
  98, 115, 116, 114, 97, 99, 116, 105, 111, 110, 61, 49, 10, 68, 101, 116,
  97, 105, 108, 115, 95, 115, 99, 97, 108, 101, 61, 48, 10, 67, 111, 108,
  111, 114, 61, 49, 10, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61,
  48, 10, 83, 104, 97, 114, 112, 101, 110, 95, 115, 104, 97, 100, 101, 115,
  61, 49, 10, 35, 103, 105, 109, 112, 95, 109, 111, 114, 112, 104, 111, 10,
  65, 99, 116, 105, 111, 110, 61, 36, 52, 10, 83, 105, 122, 101, 61, 36,
  53, 10, 73, 110, 118, 101, 114, 116, 95, 99, 111, 108, 111, 114, 115, 61,
  36, 54, 10, 83, 104, 97, 112, 101, 61, 36, 55, 10, 67, 104, 97, 110,
  110, 101, 108, 95, 109, 111, 114, 112, 104, 111, 61, 36, 56, 10, 35, 103,
  105, 109, 112, 95, 115, 112, 114, 101, 97, 100, 10, 88, 95, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 115, 61, 36, 57, 10, 89, 95, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 115, 61, 36, 49, 48, 10, 67, 104, 97, 110,
  110, 101, 108, 95, 115, 112, 114, 101, 97, 100, 61, 36, 49, 49, 10, 45,
  114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99, 105, 116, 121, 91, 45,
  49, 93, 10, 45, 103, 105, 109, 112, 95, 112, 97, 105, 110, 116, 105, 110,
  103, 91, 45, 49, 93, 32, 36, 65, 98, 115, 116, 114, 97, 99, 116, 105,
  111, 110, 44, 36, 68, 101, 116, 97, 105, 108, 115, 95, 115, 99, 97, 108,
  101, 44, 36, 67, 111, 108, 111, 114, 44, 36, 83, 109, 111, 111, 116, 104,
  110, 101, 115, 115, 44, 36, 83, 104, 97, 114, 112, 101, 110, 95, 115, 104,
  97, 100, 101, 115, 10, 45, 103, 105, 109, 112, 95, 109, 111, 114, 112, 104,
  111, 91, 45, 49, 93, 32, 36, 65, 99, 116, 105, 111, 110, 44, 36, 83,
  105, 122, 101, 44, 36, 73, 110, 118, 101, 114, 116, 95, 99, 111, 108, 111,
  114, 115, 44, 36, 83, 104, 97, 112, 101, 44, 36, 67, 104, 97, 110, 110,
  101, 108, 95, 109, 111, 114, 112, 104, 111, 44, 48, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 114, 101, 97, 100, 91, 45, 49, 93, 32, 36, 88, 95,
  118, 97, 114, 105, 97, 116, 105, 111, 110, 115, 44, 36, 89, 95, 118, 97,
  114, 105, 97, 116, 105, 111, 110, 115, 44, 36, 67, 104, 97, 110, 110, 101,
  108, 95, 115, 112, 114, 101, 97, 100, 10, 45, 116, 101, 120, 116, 95, 111,
  117, 116, 108, 105, 110, 101, 91, 45, 49, 93, 32, 34, 83, 116, 97, 114,
  116, 34, 44, 49, 44, 48, 44, 49, 51, 44, 49, 44, 49, 44, 50, 53,
  53, 10, 115, 97, 109, 106, 95, 114, 105, 101, 110, 95, 118, 97, 114, 105,
  111, 117, 115, 32, 58, 10, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110,
  111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 10, 35, 64, 103, 105, 109,
  112, 32, 84, 101, 115, 116, 32, 100, 101, 115, 115, 105, 110, 32, 112, 101,
  105, 110, 116, 117, 114, 101, 32, 115, 101, 113, 117, 101, 110, 99, 101, 115,
  32, 58, 32, 116, 101, 115, 116, 95, 100, 101, 115, 115, 105, 110, 95, 112,
  101, 105, 110, 116, 117, 114, 101, 95, 115, 101, 113, 117, 101, 110, 99, 101,
  115, 44, 32, 116, 101, 115, 116, 95, 100, 101, 115, 115, 105, 110, 95, 112,
  101, 105, 110, 116, 117, 114, 101, 95, 115, 101, 113, 117, 101, 110, 99, 101,
  115, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116,
  111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 110, 105, 109, 97, 116,
  105, 111, 110, 32, 68, 92, 51, 48, 51, 92, 50, 53, 49, 98, 117, 116,
  32, 47, 32, 83, 116, 97, 114, 116, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 101, 116, 116,
  101, 116, 92, 51, 48, 51, 92, 50, 53, 49, 32, 61, 32, 105, 110, 116,
  40, 52, 48, 48, 44, 48, 44, 52, 48, 48, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 68, 92, 51, 48, 51, 92, 50, 53, 49, 116, 97,
  105, 108, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111,
  116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108,
  108, 62, 65, 110, 105, 109, 97, 116, 105, 111, 110, 32, 70, 105, 110, 32,
  47, 32, 69, 110, 100, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 101, 116, 116, 101, 116, 92,
  51, 48, 51, 92, 50, 53, 49, 32, 61, 32, 105, 110, 116, 40, 48, 44,
  48, 44, 52, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  68, 92, 51, 48, 51, 92, 50, 53, 49, 116, 97, 105, 108, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 110, 105,
  109, 97, 116, 105, 111, 110, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 70, 114, 97, 109, 101, 115,
  32, 61, 32, 105, 110, 116, 40, 50, 44, 50, 44, 51, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 110, 100, 117, 32, 61, 32,
  99, 104, 111, 105, 99, 101, 40, 49, 44, 34, 65, 115, 32, 70, 114, 97,
  109, 101, 115, 32, 97, 110, 100, 32, 70, 105, 108, 101, 115, 34, 44, 34,
  65, 115, 32, 70, 114, 97, 109, 101, 115, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 79, 117, 116, 112, 117, 116, 32, 102, 111, 108, 100,
  101, 114, 32, 61, 32, 95, 102, 111, 108, 100, 101, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 82, 101, 115, 105, 122, 101, 32, 119,
  105, 100, 116, 104, 32, 52, 48, 48, 32, 61, 32, 98, 111, 111, 108, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 83,
  97, 109, 106, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97,
  116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32, 58, 32, 60, 105,
  62, 50, 48, 49, 52, 47, 48, 49, 47, 49, 55, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 116, 101, 115, 116, 95,
  100, 101, 115, 115, 105, 110, 95, 112, 101, 105, 110, 116, 117, 114, 101, 95,
  115, 101, 113, 117, 101, 110, 99, 101, 115, 32, 58, 10, 110, 101, 116, 116,
  101, 116, 101, 61, 36, 49, 10, 100, 101, 116, 97, 105, 108, 61, 36, 50,
  10, 110, 101, 116, 116, 101, 116, 101, 95, 102, 105, 110, 61, 36, 51, 10,
  100, 101, 116, 97, 105, 108, 95, 102, 105, 110, 61, 36, 52, 10, 82, 101,
  100, 117, 105, 114, 101, 61, 36, 56, 10, 45, 114, 101, 109, 111, 118, 101,
  95, 111, 112, 97, 99, 105, 116, 121, 91, 45, 49, 93, 10, 45, 105, 102,
  32, 123, 36, 82, 101, 100, 117, 105, 114, 101, 61, 61, 49, 125, 10, 45,
  114, 101, 115, 105, 122, 101, 91, 45, 49, 93, 32, 52, 48, 48, 44, 123,
  123, 104, 125, 47, 123, 119, 125, 42, 52, 48, 48, 125, 44, 49, 44, 51,
  44, 51, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 54,
  10, 45, 97, 110, 105, 109, 97, 116, 101, 91, 45, 49, 93, 32, 102, 111,
  110, 99, 116, 105, 111, 110, 95, 116, 101, 115, 116, 95, 100, 101, 115, 115,
  105, 110, 95, 112, 101, 105, 110, 116, 117, 114, 101, 95, 115, 101, 113, 117,
  101, 110, 99, 101, 115, 44, 34, 36, 49, 44, 36, 50, 34, 44, 34, 36,
  51, 44, 36, 52, 34, 44, 36, 53, 10, 45, 101, 108, 115, 101, 10, 102,
  105, 108, 101, 110, 97, 109, 101, 61, 34, 36, 55, 47, 116, 101, 115, 116,
  95, 100, 101, 115, 115, 105, 110, 95, 112, 101, 105, 110, 116, 117, 114, 101,
  95, 115, 101, 113, 117, 101, 110, 99, 101, 115, 46, 112, 110, 103, 34, 10,
  45, 97, 110, 105, 109, 97, 116, 101, 91, 45, 49, 93, 32, 102, 111, 110,
  99, 116, 105, 111, 110, 95, 116, 101, 115, 116, 95, 100, 101, 115, 115, 105,
  110, 95, 112, 101, 105, 110, 116, 117, 114, 101, 95, 115, 101, 113, 117, 101,
  110, 99, 101, 115, 44, 34, 36, 49, 44, 36, 50, 34, 44, 34, 36, 51,
  44, 36, 52, 34, 44, 36, 53, 44, 49, 44, 36, 102, 105, 108, 101, 110,
  97, 109, 101, 10, 45, 101, 110, 100, 105, 102, 10, 116, 101, 115, 116, 95,
  100, 101, 115, 115, 105, 110, 95, 112, 101, 105, 110, 116, 117, 114, 101, 95,
  115, 101, 113, 117, 101, 110, 99, 101, 115, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 35, 32, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97,
  116, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 32, 95, 99, 111,
  109, 109, 97, 110, 100, 44, 95, 112, 97, 114, 97, 109, 101, 116, 101, 114,
  115, 49, 44, 95, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 50, 44,
  95, 99, 111, 109, 112, 117, 116, 101, 95, 104, 97, 108, 102, 61, 123, 32,
  48, 32, 124, 32, 49, 32, 125, 44, 95, 119, 105, 100, 116, 104, 62, 61,
  48, 44, 95, 104, 101, 105, 103, 104, 116, 62, 61, 48, 10, 45, 103, 105,
  109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 102, 111, 110, 99, 116, 105, 111, 110, 95, 116, 101, 115, 116,
  95, 100, 101, 115, 115, 105, 110, 95, 112, 101, 105, 110, 116, 117, 114, 101,
  95, 115, 101, 113, 117, 101, 110, 99, 101, 115, 44, 34, 36, 49, 44, 36,
  50, 34, 44, 34, 36, 51, 44, 36, 52, 34, 44, 48, 44, 36, 119, 44,
  36, 104, 10, 102, 111, 110, 99, 116, 105, 111, 110, 95, 116, 101, 115, 116,
  95, 100, 101, 115, 115, 105, 110, 95, 112, 101, 105, 110, 116, 117, 114, 101,
  95, 115, 101, 113, 117, 101, 110, 99, 101, 115, 32, 58, 10, 110, 101, 116,
  116, 101, 116, 101, 61, 36, 49, 10, 100, 101, 116, 97, 105, 108, 61, 36,
  50, 10, 110, 101, 116, 116, 101, 116, 101, 61, 123, 36, 110, 101, 116, 116,
  101, 116, 101, 43, 49, 48, 125, 10, 110, 101, 116, 116, 101, 116, 101, 49,
  61, 123, 36, 110, 101, 116, 116, 101, 116, 101, 47, 49, 48, 48, 48, 125,
  10, 110, 101, 116, 116, 101, 116, 101, 49, 61, 123, 36, 110, 101, 116, 116,
  101, 116, 101, 49, 43, 48, 46, 56, 125, 10, 110, 101, 116, 116, 101, 116,
  101, 50, 61, 123, 36, 110, 101, 116, 116, 101, 116, 101, 47, 50, 125, 10,
  110, 101, 116, 116, 101, 116, 101, 51, 61, 123, 36, 110, 101, 116, 116, 101,
  116, 101, 47, 52, 125, 10, 110, 101, 116, 116, 101, 116, 101, 51, 61, 123,
  36, 110, 101, 116, 116, 101, 116, 101, 51, 43, 49, 48, 125, 10, 45, 103,
  105, 109, 112, 95, 97, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 95,
  115, 109, 111, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 32, 56, 48,
  44, 36, 110, 101, 116, 116, 101, 116, 101, 49, 44, 48, 46, 51, 44, 48,
  46, 54, 44, 49, 46, 49, 44, 48, 46, 56, 44, 51, 48, 44, 50, 44,
  48, 44, 49, 44, 53, 44, 49, 44, 49, 10, 45, 110, 91, 45, 49, 93,
  32, 49, 50, 55, 44, 50, 53, 53, 10, 45, 115, 104, 97, 114, 112, 101,
  110, 91, 45, 49, 93, 32, 36, 110, 101, 116, 116, 101, 116, 101, 50, 10,
  45, 99, 97, 114, 116, 111, 111, 110, 91, 45, 49, 93, 32, 36, 100, 101,
  116, 97, 105, 108, 44, 36, 110, 101, 116, 116, 101, 116, 101, 51, 44, 51,
  48, 44, 48, 46, 49, 56, 44, 48, 46, 55, 53, 44, 50, 53, 54, 10,
  45, 115, 104, 97, 114, 112, 101, 110, 91, 45, 49, 93, 32, 36, 110, 101,
  116, 116, 101, 116, 101, 10, 35, 64, 103, 105, 109, 112, 32, 95, 10, 35,
  64, 103, 105, 109, 112, 32, 60, 105, 62, 86, 97, 114, 105, 111, 117, 115,
  60, 47, 105, 62, 10, 35, 64, 103, 105, 109, 112, 32, 82, 101, 99, 111,
  108, 111, 114, 105, 122, 101, 32, 50, 48, 49, 51, 48, 49, 49, 53, 32,
  58, 32, 103, 105, 109, 112, 95, 114, 101, 99, 111, 108, 111, 114, 105, 122,
  101, 95, 50, 48, 49, 51, 48, 49, 49, 53, 95, 109, 111, 100, 105, 102,
  105, 101, 44, 32, 103, 105, 109, 112, 95, 114, 101, 99, 111, 108, 111, 114,
  105, 122, 101, 95, 50, 48, 49, 51, 48, 49, 49, 53, 95, 109, 111, 100,
  105, 102, 105, 101, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 32, 61, 32, 102, 108,
  111, 97, 116, 40, 51, 48, 44, 48, 44, 50, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 117, 97, 110, 99, 101, 115, 47, 100,
  101, 99, 111, 109, 112, 111, 115, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 48, 44, 34, 79, 114, 105, 103, 105, 110, 101, 34, 44, 34, 67,
  97, 110, 97, 108, 32, 89, 32, 100, 101, 32, 89, 85, 86, 34, 44, 34,
  67, 97, 110, 97, 108, 32, 76, 32, 100, 101, 32, 72, 83, 76, 32, 56,
  34, 44, 34, 67, 97, 110, 97, 108, 32, 76, 32, 100, 101, 32, 76, 67,
  72, 34, 44, 34, 67, 97, 110, 97, 108, 32, 75, 32, 100, 101, 32, 67,
  77, 89, 75, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 114, 109, 97, 108, 105, 122, 101, 32, 97, 32, 61, 32, 105, 110, 116,
  40, 48, 44, 48, 44, 50, 53, 53, 41, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 114, 109, 97, 108, 105, 122, 101, 32, 98, 32, 61,
  32, 105, 110, 116, 40, 50, 53, 53, 44, 48, 44, 50, 53, 53, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 92, 51, 48, 51, 92, 50,
  53, 49, 103, 111, 117, 108, 105, 110, 97, 100, 101, 32, 97, 32, 47, 32,
  101, 120, 116, 101, 110, 115, 105, 111, 110, 32, 99, 111, 108, 111, 114, 115,
  32, 97, 32, 61, 32, 105, 110, 116, 40, 48, 44, 48, 44, 50, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 92, 51, 48, 51, 92,
  50, 53, 49, 103, 111, 117, 108, 105, 110, 97, 100, 101, 32, 98, 32, 47,
  32, 101, 120, 116, 101, 110, 115, 105, 111, 110, 32, 99, 111, 108, 111, 114,
  115, 32, 98, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 44, 48, 44,
  49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 92,
  51, 48, 51, 92, 50, 53, 49, 99, 105, 115, 105, 111, 110, 32, 61, 32,
  98, 111, 111, 108, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114,
  40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 98, 62, 78, 111, 116, 101,
  32, 58, 60, 47, 98, 62, 32, 84, 104, 105, 115, 32, 102, 105, 108, 116,
  101, 114, 32, 110, 101, 101, 100, 115, 32, 116, 119, 111, 32, 108, 97, 121,
  101, 114, 115, 32, 116, 111, 32, 119, 111, 114, 107, 32, 112, 114, 111, 112,
  101, 114, 108, 121, 46, 32, 84, 104, 101, 32, 98, 111, 116, 116, 111, 109,
  32, 108, 97, 121, 101, 114, 32, 99, 97, 110, 32, 98, 101, 32, 97, 32,
  66, 38, 97, 109, 112, 59, 87, 32, 111, 114, 32, 97, 32, 99, 111, 108,
  111, 114, 101, 100, 32, 105, 109, 97, 103, 101, 44, 32, 119, 104, 105, 108,
  101, 32, 116, 104, 101, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 116,
  111, 112, 32, 108, 97, 121, 101, 114, 32, 99, 111, 110, 116, 97, 105, 110,
  115, 32, 99, 111, 108, 111, 114, 32, 112, 97, 116, 99, 104, 101, 115, 32,
  116, 104, 97, 116, 32, 119, 105, 108, 108, 32, 98, 101, 32, 101, 120, 116,
  114, 97, 112, 111, 108, 97, 116, 101, 100, 32, 105, 110, 32, 97, 32, 115,
  109, 97, 114, 116, 32, 119, 97, 121, 32, 40, 101, 100, 103, 101, 45, 100,
  105, 114, 101, 99, 116, 101, 100, 41, 32, 116, 111, 32, 102, 105, 108, 108,
  32, 116, 104, 101, 32, 101, 110, 116, 105, 114, 101, 32, 105, 109, 97, 103,
  101, 46, 32, 65, 116, 32, 116, 104, 101, 32, 101, 110, 100, 44, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 121, 111, 117, 32, 103, 101, 116, 32,
  97, 32, 99, 111, 109, 112, 108, 101, 116, 101, 108, 121, 32, 114, 101, 99,
  111, 108, 111, 114, 101, 100, 32, 105, 109, 97, 103, 101, 46, 34, 125, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 32, 58, 32, 60, 105, 62, 68, 97, 118, 105,
  100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51,
  51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116,
  101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50,
  48, 49, 51, 47, 48, 49, 47, 49, 56, 32, 115, 97, 109, 106, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 114, 101, 99, 111, 108, 111, 114, 105, 122, 101, 95, 50, 48,
  49, 51, 48, 49, 49, 53, 95, 109, 111, 100, 105, 102, 105, 101, 32, 58,
  10, 83, 109, 111, 111, 116, 104, 110, 101, 115, 115, 61, 36, 49, 10, 78,
  117, 97, 110, 99, 101, 115, 61, 36, 50, 10, 78, 111, 114, 109, 97, 108,
  105, 122, 101, 95, 65, 61, 36, 51, 10, 78, 111, 114, 109, 97, 108, 105,
  122, 101, 95, 66, 61, 36, 52, 10, 68, 101, 103, 111, 117, 108, 105, 110,
  97, 100, 101, 95, 65, 61, 36, 53, 10, 68, 101, 103, 111, 117, 108, 105,
  110, 97, 100, 101, 95, 66, 61, 36, 54, 10, 80, 114, 101, 99, 105, 115,
  105, 111, 110, 61, 36, 55, 10, 45, 114, 118, 91, 45, 50, 44, 45, 49,
  93, 10, 45, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114, 99, 91, 45,
  49, 93, 32, 36, 68, 101, 103, 111, 117, 108, 105, 110, 97, 100, 101, 95,
  65, 10, 45, 105, 102, 32, 123, 36, 78, 117, 97, 110, 99, 101, 115, 61,
  61, 48, 125, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 50,
  93, 32, 48, 10, 45, 101, 108, 105, 102, 32, 123, 36, 78, 117, 97, 110,
  99, 101, 115, 61, 61, 49, 125, 10, 45, 103, 105, 109, 112, 95, 100, 101,
  99, 111, 109, 112, 111, 115, 101, 95, 99, 104, 97, 110, 110, 101, 108, 115,
  91, 45, 50, 93, 32, 52, 44, 48, 44, 49, 44, 48, 32, 45, 114, 101,
  109, 111, 118, 101, 91, 45, 50, 44, 45, 51, 93, 10, 45, 101, 108, 105,
  102, 32, 123, 36, 78, 117, 97, 110, 99, 101, 115, 61, 61, 50, 125, 10,
  45, 116, 111, 95, 114, 103, 98, 91, 45, 50, 93, 32, 45, 114, 103, 98,
  50, 104, 115, 108, 56, 91, 45, 50, 93, 32, 45, 115, 112, 108, 105, 116,
  91, 45, 50, 93, 32, 99, 32, 45, 114, 109, 91, 45, 51, 44, 45, 52,
  93, 10, 45, 101, 108, 105, 102, 32, 123, 36, 78, 117, 97, 110, 99, 101,
  115, 61, 61, 51, 125, 10, 45, 116, 111, 95, 114, 103, 98, 91, 45, 50,
  93, 32, 45, 114, 103, 98, 50, 108, 97, 98, 56, 91, 45, 50, 93, 32,
  45, 115, 112, 108, 105, 116, 91, 45, 50, 93, 32, 99, 32, 45, 114, 109,
  91, 45, 50, 44, 45, 51, 93, 10, 45, 101, 108, 105, 102, 32, 123, 36,
  78, 117, 97, 110, 99, 101, 115, 61, 61, 52, 125, 10, 45, 116, 111, 95,
  114, 103, 98, 91, 45, 50, 93, 32, 45, 114, 103, 98, 50, 99, 109, 121,
  107, 91, 45, 50, 93, 32, 45, 115, 112, 108, 105, 116, 91, 45, 50, 93,
  32, 99, 32, 45, 114, 109, 91, 45, 51, 44, 45, 52, 44, 45, 53, 93,
  32, 45, 110, 101, 103, 97, 116, 105, 118, 101, 91, 45, 50, 93, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 114, 103, 98, 91, 45, 50,
  93, 32, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 10, 45,
  110, 91, 45, 50, 93, 32, 36, 78, 111, 114, 109, 97, 108, 105, 122, 101,
  95, 65, 44, 36, 78, 111, 114, 109, 97, 108, 105, 122, 101, 95, 66, 10,
  45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99, 105, 116, 121, 91, 45,
  49, 93, 10, 45, 110, 101, 113, 91, 45, 49, 93, 32, 48, 10, 35, 32,
  105, 108, 32, 121, 32, 97, 32, 51, 32, 105, 109, 97, 103, 101, 115, 32,
  58, 32, 45, 51, 61, 108, 39, 105, 109, 97, 103, 101, 32, 103, 114, 105,
  115, 101, 32, 32, 45, 50, 61, 108, 101, 115, 32, 99, 111, 117, 108, 101,
  117, 114, 115, 32, 32, 45, 49, 61, 108, 101, 32, 109, 97, 115, 113, 117,
  101, 10, 45, 115, 114, 103, 98, 50, 114, 103, 98, 91, 45, 51, 44, 45,
  50, 93, 10, 45, 114, 103, 98, 50, 108, 97, 98, 56, 91, 45, 51, 44,
  45, 50, 93, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 51,
  93, 32, 48, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 50,
  93, 32, 49, 44, 50, 10, 45, 43, 91, 45, 50, 93, 32, 49, 10, 45,
  42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 10, 45, 45, 103, 114, 97,
  100, 105, 101, 110, 116, 95, 110, 111, 114, 109, 91, 45, 51, 93, 10, 45,
  98, 108, 117, 114, 91, 45, 49, 93, 32, 36, 68, 101, 103, 111, 117, 108,
  105, 110, 97, 100, 101, 95, 66, 10, 45, 42, 91, 45, 49, 93, 32, 45,
  49, 10, 45, 119, 97, 116, 101, 114, 115, 104, 101, 100, 91, 45, 51, 93,
  32, 91, 45, 49, 93, 10, 45, 114, 109, 91, 45, 49, 93, 10, 45, 45,
  91, 45, 50, 93, 32, 49, 10, 35, 32, 71, 101, 116, 32, 102, 105, 114,
  115, 116, 32, 101, 115, 116, 105, 109, 97, 116, 101, 32, 102, 111, 114, 32,
  116, 104, 101, 32, 99, 111, 108, 111, 114, 32, 105, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 105, 111, 110, 46, 10, 45, 105, 102, 32, 123, 36, 80,
  114, 101, 99, 105, 115, 105, 111, 110, 61, 61, 49, 125, 10, 45, 45, 100,
  105, 102, 102, 117, 115, 105, 111, 110, 116, 101, 110, 115, 111, 114, 115, 91,
  45, 51, 93, 32, 48, 44, 49, 44, 49, 44, 49, 10, 45, 101, 113, 91,
  45, 50, 93, 32, 48, 10, 45, 42, 91, 45, 49, 93, 32, 91, 45, 50,
  93, 10, 45, 114, 109, 91, 45, 50, 93, 10, 45, 115, 109, 111, 111, 116,
  104, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 36, 83, 109, 111, 111,
  116, 104, 110, 101, 115, 115, 44, 48, 46, 56, 44, 52, 53, 44, 50, 44,
  48, 10, 45, 101, 110, 100, 105, 102, 10, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 97, 91, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 108, 97,
  98, 56, 50, 114, 103, 98, 91, 45, 49, 93, 10, 45, 114, 103, 98, 50,
  115, 114, 103, 98, 91, 45, 49, 93, 10, 35, 64, 103, 105, 109, 112, 32,
  84, 101, 115, 116, 32, 109, 97, 120, 32, 109, 105, 110, 32, 112, 97, 116,
  99, 104, 32, 58, 32, 115, 97, 109, 106, 95, 84, 101, 115, 116, 95, 77,
  97, 120, 95, 77, 105, 110, 95, 80, 97, 116, 99, 104, 44, 32, 115, 97,
  109, 106, 95, 84, 101, 115, 116, 95, 77, 97, 120, 95, 77, 105, 110, 95,
  80, 97, 116, 99, 104, 95, 112, 114, 101, 118, 105, 101, 119, 40, 49, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32,
  102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110,
  103, 101, 114, 101, 100, 34, 62, 66, 97, 115, 101, 60, 47, 115, 112, 97,
  110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34,
  111, 114, 97, 110, 103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108,
  108, 62, 77, 97, 120, 32, 80, 97, 116, 99, 104, 60, 47, 115, 109, 97,
  108, 108, 62, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 80, 97, 116, 99, 104, 32, 115, 105, 122, 101,
  32, 61, 32, 105, 110, 116, 40, 54, 52, 44, 49, 44, 50, 53, 53, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68, 105, 108, 97, 116, 101,
  32, 61, 32, 105, 110, 116, 40, 49, 48, 44, 49, 44, 49, 50, 56, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32,
  102, 111, 114, 101, 103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110,
  103, 101, 114, 101, 100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 77, 105,
  110, 32, 80, 97, 116, 99, 104, 60, 47, 115, 109, 97, 108, 108, 62, 60,
  47, 115, 112, 97, 110, 62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 80, 97, 116, 99, 104, 32, 115, 105, 122, 101, 32, 61, 32, 105,
  110, 116, 40, 54, 52, 44, 49, 44, 50, 53, 53, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 68, 105, 108, 97, 116, 101, 32, 61, 32, 105,
  110, 116, 40, 49, 48, 44, 49, 44, 49, 50, 56, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32,
  110, 111, 116, 101, 40, 34, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101,
  103, 114, 111, 117, 110, 100, 61, 34, 111, 114, 97, 110, 103, 101, 114, 101,
  100, 34, 62, 60, 115, 109, 97, 108, 108, 62, 84, 114, 97, 110, 115, 112,
  97, 114, 101, 110, 99, 101, 60, 47, 115, 112, 97, 110, 62, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 114, 97, 110, 115, 112, 97,
  114, 101, 110, 99, 101, 32, 61, 32, 98, 111, 111, 108, 40, 49, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 115, 97, 109, 106,
  32, 45, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101,
  32, 58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 49, 57,
  60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10,
  115, 97, 109, 106, 95, 84, 101, 115, 116, 95, 77, 97, 120, 95, 77, 105,
  110, 95, 80, 97, 116, 99, 104, 32, 58, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 77, 97, 120, 95,
  80, 97, 116, 99, 104, 95, 80, 97, 116, 99, 104, 95, 83, 105, 122, 101,
  61, 36, 49, 10, 68, 105, 108, 97, 116, 101, 95, 77, 97, 120, 95, 80,
  97, 116, 99, 104, 61, 36, 50, 10, 77, 105, 110, 95, 80, 97, 116, 99,
  104, 95, 80, 97, 116, 99, 104, 95, 83, 105, 122, 101, 61, 36, 51, 10,
  68, 105, 108, 97, 116, 101, 95, 77, 105, 110, 95, 80, 97, 116, 99, 104,
  61, 36, 52, 10, 84, 114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101,
  61, 36, 53, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93,
  10, 45, 45, 103, 105, 109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105,
  110, 103, 91, 45, 49, 93, 10, 45, 109, 97, 120, 95, 112, 97, 116, 99,
  104, 91, 45, 49, 93, 32, 36, 77, 97, 120, 95, 80, 97, 116, 99, 104,
  95, 80, 97, 116, 99, 104, 95, 83, 105, 122, 101, 10, 45, 116, 111, 95,
  114, 103, 98, 91, 45, 49, 93, 10, 45, 110, 91, 45, 49, 93, 32, 48,
  44, 50, 53, 53, 10, 45, 100, 105, 108, 97, 116, 101, 95, 99, 105, 114,
  99, 91, 45, 49, 93, 32, 36, 68, 105, 108, 97, 116, 101, 95, 77, 97,
  120, 95, 80, 97, 116, 99, 104, 10, 45, 109, 105, 110, 95, 112, 97, 116,
  99, 104, 91, 45, 50, 93, 32, 36, 77, 105, 110, 95, 80, 97, 116, 99,
  104, 95, 80, 97, 116, 99, 104, 95, 83, 105, 122, 101, 10, 45, 116, 111,
  95, 114, 103, 98, 91, 45, 50, 93, 10, 45, 110, 91, 45, 50, 93, 32,
  48, 44, 50, 53, 53, 10, 45, 100, 105, 108, 97, 116, 101, 95, 99, 105,
  114, 99, 91, 45, 50, 93, 32, 36, 68, 105, 108, 97, 116, 101, 95, 77,
  105, 110, 95, 80, 97, 116, 99, 104, 10, 45, 105, 102, 32, 123, 36, 84,
  114, 97, 110, 115, 112, 97, 114, 101, 110, 99, 101, 61, 61, 49, 125, 10,
  45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 44, 45, 50, 93, 10,
  45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 45,
  49, 44, 45, 50, 93, 32, 52, 48, 44, 51, 44, 48, 44, 48, 44, 48,
  44, 50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 48, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 10,
  115, 97, 109, 106, 95, 84, 101, 115, 116, 95, 77, 97, 120, 95, 77, 105,
  110, 95, 80, 97, 116, 99, 104, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 112, 114,
  101, 118, 105, 101, 119, 32, 34, 45, 115, 97, 109, 106, 95, 84, 101, 115,
  116, 95, 77, 97, 120, 95, 77, 105, 110, 95, 80, 97, 116, 99, 104, 32,
  36, 42, 34, 44, 36, 45, 49, 10, 100, 111, 116, 115, 98, 119, 95, 97,
  110, 99, 105, 101, 110, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 34,
  105, 115, 105, 110, 116, 40, 36, 123, 49, 61, 49, 54, 125, 41, 32, 38,
  38, 32, 36, 49, 62, 48, 32, 38, 38, 32, 36, 123, 50, 61, 49, 48,
  125, 62, 48, 32, 38, 38, 32, 36, 50, 60, 49, 48, 48, 32, 38, 38,
  32, 36, 123, 51, 61, 49, 125, 62, 61, 48, 34, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 65, 112, 112, 108, 121, 32, 66, 38, 87, 32, 100,
  111, 116, 115, 32, 101, 102, 102, 101, 99, 116, 32, 111, 110, 32, 105, 109,
  97, 103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 36, 49, 32, 115,
  99, 97, 108, 101, 40, 115, 41, 44, 32, 114, 101, 115, 111, 108, 117, 116,
  105, 111, 110, 32, 36, 50, 37, 32, 97, 110, 100, 32, 114, 97, 100, 105,
  117, 115, 32, 102, 97, 99, 116, 111, 114, 32, 37, 51, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 109, 111, 118, 101, 95, 111, 112, 97, 99,
  105, 116, 121, 32, 45, 110, 111, 114, 109, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 119, 61, 123, 119,
  125, 32, 104, 61, 123, 104, 125, 32, 45, 114, 32, 36, 50, 37, 44, 36,
  50, 37, 44, 49, 44, 49, 44, 50, 32, 100, 120, 61, 123, 114, 111, 117,
  110, 100, 40, 36, 119, 47, 119, 41, 125, 32, 100, 121, 61, 123, 114, 111,
  117, 110, 100, 40, 36, 104, 47, 104, 41, 125, 32, 45, 110, 32, 48, 44,
  50, 53, 53, 32, 45, 110, 32, 48, 44, 123, 36, 49, 45, 49, 125, 32,
  45, 114, 111, 117, 110, 100, 10, 36, 119, 44, 36, 104, 32, 45, 110, 109,
  91, 45, 49, 93, 32, 64, 123, 48, 44, 110, 125, 10, 45, 114, 101, 112,
  101, 97, 116, 32, 36, 49, 10, 45, 45, 61, 61, 91, 48, 93, 32, 36,
  62, 32, 45, 114, 91, 45, 49, 93, 32, 36, 119, 44, 36, 104, 44, 49,
  44, 49, 44, 52, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45,
  100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32, 45,
  108, 101, 91, 45, 49, 93, 32, 123, 48, 46, 54, 53, 42, 36, 51, 42,
  36, 100, 120, 42, 36, 62, 47, 36, 49, 45, 49, 125, 32, 45, 111, 114,
  91, 45, 50, 44, 45, 49, 93, 10, 45, 100, 111, 110, 101, 10, 45, 114,
  109, 91, 48, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 42, 32, 50, 53, 53, 32, 45, 118, 32, 43, 10, 115, 116, 97,
  114, 95, 112, 97, 116, 116, 101, 114, 110, 95, 115, 97, 109, 106, 58, 10,
  45, 118, 101, 114, 98, 111, 115, 101, 32, 45, 10, 35, 35, 32, 86, 97,
  114, 105, 97, 98, 108, 101, 115, 10, 76, 97, 114, 103, 101, 117, 114, 95,
  101, 110, 95, 112, 105, 120, 101, 108, 115, 61, 36, 49, 10, 78, 111, 109,
  98, 114, 101, 95, 100, 101, 95, 115, 111, 109, 109, 101, 116, 115, 61, 36,
  50, 10, 80, 111, 117, 114, 99, 101, 110, 116, 97, 103, 101, 95, 82, 97,
  121, 111, 110, 95, 73, 110, 116, 101, 114, 105, 101, 117, 114, 61, 36, 51,
  10, 65, 110, 103, 108, 101, 95, 105, 110, 99, 108, 105, 110, 97, 105, 115,
  111, 110, 61, 36, 52, 10, 80, 111, 117, 114, 99, 101, 110, 116, 97, 103,
  101, 95, 101, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116, 101, 61, 36,
  53, 10, 65, 110, 103, 108, 101, 95, 101, 120, 99, 101, 110, 116, 114, 105,
  99, 105, 116, 101, 61, 36, 54, 10, 82, 101, 109, 112, 108, 105, 114, 95,
  112, 111, 105, 110, 116, 101, 115, 61, 36, 55, 10, 82, 95, 112, 111, 105,
  110, 116, 101, 115, 95, 112, 108, 101, 105, 110, 61, 36, 56, 10, 86, 95,
  112, 111, 105, 110, 116, 101, 115, 95, 112, 108, 101, 105, 110, 61, 36, 57,
  10, 66, 95, 112, 111, 105, 110, 116, 101, 115, 95, 112, 108, 101, 105, 110,
  61, 36, 49, 48, 10, 65, 95, 112, 111, 105, 110, 116, 101, 115, 95, 112,
  108, 101, 105, 110, 61, 36, 49, 49, 10, 67, 111, 110, 116, 111, 117, 114,
  95, 112, 111, 105, 110, 116, 101, 115, 61, 36, 49, 50, 10, 82, 95, 112,
  111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36,
  49, 51, 10, 86, 95, 112, 111, 105, 110, 116, 101, 115, 95, 99, 111, 110,
  116, 111, 117, 114, 61, 36, 49, 52, 10, 66, 95, 112, 111, 105, 110, 116,
  101, 115, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 49, 53, 10, 65,
  95, 112, 111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116, 111, 117, 114,
  61, 36, 49, 54, 10, 82, 101, 109, 112, 108, 105, 114, 95, 99, 101, 114,
  99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 36, 49,
  55, 10, 82, 95, 67, 73, 95, 112, 108, 101, 105, 110, 61, 36, 49, 56,
  10, 86, 95, 67, 73, 95, 112, 108, 101, 105, 110, 61, 36, 49, 57, 10,
  66, 95, 67, 73, 95, 112, 108, 101, 105, 110, 61, 36, 50, 48, 10, 65,
  95, 67, 73, 95, 112, 108, 101, 105, 110, 61, 36, 50, 49, 10, 67, 111,
  110, 116, 111, 117, 114, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116,
  101, 114, 105, 101, 117, 114, 61, 36, 50, 50, 10, 82, 95, 67, 73, 95,
  99, 111, 110, 116, 111, 117, 114, 61, 36, 50, 51, 10, 86, 95, 67, 73,
  95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 50, 52, 10, 66, 95, 67,
  73, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 50, 53, 10, 65, 95,
  67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 50, 54, 10, 82,
  101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120,
  116, 101, 114, 105, 101, 117, 114, 61, 36, 50, 55, 10, 82, 95, 67, 69,
  95, 112, 108, 101, 105, 110, 61, 36, 50, 56, 10, 86, 95, 67, 69, 95,
  112, 108, 101, 105, 110, 61, 36, 50, 57, 10, 66, 95, 67, 69, 95, 112,
  108, 101, 105, 110, 61, 36, 51, 48, 10, 65, 95, 67, 69, 95, 112, 108,
  101, 105, 110, 61, 36, 51, 49, 10, 67, 111, 110, 116, 111, 117, 114, 95,
  99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114,
  61, 36, 51, 50, 10, 82, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117,
  114, 61, 36, 51, 51, 10, 86, 95, 67, 69, 95, 99, 111, 110, 116, 111,
  117, 114, 61, 36, 51, 52, 10, 66, 95, 67, 69, 95, 99, 111, 110, 116,
  111, 117, 114, 61, 36, 51, 53, 10, 65, 95, 67, 69, 95, 99, 111, 110,
  116, 111, 117, 114, 61, 36, 51, 54, 10, 86, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 36, 51,
  55, 10, 35, 35, 32, 86, 97, 114, 105, 97, 98, 108, 101, 115, 32, 99,
  97, 108, 99, 117, 108, -23, 101, 115, 10, 65, 110, 103, 108, 101, 95, 105,
  110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 61, 123, 36, 65, 110, 103,
  108, 101, 95, 105, 110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 45, 57,
  48, 125, 10, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95,
  101, 120, 116, 101, 114, 105, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100,
  40, 123, 123, 36, 76, 97, 114, 103, 101, 117, 114, 95, 101, 110, 95, 112,
  105, 120, 101, 108, 115, 45, 50, 46, 53, 125, 47, 50, 125, 41, 125, 10,
  82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116,
  101, 114, 105, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36,
  82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116,
  101, 114, 105, 101, 117, 114, 47, 49, 48, 48, 42, 36, 80, 111, 117, 114,
  99, 101, 110, 116, 97, 103, 101, 95, 82, 97, 121, 111, 110, 95, 73, 110,
  116, 101, 114, 105, 101, 117, 114, 125, 41, 125, 10, 36, 76, 97, 114, 103,
  101, 117, 114, 95, 101, 110, 95, 112, 105, 120, 101, 108, 115, 44, 36, 76,
  97, 114, 103, 101, 117, 114, 95, 101, 110, 95, 112, 105, 120, 101, 108, 115,
  44, 49, 44, 52, 10, 88, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101,
  114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 61, 123,
  114, 111, 117, 110, 100, 40, 123, 119, 47, 50, 125, 41, 125, 10, 89, 95,
  99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120,
  116, 101, 114, 105, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 123,
  104, 47, 50, 125, 41, 125, 10, 35, 10, 45, 105, 102, 32, 123, 36, 82,
  101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120,
  116, 101, 114, 105, 101, 117, 114, 61, 61, 49, 125, 10, 45, 101, 108, 108,
  105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 88, 95, 99, 101, 110, 116,
  114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105,
  101, 117, 114, 44, 36, 89, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101,
  114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 44, 36,
  82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116,
  101, 114, 105, 101, 117, 114, 44, 36, 82, 97, 121, 111, 110, 95, 99, 101,
  114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 44, 48,
  44, 49, 44, 36, 82, 95, 67, 69, 95, 112, 108, 101, 105, 110, 44, 36,
  86, 95, 67, 69, 95, 112, 108, 101, 105, 110, 44, 36, 66, 95, 67, 69,
  95, 112, 108, 101, 105, 110, 44, 36, 65, 95, 67, 69, 95, 112, 108, 101,
  105, 110, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  67, 111, 110, 116, 111, 117, 114, 95, 99, 101, 114, 99, 108, 101, 95, 101,
  120, 116, 101, 114, 105, 101, 117, 114, 61, 61, 49, 125, 10, 45, 101, 108,
  108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 88, 95, 99, 101, 110,
  116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114,
  105, 101, 117, 114, 44, 36, 89, 95, 99, 101, 110, 116, 114, 101, 95, 99,
  101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 44,
  36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120,
  116, 101, 114, 105, 101, 117, 114, 44, 36, 82, 97, 121, 111, 110, 95, 99,
  101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 44,
  48, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 44, 36, 82, 95,
  67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 86, 95, 67, 69,
  95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 66, 95, 67, 69, 95, 99,
  111, 110, 116, 111, 117, 114, 44, 36, 65, 95, 67, 69, 95, 99, 111, 110,
  116, 111, 117, 114, 10, 45, 101, 110, 100, 105, 102, 10, 35, 10, 76, 111,
  110, 103, 117, 101, 117, 114, 95, 101, 120, 99, 101, 110, 116, 114, 105, 99,
  105, 116, 101, 61, 123, 36, 80, 111, 117, 114, 99, 101, 110, 116, 97, 103,
  101, 95, 101, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116, 101, 47, 49,
  48, 48, 42, 123, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108,
  101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 45, 36, 82, 97, 121,
  111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105,
  101, 117, 114, 125, 125, 10, 68, 101, 99, 97, 108, 97, 103, 101, 95, 88,
  95, 101, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116, 101, 61, 123, 114,
  111, 117, 110, 100, 40, 123, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95,
  101, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116, 101, 42, 123, 99, 111,
  115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 65, 110, 103, 108, 101, 95,
  101, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116, 101, 41, 125, 125, 41,
  125, 10, 68, 101, 99, 97, 108, 97, 103, 101, 95, 89, 95, 101, 120, 99,
  101, 110, 116, 114, 105, 99, 105, 116, 101, 61, 123, 114, 111, 117, 110, 100,
  40, 123, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95, 101, 120, 99, 101,
  110, 116, 114, 105, 99, 105, 116, 101, 42, 123, 115, 105, 110, 40, 112, 105,
  47, 49, 56, 48, 42, 36, 65, 110, 103, 108, 101, 95, 101, 120, 99, 101,
  110, 116, 114, 105, 99, 105, 116, 101, 41, 125, 125, 41, 125, 10, 88, 95,
  99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110,
  116, 101, 114, 105, 101, 117, 114, 61, 123, 36, 88, 95, 99, 101, 110, 116,
  114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105,
  101, 117, 114, 43, 36, 68, 101, 99, 97, 108, 97, 103, 101, 95, 88, 95,
  101, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116, 101, 125, 10, 89, 95,
  99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110,
  116, 101, 114, 105, 101, 117, 114, 61, 123, 36, 89, 95, 99, 101, 110, 116,
  114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105,
  101, 117, 114, 43, 36, 68, 101, 99, 97, 108, 97, 103, 101, 95, 89, 95,
  101, 120, 99, 101, 110, 116, 114, 105, 99, 105, 116, 101, 125, 10, 45, 105,
  102, 32, 123, 36, 82, 101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99,
  108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 61, 49, 125,
  10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 88,
  95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 105,
  110, 116, 101, 114, 105, 101, 117, 114, 44, 36, 89, 95, 99, 101, 110, 116,
  114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105,
  101, 117, 114, 44, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108,
  101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 36, 82, 97, 121,
  111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105,
  101, 117, 114, 44, 48, 44, 49, 44, 36, 82, 95, 67, 73, 95, 112, 108,
  101, 105, 110, 44, 36, 86, 95, 67, 73, 95, 112, 108, 101, 105, 110, 44,
  36, 66, 95, 67, 73, 95, 112, 108, 101, 105, 110, 44, 36, 65, 95, 67,
  73, 95, 112, 108, 101, 105, 110, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 67, 111, 110, 116, 111, 117, 114, 95, 99, 101, 114,
  99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 61, 49,
  125, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36,
  88, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95,
  105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 36, 89, 95, 99, 101, 110,
  116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114,
  105, 101, 117, 114, 44, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99,
  108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 44, 36, 82, 97,
  121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114,
  105, 101, 117, 114, 44, 48, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70,
  70, 44, 36, 82, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 44,
  36, 86, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 66,
  95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 65, 95, 67,
  73, 95, 99, 111, 110, 116, 111, 117, 114, 10, 45, 101, 110, 100, 105, 102,
  10, 35, 10, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103,
  108, 101, 61, 123, 51, 54, 48, 47, 36, 78, 111, 109, 98, 114, 101, 95,
  100, 101, 95, 115, 111, 109, 109, 101, 116, 115, 125, 10, 78, 98, 95, 98,
  111, 117, 99, 108, 101, 61, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101,
  95, 115, 111, 109, 109, 101, 116, 115, 10, 45, 100, 111, 10, 88, 95, 112,
  111, 105, 110, 116, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 61, 123,
  36, 88, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101,
  95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 43, 123, 114, 111, 117, 110,
  100, 40, 123, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101,
  95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 42, 123, 99, 111, 115, 40,
  123, 112, 105, 47, 49, 56, 48, 42, 123, 36, 73, 110, 99, 114, 101, 109,
  101, 110, 116, 95, 97, 110, 103, 108, 101, 43, 36, 65, 110, 103, 108, 101,
  95, 105, 110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 125, 125, 41, 125,
  125, 41, 125, 125, 10, 89, 95, 112, 111, 105, 110, 116, 95, 101, 120, 116,
  101, 114, 105, 101, 117, 114, 61, 123, 36, 89, 95, 99, 101, 110, 116, 114,
  101, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101,
  117, 114, 43, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82, 97, 121, 111,
  110, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101,
  117, 114, 42, 123, 115, 105, 110, 40, 123, 112, 105, 47, 49, 56, 48, 42,
  123, 36, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 108,
  101, 43, 36, 65, 110, 103, 108, 101, 95, 105, 110, 99, 108, 105, 110, 97,
  105, 115, 111, 110, 125, 125, 41, 125, 125, 41, 125, 125, 10, 88, 95, 112,
  111, 105, 110, 116, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 49,
  61, 123, 36, 88, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99,
  108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 43, 123, 114, 111,
  117, 110, 100, 40, 123, 36, 82, 97, 121, 111, 110, 95, 99, 101, 114, 99,
  108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 42, 123, 99, 111,
  115, 40, 123, 112, 105, 47, 49, 56, 48, 42, 123, 36, 73, 110, 99, 114,
  101, 109, 101, 110, 116, 95, 97, 110, 103, 108, 101, 43, 36, 65, 110, 103,
  108, 101, 95, 105, 110, 99, 108, 105, 110, 97, 105, 115, 111, 110, 43, 123,
  49, 56, 48, 47, 36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 115,
  111, 109, 109, 101, 116, 115, 125, 125, 125, 41, 125, 125, 41, 125, 125, 10,
  89, 95, 112, 111, 105, 110, 116, 95, 105, 110, 116, 101, 114, 105, 101, 117,
  114, 95, 49, 61, 123, 36, 89, 95, 99, 101, 110, 116, 114, 101, 95, 99,
  101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 43,
  123, 114, 111, 117, 110, 100, 40, 123, 36, 82, 97, 121, 111, 110, 95, 99,
  101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 42,
  123, 115, 105, 110, 40, 123, 112, 105, 47, 49, 56, 48, 42, 123, 36, 73,
  110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 108, 101, 43, 36,
  65, 110, 103, 108, 101, 95, 105, 110, 99, 108, 105, 110, 97, 105, 115, 111,
  110, 43, 123, 49, 56, 48, 47, 36, 78, 111, 109, 98, 114, 101, 95, 100,
  101, 95, 115, 111, 109, 109, 101, 116, 115, 125, 125, 125, 41, 125, 125, 41,
  125, 125, 10, 88, 95, 112, 111, 105, 110, 116, 95, 105, 110, 116, 101, 114,
  105, 101, 117, 114, 95, 50, 61, 123, 36, 88, 95, 99, 101, 110, 116, 114,
  101, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101,
  117, 114, 43, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82, 97, 121, 111,
  110, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101,
  117, 114, 42, 123, 99, 111, 115, 40, 123, 112, 105, 47, 49, 56, 48, 42,
  123, 36, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103, 108,
  101, 43, 36, 65, 110, 103, 108, 101, 95, 105, 110, 99, 108, 105, 110, 97,
  105, 115, 111, 110, 45, 123, 49, 56, 48, 47, 36, 78, 111, 109, 98, 114,
  101, 95, 100, 101, 95, 115, 111, 109, 109, 101, 116, 115, 125, 125, 125, 41,
  125, 125, 41, 125, 125, 10, 89, 95, 112, 111, 105, 110, 116, 95, 105, 110,
  116, 101, 114, 105, 101, 117, 114, 95, 50, 61, 123, 36, 89, 95, 99, 101,
  110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101,
  114, 105, 101, 117, 114, 43, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82,
  97, 121, 111, 110, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101,
  114, 105, 101, 117, 114, 42, 123, 115, 105, 110, 40, 123, 112, 105, 47, 49,
  56, 48, 42, 123, 36, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97,
  110, 103, 108, 101, 43, 36, 65, 110, 103, 108, 101, 95, 105, 110, 99, 108,
  105, 110, 97, 105, 115, 111, 110, 45, 123, 49, 56, 48, 47, 36, 78, 111,
  109, 98, 114, 101, 95, 100, 101, 95, 115, 111, 109, 109, 101, 116, 115, 125,
  125, 125, 41, 125, 125, 41, 125, 125, 10, 45, 105, 102, 32, 123, 36, 86,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108,
  101, 117, 114, 61, 61, 48, 125, 10, 45, 105, 102, 32, 123, 36, 82, 101,
  109, 112, 108, 105, 114, 95, 112, 111, 105, 110, 116, 101, 115, 61, 61, 49,
  125, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 51,
  44, 36, 88, 95, 112, 111, 105, 110, 116, 95, 101, 120, 116, 101, 114, 105,
  101, 117, 114, 44, 36, 89, 95, 112, 111, 105, 110, 116, 95, 101, 120, 116,
  101, 114, 105, 101, 117, 114, 44, 36, 88, 95, 112, 111, 105, 110, 116, 95,
  105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 49, 44, 36, 89, 95, 112,
  111, 105, 110, 116, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 49,
  44, 36, 88, 95, 112, 111, 105, 110, 116, 95, 105, 110, 116, 101, 114, 105,
  101, 117, 114, 95, 50, 44, 36, 89, 95, 112, 111, 105, 110, 116, 95, 105,
  110, 116, 101, 114, 105, 101, 117, 114, 95, 50, 44, 49, 44, 36, 82, 95,
  112, 111, 105, 110, 116, 101, 115, 95, 112, 108, 101, 105, 110, 44, 36, 86,
  95, 112, 111, 105, 110, 116, 101, 115, 95, 112, 108, 101, 105, 110, 44, 36,
  66, 95, 112, 111, 105, 110, 116, 101, 115, 95, 112, 108, 101, 105, 110, 44,
  36, 65, 95, 112, 111, 105, 110, 116, 101, 115, 95, 112, 108, 101, 105, 110,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 67, 111,
  110, 116, 111, 117, 114, 95, 112, 111, 105, 110, 116, 101, 115, 61, 61, 49,
  125, 10, 45, 112, 111, 108, 121, 103, 111, 110, 91, 45, 49, 93, 32, 51,
  44, 36, 88, 95, 112, 111, 105, 110, 116, 95, 101, 120, 116, 101, 114, 105,
  101, 117, 114, 44, 36, 89, 95, 112, 111, 105, 110, 116, 95, 101, 120, 116,
  101, 114, 105, 101, 117, 114, 44, 36, 88, 95, 112, 111, 105, 110, 116, 95,
  105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 49, 44, 36, 89, 95, 112,
  111, 105, 110, 116, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 49,
  44, 36, 88, 95, 112, 111, 105, 110, 116, 95, 105, 110, 116, 101, 114, 105,
  101, 117, 114, 95, 50, 44, 36, 89, 95, 112, 111, 105, 110, 116, 95, 105,
  110, 116, 101, 114, 105, 101, 117, 114, 95, 50, 44, 49, 44, 48, 120, 70,
  70, 70, 70, 70, 70, 44, 36, 82, 95, 112, 111, 105, 110, 116, 101, 115,
  95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 86, 95, 112, 111, 105, 110,
  116, 101, 115, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 66, 95, 112,
  111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36,
  65, 95, 112, 111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116, 111, 117,
  114, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 61, 49, 125, 10, 45,
  105, 102, 32, 123, 36, 82, 101, 109, 112, 108, 105, 114, 95, 112, 111, 105,
  110, 116, 101, 115, 61, 61, 49, 125, 10, 45, 112, 111, 108, 121, 103, 111,
  110, 91, 45, 49, 93, 32, 51, 44, 36, 88, 95, 112, 111, 105, 110, 116,
  95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 44, 36, 89, 95, 112, 111,
  105, 110, 116, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 44, 36, 88,
  95, 112, 111, 105, 110, 116, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114,
  95, 49, 44, 36, 89, 95, 112, 111, 105, 110, 116, 95, 105, 110, 116, 101,
  114, 105, 101, 117, 114, 95, 49, 44, 36, 88, 95, 112, 111, 105, 110, 116,
  95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 50, 44, 36, 89, 95,
  112, 111, 105, 110, 116, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95,
  50, 44, 49, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50,
  53, 53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 50, 53, 53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63,
  40, 48, 44, 50, 53, 53, 41, 41, 125, 44, 36, 65, 95, 112, 111, 105,
  110, 116, 101, 115, 95, 112, 108, 101, 105, 110, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 67, 111, 110, 116, 111, 117, 114, 95,
  112, 111, 105, 110, 116, 101, 115, 61, 61, 49, 125, 10, 45, 112, 111, 108,
  121, 103, 111, 110, 91, 45, 49, 93, 32, 51, 44, 36, 88, 95, 112, 111,
  105, 110, 116, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 44, 36, 89,
  95, 112, 111, 105, 110, 116, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114,
  44, 36, 88, 95, 112, 111, 105, 110, 116, 95, 105, 110, 116, 101, 114, 105,
  101, 117, 114, 95, 49, 44, 36, 89, 95, 112, 111, 105, 110, 116, 95, 105,
  110, 116, 101, 114, 105, 101, 117, 114, 95, 49, 44, 36, 88, 95, 112, 111,
  105, 110, 116, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 50, 44,
  36, 89, 95, 112, 111, 105, 110, 116, 95, 105, 110, 116, 101, 114, 105, 101,
  117, 114, 95, 50, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 44,
  123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41,
  125, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53,
  41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50,
  53, 53, 41, 41, 125, 44, 36, 65, 95, 112, 111, 105, 110, 116, 101, 115,
  95, 99, 111, 110, 116, 111, 117, 114, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117,
  114, 62, 49, 125, 10, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 61, 49, 54,
  10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 61, 51, 125, 10,
  86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 99, 111, 117, 108, 101, 117, 114, 61, 51, 50, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 61, 52,
  125, 10, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 61, 54, 52, 10, 45, 101,
  110, 100, 105, 102, 10, 82, 95, 112, 111, 105, 110, 116, 101, 115, 95, 112,
  108, 101, 105, 110, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82, 95,
  112, 111, 105, 110, 116, 101, 115, 95, 112, 108, 101, 105, 110, 43, 123, 63,
  40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 44, 36, 86, 97, 108,
  101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111,
  117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10, 45, 105, 102, 32, 123,
  36, 82, 95, 112, 111, 105, 110, 116, 101, 115, 95, 112, 108, 101, 105, 110,
  62, 50, 53, 53, 125, 10, 82, 95, 112, 111, 105, 110, 116, 101, 115, 95,
  112, 108, 101, 105, 110, 61, 36, 82, 95, 112, 111, 105, 110, 116, 101, 115,
  95, 112, 108, 101, 105, 110, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 82, 95, 112, 111, 105, 110, 116, 101, 115, 95, 112, 108,
  101, 105, 110, 60, 48, 125, 10, 82, 95, 112, 111, 105, 110, 116, 101, 115,
  95, 112, 108, 101, 105, 110, 61, 36, 82, 95, 112, 111, 105, 110, 116, 101,
  115, 95, 112, 108, 101, 105, 110, 10, 45, 101, 110, 100, 105, 102, 10, 86,
  95, 112, 111, 105, 110, 116, 101, 115, 95, 112, 108, 101, 105, 110, 61, 123,
  114, 111, 117, 110, 100, 40, 123, 36, 86, 95, 112, 111, 105, 110, 116, 101,
  115, 95, 112, 108, 101, 105, 110, 43, 123, 63, 40, 45, 36, 86, 97, 108,
  101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111,
  117, 108, 101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41,
  125, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 86, 95, 112, 111, 105,
  110, 116, 101, 115, 95, 112, 108, 101, 105, 110, 62, 50, 53, 53, 125, 10,
  86, 95, 112, 111, 105, 110, 116, 101, 115, 95, 112, 108, 101, 105, 110, 61,
  36, 86, 95, 112, 111, 105, 110, 116, 101, 115, 95, 112, 108, 101, 105, 110,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 95,
  112, 111, 105, 110, 116, 101, 115, 95, 112, 108, 101, 105, 110, 60, 48, 125,
  10, 86, 95, 112, 111, 105, 110, 116, 101, 115, 95, 112, 108, 101, 105, 110,
  61, 36, 86, 95, 112, 111, 105, 110, 116, 101, 115, 95, 112, 108, 101, 105,
  110, 10, 45, 101, 110, 100, 105, 102, 10, 66, 95, 112, 111, 105, 110, 116,
  101, 115, 95, 112, 108, 101, 105, 110, 61, 123, 114, 111, 117, 110, 100, 40,
  123, 36, 66, 95, 112, 111, 105, 110, 116, 101, 115, 95, 112, 108, 101, 105,
  110, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 44,
  36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10, 45,
  105, 102, 32, 123, 36, 66, 95, 112, 111, 105, 110, 116, 101, 115, 95, 112,
  108, 101, 105, 110, 62, 50, 53, 53, 125, 10, 66, 95, 112, 111, 105, 110,
  116, 101, 115, 95, 112, 108, 101, 105, 110, 61, 36, 66, 95, 112, 111, 105,
  110, 116, 101, 115, 95, 112, 108, 101, 105, 110, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 123, 36, 66, 95, 112, 111, 105, 110, 116, 101,
  115, 95, 112, 108, 101, 105, 110, 60, 48, 125, 10, 66, 95, 112, 111, 105,
  110, 116, 101, 115, 95, 112, 108, 101, 105, 110, 61, 36, 66, 95, 112, 111,
  105, 110, 116, 101, 115, 95, 112, 108, 101, 105, 110, 10, 45, 101, 110, 100,
  105, 102, 10, 82, 95, 112, 111, 105, 110, 116, 101, 115, 95, 99, 111, 110,
  116, 111, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82, 95,
  112, 111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116, 111, 117, 114, 43,
  123, 63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 44, 36, 86,
  97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  99, 111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10, 45, 105, 102,
  32, 123, 36, 82, 95, 112, 111, 105, 110, 116, 101, 115, 95, 99, 111, 110,
  116, 111, 117, 114, 62, 50, 53, 53, 125, 10, 82, 95, 112, 111, 105, 110,
  116, 101, 115, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 82, 95, 112,
  111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116, 111, 117, 114, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 95, 112, 111,
  105, 110, 116, 101, 115, 95, 99, 111, 110, 116, 111, 117, 114, 60, 48, 125,
  10, 82, 95, 112, 111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116, 111,
  117, 114, 61, 36, 82, 95, 112, 111, 105, 110, 116, 101, 115, 95, 99, 111,
  110, 116, 111, 117, 114, 10, 45, 101, 110, 100, 105, 102, 10, 86, 95, 112,
  111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116, 111, 117, 114, 61, 123,
  114, 111, 117, 110, 100, 40, 123, 36, 86, 95, 112, 111, 105, 110, 116, 101,
  115, 95, 99, 111, 110, 116, 111, 117, 114, 43, 123, 63, 40, 45, 36, 86,
  97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  99, 111, 117, 108, 101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114, 95,
  118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117,
  114, 41, 125, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 86, 95, 112,
  111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116, 111, 117, 114, 62, 50,
  53, 53, 125, 10, 86, 95, 112, 111, 105, 110, 116, 101, 115, 95, 99, 111,
  110, 116, 111, 117, 114, 61, 36, 86, 95, 112, 111, 105, 110, 116, 101, 115,
  95, 99, 111, 110, 116, 111, 117, 114, 10, 45, 101, 110, 100, 105, 102, 10,
  45, 105, 102, 32, 123, 36, 86, 95, 112, 111, 105, 110, 116, 101, 115, 95,
  99, 111, 110, 116, 111, 117, 114, 60, 48, 125, 10, 86, 95, 112, 111, 105,
  110, 116, 101, 115, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 86, 95,
  112, 111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116, 111, 117, 114, 10,
  45, 101, 110, 100, 105, 102, 10, 66, 95, 112, 111, 105, 110, 116, 101, 115,
  95, 99, 111, 110, 116, 111, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40,
  123, 36, 66, 95, 112, 111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116,
  111, 117, 114, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95,
  118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117,
  114, 44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125,
  10, 45, 105, 102, 32, 123, 36, 66, 95, 112, 111, 105, 110, 116, 101, 115,
  95, 99, 111, 110, 116, 111, 117, 114, 62, 50, 53, 53, 125, 10, 66, 95,
  112, 111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116, 111, 117, 114, 61,
  36, 66, 95, 112, 111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116, 111,
  117, 114, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  66, 95, 112, 111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116, 111, 117,
  114, 60, 48, 125, 10, 66, 95, 112, 111, 105, 110, 116, 101, 115, 95, 99,
  111, 110, 116, 111, 117, 114, 61, 36, 66, 95, 112, 111, 105, 110, 116, 101,
  115, 95, 99, 111, 110, 116, 111, 117, 114, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 82, 101, 109, 112, 108, 105, 114, 95, 112,
  111, 105, 110, 116, 101, 115, 61, 61, 49, 125, 10, 45, 112, 111, 108, 121,
  103, 111, 110, 91, 45, 49, 93, 32, 51, 44, 36, 88, 95, 112, 111, 105,
  110, 116, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 44, 36, 89, 95,
  112, 111, 105, 110, 116, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 44,
  36, 88, 95, 112, 111, 105, 110, 116, 95, 105, 110, 116, 101, 114, 105, 101,
  117, 114, 95, 49, 44, 36, 89, 95, 112, 111, 105, 110, 116, 95, 105, 110,
  116, 101, 114, 105, 101, 117, 114, 95, 49, 44, 36, 88, 95, 112, 111, 105,
  110, 116, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 50, 44, 36,
  89, 95, 112, 111, 105, 110, 116, 95, 105, 110, 116, 101, 114, 105, 101, 117,
  114, 95, 50, 44, 49, 44, 36, 82, 95, 112, 111, 105, 110, 116, 101, 115,
  95, 112, 108, 101, 105, 110, 44, 36, 86, 95, 112, 111, 105, 110, 116, 101,
  115, 95, 112, 108, 101, 105, 110, 44, 36, 66, 95, 112, 111, 105, 110, 116,
  101, 115, 95, 112, 108, 101, 105, 110, 44, 36, 65, 95, 112, 111, 105, 110,
  116, 101, 115, 95, 112, 108, 101, 105, 110, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 67, 111, 110, 116, 111, 117, 114, 95, 112,
  111, 105, 110, 116, 101, 115, 61, 61, 49, 125, 10, 45, 112, 111, 108, 121,
  103, 111, 110, 91, 45, 49, 93, 32, 51, 44, 36, 88, 95, 112, 111, 105,
  110, 116, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 44, 36, 89, 95,
  112, 111, 105, 110, 116, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 44,
  36, 88, 95, 112, 111, 105, 110, 116, 95, 105, 110, 116, 101, 114, 105, 101,
  117, 114, 95, 49, 44, 36, 89, 95, 112, 111, 105, 110, 116, 95, 105, 110,
  116, 101, 114, 105, 101, 117, 114, 95, 49, 44, 36, 88, 95, 112, 111, 105,
  110, 116, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 95, 50, 44, 36,
  89, 95, 112, 111, 105, 110, 116, 95, 105, 110, 116, 101, 114, 105, 101, 117,
  114, 95, 50, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 44, 36,
  82, 95, 112, 111, 105, 110, 116, 101, 115, 95, 99, 111, 110, 116, 111, 117,
  114, 44, 36, 86, 95, 112, 111, 105, 110, 116, 101, 115, 95, 99, 111, 110,
  116, 111, 117, 114, 44, 36, 66, 95, 112, 111, 105, 110, 116, 101, 115, 95,
  99, 111, 110, 116, 111, 117, 114, 44, 36, 65, 95, 112, 111, 105, 110, 116,
  101, 115, 95, 99, 111, 110, 116, 111, 117, 114, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 105, 102, 10, 73, 110, 99, 114, 101, 109, 101,
  110, 116, 95, 97, 110, 103, 108, 101, 61, 123, 36, 73, 110, 99, 114, 101,
  109, 101, 110, 116, 95, 97, 110, 103, 108, 101, 43, 123, 51, 54, 48, 47,
  36, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 115, 111, 109, 109, 101,
  116, 115, 125, 125, 10, 78, 98, 95, 98, 111, 117, 99, 108, 101, 61, 123,
  36, 78, 98, 95, 98, 111, 117, 99, 108, 101, 45, 49, 125, 10, 45, 119,
  104, 105, 108, 101, 32, 123, 36, 78, 98, 95, 98, 111, 117, 99, 108, 101,
  62, 48, 125, 10, 45, 118, 101, 114, 98, 111, 115, 101, 32, 43, 10, 102,
  108, 111, 119, 101, 114, 95, 112, 97, 116, 116, 101, 114, 110, 95, 115, 97,
  109, 106, 58, 10, 45, 118, 101, 114, 98, 111, 115, 101, 32, 45, 10, 35,
  35, 32, 86, 97, 114, 105, 97, 98, 108, 101, 115, 10, 76, 97, 114, 103,
  101, 117, 114, 95, 101, 110, 95, 112, 105, 120, 101, 108, 115, 61, 36, 49,
  10, 78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 112, 101, 116, 97, 108,
  101, 115, 61, 36, 50, 10, 65, 110, 103, 108, 101, 95, 105, 110, 99, 108,
  105, 110, 97, 105, 115, 111, 110, 61, 36, 51, 10, 82, 97, 121, 111, 110,
  95, 103, 114, 97, 110, 100, 95, 99, 101, 114, 99, 108, 101, 61, 36, 52,
  10, 82, 97, 121, 111, 110, 95, 112, 101, 116, 105, 116, 95, 99, 101, 114,
  99, 108, 101, 61, 36, 53, 10, 76, 111, 110, 103, 117, 101, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 61, 36, 54, 10, 76, 97, 114, 103, 101,
  117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 55, 10, 69, 115,
  112, 97, 99, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101, 110, 116,
  114, 101, 61, 36, 56, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  108, 111, 110, 103, 117, 101, 117, 114, 61, 36, 57, 10, 86, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114, 61,
  36, 49, 48, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 97, 110,
  103, 108, 101, 61, 36, 49, 49, 10, 82, 101, 109, 112, 108, 105, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 61, 36, 49, 50, 10, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 49,
  51, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 61, 36, 49, 52, 10, 66, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 49, 53, 10, 65, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61,
  36, 49, 54, 10, 67, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 61, 36, 49, 55, 10, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101,
  115, 61, 36, 49, 56, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61,
  36, 49, 57, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111,
  110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 50,
  48, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116,
  111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 50, 49, 10,
  82, 101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108, 101, 95, 105,
  110, 116, 101, 114, 105, 101, 117, 114, 61, 36, 50, 50, 10, 82, 95, 67,
  73, 95, 112, 108, 101, 105, 110, 61, 36, 50, 51, 10, 86, 95, 67, 73,
  95, 112, 108, 101, 105, 110, 61, 36, 50, 52, 10, 66, 95, 67, 73, 95,
  112, 108, 101, 105, 110, 61, 36, 50, 53, 10, 65, 95, 67, 73, 95, 112,
  108, 101, 105, 110, 61, 36, 50, 54, 10, 67, 111, 110, 116, 111, 117, 114,
  95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117,
  114, 61, 36, 50, 55, 10, 82, 95, 67, 73, 95, 99, 111, 110, 116, 111,
  117, 114, 61, 36, 50, 56, 10, 86, 95, 67, 73, 95, 99, 111, 110, 116,
  111, 117, 114, 61, 36, 50, 57, 10, 66, 95, 67, 73, 95, 99, 111, 110,
  116, 111, 117, 114, 61, 36, 51, 48, 10, 65, 95, 67, 73, 95, 99, 111,
  110, 116, 111, 117, 114, 61, 36, 51, 49, 10, 82, 101, 109, 112, 108, 105,
  114, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101,
  117, 114, 61, 36, 51, 50, 10, 82, 95, 67, 69, 95, 112, 108, 101, 105,
  110, 61, 36, 51, 51, 10, 86, 95, 67, 69, 95, 112, 108, 101, 105, 110,
  61, 36, 51, 52, 10, 66, 95, 67, 69, 95, 112, 108, 101, 105, 110, 61,
  36, 51, 53, 10, 65, 95, 67, 69, 95, 112, 108, 101, 105, 110, 61, 36,
  51, 54, 10, 67, 111, 110, 116, 111, 117, 114, 95, 99, 101, 114, 99, 108,
  101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 61, 36, 51, 55, 10,
  82, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 51, 56,
  10, 86, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 51,
  57, 10, 66, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36,
  52, 48, 10, 65, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 61,
  36, 52, 49, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101,
  95, 99, 111, 117, 108, 101, 117, 114, 61, 36, 52, 50, 10, 35, 35, 32,
  86, 97, 114, 105, 97, 98, 108, 101, 115, 32, 99, 97, 108, 99, 117, 108,
  -23, 101, 115, 10, 88, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114,
  99, 108, 101, 115, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 76, 97,
  114, 103, 101, 117, 114, 95, 101, 110, 95, 112, 105, 120, 101, 108, 115, 47,
  50, 125, 41, 125, 10, 89, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101,
  114, 99, 108, 101, 115, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 76,
  97, 114, 103, 101, 117, 114, 95, 101, 110, 95, 112, 105, 120, 101, 108, 115,
  47, 50, 125, 41, 125, 10, 82, 97, 121, 111, 110, 95, 100, 101, 95, 108,
  97, 95, 102, 108, 101, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 123,
  36, 76, 97, 114, 103, 101, 117, 114, 95, 101, 110, 95, 112, 105, 120, 101,
  108, 115, 47, 56, 125, 41, 125, 10, 82, 97, 121, 111, 110, 95, 103, 114,
  97, 110, 100, 95, 99, 101, 114, 99, 108, 101, 61, 123, 114, 111, 117, 110,
  100, 40, 123, 36, 82, 97, 121, 111, 110, 95, 100, 101, 95, 108, 97, 95,
  102, 108, 101, 117, 114, 47, 49, 48, 48, 42, 36, 82, 97, 121, 111, 110,
  95, 103, 114, 97, 110, 100, 95, 99, 101, 114, 99, 108, 101, 125, 41, 125,
  10, 82, 97, 121, 111, 110, 95, 112, 101, 116, 105, 116, 95, 99, 101, 114,
  99, 108, 101, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82, 97, 121,
  111, 110, 95, 100, 101, 95, 108, 97, 95, 102, 108, 101, 117, 114, 47, 49,
  48, 48, 42, 36, 82, 97, 121, 111, 110, 95, 112, 101, 116, 105, 116, 95,
  99, 101, 114, 99, 108, 101, 125, 41, 125, 10, 76, 111, 110, 103, 117, 101,
  117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 123, 114, 111, 117, 110,
  100, 40, 123, 36, 82, 97, 121, 111, 110, 95, 100, 101, 95, 108, 97, 95,
  102, 108, 101, 117, 114, 47, 49, 48, 48, 42, 36, 76, 111, 110, 103, 117,
  101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 125, 41, 125, 10, 76,
  97, 114, 103, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 123,
  114, 111, 117, 110, 100, 40, 123, 36, 76, 111, 110, 103, 117, 101, 117, 114,
  95, 112, 101, 116, 97, 108, 101, 115, 47, 49, 48, 48, 42, 36, 76, 97,
  114, 103, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 125, 41, 125,
  10, 69, 115, 112, 97, 99, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99,
  101, 110, 116, 114, 101, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 76,
  111, 110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 47,
  49, 48, 48, 42, 36, 69, 115, 112, 97, 99, 101, 109, 101, 110, 116, 95,
  100, 117, 95, 99, 101, 110, 116, 114, 101, 125, 41, 125, 10, 86, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 108, 111, 110, 103, 117, 101, 117, 114, 61,
  123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 108, 111, 110, 103,
  117, 101, 117, 114, 43, 49, 125, 10, 86, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114, 61, 123, 36, 86, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 101, 112, 97, 105, 115, 115, 101, 117,
  114, 43, 49, 125, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 97,
  110, 103, 108, 101, 61, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 97, 110, 103, 108, 101, 43, 49, 125, 10, 73, 110, 99, 114, 101, 109,
  101, 110, 116, 95, 97, 110, 103, 108, 101, 61, 123, 51, 54, 48, 47, 36,
  78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 112, 101, 116, 97, 108, 101,
  115, 125, 10, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103,
  108, 101, 95, 112, 101, 116, 97, 108, 101, 61, 123, 51, 54, 48, 47, 36,
  78, 111, 109, 98, 114, 101, 95, 100, 101, 95, 112, 101, 116, 97, 108, 101,
  115, 125, 10, 35, 35, 35, 10, 36, 76, 97, 114, 103, 101, 117, 114, 95,
  101, 110, 95, 112, 105, 120, 101, 108, 115, 44, 36, 76, 97, 114, 103, 101,
  117, 114, 95, 101, 110, 95, 112, 105, 120, 101, 108, 115, 44, 49, 44, 52,
  10, 78, 98, 95, 98, 111, 117, 99, 108, 101, 61, 36, 78, 111, 109, 98,
  114, 101, 95, 100, 101, 95, 112, 101, 116, 97, 108, 101, 115, 10, 73, 110,
  100, 101, 120, 61, 48, 10, 45, 100, 111, 10, 86, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 97, 110, 103, 108, 101, 95, 98, 111, 117, 99, 108, 101,
  61, 123, 63, 40, 45, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  97, 110, 103, 108, 101, 44, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 97, 110, 103, 108, 101, 41, 125, 10, 86, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 108, 111, 110, 103, 117, 101, 117, 114, 95, 98, 111, 117, 99,
  108, 101, 61, 123, 63, 40, 45, 36, 86, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 108, 111, 110, 103, 117, 101, 117, 114, 44, 36, 86, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 108, 111, 110, 103, 117, 101, 117, 114, 41, 125,
  10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 101, 112, 97, 105, 115,
  115, 101, 117, 114, 95, 98, 111, 117, 99, 108, 101, 61, 123, 63, 40, 45,
  36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 101, 112, 97, 105, 115,
  115, 101, 117, 114, 44, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  101, 112, 97, 105, 115, 115, 101, 117, 114, 41, 125, 10, 76, 111, 110, 103,
  117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 98, 111, 117,
  99, 108, 101, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 76, 111, 110,
  103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 43, 123, 36,
  76, 111, 110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  47, 49, 48, 48, 42, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  108, 111, 110, 103, 117, 101, 117, 114, 95, 98, 111, 117, 99, 108, 101, 125,
  125, 41, 125, 10, 76, 97, 114, 103, 101, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 95, 98, 111, 117, 99, 108, 101, 61, 123, 114, 111, 117, 110,
  100, 40, 123, 36, 76, 97, 114, 103, 101, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 43, 123, 36, 76, 97, 114, 103, 101, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 47, 49, 48, 48, 42, 36, 86, 97, 114, 105, 97,
  116, 105, 111, 110, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114, 95, 98,
  111, 117, 99, 108, 101, 125, 125, 41, 125, 10, 97, 110, 103, 108, 101, 95,
  112, 101, 116, 97, 108, 101, 61, 123, 123, 36, 73, 110, 99, 114, 101, 109,
  101, 110, 116, 95, 97, 110, 103, 108, 101, 95, 112, 101, 116, 97, 108, 101,
  42, 36, 73, 110, 100, 101, 120, 125, 43, 36, 86, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 97, 110, 103, 108, 101, 95, 98, 111, 117, 99, 108, 101,
  43, 36, 65, 110, 103, 108, 101, 95, 105, 110, 99, 108, 105, 110, 97, 105,
  115, 111, 110, 125, 10, 76, 111, 110, 103, 117, 101, 117, 114, 95, 99, 101,
  110, 116, 114, 101, 95, 112, 101, 116, 97, 108, 101, 61, 123, 36, 76, 111,
  110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 98,
  111, 117, 99, 108, 101, 43, 36, 69, 115, 112, 97, 99, 101, 109, 101, 110,
  116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101, 125, 10, 68, 101, 99,
  97, 108, 97, 103, 101, 95, 88, 95, 99, 101, 110, 116, 114, 101, 95, 112,
  101, 116, 97, 108, 101, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 76,
  111, 110, 103, 117, 101, 117, 114, 95, 99, 101, 110, 116, 114, 101, 95, 112,
  101, 116, 97, 108, 101, 42, 123, 99, 111, 115, 40, 112, 105, 47, 49, 56,
  48, 42, 36, 97, 110, 103, 108, 101, 95, 112, 101, 116, 97, 108, 101, 41,
  125, 125, 41, 125, 10, 68, 101, 99, 97, 108, 97, 103, 101, 95, 89, 95,
  99, 101, 110, 116, 114, 101, 95, 112, 101, 116, 97, 108, 101, 61, 123, 114,
  111, 117, 110, 100, 40, 123, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95,
  99, 101, 110, 116, 114, 101, 95, 112, 101, 116, 97, 108, 101, 42, 123, 115,
  105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 97, 110, 103, 108, 101,
  95, 112, 101, 116, 97, 108, 101, 41, 125, 125, 41, 125, 10, 88, 95, 99,
  101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 112, 101, 116,
  97, 108, 101, 61, 123, 36, 88, 95, 99, 101, 110, 116, 114, 101, 95, 99,
  101, 114, 99, 108, 101, 115, 43, 36, 68, 101, 99, 97, 108, 97, 103, 101,
  95, 88, 95, 99, 101, 110, 116, 114, 101, 95, 112, 101, 116, 97, 108, 101,
  125, 10, 89, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108,
  101, 95, 112, 101, 116, 97, 108, 101, 61, 123, 36, 89, 95, 99, 101, 110,
  116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 115, 43, 36, 68, 101, 99,
  97, 108, 97, 103, 101, 95, 89, 95, 99, 101, 110, 116, 114, 101, 95, 112,
  101, 116, 97, 108, 101, 125, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117,
  114, 61, 61, 48, 125, 10, 45, 105, 102, 32, 123, 36, 82, 101, 109, 112,
  108, 105, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 61, 49, 125, 10,
  45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 88, 95,
  99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 112, 101,
  116, 97, 108, 101, 44, 36, 89, 95, 99, 101, 110, 116, 114, 101, 95, 99,
  101, 114, 99, 108, 101, 95, 112, 101, 116, 97, 108, 101, 44, 36, 76, 111,
  110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 98,
  111, 117, 99, 108, 101, 44, 36, 76, 97, 114, 103, 101, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 95, 98, 111, 117, 99, 108, 101, 44, 36, 97,
  110, 103, 108, 101, 95, 112, 101, 116, 97, 108, 101, 44, 49, 44, 36, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 112, 101, 116, 97, 108, 101, 115, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 105, 102, 32, 123, 36, 67, 111, 110, 116, 111, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 61, 61, 49, 125, 10, 45, 101, 108, 108, 105,
  112, 115, 101, 91, 45, 49, 93, 32, 36, 88, 95, 99, 101, 110, 116, 114,
  101, 95, 99, 101, 114, 99, 108, 101, 95, 112, 101, 116, 97, 108, 101, 44,
  36, 89, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101,
  95, 112, 101, 116, 97, 108, 101, 44, 36, 76, 111, 110, 103, 117, 101, 117,
  114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 98, 111, 117, 99, 108, 101,
  44, 36, 76, 97, 114, 103, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101,
  115, 95, 98, 111, 117, 99, 108, 101, 44, 36, 97, 110, 103, 108, 101, 95,
  112, 101, 116, 97, 108, 101, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70,
  70, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110,
  116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 44, 36, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108,
  101, 115, 44, 36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111,
  110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99,
  111, 117, 108, 101, 117, 114, 61, 61, 49, 125, 10, 45, 105, 102, 32, 123,
  36, 82, 101, 109, 112, 108, 105, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  61, 61, 49, 125, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49,
  93, 32, 36, 88, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99,
  108, 101, 95, 112, 101, 116, 97, 108, 101, 44, 36, 89, 95, 99, 101, 110,
  116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 112, 101, 116, 97, 108,
  101, 44, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 95, 98, 111, 117, 99, 108, 101, 44, 36, 76, 97, 114, 103,
  101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 98, 111, 117, 99,
  108, 101, 44, 36, 97, 110, 103, 108, 101, 95, 112, 101, 116, 97, 108, 101,
  44, 49, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53,
  53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44,
  50, 53, 53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40,
  48, 44, 50, 53, 53, 41, 41, 125, 44, 36, 65, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 67, 111, 110, 116, 111, 117, 114,
  95, 112, 101, 116, 97, 108, 101, 115, 61, 61, 49, 125, 10, 45, 101, 108,
  108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 88, 95, 99, 101, 110,
  116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 112, 101, 116, 97, 108,
  101, 44, 36, 89, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99,
  108, 101, 95, 112, 101, 116, 97, 108, 101, 44, 36, 76, 111, 110, 103, 117,
  101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 98, 111, 117, 99,
  108, 101, 44, 36, 76, 97, 114, 103, 101, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 95, 98, 111, 117, 99, 108, 101, 44, 36, 97, 110, 103, 108,
  101, 95, 112, 101, 116, 97, 108, 101, 44, 49, 44, 48, 120, 70, 70, 70,
  70, 70, 70, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50,
  53, 53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 50, 53, 53, 41, 41, 125, 44, 123, 114, 111, 117, 110, 100, 40, 63,
  40, 48, 44, 50, 53, 53, 41, 41, 125, 44, 36, 65, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116,
  97, 108, 101, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 62, 49, 125,
  10, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 99, 111, 117, 108, 101, 117, 114, 61, 49, 54, 10, 45, 105, 102,
  32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95,
  99, 111, 117, 108, 101, 117, 114, 61, 61, 51, 125, 10, 86, 97, 108, 101,
  117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117,
  108, 101, 117, 114, 61, 51, 50, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100,
  101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 61, 52, 125, 10, 86, 97,
  108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99,
  111, 117, 108, 101, 117, 114, 61, 54, 52, 10, 45, 101, 110, 100, 105, 102,
  10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108,
  101, 115, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 43, 123, 63,
  40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 44, 36, 86, 97, 108,
  101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111,
  117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10, 45, 105, 102, 32, 123,
  36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108,
  101, 115, 62, 50, 53, 53, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 60, 48, 125, 10, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 10, 45, 101, 110, 100, 105, 102, 10, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 123, 114, 111,
  117, 110, 100, 40, 123, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 43, 123, 63, 40, 45, 36, 86, 97, 108,
  101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111,
  117, 108, 101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41,
  125, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 62, 50, 53, 53,
  125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 61, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 60, 48, 125, 10, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 86, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 10, 45, 101,
  110, 100, 105, 102, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101,
  115, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 44,
  36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10, 45,
  105, 102, 32, 123, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 62, 50, 53, 53, 125, 10, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 66, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 60,
  48, 125, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116,
  97, 108, 101, 115, 61, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 10, 45, 101, 110, 100, 105, 102, 10, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114,
  95, 112, 101, 116, 97, 108, 101, 115, 61, 123, 114, 111, 117, 110, 100, 40,
  123, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116,
  111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 43, 123, 63, 40, 45,
  36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 99, 111, 117, 108, 101, 117, 114, 44, 36, 86, 97, 108, 101, 117,
  114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108,
  101, 117, 114, 41, 125, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 82,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114,
  95, 112, 101, 116, 97, 108, 101, 115, 62, 50, 53, 53, 125, 10, 82, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 61, 36, 82, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108,
  101, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117,
  114, 95, 112, 101, 116, 97, 108, 101, 115, 60, 48, 125, 10, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 61, 36, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101,
  115, 10, 45, 101, 110, 100, 105, 102, 10, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108,
  101, 115, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 86, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117,
  114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108,
  101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125,
  41, 125, 10, 45, 105, 102, 32, 123, 36, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108,
  101, 115, 62, 50, 53, 53, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101,
  115, 61, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110,
  116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 60, 48, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  61, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116,
  111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 10, 45, 101, 110, 100,
  105, 102, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110,
  116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 123, 114, 111,
  117, 110, 100, 40, 123, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 43,
  123, 63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105,
  97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 44, 36, 86,
  97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  99, 111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10, 45, 105, 102,
  32, 123, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110,
  116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 62, 50, 53, 53,
  125, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116,
  111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111,
  110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 60, 48, 125,
  10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111,
  117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 82, 101, 109, 112, 108, 105, 114, 95, 112, 101, 116, 97, 108,
  101, 115, 61, 61, 49, 125, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91,
  45, 49, 93, 32, 36, 88, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101,
  114, 99, 108, 101, 95, 112, 101, 116, 97, 108, 101, 44, 36, 89, 95, 99,
  101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 112, 101, 116,
  97, 108, 101, 44, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 95, 98, 111, 117, 99, 108, 101, 44, 36, 76, 97,
  114, 103, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 98, 111,
  117, 99, 108, 101, 44, 36, 97, 110, 103, 108, 101, 95, 112, 101, 116, 97,
  108, 101, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 44, 36, 86, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 65,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 67, 111,
  110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 61, 49,
  125, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36,
  88, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95,
  112, 101, 116, 97, 108, 101, 44, 36, 89, 95, 99, 101, 110, 116, 114, 101,
  95, 99, 101, 114, 99, 108, 101, 95, 112, 101, 116, 97, 108, 101, 44, 36,
  76, 111, 110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  95, 98, 111, 117, 99, 108, 101, 44, 36, 76, 97, 114, 103, 101, 117, 114,
  95, 112, 101, 116, 97, 108, 101, 115, 95, 98, 111, 117, 99, 108, 101, 44,
  36, 97, 110, 103, 108, 101, 95, 112, 101, 116, 97, 108, 101, 44, 49, 44,
  48, 120, 70, 70, 70, 70, 70, 70, 44, 36, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99,
  111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117,
  114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 65, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116,
  97, 108, 101, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100,
  105, 102, 10, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97, 110, 103,
  108, 101, 61, 123, 36, 73, 110, 99, 114, 101, 109, 101, 110, 116, 95, 97,
  110, 103, 108, 101, 43, 123, 51, 54, 48, 47, 36, 78, 111, 109, 98, 114,
  101, 95, 100, 101, 95, 112, 101, 116, 97, 108, 101, 115, 125, 125, 10, 78,
  98, 95, 98, 111, 117, 99, 108, 101, 61, 123, 36, 78, 98, 95, 98, 111,
  117, 99, 108, 101, 45, 49, 125, 10, 73, 110, 100, 101, 120, 61, 123, 36,
  73, 110, 100, 101, 120, 43, 49, 125, 10, 45, 119, 104, 105, 108, 101, 32,
  123, 36, 78, 98, 95, 98, 111, 117, 99, 108, 101, 62, 48, 125, 10, 45,
  105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100,
  101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 61, 49, 125, 10, 82, 95,
  67, 73, 95, 112, 108, 101, 105, 110, 61, 123, 114, 111, 117, 110, 100, 40,
  63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 86, 95, 67, 73, 95,
  112, 108, 101, 105, 110, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 50, 53, 53, 41, 41, 125, 10, 66, 95, 67, 73, 95, 112, 108, 101,
  105, 110, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53,
  53, 41, 41, 125, 10, 82, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117,
  114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53,
  41, 41, 125, 10, 86, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114,
  61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41,
  41, 125, 10, 66, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 61,
  123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41,
  125, 10, 82, 95, 67, 69, 95, 112, 108, 101, 105, 110, 61, 123, 114, 111,
  117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 86,
  95, 67, 69, 95, 112, 108, 101, 105, 110, 61, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 66, 95, 67, 69,
  95, 112, 108, 101, 105, 110, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40,
  48, 44, 50, 53, 53, 41, 41, 125, 10, 82, 95, 67, 69, 95, 99, 111,
  110, 116, 111, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 50, 53, 53, 41, 41, 125, 10, 86, 95, 67, 69, 95, 99, 111, 110,
  116, 111, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44,
  50, 53, 53, 41, 41, 125, 10, 66, 95, 67, 69, 95, 99, 111, 110, 116,
  111, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50,
  53, 53, 41, 41, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 36, 82, 101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108,
  101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 61, 61, 49, 125, 10,
  45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 88, 95,
  99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 115, 44, 36,
  89, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 115,
  44, 36, 82, 97, 121, 111, 110, 95, 103, 114, 97, 110, 100, 95, 99, 101,
  114, 99, 108, 101, 44, 36, 82, 97, 121, 111, 110, 95, 103, 114, 97, 110,
  100, 95, 99, 101, 114, 99, 108, 101, 44, 48, 44, 49, 44, 36, 82, 95,
  67, 69, 95, 112, 108, 101, 105, 110, 44, 36, 86, 95, 67, 69, 95, 112,
  108, 101, 105, 110, 44, 36, 66, 95, 67, 69, 95, 112, 108, 101, 105, 110,
  44, 36, 65, 95, 67, 69, 95, 112, 108, 101, 105, 110, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 67, 111, 110, 116, 111, 117,
  114, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101,
  117, 114, 61, 61, 49, 125, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91,
  45, 49, 93, 32, 36, 88, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101,
  114, 99, 108, 101, 115, 44, 36, 89, 95, 99, 101, 110, 116, 114, 101, 95,
  99, 101, 114, 99, 108, 101, 115, 44, 36, 82, 97, 121, 111, 110, 95, 103,
  114, 97, 110, 100, 95, 99, 101, 114, 99, 108, 101, 44, 36, 82, 97, 121,
  111, 110, 95, 103, 114, 97, 110, 100, 95, 99, 101, 114, 99, 108, 101, 44,
  48, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 44, 36, 82, 95,
  67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 86, 95, 67, 69,
  95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 66, 95, 67, 69, 95, 99,
  111, 110, 116, 111, 117, 114, 44, 36, 65, 95, 67, 69, 95, 99, 111, 110,
  116, 111, 117, 114, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32,
  123, 36, 82, 101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108, 101,
  95, 105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 61, 49, 125, 10, 45,
  101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 88, 95, 99,
  101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 115, 44, 36, 89,
  95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 115, 44,
  36, 82, 97, 121, 111, 110, 95, 112, 101, 116, 105, 116, 95, 99, 101, 114,
  99, 108, 101, 44, 36, 82, 97, 121, 111, 110, 95, 112, 101, 116, 105, 116,
  95, 99, 101, 114, 99, 108, 101, 44, 48, 44, 49, 44, 36, 82, 95, 67,
  73, 95, 112, 108, 101, 105, 110, 44, 36, 86, 95, 67, 73, 95, 112, 108,
  101, 105, 110, 44, 36, 66, 95, 67, 73, 95, 112, 108, 101, 105, 110, 44,
  36, 65, 95, 67, 73, 95, 112, 108, 101, 105, 110, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 67, 111, 110, 116, 111, 117, 114,
  95, 99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117,
  114, 61, 61, 49, 125, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45,
  49, 93, 32, 36, 88, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114,
  99, 108, 101, 115, 44, 36, 89, 95, 99, 101, 110, 116, 114, 101, 95, 99,
  101, 114, 99, 108, 101, 115, 44, 36, 82, 97, 121, 111, 110, 95, 112, 101,
  116, 105, 116, 95, 99, 101, 114, 99, 108, 101, 44, 36, 82, 97, 121, 111,
  110, 95, 112, 101, 116, 105, 116, 95, 99, 101, 114, 99, 108, 101, 44, 48,
  44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 44, 36, 82, 95, 67,
  73, 95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 86, 95, 67, 73, 95,
  99, 111, 110, 116, 111, 117, 114, 44, 36, 66, 95, 67, 73, 95, 99, 111,
  110, 116, 111, 117, 114, 44, 36, 65, 95, 67, 73, 95, 99, 111, 110, 116,
  111, 117, 114, 10, 45, 101, 110, 100, 105, 102, 10, 45, 118, 101, 114, 98,
  111, 115, 101, 32, 43, 10, 102, 108, 111, 119, 101, 114, 95, 115, 112, 105,
  114, 97, 108, 95, 112, 97, 116, 116, 101, 114, 110, 95, 115, 97, 109, 106,
  32, 58, 10, 45, 118, 101, 114, 98, 111, 115, 101, 32, 45, 10, 35, 35,
  32, 86, 97, 114, 105, 97, 98, 108, 101, 115, 10, 116, 111, 117, 114, 115,
  61, 36, 49, 10, 105, 110, 99, 114, 101, 109, 101, 110, 116, 95, 116, 104,
  101, 116, 97, 61, 36, 50, 10, 99, 111, 101, 102, 102, 95, 100, 105, 109,
  61, 36, 51, 10, 115, 101, 110, 115, 95, 114, 111, 116, 97, 116, 105, 111,
  110, 61, 36, 52, 10, 76, 111, 110, 103, 117, 101, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 61, 36, 53, 10, 76, 97, 114, 103, 101, 117, 114,
  95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 54, 10, 69, 115, 112, 97,
  99, 101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101,
  61, 36, 55, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 108, 111,
  110, 103, 117, 101, 117, 114, 61, 36, 56, 10, 86, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114, 61, 36, 57,
  10, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 97, 110, 103, 108, 101,
  61, 36, 49, 48, 10, 65, 103, 114, 97, 110, 100, 105, 115, 115, 101, 109,
  101, 110, 116, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 49, 49, 10,
  82, 101, 109, 112, 108, 105, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61,
  36, 49, 50, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 61, 36, 49, 51, 10, 86, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 49, 52, 10,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101,
  115, 61, 36, 49, 53, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 61, 36, 49, 54, 10, 67, 111, 110, 116,
  111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 49, 55, 10,
  82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117,
  114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 49, 56, 10, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 61, 36, 49, 57, 10, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 61, 36, 50, 48, 10, 65, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 61, 36, 50, 49, 10, 82, 101, 109, 112, 108, 105, 114, 95,
  99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114,
  61, 36, 50, 50, 10, 82, 95, 67, 73, 95, 112, 108, 101, 105, 110, 61,
  36, 50, 51, 10, 86, 95, 67, 73, 95, 112, 108, 101, 105, 110, 61, 36,
  50, 52, 10, 66, 95, 67, 73, 95, 112, 108, 101, 105, 110, 61, 36, 50,
  53, 10, 65, 95, 67, 73, 95, 112, 108, 101, 105, 110, 61, 36, 50, 54,
  10, 67, 111, 110, 116, 111, 117, 114, 95, 99, 101, 114, 99, 108, 101, 95,
  105, 110, 116, 101, 114, 105, 101, 117, 114, 61, 36, 50, 55, 10, 82, 95,
  67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 50, 56, 10, 86,
  95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 50, 57, 10,
  66, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 51, 48,
  10, 65, 95, 67, 73, 95, 99, 111, 110, 116, 111, 117, 114, 61, 36, 51,
  49, 10, 82, 101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108, 101,
  95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 61, 36, 51, 50, 10, 82,
  95, 67, 69, 95, 112, 108, 101, 105, 110, 61, 36, 51, 51, 10, 86, 95,
  67, 69, 95, 112, 108, 101, 105, 110, 61, 36, 51, 52, 10, 66, 95, 67,
  69, 95, 112, 108, 101, 105, 110, 61, 36, 51, 53, 10, 65, 95, 67, 69,
  95, 112, 108, 101, 105, 110, 61, 36, 51, 54, 10, 67, 111, 110, 116, 111,
  117, 114, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114, 105,
  101, 117, 114, 61, 36, 51, 55, 10, 82, 95, 67, 69, 95, 99, 111, 110,
  116, 111, 117, 114, 61, 36, 51, 56, 10, 86, 95, 67, 69, 95, 99, 111,
  110, 116, 111, 117, 114, 61, 36, 51, 57, 10, 66, 95, 67, 69, 95, 99,
  111, 110, 116, 111, 117, 114, 61, 36, 52, 48, 10, 65, 95, 67, 69, 95,
  99, 111, 110, 116, 111, 117, 114, 61, 36, 52, 49, 10, 82, 97, 121, 111,
  110, 95, 103, 114, 97, 110, 100, 95, 99, 101, 114, 99, 108, 101, 61, 36,
  52, 50, 10, 82, 97, 121, 111, 110, 95, 112, 101, 116, 105, 116, 95, 99,
  101, 114, 99, 108, 101, 61, 36, 52, 51, 10, 86, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 36,
  52, 52, 10, 35, 35, 32, 86, 97, 114, 105, 97, 98, 108, 101, 115, 32,
  99, 97, 108, 99, 117, 108, -23, 101, 115, 10, 99, 101, 110, 116, 114, 101,
  95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 61, 123, 114, 111, 117, 110,
  100, 40, 123, 36, 116, 111, 117, 114, 115, 42, 123, 49, 43, 123, 36, 99,
  111, 101, 102, 102, 95, 100, 105, 109, 47, 49, 48, 125, 125, 42, 123, 36,
  76, 111, 110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  43, 123, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 42, 123, 49, 43, 123, 52, 42, 36, 65, 103, 114, 97, 110,
  100, 105, 115, 115, 101, 109, 101, 110, 116, 95, 112, 101, 116, 97, 108, 101,
  115, 125, 125, 125, 43, 123, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 47, 49, 48, 48, 42, 123, 36, 86, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 108, 111, 110, 103, 117, 101, 117, 114,
  43, 49, 125, 125, 125, 125, 43, 36, 69, 115, 112, 97, 99, 101, 109, 101,
  110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101, 41, 125, 10, 45,
  105, 102, 32, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103,
  105, 110, 101, 95, 88, 62, 53, 48, 48, 48, 125, 10, 99, 101, 110, 116,
  114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 61, 53, 48, 48,
  48, 10, 45, 101, 110, 100, 105, 102, 10, 99, 101, 110, 116, 114, 101, 95,
  111, 114, 105, 103, 105, 110, 101, 95, 89, 61, 36, 99, 101, 110, 116, 114,
  101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 10, 76, 97, 114, 103,
  101, 117, 114, 95, 101, 110, 95, 112, 105, 120, 101, 108, 115, 61, 123, 36,
  99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88,
  42, 50, 125, 10, 99, 111, 101, 102, 102, 95, 100, 105, 109, 61, 123, 36,
  99, 111, 101, 102, 102, 95, 100, 105, 109, 47, 49, 48, 48, 125, 10, 86,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 108, 111, 110, 103, 117, 101, 117,
  114, 61, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 108, 111,
  110, 103, 117, 101, 117, 114, 43, 49, 125, 10, 86, 97, 114, 105, 97, 116,
  105, 111, 110, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114, 61, 123, 36,
  86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 101, 112, 97, 105, 115, 115,
  101, 117, 114, 43, 49, 125, 10, 86, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 97, 110, 103, 108, 101, 61, 123, 36, 86, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 97, 110, 103, 108, 101, 43, 49, 125, 10, 88, 95, 112, 114,
  101, 99, 101, 100, 101, 110, 116, 61, 36, 99, 101, 110, 116, 114, 101, 95,
  111, 114, 105, 103, 105, 110, 101, 95, 88, 10, 89, 95, 112, 114, 101, 99,
  101, 100, 101, 110, 116, 61, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114,
  105, 103, 105, 110, 101, 95, 89, 10, 99, 111, 109, 112, 116, 101, 117, 114,
  95, 98, 111, 117, 99, 108, 101, 61, 48, 10, 109, 111, 100, 117, 108, 111,
  95, 115, 101, 110, 115, 95, 114, 111, 116, 97, 116, 105, 111, 110, 61, 123,
  36, 115, 101, 110, 115, 95, 114, 111, 116, 97, 116, 105, 111, 110, 37, 50,
  125, 10, 82, 97, 121, 111, 110, 95, 112, 101, 116, 105, 116, 95, 99, 101,
  114, 99, 108, 101, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82, 97,
  121, 111, 110, 95, 103, 114, 97, 110, 100, 95, 99, 101, 114, 99, 108, 101,
  47, 49, 48, 48, 42, 36, 82, 97, 121, 111, 110, 95, 112, 101, 116, 105,
  116, 95, 99, 101, 114, 99, 108, 101, 125, 41, 125, 10, 35, 35, 32, 98,
  111, 117, 99, 108, 101, 32, 111, 114, 100, 114, 101, 32, 100, -23, 99, 114,
  111, 105, 115, 115, 97, 110, 116, 32, 111, 117, 32, 99, 114, 111, 105, 115,
  115, 97, 110, 116, 10, 45, 105, 102, 32, 123, 36, 109, 111, 100, 117, 108,
  111, 95, 115, 101, 110, 115, 95, 114, 111, 116, 97, 116, 105, 111, 110, 61,
  61, 48, 125, 10, 116, 104, 101, 116, 97, 61, 123, 36, 116, 111, 117, 114,
  115, 42, 51, 54, 48, 125, 10, 116, 104, 101, 116, 97, 95, 102, 105, 110,
  61, 48, 10, 105, 110, 99, 114, 101, 109, 101, 110, 116, 95, 116, 104, 101,
  116, 97, 61, 123, 45, 36, 105, 110, 99, 114, 101, 109, 101, 110, 116, 95,
  116, 104, 101, 116, 97, 125, 10, 97, 114, 114, 101, 116, 95, 98, 111, 117,
  99, 108, 101, 61, 48, 10, 45, 101, 108, 115, 101, 10, 116, 104, 101, 116,
  97, 61, 48, 10, 116, 104, 101, 116, 97, 95, 102, 105, 110, 61, 123, 123,
  36, 116, 111, 117, 114, 115, 42, 51, 54, 48, 125, 43, 36, 105, 110, 99,
  114, 101, 109, 101, 110, 116, 95, 116, 104, 101, 116, 97, 125, 10, 97, 114,
  114, 101, 116, 95, 98, 111, 117, 99, 108, 101, 61, 48, 10, 45, 101, 110,
  100, 105, 102, 10, 35, 35, 10, 36, 76, 97, 114, 103, 101, 117, 114, 95,
  101, 110, 95, 112, 105, 120, 101, 108, 115, 44, 36, 76, 97, 114, 103, 101,
  117, 114, 95, 101, 110, 95, 112, 105, 120, 101, 108, 115, 44, 49, 44, 52,
  10, 45, 100, 111, 10, 45, 105, 102, 32, 123, 123, 36, 115, 101, 110, 115,
  95, 114, 111, 116, 97, 116, 105, 111, 110, 61, 61, 48, 125, 124, 124, 123,
  36, 115, 101, 110, 115, 95, 114, 111, 116, 97, 116, 105, 111, 110, 61, 61,
  49, 125, 125, 10, 88, 61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111,
  114, 105, 103, 105, 110, 101, 95, 88, 43, 123, 36, 99, 111, 101, 102, 102,
  95, 100, 105, 109, 42, 114, 111, 117, 110, 100, 40, 115, 105, 110, 40, 112,
  105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 43, 123, 36,
  116, 104, 101, 116, 97, 42, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48,
  42, 36, 116, 104, 101, 116, 97, 41, 125, 41, 125, 125, 10, 89, 61, 123,
  36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95,
  89, 43, 123, 36, 99, 111, 101, 102, 102, 95, 100, 105, 109, 42, 114, 111,
  117, 110, 100, 40, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36,
  116, 104, 101, 116, 97, 41, 43, 123, 36, 116, 104, 101, 116, 97, 42, 115,
  105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97,
  41, 125, 41, 125, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102,
  32, 123, 123, 36, 115, 101, 110, 115, 95, 114, 111, 116, 97, 116, 105, 111,
  110, 61, 61, 50, 125, 124, 124, 123, 36, 115, 101, 110, 115, 95, 114, 111,
  116, 97, 116, 105, 111, 110, 61, 61, 51, 125, 125, 10, 88, 61, 123, 36,
  99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88,
  43, 123, 36, 99, 111, 101, 102, 102, 95, 100, 105, 109, 42, 45, 114, 111,
  117, 110, 100, 40, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36,
  116, 104, 101, 116, 97, 41, 43, 123, 36, 116, 104, 101, 116, 97, 42, 99,
  111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97,
  41, 125, 41, 125, 125, 10, 89, 61, 123, 36, 99, 101, 110, 116, 114, 101,
  95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 43, 123, 36, 99, 111, 101,
  102, 102, 95, 100, 105, 109, 42, 45, 114, 111, 117, 110, 100, 40, 99, 111,
  115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41,
  43, 123, 36, 116, 104, 101, 116, 97, 42, 115, 105, 110, 40, 112, 105, 47,
  49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 41, 125, 125, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 123, 36, 115, 101,
  110, 115, 95, 114, 111, 116, 97, 116, 105, 111, 110, 61, 61, 52, 125, 124,
  124, 123, 36, 115, 101, 110, 115, 95, 114, 111, 116, 97, 116, 105, 111, 110,
  61, 61, 53, 125, 125, 10, 88, 61, 123, 36, 99, 101, 110, 116, 114, 101,
  95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 43, 123, 36, 99, 111, 101,
  102, 102, 95, 100, 105, 109, 42, 114, 111, 117, 110, 100, 40, 99, 111, 115,
  40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 43,
  123, 36, 116, 104, 101, 116, 97, 42, 115, 105, 110, 40, 112, 105, 47, 49,
  56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 41, 125, 125, 10, 89,
  61, 123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110,
  101, 95, 89, 43, 123, 36, 99, 111, 101, 102, 102, 95, 100, 105, 109, 42,
  114, 111, 117, 110, 100, 40, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48,
  42, 36, 116, 104, 101, 116, 97, 41, 43, 123, 36, 116, 104, 101, 116, 97,
  42, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101,
  116, 97, 41, 125, 41, 125, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 123, 36, 115, 101, 110, 115, 95, 114, 111, 116, 97, 116,
  105, 111, 110, 61, 61, 54, 125, 124, 124, 123, 36, 115, 101, 110, 115, 95,
  114, 111, 116, 97, 116, 105, 111, 110, 61, 61, 55, 125, 125, 10, 88, 61,
  123, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101,
  95, 88, 43, 123, 36, 99, 111, 101, 102, 102, 95, 100, 105, 109, 42, 45,
  114, 111, 117, 110, 100, 40, 99, 111, 115, 40, 112, 105, 47, 49, 56, 48,
  42, 36, 116, 104, 101, 116, 97, 41, 43, 123, 36, 116, 104, 101, 116, 97,
  42, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101,
  116, 97, 41, 125, 41, 125, 125, 10, 89, 61, 123, 36, 99, 101, 110, 116,
  114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 43, 123, 36, 99,
  111, 101, 102, 102, 95, 100, 105, 109, 42, 45, 114, 111, 117, 110, 100, 40,
  115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116,
  97, 41, 43, 123, 36, 116, 104, 101, 116, 97, 42, 99, 111, 115, 40, 112,
  105, 47, 49, 56, 48, 42, 36, 116, 104, 101, 116, 97, 41, 125, 41, 125,
  125, 10, 45, 101, 110, 100, 105, 102, 10, 86, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 97, 110, 103, 108, 101, 95, 98, 111, 117, 99, 108, 101, 61,
  123, 63, 40, 45, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 97,
  110, 103, 108, 101, 44, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95,
  97, 110, 103, 108, 101, 41, 125, 10, 86, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 108, 111, 110, 103, 117, 101, 117, 114, 95, 98, 111, 117, 99, 108,
  101, 61, 123, 63, 40, 45, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 108, 111, 110, 103, 117, 101, 117, 114, 44, 36, 86, 97, 114, 105, 97,
  116, 105, 111, 110, 95, 108, 111, 110, 103, 117, 101, 117, 114, 41, 125, 10,
  86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 101, 112, 97, 105, 115, 115,
  101, 117, 114, 95, 98, 111, 117, 99, 108, 101, 61, 123, 63, 40, 45, 36,
  86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 101, 112, 97, 105, 115, 115,
  101, 117, 114, 44, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 101,
  112, 97, 105, 115, 115, 101, 117, 114, 41, 125, 10, 76, 111, 110, 103, 117,
  101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 98, 111, 117, 99,
  108, 101, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 76, 111, 110, 103,
  117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 43, 123, 36, 76,
  111, 110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 47,
  49, 48, 48, 42, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 108,
  111, 110, 103, 117, 101, 117, 114, 95, 98, 111, 117, 99, 108, 101, 125, 125,
  41, 125, 10, 76, 111, 110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 95, 98, 111, 117, 99, 108, 101, 61, 123, 36, 76, 111, 110,
  103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 98, 111,
  117, 99, 108, 101, 42, 123, 36, 116, 111, 117, 114, 115, 47, 51, 125, 42,
  123, 49, 45, 123, 123, 36, 99, 111, 101, 102, 102, 95, 100, 105, 109, 47,
  49, 48, 48, 125, 42, 36, 99, 111, 109, 112, 116, 101, 117, 114, 95, 98,
  111, 117, 99, 108, 101, 125, 125, 125, 10, 45, 105, 102, 32, 123, 36, 65,
  103, 114, 97, 110, 100, 105, 115, 115, 101, 109, 101, 110, 116, 95, 112, 101,
  116, 97, 108, 101, 115, 62, 48, 125, 10, 76, 111, 110, 103, 117, 101, 117,
  114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 98, 111, 117, 99, 108, 101,
  61, 123, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 95, 98, 111, 117, 99, 108, 101, 42, 123, 36, 65, 103, 114,
  97, 110, 100, 105, 115, 115, 101, 109, 101, 110, 116, 95, 112, 101, 116, 97,
  108, 101, 115, 42, 36, 116, 104, 101, 116, 97, 42, 50, 48, 42, 36, 99,
  111, 101, 102, 102, 95, 100, 105, 109, 47, 51, 54, 48, 125, 125, 10, 45,
  101, 110, 100, 105, 102, 10, 76, 97, 114, 103, 101, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 95, 98, 111, 117, 99, 108, 101, 61, 123, 114, 111,
  117, 110, 100, 40, 123, 123, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 47, 49, 48, 48, 42, 36, 76, 97, 114,
  103, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 125, 43, 123, 123,
  36, 76, 111, 110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101,
  115, 47, 49, 48, 48, 42, 36, 76, 97, 114, 103, 101, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 125, 47, 49, 48, 48, 42, 36, 86, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 101, 112, 97, 105, 115, 115, 101, 117, 114,
  95, 98, 111, 117, 99, 108, 101, 125, 125, 41, 125, 10, 76, 97, 114, 103,
  101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 98, 111, 117, 99,
  108, 101, 61, 123, 36, 76, 97, 114, 103, 101, 117, 114, 95, 112, 101, 116,
  97, 108, 101, 115, 95, 98, 111, 117, 99, 108, 101, 42, 123, 49, 43, 123,
  36, 116, 111, 117, 114, 115, 47, 51, 48, 125, 125, 42, 123, 49, 45, 123,
  123, 36, 99, 111, 101, 102, 102, 95, 100, 105, 109, 47, 49, 48, 125, 42,
  36, 99, 111, 109, 112, 116, 101, 117, 114, 95, 98, 111, 117, 99, 108, 101,
  125, 125, 125, 10, 97, 110, 103, 108, 101, 95, 112, 101, 116, 97, 108, 101,
  61, 123, 123, 123, 36, 105, 110, 99, 114, 101, 109, 101, 110, 116, 95, 116,
  104, 101, 116, 97, 42, 36, 99, 111, 109, 112, 116, 101, 117, 114, 95, 98,
  111, 117, 99, 108, 101, 125, 43, 36, 86, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 97, 110, 103, 108, 101, 95, 98, 111, 117, 99, 108, 101, 125, 43,
  48, 125, 10, 68, 101, 99, 97, 108, 97, 103, 101, 95, 88, 95, 99, 101,
  110, 116, 114, 101, 95, 112, 101, 116, 97, 108, 101, 61, 123, 114, 111, 117,
  110, 100, 40, 123, 36, 69, 115, 112, 97, 99, 101, 109, 101, 110, 116, 95,
  100, 117, 95, 99, 101, 110, 116, 114, 101, 42, 123, 99, 111, 115, 40, 112,
  105, 47, 49, 56, 48, 42, 36, 97, 110, 103, 108, 101, 95, 112, 101, 116,
  97, 108, 101, 41, 125, 125, 41, 125, 10, 68, 101, 99, 97, 108, 97, 103,
  101, 95, 89, 95, 99, 101, 110, 116, 114, 101, 95, 112, 101, 116, 97, 108,
  101, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 69, 115, 112, 97, 99,
  101, 109, 101, 110, 116, 95, 100, 117, 95, 99, 101, 110, 116, 114, 101, 42,
  123, 115, 105, 110, 40, 112, 105, 47, 49, 56, 48, 42, 36, 97, 110, 103,
  108, 101, 95, 112, 101, 116, 97, 108, 101, 41, 125, 125, 41, 125, 10, 88,
  95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 112,
  101, 116, 97, 108, 101, 61, 123, 36, 88, 43, 36, 68, 101, 99, 97, 108,
  97, 103, 101, 95, 88, 95, 99, 101, 110, 116, 114, 101, 95, 112, 101, 116,
  97, 108, 101, 125, 10, 89, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101,
  114, 99, 108, 101, 95, 112, 101, 116, 97, 108, 101, 61, 123, 36, 89, 43,
  36, 68, 101, 99, 97, 108, 97, 103, 101, 95, 89, 95, 99, 101, 110, 116,
  114, 101, 95, 112, 101, 116, 97, 108, 101, 125, 10, 45, 105, 102, 32, 123,
  36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111,
  117, 108, 101, 117, 114, 61, 61, 49, 125, 10, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 123, 114, 111, 117,
  110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61,
  123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41,
  125, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50,
  53, 53, 41, 41, 125, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 61, 123, 123, 114, 111, 117, 110, 100, 40,
  123, 40, 63, 40, 50, 48, 48, 41, 41, 125, 41, 125, 43, 53, 53, 125,
  10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111,
  117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 123, 114, 111, 117, 110,
  100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 86, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40,
  48, 44, 50, 53, 53, 41, 41, 125, 10, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108,
  101, 115, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50, 53,
  53, 41, 41, 125, 10, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99,
  111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 61, 123, 123,
  114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 48, 48, 41, 41, 125,
  41, 125, 43, 53, 53, 125, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105,
  102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101,
  95, 99, 111, 117, 108, 101, 117, 114, 62, 49, 125, 10, 86, 97, 108, 101,
  117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117,
  108, 101, 117, 114, 61, 49, 54, 10, 45, 105, 102, 32, 123, 36, 86, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117, 108, 101,
  117, 114, 61, 61, 51, 125, 10, 86, 97, 108, 101, 117, 114, 95, 118, 97,
  114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 61,
  51, 50, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  86, 97, 114, 105, 97, 116, 105, 111, 110, 95, 100, 101, 95, 99, 111, 117,
  108, 101, 117, 114, 61, 61, 52, 125, 10, 86, 97, 108, 101, 117, 114, 95,
  118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117,
  114, 61, 54, 52, 10, 45, 101, 110, 100, 105, 102, 10, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 123, 114,
  111, 117, 110, 100, 40, 123, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 112, 101, 116, 97, 108, 101, 115, 43, 123, 63, 40, 45, 36, 86, 97,
  108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99,
  111, 117, 108, 101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114, 95, 118,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114,
  41, 125, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 62, 50, 53,
  53, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116,
  97, 108, 101, 115, 61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 60, 48, 125, 10, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 10, 45,
  101, 110, 100, 105, 102, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 61, 123, 114, 111, 117, 110, 100, 40, 123,
  36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108,
  101, 115, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118,
  97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114,
  44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10,
  45, 105, 102, 32, 123, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 62, 50, 53, 53, 125, 10, 86, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36,
  86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101,
  115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 86,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  60, 48, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 61, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 112, 101, 116, 97, 108, 101, 115, 10, 45, 101, 110, 100, 105, 102, 10,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101,
  115, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 66, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 43, 123, 63, 40,
  45, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105,
  111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 44, 36, 86, 97, 108, 101,
  117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117,
  108, 101, 117, 114, 41, 125, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36,
  66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101,
  115, 62, 50, 53, 53, 125, 10, 66, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 66, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 10, 45, 101, 110, 100,
  105, 102, 10, 45, 105, 102, 32, 123, 36, 66, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 60, 48, 125, 10, 66, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61,
  36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108,
  101, 115, 10, 45, 101, 110, 100, 105, 102, 10, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 61, 123, 114, 111, 117, 110, 100, 40, 123, 36, 82, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 43, 123, 63, 40, 45, 36, 86, 97, 108, 101,
  117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117,
  108, 101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 41, 125,
  125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 82, 95, 67, 111, 117, 108,
  101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97,
  108, 101, 115, 62, 50, 53, 53, 125, 10, 82, 95, 67, 111, 117, 108, 101,
  117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108,
  101, 115, 61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111,
  110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 82, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116,
  97, 108, 101, 115, 60, 48, 125, 10, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101,
  115, 61, 36, 82, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110,
  116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 10, 45, 101, 110,
  100, 105, 102, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111,
  110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 123, 114,
  111, 117, 110, 100, 40, 123, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  43, 123, 63, 40, 45, 36, 86, 97, 108, 101, 117, 114, 95, 118, 97, 114,
  105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101, 117, 114, 44, 36,
  86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 99, 111, 117, 108, 101, 117, 114, 41, 125, 125, 41, 125, 10, 45, 105,
  102, 32, 123, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111,
  110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 62, 50, 53,
  53, 125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110,
  116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 86, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99,
  111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 60, 48,
  125, 10, 86, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116,
  111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61, 36, 86, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 10, 45, 101, 110, 100, 105, 102, 10, 66, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 61, 123, 114, 111, 117, 110, 100, 40, 123,
  36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111,
  117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 43, 123, 63, 40, 45, 36,
  86, 97, 108, 101, 117, 114, 95, 118, 97, 114, 105, 97, 116, 105, 111, 110,
  95, 99, 111, 117, 108, 101, 117, 114, 44, 36, 86, 97, 108, 101, 117, 114,
  95, 118, 97, 114, 105, 97, 116, 105, 111, 110, 95, 99, 111, 117, 108, 101,
  117, 114, 41, 125, 125, 41, 125, 10, 45, 105, 102, 32, 123, 36, 66, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 62, 50, 53, 53, 125, 10, 66, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 61, 36, 66, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101,
  115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 66,
  95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114,
  95, 112, 101, 116, 97, 108, 101, 115, 60, 48, 125, 10, 66, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 61, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 123, 36, 82, 101, 109, 112, 108, 105, 114, 95, 112, 101, 116,
  97, 108, 101, 115, 61, 61, 49, 125, 10, 45, 101, 108, 108, 105, 112, 115,
  101, 91, 45, 49, 93, 32, 36, 88, 95, 99, 101, 110, 116, 114, 101, 95,
  99, 101, 114, 99, 108, 101, 95, 112, 101, 116, 97, 108, 101, 44, 36, 89,
  95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 112,
  101, 116, 97, 108, 101, 44, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95,
  112, 101, 116, 97, 108, 101, 115, 95, 98, 111, 117, 99, 108, 101, 44, 36,
  76, 97, 114, 103, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95,
  98, 111, 117, 99, 108, 101, 44, 36, 97, 110, 103, 108, 101, 95, 112, 101,
  116, 97, 108, 101, 44, 49, 44, 36, 82, 95, 67, 111, 117, 108, 101, 117,
  114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 86, 95, 67, 111, 117,
  108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 66, 95,
  67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44,
  36, 65, 95, 67, 111, 117, 108, 101, 117, 114, 95, 112, 101, 116, 97, 108,
  101, 115, 10, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36,
  67, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 61,
  61, 49, 125, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93,
  32, 36, 88, 95, 99, 101, 110, 116, 114, 101, 95, 99, 101, 114, 99, 108,
  101, 95, 112, 101, 116, 97, 108, 101, 44, 36, 89, 95, 99, 101, 110, 116,
  114, 101, 95, 99, 101, 114, 99, 108, 101, 95, 112, 101, 116, 97, 108, 101,
  44, 36, 76, 111, 110, 103, 117, 101, 117, 114, 95, 112, 101, 116, 97, 108,
  101, 115, 95, 98, 111, 117, 99, 108, 101, 44, 36, 76, 97, 114, 103, 101,
  117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 95, 98, 111, 117, 99, 108,
  101, 44, 36, 97, 110, 103, 108, 101, 95, 112, 101, 116, 97, 108, 101, 44,
  49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 44, 36, 82, 95, 67, 111,
  117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101,
  116, 97, 108, 101, 115, 44, 36, 86, 95, 67, 111, 117, 108, 101, 117, 114,
  95, 99, 111, 110, 116, 111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115,
  44, 36, 66, 95, 67, 111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116,
  111, 117, 114, 95, 112, 101, 116, 97, 108, 101, 115, 44, 36, 65, 95, 67,
  111, 117, 108, 101, 117, 114, 95, 99, 111, 110, 116, 111, 117, 114, 95, 112,
  101, 116, 97, 108, 101, 115, 10, 45, 101, 110, 100, 105, 102, 10, 88, 95,
  112, 114, 101, 99, 101, 100, 101, 110, 116, 61, 36, 88, 10, 89, 95, 112,
  114, 101, 99, 101, 100, 101, 110, 116, 61, 36, 89, 10, 99, 111, 109, 112,
  116, 101, 117, 114, 95, 98, 111, 117, 99, 108, 101, 61, 123, 36, 99, 111,
  109, 112, 116, 101, 117, 114, 95, 98, 111, 117, 99, 108, 101, 43, 49, 125,
  10, 116, 104, 101, 116, 97, 61, 123, 36, 116, 104, 101, 116, 97, 43, 36,
  105, 110, 99, 114, 101, 109, 101, 110, 116, 95, 116, 104, 101, 116, 97, 125,
  10, 45, 105, 102, 32, 123, 36, 109, 111, 100, 117, 108, 111, 95, 115, 101,
  110, 115, 95, 114, 111, 116, 97, 116, 105, 111, 110, 61, 61, 48, 125, 10,
  45, 105, 102, 32, 123, 36, 116, 104, 101, 116, 97, 60, 36, 116, 104, 101,
  116, 97, 95, 102, 105, 110, 125, 10, 97, 114, 114, 101, 116, 95, 98, 111,
  117, 99, 108, 101, 61, 49, 10, 45, 101, 110, 100, 105, 102, 10, 45, 101,
  108, 115, 101, 10, 45, 105, 102, 32, 123, 36, 116, 104, 101, 116, 97, 62,
  36, 116, 104, 101, 116, 97, 95, 102, 105, 110, 125, 10, 97, 114, 114, 101,
  116, 95, 98, 111, 117, 99, 108, 101, 61, 49, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 119, 104, 105, 108, 101, 32,
  123, 36, 97, 114, 114, 101, 116, 95, 98, 111, 117, 99, 108, 101, 61, 61,
  48, 125, 10, 35, 35, 32, 114, 101, 109, 112, 108, 105, 114, 32, 99, 111,
  117, 108, 101, 117, 114, 115, 32, 97, 108, -23, 97, 116, 111, 105, 114, 101,
  115, 10, 45, 105, 102, 32, 123, 36, 86, 97, 114, 105, 97, 116, 105, 111,
  110, 95, 100, 101, 95, 99, 111, 117, 108, 101, 117, 114, 61, 61, 49, 125,
  10, 82, 95, 67, 73, 95, 112, 108, 101, 105, 110, 61, 123, 114, 111, 117,
  110, 100, 40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 86, 95,
  67, 73, 95, 112, 108, 101, 105, 110, 61, 123, 114, 111, 117, 110, 100, 40,
  63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 66, 95, 67, 73, 95,
  112, 108, 101, 105, 110, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 50, 53, 53, 41, 41, 125, 10, 65, 95, 67, 73, 95, 112, 108, 101,
  105, 110, 61, 123, 123, 114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50,
  48, 48, 41, 41, 125, 41, 125, 43, 53, 53, 125, 10, 82, 95, 67, 73,
  95, 99, 111, 110, 116, 111, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40,
  63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 86, 95, 67, 73, 95,
  99, 111, 110, 116, 111, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 63,
  40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 66, 95, 67, 73, 95, 99,
  111, 110, 116, 111, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40,
  48, 44, 50, 53, 53, 41, 41, 125, 10, 65, 95, 67, 73, 95, 99, 111,
  110, 116, 111, 117, 114, 61, 123, 123, 114, 111, 117, 110, 100, 40, 123, 40,
  63, 40, 50, 48, 48, 41, 41, 125, 41, 125, 43, 53, 53, 125, 10, 82,
  95, 67, 69, 95, 112, 108, 101, 105, 110, 61, 123, 114, 111, 117, 110, 100,
  40, 63, 40, 48, 44, 50, 53, 53, 41, 41, 125, 10, 86, 95, 67, 69,
  95, 112, 108, 101, 105, 110, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40,
  48, 44, 50, 53, 53, 41, 41, 125, 10, 66, 95, 67, 69, 95, 112, 108,
  101, 105, 110, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44, 50,
  53, 53, 41, 41, 125, 10, 65, 95, 67, 69, 95, 112, 108, 101, 105, 110,
  61, 123, 123, 114, 111, 117, 110, 100, 40, 123, 40, 63, 40, 50, 48, 48,
  41, 41, 125, 41, 125, 43, 53, 53, 125, 10, 82, 95, 67, 69, 95, 99,
  111, 110, 116, 111, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40,
  48, 44, 50, 53, 53, 41, 41, 125, 10, 86, 95, 67, 69, 95, 99, 111,
  110, 116, 111, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48,
  44, 50, 53, 53, 41, 41, 125, 10, 66, 95, 67, 69, 95, 99, 111, 110,
  116, 111, 117, 114, 61, 123, 114, 111, 117, 110, 100, 40, 63, 40, 48, 44,
  50, 53, 53, 41, 41, 125, 10, 65, 95, 67, 69, 95, 99, 111, 110, 116,
  111, 117, 114, 61, 123, 123, 114, 111, 117, 110, 100, 40, 123, 40, 63, 40,
  50, 48, 48, 41, 41, 125, 41, 125, 43, 53, 53, 125, 10, 45, 101, 110,
  100, 105, 102, 10, 35, 10, 45, 105, 102, 32, 123, 36, 82, 101, 109, 112,
  108, 105, 114, 95, 99, 101, 114, 99, 108, 101, 95, 101, 120, 116, 101, 114,
  105, 101, 117, 114, 61, 61, 49, 125, 10, 45, 101, 108, 108, 105, 112, 115,
  101, 91, 45, 49, 93, 32, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114,
  105, 103, 105, 110, 101, 95, 88, 44, 36, 99, 101, 110, 116, 114, 101, 95,
  111, 114, 105, 103, 105, 110, 101, 95, 89, 44, 36, 82, 97, 121, 111, 110,
  95, 103, 114, 97, 110, 100, 95, 99, 101, 114, 99, 108, 101, 44, 36, 82,
  97, 121, 111, 110, 95, 103, 114, 97, 110, 100, 95, 99, 101, 114, 99, 108,
  101, 44, 48, 44, 49, 44, 36, 82, 95, 67, 69, 95, 112, 108, 101, 105,
  110, 44, 36, 86, 95, 67, 69, 95, 112, 108, 101, 105, 110, 44, 36, 66,
  95, 67, 69, 95, 112, 108, 101, 105, 110, 44, 36, 65, 95, 67, 69, 95,
  112, 108, 101, 105, 110, 10, 45, 101, 110, 100, 105, 102, 10, 35, 10, 45,
  105, 102, 32, 123, 36, 67, 111, 110, 116, 111, 117, 114, 95, 99, 101, 114,
  99, 108, 101, 95, 101, 120, 116, 101, 114, 105, 101, 117, 114, 61, 61, 49,
  125, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36,
  99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 88,
  44, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110, 101,
  95, 89, 44, 36, 82, 97, 121, 111, 110, 95, 103, 114, 97, 110, 100, 95,
  99, 101, 114, 99, 108, 101, 44, 36, 82, 97, 121, 111, 110, 95, 103, 114,
  97, 110, 100, 95, 99, 101, 114, 99, 108, 101, 44, 48, 44, 49, 44, 48,
  120, 70, 70, 70, 70, 70, 70, 44, 36, 82, 95, 67, 69, 95, 99, 111,
  110, 116, 111, 117, 114, 44, 36, 86, 95, 67, 69, 95, 99, 111, 110, 116,
  111, 117, 114, 44, 36, 66, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117,
  114, 44, 36, 65, 95, 67, 69, 95, 99, 111, 110, 116, 111, 117, 114, 10,
  45, 101, 110, 100, 105, 102, 10, 35, 10, 45, 105, 102, 32, 123, 36, 82,
  101, 109, 112, 108, 105, 114, 95, 99, 101, 114, 99, 108, 101, 95, 105, 110,
  116, 101, 114, 105, 101, 117, 114, 61, 61, 49, 125, 10, 45, 101, 108, 108,
  105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 99, 101, 110, 116, 114, 101,
  95, 111, 114, 105, 103, 105, 110, 101, 95, 88, 44, 36, 99, 101, 110, 116,
  114, 101, 95, 111, 114, 105, 103, 105, 110, 101, 95, 89, 44, 36, 82, 97,
  121, 111, 110, 95, 112, 101, 116, 105, 116, 95, 99, 101, 114, 99, 108, 101,
  44, 36, 82, 97, 121, 111, 110, 95, 112, 101, 116, 105, 116, 95, 99, 101,
  114, 99, 108, 101, 44, 48, 44, 49, 44, 36, 82, 95, 67, 73, 95, 112,
  108, 101, 105, 110, 44, 36, 86, 95, 67, 73, 95, 112, 108, 101, 105, 110,
  44, 36, 66, 95, 67, 73, 95, 112, 108, 101, 105, 110, 44, 36, 65, 95,
  67, 73, 95, 112, 108, 101, 105, 110, 10, 45, 101, 110, 100, 105, 102, 10,
  35, 10, 45, 105, 102, 32, 123, 36, 67, 111, 110, 116, 111, 117, 114, 95,
  99, 101, 114, 99, 108, 101, 95, 105, 110, 116, 101, 114, 105, 101, 117, 114,
  61, 61, 49, 125, 10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49,
  93, 32, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103, 105, 110,
  101, 95, 88, 44, 36, 99, 101, 110, 116, 114, 101, 95, 111, 114, 105, 103,
  105, 110, 101, 95, 89, 44, 36, 82, 97, 121, 111, 110, 95, 112, 101, 116,
  105, 116, 95, 99, 101, 114, 99, 108, 101, 44, 36, 82, 97, 121, 111, 110,
  95, 112, 101, 116, 105, 116, 95, 99, 101, 114, 99, 108, 101, 44, 48, 44,
  49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 44, 36, 82, 95, 67, 73,
  95, 99, 111, 110, 116, 111, 117, 114, 44, 36, 86, 95, 67, 73, 95, 99,
  111, 110, 116, 111, 117, 114, 44, 36, 66, 95, 67, 73, 95, 99, 111, 110,
  116, 111, 117, 114, 44, 36, 65, 95, 67, 73, 95, 99, 111, 110, 116, 111,
  117, 114, 10, 45, 101, 110, 100, 105, 102, 10, 45, 97, 117, 116, 111, 99,
  114, 111, 112, 91, 45, 49, 93, 10, 45, 118, 101, 114, 98, 111, 115, 101,
  32, 43, 10, 116, 114, 97, 105, 116, 95, 101, 112, 97, 105, 115, 95, 115,
  97, 109, 106, 32, 58, 10, 35, 35, 32, 86, 97, 114, 105, 97, 98, 108,
  101, 115, 10, 45, 118, 101, 114, 98, 111, 115, 101, 32, 45, 10, 45, 105,
  102, 32, 123, 123, 36, 51, 45, 36, 49, 125, 61, 61, 48, 125, 32, 88,
  49, 61, 123, 36, 49, 45, 123, 36, 53, 47, 50, 125, 125, 32, 89, 49,
  61, 36, 50, 32, 88, 50, 61, 123, 36, 51, 45, 123, 36, 53, 47, 50,
  125, 125, 32, 89, 50, 61, 36, 52, 32, 88, 51, 61, 123, 36, 51, 43,
  123, 36, 53, 47, 50, 125, 125, 32, 89, 51, 61, 36, 52, 32, 88, 52,
  61, 123, 36, 49, 43, 123, 36, 53, 47, 50, 125, 125, 32, 89, 52, 61,
  36, 50, 10, 45, 101, 108, 115, 101, 10, 45, 105, 102, 32, 123, 123, 36,
  52, 45, 36, 50, 125, 61, 61, 48, 125, 32, 88, 49, 61, 36, 49, 32,
  89, 49, 61, 123, 36, 50, 43, 123, 36, 53, 47, 50, 125, 125, 32, 88,
  50, 61, 36, 51, 32, 89, 50, 61, 123, 36, 52, 43, 123, 36, 53, 47,
  50, 125, 125, 32, 88, 51, 61, 36, 51, 32, 89, 51, 61, 123, 36, 52,
  45, 123, 36, 53, 47, 50, 125, 125, 32, 88, 52, 61, 36, 49, 32, 89,
  52, 61, 123, 36, 50, 45, 123, 36, 53, 47, 50, 125, 125, 10, 45, 101,
  108, 115, 101, 32, 97, 110, 103, 108, 101, 95, 116, 114, 105, 97, 110, 103,
  108, 101, 61, 123, 123, 123, 112, 105, 125, 47, 50, 125, 45, 123, 97, 116,
  97, 110, 40, 123, 123, 36, 52, 45, 36, 50, 125, 47, 123, 36, 51, 45,
  36, 49, 125, 125, 41, 125, 125, 32, 88, 95, 116, 114, 105, 97, 110, 103,
  108, 101, 61, 123, 123, 36, 53, 47, 50, 125, 42, 123, 99, 111, 115, 40,
  36, 97, 110, 103, 108, 101, 95, 116, 114, 105, 97, 110, 103, 108, 101, 41,
  125, 125, 32, 89, 95, 116, 114, 105, 97, 110, 103, 108, 101, 61, 123, 123,
  36, 53, 47, 50, 125, 42, 123, 115, 105, 110, 40, 36, 97, 110, 103, 108,
  101, 95, 116, 114, 105, 97, 110, 103, 108, 101, 41, 125, 125, 10, 88, 49,
  61, 123, 36, 49, 45, 36, 88, 95, 116, 114, 105, 97, 110, 103, 108, 101,
  125, 32, 89, 49, 61, 123, 36, 50, 43, 36, 89, 95, 116, 114, 105, 97,
  110, 103, 108, 101, 125, 32, 88, 50, 61, 123, 36, 51, 45, 36, 88, 95,
  116, 114, 105, 97, 110, 103, 108, 101, 125, 32, 89, 50, 61, 123, 36, 52,
  43, 36, 89, 95, 116, 114, 105, 97, 110, 103, 108, 101, 125, 32, 88, 51,
  61, 123, 36, 51, 43, 36, 88, 95, 116, 114, 105, 97, 110, 103, 108, 101,
  125, 32, 89, 51, 61, 123, 36, 52, 45, 36, 89, 95, 116, 114, 105, 97,
  110, 103, 108, 101, 125, 32, 88, 52, 61, 123, 36, 49, 43, 36, 88, 95,
  116, 114, 105, 97, 110, 103, 108, 101, 125, 32, 89, 52, 61, 123, 36, 50,
  45, 36, 89, 95, 116, 114, 105, 97, 110, 103, 108, 101, 125, 10, 45, 101,
  110, 100, 105, 102, 10, 45, 101, 110, 100, 105, 102, 10, 45, 112, 111, 108,
  121, 103, 111, 110, 91, 45, 49, 93, 32, 52, 44, 36, 88, 49, 44, 36,
  89, 49, 44, 36, 88, 50, 44, 36, 89, 50, 44, 36, 88, 51, 44, 36,
  89, 51, 44, 36, 88, 52, 44, 36, 89, 52, 44, 49, 44, 36, 55, 44,
  36, 56, 44, 36, 57, 44, 36, 49, 48, 10, 45, 105, 102, 32, 123, 36,
  54, 61, 61, 49, 125, 32, 45, 99, 105, 114, 99, 108, 101, 91, 45, 49,
  93, 32, 36, 49, 44, 36, 50, 44, 123, 36, 53, 47, 50, 125, 44, 49,
  44, 36, 55, 44, 36, 56, 44, 36, 57, 44, 36, 49, 48, 32, 45, 99,
  105, 114, 99, 108, 101, 91, 45, 49, 93, 32, 36, 51, 44, 36, 52, 44,
  123, 36, 53, 47, 50, 125, 44, 49, 44, 36, 55, 44, 36, 56, 44, 36,
  57, 44, 36, 49, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 101,
  114, 98, 111, 115, 101, 32, 43, 10, 98, 97, 108, 108, 95, 109, 111, 100,
  105, 102, 105, 99, 97, 116, 105, 111, 110, 95, 115, 97, 109, 106, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 49, 61, 50, 53, 53, 125, 44,
  36, 123, 50, 61, 36, 49, 125, 44, 36, 123, 51, 61, 36, 50, 125, 44,
  36, 123, 52, 61, 48, 46, 55, 125, 44, 36, 123, 53, 61, 48, 46, 51,
  125, 44, 36, 123, 54, 61, 48, 46, 48, 56, 125, 44, 36, 123, 55, 61,
  48, 46, 48, 56, 125, 44, 36, 123, 56, 61, 50, 53, 53, 125, 44, 36,
  123, 57, 61, 36, 56, 125, 44, 36, 123, 49, 48, 61, 36, 56, 125, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 68, 114, 97, 119, 32, 98, 97,
  108, 108, 32, 115, 112, 114, 105, 116, 101, 32, 111, 110, 32, 105, 109, 97,
  103, 101, 36, 63, 44, 32, 119, 105, 116, 104, 32, 99, 111, 108, 111, 114,
  32, 40, 36, 49, 44, 36, 50, 44, 36, 51, 41, 32, 108, 105, 103, 104,
  116, 32, 88, 89, 32, 40, 36, 52, 44, 36, 53, 41, 32, 114, 97, 100,
  105, 117, 115, 32, 40, 36, 54, 44, 36, 55, 41, 99, 111, 108, 111, 114,
  32, 40, 36, 56, 44, 36, 57, 44, 36, 49, 48, 41, 32, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 116, 111, 95, 114, 103, 98, 97, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10,
  109, 119, 104, 61, 123, 109, 105, 110, 40, 119, 44, 104, 41, 125, 10, 45,
  115, 104, 32, 51, 44, 51, 32, 45, 102, 91, 45, 49, 93, 32, 48, 32,
  45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 108, 105, 112, 115, 101,
  32, 123, 48, 46, 53, 42, 36, 109, 119, 104, 125, 44, 123, 48, 46, 53,
  42, 36, 109, 119, 104, 125, 44, 123, 48, 46, 53, 42, 36, 109, 119, 104,
  45, 52, 125, 44, 123, 48, 46, 53, 42, 36, 109, 119, 104, 45, 52, 125,
  44, 49, 44, 49, 44, 36, 49, 44, 36, 50, 44, 36, 51, 44, 50, 53,
  53, 10, 45, 115, 104, 32, 48, 44, 50, 32, 45, 42, 91, 45, 49, 93,
  32, 39, 40, 36, 109, 119, 104, 43, 121, 45, 120, 41, 47, 40, 50, 42,
  119, 41, 39, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 108, 108,
  105, 112, 115, 101, 32, 123, 36, 109, 119, 104, 42, 36, 52, 125, 44, 123,
  36, 109, 119, 104, 42, 36, 53, 125, 44, 123, 36, 109, 119, 104, 42, 36,
  54, 125, 44, 123, 36, 109, 119, 104, 42, 36, 55, 125, 44, 49, 44, 123,
  109, 105, 110, 40, 36, 109, 119, 104, 47, 54, 52, 44, 49, 41, 125, 44,
  36, 56, 44, 36, 57, 44, 36, 49, 48, 44, 50, 53, 53, 10, 45, 115,
  104, 32, 48, 44, 50, 32, 45, 98, 91, 45, 49, 93, 32, 123, 48, 46,
  48, 50, 42, 36, 109, 119, 104, 125, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 115, 104, 32, 51, 44, 51, 32, 45, 42, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93,
  32, 51, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 115, 104, 32, 48,
  44, 50, 32, 45, 43, 91, 45, 49, 93, 32, 39, 105, 102, 40, 105, 38,
  38, 40, 33, 105, 40, 120, 45, 49, 41, 124, 124, 33, 105, 40, 120, 43,
  49, 41, 124, 124, 33, 105, 40, 120, 44, 121, 45, 49, 41, 124, 124, 33,
  105, 40, 120, 44, 121, 43, 49, 41, 41, 44, 105, 102, 40, 99, 61, 61,
  48, 44, 36, 49, 44, 105, 102, 40, 99, 61, 61, 49, 44, 36, 50, 44,
  36, 51, 41, 41, 47, 54, 44, 48, 41, 39, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48,
  95, 97, 108, 112, 104, 97, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119,
  111, 44, 32, 117, 115, 105, 110, 103, 32, 97, 108, 112, 104, 97, 32, 98,
  108, 101, 110, 100, 105, 110, 103, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50,
  41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93,
  10, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50,
  93, 44, 91, 45, 50, 93, 44, 49, 48, 48, 37, 44, 48, 44, 48, 44,
  48, 46, 53, 44, 48, 46, 53, 10, 45, 116, 111, 95, 99, 111, 108, 111,
  114, 109, 111, 100, 101, 91, 45, 50, 93, 32, 123, 97, 49, 61, 33, 40,
  64, 123, 45, 50, 44, 115, 125, 37, 50, 41, 59, 97, 50, 61, 33, 40,
  115, 37, 50, 41, 59, 109, 97, 120, 40, 64, 123, 45, 50, 44, 115, 125,
  45, 97, 49, 44, 115, 45, 97, 50, 41, 43, 97, 49, 125, 10, 45, 116,
  111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 91, 45, 49, 93, 32,
  123, 97, 61, 109, 97, 120, 40, 64, 123, 45, 50, 44, 115, 125, 44, 115,
  41, 59, 97, 43, 40, 97, 37, 50, 41, 125, 10, 45, 105, 102, 32, 123,
  64, 123, 45, 50, 44, 115, 125, 61, 61, 50, 124, 124, 64, 123, 45, 50,
  44, 115, 125, 61, 61, 52, 125, 10, 45, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 49, 53, 51, 48, 95, 97, 108, 112, 104, 97, 91, 45, 50, 93,
  32, 45, 95, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95,
  97, 108, 112, 104, 97, 91, 45, 49, 93, 10, 45, 115, 104, 91, 45, 49,
  93, 32, 123, 115, 45, 49, 125, 44, 123, 115, 45, 49, 125, 32, 45, 45,
  42, 91, 45, 51, 44, 45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 93,
  32, 45, 43, 91, 45, 51, 44, 45, 50, 93, 32, 45, 45, 91, 45, 50,
  44, 45, 49, 93, 10, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 123,
  115, 45, 50, 125, 32, 45, 115, 104, 91, 45, 50, 93, 32, 123, 64, 123,
  45, 50, 44, 115, 125, 45, 49, 125, 44, 123, 64, 123, 45, 50, 44, 115,
  125, 45, 49, 125, 10, 45, 109, 97, 120, 91, 45, 49, 93, 32, 49, 101,
  45, 49, 48, 32, 45, 47, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32,
  45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 109, 91, 45,
  50, 44, 45, 49, 93, 10, 45, 101, 108, 115, 101, 10, 45, 115, 104, 91,
  45, 49, 93, 32, 48, 44, 123, 115, 45, 50, 125, 32, 45, 115, 104, 91,
  45, 50, 93, 32, 123, 64, 123, 45, 50, 44, 115, 125, 45, 49, 125, 44,
  123, 64, 123, 45, 50, 44, 115, 125, 45, 49, 125, 32, 45, 45, 91, 45,
  50, 93, 32, 91, 45, 52, 93, 32, 45, 42, 91, 45, 50, 44, 45, 49,
  93, 32, 45, 47, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 109,
  91, 45, 49, 93, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 118, 32, 43, 10,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 97, 108,
  112, 104, 97, 32, 58, 10, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44,
  123, 115, 45, 50, 125, 32, 45, 115, 104, 91, 45, 50, 93, 32, 123, 64,
  123, 45, 50, 44, 115, 125, 45, 49, 125, 44, 123, 64, 123, 45, 50, 44,
  115, 125, 45, 49, 125, 32, 45, 109, 97, 120, 91, 45, 49, 93, 32, 49,
  101, 45, 49, 48, 32, 45, 47, 91, 45, 49, 93, 32, 50, 53, 53, 32,
  45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 97,
  118, 101, 114, 97, 103, 101, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119,
  111, 44, 32, 117, 115, 105, 110, 103, 32, 97, 118, 101, 114, 97, 103, 101,
  32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125,
  32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 45,
  116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48, 32, 45,
  114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48,
  46, 53, 44, 48, 46, 53, 32, 45, 43, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 47, 32, 50, 32, 45, 118, 32, 43, 10,
  99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 99, 111, 108,
  111, 114, 98, 117, 114, 110, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119,
  111, 44, 32, 117, 115, 105, 110, 103, 32, 99, 111, 108, 111, 114, 98, 117,
  114, 110, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50,
  41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93,
  10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48,
  32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 45, 91, 45, 50, 93, 32,
  50, 53, 53, 32, 45, 43, 91, 45, 49, 93, 32, 48, 46, 49, 32, 45,
  47, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 42,
  32, 50, 53, 54, 32, 45, 43, 32, 50, 53, 53, 32, 45, 99, 32, 48,
  44, 50, 53, 53, 32, 45, 118, 32, 43, 10, 99, 111, 109, 112, 111, 115,
  101, 95, 49, 53, 51, 48, 95, 100, 97, 114, 107, 101, 110, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 99, 111, 109, 112, 111, 115, 101,
  95, 49, 53, 51, 48, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119,
  111, 45, 98, 121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32,
  100, 97, 114, 107, 101, 110, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40,
  64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62,
  43, 49, 125, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111,
  100, 101, 32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 109, 105,
  110, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95,
  100, 105, 102, 102, 101, 114, 101, 110, 99, 101, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53,
  51, 48, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98,
  121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 100, 105, 102,
  102, 101, 114, 101, 110, 99, 101, 32, 109, 111, 100, 101, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116,
  40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36,
  62, 43, 49, 125, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109,
  111, 100, 101, 32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50,
  93, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 45,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 97, 98,
  115, 32, 45, 118, 32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 49,
  53, 51, 48, 95, 100, 105, 118, 105, 100, 101, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53,
  51, 48, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98,
  121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 100, 105, 118,
  105, 100, 101, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47,
  50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125,
  93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32,
  48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 42, 91, 45, 50, 93,
  32, 50, 53, 54, 32, 45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 47,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 99, 32,
  48, 44, 50, 53, 53, 32, 45, 118, 32, 43, 10, 99, 111, 109, 112, 111,
  115, 101, 95, 49, 53, 51, 48, 95, 100, 111, 100, 103, 101, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 99, 111, 109, 112, 111, 115, 101,
  95, 49, 53, 51, 48, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119,
  111, 45, 98, 121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32,
  100, 111, 100, 103, 101, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64,
  35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43,
  49, 125, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100,
  101, 32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44,
  48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 45, 91, 45,
  49, 93, 32, 50, 53, 53, 46, 49, 32, 45, 47, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 42, 32, 45, 50, 53, 54, 32,
  45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 118, 32, 43, 10, 99, 111,
  109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 101, 100, 103, 101, 115,
  32, 58, 32, 45, 99, 104, 101, 99, 107, 32, 123, 36, 49, 62, 61, 48,
  125, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 99, 111, 109, 112, 111,
  115, 101, 95, 49, 53, 51, 48, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  117, 115, 105, 110, 103, 32, 101, 100, 103, 101, 32, 109, 111, 100, 101, 44,
  32, 119, 105, 116, 104, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115, 115,
  32, 36, 49, 46, 34, 10, 45, 105, 102, 32, 123, 64, 35, 62, 49, 125,
  32, 45, 118, 32, 45, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45, 114,
  91, 94, 48, 93, 32, 91, 48, 93, 44, 48, 44, 48, 44, 48, 46, 53,
  44, 48, 46, 53, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32,
  45, 108, 91, 36, 62, 93, 10, 45, 45, 103, 114, 97, 100, 105, 101, 110,
  116, 95, 110, 111, 114, 109, 32, 45, 43, 91, 45, 49, 93, 32, 49, 32,
  45, 98, 91, 45, 49, 93, 32, 36, 49, 32, 45, 110, 91, 45, 49, 93,
  32, 49, 44, 49, 48, 32, 45, 115, 113, 114, 91, 45, 49, 93, 32, 45,
  115, 91, 45, 50, 93, 32, 99, 32, 45, 42, 91, 45, 52, 45, 45, 50,
  93, 32, 91, 45, 49, 93, 32, 45, 97, 91, 45, 52, 45, 45, 49, 93,
  32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  114, 91, 94, 48, 93, 32, 91, 48, 93, 44, 48, 44, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 32, 45, 43, 32, 45, 115, 91, 45, 49, 93, 32,
  99, 32, 45, 47, 91, 45, 52, 45, 45, 50, 93, 32, 91, 45, 49, 93,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 97, 91, 45, 51, 45, 45,
  49, 93, 32, 99, 32, 45, 118, 32, 43, 32, 45, 101, 110, 100, 105, 102,
  10, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 101, 120,
  99, 108, 117, 115, 105, 111, 110, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32,
  105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116,
  119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 101, 120, 99, 108, 117, 115,
  105, 111, 110, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47,
  50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125,
  93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32,
  48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 45, 42, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 32, 45, 47, 91, 45, 49, 93, 32, 45, 49,
  50, 56, 32, 45, 43, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 49,
  53, 51, 48, 95, 102, 97, 100, 101, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 117, 115, 105, 110, 103, 32, 102,
  97, 100, 105, 110, 103, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 91, 94, 48, 93, 32, 64, 123, 45, 109, 97, 120, 95,
  119, 104, 100, 125, 44, 49, 48, 48, 37, 44, 51, 10, 45, 114, 91, 49,
  45, 45, 50, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  48, 48, 37, 44, 64, 123, 45, 109, 97, 120, 95, 115, 125, 32, 45, 99,
  104, 97, 110, 110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 10, 45, 114,
  101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 45, 45, 45,
  91, 45, 49, 93, 32, 36, 62, 32, 45, 97, 98, 115, 91, 45, 49, 93,
  32, 45, 45, 91, 45, 49, 93, 32, 49, 32, 45, 42, 91, 45, 49, 93,
  32, 45, 49, 32, 45, 109, 97, 120, 91, 45, 49, 93, 32, 48, 32, 45,
  42, 91, 36, 62, 44, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45,
  114, 109, 91, 45, 49, 93, 32, 45, 43, 32, 45, 118, 32, 43, 10, 99,
  111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 102, 114, 101, 101,
  122, 101, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 99, 111,
  109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32, 105, 109, 97, 103, 101,
  36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111, 44, 32, 117,
  115, 105, 110, 103, 32, 102, 114, 101, 101, 122, 101, 32, 109, 111, 100, 101,
  46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36,
  62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 45, 116, 111, 95, 99, 111,
  108, 111, 114, 109, 111, 100, 101, 32, 48, 32, 45, 114, 91, 45, 49, 93,
  32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46,
  53, 32, 45, 45, 91, 45, 50, 93, 32, 50, 53, 53, 32, 45, 115, 113,
  114, 91, 45, 50, 93, 32, 45, 43, 91, 45, 49, 93, 32, 48, 46, 49,
  32, 45, 47, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 45, 32, 50, 53, 53, 32, 45, 42, 32, 45, 49, 32, 45, 99, 32,
  48, 44, 50, 53, 53, 32, 45, 118, 32, 43, 10, 99, 111, 109, 112, 111,
  115, 101, 95, 49, 53, 51, 48, 95, 103, 114, 97, 105, 110, 101, 120, 116,
  114, 97, 99, 116, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32, 105, 109, 97,
  103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111, 44,
  32, 117, 115, 105, 110, 103, 32, 103, 114, 97, 105, 110, 32, 101, 120, 116,
  114, 97, 99, 116, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35,
  47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49,
  125, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101,
  32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48,
  44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 45, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 43, 32, 49, 50, 56,
  32, 45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 118, 32, 43, 10, 99,
  111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 103, 114, 97, 105,
  110, 109, 101, 114, 103, 101, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93,
  32, 34, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119,
  111, 44, 32, 117, 115, 105, 110, 103, 32, 103, 114, 97, 105, 110, 32, 109,
  101, 114, 103, 101, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35,
  47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49,
  125, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101,
  32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48,
  44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 43, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 45, 32, 49, 50, 56,
  32, 45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 118, 32, 43, 10, 99,
  111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 104, 97, 114, 100,
  108, 105, 103, 104, 116, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111,
  44, 32, 117, 115, 105, 110, 103, 32, 104, 97, 114, 100, 32, 108, 105, 103,
  104, 116, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50,
  41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93,
  10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48,
  32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45, 103, 101, 91, 45, 49,
  93, 32, 49, 50, 56, 32, 45, 45, 42, 91, 45, 51, 93, 32, 91, 45,
  50, 93, 32, 45, 47, 91, 45, 49, 93, 32, 49, 50, 56, 10, 45, 45,
  91, 45, 52, 44, 45, 51, 93, 32, 50, 53, 53, 32, 45, 42, 91, 45,
  52, 44, 45, 51, 93, 32, 45, 47, 91, 45, 51, 93, 32, 49, 50, 56,
  32, 45, 45, 91, 45, 51, 93, 32, 50, 53, 53, 32, 45, 42, 91, 45,
  51, 93, 32, 45, 49, 10, 45, 42, 91, 45, 51, 93, 32, 91, 45, 50,
  93, 32, 45, 42, 91, 45, 50, 93, 32, 45, 49, 32, 45, 43, 91, 45,
  50, 93, 32, 49, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  43, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95,
  104, 117, 101, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 99,
  111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32, 105, 109, 97, 103,
  101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111, 44, 32,
  117, 115, 105, 110, 103, 32, 104, 117, 101, 32, 109, 111, 100, 101, 46, 34,
  10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105,
  110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44,
  123, 36, 62, 43, 49, 125, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111,
  114, 109, 111, 100, 101, 32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91,
  45, 50, 93, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32,
  45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 115, 104, 32, 48, 44, 50,
  10, 45, 114, 103, 98, 50, 104, 115, 118, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 115, 104, 91, 45, 50, 93, 32, 48, 44, 48, 32, 45, 106, 91,
  45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 53, 44,
  45, 51, 44, 45, 49, 93, 32, 45, 104, 115, 118, 50, 114, 103, 98, 91,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 99, 111, 109,
  112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 105, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 105, 111, 110, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32,
  105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116,
  119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 105, 110, 116, 101, 114, 112,
  111, 108, 97, 116, 105, 111, 110, 32, 109, 111, 100, 101, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116,
  40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36,
  62, 43, 49, 125, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109,
  111, 100, 101, 32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50,
  93, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 42,
  32, 48, 46, 48, 49, 50, 50, 55, 49, 56, 52, 54, 32, 45, 99, 111,
  115, 32, 45, 47, 32, 45, 52, 32, 45, 43, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 43, 32, 48, 46, 53, 32, 45, 42,
  32, 50, 53, 54, 32, 45, 118, 32, 43, 10, 99, 111, 109, 112, 111, 115,
  101, 95, 49, 53, 51, 48, 95, 108, 105, 103, 104, 116, 101, 110, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 99, 111, 109, 112, 111, 115,
  101, 95, 49, 53, 51, 48, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116,
  119, 111, 45, 98, 121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103,
  32, 108, 105, 103, 104, 116, 101, 110, 32, 109, 111, 100, 101, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110,
  116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123,
  36, 62, 43, 49, 125, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114,
  109, 111, 100, 101, 32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45,
  109, 97, 120, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 118, 32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51,
  48, 95, 108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 99, 111, 109, 112, 111, 115, 101, 95, 49,
  53, 51, 48, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45,
  98, 121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 108, 105,
  103, 104, 116, 110, 101, 115, 115, 32, 109, 111, 100, 101, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116,
  40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36,
  62, 43, 49, 125, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109,
  111, 100, 101, 32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50,
  93, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 116,
  111, 95, 114, 103, 98, 97, 32, 45, 115, 104, 32, 48, 44, 50, 10, 45,
  114, 103, 98, 50, 108, 97, 98, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  115, 104, 91, 45, 50, 93, 32, 48, 44, 48, 32, 45, 106, 91, 45, 50,
  93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 44, 48, 44, 48, 32, 45,
  114, 109, 91, 45, 53, 44, 45, 51, 44, 45, 49, 93, 32, 45, 108, 97,
  98, 50, 114, 103, 98, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95,
  108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 58, 10, 45, 101, 91, 94,
  45, 49, 93, 32, 34, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51,
  48, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121,
  45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 108, 117, 109, 105,
  110, 97, 110, 99, 101, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64,
  35, 47, 50, 41, 125, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109,
  111, 100, 101, 91, 45, 50, 44, 45, 49, 93, 32, 48, 32, 45, 114, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 46, 53,
  44, 48, 46, 53, 32, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 50,
  44, 45, 49, 93, 32, 45, 115, 104, 91, 45, 50, 44, 45, 49, 93, 32,
  48, 44, 50, 10, 45, 114, 103, 98, 50, 121, 99, 98, 99, 114, 91, 45,
  50, 44, 45, 49, 93, 32, 45, 115, 104, 91, 45, 50, 93, 32, 48, 44,
  48, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44, 48, 44,
  48, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 53, 44, 45, 51, 44,
  45, 49, 93, 32, 45, 121, 99, 98, 99, 114, 50, 114, 103, 98, 91, 45,
  49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 109, 118, 91, 45,
  49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 109, 101, 100,
  105, 97, 110, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 99,
  111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32, 105, 109, 97, 103,
  101, 36, 63, 32, 117, 115, 105, 110, 103, 32, 109, 101, 100, 105, 97, 110,
  32, 109, 111, 100, 101, 46, 34, 10, 45, 105, 102, 32, 123, 64, 35, 61,
  61, 49, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 118, 32, 45, 32, 45, 114, 91, 94, 48, 93, 32, 91,
  48, 93, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45,
  97, 32, 122, 32, 45, 112, 101, 114, 109, 117, 116, 101, 32, 122, 120, 121,
  99, 32, 45, 115, 32, 121, 44, 45, 54, 52, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 10, 45, 114, 32,
  49, 48, 48, 37, 44, 123, 119, 42, 49, 48, 48, 125, 37, 10, 45, 115,
  32, 122, 32, 45, 109, 101, 100, 105, 97, 110, 32, 123, 119, 125, 32, 119,
  61, 123, 119, 125, 32, 45, 99, 111, 108, 117, 109, 110, 115, 32, 123, 105,
  110, 116, 40, 119, 47, 50, 41, 125, 32, 45, 114, 32, 49, 44, 123, 104,
  47, 36, 119, 125, 32, 45, 97, 32, 122, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 97, 32, 121, 32, 45, 112, 101, 114, 109,
  117, 116, 101, 32, 121, 122, 120, 99, 32, 45, 118, 32, 43, 10, 99, 111,
  109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 109, 117, 108, 116, 105,
  112, 108, 121, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 99,
  111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32, 105, 109, 97, 103,
  101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111, 44, 32,
  117, 115, 105, 110, 103, 32, 109, 117, 108, 116, 105, 112, 108, 121, 32, 109,
  111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45,
  108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 45, 116, 111,
  95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48, 32, 45, 114, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 46, 53,
  44, 48, 46, 53, 32, 45, 42, 10, 45, 101, 110, 100, 108, 32, 45, 100,
  111, 110, 101, 32, 45, 47, 32, 50, 53, 53, 32, 45, 118, 32, 43, 10,
  99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 110, 101, 103,
  97, 116, 105, 111, 110, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111,
  44, 32, 117, 115, 105, 110, 103, 32, 110, 101, 103, 97, 116, 105, 111, 110,
  32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125,
  32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 45,
  116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48, 32, 45,
  114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48,
  46, 53, 44, 48, 46, 53, 32, 45, 43, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 45, 32, 50, 53, 53, 32, 45, 97, 98,
  115, 32, 45, 45, 32, 50, 53, 53, 32, 45, 42, 32, 45, 49, 32, 45,
  118, 32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48,
  95, 111, 118, 101, 114, 108, 97, 121, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45,
  116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 111, 118, 101, 114, 108,
  97, 121, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50,
  41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93,
  10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48,
  32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45, 103, 101, 91, 45, 50,
  93, 32, 49, 50, 56, 10, 45, 45, 42, 91, 45, 51, 93, 32, 91, 45,
  50, 93, 32, 45, 47, 91, 45, 49, 93, 32, 49, 50, 56, 10, 45, 45,
  91, 45, 52, 44, 45, 51, 93, 32, 50, 53, 53, 32, 45, 42, 91, 45,
  52, 44, 45, 51, 93, 32, 45, 47, 91, 45, 51, 93, 32, 49, 50, 56,
  32, 45, 45, 91, 45, 51, 93, 32, 50, 53, 53, 32, 45, 42, 91, 45,
  51, 93, 32, 45, 49, 10, 45, 42, 91, 45, 51, 93, 32, 91, 45, 50,
  93, 32, 45, 42, 91, 45, 50, 93, 32, 45, 49, 32, 45, 43, 91, 45,
  50, 93, 32, 49, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  43, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95,
  114, 101, 102, 108, 101, 99, 116, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32,
  105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116,
  119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 114, 101, 102, 108, 101, 99,
  116, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114,
  101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41,
  125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10,
  45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48, 32,
  45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44,
  48, 46, 53, 44, 48, 46, 53, 32, 45, 115, 113, 114, 91, 45, 50, 93,
  32, 45, 45, 91, 45, 49, 93, 32, 50, 53, 53, 46, 49, 32, 45, 47,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 42, 32,
  45, 49, 32, 45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 118, 32, 43,
  10, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 114, 103,
  98, 97, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 99, 111,
  109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32, 105, 109, 97, 103, 101,
  36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111, 44, 32, 117,
  115, 105, 110, 103, 32, 97, 108, 112, 104, 97, 32, 98, 108, 101, 110, 100,
  105, 110, 103, 46, 34, 10, 45, 118, 32, 45, 32, 45, 116, 111, 95, 114,
  103, 98, 91, 48, 45, 45, 49, 58, 50, 93, 32, 45, 99, 111, 109, 112,
  111, 115, 101, 95, 49, 53, 51, 48, 95, 97, 108, 112, 104, 97, 32, 45,
  118, 32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48,
  95, 115, 97, 116, 117, 114, 97, 116, 105, 111, 110, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 99, 111, 109, 112, 111, 115, 101, 95, 49,
  53, 51, 48, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45,
  98, 121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 115, 97,
  116, 117, 114, 97, 116, 105, 111, 110, 32, 109, 111, 100, 101, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110,
  116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123,
  36, 62, 43, 49, 125, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114,
  109, 111, 100, 101, 32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45,
  116, 111, 95, 114, 103, 98, 97, 32, 45, 115, 104, 32, 48, 44, 50, 10,
  45, 114, 103, 98, 50, 104, 115, 118, 91, 45, 50, 44, 45, 49, 93, 32,
  45, 115, 104, 91, 45, 50, 93, 32, 49, 44, 49, 32, 45, 106, 91, 45,
  50, 93, 32, 91, 45, 49, 93, 44, 48, 44, 48, 44, 48, 44, 49, 32,
  45, 114, 109, 91, 45, 53, 44, 45, 51, 44, 45, 49, 93, 32, 45, 104,
  115, 118, 50, 114, 103, 98, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45,
  49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  118, 32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48,
  95, 115, 99, 114, 101, 101, 110, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32,
  105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116,
  119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 115, 99, 114, 101, 101, 110,
  32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125,
  32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 45,
  116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48, 32, 45,
  114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48,
  46, 53, 44, 48, 46, 53, 32, 45, 45, 32, 50, 53, 53, 32, 45, 42,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 47, 32,
  50, 53, 54, 32, 45, 45, 32, 50, 53, 53, 32, 45, 42, 32, 45, 49,
  32, 45, 118, 32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53,
  51, 48, 95, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97, 103, 101, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 99, 111, 109, 112, 111,
  115, 101, 95, 49, 53, 51, 48, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  116, 119, 111, 45, 98, 121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110,
  103, 32, 115, 104, 97, 112, 101, 32, 97, 118, 101, 114, 97, 103, 101, 32,
  109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32,
  45, 108, 91, 45, 50, 44, 45, 49, 93, 32, 110, 109, 61, 64, 123, 48,
  44, 110, 125, 10, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 45, 49,
  93, 32, 48, 32, 45, 103, 101, 91, 45, 49, 93, 32, 53, 48, 37, 32,
  45, 108, 97, 98, 101, 108, 95, 102, 103, 91, 45, 49, 93, 32, 48, 32,
  110, 98, 61, 123, 105, 77, 43, 49, 125, 32, 45, 42, 91, 45, 49, 93,
  32, 50, 53, 54, 10, 45, 114, 118, 91, 45, 50, 44, 45, 49, 93, 32,
  109, 61, 123, 105, 109, 125, 32, 77, 61, 123, 105, 77, 125, 32, 45, 110,
  91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45, 115, 91, 45, 49,
  93, 32, 99, 32, 45, 43, 91, 94, 48, 93, 32, 91, 48, 93, 10, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49, 125, 10, 45, 104,
  105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 49, 93, 32, 123, 36, 110,
  98, 42, 50, 53, 54, 125, 44, 48, 44, 123, 36, 110, 98, 42, 50, 53,
  54, 45, 49, 125, 10, 45, 105, 91, 45, 50, 93, 32, 50, 53, 54, 44,
  49, 44, 49, 44, 49, 44, 39, 120, 39, 32, 45, 114, 91, 45, 50, 93,
  32, 123, 119, 125, 44, 49, 44, 49, 44, 49, 44, 48, 44, 50, 32, 45,
  42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 114, 91, 45, 50,
  44, 45, 49, 93, 32, 36, 110, 98, 44, 49, 44, 49, 44, 49, 44, 50,
  32, 45, 109, 97, 120, 91, 45, 49, 93, 32, 49, 32, 45, 47, 91, 45,
  50, 44, 45, 49, 93, 10, 45, 109, 118, 91, 45, 49, 93, 32, 49, 32,
  45, 100, 111, 110, 101, 10, 45, 47, 91, 48, 93, 32, 50, 53, 54, 32,
  45, 97, 91, 94, 48, 93, 32, 99, 32, 45, 42, 91, 45, 49, 93, 32,
  123, 40, 36, 77, 45, 36, 109, 41, 47, 50, 53, 54, 125, 32, 45, 43,
  91, 45, 49, 93, 32, 36, 109, 32, 45, 112, 111, 105, 110, 116, 91, 45,
  49, 93, 32, 48, 44, 48, 44, 48, 44, 49, 44, 48, 32, 45, 109, 97,
  112, 91, 48, 93, 32, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32, 45, 101, 110, 100,
  108, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110,
  101, 32, 45, 118, 32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 49,
  53, 51, 48, 95, 115, 111, 102, 116, 108, 105, 103, 104, 116, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 99, 111, 109, 112, 111, 115, 101,
  95, 49, 53, 51, 48, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119,
  111, 45, 98, 121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32,
  115, 111, 102, 116, 32, 108, 105, 103, 104, 116, 32, 109, 111, 100, 101, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62,
  44, 123, 36, 62, 43, 49, 125, 93, 10, 45, 116, 111, 95, 99, 111, 108,
  111, 114, 109, 111, 100, 101, 32, 48, 32, 45, 114, 91, 45, 49, 93, 32,
  91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53,
  32, 45, 47, 32, 50, 53, 54, 32, 45, 45, 42, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 32, 45, 42, 91, 45, 49, 93, 32, 50, 32, 45, 115,
  113, 114, 91, 45, 51, 93, 32, 45, 42, 91, 45, 50, 93, 32, 91, 45,
  51, 93, 32, 45, 42, 91, 45, 50, 93, 32, 45, 50, 32, 45, 43, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 42, 32, 50,
  53, 54, 32, 45, 118, 32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95,
  49, 53, 51, 48, 95, 115, 116, 97, 109, 112, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53,
  51, 48, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98,
  121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 115, 116, 97,
  109, 112, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50,
  41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93,
  10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48,
  32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 42, 91, 45, 49, 93, 32,
  50, 32, 45, 43, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 45, 32, 50, 53, 53, 32, 45, 99, 32, 48, 44, 50, 53, 53,
  32, 45, 118, 32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53,
  51, 48, 95, 118, 97, 108, 117, 101, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45,
  116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 118, 97, 108, 117, 101,
  32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125,
  32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 45,
  116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48, 32, 45,
  114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48,
  46, 53, 44, 48, 46, 53, 32, 45, 116, 111, 95, 114, 103, 98, 97, 32,
  45, 115, 104, 32, 48, 44, 50, 10, 45, 114, 103, 98, 50, 104, 115, 118,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 115, 104, 91, 45, 50, 93, 32,
  50, 44, 50, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44,
  48, 44, 48, 44, 48, 44, 50, 32, 45, 114, 109, 91, 45, 53, 44, 45,
  51, 44, 45, 49, 93, 32, 45, 104, 115, 118, 50, 114, 103, 98, 91, 45,
  49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 99, 111, 109, 112,
  111, 115, 101, 95, 49, 53, 51, 48, 95, 120, 111, 114, 32, 58, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 99, 111, 109, 112, 111, 115, 101, 95,
  49, 53, 51, 48, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111,
  45, 98, 121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 120,
  111, 114, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50,
  41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93,
  10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48,
  32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 120, 111, 114, 10, 45, 101,
  110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 95,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51,
  48, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116,
  40, 64, 35, 47, 50, 41, 125, 32, 45, 45, 99, 111, 109, 112, 111, 115,
  101, 95, 49, 53, 51, 48, 95, 36, 49, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 114, 109, 91, 45, 51, 93, 32, 45, 116, 111, 95, 114, 103, 98,
  97, 91, 45, 49, 93, 32, 45, 115, 104, 91, 45, 49, 93, 32, 51, 44,
  51, 32, 45, 42, 91, 45, 49, 93, 32, 36, 50, 32, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51,
  48, 95, 97, 108, 112, 104, 97, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 95,
  103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101,
  114, 115, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110,
  116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 114, 118, 91, 123, 50, 42,
  36, 62, 125, 44, 123, 50, 42, 36, 62, 43, 49, 125, 93, 32, 45, 100,
  111, 110, 101, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 49, 53, 51, 48, 95, 97, 108, 112, 104, 97, 32, 58, 10, 45, 105,
  102, 32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95,
  114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110,
  116, 40, 64, 35, 47, 50, 41, 125, 10, 45, 116, 111, 95, 114, 103, 98,
  97, 91, 45, 49, 93, 32, 45, 115, 104, 91, 45, 49, 93, 32, 51, 44,
  51, 32, 45, 42, 91, 45, 49, 93, 32, 36, 49, 32, 45, 114, 109, 91,
  45, 49, 93, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51,
  48, 95, 97, 108, 112, 104, 97, 91, 45, 50, 44, 45, 49, 93, 10, 45,
  109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48,
  95, 97, 118, 101, 114, 97, 103, 101, 32, 58, 10, 45, 105, 102, 32, 36,
  123, 50, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118,
  101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 49, 53, 51, 48, 32, 97, 118, 101, 114, 97, 103, 101, 44, 36, 49,
  10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53,
  51, 48, 95, 99, 111, 108, 111, 114, 98, 117, 114, 110, 32, 58, 10, 45,
  105, 102, 32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112,
  95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 49, 53, 51, 48, 32, 99, 111, 108, 111, 114, 98,
  117, 114, 110, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 49, 53, 51, 48, 95, 100, 97, 114, 107, 101, 110, 32,
  58, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103,
  105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114,
  115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95,
  99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32, 100, 97, 114,
  107, 101, 110, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 49, 53, 51, 48, 95, 100, 105, 102, 102, 101, 114, 101,
  110, 99, 101, 32, 58, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125,
  32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108,
  97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111,
  95, 114, 103, 98, 32, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 49, 53, 51, 48, 32, 100, 105, 102, 102, 101, 114, 101,
  110, 99, 101, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 49, 53, 51, 48, 95, 100, 105, 118, 105, 100, 101, 32,
  58, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103,
  105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114,
  115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95,
  99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32, 100, 105, 118,
  105, 100, 101, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 49, 53, 51, 48, 95, 100, 111, 100, 103, 101, 32, 58,
  10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103, 105,
  109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32, 100, 111, 100, 103,
  101, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 49, 53, 51, 48, 95, 101, 100, 103, 101, 115, 32, 58, 10, 45,
  105, 102, 32, 36, 123, 51, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112,
  95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105,
  110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 45, 99, 111, 109, 112,
  111, 115, 101, 95, 49, 53, 51, 48, 95, 101, 100, 103, 101, 115, 91, 45,
  50, 44, 45, 49, 93, 32, 36, 50, 32, 45, 114, 109, 91, 45, 51, 93,
  32, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 32, 45, 115,
  104, 91, 45, 49, 93, 32, 51, 44, 51, 32, 45, 42, 91, 45, 49, 93,
  32, 36, 49, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 99, 111, 109,
  112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 97, 108, 112, 104, 97, 91,
  45, 50, 44, 45, 49, 93, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48,
  32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 49, 53, 51, 48, 95, 101, 120, 99, 108, 117, 115, 105,
  111, 110, 32, 58, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125, 32,
  45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97,
  121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95,
  114, 103, 98, 32, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 49, 53, 51, 48, 32, 101, 120, 99, 108, 117, 115, 105, 111,
  110, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 49, 53, 51, 48, 95, 102, 97, 100, 101, 32, 58, 10, 45, 105,
  102, 32, 123, 64, 35, 61, 61, 49, 125, 32, 45, 114, 101, 116, 117, 114,
  110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 99, 111, 108,
  111, 114, 109, 111, 100, 101, 32, 52, 10, 45, 105, 102, 32, 123, 36, 49,
  61, 61, 48, 125, 32, 91, 48, 93, 44, 91, 48, 93, 44, 49, 44, 49,
  44, 34, 36, 49, 48, 34, 10, 45, 101, 108, 115, 101, 32, 45, 95, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48,
  95, 102, 97, 100, 101, 36, 49, 32, 36, 55, 44, 36, 56, 44, 36, 57,
  32, 45, 114, 91, 45, 49, 93, 32, 91, 48, 93, 44, 91, 48, 93, 44,
  49, 44, 49, 44, 51, 10, 45, 101, 110, 100, 105, 102, 10, 45, 110, 91,
  45, 49, 93, 32, 123, 45, 40, 64, 35, 45, 50, 41, 42, 36, 51, 125,
  44, 123, 40, 64, 35, 45, 50, 41, 42, 40, 49, 43, 36, 51, 41, 125,
  10, 45, 45, 91, 45, 49, 93, 32, 123, 36, 50, 42, 40, 49, 43, 36,
  51, 41, 42, 40, 64, 35, 45, 50, 41, 125, 10, 45, 99, 91, 45, 49,
  93, 32, 48, 44, 123, 64, 35, 45, 50, 125, 10, 45, 105, 102, 32, 36,
  54, 32, 45, 114, 118, 91, 94, 45, 49, 93, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 105, 102, 32, 36, 53, 32, 45, 114, 111, 117, 110, 100, 91,
  45, 49, 93, 32, 49, 10, 45, 101, 108, 115, 101, 32, 45, 114, 111, 117,
  110, 100, 105, 102, 121, 91, 45, 49, 93, 32, 36, 52, 10, 45, 101, 110,
  100, 105, 102, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51,
  48, 95, 102, 97, 100, 101, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10,
  95, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53,
  51, 48, 95, 102, 97, 100, 101, 49, 32, 58, 32, 91, 48, 93, 44, 91,
  48, 93, 44, 49, 44, 49, 44, 34, 97, 61, 36, 49, 42, 112, 105, 47,
  50, 59, 32, 120, 42, 99, 111, 115, 40, 97, 41, 32, 43, 32, 121, 42,
  115, 105, 110, 40, 97, 41, 34, 10, 95, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 102, 97, 100, 101, 50,
  32, 58, 32, 91, 48, 93, 44, 91, 48, 93, 44, 49, 44, 49, 44, 48,
  32, 45, 61, 91, 45, 49, 93, 32, 49, 44, 123, 40, 36, 49, 43, 49,
  41, 42, 53, 48, 125, 37, 44, 123, 40, 36, 50, 43, 49, 41, 42, 53,
  48, 125, 37, 32, 45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49,
  93, 32, 49, 10, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 49, 53, 51, 48, 95, 102, 97, 100, 101, 51, 32, 58, 32, 91,
  48, 93, 44, 91, 48, 93, 44, 49, 44, 49, 44, 48, 32, 45, 61, 91,
  45, 49, 93, 32, 49, 44, 123, 40, 36, 49, 43, 49, 41, 42, 53, 48,
  125, 37, 44, 123, 40, 36, 50, 43, 49, 41, 42, 53, 48, 125, 37, 32,
  45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32,
  45, 42, 91, 45, 49, 93, 32, 123, 48, 46, 48, 49, 43, 36, 51, 47,
  50, 125, 32, 45, 99, 111, 115, 91, 45, 49, 93, 10, 95, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 102,
  97, 100, 101, 52, 32, 58, 32, 91, 48, 93, 44, 91, 48, 93, 44, 49,
  44, 49, 44, 34, 40, 40, 120, 45, 119, 42, 40, 36, 49, 43, 48, 46,
  53, 41, 41, 42, 40, 121, 45, 104, 42, 40, 36, 50, 43, 48, 46, 53,
  41, 41, 41, 37, 40, 48, 46, 50, 42, 119, 42, 104, 42, 40, 49, 46,
  48, 48, 49, 43, 36, 51, 41, 41, 34, 10, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 102, 114, 101, 101,
  122, 101, 32, 58, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125, 32,
  45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97,
  121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32,
  102, 114, 101, 101, 122, 101, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 103, 114, 97, 105,
  110, 101, 120, 116, 114, 97, 99, 116, 32, 58, 10, 45, 105, 102, 32, 36,
  123, 50, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118,
  101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 49, 53, 51, 48, 32, 103, 114, 97, 105, 110, 101, 120, 116, 114, 97,
  99, 116, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 49, 53, 51, 48, 95, 103, 114, 97, 105, 110, 109, 101, 114,
  103, 101, 32, 58, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125, 32,
  45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97,
  121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32,
  103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 44, 36, 49, 10, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95,
  104, 97, 114, 100, 108, 105, 103, 104, 116, 32, 58, 10, 45, 105, 102, 32,
  36, 123, 50, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101,
  118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 49, 53, 51, 48, 32, 104, 97, 114, 100, 108, 105, 103, 104, 116,
  44, 36, 49, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 49, 53, 51, 48, 95, 104, 117, 101, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 50, 61, 48, 125, 10, 45, 105, 102, 32, 36, 123, 50,
  61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114,
  116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 49,
  53, 51, 48, 32, 104, 117, 101, 44, 36, 49, 10, 103, 105, 109, 112, 95,
  99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 105, 110, 116,
  101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 32, 58, 10, 45, 105, 102,
  32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114,
  101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 49, 53, 51, 48, 32, 105, 110, 116, 101, 114, 112, 111, 108,
  97, 116, 105, 111, 110, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 108, 105, 103, 104, 116,
  101, 110, 32, 58, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125, 32,
  45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97,
  121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32,
  108, 105, 103, 104, 116, 101, 110, 44, 36, 49, 10, 103, 105, 109, 112, 95,
  99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 108, 105, 103,
  104, 116, 110, 101, 115, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 50, 61, 48, 125, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125,
  32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108,
  97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48,
  32, 108, 105, 103, 104, 116, 110, 101, 115, 115, 44, 36, 49, 10, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95,
  108, 117, 109, 105, 110, 97, 110, 99, 101, 32, 58, 32, 45, 115, 107, 105,
  112, 32, 36, 123, 50, 61, 48, 125, 10, 45, 105, 102, 32, 36, 123, 50,
  61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114,
  116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 49,
  53, 51, 48, 32, 108, 117, 109, 105, 110, 97, 110, 99, 101, 44, 36, 49,
  10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53,
  51, 48, 95, 109, 117, 108, 116, 105, 112, 108, 121, 32, 58, 10, 45, 105,
  102, 32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95,
  114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 49, 53, 51, 48, 32, 109, 117, 108, 116, 105, 112, 108,
  121, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 49, 53, 51, 48, 95, 110, 101, 103, 97, 116, 105, 111, 110, 32,
  58, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103,
  105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114,
  115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 114, 103, 98,
  32, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95,
  49, 53, 51, 48, 32, 110, 101, 103, 97, 116, 105, 111, 110, 44, 36, 49,
  10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53,
  51, 48, 95, 111, 118, 101, 114, 108, 97, 121, 32, 58, 10, 45, 105, 102,
  32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114,
  101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 49, 53, 51, 48, 32, 111, 118, 101, 114, 108, 97, 121, 44,
  36, 49, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95,
  49, 53, 51, 48, 95, 114, 101, 102, 108, 101, 99, 116, 32, 58, 10, 45,
  105, 102, 32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112,
  95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 49, 53, 51, 48, 32, 114, 101, 102, 108, 101, 99,
  116, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 49, 53, 51, 48, 95, 115, 97, 116, 117, 114, 97, 116, 105, 111,
  110, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 48, 125,
  10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103, 105,
  109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32, 115, 97, 116, 117,
  114, 97, 116, 105, 111, 110, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 115, 99, 114, 101,
  101, 110, 32, 58, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125, 32,
  45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97,
  121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32,
  115, 99, 114, 101, 101, 110, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 115, 104, 97, 112,
  101, 97, 118, 101, 114, 97, 103, 101, 32, 58, 10, 45, 105, 102, 32, 36,
  123, 51, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118,
  101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 116, 111, 95, 114, 103, 98, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 10, 45, 114,
  118, 91, 45, 50, 44, 45, 49, 93, 10, 45, 105, 102, 32, 36, 49, 32,
  45, 105, 91, 48, 93, 32, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95,
  115, 104, 97, 112, 101, 97, 118, 101, 114, 97, 103, 101, 91, 45, 50, 44,
  45, 49, 93, 10, 45, 105, 102, 32, 36, 49, 32, 45, 42, 91, 48, 44,
  45, 49, 93, 32, 45, 47, 91, 48, 93, 32, 50, 53, 53, 32, 45, 109,
  118, 91, 48, 93, 32, 64, 35, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  105, 102, 32, 36, 50, 32, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45,
  49, 93, 32, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111,
  114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44,
  50, 53, 53, 44, 48, 44, 48, 44, 48, 44, 48, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111,
  110, 101, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95,
  49, 53, 51, 48, 95, 115, 111, 102, 116, 108, 105, 103, 104, 116, 32, 58,
  10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103, 105,
  109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32, 115, 111, 102, 116,
  108, 105, 103, 104, 116, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 95, 115, 116, 97, 109, 112,
  32, 58, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125, 32, 45, 95,
  103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101,
  114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32, 115, 116,
  97, 109, 112, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 49, 53, 51, 48, 95, 118, 97, 108, 117, 101, 32, 58,
  32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 48, 125, 10, 45, 105,
  102, 32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95,
  114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 49, 53, 51, 48, 32, 118, 97, 108, 117, 101, 44, 36,
  49, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 49,
  53, 51, 48, 95, 120, 111, 114, 32, 58, 10, 45, 105, 102, 32, 36, 123,
  50, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101,
  114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 116, 111, 95, 114, 103, 98, 32, 45, 95, 103, 105, 109, 112, 95,
  99, 111, 109, 112, 111, 115, 101, 95, 49, 53, 51, 48, 32, 120, 111, 114,
  44, 36, 49, 10, 35, 10, 35, 10, 116, 107, 95, 103, 105, 109, 112, 95,
  99, 104, 97, 110, 110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105,
  110, 103, 32, 58, 10, 45, 103, 105, 109, 112, 95, 99, 104, 97, 110, 110,
  101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 123, 108,
  111, 103, 40, 36, 49, 41, 125, 44, 36, 123, 50, 45, 45, 49, 125, 10,
  116, 107, 95, 103, 105, 109, 112, 95, 115, 101, 108, 101, 99, 116, 95, 99,
  111, 108, 111, 114, 32, 58, 10, 40, 36, 52, 94, 36, 53, 94, 36, 54,
  94, 36, 55, 41, 32, 45, 95, 103, 105, 109, 112, 95, 115, 101, 108, 101,
  99, 116, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 36, 49, 32,
  99, 111, 108, 111, 114, 61, 64, 45, 49, 32, 45, 114, 109, 91, 45, 49,
  93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 105, 102,
  32, 123, 36, 56, 61, 61, 48, 125, 10, 45, 45, 95, 103, 105, 109, 112,
  95, 115, 101, 108, 101, 99, 116, 95, 99, 111, 108, 111, 114, 91, 45, 49,
  93, 32, 36, 49, 10, 45, 115, 101, 108, 101, 99, 116, 95, 99, 111, 108,
  111, 114, 91, 45, 49, 93, 32, 36, 50, 37, 44, 36, 99, 111, 108, 111,
  114, 10, 45, 98, 91, 45, 49, 93, 32, 36, 51, 37, 10, 45, 105, 102,
  32, 36, 57, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49, 32, 45, 43,
  91, 45, 49, 93, 32, 49, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116,
  111, 95, 114, 103, 98, 97, 91, 45, 50, 93, 32, 45, 115, 91, 45, 50,
  93, 32, 99, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 97,
  91, 45, 52, 45, 45, 49, 93, 32, 99, 10, 45, 101, 108, 115, 101, 10,
  45, 95, 103, 105, 109, 112, 95, 115, 101, 108, 101, 99, 116, 95, 99, 111,
  108, 111, 114, 91, 45, 49, 93, 32, 36, 49, 10, 45, 115, 101, 108, 101,
  99, 116, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93, 32, 36, 50, 37,
  44, 36, 99, 111, 108, 111, 114, 10, 45, 98, 91, 45, 49, 93, 32, 36,
  51, 10, 45, 105, 102, 32, 36, 57, 32, 45, 42, 91, 45, 49, 93, 32,
  45, 49, 32, 45, 43, 91, 45, 49, 93, 32, 49, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 42, 91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114,
  91, 45, 49, 93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49,
  44, 52, 10, 45, 101, 110, 100, 105, 102, 10, 45, 109, 118, 91, 45, 49,
  93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 116, 107, 95, 103, 105, 109,
  112, 95, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 32,
  58, 10, 45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 114, 101, 112, 108,
  97, 99, 101, 95, 99, 111, 108, 111, 114, 32, 36, 49, 44, 36, 50, 37,
  44, 36, 123, 51, 45, 45, 49, 125, 32, 45, 99, 32, 48, 44, 50, 53,
  53, 10, 35, 64, 103, 105, 109, 112, 32, 84, 101, 115, 116, 32, 114, 97,
  112, 105, 100, 105, 116, 101, 32, 99, 111, 109, 112, 105, 108, 97, 116, 105,
  111, 110, 32, 58, 32, 84, 101, 115, 116, 95, 82, 97, 112, 105, 100, 105,
  116, 101, 95, 115, 97, 109, 106, 44, 32, 84, 101, 115, 116, 95, 82, 97,
  112, 105, 100, 105, 116, 101, 95, 115, 97, 109, 106, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 84, 101, 115, 116, 32, 99, 111, 109, 112, 105, 108, 97, 116, 105,
  111, 110, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118,
  105, 101, 119, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99,
  101, 40, 34, 70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114,
  100, 32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70,
  111, 114, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122,
  111, 110, 116, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 101,
  117, 114, 115, 32, 47, 32, 65, 117, 116, 104, 111, 114, 115, 32, 58, 32,
  60, 105, 62, 83, 97, 109, 106, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 32,
  58, 32, 60, 105, 62, 50, 48, 49, 52, 47, 48, 49, 47, 49, 55, 60,
  47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 84,
  101, 115, 116, 95, 82, 97, 112, 105, 100, 105, 116, 101, 95, 115, 97, 109,
  106, 32, 58, 10, 116, 101, 109, 112, 115, 95, 111, 114, 105, 103, 105, 110,
  101, 61, 64, 124, 10, 100, 101, 109, 111, 61, 48, 10, 116, 101, 109, 112,
  115, 95, 100, 101, 109, 111, 61, 48, 10, 45, 116, 111, 95, 114, 103, 98,
  97, 91, 45, 49, 93, 10, 45, 102, 105, 108, 108, 95, 99, 111, 108, 111,
  114, 91, 45, 49, 93, 32, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53,
  53, 44, 50, 53, 53, 10, 45, 103, 105, 109, 112, 95, 99, 104, 101, 115,
  115, 98, 111, 97, 114, 100, 91, 45, 49, 93, 32, 51, 50, 44, 51, 50,
  44, 48, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 44, 48, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 44, 50,
  53, 53, 10, 45, 107, 117, 119, 97, 104, 97, 114, 97, 91, 45, 49, 93,
  32, 53, 10, 45, 103, 105, 109, 112, 95, 117, 110, 115, 104, 97, 114, 112,
  95, 111, 99, 116, 97, 118, 101, 91, 45, 49, 93, 32, 52, 44, 53, 44,
  51, 44, 48, 44, 48, 44, 48, 44, 50, 52, 44, 48, 10, 45, 103, 105,
  109, 112, 95, 97, 110, 105, 115, 111, 116, 114, 111, 112, 105, 99, 95, 115,
  109, 111, 111, 116, 104, 105, 110, 103, 91, 45, 49, 93, 32, 54, 48, 44,
  48, 46, 55, 44, 48, 46, 51, 44, 48, 46, 54, 44, 49, 46, 49, 44,
  48, 46, 56, 44, 51, 48, 44, 50, 44, 48, 44, 49, 44, 49, 48, 44,
  48, 44, 49, 44, 50, 52, 44, 48, 10, 45, 103, 105, 109, 112, 95, 98,
  108, 117, 114, 95, 108, 105, 110, 101, 97, 114, 91, 45, 49, 93, 32, 49,
  48, 44, 48, 46, 53, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 10,
  116, 101, 109, 112, 115, 95, 102, 105, 110, 61, 64, 124, 10, 116, 101, 109,
  112, 115, 95, 100, 101, 109, 111, 61, 123, 36, 116, 101, 109, 112, 115, 95,
  102, 105, 110, 45, 36, 116, 101, 109, 112, 115, 95, 111, 114, 105, 103, 105,
  110, 101, 125, 10, 45, 116, 101, 120, 116, 95, 111, 117, 116, 108, 105, 110,
  101, 91, 45, 49, 93, 32, 36, 116, 101, 109, 112, 115, 95, 100, 101, 109,
  111, 44, 49, 48, 44, 49, 48, 44, 54, 52, 44, 49, 44, 49, 44, 50,
  53, 53, 44, 50, 53, 53, 44, 50, 53, 53, 10, 35, 64, 103, 105, 109,
  112, 32, 95, 95, 10, 35, 64, 103, 105, 109, 112, 32, 60, 105, 62, 84,
  111, 109, 32, 107, 101, 105, 108, 60, 47, 105, 62, 10, 35, 64, 103, 105,
  109, 112, 32, 65, 98, 111, 117, 116, 32, 58, 32, 95, 110, 111, 110, 101,
  95, 44, 32, 103, 105, 109, 112, 95, 116, 107, 95, 97, 98, 111, 117, 116,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 123, 34, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 60, 115, 112, 97, 110, 32, 102, 111, 114, 101, 103, 114, 111, 117, 110,
  100, 32, 61, 34, 112, 117, 114, 112, 108, 101, 34, 62, 40, 32, 60, 98,
  62, 84, 60, 47, 98, 62, 111, 109, 32, 75, 101, 105, 108, -76, 115, 32,
  60, 98, 62, 70, 60, 47, 98, 62, 105, 108, 116, 101, 114, 32, 60, 98,
  62, 83, 60, 47, 98, 62, 101, 116, 32, 102, 111, 114, 32, 60, 98, 62,
  71, 39, 77, 73, 67, 60, 47, 98, 62, 41, 60, 47, 115, 112, 97, 110,
  62, 92, 110, 92, 110, 105, 115, 32, 112, 114, 111, 112, 111, 115, 101, 100,
  32, 116, 111, 32, 121, 111, 117, 32, 98, 121, 34, 125, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 40, 34, 84, 111, 109, 32, 75, 101, 105, 108, 34, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 123, 34, 92, 110, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 84, 104, 101, 32, 115, 111, 117, 114, 99, 101, 32, 99,
  111, 100, 101, 32, 111, 102, 32, 116, 104, 105, 115, 32, 115, 101, 116, 32,
  111, 102, 32, 102, 105, 108, 116, 101, 114, 115, 32, 97, 110, 100, 32, 97,
  100, 100, 105, 116, 105, 111, 110, 97, 108, 32, 105, 110, 102, 111, 114, 109,
  97, 116, 105, 111, 110, 115, 32, 97, 110, 100, 32, 116, 117, 116, 111, 114,
  105, 97, 108, 115, 32, 97, 114, 101, 32, 97, 118, 97, 105, 108, 97, 98,
  108, 101, 32, 97, 116, 32, 58, 34, 125, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34,
  104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 116, 107, 102, 105, 108,
  116, 101, 114, 46, 98, 112, 108, 97, 99, 101, 100, 46, 110, 101, 116, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 34, 125, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 92,
  110, 84, 104, 101, 32, 102, 105, 108, 116, 101, 114, 115, 32, 105, 110, 32,
  116, 104, 105, 115, 32, 102, 111, 108, 100, 101, 114, 32, 97, 114, 101, 32,
  115, 116, 105, 108, 108, 32, 117, 110, 100, 101, 114, 32, 100, 101, 118, 101,
  108, 111, 112, 109, 101, 110, 116, 32, 97, 110, 100, 32, 109, 97, 121, 32,
  98, 101, 32, 115, 117, 98, 106, 101, 99, 116, 32, 116, 111, 32, 99, 104,
  97, 110, 103, 101, 115, 46, 32, 83, 111, 109, 101, 32, 102, 105, 108, 116,
  101, 114, 115, 32, 97, 112, 112, 101, 97, 114, 105, 110, 103, 32, 104, 101,
  114, 101, 32, 97, 114, 101, 32, 97, 108, 115, 111, 32, 112, 97, 114, 116,
  32, 111, 102, 32, 116, 104, 101, 32, 109, 97, 105, 110, 32, 102, 105, 108,
  116, 101, 114, 32, 116, 114, 101, 101, 32, 111, 102, 32, 71, -76, 77, 73,
  67, 46, 32, 73, 102, 32, 116, 104, 101, 121, 32, 97, 112, 112, 101, 97,
  114, 32, 104, 101, 114, 101, 32, 116, 111, 111, 32, 105, 116, 32, 109, 101,
  97, 110, 115, 32, 116, 104, 101, 114, 101, 32, 97, 114, 101, 32, 99, 104,
  97, 110, 103, 101, 115, 32, 97, 110, 100, 32, 117, 112, 100, 97, 116, 101,
  115, 32, 110, 111, 116, 32, 121, 101, 116, 32, 105, 109, 112, 108, 101, 109,
  101, 110, 116, 101, 100, 32, 105, 110, 32, 116, 104, 101, 32, 109, 97, 105,
  110, 32, 102, 105, 108, 116, 101, 114, 32, 116, 114, 101, 101, 46, 34, 125,
  10, 103, 105, 109, 112, 95, 116, 107, 95, 97, 98, 111, 117, 116, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 108, 111, 103, 111, 32, 34, 84, 111, 109,
  32, 75, 101, 105, 108, -76, 115, 32, 70, 105, 108, 116, 101, 114, 115, 34,
  10, 35, 64, 103, 105, 109, 112, 32, 66, 101, 97, 117, 116, 121, 32, 114,
  101, 116, 111, 117, 99, 104, 32, 58, 32, 103, 105, 109, 112, 95, 116, 107,
  95, 114, 101, 116, 111, 117, 99, 104, 44, 32, 103, 105, 109, 112, 95, 116,
  107, 95, 114, 101, 116, 111, 117, 99, 104, 95, 112, 114, 101, 118, 105, 101,
  119, 40, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51, 48, 44, 48,
  44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 68,
  101, 116, 97, 105, 108, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 51,
  44, 48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  83, 109, 111, 111, 116, 104, 105, 110, 103, 32, 115, 116, 114, 101, 110, 103,
  116, 104, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 53,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 69, 100, 103, 101, 32,
  116, 104, 114, 101, 115, 104, 111, 108, 100, 32, 61, 32, 102, 108, 111, 97,
  116, 40, 50, 48, 44, 48, 44, 53, 48, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 69, 100, 103, 101, 32, 115, 109, 111, 111, 116, 104, 110,
  101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 46, 53, 44,
  48, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  104, 97, 114, 112, 101, 110, 105, 110, 103, 32, 114, 97, 100, 105, 117, 115,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 104, 97, 114, 112, 101,
  110, 105, 110, 103, 32, 115, 116, 114, 101, 110, 103, 116, 104, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 50, 46, 53, 44, 48, 44, 53, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 86, 105, 101, 119, 32, 101, 100, 103,
  101, 32, 109, 97, 115, 107, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116, 104,
  101, 110, 32, 115, 107, 105, 110, 32, 116, 111, 110, 101, 115, 32, 111, 110,
  108, 121, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 44, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58,
  32, 60, 105, 62, 84, 111, 109, 32, 75, 101, 105, 108, 60, 47, 105, 62,
  46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112,
  100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48, 49,
  47, 48, 53, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 108, 105, 110, 107, 40, 34, 70, 105, 108, 116, 101, 114, 32,
  101, 120, 112, 108, 97, 105, 110, 101, 100, 32, 104, 101, 114, 101, 34, 44,
  34, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 102, 108, 105, 99,
  107, 114, 46, 99, 111, 109, 47, 103, 114, 111, 117, 112, 115, 47, 103, 109,
  105, 99, 47, 100, 105, 115, 99, 117, 115, 115, 47, 55, 50, 49, 53, 55,
  54, 50, 53, 53, 51, 56, 54, 54, 57, 48, 52, 49, 47, 34, 41, 10,
  103, 105, 109, 112, 95, 116, 107, 95, 114, 101, 116, 111, 117, 99, 104, 32,
  58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91,
  36, 62, 93, 10, 45, 105, 102, 32, 123, 36, 56, 61, 61, 49, 125, 10,
  45, 45, 103, 105, 109, 112, 95, 101, 100, 103, 101, 115, 32, 36, 53, 44,
  36, 52, 44, 48, 44, 48, 32, 45, 103, 105, 109, 112, 95, 103, 97, 117,
  115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 32, 123, 36, 53, 42, 53,
  125, 44, 48, 44, 48, 44, 49, 44, 49, 44, 48, 44, 48, 10, 45, 101,
  108, 115, 101, 10, 45, 45, 116, 111, 95, 114, 103, 98, 97, 91, 48, 93,
  32, 32, 45, 45, 116, 111, 95, 103, 114, 97, 121, 91, 48, 93, 32, 45,
  103, 105, 109, 112, 95, 101, 100, 103, 101, 115, 91, 50, 93, 32, 36, 53,
  44, 36, 52, 44, 48, 44, 48, 10, 45, 103, 105, 109, 112, 95, 103, 97,
  117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 50, 93, 32, 123,
  36, 53, 42, 53, 125, 44, 48, 44, 48, 44, 49, 44, 49, 44, 48, 44,
  48, 32, 45, 116, 111, 95, 103, 114, 97, 121, 91, 50, 93, 32, 45, 45,
  116, 111, 95, 114, 103, 98, 97, 91, 48, 93, 32, 45, 45, 110, 101, 103,
  97, 116, 105, 118, 101, 91, 50, 93, 10, 45, 103, 105, 109, 112, 95, 104,
  105, 103, 104, 112, 97, 115, 115, 91, 49, 93, 32, 123, 36, 49, 125, 44,
  50, 44, 49, 44, 49, 44, 48, 10, 45, 103, 105, 109, 112, 95, 103, 97,
  117, 115, 115, 105, 97, 110, 95, 98, 108, 117, 114, 91, 49, 93, 32, 36,
  50, 44, 48, 44, 48, 44, 49, 44, 49, 44, 48, 44, 48, 10, 45, 116,
  111, 95, 114, 103, 98, 97, 91, 48, 93, 10, 45, 105, 102, 32, 123, 36,
  57, 61, 61, 49, 125, 32, 32, 45, 45, 116, 111, 95, 114, 103, 98, 97,
  91, 48, 93, 32, 45, 99, 104, 97, 110, 110, 101, 108, 115, 91, 53, 93,
  32, 48, 10, 45, 116, 107, 95, 103, 105, 109, 112, 95, 99, 104, 97, 110,
  110, 101, 108, 95, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 91, 53,
  93, 32, 49, 44, 49, 44, 52, 44, 48, 44, 48, 44, 48, 44, 49, 48,
  48, 44, 50, 53, 54, 44, 48, 44, 48, 44, 48, 44, 50, 44, 55, 44,
  48, 10, 45, 103, 105, 109, 112, 95, 103, 97, 117, 115, 115, 105, 97, 110,
  95, 98, 108, 117, 114, 91, 53, 93, 32, 123, 123, 119, 43, 104, 125, 47,
  49, 48, 48, 48, 125, 44, 48, 44, 48, 44, 49, 44, 48, 44, 48, 44,
  48, 32, 45, 116, 111, 95, 103, 114, 97, 121, 91, 53, 93, 32, 45, 101,
  110, 100, 105, 102, 10, 45, 115, 112, 108, 105, 116, 91, 49, 93, 32, 99,
  32, 32, 45, 114, 101, 118, 101, 114, 115, 101, 91, 52, 44, 53, 93, 32,
  45, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108, 116, 105, 112, 108,
  121, 91, 52, 44, 53, 93, 10, 45, 105, 102, 32, 123, 36, 57, 61, 61,
  49, 125, 32, 45, 114, 101, 118, 101, 114, 115, 101, 91, 52, 44, 45, 49,
  93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 109, 117, 108, 116, 105,
  112, 108, 121, 91, 52, 44, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 97, 112, 112, 101, 110, 100, 91, 45, 54, 44, 45, 53, 44, 45,
  52, 44, 45, 51, 93, 32, 99, 10, 45, 114, 101, 118, 101, 114, 115, 101,
  91, 48, 44, 49, 93, 32, 45, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 115, 111, 102, 116, 108, 105, 103, 104, 116, 91, 48, 44,
  49, 93, 32, 123, 36, 51, 47, 53, 125, 10, 45, 103, 105, 109, 112, 95,
  117, 110, 115, 104, 97, 114, 112, 91, 45, 50, 93, 32, 48, 44, 36, 54,
  44, 51, 48, 44, 36, 55, 44, 48, 46, 48, 48, 44, 49, 46, 48, 48,
  44, 48, 46, 53, 44, 49, 44, 48, 44, 55, 44, 48, 10, 45, 115, 112,
  108, 105, 116, 91, 45, 50, 93, 32, 99, 32, 32, 45, 114, 101, 118, 101,
  114, 115, 101, 91, 45, 49, 44, 45, 50, 93, 32, 45, 99, 111, 109, 112,
  111, 115, 101, 95, 109, 117, 108, 116, 105, 112, 108, 121, 91, 45, 49, 44,
  45, 50, 93, 32, 45, 97, 112, 112, 101, 110, 100, 91, 45, 52, 44, 45,
  51, 44, 45, 50, 44, 45, 49, 93, 32, 99, 10, 45, 99, 111, 109, 112,
  111, 115, 101, 95, 97, 108, 112, 104, 97, 91, 48, 44, 49, 93, 10, 45,
  101, 110, 100, 105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 10, 103, 105, 109, 112, 95, 116, 107, 95, 114, 101, 116, 111, 117, 99,
  104, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 105, 109, 112, 95, 116, 107, 95, 114, 101, 116, 111, 117, 99,
  104, 32, 36, 123, 49, 45, 45, 50, 125, 34, 44, 36, 45, 49, 10, 35,
  64, 103, 105, 109, 112, 32, 95, 10, 35, 64, 103, 105, 109, 112, 32, 60,
  105, 62, 90, 111, 110, 100, 101, 114, 114, 60, 47, 105, 62, 10, 35, 64,
  103, 105, 109, 112, 32, 68, 101, 109, 111, 32, 109, 97, 116, 104, 109, 97,
  112, 32, 114, 97, 32, 58, 32, 100, 101, 109, 111, 95, 114, 97, 44, 32,
  100, 101, 109, 111, 95, 114, 97, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 109, 97,
  116, 104, 109, 97, 112, 32, 114, 97, 58, 32, 100, 101, 109, 111, 34, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32,
  115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 82, 97, 100, 105, 117, 115, 32, 115, 99, 97, 108,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 110, 103, 108, 101,
  32, 115, 99, 97, 108, 101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49,
  44, 48, 44, 49, 48, 41, 10, 100, 101, 109, 111, 95, 114, 97, 58, 10,
  45, 109, 97, 116, 104, 109, 97, 112, 95, 114, 97, 32, 34, 114, 109, 97,
  116, 104, 42, 36, 49, 34, 44, 34, 97, 109, 97, 116, 104, 42, 36, 50,
  34, 10, 35, 64, 103, 105, 109, 112, 32, 68, 101, 109, 111, 32, 109, 97,
  116, 104, 109, 97, 112, 32, 120, 121, 32, 58, 32, 100, 101, 109, 111, 95,
  120, 121, 44, 32, 100, 101, 109, 111, 95, 120, 121, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  40, 34, 109, 97, 116, 104, 109, 97, 112, 32, 120, 121, 58, 32, 100, 101,
  109, 111, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 88, 32, 115, 99, 97, 108, 101,
  32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 48, 41,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 89, 32, 115, 99, 97, 108,
  101, 32, 61, 32, 102, 108, 111, 97, 116, 40, 49, 44, 48, 44, 49, 48,
  41, 10, 100, 101, 109, 111, 95, 120, 121, 58, 10, 45, 109, 97, 116, 104,
  109, 97, 112, 95, 120, 121, 32, 34, 120, 109, 97, 116, 104, 42, 36, 49,
  34, 44, 34, 121, 109, 97, 116, 104, 42, 36, 50, 34, 10, 35, 64, 103,
  105, 109, 112, 32, 70, 111, 117, 114, 105, 101, 114, 32, 112, 105, 99, 116,
  117, 114, 101, 32, 119, 97, 116, 101, 114, 109, 97, 114, 107, 32, 58, 32,
  103, 105, 109, 112, 95, 102, 111, 117, 114, 105, 101, 114, 95, 112, 105, 99,
  116, 117, 114, 101, 95, 119, 97, 116, 101, 114, 109, 97, 114, 107, 44, 32,
  95, 110, 111, 110, 101, 95, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  82, 101, 108, 97, 116, 105, 118, 101, 32, 115, 105, 122, 101, 32, 61, 32,
  102, 108, 111, 97, 116, 40, 48, 46, 50, 44, 48, 46, 49, 44, 48, 46,
  53, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111,
  116, 101, 40, 34, 78, 111, 116, 101, 32, 58, 32, 84, 111, 32, 109, 97,
  107, 101, 32, 116, 104, 101, 32, 119, 97, 116, 101, 114, 109, 97, 114, 107,
  32, 118, 105, 115, 105, 98, 108, 101, 32, 97, 102, 116, 101, 114, 119, 97,
  114, 100, 115, 44, 32, 117, 115, 101, 32, 116, 104, 101, 32, 39, 70, 111,
  117, 114, 105, 101, 114, 32, 65, 110, 97, 108, 121, 115, 105, 115, 39, 32,
  102, 105, 108, 116, 101, 114, 46, 32, 34, 41, 10, 103, 105, 109, 112, 95,
  102, 111, 117, 114, 105, 101, 114, 95, 112, 105, 99, 116, 117, 114, 101, 95,
  119, 97, 116, 101, 114, 109, 97, 114, 107, 32, 58, 10, 45, 114, 101, 115,
  105, 122, 101, 95, 114, 97, 116, 105, 111, 50, 100, 91, 48, 93, 32, 123,
  64, 123, 49, 44, 119, 125, 42, 36, 49, 125, 44, 123, 64, 123, 49, 44,
  104, 125, 42, 36, 49, 125, 32, 45, 116, 111, 95, 103, 114, 97, 121, 91,
  48, 93, 32, 45, 116, 104, 114, 101, 115, 104, 111, 108, 100, 91, 48, 93,
  32, 49, 50, 55, 10, 45, 119, 97, 116, 101, 114, 109, 97, 114, 107, 95,
  102, 111, 117, 114, 105, 101, 114, 50, 32, 45, 99, 32, 48, 44, 50, 53,
  53, 10, 119, 97, 116, 101, 114, 109, 97, 114, 107, 95, 102, 111, 117, 114,
  105, 101, 114, 50, 32, 58, 10, 45, 102, 102, 116, 91, 45, 49, 93, 32,
  45, 115, 104, 105, 102, 116, 91, 45, 50, 44, 45, 49, 93, 32, 53, 48,
  37, 44, 53, 48, 37, 44, 48, 44, 48, 44, 50, 10, 91, 48, 93, 44,
  91, 48, 93, 44, 49, 44, 123, 115, 125, 10, 45, 105, 109, 97, 103, 101,
  91, 45, 51, 44, 45, 50, 93, 32, 91, 45, 49, 93, 44, 51, 44, 51,
  44, 48, 44, 48, 44, 49, 44, 91, 48, 93, 10, 45, 109, 105, 114, 114,
  111, 114, 91, 48, 93, 32, 120, 10, 45, 105, 109, 97, 103, 101, 91, 45,
  51, 44, 45, 50, 93, 32, 91, 45, 49, 93, 44, 123, 64, 123, 45, 50,
  44, 119, 125, 45, 50, 45, 64, 123, 48, 44, 119, 125, 125, 44, 51, 44,
  48, 44, 48, 44, 49, 44, 91, 48, 93, 10, 45, 109, 105, 114, 114, 111,
  114, 91, 48, 93, 32, 121, 10, 45, 105, 109, 97, 103, 101, 91, 45, 51,
  44, 45, 50, 93, 32, 91, 45, 49, 93, 44, 123, 64, 123, 45, 50, 44,
  119, 125, 45, 50, 45, 64, 123, 48, 44, 119, 125, 125, 44, 123, 64, 123,
  45, 50, 44, 104, 125, 45, 50, 45, 64, 123, 48, 44, 104, 125, 125, 44,
  48, 44, 48, 44, 49, 44, 91, 48, 93, 10, 45, 109, 105, 114, 114, 111,
  114, 91, 48, 93, 32, 120, 10, 45, 105, 109, 97, 103, 101, 91, 45, 51,
  44, 45, 50, 93, 32, 91, 45, 49, 93, 44, 51, 44, 123, 64, 123, 45,
  50, 44, 104, 125, 45, 50, 45, 64, 123, 48, 44, 104, 125, 125, 44, 48,
  44, 48, 44, 49, 44, 91, 48, 93, 10, 45, 109, 105, 114, 114, 111, 114,
  91, 48, 93, 32, 121, 10, 45, 114, 109, 91, 45, 49, 93, 32, 45, 115,
  104, 105, 102, 116, 91, 45, 50, 44, 45, 49, 93, 32, 45, 53, 48, 37,
  44, 45, 53, 48, 37, 44, 48, 44, 48, 44, 50, 32, 45, 105, 102, 102,
  116, 91, 45, 50, 44, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 109, 118, 91, 45, 49, 93, 32, 49, 10, 45, 114, 109, 91, 48,
  93, 10, 35, 64, 103, 105, 109, 112, 32, 77, 97, 116, 104, 109, 97, 112,
  32, 102, 108, 97, 103, 32, 58, 32, 109, 97, 116, 104, 109, 97, 112, 95,
  102, 108, 97, 103, 44, 32, 109, 97, 116, 104, 109, 97, 112, 95, 102, 108,
  97, 103, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 65, 109, 112, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 48, 46, 48, 53, 44, 48, 44, 49,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 76, 101, 110, 32, 61,
  32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 53, 48, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 112, 101, 101, 100, 32, 61, 32,
  105, 110, 116, 40, 49, 44, 49, 44, 53, 41, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 84, 105, 109, 101, 32, 61, 32, 102, 108, 111, 97, 116,
  40, 53, 44, 48, 44, 53, 48, 41, 10, 109, 97, 116, 104, 109, 97, 112,
  95, 102, 108, 97, 103, 58, 10, 45, 109, 97, 116, 104, 109, 97, 112, 95,
  120, 121, 32, 34, 120, 109, 97, 116, 104, 34, 44, 34, 121, 109, 97, 116,
  104, 43, 36, 49, 42, 115, 105, 110, 40, 112, 105, 42, 36, 50, 47, 49,
  42, 40, 45, 120, 109, 97, 116, 104, 43, 36, 52, 42, 50, 42, 36, 51,
  47, 36, 50, 41, 41, 34, 10, 35, 64, 103, 105, 109, 112, 32, 82, 101,
  108, 50, 101, 108, 108, 118, 51, 32, 58, 32, 109, 97, 116, 104, 109, 97,
  112, 95, 114, 101, 108, 50, 101, 108, 108, 118, 51, 44, 109, 97, 116, 104,
  109, 97, 112, 95, 114, 101, 108, 50, 101, 108, 108, 118, 51, 10, 109, 97,
  116, 104, 109, 97, 112, 95, 114, 101, 108, 50, 101, 108, 108, 118, 51, 58,
  10, 45, 109, 97, 116, 104, 109, 97, 112, 95, 120, 121, 32, 34, 120, 109,
  97, 116, 104, 47, 115, 113, 114, 116, 40, 49, 45, 52, 42, 40, 121, 109,
  97, 116, 104, 47, 72, 41, 42, 40, 121, 109, 97, 116, 104, 47, 72, 41,
  41, 34, 44, 34, 121, 109, 97, 116, 104, 47, 115, 113, 114, 116, 40, 49,
  45, 52, 42, 40, 120, 109, 97, 116, 104, 47, 87, 41, 42, 40, 120, 109,
  97, 116, 104, 47, 87, 41, 41, 34, 10, 35, 64, 103, 105, 109, 112, 32,
  95, 95, 10, 35, 64, 103, 105, 109, 112, 32, 60, 98, 62, 86, 97, 114,
  105, 111, 117, 115, 60, 47, 98, 62, 10, 35, 64, 103, 105, 109, 112, 32,
  67, 117, 115, 116, 111, 109, 32, 99, 111, 100, 101, 32, 40, 103, 108, 111,
  98, 97, 108, 41, 32, 58, 32, 103, 105, 109, 112, 95, 99, 117, 115, 116,
  111, 109, 95, 99, 111, 100, 101, 44, 32, 103, 105, 109, 112, 95, 99, 117,
  115, 116, 111, 109, 95, 99, 111, 100, 101, 95, 112, 114, 101, 118, 105, 101,
  119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 111,
  100, 101, 32, 61, 32, 116, 101, 120, 116, 40, 49, 44, 34, 45, 114, 101,
  112, 101, 97, 116, 32, 64, 35, 32, 45, 108, 91, 36, 62, 93, 92, 110,
  92, 110, 32, 32, 45, 116, 111, 95, 114, 103, 98, 92, 110, 32, 32, 45,
  45, 100, 101, 102, 111, 114, 109, 32, 50, 48, 92, 110, 32, 32, 45, 98,
  108, 101, 110, 100, 95, 101, 100, 103, 101, 115, 32, 51, 92, 110, 92, 110,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 92, 110, 92, 110, 92,
  110, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112,
  32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 86, 97, 108, 117, 101, 32, 114, 97,
  110, 103, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 67, 117,
  116, 34, 44, 34, 78, 111, 114, 109, 97, 108, 105, 122, 101, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 67, 104, 97, 110, 110, 101, 108,
  40, 115, 41, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34, 65, 108,
  108, 34, 44, 34, 82, 71, 66, 65, 34, 44, 34, 82, 71, 66, 34, 44,
  34, 76, 117, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 66, 108, 117,
  101, 47, 114, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99,
  101, 115, 34, 44, 34, 66, 108, 117, 101, 32, 99, 104, 114, 111, 109, 105,
  110, 97, 110, 99, 101, 34, 44, 34, 82, 101, 100, 32, 99, 104, 114, 111,
  109, 105, 110, 97, 110, 99, 101, 34, 44, 34, 76, 105, 103, 104, 116, 110,
  101, 115, 115, 34, 44, 34, 97, 98, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 115, 34, 44, 34, 97, 45, 99, 111, 109, 112, 111, 110, 101, 110,
  116, 34, 44, 34, 98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34,
  44, 34, 72, 117, 101, 34, 44, 34, 83, 97, 116, 117, 114, 97, 116, 105,
  111, 110, 34, 44, 34, 86, 97, 108, 117, 101, 34, 44, 34, 75, 101, 121,
  34, 44, 34, 71, 114, 101, 101, 110, 32, 99, 104, 114, 111, 109, 105, 110,
  97, 110, 99, 101, 34, 44, 34, 99, 104, 45, 99, 111, 109, 112, 111, 110,
  101, 110, 116, 115, 34, 44, 34, 99, 45, 99, 111, 109, 112, 111, 110, 101,
  110, 116, 34, 44, 34, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116,
  34, 44, 34, 82, 101, 100, 34, 44, 34, 71, 114, 101, 101, 110, 34, 44,
  34, 66, 108, 117, 101, 34, 44, 34, 65, 108, 112, 104, 97, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 80, 114, 101, 118, 105, 101, 119,
  32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111, 105, 99, 101, 40, 34,
  70, 117, 108, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 104,
  111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 70, 111, 114, 119,
  97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34, 44, 34, 66,
  97, 99, 107, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100, 32, 118, 101,
  114, 116, 105, 99, 97, 108, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116,
  101, 32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 115, 109, 97, 108, 108,
  62, 60, 98, 62, 78, 111, 116, 101, 58, 32, 60, 47, 98, 62, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 105, 115, 32, 102, 105, 108,
  116, 101, 114, 32, 99, 97, 110, 32, 101, 120, 101, 99, 117, 116, 101, 32,
  97, 110, 121, 32, 115, 101, 116, 32, 111, 102, 32, 105, 110, 115, 116, 114,
  117, 99, 116, 105, 111, 110, 115, 32, 117, 110, 100, 101, 114, 115, 116, 111,
  111, 100, 32, 98, 121, 32, 116, 104, 101, 32, 60, 98, 62, 71, 39, 77,
  73, 67, 60, 47, 98, 62, 32, 108, 97, 110, 103, 117, 97, 103, 101, 32,
  105, 110, 116, 101, 114, 112, 114, 101, 116, 101, 114, 46, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 72, 101, 114, 101, 44, 32, 121, 111, 117, 32,
  99, 97, 110, 32, 116, 104, 101, 110, 32, 116, 101, 115, 116, 32, 115, 111,
  109, 101, 32, 99, 111, 109, 109, 97, 110, 100, 115, 32, 98, 101, 102, 111,
  114, 101, 32, 99, 114, 101, 97, 116, 105, 110, 103, 32, 121, 111, 117, 114,
  32, 111, 119, 110, 32, 71, 39, 77, 73, 67, 32, 99, 117, 115, 116, 111,
  109, 32, 99, 111, 109, 109, 97, 110, 100, 115, 32, 97, 110, 100, 32, 71,
  73, 77, 80, 32, 109, 101, 110, 117, 32, 101, 110, 116, 114, 105, 101, 115,
  46, 92, 110, 92, 110, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 80,
  108, 101, 97, 115, 101, 32, 108, 111, 111, 107, 32, 97, 116, 32, 116, 104,
  101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 97, 116, 105, 111, 110, 32,
  114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 119, 101, 98, 32, 112, 97,
  103, 101, 32, 58, 60, 47, 115, 109, 97, 108, 108, 62, 34, 125, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 108,
  105, 110, 107, 40, 34, 104, 116, 116, 112, 58, 47, 47, 103, 109, 105, 99,
  46, 115, 111, 117, 114, 99, 101, 102, 111, 114, 103, 101, 46, 110, 101, 116,
  47, 114, 101, 102, 101, 114, 101, 110, 99, 101, 46, 115, 104, 116, 109, 108,
  34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 123, 34, 60, 115, 109, 97, 108, 108, 62,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 116, 111, 32, 108, 101, 97,
  114, 110, 32, 109, 111, 114, 101, 32, 97, 98, 111, 117, 116, 32, 97, 118,
  97, 105, 108, 97, 98, 108, 101, 32, 60, 98, 62, 71, 39, 77, 73, 67,
  60, 47, 98, 62, 32, 99, 111, 109, 109, 97, 110, 100, 115, 46, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 60, 47, 115, 109, 97, 108, 108, 62,
  34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32,
  61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110,
  111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97,
  108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97,
  118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35,
  50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76,
  97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105,
  62, 50, 48, 49, 49, 47, 48, 54, 47, 49, 52, 60, 47, 105, 62, 46,
  60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95,
  99, 117, 115, 116, 111, 109, 95, 99, 111, 100, 101, 32, 58, 32, 45, 115,
  107, 105, 112, 32, 34, 36, 123, 49, 61, 45, 115, 107, 105, 112, 32, 44,
  125, 34, 10, 45, 109, 32, 34, 95, 103, 105, 109, 112, 95, 99, 117, 115,
  116, 111, 109, 95, 99, 111, 100, 101, 95, 115, 116, 97, 114, 116, 32, 58,
  32, 36, 49, 34, 10, 45, 105, 102, 32, 123, 36, 51, 62, 48, 125, 10,
  45, 97, 112, 112, 108, 121, 95, 99, 104, 97, 110, 110, 101, 108, 115, 32,
  34, 45, 95, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 99,
  111, 100, 101, 95, 115, 116, 97, 114, 116, 34, 44, 36, 51, 44, 36, 50,
  10, 45, 101, 108, 115, 101, 10, 45, 95, 103, 105, 109, 112, 95, 99, 117,
  115, 116, 111, 109, 95, 99, 111, 100, 101, 10, 45, 105, 102, 32, 36, 50,
  32, 45, 110, 32, 48, 44, 50, 53, 53, 32, 45, 101, 108, 115, 101, 32,
  45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 101, 110, 100, 105, 102, 10, 45, 117, 110, 99, 111, 109, 109, 97, 110,
  100, 32, 95, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 99,
  111, 100, 101, 95, 115, 116, 97, 114, 116, 10, 103, 105, 109, 112, 95, 99,
  117, 115, 116, 111, 109, 95, 99, 111, 100, 101, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 32, 45, 115, 107, 105, 112, 32, 34, 36, 123, 49, 61,
  45, 115, 107, 105, 112, 32, 44, 125, 34, 10, 95, 103, 99, 112, 95, 97,
  114, 103, 61, 34, 36, 49, 34, 10, 45, 103, 105, 109, 112, 95, 115, 112,
  108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 105,
  109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 99, 111, 100, 101, 32, 36,
  95, 103, 99, 112, 95, 97, 114, 103, 44, 36, 123, 50, 45, 45, 50, 125,
  34, 44, 36, 45, 49, 10, 95, 103, 105, 109, 112, 95, 99, 117, 115, 116,
  111, 109, 95, 99, 111, 100, 101, 32, 58, 10, 45, 95, 103, 105, 109, 112,
  95, 99, 117, 115, 116, 111, 109, 95, 99, 111, 100, 101, 95, 115, 116, 97,
  114, 116, 10, 35, 64, 103, 105, 109, 112, 32, 67, 117, 115, 116, 111, 109,
  32, 99, 111, 100, 101, 32, 40, 108, 111, 99, 97, 108, 41, 32, 58, 32,
  103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 99, 111, 100, 101,
  44, 32, 103, 105, 109, 112, 95, 99, 117, 115, 116, 111, 109, 95, 99, 111,
  100, 101, 95, 112, 114, 101, 118, 105, 101, 119, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 67, 111, 100, 101, 32, 61, 32, 116, 101,
  120, 116, 40, 49, 44, 34, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 92, 110, 92, 110, 32, 32, 45, 116, 111,
  95, 114, 103, 98, 92, 110, 32, 32, 45, 45, 100, 101, 102, 111, 114, 109,
  32, 50, 48, 92, 110, 32, 32, 45, 98, 108, 101, 110, 100, 95, 101, 100,
  103, 101, 115, 32, 51, 92, 110, 92, 110, 45, 101, 110, 100, 108, 32, 45,
  100, 111, 110, 101, 92, 110, 92, 110, 92, 110, 34, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97,
  114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 86, 97, 108, 117, 101, 32, 114, 97, 110, 103, 101, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 67, 117, 116, 34, 44, 34, 78, 111, 114,
  109, 97, 108, 105, 122, 101, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 67, 104, 97, 110, 110, 101, 108, 40, 115, 41, 32, 61, 32, 99,
  104, 111, 105, 99, 101, 40, 34, 65, 108, 108, 34, 44, 34, 82, 71, 66,
  65, 34, 44, 34, 82, 71, 66, 34, 44, 34, 76, 117, 109, 105, 110, 97,
  110, 99, 101, 34, 44, 34, 66, 108, 117, 101, 47, 114, 101, 100, 32, 99,
  104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 115, 34, 44, 34, 66, 108,
  117, 101, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44,
  34, 82, 101, 100, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101,
  34, 44, 34, 76, 105, 103, 104, 116, 110, 101, 115, 115, 34, 44, 34, 97,
  98, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34, 97,
  45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 98, 45, 99,
  111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 72, 117, 101, 34, 44,
  34, 83, 97, 116, 117, 114, 97, 116, 105, 111, 110, 34, 44, 34, 86, 97,
  108, 117, 101, 34, 44, 34, 75, 101, 121, 34, 44, 34, 71, 114, 101, 101,
  110, 32, 99, 104, 114, 111, 109, 105, 110, 97, 110, 99, 101, 34, 44, 34,
  99, 104, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 34, 44, 34,
  99, 45, 99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 104, 45,
  99, 111, 109, 112, 111, 110, 101, 110, 116, 34, 44, 34, 82, 101, 100, 34,
  44, 34, 71, 114, 101, 101, 110, 34, 44, 34, 66, 108, 117, 101, 34, 44,
  34, 65, 108, 112, 104, 97, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 80, 114, 101, 118, 105, 101, 119, 32, 116, 121, 112, 101, 32, 61,
  32, 99, 104, 111, 105, 99, 101, 40, 34, 70, 117, 108, 108, 34, 44, 34,
  70, 111, 114, 119, 97, 114, 100, 32, 104, 111, 114, 105, 122, 111, 110, 116,
  97, 108, 34, 44, 34, 70, 111, 114, 119, 97, 114, 100, 32, 118, 101, 114,
  116, 105, 99, 97, 108, 34, 44, 34, 66, 97, 99, 107, 119, 97, 114, 100,
  32, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 34, 44, 34, 66, 97,
  99, 107, 119, 97, 114, 100, 32, 118, 101, 114, 116, 105, 99, 97, 108, 34,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61,
  32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116,
  101, 123, 34, 60, 115, 109, 97, 108, 108, 62, 60, 98, 62, 78, 111, 116,
  101, 58, 32, 60, 47, 98, 62, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 84, 104, 105, 115, 32, 102, 105, 108, 116, 101, 114, 32, 99, 97, 110,
  32, 101, 120, 101, 99, 117, 116, 101, 32, 97, 110, 121, 32, 115, 101, 116,
  32, 111, 102, 32, 105, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115,
  32, 117, 110, 100, 101, 114, 115, 116, 111, 111, 100, 32, 98, 121, 32, 116,
  104, 101, 32, 60, 98, 62, 71, 39, 77, 73, 67, 60, 47, 98, 62, 32,
  108, 97, 110, 103, 117, 97, 103, 101, 32, 105, 110, 116, 101, 114, 112, 114,
  101, 116, 101, 114, 46, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 72,
  101, 114, 101, 44, 32, 121, 111, 117, 32, 99, 97, 110, 32, 116, 104, 101,
  110, 32, 116, 101, 115, 116, 32, 115, 111, 109, 101, 32, 99, 111, 109, 109,
  97, 110, 100, 115, 32, 98, 101, 102, 111, 114, 101, 32, 99, 114, 101, 97,
  116, 105, 110, 103, 32, 121, 111, 117, 114, 32, 111, 119, 110, 32, 71, 39,
  77, 73, 67, 32, 99, 117, 115, 116, 111, 109, 32, 99, 111, 109, 109, 97,
  110, 100, 115, 32, 97, 110, 100, 32, 71, 73, 77, 80, 32, 109, 101, 110,
  117, 32, 101, 110, 116, 114, 105, 101, 115, 46, 92, 110, 92, 110, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 80, 108, 101, 97, 115, 101, 32, 108,
  111, 111, 107, 32, 97, 116, 32, 116, 104, 101, 32, 100, 111, 99, 117, 109,
  101, 110, 116, 97, 116, 105, 111, 110, 32, 114, 101, 102, 101, 114, 101, 110,
  99, 101, 32, 119, 101, 98, 32, 112, 97, 103, 101, 32, 58, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 78, 111, 116, 101, 32, 61, 32, 108, 105, 110, 107, 40, 34, 104, 116,
  116, 112, 58, 47, 47, 103, 109, 105, 99, 46, 115, 111, 117, 114, 99, 101,
  102, 111, 114, 103, 101, 46, 110, 101, 116, 47, 114, 101, 102, 101, 114, 101,
  110, 99, 101, 46, 115, 104, 116, 109, 108, 34, 41, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  123, 34, 60, 115, 109, 97, 108, 108, 62, 10, 35, 64, 103, 105, 109, 112,
  32, 58, 32, 116, 111, 32, 108, 101, 97, 114, 110, 32, 109, 111, 114, 101,
  32, 97, 98, 111, 117, 116, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101,
  32, 60, 98, 62, 71, 39, 77, 73, 67, 60, 47, 98, 62, 32, 99, 111,
  109, 109, 97, 110, 100, 115, 46, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 60, 47, 115, 109, 97, 108, 108, 62, 34, 125, 10, 35, 64, 103, 105,
  109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114,
  97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110,
  111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117, 116, 104,
  111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84, 115, 99,
  104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60, 47, 105,
  62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116, 32, 117,
  112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 49, 47, 48,
  54, 47, 49, 52, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97, 108, 108,
  62, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 68, 111, 32, 110, 111,
  116, 104, 105, 110, 103, 32, 58, 32, 103, 105, 109, 112, 95, 100, 111, 95,
  110, 111, 116, 104, 105, 110, 103, 44, 32, 103, 105, 109, 112, 95, 100, 111,
  95, 110, 111, 116, 104, 105, 110, 103, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 78, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  98, 62, 78, 111, 116, 101, 60, 47, 98, 62, 32, 58, 32, 84, 104, 105,
  115, 32, 102, 105, 108, 116, 101, 114, 115, 32, 100, 111, 101, 115, 32, 110,
  111, 116, 104, 105, 110, 103, 32, 111, 110, 32, 116, 104, 101, 32, 105, 109,
  97, 103, 101, 46, 32, 85, 115, 101, 32, 105, 116, 32, 116, 111, 32, 109,
  97, 110, 105, 112, 117, 108, 97, 116, 101, 32, 108, 97, 121, 101, 114, 115,
  32, 105, 110, 32, 99, 111, 110, 106, 117, 110, 99, 116, 105, 111, 110, 32,
  119, 105, 116, 104, 32, 116, 104, 101, 32, 105, 110, 112, 117, 116, 47, 111,
  117, 116, 112, 117, 116, 32, 111, 112, 116, 105, 111, 110, 115, 32, 111, 102,
  32, 116, 104, 101, 32, 71, 39, 77, 73, 67, 32, 112, 108, 117, 103, 45,
  105, 110, 46, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83,
  101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41,
  44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60,
  115, 109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105,
  62, 68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114,
  108, 38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32,
  32, 32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58,
  32, 60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47,
  105, 62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105,
  109, 112, 95, 100, 111, 95, 110, 111, 116, 104, 105, 110, 103, 32, 58, 10,
  35, 64, 103, 105, 109, 112, 32, 71, 114, 101, 121, 99, 32, 112, 111, 107,
  101, 114, 32, 116, 111, 117, 114, 32, 58, 32, 103, 105, 109, 112, 95, 103,
  112, 116, 44, 32, 103, 105, 109, 112, 95, 110, 111, 95, 112, 114, 101, 118,
  105, 101, 119, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 99, 111,
  114, 101, 32, 116, 121, 112, 101, 32, 61, 32, 95, 99, 104, 111, 105, 99,
  101, 40, 48, 44, 34, 65, 108, 108, 45, 116, 105, 109, 101, 115, 34, 44,
  34, 76, 97, 115, 116, 32, 53, 48, 32, 115, 101, 115, 115, 105, 111, 110,
  115, 34, 44, 34, 76, 97, 115, 116, 32, 50, 53, 32, 115, 101, 115, 115,
  105, 111, 110, 115, 34, 44, 34, 76, 97, 115, 116, 32, 49, 48, 32, 115,
  101, 115, 115, 105, 111, 110, 115, 34, 44, 34, 76, 97, 115, 116, 32, 116,
  111, 117, 114, 110, 97, 109, 101, 110, 116, 32, 53, 48, 34, 44, 34, 76,
  97, 115, 116, 32, 116, 111, 117, 114, 110, 97, 109, 101, 110, 116, 32, 50,
  53, 34, 44, 34, 76, 97, 115, 116, 32, 116, 111, 117, 114, 110, 97, 109,
  101, 110, 116, 32, 49, 48, 34, 41, 10, 35, 64, 103, 105, 109, 112, 32,
  58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111,
  114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101,
  123, 34, 60, 98, 62, 78, 111, 116, 101, 60, 47, 98, 62, 32, 58, 32,
  84, 104, 105, 115, 32, 102, 105, 108, 116, 101, 114, 115, 32, 114, 101, 110,
  100, 101, 114, 115, 32, 97, 110, 100, 32, 100, 105, 115, 112, 108, 97, 121,
  115, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 115, 99,
  111, 114, 101, 32, 98, 111, 97, 114, 100, 32, 102, 111, 114, 32, 116, 104,
  101, 32, 60, 98, 62, 71, 80, 84, 32, 40, 71, 82, 69, 89, 67, 32,
  80, 111, 107, 101, 114, 32, 84, 111, 117, 114, 41, 60, 47, 98, 62, 44,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 97, 32, 115, 109, 97, 108,
  108, 32, 97, 110, 100, 32, 108, 111, 99, 97, 108, 32, 112, 111, 107, 101,
  114, 32, 116, 111, 117, 114, 110, 97, 109, 101, 110, 116, 32, 111, 114, 103,
  97, 110, 105, 122, 101, 100, 32, 105, 110, 32, 111, 117, 114, 32, 114, 101,
  115, 101, 97, 114, 99, 104, 32, 108, 97, 98, 46, 34, 125, 59, 10, 35,
  64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101,
  112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32,
  61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65,
  117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32,
  84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59,
  60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115,
  116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49,
  49, 47, 48, 51, 47, 50, 55, 60, 47, 105, 62, 46, 60, 47, 115, 109,
  97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 103, 112, 116, 32,
  58, 10, 45, 103, 112, 116, 32, 44, 64, 123, 45, 95, 103, 105, 109, 112,
  95, 103, 112, 116, 36, 49, 125, 10, 95, 103, 105, 109, 112, 95, 103, 112,
  116, 48, 32, 58, 32, 45, 117, 32, 48, 10, 95, 103, 105, 109, 112, 95,
  103, 112, 116, 49, 32, 58, 32, 45, 117, 32, 53, 48, 10, 95, 103, 105,
  109, 112, 95, 103, 112, 116, 50, 32, 58, 32, 45, 117, 32, 50, 53, 10,
  95, 103, 105, 109, 112, 95, 103, 112, 116, 51, 32, 58, 32, 45, 117, 32,
  49, 48, 10, 95, 103, 105, 109, 112, 95, 103, 112, 116, 52, 32, 58, 32,
  45, 117, 32, 45, 53, 48, 10, 95, 103, 105, 109, 112, 95, 103, 112, 116,
  53, 32, 58, 32, 45, 117, 32, 45, 50, 53, 10, 95, 103, 105, 109, 112,
  95, 103, 112, 116, 54, 32, 58, 32, 45, 117, 32, 45, 49, 48, 10, 35,
  64, 103, 105, 109, 112, 32, 72, 105, 115, 116, 111, 103, 114, 97, 109, 32,
  97, 110, 97, 108, 121, 115, 105, 115, 32, 58, 32, 95, 110, 111, 110, 101,
  95, 44, 32, 103, 105, 109, 112, 95, 100, 105, 115, 112, 108, 97, 121, 95,
  104, 105, 115, 116, 111, 103, 114, 97, 109, 40, 49, 41, 10, 35, 64, 103,
  105, 109, 112, 32, 58, 32, 67, 108, 117, 115, 116, 101, 114, 115, 32, 61,
  32, 105, 110, 116, 40, 50, 53, 54, 44, 50, 44, 50, 53, 54, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 77, 111, 110, 111, 99, 104, 114,
  111, 109, 101, 32, 61, 32, 98, 111, 111, 108, 40, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115, 101, 112,
  97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101, 32, 61,
  32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62, 65, 117,
  116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100, 32, 84,
  115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51, 59, 60,
  47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101, 115, 116,
  32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48, 49, 48,
  47, 49, 50, 47, 50, 57, 60, 47, 105, 62, 46, 60, 47, 115, 109, 97,
  108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 100, 105, 115, 112, 108,
  97, 121, 95, 104, 105, 115, 116, 111, 103, 114, 97, 109, 32, 58, 10, 45,
  116, 111, 95, 114, 103, 98, 32, 45, 105, 102, 32, 36, 50, 32, 45, 108,
  117, 109, 105, 110, 97, 110, 99, 101, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 100, 105, 115, 112,
  108, 97, 121, 95, 104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 49,
  93, 32, 123, 119, 125, 44, 123, 104, 125, 44, 36, 49, 44, 48, 44, 50,
  53, 53, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111,
  110, 101, 10, 35, 64, 103, 105, 109, 112, 32, 73, 109, 112, 111, 114, 116,
  32, 100, 97, 116, 97, 32, 58, 32, 103, 105, 109, 112, 95, 105, 109, 112,
  111, 114, 116, 95, 105, 109, 97, 103, 101, 44, 32, 103, 105, 109, 112, 95,
  110, 111, 95, 112, 114, 101, 118, 105, 101, 119, 10, 35, 64, 103, 105, 109,
  112, 32, 58, 32, 70, 105, 108, 101, 110, 97, 109, 101, 32, 61, 32, 102,
  105, 108, 101, 40, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78,
  111, 114, 109, 97, 108, 105, 122, 101, 32, 61, 32, 98, 111, 111, 108, 40,
  49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 78, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 123, 34, 92, 110, 60, 115, 109, 97, 108,
  108, 62, 60, 98, 62, 78, 111, 116, 101, 58, 32, 60, 47, 98, 62, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 84, 104, 105, 115, 32, 102, 105,
  108, 116, 101, 114, 32, 99, 97, 110, 32, 105, 109, 112, 111, 114, 116, 32,
  97, 110, 121, 32, 105, 109, 97, 103, 101, 32, 100, 97, 116, 97, 32, 114,
  101, 97, 100, 32, 98, 121, 32, 116, 104, 101, 32, 60, 98, 62, 71, 39,
  77, 73, 67, 60, 47, 98, 62, 32, 108, 97, 110, 103, 117, 97, 103, 101,
  32, 105, 110, 116, 101, 114, 112, 114, 101, 116, 101, 114, 46, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 73, 116, 32, 105, 110, 99, 108, 117, 100,
  101, 115, 32, 101, 120, 111, 116, 105, 99, 32, 102, 111, 114, 109, 97, 116,
  115, 32, 97, 115, 32, 58, 32, 60, 105, 62, 80, 97, 110, 100, 111, 114,
  101, 44, 32, 67, 73, 109, 103, 44, 32, 73, 110, 114, 105, 109, 97, 103,
  101, 44, 32, 65, 86, 73, 47, 77, 80, 69, 71, 32, 40, 114, 101, 113,
  117, 105, 114, 101, 115, 32, 70, 70, 77, 80, 69, 71, 32, 105, 110, 115,
  116, 97, 108, 108, 101, 100, 41, 44, 32, 46, 46, 46, 60, 47, 105, 62,
  10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 60, 47, 115, 109, 97, 108,
  108, 62, 34, 125, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101,
  112, 32, 61, 32, 115, 101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44,
  32, 110, 111, 116, 101, 32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115,
  109, 97, 108, 108, 62, 65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62,
  68, 97, 118, 105, 100, 32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108,
  38, 35, 50, 51, 51, 59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32,
  32, 76, 97, 116, 101, 115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32,
  60, 105, 62, 50, 48, 49, 48, 47, 49, 50, 47, 50, 57, 60, 47, 105,
  62, 46, 60, 47, 115, 109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109,
  112, 95, 105, 109, 112, 111, 114, 116, 95, 105, 109, 97, 103, 101, 32, 58,
  10, 45, 114, 109, 32, 45, 105, 32, 34, 36, 49, 34, 32, 45, 115, 32,
  122, 32, 45, 105, 102, 32, 36, 50, 32, 45, 110, 32, 48, 44, 50, 53,
  53, 32, 45, 101, 108, 115, 101, 32, 45, 99, 32, 48, 44, 50, 53, 53,
  32, 45, 101, 110, 100, 105, 102, 10, 35, 64, 103, 105, 109, 112, 32, 83,
  111, 108, 118, 101, 32, 109, 97, 122, 101, 32, 58, 32, 103, 105, 109, 112,
  95, 115, 111, 108, 118, 101, 95, 109, 97, 122, 101, 44, 32, 103, 105, 109,
  112, 95, 115, 111, 108, 118, 101, 95, 109, 97, 122, 101, 95, 112, 114, 101,
  118, 105, 101, 119, 40, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 83, 116, 97, 114, 116, 105, 110, 103, 32, 120, 45, 99, 111, 111, 114,
  100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 53, 44, 48, 44, 49, 48,
  48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 116, 97, 114,
  116, 105, 110, 103, 32, 121, 45, 99, 111, 111, 114, 100, 32, 61, 32, 102,
  108, 111, 97, 116, 40, 53, 44, 48, 44, 49, 48, 48, 41, 10, 35, 64,
  103, 105, 109, 112, 32, 58, 32, 69, 110, 100, 105, 110, 103, 32, 120, 45,
  99, 111, 111, 114, 100, 32, 61, 32, 102, 108, 111, 97, 116, 40, 57, 53,
  44, 48, 44, 49, 48, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 69, 110, 100, 105, 110, 100, 32, 121, 45, 99, 111, 111, 114, 100, 32,
  61, 32, 102, 108, 111, 97, 116, 40, 57, 53, 44, 48, 44, 49, 48, 48,
  41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 109, 111, 111, 116,
  104, 110, 101, 115, 115, 32, 61, 32, 102, 108, 111, 97, 116, 40, 48, 46,
  49, 44, 48, 44, 49, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58, 32,
  84, 104, 105, 99, 107, 110, 101, 115, 115, 32, 61, 32, 105, 110, 116, 40,
  51, 44, 49, 44, 49, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 67, 111, 108, 111, 114, 32, 61, 32, 99, 111, 108, 111, 114, 40, 50,
  53, 53, 44, 48, 44, 48, 41, 10, 35, 64, 103, 105, 109, 112, 32, 58,
  32, 77, 97, 122, 101, 32, 116, 121, 112, 101, 32, 61, 32, 99, 104, 111,
  105, 99, 101, 40, 34, 68, 97, 114, 107, 32, 119, 97, 108, 108, 115, 34,
  44, 34, 87, 104, 105, 116, 101, 32, 119, 97, 108, 108, 115, 34, 41, 10,
  35, 64, 103, 105, 109, 112, 32, 58, 32, 83, 101, 112, 32, 61, 32, 115,
  101, 112, 97, 114, 97, 116, 111, 114, 40, 41, 44, 32, 110, 111, 116, 101,
  32, 61, 32, 110, 111, 116, 101, 40, 34, 60, 115, 109, 97, 108, 108, 62,
  65, 117, 116, 104, 111, 114, 58, 32, 60, 105, 62, 68, 97, 118, 105, 100,
  32, 84, 115, 99, 104, 117, 109, 112, 101, 114, 108, 38, 35, 50, 51, 51,
  59, 60, 47, 105, 62, 46, 32, 32, 32, 32, 32, 32, 76, 97, 116, 101,
  115, 116, 32, 117, 112, 100, 97, 116, 101, 58, 32, 60, 105, 62, 50, 48,
  49, 49, 47, 48, 57, 47, 48, 49, 60, 47, 105, 62, 46, 60, 47, 115,
  109, 97, 108, 108, 62, 34, 41, 10, 103, 105, 109, 112, 95, 115, 111, 108,
  118, 101, 95, 109, 97, 122, 101, 32, 58, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 64, 35, 10, 45, 45, 110, 111, 114, 109, 91, 45, 49, 93, 32,
  45, 103, 101, 91, 45, 49, 93, 32, 53, 48, 37, 10, 45, 105, 102, 32,
  123, 33, 36, 49, 48, 125, 32, 45, 110, 101, 103, 97, 116, 105, 118, 101,
  91, 45, 49, 93, 32, 45, 101, 110, 100, 105, 102, 10, 45, 42, 91, 45,
  49, 93, 32, 50, 53, 53, 32, 45, 45, 98, 91, 45, 49, 93, 32, 36,
  53, 37, 32, 45, 42, 91, 45, 50, 93, 32, 49, 101, 49, 48, 32, 45,
  43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 109, 105, 110, 105, 109, 97,
  108, 95, 112, 97, 116, 104, 91, 45, 49, 93, 32, 36, 49, 37, 44, 36,
  50, 37, 44, 48, 44, 36, 51, 37, 44, 36, 52, 37, 44, 48, 10, 45,
  112, 111, 105, 110, 116, 99, 108, 111, 117, 100, 91, 45, 49, 93, 32, 48,
  32, 45, 100, 105, 108, 97, 116, 101, 91, 45, 49, 93, 32, 36, 54, 32,
  45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 91, 45, 50, 93,
  44, 49, 44, 49, 44, 48, 10, 45, 116, 111, 95, 114, 103, 98, 97, 91,
  45, 49, 93, 10, 45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108,
  111, 114, 91, 45, 49, 93, 32, 48, 44, 48, 44, 49, 44, 49, 44, 49,
  44, 50, 53, 53, 44, 36, 123, 55, 45, 57, 125, 44, 50, 53, 53, 10,
  45, 114, 101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 45,
  49, 93, 32, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53,
  44, 48, 44, 48, 44, 48, 44, 48, 10, 45, 101, 108, 108, 105, 112, 115,
  101, 91, 45, 49, 93, 32, 36, 49, 37, 44, 36, 50, 37, 44, 53, 44,
  53, 44, 48, 44, 49, 44, 36, 123, 55, 45, 57, 125, 44, 50, 53, 53,
  10, 45, 101, 108, 108, 105, 112, 115, 101, 91, 45, 49, 93, 32, 36, 51,
  37, 44, 36, 52, 37, 44, 53, 44, 53, 44, 48, 44, 49, 44, 36, 123,
  55, 45, 57, 125, 44, 50, 53, 53, 10, 45, 114, 118, 91, 45, 50, 44,
  45, 49, 93, 10, 45, 109, 118, 91, 45, 50, 44, 45, 49, 93, 32, 48,
  32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 115, 111, 108, 118,
  101, 95, 109, 97, 122, 101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58,
  10, 45, 100, 114, 103, 98, 97, 10, 45, 108, 105, 110, 101, 32, 36, 49,
  37, 44, 36, 50, 37, 44, 36, 51, 37, 44, 36, 52, 37, 44, 49, 44,
  48, 120, 67, 67, 67, 67, 67, 67, 67, 67, 44, 36, 123, 55, 45, 57,
  125, 10, 45, 101, 108, 108, 105, 112, 115, 101, 32, 36, 49, 37, 44, 36,
  50, 37, 44, 51, 44, 51, 44, 48, 44, 49, 44, 36, 123, 55, 45, 57,
  125, 10, 45, 101, 108, 108, 105, 112, 115, 101, 32, 36, 49, 37, 44, 36,
  50, 37, 44, 51, 44, 51, 44, 48, 44, 49, 44, 48, 120, 49, 44, 48,
  10, 45, 101, 108, 108, 105, 112, 115, 101, 32, 36, 51, 37, 44, 36, 52,
  37, 44, 51, 44, 51, 44, 48, 44, 49, 44, 36, 123, 55, 45, 57, 125,
  10, 45, 101, 108, 108, 105, 112, 115, 101, 32, 36, 51, 37, 44, 36, 52,
  37, 44, 51, 44, 51, 44, 48, 44, 49, 44, 48, 120, 49, 44, 48, 10,
  103, 109, 105, 99, 111, 108, 95, 108, 111, 103, 111, 95, 101, 110, 32, 58,
  10, 45, 103, 105, 109, 112, 95, 108, 111, 103, 111, 32, 34, 32, 32, 32,
  32, 45, 32, 79, 110, 108, 105, 110, 101, 32, 45, 34, 10, 103, 109, 105,
  99, 111, 108, 95, 97, 100, 106, 117, 115, 116, 95, 99, 111, 108, 111, 114,
  115, 32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 97, 118, 103, 61, 123, 105, 97, 125, 32, 45,
  45, 32, 36, 97, 118, 103, 32, 45, 42, 32, 36, 49, 32, 45, 43, 32,
  36, 97, 118, 103, 10, 45, 43, 32, 123, 36, 50, 42, 50, 53, 54, 125,
  10, 45, 105, 102, 32, 123, 36, 51, 33, 61, 49, 125, 32, 45, 97, 112,
  112, 108, 121, 95, 103, 97, 109, 109, 97, 32, 123, 49, 48, 94, 36, 51,
  125, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 123, 36, 52,
  37, 51, 54, 48, 125, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109,
  111, 100, 101, 32, 123, 109, 97, 120, 40, 51, 44, 115, 41, 43, 49, 45,
  115, 37, 50, 125, 32, 45, 115, 112, 108, 105, 116, 95, 111, 112, 97, 99,
  105, 116, 121, 32, 45, 108, 91, 48, 93, 10, 45, 114, 103, 98, 50, 104,
  115, 118, 32, 45, 115, 104, 32, 48, 44, 48, 32, 45, 43, 91, 45, 49,
  93, 32, 36, 52, 32, 45, 37, 91, 45, 49, 93, 32, 51, 54, 48, 32,
  45, 114, 109, 91, 45, 49, 93, 32, 45, 104, 115, 118, 50, 114, 103, 98,
  10, 45, 101, 110, 100, 108, 10, 45, 97, 32, 99, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  99, 32, 48, 44, 50, 53, 53, 10, 103, 109, 105, 99, 111, 108, 95, 97,
  100, 106, 117, 115, 116, 95, 99, 111, 108, 111, 114, 115, 95, 112, 114, 101,
  118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 115, 112, 108,
  105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32, 34, 45, 103, 109, 105,
  99, 111, 108, 95, 97, 100, 106, 117, 115, 116, 95, 99, 111, 108, 111, 114,
  115, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 109, 105, 99, 111, 108,
  95, 99, 114, 111, 112, 32, 58, 10, 45, 99, 114, 111, 112, 32, 36, 49,
  37, 44, 36, 50, 37, 44, 36, 51, 37, 44, 36, 52, 37, 10, 103, 109,
  105, 99, 111, 108, 95, 99, 114, 111, 112, 95, 112, 114, 101, 118, 105, 101,
  119, 32, 58, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108, 101, 32, 36,
  49, 37, 44, 36, 50, 37, 44, 36, 51, 37, 44, 36, 52, 37, 44, 48,
  46, 53, 44, 49, 50, 56, 10, 45, 114, 101, 99, 116, 97, 110, 103, 108,
  101, 32, 36, 49, 37, 44, 36, 50, 37, 44, 36, 51, 37, 44, 36, 52,
  37, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48,
  10, 45, 99, 105, 114, 99, 108, 101, 32, 36, 49, 37, 44, 36, 50, 37,
  44, 51, 44, 49, 44, 48, 44, 50, 53, 53, 44, 48, 32, 45, 99, 105,
  114, 99, 108, 101, 32, 36, 49, 37, 44, 36, 50, 37, 44, 51, 44, 49,
  44, 48, 120, 70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 10, 45, 99,
  105, 114, 99, 108, 101, 32, 36, 51, 37, 44, 36, 50, 37, 44, 51, 44,
  49, 44, 48, 44, 50, 53, 53, 44, 48, 32, 45, 99, 105, 114, 99, 108,
  101, 32, 36, 51, 37, 44, 36, 50, 37, 44, 51, 44, 49, 44, 48, 120,
  70, 70, 70, 70, 70, 70, 70, 70, 44, 48, 10, 45, 99, 105, 114, 99,
  108, 101, 32, 36, 51, 37, 44, 36, 52, 37, 44, 51, 44, 49, 44, 48,
  44, 50, 53, 53, 44, 48, 32, 45, 99, 105, 114, 99, 108, 101, 32, 36,
  51, 37, 44, 36, 52, 37, 44, 51, 44, 49, 44, 48, 120, 70, 70, 70,
  70, 70, 70, 70, 70, 44, 48, 10, 45, 99, 105, 114, 99, 108, 101, 32,
  36, 49, 37, 44, 36, 52, 37, 44, 51, 44, 49, 44, 48, 44, 50, 53,
  53, 44, 48, 32, 45, 99, 105, 114, 99, 108, 101, 32, 36, 49, 37, 44,
  36, 52, 37, 44, 51, 44, 49, 44, 48, 120, 70, 70, 70, 70, 70, 70,
  70, 70, 44, 48, 10, 103, 109, 105, 99, 111, 108, 95, 101, 113, 117, 97,
  108, 105, 122, 101, 32, 58, 10, 45, 97, 112, 112, 108, 121, 95, 99, 104,
  97, 110, 110, 101, 108, 115, 32, 34, 45, 101, 113, 117, 97, 108, 105, 122,
  101, 32, 50, 53, 54, 44, 48, 44, 50, 53, 53, 34, 44, 36, 49, 44,
  49, 10, 103, 109, 105, 99, 111, 108, 95, 101, 113, 117, 97, 108, 105, 122,
  101, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109,
  112, 95, 115, 112, 108, 105, 116, 95, 112, 114, 101, 118, 105, 101, 119, 32,
  34, 45, 103, 109, 105, 99, 111, 108, 95, 101, 113, 117, 97, 108, 105, 122,
  101, 32, 36, 42, 34, 44, 36, 45, 49, 10, 103, 109, 105, 99, 111, 108,
  95, 102, 108, 105, 112, 32, 58, 10, 45, 105, 102, 32, 36, 49, 32, 45,
  109, 105, 114, 114, 111, 114, 32, 121, 32, 45, 101, 108, 115, 101, 32, 45,
  109, 105, 114, 114, 111, 114, 32, 120, 32, 45, 101, 110, 100, 105, 102, 10,
  103, 109, 105, 99, 111, 108, 95, 104, 105, 115, 116, 111, 103, 114, 97, 109,
  32, 58, 10, 45, 116, 111, 95, 114, 103, 98, 32, 45, 100, 104, 32, 54,
  52, 48, 44, 52, 56, 48, 44, 36, 49, 10, 103, 109, 105, 99, 111, 108,
  95, 104, 105, 115, 116, 111, 103, 114, 97, 109, 95, 112, 114, 101, 118, 105,
  101, 119, 32, 58, 10, 45, 116, 111, 95, 114, 103, 98, 32, 45, 100, 104,
  32, 51, 50, 48, 44, 50, 52, 48, 44, 36, 49, 10, 103, 109, 105, 99,
  111, 108, 95, 114, 101, 115, 105, 122, 101, 32, 58, 10, 45, 105, 102, 32,
  123, 36, 49, 61, 61, 48, 125, 10, 45, 114, 101, 115, 105, 122, 101, 32,
  36, 50, 37, 44, 36, 50, 37, 44, 49, 44, 49, 48, 48, 37, 44, 54,
  10, 45, 101, 108, 105, 102, 32, 123, 36, 49, 61, 61, 49, 125, 10, 45,
  114, 101, 115, 105, 122, 101, 50, 100, 120, 32, 36, 51, 44, 54, 10, 45,
  101, 108, 115, 101, 10, 45, 114, 101, 115, 105, 122, 101, 50, 100, 121, 32,
  36, 52, 44, 54, 10, 45, 101, 110, 100, 105, 102, 10, 45, 99, 32, 48,
  44, 50, 53, 53, 10, 103, 109, 105, 99, 111, 108, 95, 114, 111, 116, 97,
  116, 101, 32, 58, 10, 45, 105, 102, 32, 36, 50, 10, 45, 114, 111, 116,
  97, 116, 101, 32, 123, 57, 48, 42, 114, 111, 117, 110, 100, 40, 36, 49,
  47, 57, 48, 41, 125, 44, 48, 44, 48, 10, 45, 101, 108, 115, 101, 10,
  45, 116, 111, 95, 114, 103, 98, 97, 32, 45, 114, 111, 116, 97, 116, 101,
  32, 36, 49, 44, 49, 44, 36, 51, 10, 45, 101, 110, 100, 105, 102, 10,
  95, 103, 109, 105, 99, 111, 108, 95, 114, 103, 98, 95, 100, 105, 115, 116,
  114, 105, 98, 117, 116, 105, 111, 110, 32, 58, 10, 45, 100, 105, 115, 116,
  114, 105, 98, 117, 116, 105, 111, 110, 51, 100, 32, 45, 99, 111, 108, 111,
  114, 99, 117, 98, 101, 51, 100, 32, 45, 112, 51, 100, 91, 45, 49, 93,
  32, 49, 32, 45, 43, 51, 100, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  52, 10, 45, 45, 115, 110, 97, 112, 115, 104, 111, 116, 51, 100, 91, 48,
  93, 32, 36, 49, 44, 48, 46, 57, 44, 50, 53, 53, 10, 45, 114, 51,
  100, 91, 48, 93, 32, 48, 44, 49, 44, 48, 46, 50, 44, 57, 48, 10,
  45, 100, 111, 110, 101, 10, 45, 114, 109, 91, 48, 93, 32, 45, 97, 117,
  116, 111, 99, 114, 111, 112, 32, 45, 45, 32, 50, 53, 53, 10, 45, 114,
  32, 64, 123, 45, 109, 97, 120, 95, 119, 104, 125, 44, 49, 44, 51, 44,
  48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 43, 32, 50,
  53, 53, 32, 45, 102, 114, 97, 109, 101, 32, 53, 44, 53, 44, 50, 53,
  53, 32, 45, 102, 114, 97, 109, 101, 32, 49, 44, 49, 44, 48, 32, 45,
  97, 112, 112, 101, 110, 100, 95, 116, 105, 108, 101, 115, 32, 44, 10, 103,
  109, 105, 99, 111, 108, 95, 114, 103, 98, 95, 100, 105, 115, 116, 114, 105,
  98, 117, 116, 105, 111, 110, 32, 58, 10, 45, 95, 103, 109, 105, 99, 111,
  108, 95, 114, 103, 98, 95, 100, 105, 115, 116, 114, 105, 98, 117, 116, 105,
  111, 110, 32, 53, 49, 50, 10, 103, 109, 105, 99, 111, 108, 95, 114, 103,
  98, 95, 100, 105, 115, 116, 114, 105, 98, 117, 116, 105, 111, 110, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 95, 103, 109, 105, 99, 111,
  108, 95, 114, 103, 98, 95, 100, 105, 115, 116, 114, 105, 98, 117, 116, 105,
  111, 110, 32, 51, 50, 48, 10, 103, 109, 105, 99, 111, 108, 95, 97, 110,
  105, 109, 97, 116, 101, 95, 101, 108, 101, 118, 97, 116, 105, 111, 110, 51,
  100, 32, 58, 10, 45, 95, 103, 105, 109, 112, 95, 101, 108, 101, 118, 97,
  116, 105, 111, 110, 51, 100, 32, 36, 123, 50, 45, 51, 125, 10, 45, 97,
  110, 105, 109, 97, 116, 101, 32, 103, 105, 109, 112, 95, 114, 101, 110, 100,
  101, 114, 51, 100, 44, 34, 36, 123, 52, 45, 53, 125, 44, 36, 123, 55,
  45, 49, 54, 125, 44, 36, 54, 34, 44, 92, 10, 34, 36, 123, 52, 45,
  53, 125, 44, 36, 123, 49, 55, 45, 50, 54, 125, 44, 36, 54, 34, 44,
  36, 49, 10, 45, 111, 32, 36, 95, 111, 117, 116, 112, 117, 116, 46, 103,
  105, 102, 44, 49, 48, 10, 45, 114, 109, 10, 103, 109, 105, 99, 111, 108,
  95, 97, 110, 105, 109, 97, 116, 101, 95, 101, 108, 101, 118, 97, 116, 105,
  111, 110, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 101, 108, 101,
  118, 97, 116, 105, 111, 110, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119,
  32, 36, 49, 44, 49, 44, 48, 44, 92, 34, 92, 34, 44, 36, 123, 50,
  45, 45, 49, 125, 10, 103, 109, 105, 99, 111, 108, 95, 97, 110, 105, 109,
  97, 116, 101, 95, 101, 120, 116, 114, 117, 100, 101, 51, 100, 32, 58, 10,
  45, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 101, 120,
  116, 114, 117, 100, 101, 51, 100, 32, 36, 49, 44, 49, 44, 48, 44, 92,
  34, 92, 34, 44, 36, 123, 50, 45, 45, 49, 125, 10, 103, 109, 105, 99,
  111, 108, 95, 97, 110, 105, 109, 97, 116, 101, 95, 101, 120, 116, 114, 117,
  100, 101, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32, 58, 10, 45,
  103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95, 101, 120, 116,
  114, 117, 100, 101, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36,
  49, 44, 49, 44, 48, 44, 92, 34, 92, 34, 44, 36, 123, 50, 45, 45,
  49, 125, 10, 103, 109, 105, 99, 111, 108, 95, 97, 110, 105, 109, 97, 116,
  101, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 32,
  58, 10, 45, 103, 105, 109, 112, 95, 97, 110, 105, 109, 97, 116, 101, 95,
  105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 32, 36, 49,
  44, 49, 44, 48, 44, 92, 34, 92, 34, 44, 36, 123, 50, 45, 45, 49,
  125, 10, 103, 109, 105, 99, 111, 108, 95, 97, 110, 105, 109, 97, 116, 101,
  95, 105, 109, 97, 103, 101, 111, 98, 106, 101, 99, 116, 51, 100, 95, 112,
  114, 101, 118, 105, 101, 119, 32, 58, 10, 45, 103, 105, 109, 112, 95, 97,
  110, 105, 109, 97, 116, 101, 95, 105, 109, 97, 103, 101, 111, 98, 106, 101,
  99, 116, 51, 100, 95, 112, 114, 101, 118, 105, 101, 119, 32, 36, 49, 44,
  49, 44, 48, 44, 92, 34, 92, 34, 44, 36, 123, 50, 45, 45, 49, 125,
  10, 103, 105, 109, 112, 95, 115, 112, 108, 105, 116, 95, 102, 114, 101, 113,
  32, 58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 10, 45, 45,
  98, 91, 45, 49, 93, 32, 36, 49, 32, 45, 45, 91, 45, 50, 93, 32,
  91, 45, 49, 93, 32, 45, 47, 91, 45, 50, 93, 32, 50, 32, 45, 43,
  91, 45, 50, 93, 32, 49, 50, 56, 32, 45, 114, 118, 91, 45, 50, 44,
  45, 49, 93, 10, 45, 109, 118, 91, 45, 50, 44, 45, 49, 93, 32, 48,
  32, 45, 100, 111, 110, 101, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 102, 114, 101, 113, 32, 58, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 10, 45,
  45, 91, 45, 49, 93, 32, 49, 50, 56, 32, 45, 42, 91, 45, 49, 93,
  32, 50, 32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 32, 45, 99, 91,
  45, 49, 93, 32, 48, 44, 50, 53, 53, 10, 45, 109, 118, 91, 45, 49,
  93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 98, 108, 101, 110, 100, 95,
  115, 104, 97, 112, 101, 97, 118, 101, 114, 97, 103, 101, 32, 58, 32, 45,
  98, 108, 101, 110, 100, 32, 115, 104, 97, 112, 101, 97, 118, 101, 114, 97,
  103, 101, 48, 10, 99, 111, 109, 112, 111, 115, 101, 95, 97, 108, 112, 104,
  97, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109,
  112, 111, 115, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111,
  45, 98, 121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 97,
  108, 112, 104, 97, 32, 98, 108, 101, 110, 100, 105, 110, 103, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110,
  116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123,
  36, 62, 43, 49, 125, 93, 10, 45, 114, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 44, 91, 45, 50, 93, 44, 91, 45, 50, 93, 44, 49, 48, 48,
  37, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 116,
  111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 91, 45, 50, 93, 32,
  123, 97, 49, 61, 33, 40, 64, 123, 45, 50, 44, 115, 125, 37, 50, 41,
  59, 97, 50, 61, 33, 40, 115, 37, 50, 41, 59, 109, 97, 120, 40, 64,
  123, 45, 50, 44, 115, 125, 45, 97, 49, 44, 115, 45, 97, 50, 41, 43,
  97, 49, 125, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100,
  101, 91, 45, 49, 93, 32, 123, 97, 61, 109, 97, 120, 40, 64, 123, 45,
  50, 44, 115, 125, 44, 115, 41, 59, 97, 43, 40, 97, 37, 50, 41, 125,
  10, 45, 105, 102, 32, 123, 64, 123, 45, 50, 44, 115, 125, 61, 61, 50,
  124, 124, 64, 123, 45, 50, 44, 115, 125, 61, 61, 52, 125, 10, 45, 95,
  99, 111, 109, 112, 111, 115, 101, 95, 97, 108, 112, 104, 97, 91, 45, 50,
  93, 32, 45, 95, 99, 111, 109, 112, 111, 115, 101, 95, 97, 108, 112, 104,
  97, 91, 45, 49, 93, 10, 45, 115, 104, 91, 45, 49, 93, 32, 123, 115,
  45, 49, 125, 44, 123, 115, 45, 49, 125, 32, 45, 45, 42, 91, 45, 51,
  44, 45, 49, 93, 32, 45, 114, 109, 91, 45, 50, 93, 32, 45, 43, 91,
  45, 51, 44, 45, 50, 93, 32, 45, 45, 91, 45, 50, 44, 45, 49, 93,
  10, 45, 115, 104, 91, 45, 49, 93, 32, 48, 44, 123, 115, 45, 50, 125,
  32, 45, 115, 104, 91, 45, 50, 93, 32, 123, 64, 123, 45, 50, 44, 115,
  125, 45, 49, 125, 44, 123, 64, 123, 45, 50, 44, 115, 125, 45, 49, 125,
  10, 45, 109, 97, 120, 91, 45, 49, 93, 32, 49, 101, 45, 49, 48, 32,
  45, 47, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 42, 91, 45,
  49, 93, 32, 50, 53, 53, 32, 45, 114, 109, 91, 45, 50, 44, 45, 49,
  93, 10, 45, 101, 108, 115, 101, 10, 45, 115, 104, 91, 45, 49, 93, 32,
  48, 44, 123, 115, 45, 50, 125, 32, 45, 115, 104, 91, 45, 50, 93, 32,
  123, 64, 123, 45, 50, 44, 115, 125, 45, 49, 125, 44, 123, 64, 123, 45,
  50, 44, 115, 125, 45, 49, 125, 32, 45, 45, 91, 45, 50, 93, 32, 91,
  45, 52, 93, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 47,
  91, 45, 49, 93, 32, 50, 53, 53, 32, 45, 114, 109, 91, 45, 49, 93,
  32, 45, 43, 91, 45, 50, 44, 45, 49, 93, 10, 45, 101, 110, 100, 105,
  102, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 99,
  32, 48, 44, 50, 53, 53, 32, 45, 118, 32, 43, 10, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 97, 108, 112, 104, 97, 32, 58, 10, 45, 115, 104,
  91, 45, 49, 93, 32, 48, 44, 123, 115, 45, 50, 125, 32, 45, 115, 104,
  91, 45, 50, 93, 32, 123, 64, 123, 45, 50, 44, 115, 125, 45, 49, 125,
  44, 123, 64, 123, 45, 50, 44, 115, 125, 45, 49, 125, 32, 45, 109, 97,
  120, 91, 45, 49, 93, 32, 49, 101, 45, 49, 48, 32, 45, 47, 91, 45,
  49, 93, 32, 50, 53, 53, 32, 45, 42, 91, 45, 50, 44, 45, 49, 93,
  32, 45, 114, 109, 91, 45, 49, 93, 10, 99, 111, 109, 112, 111, 115, 101,
  95, 97, 118, 101, 114, 97, 103, 101, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 67, 111, 109, 112, 111, 115, 101, 32, 105, 109, 97, 103,
  101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111, 44, 32,
  117, 115, 105, 110, 103, 32, 97, 118, 101, 114, 97, 103, 101, 32, 109, 111,
  100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108,
  91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 45, 116, 111, 95,
  99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48, 32, 45, 114, 91, 45,
  49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 46, 53, 44,
  48, 46, 53, 32, 45, 43, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 47, 32, 50, 32, 45, 118, 32, 43, 10, 99, 111, 109,
  112, 111, 115, 101, 95, 99, 111, 108, 111, 114, 98, 117, 114, 110, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 111, 115,
  101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121,
  45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 99, 111, 108, 111,
  114, 98, 117, 114, 110, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64,
  35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43,
  49, 125, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100,
  101, 32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44,
  48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 45, 91, 45,
  50, 93, 32, 50, 53, 53, 32, 45, 43, 91, 45, 49, 93, 32, 48, 46,
  49, 32, 45, 47, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 42, 32, 50, 53, 54, 32, 45, 43, 32, 50, 53, 53, 32, 45,
  99, 32, 48, 44, 50, 53, 53, 32, 45, 118, 32, 43, 10, 99, 111, 109,
  112, 111, 115, 101, 95, 100, 97, 114, 107, 101, 110, 32, 58, 10, 45, 101,
  91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 111, 115, 101, 32, 105,
  109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119,
  111, 44, 32, 117, 115, 105, 110, 103, 32, 100, 97, 114, 107, 101, 110, 32,
  109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32,
  45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 45, 116,
  111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48, 32, 45, 114,
  91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 32, 45, 109, 105, 110, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 99, 111, 109, 112,
  111, 115, 101, 95, 100, 105, 102, 102, 101, 114, 101, 110, 99, 101, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 111, 115,
  101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121,
  45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 100, 105, 102, 102,
  101, 114, 101, 110, 99, 101, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40,
  64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62,
  43, 49, 125, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111,
  100, 101, 32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 45, 10,
  45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 97, 98, 115,
  32, 45, 118, 32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 100, 105,
  118, 105, 100, 101, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34,
  67, 111, 109, 112, 111, 115, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32,
  116, 119, 111, 45, 98, 121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110,
  103, 32, 100, 105, 118, 105, 100, 101, 32, 109, 111, 100, 101, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110,
  116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123,
  36, 62, 43, 49, 125, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114,
  109, 111, 100, 101, 32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45,
  42, 91, 45, 50, 93, 32, 50, 53, 54, 32, 45, 43, 91, 45, 49, 93,
  32, 49, 32, 45, 47, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110,
  101, 32, 45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 118, 32, 43, 10,
  99, 111, 109, 112, 111, 115, 101, 95, 100, 111, 100, 103, 101, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 111, 115, 101,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45,
  116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 100, 111, 100, 103, 101,
  32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125,
  32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 45,
  116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48, 32, 45,
  114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48,
  46, 53, 44, 48, 46, 53, 32, 45, 45, 91, 45, 49, 93, 32, 50, 53,
  53, 46, 49, 32, 45, 47, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 42, 32, 45, 50, 53, 54, 32, 45, 99, 32, 48, 44,
  50, 53, 53, 32, 45, 118, 32, 43, 10, 99, 111, 109, 112, 111, 115, 101,
  95, 101, 100, 103, 101, 115, 32, 58, 32, 45, 99, 104, 101, 99, 107, 32,
  123, 36, 49, 62, 61, 48, 125, 10, 45, 101, 91, 94, 45, 49, 93, 32,
  34, 67, 111, 109, 112, 111, 115, 101, 32, 105, 109, 97, 103, 101, 36, 63,
  32, 117, 115, 105, 110, 103, 32, 101, 100, 103, 101, 32, 109, 111, 100, 101,
  44, 32, 119, 105, 116, 104, 32, 115, 109, 111, 111, 116, 104, 110, 101, 115,
  115, 32, 36, 49, 46, 34, 10, 45, 105, 102, 32, 123, 64, 35, 62, 49,
  125, 32, 45, 118, 32, 45, 32, 45, 116, 111, 95, 114, 103, 98, 32, 45,
  114, 91, 94, 48, 93, 32, 91, 48, 93, 44, 48, 44, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 32, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35,
  32, 45, 108, 91, 36, 62, 93, 10, 45, 45, 103, 114, 97, 100, 105, 101,
  110, 116, 95, 110, 111, 114, 109, 32, 45, 43, 91, 45, 49, 93, 32, 49,
  32, 45, 98, 91, 45, 49, 93, 32, 36, 49, 32, 45, 110, 91, 45, 49,
  93, 32, 49, 44, 49, 48, 32, 45, 115, 113, 114, 91, 45, 49, 93, 32,
  45, 115, 91, 45, 50, 93, 32, 99, 32, 45, 42, 91, 45, 52, 45, 45,
  50, 93, 32, 91, 45, 49, 93, 32, 45, 97, 91, 45, 52, 45, 45, 49,
  93, 32, 99, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32,
  45, 114, 91, 94, 48, 93, 32, 91, 48, 93, 44, 48, 44, 48, 44, 48,
  46, 53, 44, 48, 46, 53, 32, 45, 43, 32, 45, 115, 91, 45, 49, 93,
  32, 99, 32, 45, 47, 91, 45, 52, 45, 45, 50, 93, 32, 91, 45, 49,
  93, 32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 97, 91, 45, 51, 45,
  45, 49, 93, 32, 99, 32, 45, 118, 32, 43, 32, 45, 101, 110, 100, 105,
  102, 10, 99, 111, 109, 112, 111, 115, 101, 95, 101, 120, 99, 108, 117, 115,
  105, 111, 110, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67,
  111, 109, 112, 111, 115, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116,
  119, 111, 45, 98, 121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103,
  32, 101, 120, 99, 108, 117, 115, 105, 111, 110, 32, 109, 111, 100, 101, 46,
  34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123,
  105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62,
  44, 123, 36, 62, 43, 49, 125, 93, 10, 45, 116, 111, 95, 99, 111, 108,
  111, 114, 109, 111, 100, 101, 32, 48, 32, 45, 114, 91, 45, 49, 93, 32,
  91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53,
  32, 45, 45, 42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45, 47,
  91, 45, 49, 93, 32, 45, 49, 50, 56, 32, 45, 43, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 99, 111,
  109, 112, 111, 115, 101, 95, 102, 97, 100, 101, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 111, 115, 101, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 117, 115, 105, 110, 103, 32, 102, 97, 100, 105,
  110, 103, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 91, 94, 48, 93, 32, 64, 123, 45, 109, 97, 120, 95, 119, 104, 100,
  125, 44, 49, 48, 48, 37, 44, 51, 10, 45, 114, 91, 49, 45, 45, 50,
  93, 32, 49, 48, 48, 37, 44, 49, 48, 48, 37, 44, 49, 48, 48, 37,
  44, 64, 123, 45, 109, 97, 120, 95, 115, 125, 32, 45, 99, 104, 97, 110,
  110, 101, 108, 115, 91, 45, 49, 93, 32, 48, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 64, 35, 45, 49, 125, 32, 45, 45, 45, 91, 45, 49,
  93, 32, 36, 62, 32, 45, 97, 98, 115, 91, 45, 49, 93, 32, 45, 45,
  91, 45, 49, 93, 32, 49, 32, 45, 42, 91, 45, 49, 93, 32, 45, 49,
  32, 45, 109, 97, 120, 91, 45, 49, 93, 32, 48, 32, 45, 42, 91, 36,
  62, 44, 45, 49, 93, 32, 45, 100, 111, 110, 101, 10, 45, 114, 109, 91,
  45, 49, 93, 32, 45, 43, 32, 45, 118, 32, 43, 10, 99, 111, 109, 112,
  111, 115, 101, 95, 102, 114, 101, 101, 122, 101, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 111, 115, 101, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111,
  44, 32, 117, 115, 105, 110, 103, 32, 102, 114, 101, 101, 122, 101, 32, 109,
  111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45,
  108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 45, 116, 111,
  95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48, 32, 45, 114, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 46, 53,
  44, 48, 46, 53, 32, 45, 45, 91, 45, 50, 93, 32, 50, 53, 53, 32,
  45, 115, 113, 114, 91, 45, 50, 93, 32, 45, 43, 91, 45, 49, 93, 32,
  48, 46, 49, 32, 45, 47, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 45, 32, 50, 53, 53, 32, 45, 42, 32, 45, 49, 32,
  45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 118, 32, 43, 10, 99, 111,
  109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 101, 120, 116, 114, 97,
  99, 116, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111,
  109, 112, 111, 115, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119,
  111, 45, 98, 121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32,
  103, 114, 97, 105, 110, 32, 101, 120, 116, 114, 97, 99, 116, 32, 109, 111,
  100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108,
  91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 45, 116, 111, 95,
  99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48, 32, 45, 114, 91, 45,
  49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 46, 53, 44,
  48, 46, 53, 32, 45, 45, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 43, 32, 49, 50, 56, 32, 45, 99, 32, 48, 44, 50,
  53, 53, 32, 45, 118, 32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95,
  103, 114, 97, 105, 110, 109, 101, 114, 103, 101, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 111, 115, 101, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111,
  44, 32, 117, 115, 105, 110, 103, 32, 103, 114, 97, 105, 110, 32, 109, 101,
  114, 103, 101, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47,
  50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125,
  93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32,
  48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44,
  48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 43, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 45, 32, 49, 50, 56, 32,
  45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 118, 32, 43, 10, 99, 111,
  109, 112, 111, 115, 101, 95, 104, 97, 114, 100, 108, 105, 103, 104, 116, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 111,
  115, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98,
  121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 104, 97, 114,
  100, 32, 108, 105, 103, 104, 116, 32, 109, 111, 100, 101, 46, 34, 10, 45,
  118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116,
  40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36,
  62, 43, 49, 125, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109,
  111, 100, 101, 32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50,
  93, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 10, 45, 45,
  103, 101, 91, 45, 49, 93, 32, 49, 50, 56, 32, 45, 45, 42, 91, 45,
  51, 93, 32, 91, 45, 50, 93, 32, 45, 47, 91, 45, 49, 93, 32, 49,
  50, 56, 10, 45, 45, 91, 45, 52, 44, 45, 51, 93, 32, 50, 53, 53,
  32, 45, 42, 91, 45, 52, 44, 45, 51, 93, 32, 45, 47, 91, 45, 51,
  93, 32, 49, 50, 56, 32, 45, 45, 91, 45, 51, 93, 32, 50, 53, 53,
  32, 45, 42, 91, 45, 51, 93, 32, 45, 49, 10, 45, 42, 91, 45, 51,
  93, 32, 91, 45, 50, 93, 32, 45, 42, 91, 45, 50, 93, 32, 45, 49,
  32, 45, 43, 91, 45, 50, 93, 32, 49, 32, 45, 42, 91, 45, 50, 44,
  45, 49, 93, 32, 45, 43, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95,
  104, 117, 101, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67,
  111, 109, 112, 111, 115, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116,
  119, 111, 45, 98, 121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103,
  32, 104, 117, 101, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35,
  47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49,
  125, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101,
  32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48,
  44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 116, 111, 95, 114,
  103, 98, 97, 32, 45, 115, 104, 32, 48, 44, 50, 10, 45, 114, 103, 98,
  50, 104, 115, 118, 91, 45, 50, 44, 45, 49, 93, 32, 45, 115, 104, 91,
  45, 50, 93, 32, 48, 44, 48, 32, 45, 106, 91, 45, 50, 93, 32, 91,
  45, 49, 93, 32, 45, 114, 109, 91, 45, 53, 44, 45, 51, 44, 45, 49,
  93, 32, 45, 104, 115, 118, 50, 114, 103, 98, 91, 45, 49, 93, 32, 45,
  114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 118, 32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95,
  105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 111, 115, 101,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45,
  116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 105, 110, 116, 101, 114,
  112, 111, 108, 97, 116, 105, 111, 110, 32, 109, 111, 100, 101, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110,
  116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123,
  36, 62, 43, 49, 125, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114,
  109, 111, 100, 101, 32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45,
  50, 93, 44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45,
  42, 32, 48, 46, 48, 49, 50, 50, 55, 49, 56, 52, 54, 32, 45, 99,
  111, 115, 32, 45, 47, 32, 45, 52, 32, 45, 43, 10, 45, 101, 110, 100,
  108, 32, 45, 100, 111, 110, 101, 32, 45, 43, 32, 48, 46, 53, 32, 45,
  42, 32, 50, 53, 54, 32, 45, 118, 32, 43, 10, 99, 111, 109, 112, 111,
  115, 101, 95, 108, 105, 103, 104, 116, 101, 110, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 111, 115, 101, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111,
  44, 32, 117, 115, 105, 110, 103, 32, 108, 105, 103, 104, 116, 101, 110, 32,
  109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112,
  101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32,
  45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 45, 116,
  111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48, 32, 45, 114,
  91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 46,
  53, 44, 48, 46, 53, 32, 45, 109, 97, 120, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 99, 111, 109, 112,
  111, 115, 101, 95, 108, 105, 103, 104, 116, 110, 101, 115, 115, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 111, 115, 101,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45,
  116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 108, 105, 103, 104, 116,
  110, 101, 115, 115, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35,
  47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49,
  125, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101,
  32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48,
  44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 116, 111, 95, 114,
  103, 98, 97, 32, 45, 115, 104, 32, 48, 44, 50, 10, 45, 114, 103, 98,
  50, 108, 97, 98, 91, 45, 50, 44, 45, 49, 93, 32, 45, 115, 104, 91,
  45, 50, 93, 32, 48, 44, 48, 32, 45, 106, 91, 45, 50, 93, 32, 91,
  45, 49, 93, 44, 48, 44, 48, 44, 48, 44, 48, 32, 45, 114, 109, 91,
  45, 53, 44, 45, 51, 44, 45, 49, 93, 32, 45, 108, 97, 98, 50, 114,
  103, 98, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10,
  99, 111, 109, 112, 111, 115, 101, 95, 108, 117, 109, 105, 110, 97, 110, 99,
  101, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109,
  112, 111, 115, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111,
  45, 98, 121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 108,
  117, 109, 105, 110, 97, 110, 99, 101, 32, 109, 111, 100, 101, 46, 34, 10,
  45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110,
  116, 40, 64, 35, 47, 50, 41, 125, 10, 45, 116, 111, 95, 99, 111, 108,
  111, 114, 109, 111, 100, 101, 91, 45, 50, 44, 45, 49, 93, 32, 48, 32,
  45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44,
  48, 46, 53, 44, 48, 46, 53, 32, 45, 116, 111, 95, 114, 103, 98, 97,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 115, 104, 91, 45, 50, 44, 45,
  49, 93, 32, 48, 44, 50, 10, 45, 114, 103, 98, 50, 121, 99, 98, 99,
  114, 91, 45, 50, 44, 45, 49, 93, 32, 45, 115, 104, 91, 45, 50, 93,
  32, 48, 44, 48, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93,
  44, 48, 44, 48, 44, 48, 44, 48, 32, 45, 114, 109, 91, 45, 53, 44,
  45, 51, 44, 45, 49, 93, 32, 45, 121, 99, 98, 99, 114, 50, 114, 103,
  98, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 109,
  118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 32, 45, 118,
  32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 109, 101, 100, 105, 97,
  110, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109,
  112, 111, 115, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 117, 115, 105,
  110, 103, 32, 109, 101, 100, 105, 97, 110, 32, 109, 111, 100, 101, 46, 34,
  10, 45, 105, 102, 32, 123, 64, 35, 61, 61, 49, 125, 32, 45, 114, 101,
  116, 117, 114, 110, 32, 45, 101, 110, 100, 105, 102, 10, 45, 118, 32, 45,
  32, 45, 114, 91, 94, 48, 93, 32, 91, 48, 93, 44, 48, 44, 48, 44,
  48, 46, 53, 44, 48, 46, 53, 32, 45, 97, 32, 122, 32, 45, 112, 101,
  114, 109, 117, 116, 101, 32, 122, 120, 121, 99, 32, 45, 115, 32, 121, 44,
  45, 54, 52, 10, 45, 114, 101, 112, 101, 97, 116, 32, 64, 35, 32, 45,
  108, 91, 36, 62, 93, 10, 45, 114, 32, 49, 48, 48, 37, 44, 123, 119,
  42, 49, 48, 48, 125, 37, 10, 45, 115, 32, 122, 32, 45, 109, 101, 100,
  105, 97, 110, 32, 123, 119, 125, 32, 119, 61, 123, 119, 125, 32, 45, 99,
  111, 108, 117, 109, 110, 115, 32, 123, 105, 110, 116, 40, 119, 47, 50, 41,
  125, 32, 45, 114, 32, 49, 44, 123, 104, 47, 36, 119, 125, 32, 45, 97,
  32, 122, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45,
  97, 32, 121, 32, 45, 112, 101, 114, 109, 117, 116, 101, 32, 121, 122, 120,
  99, 32, 45, 118, 32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 109,
  117, 108, 116, 105, 112, 108, 121, 32, 58, 10, 45, 101, 91, 94, 45, 49,
  93, 32, 34, 67, 111, 109, 112, 111, 115, 101, 32, 105, 109, 97, 103, 101,
  36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111, 44, 32, 117,
  115, 105, 110, 103, 32, 109, 117, 108, 116, 105, 112, 108, 121, 32, 109, 111,
  100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108,
  91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 45, 116, 111, 95,
  99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48, 32, 45, 114, 91, 45,
  49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 46, 53, 44,
  48, 46, 53, 32, 45, 42, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111,
  110, 101, 32, 45, 47, 32, 50, 53, 53, 32, 45, 118, 32, 43, 10, 99,
  111, 109, 112, 111, 115, 101, 95, 110, 101, 103, 97, 116, 105, 111, 110, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 111,
  115, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98,
  121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 110, 101, 103,
  97, 116, 105, 111, 110, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64,
  35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43,
  49, 125, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100,
  101, 32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44,
  48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 43, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 45, 32, 50, 53,
  53, 32, 45, 97, 98, 115, 32, 45, 45, 32, 50, 53, 53, 32, 45, 42,
  32, 45, 49, 32, 45, 118, 32, 43, 10, 99, 111, 109, 112, 111, 115, 101,
  95, 111, 118, 101, 114, 108, 97, 121, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 67, 111, 109, 112, 111, 115, 101, 32, 105, 109, 97, 103,
  101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111, 44, 32,
  117, 115, 105, 110, 103, 32, 111, 118, 101, 114, 108, 97, 121, 32, 109, 111,
  100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 108,
  91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 45, 116, 111, 95,
  99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48, 32, 45, 114, 91, 45,
  49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 46, 53, 44,
  48, 46, 53, 10, 45, 45, 103, 101, 91, 45, 50, 93, 32, 49, 50, 56,
  10, 45, 45, 42, 91, 45, 51, 93, 32, 91, 45, 50, 93, 32, 45, 47,
  91, 45, 49, 93, 32, 49, 50, 56, 10, 45, 45, 91, 45, 52, 44, 45,
  51, 93, 32, 50, 53, 53, 32, 45, 42, 91, 45, 52, 44, 45, 51, 93,
  32, 45, 47, 91, 45, 51, 93, 32, 49, 50, 56, 32, 45, 45, 91, 45,
  51, 93, 32, 50, 53, 53, 32, 45, 42, 91, 45, 51, 93, 32, 45, 49,
  10, 45, 42, 91, 45, 51, 93, 32, 91, 45, 50, 93, 32, 45, 42, 91,
  45, 50, 93, 32, 45, 49, 32, 45, 43, 91, 45, 50, 93, 32, 49, 32,
  45, 42, 91, 45, 50, 44, 45, 49, 93, 32, 45, 43, 10, 45, 101, 110,
  100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 99, 111,
  109, 112, 111, 115, 101, 95, 114, 101, 102, 108, 101, 99, 116, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 111, 115, 101,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45,
  116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 114, 101, 102, 108, 101,
  99, 116, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50,
  41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93,
  10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48,
  32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 115, 113, 114, 91, 45, 50,
  93, 32, 45, 45, 91, 45, 49, 93, 32, 50, 53, 53, 46, 49, 32, 45,
  47, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 42,
  32, 45, 49, 32, 45, 99, 32, 48, 44, 50, 53, 53, 32, 45, 118, 32,
  43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 114, 103, 98, 97, 32, 58,
  10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 111, 115,
  101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121,
  45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 97, 108, 112, 104,
  97, 32, 98, 108, 101, 110, 100, 105, 110, 103, 46, 34, 10, 45, 118, 32,
  45, 32, 45, 116, 111, 95, 114, 103, 98, 91, 48, 45, 45, 49, 58, 50,
  93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 97, 108, 112, 104, 97,
  32, 45, 118, 32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 115, 97,
  116, 117, 114, 97, 116, 105, 111, 110, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 67, 111, 109, 112, 111, 115, 101, 32, 105, 109, 97, 103,
  101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111, 44, 32,
  117, 115, 105, 110, 103, 32, 115, 97, 116, 117, 114, 97, 116, 105, 111, 110,
  32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125,
  32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 45,
  116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48, 32, 45,
  114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48,
  46, 53, 44, 48, 46, 53, 32, 45, 116, 111, 95, 114, 103, 98, 97, 32,
  45, 115, 104, 32, 48, 44, 50, 10, 45, 114, 103, 98, 50, 104, 115, 118,
  91, 45, 50, 44, 45, 49, 93, 32, 45, 115, 104, 91, 45, 50, 93, 32,
  49, 44, 49, 32, 45, 106, 91, 45, 50, 93, 32, 91, 45, 49, 93, 44,
  48, 44, 48, 44, 48, 44, 49, 32, 45, 114, 109, 91, 45, 53, 44, 45,
  51, 44, 45, 49, 93, 32, 45, 104, 115, 118, 50, 114, 103, 98, 91, 45,
  49, 93, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 101, 110, 100, 108,
  32, 45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 99, 111, 109, 112,
  111, 115, 101, 95, 115, 99, 114, 101, 101, 110, 32, 58, 10, 45, 101, 91,
  94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 111, 115, 101, 32, 105, 109,
  97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111,
  44, 32, 117, 115, 105, 110, 103, 32, 115, 99, 114, 101, 101, 110, 32, 109,
  111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45,
  108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 45, 116, 111,
  95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48, 32, 45, 114, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 46, 53,
  44, 48, 46, 53, 32, 45, 45, 32, 50, 53, 53, 32, 45, 42, 10, 45,
  101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 47, 32, 50, 53,
  54, 32, 45, 45, 32, 50, 53, 53, 32, 45, 42, 32, 45, 49, 32, 45,
  118, 32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 115, 104, 97, 112,
  101, 97, 118, 101, 114, 97, 103, 101, 32, 58, 10, 45, 101, 91, 94, 45,
  49, 93, 32, 34, 67, 111, 109, 112, 111, 115, 101, 32, 105, 109, 97, 103,
  101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116, 119, 111, 44, 32,
  117, 115, 105, 110, 103, 32, 115, 104, 97, 112, 101, 32, 97, 118, 101, 114,
  97, 103, 101, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32,
  45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47,
  50, 41, 125, 32, 45, 108, 91, 45, 50, 44, 45, 49, 93, 32, 110, 109,
  61, 64, 123, 48, 44, 110, 125, 10, 45, 99, 104, 97, 110, 110, 101, 108,
  115, 91, 45, 49, 93, 32, 48, 32, 45, 103, 101, 91, 45, 49, 93, 32,
  53, 48, 37, 32, 45, 108, 97, 98, 101, 108, 95, 102, 103, 91, 45, 49,
  93, 32, 48, 32, 110, 98, 61, 123, 105, 77, 43, 49, 125, 32, 45, 42,
  91, 45, 49, 93, 32, 50, 53, 54, 10, 45, 114, 118, 91, 45, 50, 44,
  45, 49, 93, 32, 109, 61, 123, 105, 109, 125, 32, 77, 61, 123, 105, 77,
  125, 32, 45, 110, 91, 45, 49, 93, 32, 48, 44, 50, 53, 53, 32, 45,
  115, 91, 45, 49, 93, 32, 99, 32, 45, 43, 91, 94, 48, 93, 32, 91,
  48, 93, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 64, 35, 45, 49,
  125, 10, 45, 104, 105, 115, 116, 111, 103, 114, 97, 109, 91, 45, 49, 93,
  32, 123, 36, 110, 98, 42, 50, 53, 54, 125, 44, 48, 44, 123, 36, 110,
  98, 42, 50, 53, 54, 45, 49, 125, 10, 45, 105, 91, 45, 50, 93, 32,
  50, 53, 54, 44, 49, 44, 49, 44, 49, 44, 39, 120, 39, 32, 45, 114,
  91, 45, 50, 93, 32, 123, 119, 125, 44, 49, 44, 49, 44, 49, 44, 48,
  44, 50, 32, 45, 42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45,
  114, 91, 45, 50, 44, 45, 49, 93, 32, 36, 110, 98, 44, 49, 44, 49,
  44, 49, 44, 50, 32, 45, 109, 97, 120, 91, 45, 49, 93, 32, 49, 32,
  45, 47, 91, 45, 50, 44, 45, 49, 93, 10, 45, 109, 118, 91, 45, 49,
  93, 32, 49, 32, 45, 100, 111, 110, 101, 10, 45, 47, 91, 48, 93, 32,
  50, 53, 54, 32, 45, 97, 91, 94, 48, 93, 32, 99, 32, 45, 42, 91,
  45, 49, 93, 32, 123, 40, 36, 77, 45, 36, 109, 41, 47, 50, 53, 54,
  125, 32, 45, 43, 91, 45, 49, 93, 32, 36, 109, 32, 45, 112, 111, 105,
  110, 116, 91, 45, 49, 93, 32, 48, 44, 48, 44, 48, 44, 49, 44, 48,
  32, 45, 109, 97, 112, 91, 48, 93, 32, 91, 45, 49, 93, 32, 45, 114,
  109, 91, 45, 49, 93, 10, 45, 110, 109, 32, 36, 110, 109, 44, 49, 32,
  45, 101, 110, 100, 108, 32, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 99, 111, 109, 112, 111,
  115, 101, 95, 115, 111, 102, 116, 108, 105, 103, 104, 116, 32, 58, 10, 45,
  101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 111, 115, 101, 32,
  105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45, 116,
  119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 115, 111, 102, 116, 32, 108,
  105, 103, 104, 116, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45,
  32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35,
  47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49,
  125, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101,
  32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48,
  44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 47, 32, 50, 53,
  54, 32, 45, 45, 42, 91, 45, 50, 93, 32, 91, 45, 49, 93, 32, 45,
  42, 91, 45, 49, 93, 32, 50, 32, 45, 115, 113, 114, 91, 45, 51, 93,
  32, 45, 42, 91, 45, 50, 93, 32, 91, 45, 51, 93, 32, 45, 42, 91,
  45, 50, 93, 32, 45, 50, 32, 45, 43, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 42, 32, 50, 53, 54, 32, 45, 118, 32,
  43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 115, 116, 97, 109, 112, 32,
  58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 111,
  115, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98,
  121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 115, 116, 97,
  109, 112, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45,
  114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50,
  41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93,
  10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48,
  32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48,
  44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 42, 91, 45, 49, 93, 32,
  50, 32, 45, 43, 10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101,
  32, 45, 45, 32, 50, 53, 53, 32, 45, 99, 32, 48, 44, 50, 53, 53,
  32, 45, 118, 32, 43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 118, 97,
  108, 117, 101, 32, 58, 10, 45, 101, 91, 94, 45, 49, 93, 32, 34, 67,
  111, 109, 112, 111, 115, 101, 32, 105, 109, 97, 103, 101, 36, 63, 32, 116,
  119, 111, 45, 98, 121, 45, 116, 119, 111, 44, 32, 117, 115, 105, 110, 103,
  32, 118, 97, 108, 117, 101, 32, 109, 111, 100, 101, 46, 34, 10, 45, 118,
  32, 45, 32, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40,
  64, 35, 47, 50, 41, 125, 32, 45, 108, 91, 36, 62, 44, 123, 36, 62,
  43, 49, 125, 93, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111,
  100, 101, 32, 48, 32, 45, 114, 91, 45, 49, 93, 32, 91, 45, 50, 93,
  44, 48, 44, 48, 44, 48, 46, 53, 44, 48, 46, 53, 32, 45, 116, 111,
  95, 114, 103, 98, 97, 32, 45, 115, 104, 32, 48, 44, 50, 10, 45, 114,
  103, 98, 50, 104, 115, 118, 91, 45, 50, 44, 45, 49, 93, 32, 45, 115,
  104, 91, 45, 50, 93, 32, 50, 44, 50, 32, 45, 106, 91, 45, 50, 93,
  32, 91, 45, 49, 93, 44, 48, 44, 48, 44, 48, 44, 50, 32, 45, 114,
  109, 91, 45, 53, 44, 45, 51, 44, 45, 49, 93, 32, 45, 104, 115, 118,
  50, 114, 103, 98, 91, 45, 49, 93, 32, 45, 114, 109, 91, 45, 49, 93,
  10, 45, 101, 110, 100, 108, 32, 45, 100, 111, 110, 101, 32, 45, 118, 32,
  43, 10, 99, 111, 109, 112, 111, 115, 101, 95, 120, 111, 114, 32, 58, 10,
  45, 101, 91, 94, 45, 49, 93, 32, 34, 67, 111, 109, 112, 111, 115, 101,
  32, 105, 109, 97, 103, 101, 36, 63, 32, 116, 119, 111, 45, 98, 121, 45,
  116, 119, 111, 44, 32, 117, 115, 105, 110, 103, 32, 120, 111, 114, 32, 109,
  111, 100, 101, 46, 34, 10, 45, 118, 32, 45, 32, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45,
  108, 91, 36, 62, 44, 123, 36, 62, 43, 49, 125, 93, 10, 45, 116, 111,
  95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32, 48, 32, 45, 114, 91,
  45, 49, 93, 32, 91, 45, 50, 93, 44, 48, 44, 48, 44, 48, 46, 53,
  44, 48, 46, 53, 32, 45, 120, 111, 114, 10, 45, 101, 110, 100, 108, 32,
  45, 100, 111, 110, 101, 32, 45, 118, 32, 43, 10, 95, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 32, 58, 10, 45, 114, 101, 112, 101,
  97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45,
  45, 99, 111, 109, 112, 111, 115, 101, 95, 36, 49, 91, 45, 50, 44, 45,
  49, 93, 32, 45, 114, 109, 91, 45, 51, 93, 32, 45, 116, 111, 95, 114,
  103, 98, 97, 91, 45, 49, 93, 32, 45, 115, 104, 91, 45, 49, 93, 32,
  51, 44, 51, 32, 45, 42, 91, 45, 49, 93, 32, 36, 50, 32, 45, 114,
  109, 91, 45, 49, 93, 32, 45, 99, 111, 109, 112, 111, 115, 101, 95, 97,
  108, 112, 104, 97, 91, 45, 50, 44, 45, 49, 93, 32, 45, 109, 118, 91,
  45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 95, 103, 105, 109,
  112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32,
  58, 10, 45, 114, 101, 112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64,
  35, 47, 50, 41, 125, 32, 45, 114, 118, 91, 123, 50, 42, 36, 62, 125,
  44, 123, 50, 42, 36, 62, 43, 49, 125, 93, 32, 45, 100, 111, 110, 101,
  10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 97, 108,
  112, 104, 97, 32, 58, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125,
  32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108,
  97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101,
  112, 101, 97, 116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125,
  10, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 32, 45, 115,
  104, 91, 45, 49, 93, 32, 51, 44, 51, 32, 45, 42, 91, 45, 49, 93,
  32, 36, 49, 32, 45, 114, 109, 91, 45, 49, 93, 10, 45, 99, 111, 109,
  112, 111, 115, 101, 95, 97, 108, 112, 104, 97, 91, 45, 50, 44, 45, 49,
  93, 10, 45, 109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110,
  101, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 97,
  118, 101, 114, 97, 103, 101, 32, 58, 10, 45, 105, 102, 32, 36, 123, 50,
  61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114,
  116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10,
  45, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 32, 97,
  118, 101, 114, 97, 103, 101, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 99, 111, 108, 111, 114, 98, 117, 114, 110,
  32, 58, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125, 32, 45, 95,
  103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101,
  114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 32, 99, 111, 108, 111, 114, 98, 117,
  114, 110, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 100, 97, 114, 107, 101, 110, 32, 58, 10, 45, 105, 102, 32,
  36, 123, 50, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101,
  118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100,
  105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 32, 100, 97, 114, 107, 101, 110, 44, 36, 49, 10, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 100, 105, 102, 102, 101, 114, 101,
  110, 99, 101, 32, 58, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125,
  32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108,
  97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111,
  95, 114, 103, 98, 32, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 32, 100, 105, 102, 102, 101, 114, 101, 110, 99, 101, 44, 36,
  49, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 100,
  105, 118, 105, 100, 101, 32, 58, 10, 45, 105, 102, 32, 36, 123, 50, 61,
  48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116,
  95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  95, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 32, 100, 105,
  118, 105, 100, 101, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 100, 111, 100, 103, 101, 32, 58, 10, 45, 105, 102,
  32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114,
  101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 32, 100, 111, 100, 103, 101, 44, 36, 49, 10, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 101, 100, 103, 101, 115, 32, 58,
  10, 45, 105, 102, 32, 36, 123, 51, 61, 48, 125, 32, 45, 95, 103, 105,
  109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 114, 101, 112, 101, 97, 116, 32,
  123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 32, 45, 45, 99, 111,
  109, 112, 111, 115, 101, 95, 101, 100, 103, 101, 115, 91, 45, 50, 44, 45,
  49, 93, 32, 36, 50, 32, 45, 114, 109, 91, 45, 51, 93, 32, 45, 116,
  111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 32, 45, 115, 104, 91, 45,
  49, 93, 32, 51, 44, 51, 32, 45, 42, 91, 45, 49, 93, 32, 36, 49,
  32, 45, 114, 109, 91, 45, 49, 93, 32, 45, 99, 111, 109, 112, 111, 115,
  101, 95, 97, 108, 112, 104, 97, 91, 45, 50, 44, 45, 49, 93, 32, 45,
  109, 118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 101, 120, 99, 108,
  117, 115, 105, 111, 110, 32, 58, 10, 45, 105, 102, 32, 36, 123, 50, 61,
  48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116,
  95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45,
  116, 111, 95, 114, 103, 98, 32, 45, 95, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 32, 101, 120, 99, 108, 117, 115, 105, 111, 110, 44,
  36, 49, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95,
  102, 97, 100, 101, 32, 58, 10, 45, 105, 102, 32, 123, 64, 35, 61, 61,
  49, 125, 32, 45, 114, 101, 116, 117, 114, 110, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 116, 111, 95, 99, 111, 108, 111, 114, 109, 111, 100, 101, 32,
  52, 10, 45, 105, 102, 32, 123, 36, 49, 61, 61, 48, 125, 32, 91, 48,
  93, 44, 91, 48, 93, 44, 49, 44, 49, 44, 34, 36, 49, 48, 34, 10,
  45, 101, 108, 115, 101, 32, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 102, 97, 100, 101, 36, 49, 32, 36, 55, 44, 36,
  56, 44, 36, 57, 32, 45, 114, 91, 45, 49, 93, 32, 91, 48, 93, 44,
  91, 48, 93, 44, 49, 44, 49, 44, 51, 10, 45, 101, 110, 100, 105, 102,
  10, 45, 110, 91, 45, 49, 93, 32, 123, 45, 40, 64, 35, 45, 50, 41,
  42, 36, 51, 125, 44, 123, 40, 64, 35, 45, 50, 41, 42, 40, 49, 43,
  36, 51, 41, 125, 10, 45, 45, 91, 45, 49, 93, 32, 123, 36, 50, 42,
  40, 49, 43, 36, 51, 41, 42, 40, 64, 35, 45, 50, 41, 125, 10, 45,
  99, 91, 45, 49, 93, 32, 48, 44, 123, 64, 35, 45, 50, 125, 10, 45,
  105, 102, 32, 36, 54, 32, 45, 114, 118, 91, 94, 45, 49, 93, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 53, 32, 45, 114, 111,
  117, 110, 100, 91, 45, 49, 93, 32, 49, 10, 45, 101, 108, 115, 101, 32,
  45, 114, 111, 117, 110, 100, 105, 102, 121, 91, 45, 49, 93, 32, 36, 52,
  10, 45, 101, 110, 100, 105, 102, 10, 45, 99, 111, 109, 112, 111, 115, 101,
  95, 102, 97, 100, 101, 10, 45, 99, 32, 48, 44, 50, 53, 53, 10, 95,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 102, 97, 100,
  101, 49, 32, 58, 32, 91, 48, 93, 44, 91, 48, 93, 44, 49, 44, 49,
  44, 34, 97, 61, 36, 49, 42, 112, 105, 47, 50, 59, 32, 120, 42, 99,
  111, 115, 40, 97, 41, 32, 43, 32, 121, 42, 115, 105, 110, 40, 97, 41,
  34, 10, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95,
  102, 97, 100, 101, 50, 32, 58, 32, 91, 48, 93, 44, 91, 48, 93, 44,
  49, 44, 49, 44, 48, 32, 45, 61, 91, 45, 49, 93, 32, 49, 44, 123,
  40, 36, 49, 43, 49, 41, 42, 53, 48, 125, 37, 44, 123, 40, 36, 50,
  43, 49, 41, 42, 53, 48, 125, 37, 32, 45, 100, 105, 115, 116, 97, 110,
  99, 101, 91, 45, 49, 93, 32, 49, 10, 95, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 102, 97, 100, 101, 51, 32, 58, 32, 91,
  48, 93, 44, 91, 48, 93, 44, 49, 44, 49, 44, 48, 32, 45, 61, 91,
  45, 49, 93, 32, 49, 44, 123, 40, 36, 49, 43, 49, 41, 42, 53, 48,
  125, 37, 44, 123, 40, 36, 50, 43, 49, 41, 42, 53, 48, 125, 37, 32,
  45, 100, 105, 115, 116, 97, 110, 99, 101, 91, 45, 49, 93, 32, 49, 32,
  45, 42, 91, 45, 49, 93, 32, 123, 48, 46, 48, 49, 43, 36, 51, 47,
  50, 125, 32, 45, 99, 111, 115, 91, 45, 49, 93, 10, 95, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 102, 97, 100, 101, 52, 32,
  58, 32, 91, 48, 93, 44, 91, 48, 93, 44, 49, 44, 49, 44, 34, 40,
  40, 120, 45, 119, 42, 40, 36, 49, 43, 48, 46, 53, 41, 41, 42, 40,
  121, 45, 104, 42, 40, 36, 50, 43, 48, 46, 53, 41, 41, 41, 37, 40,
  48, 46, 50, 42, 119, 42, 104, 42, 40, 49, 46, 48, 48, 49, 43, 36,
  51, 41, 41, 34, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 95, 102, 114, 101, 101, 122, 101, 32, 58, 10, 45, 105, 102, 32, 36,
  123, 50, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118,
  101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  32, 102, 114, 101, 101, 122, 101, 44, 36, 49, 10, 103, 105, 109, 112, 95,
  99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 101, 120, 116,
  114, 97, 99, 116, 32, 58, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48,
  125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95,
  108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 32, 103, 114, 97,
  105, 110, 101, 120, 116, 114, 97, 99, 116, 44, 36, 49, 10, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 103, 114, 97, 105, 110, 109,
  101, 114, 103, 101, 32, 58, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48,
  125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95,
  108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 32, 103, 114, 97,
  105, 110, 109, 101, 114, 103, 101, 44, 36, 49, 10, 103, 105, 109, 112, 95,
  99, 111, 109, 112, 111, 115, 101, 95, 104, 97, 114, 100, 108, 105, 103, 104,
  116, 32, 58, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125, 32, 45,
  95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121,
  101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103, 105, 109,
  112, 95, 99, 111, 109, 112, 111, 115, 101, 32, 104, 97, 114, 100, 108, 105,
  103, 104, 116, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112,
  111, 115, 101, 95, 104, 117, 101, 32, 58, 32, 45, 115, 107, 105, 112, 32,
  36, 123, 50, 61, 48, 125, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48,
  125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95,
  108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 32, 104, 117, 101,
  44, 36, 49, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101,
  95, 105, 110, 116, 101, 114, 112, 111, 108, 97, 116, 105, 111, 110, 32, 58,
  10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103, 105,
  109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115,
  32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 32, 105, 110, 116, 101, 114, 112, 111, 108, 97,
  116, 105, 111, 110, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 95, 108, 105, 103, 104, 116, 101, 110, 32, 58, 10, 45,
  105, 102, 32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112,
  95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 32, 108, 105, 103, 104, 116, 101, 110, 44, 36, 49, 10,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 108, 105, 103,
  104, 116, 110, 101, 115, 115, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36,
  123, 50, 61, 48, 125, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125,
  32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108,
  97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 32, 108, 105, 103, 104,
  116, 110, 101, 115, 115, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 108, 117, 109, 105, 110, 97, 110, 99, 101, 32,
  58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 48, 125, 10, 45,
  105, 102, 32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112,
  95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 32, 108, 117, 109, 105, 110, 97, 110, 99, 101, 44, 36,
  49, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 109,
  117, 108, 116, 105, 112, 108, 121, 32, 58, 10, 45, 105, 102, 32, 36, 123,
  50, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101,
  114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102,
  10, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 32,
  109, 117, 108, 116, 105, 112, 108, 121, 44, 36, 49, 10, 103, 105, 109, 112,
  95, 99, 111, 109, 112, 111, 115, 101, 95, 110, 101, 103, 97, 116, 105, 111,
  110, 32, 58, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125, 32, 45,
  95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121,
  101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 114,
  103, 98, 32, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115,
  101, 32, 110, 101, 103, 97, 116, 105, 111, 110, 44, 36, 49, 10, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 111, 118, 101, 114, 108,
  97, 121, 32, 58, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125, 32,
  45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97,
  121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 32, 111, 118, 101, 114, 108,
  97, 121, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 95, 114, 101, 102, 108, 101, 99, 116, 32, 58, 10, 45, 105, 102,
  32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114,
  101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110,
  100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111,
  115, 101, 32, 114, 101, 102, 108, 101, 99, 116, 44, 36, 49, 10, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 115, 97, 116, 117, 114,
  97, 116, 105, 111, 110, 32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123,
  50, 61, 48, 125, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125, 32,
  45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97,
  121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 32, 115, 97, 116, 117, 114,
  97, 116, 105, 111, 110, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 95, 115, 99, 114, 101, 101, 110, 32, 58, 10, 45,
  105, 102, 32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112,
  95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 32, 115, 99, 114, 101, 101, 110, 44, 36, 49, 10, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 115, 104, 97, 112,
  101, 97, 118, 101, 114, 97, 103, 101, 32, 58, 10, 45, 105, 102, 32, 36,
  123, 51, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118,
  101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 116, 111, 95, 114, 103, 98, 10, 45, 114, 101, 112, 101, 97,
  116, 32, 123, 105, 110, 116, 40, 64, 35, 47, 50, 41, 125, 10, 45, 114,
  118, 91, 45, 50, 44, 45, 49, 93, 10, 45, 105, 102, 32, 36, 49, 32,
  45, 105, 91, 48, 93, 32, 91, 45, 49, 93, 32, 45, 101, 110, 100, 105,
  102, 10, 45, 99, 111, 109, 112, 111, 115, 101, 95, 115, 104, 97, 112, 101,
  97, 118, 101, 114, 97, 103, 101, 91, 45, 50, 44, 45, 49, 93, 10, 45,
  105, 102, 32, 36, 49, 32, 45, 42, 91, 48, 44, 45, 49, 93, 32, 45,
  47, 91, 48, 93, 32, 50, 53, 53, 32, 45, 109, 118, 91, 48, 93, 32,
  64, 35, 32, 45, 101, 110, 100, 105, 102, 10, 45, 105, 102, 32, 36, 50,
  32, 45, 116, 111, 95, 114, 103, 98, 97, 91, 45, 49, 93, 32, 45, 114,
  101, 112, 108, 97, 99, 101, 95, 99, 111, 108, 111, 114, 91, 45, 49, 93,
  32, 48, 44, 48, 44, 48, 44, 48, 44, 48, 44, 50, 53, 53, 44, 48,
  44, 48, 44, 48, 44, 48, 32, 45, 101, 110, 100, 105, 102, 10, 45, 109,
  118, 91, 45, 49, 93, 32, 48, 32, 45, 100, 111, 110, 101, 10, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 115, 111, 102, 116, 108,
  105, 103, 104, 116, 32, 58, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48,
  125, 32, 45, 95, 103, 105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95,
  108, 97, 121, 101, 114, 115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 95,
  103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 32, 115, 111, 102,
  116, 108, 105, 103, 104, 116, 44, 36, 49, 10, 103, 105, 109, 112, 95, 99,
  111, 109, 112, 111, 115, 101, 95, 115, 116, 97, 109, 112, 32, 58, 10, 45,
  105, 102, 32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103, 105, 109, 112,
  95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32, 45,
  101, 110, 100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109,
  112, 111, 115, 101, 32, 115, 116, 97, 109, 112, 44, 36, 49, 10, 103, 105,
  109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 118, 97, 108, 117, 101,
  32, 58, 32, 45, 115, 107, 105, 112, 32, 36, 123, 50, 61, 48, 125, 10,
  45, 105, 102, 32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103, 105, 109,
  112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114, 115, 32,
  45, 101, 110, 100, 105, 102, 10, 45, 95, 103, 105, 109, 112, 95, 99, 111,
  109, 112, 111, 115, 101, 32, 118, 97, 108, 117, 101, 44, 36, 49, 10, 103,
  105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 95, 120, 111, 114, 32,
  58, 10, 45, 105, 102, 32, 36, 123, 50, 61, 48, 125, 32, 45, 95, 103,
  105, 109, 112, 95, 114, 101, 118, 101, 114, 116, 95, 108, 97, 121, 101, 114,
  115, 32, 45, 101, 110, 100, 105, 102, 10, 45, 116, 111, 95, 114, 103, 98,
  32, 45, 95, 103, 105, 109, 112, 95, 99, 111, 109, 112, 111, 115, 101, 32,
  120, 111, 114, 44, 36, 49, 10, 114, 101, 115, 105, 122, 101, 50, 120, 32,
  58, 10, 45, 115, 99, 97, 108, 101, 50, 120, 10, 114, 101, 115, 105, 122,
  101, 51, 120, 32, 58, 10, 45, 115, 99, 97, 108, 101, 51, 120, 0 };

unsigned int size_data_gmic_def = sizeof(data_gmic_def);

/* Define image 'gmic_logo' of size 3x102x22x1 and type 'unsigned char' */
unsigned char data_gmic_logo[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 254, 254, 254, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 254, 254, 254, 254, 254, 254, 244, 247, 248, 203, 211, 218, 176, 189, 201,
  182, 194, 205, 210, 217, 224, 247, 248, 249, 255, 255, 254, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 254, 254,
  254, 254, 254, 254, 255, 255, 255, 254, 254, 254, 254, 254, 254, 255, 255, 255,
  254, 254, 254, 255, 255, 255, 254, 254, 254, 255, 255, 255, 183, 127, 176, 124,
  22, 110, 111, 0, 97, 121, 17, 108, 119, 13, 105, 119, 13, 105, 135, 43,
  123, 252, 250, 252, 254, 254, 254, 255, 255, 255, 254, 254, 254, 255, 255, 255,
  254, 254, 254, 254, 254, 254, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 254,
  254, 254, 238, 248, 252, 201, 233, 247, 169, 220, 242, 141, 206, 236, 119, 193,
  230, 101, 182, 223, 87, 171, 217, 78, 162, 210, 73, 153, 204, 72, 147, 199,
  76, 143, 194, 85, 142, 192, 160, 188, 217, 254, 254, 254, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 119, 120, 124, 119, 120, 124, 118, 119, 123, 124, 125, 129, 121,
  122, 126, 135, 136, 140, 174, 174, 177, 143, 144, 147, 119, 120, 124, 119, 120,
  124, 0, 0, 0, 0, 0, 0, 255, 255, 255, 254, 254, 254, 254, 254, 254,
  254, 254, 253, 243, 245, 246, 139, 158, 175, 42, 75, 107, 20, 58, 93, 19,
  58, 94, 21, 60, 97, 28, 66, 102, 54, 88, 120, 130, 151, 171, 227, 232,
  235, 254, 254, 255, 254, 254, 254, 254, 254, 254, 254, 254, 254, 255, 255, 255,
  254, 254, 254, 254, 254, 254, 255, 255, 255, 254, 254, 254, 255, 255, 255, 255,
  255, 255, 197, 152, 191, 255, 255, 255, 254, 254, 254, 255, 255, 255, 112, 1,
  98, 118, 12, 104, 119, 13, 105, 119, 13, 105, 119, 13, 105, 119, 14, 105,
  105, 0, 90, 247, 241, 246, 254, 254, 254, 255, 255, 255, 254, 254, 254, 255,
  255, 255, 254, 254, 254, 254, 254, 254, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 254, 254, 254, 252, 253, 254, 225, 243, 251, 177, 226, 245, 91, 205,
  238, 26, 181, 231, 3, 162, 225, 27, 166, 225, 54, 173, 226, 77, 179, 226,
  96, 184, 226, 111, 187, 225, 121, 188, 225, 128, 188, 223, 130, 185, 219, 129,
  180, 216, 123, 172, 210, 113, 161, 202, 161, 189, 217, 254, 254, 254, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 119, 120, 124, 119, 120, 124, 119, 120, 124, 133, 134,
  137, 136, 137, 140, 173, 174, 176, 231, 231, 231, 166, 166, 169, 119, 120, 124,
  119, 120, 124, 0, 0, 0, 0, 0, 0, 255, 255, 255, 254, 254, 254, 254,
  254, 254, 225, 229, 234, 64, 94, 122, 14, 53, 89, 19, 58, 94, 24, 62,
  98, 26, 65, 101, 28, 68, 104, 31, 69, 105, 31, 70, 106, 30, 69, 105,
  45, 81, 114, 151, 169, 185, 247, 249, 249, 254, 254, 254, 254, 254, 254, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 218, 190, 214, 149, 67, 138, 110, 0,
  95, 118, 12, 104, 113, 3, 99, 255, 255, 255, 255, 255, 255, 254, 254, 254,
  134, 41, 122, 119, 13, 105, 119, 13, 105, 115, 7, 101, 193, 147, 187, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 254, 254, 254, 253, 254,
  254, 241, 249, 252, 215, 238, 249, 178, 224, 245, 169, 221, 244, 172, 224, 245,
  155, 224, 244, 144, 219, 243, 141, 213, 241, 117, 200, 236, 89, 187, 231, 65,
  174, 224, 46, 161, 217, 31, 149, 210, 21, 138, 202, 14, 127, 194, 12, 119,
  187, 13, 112, 181, 19, 107, 175, 29, 104, 172, 124, 163, 203, 254, 254, 254,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 119, 120, 124, 119, 120, 124, 119, 120, 124,
  146, 147, 149, 173, 174, 176, 254, 254, 254, 223, 223, 224, 129, 130, 134, 123,
  124, 127, 119, 120, 124, 0, 0, 0, 0, 0, 0, 254, 254, 254, 254, 254,
  254, 230, 234, 238, 55, 87, 116, 15, 52, 88, 19, 58, 93, 23, 61, 98,
  27, 65, 102, 30, 69, 105, 34, 73, 109, 37, 75, 111, 38, 76, 112, 38,
  75, 112, 35, 74, 110, 33, 71, 107, 92, 120, 145, 237, 241, 243, 254, 254,
  254, 254, 255, 255, 232, 215, 230, 117, 10, 103, 119, 14, 106, 119, 13, 105,
  118, 12, 104, 119, 13, 105, 119, 14, 106, 255, 255, 255, 252, 249, 251, 206,
  169, 201, 157, 81, 147, 117, 10, 103, 119, 13, 105, 118, 13, 105, 252, 250,
  252, 254, 254, 254, 254, 254, 254, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 254, 254, 254, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 251, 253, 254,
  240, 248, 252, 235, 246, 251, 230, 244, 251, 214, 238, 249, 174, 223, 244, 112,
  203, 238, 38, 189, 233, 51, 189, 234, 83, 192, 234, 111, 198, 236, 134, 205,
  237, 143, 207, 236, 143, 204, 234, 143, 202, 232, 143, 199, 229, 143, 195, 226,
  143, 192, 223, 143, 189, 220, 143, 184, 216, 143, 180, 213, 184, 205, 226, 254,
  254, 254, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 119, 120, 124, 119, 120, 124, 147,
  148, 151, 251, 251, 251, 254, 254, 254, 201, 202, 203, 130, 130, 134, 128, 129,
  133, 124, 125, 129, 119, 120, 124, 0, 0, 0, 0, 0, 0, 254, 254, 254,
  250, 251, 251, 86, 111, 135, 10, 49, 84, 20, 59, 93, 25, 63, 98, 26,
  64, 101, 31, 69, 105, 36, 75, 111, 40, 79, 114, 43, 80, 117, 46, 82,
  118, 48, 84, 119, 41, 79, 115, 38, 77, 113, 32, 70, 106, 84, 113, 139,
  243, 244, 246, 254, 254, 254, 236, 221, 234, 119, 14, 105, 118, 12, 104, 120,
  15, 106, 119, 13, 105, 119, 13, 105, 119, 13, 105, 203, 163, 198, 252, 255,
  255, 209, 229, 231, 161, 193, 202, 157, 77, 145, 119, 13, 105, 114, 4, 99,
  255, 255, 255, 255, 255, 255, 254, 253, 253, 255, 255, 255, 252, 250, 252, 255,
  255, 255, 254, 254, 254, 255, 255, 255, 255, 255, 255, 254, 254, 254, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 253,
  253, 254, 244, 250, 253, 224, 241, 250, 211, 236, 249, 212, 237, 249, 205, 235,
  248, 186, 230, 246, 140, 220, 243, 92, 202, 238, 60, 183, 232, 32, 168, 226,
  9, 154, 219, 0, 146, 214, 0, 140, 209, 0, 134, 203, 1, 128, 198, 3,
  122, 191, 0, 112, 184, 0, 104, 177, 0, 94, 169, 0, 85, 161, 94, 143,
  191, 255, 254, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 119, 120, 124, 127, 128,
  132, 214, 215, 216, 180, 180, 182, 192, 192, 194, 198, 198, 200, 132, 132, 136,
  131, 132, 136, 129, 129, 133, 119, 120, 124, 0, 0, 0, 0, 0, 0, 253,
  254, 253, 177, 189, 200, 8, 47, 82, 79, 107, 133, 201, 210, 218, 199, 208,
  216, 80, 114, 142, 78, 159, 187, 82, 166, 193, 81, 160, 189, 95, 128, 156,
  199, 209, 217, 199, 209, 219, 95, 152, 179, 83, 166, 194, 77, 156, 185, 31,
  71, 106, 139, 158, 177, 253, 254, 253, 237, 223, 235, 108, 0, 93, 140, 51,
  128, 210, 175, 205, 165, 95, 156, 119, 13, 105, 118, 12, 104, 219, 243, 241,
  161, 196, 204, 161, 196, 204, 160, 195, 203, 234, 233, 239, 120, 14, 106, 118,
  11, 104, 179, 120, 171, 253, 253, 253, 180, 122, 172, 114, 4, 99, 116, 9,
  102, 213, 180, 209, 254, 254, 254, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 252, 253, 254, 247, 251, 253, 238, 247, 252, 215, 238, 249, 178, 223, 245,
  156, 216, 242, 146, 215, 242, 128, 216, 242, 140, 218, 243, 143, 214, 241, 143,
  211, 240, 143, 209, 238, 143, 207, 236, 143, 204, 234, 143, 202, 232, 142, 198,
  229, 140, 194, 226, 143, 192, 223, 143, 188, 220, 143, 184, 217, 143, 180, 213,
  183, 205, 226, 254, 254, 254, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 119, 120, 124,
  126, 127, 130, 151, 152, 155, 120, 121, 125, 193, 193, 195, 171, 171, 173, 119,
  120, 124, 119, 120, 124, 119, 120, 124, 119, 120, 124, 0, 0, 0, 0, 0,
  0, 254, 253, 253, 87, 114, 136, 13, 51, 86, 199, 207, 215, 73, 103, 130,
  101, 126, 151, 181, 200, 211, 90, 180, 206, 77, 118, 148, 76, 144, 174, 129,
  182, 202, 195, 205, 216, 73, 108, 140, 88, 173, 200, 50, 94, 129, 48, 95,
  129, 32, 71, 107, 50, 85, 117, 241, 243, 245, 250, 247, 250, 255, 255, 255,
  254, 254, 254, 254, 253, 254, 242, 232, 240, 121, 16, 107, 119, 13, 105, 214,
  199, 218, 162, 196, 204, 161, 196, 204, 164, 198, 206, 180, 211, 216, 210, 178,
  207, 255, 255, 255, 255, 255, 255, 255, 255, 255, 172, 108, 164, 119, 13, 105,
  118, 12, 104, 110, 0, 95, 255, 255, 255, 255, 255, 255, 254, 254, 254, 254,
  254, 254, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 251, 253, 254, 241, 249, 252, 237, 246, 252, 229, 244, 251, 217,
  239, 250, 187, 228, 246, 137, 212, 241, 50, 193, 235, 3, 174, 229, 10, 165,
  226, 27, 166, 225, 42, 168, 224, 54, 169, 223, 62, 168, 220, 66, 166, 217,
  69, 162, 213, 66, 155, 207, 61, 146, 200, 53, 135, 193, 41, 121, 183, 26,
  102, 170, 97, 145, 192, 254, 255, 254, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 119,
  120, 124, 124, 125, 129, 119, 120, 124, 122, 123, 127, 178, 179, 181, 183, 183,
  185, 119, 120, 124, 119, 120, 124, 119, 120, 124, 119, 120, 124, 0, 0, 0,
  0, 0, 0, 246, 248, 249, 43, 78, 107, 35, 68, 100, 208, 216, 222, 20,
  59, 94, 30, 68, 103, 61, 100, 130, 81, 165, 193, 115, 140, 163, 74, 130,
  161, 132, 189, 210, 164, 180, 196, 60, 95, 130, 84, 164, 192, 75, 146, 176,
  46, 92, 127, 32, 70, 106, 24, 62, 98, 210, 217, 224, 254, 254, 254, 255,
  255, 255, 255, 255, 255, 254, 254, 254, 255, 255, 255, 119, 13, 105, 108, 0,
  93, 209, 167, 200, 143, 182, 191, 98, 147, 159, 83, 136, 149, 87, 139, 151,
  254, 254, 254, 254, 254, 254, 254, 254, 254, 255, 255, 255, 255, 255, 255, 114,
  4, 99, 119, 13, 105, 119, 13, 105, 178, 119, 170, 253, 252, 253, 255, 255,
  255, 254, 254, 254, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 252, 253, 254, 241, 249, 252, 223, 241, 250, 212, 236,
  248, 207, 235, 248, 203, 235, 248, 186, 230, 246, 154, 224, 244, 143, 219, 242,
  133, 210, 240, 115, 200, 236, 100, 192, 232, 89, 184, 228, 81, 177, 223, 76,
  170, 218, 73, 164, 214, 77, 161, 210, 82, 158, 206, 90, 157, 204, 102, 159,
  203, 117, 163, 204, 175, 199, 223, 254, 254, 254, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 119, 120, 124, 119, 120, 124, 125, 126, 130, 131, 132, 135, 166, 167, 169,
  192, 192, 193, 119, 120, 124, 119, 120, 124, 119, 120, 124, 119, 120, 124, 0,
  0, 0, 0, 0, 0, 246, 247, 248, 39, 74, 103, 38, 70, 101, 209, 217,
  223, 20, 59, 94, 26, 64, 100, 41, 83, 117, 81, 165, 193, 113, 139, 162,
  73, 129, 160, 131, 189, 210, 162, 178, 195, 57, 91, 128, 54, 94, 130, 71,
  136, 167, 86, 174, 200, 38, 84, 119, 20, 60, 97, 191, 201, 211, 254, 254,
  254, 254, 253, 254, 255, 255, 255, 254, 254, 254, 255, 255, 255, 246, 240, 245,
  255, 255, 255, 255, 255, 255, 89, 141, 153, 88, 140, 152, 88, 140, 152, 78,
  134, 146, 255, 255, 255, 255, 255, 255, 254, 254, 254, 255, 255, 255, 255, 255,
  255, 137, 46, 125, 119, 13, 105, 119, 13, 105, 114, 5, 100, 255, 255, 255,
  254, 254, 254, 254, 254, 254, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 252, 253, 254, 247, 251, 253, 236, 246, 252,
  214, 237, 249, 181, 225, 245, 145, 212, 241, 121, 206, 239, 81, 202, 237, 83,
  199, 236, 100, 198, 236, 114, 199, 236, 124, 201, 235, 131, 202, 235, 135, 201,
  233, 137, 199, 231, 134, 194, 227, 130, 189, 223, 123, 181, 218, 112, 170, 211,
  99, 157, 202, 81, 139, 191, 131, 169, 206, 254, 255, 254, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 119, 120, 124, 119, 120, 124, 118, 119, 123, 119, 120, 124, 185,
  185, 187, 141, 142, 145, 153, 154, 157, 119, 120, 124, 119, 120, 124, 119, 120,
  124, 0, 0, 0, 0, 0, 0, 250, 250, 251, 56, 88, 115, 18, 55, 88,
  205, 213, 220, 42, 77, 108, 69, 100, 129, 168, 188, 202, 81, 165, 193, 112,
  138, 162, 71, 128, 159, 131, 188, 208, 159, 175, 192, 52, 88, 123, 53, 97,
  131, 41, 78, 114, 77, 154, 183, 48, 104, 136, 19, 58, 95, 200, 209, 217,
  245, 237, 244, 172, 107, 163, 112, 1, 98, 210, 175, 205, 254, 254, 254, 254,
  254, 254, 254, 254, 254, 255, 255, 255, 118, 160, 170, 89, 141, 153, 88, 140,
  152, 76, 132, 145, 255, 255, 255, 254, 254, 254, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 118, 12, 104, 118, 12, 104, 118, 12, 104, 118, 12, 104, 147,
  63, 135, 253, 252, 253, 254, 254, 254, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 251, 253, 254, 244, 250, 253, 238,
  247, 252, 229, 244, 251, 218, 239, 249, 199, 233, 247, 161, 221, 243, 96, 207,
  239, 60, 192, 234, 43, 177, 230, 29, 166, 225, 18, 158, 221, 11, 151, 216,
  8, 144, 210, 7, 137, 205, 8, 132, 199, 12, 127, 194, 20, 123, 189, 30,
  122, 186, 44, 123, 184, 62, 126, 183, 142, 176, 210, 254, 254, 254, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 119, 120, 124, 119, 120, 124, 119, 120, 124, 132, 133,
  137, 161, 161, 164, 213, 213, 214, 196, 196, 198, 119, 120, 124, 119, 120, 124,
  119, 120, 124, 0, 0, 0, 0, 0, 0, 253, 253, 254, 91, 117, 139, 5,
  45, 79, 120, 141, 160, 203, 211, 219, 206, 214, 221, 111, 141, 163, 77, 159,
  187, 111, 135, 159, 68, 124, 155, 124, 182, 203, 151, 169, 186, 46, 85, 120,
  81, 162, 189, 79, 160, 188, 80, 163, 191, 33, 75, 111, 30, 67, 102, 223,
  229, 233, 243, 233, 241, 119, 14, 106, 118, 12, 104, 184, 130, 177, 254, 253,
  254, 255, 255, 255, 255, 255, 255, 255, 255, 255, 245, 248, 249, 157, 187, 194,
  236, 242, 243, 255, 255, 255, 254, 254, 254, 255, 255, 255, 172, 108, 164, 116,
  8, 102, 115, 6, 101, 118, 12, 104, 119, 13, 105, 119, 13, 105, 119, 13,
  105, 117, 10, 103, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 251, 253, 254, 239, 248,
  252, 223, 241, 250, 212, 237, 249, 203, 233, 248, 195, 232, 247, 188, 230, 246,
  174, 230, 247, 180, 230, 247, 192, 231, 247, 200, 233, 247, 206, 235, 248, 210,
  235, 247, 211, 235, 247, 208, 232, 245, 203, 229, 243, 195, 223, 240, 185, 216,
  235, 172, 206, 229, 156, 193, 221, 137, 176, 211, 169, 195, 220, 254, 254, 254,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 119, 120, 124, 119, 120, 124, 119, 120, 124,
  143, 144, 147, 145, 146, 149, 192, 193, 195, 238, 239, 239, 130, 131, 134, 119,
  120, 124, 119, 120, 124, 0, 0, 0, 0, 0, 0, 254, 254, 254, 141, 159,
  174, 4, 42, 78, 10, 51, 84, 46, 80, 110, 49, 83, 114, 25, 64, 99,
  35, 79, 115, 107, 132, 156, 49, 88, 122, 51, 92, 126, 58, 92, 125, 38,
  76, 112, 39, 81, 116, 43, 91, 125, 32, 74, 109, 26, 64, 99, 67, 97,
  126, 249, 250, 250, 244, 235, 242, 119, 13, 105, 119, 13, 105, 160, 85, 150,
  253, 252, 253, 255, 255, 255, 255, 255, 255, 255, 255, 255, 254, 254, 254, 253,
  254, 254, 254, 254, 254, 254, 255, 255, 255, 255, 255, 255, 255, 255, 118, 11,
  104, 119, 13, 105, 119, 13, 105, 119, 13, 105, 119, 13, 105, 119, 13, 105,
  119, 13, 105, 118, 12, 104, 119, 15, 105, 254, 253, 254, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 254, 254, 254,
  254, 254, 254, 254, 254, 254, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 119, 120, 124, 119, 120, 124, 119,
  120, 124, 129, 130, 133, 202, 202, 203, 245, 245, 245, 219, 219, 220, 206, 207,
  208, 119, 119, 124, 119, 120, 124, 0, 0, 0, 0, 0, 0, 254, 254, 254,
  206, 214, 220, 9, 46, 79, 7, 47, 82, 12, 51, 86, 16, 54, 90, 20,
  58, 94, 22, 61, 97, 104, 130, 154, 40, 77, 112, 32, 70, 107, 32, 71,
  107, 32, 70, 106, 31, 69, 105, 28, 66, 103, 26, 64, 100, 22, 60, 96,
  158, 175, 189, 253, 253, 253, 245, 238, 244, 119, 13, 105, 119, 13, 105, 129,
  32, 116, 255, 255, 255, 255, 255, 255, 218, 189, 214, 128, 30, 115, 227, 206,
  224, 254, 254, 254, 254, 254, 254, 254, 254, 254, 255, 255, 255, 255, 255, 255,
  117, 9, 102, 119, 13, 105, 118, 12, 104, 119, 13, 105, 118, 12, 104, 119,
  13, 105, 118, 12, 104, 119, 13, 105, 137, 45, 124, 251, 247, 250, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 119, 120, 124, 119, 120,
  124, 119, 120, 124, 181, 181, 183, 251, 251, 251, 200, 200, 202, 131, 132, 135,
  253, 253, 253, 135, 136, 139, 119, 120, 124, 0, 0, 0, 0, 0, 0, 255,
  255, 255, 252, 252, 253, 74, 98, 123, 4, 44, 79, 8, 48, 83, 13, 51,
  87, 17, 55, 91, 19, 57, 93, 101, 127, 150, 36, 72, 106, 27, 65, 101,
  27, 65, 101, 27, 65, 101, 26, 64, 100, 24, 62, 98, 21, 59, 95, 59,
  90, 120, 242, 244, 245, 254, 254, 253, 246, 239, 245, 119, 13, 105, 118, 12,
  104, 119, 13, 105, 114, 4, 99, 116, 8, 102, 120, 16, 107, 119, 13, 105,
  163, 91, 153, 253, 251, 253, 255, 255, 255, 254, 254, 254, 255, 255, 255, 254,
  254, 254, 168, 100, 159, 119, 14, 105, 118, 12, 104, 118, 12, 104, 118, 12,
  104, 118, 12, 104, 118, 12, 104, 128, 34, 118, 128, 113, 170, 133, 167, 205,
  133, 169, 206, 133, 169, 206, 170, 195, 220, 249, 250, 252, 133, 169, 205, 182,
  203, 225, 254, 254, 254, 255, 255, 255, 162, 189, 217, 161, 189, 217, 254, 254,
  254, 246, 249, 251, 158, 186, 215, 115, 156, 198, 132, 168, 205, 211, 224, 237,
  254, 254, 254, 211, 223, 237, 133, 169, 205, 234, 240, 246, 255, 255, 255, 237,
  242, 247, 147, 178, 211, 115, 155, 198, 145, 176, 210, 236, 241, 247, 255, 255,
  255, 255, 255, 255, 253, 253, 254, 141, 174, 208, 165, 191, 218, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 160, 187, 216, 133, 169, 205, 133, 169, 206, 133,
  169, 206, 133, 169, 206, 228, 236, 244, 189, 208, 227, 134, 169, 206, 239, 244,
  248, 255, 255, 255, 226, 234, 243, 133, 169, 205, 221, 231, 241, 119, 120, 124,
  119, 120, 124, 183, 183, 186, 223, 223, 224, 194, 194, 196, 210, 211, 212, 121,
  122, 125, 254, 254, 254, 172, 173, 175, 119, 120, 124, 0, 0, 0, 0, 0,
  0, 255, 255, 255, 254, 254, 254, 193, 202, 210, 10, 45, 78, 5, 45, 80,
  8, 48, 83, 13, 51, 87, 14, 53, 88, 98, 124, 146, 31, 68, 102, 22,
  60, 96, 22, 60, 96, 22, 60, 96, 21, 60, 95, 19, 58, 93, 24, 61,
  96, 190, 201, 209, 254, 254, 254, 254, 255, 254, 247, 241, 246, 119, 13, 105,
  118, 12, 104, 119, 13, 105, 118, 12, 104, 119, 13, 105, 118, 12, 104, 118,
  12, 104, 125, 23, 111, 253, 252, 253, 254, 254, 254, 254, 254, 254, 255, 255,
  255, 254, 254, 254, 246, 240, 245, 119, 13, 105, 118, 12, 104, 119, 13, 105,
  118, 12, 104, 119, 13, 105, 116, 8, 102, 127, 46, 126, 18, 67, 147, 54,
  112, 174, 71, 124, 181, 71, 125, 181, 127, 164, 203, 243, 246, 250, 0, 74,
  152, 6, 78, 155, 191, 209, 228, 254, 254, 254, 61, 117, 177, 59, 116, 177,
  254, 254, 254, 78, 129, 183, 14, 84, 158, 88, 137, 188, 48, 108, 171, 27,
  93, 163, 232, 239, 245, 164, 190, 218, 0, 74, 152, 211, 224, 237, 226, 234,
  243, 28, 94, 163, 24, 91, 162, 83, 133, 185, 21, 89, 161, 44, 105, 169,
  249, 250, 252, 255, 255, 255, 176, 199, 223, 0, 74, 152, 6, 78, 154, 225,
  234, 242, 255, 255, 255, 255, 255, 255, 55, 113, 174, 17, 86, 159, 71, 124,
  181, 71, 124, 181, 71, 125, 181, 214, 226, 238, 117, 157, 199, 0, 74, 153,
  71, 124, 180, 250, 251, 252, 195, 212, 230, 0, 74, 152, 185, 206, 227, 119,
  120, 124, 137, 138, 141, 213, 213, 214, 121, 122, 126, 178, 178, 181, 225, 225,
  226, 137, 138, 141, 254, 254, 254, 189, 190, 191, 119, 120, 124, 0, 0, 0,
  0, 0, 0, 255, 255, 255, 254, 254, 254, 252, 252, 253, 129, 148, 164, 3,
  43, 77, 5, 45, 80, 8, 48, 83, 9, 49, 84, 96, 121, 144, 26, 63,
  96, 17, 55, 91, 17, 55, 91, 16, 55, 91, 16, 54, 90, 18, 56, 91,
  153, 169, 184, 253, 253, 253, 254, 254, 254, 255, 255, 255, 248, 244, 248, 119,
  13, 105, 118, 12, 104, 119, 13, 105, 118, 12, 104, 118, 12, 104, 118, 12,
  104, 118, 12, 104, 113, 2, 98, 255, 255, 255, 255, 255, 255, 254, 254, 254,
  255, 255, 255, 254, 254, 254, 255, 255, 255, 114, 4, 99, 119, 13, 105, 109,
  0, 94, 117, 11, 103, 175, 114, 167, 245, 237, 244, 222, 231, 241, 2, 75,
  153, 109, 151, 196, 143, 175, 209, 225, 234, 242, 255, 255, 255, 243, 246, 250,
  0, 74, 152, 10, 81, 155, 18, 87, 160, 216, 227, 239, 61, 117, 176, 59,
  116, 176, 254, 254, 254, 46, 107, 171, 26, 93, 163, 142, 175, 209, 194, 212,
  230, 233, 239, 246, 254, 254, 254, 164, 191, 218, 0, 74, 152, 211, 224, 237,
  114, 155, 198, 4, 77, 154, 224, 233, 242, 255, 255, 255, 232, 238, 245, 244,
  247, 250, 255, 255, 255, 254, 254, 254, 54, 112, 173, 59, 116, 176, 14, 84,
  158, 109, 151, 196, 255, 255, 255, 255, 255, 255, 55, 113, 175, 34, 98, 166,
  142, 175, 209, 169, 194, 220, 255, 255, 255, 255, 255, 255, 117, 157, 199, 2,
  76, 153, 8, 80, 155, 105, 148, 194, 194, 212, 230, 0, 75, 152, 185, 206,
  227, 119, 120, 124, 188, 188, 190, 153, 153, 156, 119, 120, 124, 189, 190, 192,
  239, 239, 240, 174, 174, 177, 255, 255, 255, 186, 187, 188, 119, 120, 124, 0,
  0, 0, 0, 0, 0, 255, 255, 255, 254, 254, 254, 254, 254, 254, 249, 249,
  251, 108, 131, 150, 4, 42, 76, 4, 44, 78, 6, 45, 80, 90, 116, 140,
  20, 58, 92, 11, 51, 86, 11, 51, 86, 11, 50, 85, 22, 60, 92, 158,
  175, 188, 252, 253, 253, 254, 254, 253, 254, 254, 254, 255, 255, 255, 249, 246,
  249, 118, 12, 104, 119, 13, 105, 118, 12, 104, 118, 12, 104, 119, 13, 105,
  118, 12, 104, 119, 13, 105, 107, 0, 92, 255, 255, 255, 254, 254, 254, 254,
  254, 254, 255, 255, 255, 254, 254, 254, 255, 255, 255, 144, 59, 133, 230, 213,
  228, 255, 255, 255, 255, 255, 255, 253, 252, 253, 255, 255, 255, 218, 229, 240,
  0, 74, 152, 47, 108, 171, 62, 118, 177, 205, 220, 235, 255, 255, 255, 243,
  246, 250, 0, 74, 152, 122, 161, 201, 46, 107, 171, 37, 100, 167, 48, 108,
  171, 59, 116, 176, 254, 254, 254, 214, 225, 238, 96, 142, 191, 38, 101, 167,
  1, 75, 152, 30, 96, 164, 219, 229, 240, 164, 191, 218, 0, 74, 152, 211,
  224, 237, 84, 134, 186, 21, 89, 160, 254, 254, 254, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 184, 204, 226, 0, 74, 152, 129, 166, 204,
  76, 128, 182, 9, 81, 156, 231, 238, 245, 255, 255, 255, 55, 113, 175, 15,
  85, 158, 62, 118, 177, 107, 150, 195, 255, 255, 255, 255, 255, 255, 117, 157,
  199, 6, 79, 155, 161, 188, 217, 1, 74, 152, 86, 135, 186, 0, 74, 152,
  185, 206, 227, 119, 120, 124, 208, 209, 210, 164, 164, 167, 119, 120, 124, 174,
  174, 176, 254, 254, 254, 248, 248, 248, 255, 255, 254, 164, 164, 167, 119, 120,
  124, 0, 0, 0, 0, 0, 0, 255, 255, 255, 254, 254, 255, 255, 254, 254,
  254, 255, 254, 249, 250, 250, 155, 168, 182, 31, 62, 94, 3, 40, 75, 8,
  46, 80, 5, 45, 80, 5, 45, 79, 12, 49, 83, 74, 99, 125, 204, 212,
  219, 253, 253, 253, 255, 254, 254, 255, 255, 254, 255, 255, 254, 255, 255, 255,
  250, 248, 250, 118, 12, 104, 118, 12, 104, 119, 13, 105, 118, 12, 104, 119,
  13, 105, 118, 12, 104, 118, 12, 104, 119, 13, 105, 224, 199, 220, 254, 253,
  254, 254, 254, 254, 255, 255, 255, 254, 254, 254, 255, 255, 255, 253, 252, 253,
  254, 254, 254, 254, 254, 254, 254, 254, 254, 255, 255, 255, 254, 254, 254, 218,
  229, 240, 0, 74, 152, 187, 207, 227, 245, 248, 251, 245, 247, 250, 247, 249,
  251, 242, 246, 249, 0, 74, 152, 133, 169, 206, 225, 234, 242, 25, 92, 162,
  0, 74, 152, 59, 116, 176, 254, 254, 254, 178, 199, 223, 197, 214, 231, 253,
  253, 253, 179, 201, 224, 0, 74, 153, 148, 179, 211, 164, 191, 218, 0, 74,
  152, 211, 224, 237, 137, 171, 207, 0, 74, 152, 167, 193, 219, 253, 253, 254,
  167, 193, 219, 160, 187, 216, 251, 252, 253, 60, 117, 176, 6, 78, 154, 16,
  85, 158, 16, 86, 159, 1, 75, 153, 118, 157, 199, 254, 254, 254, 55, 113,
  174, 59, 116, 176, 245, 248, 250, 245, 247, 250, 245, 248, 251, 251, 252, 253,
  117, 157, 199, 6, 79, 155, 252, 252, 253, 126, 164, 203, 0, 74, 152, 0,
  74, 152, 185, 206, 227, 119, 120, 124, 190, 191, 192, 243, 243, 243, 153, 154,
  157, 183, 184, 186, 255, 255, 255, 255, 255, 255, 250, 250, 250, 127, 128, 132,
  119, 120, 124, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 254, 254, 254, 254, 254, 253, 235, 239, 241, 173, 186,
  197, 124, 144, 162, 114, 135, 154, 149, 166, 180, 207, 215, 221, 251, 252, 252,
  254, 254, 254, 254, 254, 254, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 252, 249, 251, 118, 12, 104, 119, 13, 105, 118, 12, 104, 118, 12,
  104, 119, 13, 105, 113, 3, 99, 111, 0, 97, 149, 67, 138, 226, 204, 224,
  255, 255, 255, 254, 254, 254, 255, 255, 255, 255, 255, 255, 254, 254, 254, 255,
  255, 255, 254, 254, 254, 255, 255, 255, 255, 255, 255, 255, 255, 255, 254, 254,
  254, 233, 239, 246, 33, 97, 165, 0, 74, 152, 0, 74, 152, 0, 74, 153,
  39, 102, 168, 242, 246, 249, 0, 74, 152, 133, 169, 206, 255, 255, 255, 203,
  217, 233, 10, 81, 156, 59, 117, 176, 245, 248, 251, 70, 123, 180, 0, 74,
  152, 10, 82, 156, 2, 77, 153, 34, 99, 166, 225, 234, 243, 164, 190, 218,
  0, 74, 152, 212, 224, 237, 245, 248, 251, 79, 130, 184, 0, 74, 152, 6,
  78, 155, 1, 75, 153, 99, 144, 192, 190, 209, 228, 0, 74, 152, 157, 186,
  215, 255, 255, 255, 254, 254, 254, 88, 137, 188, 13, 84, 158, 236, 242, 247,
  55, 113, 175, 0, 74, 152, 0, 74, 153, 0, 74, 152, 0, 74, 153, 161,
  188, 217, 117, 157, 199, 6, 78, 155, 252, 253, 254, 253, 253, 254, 90, 138,
  188, 0, 74, 152, 185, 206, 227, 119, 120, 124, 134, 135, 138, 246, 246, 246,
  254, 254, 254, 254, 254, 254, 255, 255, 255, 255, 255, 255, 199, 199, 201, 118,
  119, 123, 119, 120, 124, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 255, 255, 255, 253, 254, 254, 253, 254, 253, 253, 254, 254,
  254, 254, 255, 254, 254, 254, 254, 254, 254, 254, 254, 255, 254, 254, 255, 254,
  254, 254, 254, 254, 254, 254, 254, 254, 255, 255, 255, 255, 255, 255, 255, 255,
  255, 255, 255, 255, 253, 252, 253, 118, 12, 104, 118, 11, 103, 106, 0, 91,
  125, 24, 112, 207, 170, 202, 254, 254, 254, 255, 255, 255, 252, 251, 252, 255,
  255, 255, 255, 255, 255, 254, 254, 254, 255, 255, 255, 254, 254, 254, 254, 254,
  254, 255, 255, 255, 254, 254, 254, 255, 255, 255, 254, 254, 254, 255, 255, 255,
  254, 254, 254, 252, 253, 253, 226, 234, 243, 214, 226, 238, 214, 226, 238, 214,
  226, 238, 220, 230, 241, 252, 253, 253, 214, 226, 238, 235, 241, 247, 255, 255,
  255, 255, 255, 255, 227, 235, 243, 224, 233, 242, 254, 254, 254, 254, 254, 254,
  224, 233, 242, 194, 211, 230, 208, 221, 235, 251, 252, 253, 255, 255, 255, 240,
  244, 248, 214, 226, 238, 248, 250, 252, 255, 255, 255, 254, 254, 254, 221, 231,
  241, 194, 211, 230, 225, 234, 242, 254, 254, 254, 233, 240, 246, 214, 226, 238,
  250, 251, 253, 255, 255, 255, 254, 254, 254, 238, 243, 247, 214, 226, 238, 242,
  246, 249, 223, 232, 242, 214, 226, 238, 214, 226, 238, 214, 226, 238, 214, 226,
  238, 240, 244, 249, 233, 239, 246, 215, 227, 238, 254, 254, 254, 255, 255, 255,
  248, 250, 252, 214, 226, 238, 244, 247, 250, 119, 120, 124, 119, 120, 124, 148,
  149, 152, 241, 241, 242, 255, 255, 255, 255, 255, 255, 242, 242, 243, 130, 131,
  135, 119, 120, 124, 119, 120, 124, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
unsigned int size_data_logo = sizeof(data_gmic_logo);
#endif
# 146066 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic_def.h"

# 1717 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp" 2
#else // #ifdef gmic_float
# 1718 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
extern char data_gmic_def[];
extern unsigned int size_data_gmic_def;
#endif // #ifdef gmic_float
# 1721 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

using namespace cimg_library;
#undef min
#undef max

// Define some useful variables and macros.
//------------------------------------------

// Ellipsize a string.
#define gmic_ellipsize(s,l) { if (l>=5 && s[l-2]) s[l-4] = s[l-3] = s[l-2] = '.'; }

// Return current selection as a selection string.
#define gmic_selection selection2string(selection,images_names,true).data()

// Return image argument as a shared or non-shared copy of one existing image.
inline bool _gmic_image_arg(const unsigned int ind, const CImg<unsigned int>& selection) {
  cimg_forY(selection,l) if (selection[l]==ind) return true;
  return false;
}
#define gmic_image_arg(ind) gmic_check(_gmic_image_arg(ind,selection)?images[ind]:\
                                       images[ind].get_shared())

// Return true if specified filename corresponds to an existing file or directory.
inline bool gmic_check_filename(const char *const filename) {
  bool res = false;
#if cimg_OS==2
  const unsigned int attr = (unsigned int)GetFileAttributesA(filename);
  res = (attr!=~0U);
#else
# 1750 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  try {
    std::FILE *file = cimg::fopen(filename,"r");
    if (file) { res = true; cimg::fclose(file); }
  } catch (CImgException&) {}
#endif
# 1755 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  return res;
}

// Manage mutexes.
struct _gmic_mutex {
#if cimg_OS==2
  HANDLE mutex[256];
  _gmic_mutex() { for (unsigned int i = 0; i<256; ++i) mutex[i] = CreateMutex(0,FALSE,0); }
  void lock(const unsigned int n) { WaitForSingleObject(mutex[n],INFINITE); }
  void unlock(const unsigned int n) { ReleaseMutex(mutex[n]); }
#elif defined(_PTHREAD_H)
# 1766 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  pthread_mutex_t mutex[256];
  _gmic_mutex() { for (unsigned int i = 0; i<256; ++i) pthread_mutex_init(&mutex[i],0); }
  void lock(const unsigned int n) { pthread_mutex_lock(&mutex[n]); }
  void unlock(const unsigned int n) { pthread_mutex_unlock(&mutex[n]); }
#else
# 1771 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  _gmic_mutex() {}
  void lock(const unsigned int) {}
  void unlock(const unsigned int) {}
#endif
# 1775 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
};
inline _gmic_mutex& gmic_mutex() { static _gmic_mutex val; return val; }

// Code for managing argument substitutions from a command.
inline const char *gmic_ellipsize_arg(const char *const argument, CImg<char>& argument_text) {
  if (argument_text) return argument_text;
  const unsigned int l = std::strlen(argument);
  if (l>=72) {
    argument_text.assign(72);
    std::memcpy(argument_text.data(),argument,32);
    std::memcpy(argument_text.data()+32," ... ",5);
    std::memcpy(argument_text.data()+37,argument+l-34,35); // Last '\0' is included.
  }
  return argument_text?argument_text:argument;
}

#define gmic_substitute_args() { \
  const char *const argument0 = argument; \
  substitute_item(argument,images,images_names,variables_sizes).move_to(_argument); \
  argument_text = gmic_ellipsize_arg(argument=argument_text=_argument,_argument_text); \
  if (is_debug) { \
    if (std::strcmp(argument,argument0)) debug(images,"Command '%s': arguments = '%s' -> '%s'.", \
                                               command,argument0,argument); \
    else debug(images,"Command '%s': arguments = '%s'.", \
               command,argument0); \
  }}

// Code for having 'get' or 'non-get' versions of G'MIC commands.
#define gmic_apply(instance,function) { \
  unsigned int posi = 0; \
  const bool is_inlist = images.contains(gmic_check(instance),posi); \
  if (is_get_version) { \
    instance.get_##function.move_to(images); \
    if (is_inlist) images_names[posi].get_copymark().mark().move_to(images_names); \
    else CImg<char>::string("[unnamed]").move_to(images_names); \
  } else { instance.function; images_names[posi].mark(); } \
}

// Code for simple commands that has no arguments and act on images.
#define gmic_simple_item(option,function,description) \
  if (!std::strcmp(option,command)) { \
    print(images,description,gmic_selection); \
    cimg_forY(selection,l) gmic_apply(images[selection[l]],function()); \
    is_released = false; continue; \
}

// Code for the type cast command.
#define gmic_cast(pixel_type,st_type) \
  if (!std::strcmp(argument,#pixel_type)) { \
    if (std::strcmp(st_type,cimg::type<T>::string())) { \
      if (!is_default_type) { --position; break; } \
      else { \
        print(images,"Set pixel data type to '%s'.",st_type); \
        CImgList<pixel_type> cast_images; \
        images.move_to(cast_images); \
        is_default_type = false; \
        is_released = false; \
        _parse_##pixel_type(commands_line,++position,cast_images,images_names,variables_sizes); \
        is_default_type = true; \
        cast_images.move_to(images); \
      } \
    } else { print(images,"Set pixel data type to '%s'.",st_type); ++position; } \
    continue; \
  }

// Code for G'MIC arithmetic commands.
#define gmic_arithmetic_item(command_name,\
                             function1,description1,arg1_1,arg1_2,arg1_3,value_type1, \
                             function2,description2,arg2_1,arg2_2, \
                             description3,arg3_1,arg3_2, \
                             description4) \
 if (!std::strcmp(command_name,command)) { \
   gmic_substitute_args(); \
   CImg<unsigned int> ind; \
   double value = 0; \
   char sep = 0; \
   *indices = *formula = 0; \
   if (std::sscanf(argument,"%lf%c",&value,&end)==1 || \
       (std::sscanf(argument,"%lf%c%c",&value,&sep,&end)==2 && sep=='%')) { \
      const char *const ssep = sep=='%'?"%":""; \
      print(images,description1 ".",arg1_1,arg1_2,arg1_3); \
      cimg_forY(selection,l) { \
       CImg<T>& img = gmic_check(images[selection[l]]); \
       double nvalue = value; \
       if (sep=='%' && img) { \
         double vmin = 0, vmax = (double)img.max_min(vmin); \
         nvalue = vmin + (vmax-vmin)*value/100; \
       } \
       if (is_get_version) { \
         images_names.insert(images_names[selection[l]].get_copymark().mark()); \
         images.insert(img); images.back().function1((value_type1)nvalue); \
       } else { \
         images_names[selection[l]].mark(); \
         img.function1((value_type1)nvalue); \
       } \
      } \
      ++position; \
   } else if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 && \
              sep==']' \
              && (ind=selection2cimg(indices,images.size(),images_names,command_name,\
                                     true,false,CImg<char>::empty())).  \
              height()==1) { \
     print(images,description2 ".",arg2_1,arg2_2); \
     const CImg<T> img0 = gmic_image_arg(*ind); \
     cimg_forY(selection,l) { \
       CImg<T>& img = gmic_check(images[selection[l]]); \
       if (is_get_version) { \
         images_names.insert(images_names[selection[l]].get_copymark().mark()); \
         images.insert(img); images.back().function2(img0); \
       } else { \
         images_names[selection[l]].mark(); img.function2(img0); \
       } \
     } \
     ++position; \
   } else if (std::sscanf(argument,"'%4095[^']%c%c",formula,&sep,&end)==2 && sep=='\'') { \
     gmic_strreplace(formula); print(images,description3 ".",arg3_1,arg3_2); \
     cimg_forY(selection,l) { \
       CImg<T>& img = gmic_check(images[selection[l]]); \
       if (is_get_version) { \
         images_names.insert(images_names[selection[l]].get_copymark().mark()); \
         images.insert(img); images.back().function2((const char*)formula); \
       } else { \
         images_names[selection[l]].mark(); img.function2((const char*)formula); \
       } \
     } \
     ++position; \
   } else { \
     print(images,description4 ".",gmic_selection); \
     if (images && selection) { \
       if (is_get_version) { \
         CImg<T> img0 = CImg<T>(gmic_check(images[selection[0]]),false); \
         for (unsigned int l = 1; l<(unsigned int)selection.height(); ++l) \
           img0.function2(gmic_check(images[selection[l]])); \
         images_names.insert(images_names[selection[0]].get_copymark().mark()); \
         img0.move_to(images); \
       } else if (selection.height()>=2) { \
       const unsigned int ind0 = selection[0]; \
       CImg<T>& img0 = gmic_check(images[ind0]); \
       for (unsigned int l = 1; l<(unsigned int)selection.height(); ++l) \
         img0.function2(gmic_check(images[selection[l]])); \
       images_names[ind0].mark(); \
       remove_images(images,images_names,selection,1,selection.height()-1); \
       }}} is_released = false; continue; \
   }

// Return a 8-bits hashcode from a string.
//----------------------------------------
inline unsigned int gmic_hashcode(const char *const str, const bool is_variable) {
  if (!str) return 0;
  unsigned int hash = 0;
  if (is_variable) {
    if (*str=='_') return 255;
    for (const char *s = str; *s; ++s) hash+=*s;
    return hash%255;
  }
  for (const char *s = str; *s; ++s) hash+=*s;
  return hash&255;
}

// Tells if the the implementation of a G'MIC command contains arguments.
//------------------------------------------------------------------------
inline bool gmic_command_has_arguments(const char *const command) {
  if (!command || !*command) return false;
  for (const char *s = std::strchr(command,'$'); s; s = std::strchr(s,'$')) {
    const char c = *(++s);
    if (c=='#' ||
        c=='*' ||
        c=='=' ||
        (c>'0' && c<='9') ||
        (c=='-' && *(s+1)>'0' && *(s+1)<='9') ||
        (c=='\"' && *(s+1)=='*' && *(s+2)=='\"') ||
        (c=='{' && (*(s+1)=='^' ||
                    (*(s+1)>'0' && *(s+1)<='9') ||
                    (*(s+1)=='-' && *(s+2)>'0' && *(s+2)<='9')))) return true;
  }
  return false;
}

// Compute the basename of a filename.
//------------------------------------
inline const char* gmic_basename(const char *const s)  {
  if (!s) return s;
  const unsigned int l = (unsigned int)std::strlen(s);
  if (*s=='[' && (s[l-1]==']' || s[l-1]=='.')) return s;
  const char *p = 0;
  for (const char *np = s; np>=s && (p=np); np = std::strchr(np,cimg_file_separator)+1) {}
  return p;
}

// Thread structure and routine for command '-parallel'.
//------------------------------------------------------
template<typename T>
struct st_gmic_parallel {
  gmic gmic_instance;
  CImgList<T> *images;
  CImgList<char> *images_names, commands_line;
  unsigned int variables_sizes[256], wait_mode;
  gmic_exception exception;
#ifdef gmic_is_parallel
#if cimg_OS!=2
  pthread_t thread_id;
#else
# 1977 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  HANDLE thread_id;
#endif // #if cimg_OS!=2
# 1979 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#endif // #ifdef gmic_is_parallel
# 1980 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
};

template<typename T>
#if cimg_OS!=2
static void *gmic_parallel(void *arg)
#else
# 1986 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
static DWORD WINAPI gmic_parallel(void *arg)
#endif
# 1988 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
{
  st_gmic_parallel<T> &st = *(st_gmic_parallel<T>*)arg;
  unsigned int pos = 0;
  try {
    st.gmic_instance._parse(st.commands_line,pos,*st.images,*st.images_names,st.variables_sizes);
  } catch (gmic_exception &e) {
    st.exception._command_help.assign(e._command_help);
    st.exception._message.assign(e._message);
  }
#if defined(gmic_is_parallel) && cimg_OS!=2
  pthread_exit(0);
#else
# 2000 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  return 0;
#endif
# 2002 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
}

// Return Levenshtein distance between two strings.
// (adapted from http://rosettacode.org/wiki/Levenshtein_distance#C)
//------------------------------------------------------------------
static int _gmic_levenshtein(const char *const s, const char *const t,
                             CImg<int>& d, const int i, const int j) {
  const int ls = d.width()-1, lt = d.height()-1;
  if (d(i,j)>=0) return d(i,j);
  int x;
  if (i==ls) x = lt - j;
  else if (j==lt) x = ls - i;
  else if (s[i]==t[j]) x = _gmic_levenshtein(s,t,d,i+1,j+1);
  else {
    x = _gmic_levenshtein(s,t,d,i+1,j+1);
    int y;
    if ((y=_gmic_levenshtein(s,t,d,i,j+1))<x) x = y;
    if ((y=_gmic_levenshtein(s,t,d,i+1,j))<x) x = y;
    ++x;
  }
  return d(i,j) = x;
}

inline int gmic_levenshtein(const char *const s, const char *const t) {
  const char *const ns = s?s:"", *const nt = t?t:"";
  const int ls = std::strlen(ns), lt = std::strlen(nt);
  if (!ls) return lt; else if (!lt) return ls;
  CImg<int> d(1+ls,1+lt,1,1,-1);
  return _gmic_levenshtein(ns,nt,d,0,0);
}

// Constructors / destructors.
//----------------------------
#if defined(gmic_float) || !defined(gmic_split_compilation)

gmic::gmic():gmic_new_attr {}

gmic::~gmic() {
  debug("%sEnd G'MIC instance.%s\n",cimg::t_bold,cimg::t_normal);
  delete[] commands;
  delete[] commands_names;
  delete[] commands_has_arguments;
  delete[] _variables;
  delete[] _variables_names;
  delete[] variables;
  delete[] variables_names;
}

gmic::gmic(const char *const commands_line, const char *const custom_commands,
           const bool include_default_commands, float *const p_progress, int *const p_cancel):gmic_new_attr {
  CImgList<float> images;
  CImgList<char> images_names;
  _gmic(commands_line,images,images_names,custom_commands,include_default_commands,
        p_progress,p_cancel);
}

// Get current scope as a string.
//-------------------------------
CImg<char> gmic::scope2string(const bool is_last_slash) const {
  CImgList<char> res;
  const unsigned int siz = (unsigned int)scope.size();
  if (siz<=8) res.assign(scope);
  else {
    res.assign(8);
    res[0].assign(scope[0]);
    res[1].assign(scope[1]);
    res[2].assign(scope[2]);
    res[3].assign("..",3);
    res[4].assign(scope[siz-4]);
    res[5].assign(scope[siz-3]);
    res[6].assign(scope[siz-2]);
    res[7].assign(scope[siz-1]);
  }
  cimglist_for(res,l) res[l].back() = '/';
  if (!is_last_slash) --(res.back()._width);
  CImg<char>::vector(0).move_to(res);
  return res>'x';
}

CImg<char> gmic::scope2string(const CImg<unsigned int>& scope_selection,
                              const bool is_last_slash) const {
  const CImg<char> def_scope("./",3);
  if (!scope_selection) return def_scope;
  CImgList<char> res(scope_selection.height());
  cimglist_for(res,l) res[l].assign(scope[scope_selection(l)]).back() = '/';
  if (!is_last_slash) --(res.back()._width);
  CImg<char>::vector(0).move_to(res);
  return res>'x';
}

// Parse items from a G'MIC command line.
//---------------------------------------
CImgList<char> gmic::commands_line_to_CImgList(const char *const commands_line) {
  if (!commands_line || !*commands_line) return CImgList<char>();
  bool is_dquoted = false;
  const char *ptrs0 = commands_line;
  while (*ptrs0==' ') ++ptrs0;  // Remove leading spaces to first item.
  CImg<char> item(std::strlen(ptrs0)+1);
  CImgList<char> items;
  char *ptrd = item.data(), c = 0;
  for (const char *ptrs = ptrs0; *ptrs; ++ptrs) {
    c = *ptrs;
    if (c=='\\') { // If escaped character.
      c = *(++ptrs);
      if (!c) { c = '\\'; --ptrs; }
      else if (c=='$') c = _dollar;
      else if (c=='{') c = _lbrace;
      else if (c=='}') c = _rbrace;
      else if (c==',') c = _comma;
      else if (c=='\"') c = _dquote;
      else if (c=='@') c = _arobace;
      else if (c==' ') c = ' ';
      else *(ptrd++) = '\\';
      *(ptrd++) = c;
    } else if (is_dquoted) { // If non-escaped character inside string.
      if (c=='\"') is_dquoted = false;
      else if (c==1) while (c!=' ') c = *(++ptrs); // Discard debug infos inside string.
      else *(ptrd++) = c=='$'?_dollar:c=='{'?_lbrace:c=='}'?_rbrace:
             c==','?_comma:c=='@'?_arobace:c;
    } else { // Non-escaped character outside string.
      if (c=='\"') is_dquoted = true;
      else if (c==' ') {
        *ptrd = 0; CImg<char>(item.data(),ptrd - item.data() + 1).move_to(items);
        ptrd = item.data();
        ++ptrs; while (*ptrs==' ') ++ptrs; ptrs0 = ptrs--;  // Remove trailing spaces to next item.
      } else *(ptrd++) = c;
    }
  }
  if (is_dquoted) error("Invalid command line: Double quotes are not closed, in expression '%s'.",
                        commands_line);
  if (ptrd!=item.data() && c!=' ') {
    *ptrd = 0; CImg<char>(item.data(),ptrd - item.data() + 1).move_to(items);
  }
  if (is_debug) {
    debug("Decompose command line into %u items: ",items.size());
    cimglist_for(items,l) {
      if (items(l,0)==1) debug("  item[%u] = (debug info 0x%s)",l,items[l].data()+1);
      else debug("  item[%u] = '%s'",l,items[l].data());
    }
  }
  return items;
}

// Print log message.
//-------------------
gmic& gmic::print(const char *format, ...) {
  if (verbosity<0 && !is_debug) return *this;
  va_list ap;
  va_start(ap,format);
  CImg<char> message(16384,1,1,1,0);
  cimg_vsnprintf(message,message.width(),format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  gmic_strreplace(message);
  if (*message!='\r')
    for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
  nb_carriages = 1;
  std::fprintf(cimg::output(),
               "[gmic]%s %s",
               scope2string().data(),message.data());
  std::fflush(cimg::output());
  return *this;
}

// Print warning message.
//-----------------------
gmic& gmic::warn(const char *format, ...) {
  if (verbosity<0 && !is_debug) return *this;
  va_list ap;
  va_start(ap,format);
  CImg<char> message(1024+512,1,1,1,0);
  cimg_snprintf(message,512,"*** Warning in %s *** ",scope2string().data());
  cimg_vsnprintf(message.data() + std::strlen(message),1024,format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  gmic_strreplace(message);
  if (*message!='\r')
    for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
  nb_carriages = 1;
  std::fprintf(cimg::output(),
               "%s[gmic]%s %s%s%s",
               cimg::t_red,scope2string().data(),cimg::t_bold,message.data(),cimg::t_normal);
  std::fflush(cimg::output());
  return *this;
}

// Print error message, and quit interpreter.
//-------------------------------------------
gmic& gmic::error(const char *const format, ...) {
  va_list ap;
  va_start(ap,format);
  CImg<char> message(1024+512,1,1,1,0);
  if (debug_filename<commands_files.size() && debug_line!=~0U)
    cimg_snprintf(message,512,"*** Error in %s (file '%s', %sline %u) *** ",
                  scope2string().data(),commands_files[debug_filename].data(),
                  is_debug_infos?"":"call from ",debug_line);
  else cimg_snprintf(message,512,"*** Error in %s *** ",scope2string().data());
  cimg_vsnprintf(message.data() + std::strlen(message),1024,format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  gmic_strreplace(message);
  if (verbosity>=0 || is_debug) {
    if (*message!='\r')
      for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
    nb_carriages = 1;
    std::fprintf(cimg::output(),"[gmic]%s %s%s%s%s",
                 scope2string().data(),cimg::t_bold,cimg::t_red,message.data(),cimg::t_normal);
    std::fflush(cimg::output());
  }
  message.move_to(status);
  throw gmic_exception(0,status);
  return *this;
}

// Print debug message.
//---------------------
gmic& gmic::debug(const char *format, ...) {
  if (!is_debug) return *this;
  va_list ap;
  va_start(ap,format);
  CImg<char> message(1024,1,1,1,0);
  cimg_vsnprintf(message,message.width(),format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  if (*message!='\r')
    for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
  nb_carriages = 1;
  std::fprintf(cimg::output(),
               "%s<gmic>%s ",
               cimg::t_green,scope2string().data());
  for (char *s = message; *s; ++s) {
    char c = *s;
    if (c<' ') switch (c) {
      case _dollar : std::fprintf(cimg::output(),"\\$"); break;
      case _lbrace : std::fprintf(cimg::output(),"\\{"); break;
      case _rbrace : std::fprintf(cimg::output(),"\\}"); break;
      case _comma : std::fprintf(cimg::output(),"\\,"); break;
      case _dquote : std::fprintf(cimg::output(),"\\\""); break;
      case _arobace : std::fprintf(cimg::output(),"\\@"); break;
      default : std::fputc(c,cimg::output());
      }
    else std::fputc(c,cimg::output());
  }
  std::fprintf(cimg::output(),
               "%s",
               cimg::t_normal);
  std::fflush(cimg::output());
  return *this;
}

// Add custom commands from a char* buffer.
//------------------------------------------
gmic& gmic::add_commands(const char *const data_commands,
                         CImgList<char> commands_names[256],
                         CImgList<char> commands[256],
                         CImgList<char> commands_has_arguments[256],
                         const char *const commands_file) {
  if (!data_commands || !*data_commands) return *this;
  CImg<char> com(256*1024), line(256*1024);
  char mac[256] = { 0 }, debug_info[32] = { 0 };
  unsigned int pos[256] = { 0 }, line_number = 1;
  bool is_last_slash = false, _is_last_slash = false, is_newline = false;
  int ind = -1, l_debug_info = 0;
  char sep = 0;
  if (commands_file) CImg<char>::string(commands_file).move_to(commands_files);

  for (const char *data = data_commands; *data; is_last_slash = _is_last_slash, line_number+=is_newline?1:0) {

    // Read new line.
    char *_line = line, *const line_end = line.end();
    while (*data!='\n' && *data && _line<line_end) *(_line++) = *(data++);
    if (_line<line_end) *_line = 0; else *(line_end-1) = 0;
    if (*data=='\n') { is_newline = true; ++data; } else is_newline = false; // Skip next '\n'.

    // Replace non-usual characters by spaces.
    for (_line = line; *_line; ++_line) if ((unsigned char)*_line<' ') *_line = ' ';
    _line = line; if (*_line=='#') *_line = 0; else do { // Remove comments.
        if ((_line=std::strchr(_line,'#')) && *(_line-1)==' ') { *--_line = 0; break; }
      } while (_line++);

    // Remove useless trailing spaces.
    char *linee = line.data() + std::strlen(line) - 1;
    while (linee>=line && *linee==' ') --linee; *(linee+1) = 0;
    char *lines = line; while (*lines==' ') ++lines; // Remove useless leading spaces.
    if (!*lines) continue; // Empty line.

    // Check if last character is a '\'...
    _is_last_slash = false;
    for (_line = linee; *_line=='\\' && _line>=lines; --_line) _is_last_slash = !_is_last_slash;
    if (_is_last_slash) *(linee--) = 0; // .. and remove it if necessary.
    if (!*lines) continue; // Empty line found.
    *mac = *com = 0;

    if (!is_last_slash && std::strchr(lines,':') && // Check for a command definition.
        std::sscanf(lines,"%255[a-zA-Z0-9_] %c %262143[^\n]",mac,&sep,com.data())>=2 &&
        (*lines<'0' || *lines>'9') && sep==':') {
      ind = gmic_hashcode(mac,false);
      CImg<char>::string(mac).move_to(commands_names[ind],pos[ind]);
      CImg<char> body = CImg<char>::string(com);
      CImg<char>::vector((char)gmic_command_has_arguments(body)).
        move_to(commands_has_arguments[ind],pos[ind]);
      if (commands_file) { // Insert code with debug infos.
        if (commands_files.width()<2)
          l_debug_info = cimg_snprintf(debug_info+1,sizeof(debug_info)-2,"%x",line_number);
        else
          l_debug_info = cimg_snprintf(debug_info+1,sizeof(debug_info)-2,"%x,%x",
                                            line_number,commands_files.width()-1);
        debug_info[0] = 1; debug_info[l_debug_info+1] = ' ';
        ((CImg<char>(debug_info,l_debug_info+2,1,1,1,true),body)>'x').move_to(commands[ind],pos[ind]++);
      } else body.move_to(commands[ind],pos[ind]++); // Insert code without debug infos.
    } else { // Continuation of a previous line.
      if (ind<0) error("Command '-command': Syntax error in expression '%s'.",lines);
      const unsigned int p = pos[ind] - 1;
      if (!is_last_slash) commands[ind][p].back() = ' ';
      else --(commands[ind][p]._width);
      const CImg<char> body = CImg<char>(lines,linee - lines + 2);
      commands_has_arguments[ind](p,0) |= (char)gmic_command_has_arguments(body);
      if (commands_file && !is_last_slash) { // Insert code with debug infos.
        if (commands_files.width()<2)
          l_debug_info = cimg_snprintf(debug_info+1,sizeof(debug_info)-2,"%x",line_number);
        else
          l_debug_info = cimg_snprintf(debug_info+1,sizeof(debug_info)-2,"%x,%x",
                                            line_number,commands_files.width()-1);
        debug_info[0] = 1; debug_info[l_debug_info+1] = ' ';
        ((commands[ind][p],CImg<char>(debug_info,l_debug_info+2,1,1,1,true),body)>'x').move_to(commands[ind][p]);
      } else commands[ind][p].append(body,'x'); // Insert code without debug infos.
    }
  }

  if (is_debug) {
    CImg<unsigned int> hdist(256);
    unsigned int nb_commands = 0;
    cimg_forX(hdist,i) { hdist[i] = commands[i].size(); nb_commands+=commands[i].size(); }
    const CImg<double> st = hdist.get_stats();
    debug("Distribution of command hashes: [ %s ], min = %u, max = %u, mean = %g, "
          "std = %g (%u commands).",
          hdist.value_string().data(),(unsigned int)st[0],(unsigned int)st[1],st[2],
          std::sqrt(st[3]),nb_commands);
  }
  return *this;
}

// Add commands from a file.
//---------------------------
gmic& gmic::add_commands(std::FILE *const file,
                         const char *const filename,
                         CImgList<char> commands_names[256],
                         CImgList<char> commands[256],
                         CImgList<char> commands_has_arguments[256],
                         const bool add_debug_infos) {
  if (!file) return *this;
  std::fseek(file,0,SEEK_END);
  const long siz = std::ftell(file);
  std::rewind(file);
  if (siz>0) {
    CImg<char> buffer(siz+1);
    if (std::fread(buffer.data(),sizeof(char),siz,file)) {
      buffer[siz] = 0;
      try { add_commands(buffer.data(),commands_names,commands,commands_has_arguments,
                         add_debug_infos?(filename?filename:"(FILE*)"):0); }
      catch (...) { std::fclose(file); throw; }
    }
  }
  return *this;
}

// Return subset indices from a selection string.
//-----------------------------------------------
CImg<unsigned int> gmic::selection2cimg(const char *const string, const unsigned int indice_max,
                                        const CImgList<char>& names,
                                        const char *const command, const bool is_selection,
                                        const bool allow_new_name, CImg<char> &new_name) {
  if (string && !*string) return CImg<unsigned int>(); // Empty selection.
  if (!string || (*string=='^' && !string[1])) { // Whole selection.
    if (indice_max) return CImg<unsigned int>::sequence(indice_max,0,indice_max-1);
    else return CImg<unsigned int>();
  }
  const char *const stype = is_selection?"selection":"subset";
  const int
    ctypel = is_selection?'[':'{',
    ctyper = is_selection?']':'}';
  CImg<bool> is_selected(1,indice_max,1,1,false);

  bool is_inverse = *string=='^';
  const char *it = string + (is_inverse?1:0);
  for (bool stopflag = false; !stopflag; ) {
    CImg<char> name(256), item;
    float ind0 = 0, ind1 = 0, step = 1;
    int iind0 = 0, iind1 = 0;
    bool is_label = false;
    char sep = 0;

    const char *const it_comma = std::strchr(it,',');
    if (it_comma) { item.assign(it,it_comma-it+1); item.back() = 0; it = it_comma + 1; }
    else { CImg<char>::string(it).move_to(item); stopflag = true; }

    char end, *const it_colon = std::strchr(item,':');
    if (it_colon) {
      *it_colon = 0;
      if (std::sscanf(it_colon+1,"%f%c",&step,&end)!=1 || step<=0)
        error("Command '%s': Invalid %s %c%s%c (syntax error after colon ':').",
              command,stype,ctypel,string,ctyper);
    }
    if (!*item) { // Particular cases [:N] or [^:N].
      if (is_inverse) { iind0 = 0; iind1 = -1; is_inverse = false; }
      else continue;
    } else if (std::sscanf(item,"%f%c",&ind0,&end)==1) { // Single indice.
      iind1 = iind0 = (int)cimg::round(ind0);
    } else if (std::sscanf(item,"%f-%f%c",&ind0,&ind1,&end)==2) { // Sequence between 2 indices.
      iind0 = (int)cimg::round(ind0);
      iind1 = (int)cimg::round(ind1);
    } else if (std::sscanf(item,"%255[a-zA-Z0-9_]%c",name.data(),&end)==1 && // Label.
               (*name<'0' || *name>'9')) {
      cimglist_for(names,l) if (names[l] && !std::strcmp(names[l],name)) {
        is_selected(l) = true; is_label = true;
      }
      if (!is_label) {
        if (allow_new_name && !new_name) {
          iind0 = iind1 = -1;
          CImg<char>::string(name).move_to(new_name);
        } else error("Command '%s': Invalid %s %c%s%c (undefined label '%s').",
                     command,stype,ctypel,string,ctyper,name.data());
      }
    } else if (std::sscanf(item,"%f%c%c",&ind0,&sep,&end)==2 && sep=='%') { // Single percent.
      iind1 = iind0 = (int)cimg::round(ind0*((int)indice_max-1)/100)-(ind0<0?1:0);
    } else if (std::sscanf(item,"%f%%-%f%c%c",&ind0,&ind1,&sep,&end)==3 && sep=='%') {
      // Sequence between 2 percents.
      iind0 = (int)cimg::round(ind0*((int)indice_max-1)/100)-(ind0<0?1:0);
      iind1 = (int)cimg::round(ind1*((int)indice_max-1)/100)-(ind1<0?1:0);
    } else if (std::sscanf(item,"%f%%-%f%c",&ind0,&ind1,&end)==2) {
      // Sequence between a percent and an indice.
      iind0 = (int)cimg::round(ind0*((int)indice_max-1)/100)-(ind0<0?1:0);;
      iind1 = (int)cimg::round(ind1);
    } else if (std::sscanf(item,"%f-%f%c%c",&ind0,&ind1,&sep,&end)==3 && sep=='%') {
      // Sequence between an indice and a percent.
      iind0 = (int)cimg::round(ind0);
      iind1 = (int)cimg::round(ind1*((int)indice_max-1)/100)-(ind1<0?1:0);;
    } else error("Command '%s': Invalid %s %c%s%c.",
                 command,stype,ctypel,string,ctyper);

    if (!indice_max) error("Command '%s': Invalid %s %c%s%c (no data available).",
                           command,stype,ctypel,string,ctyper);
    if (!is_label) {
      int
        uind0 = iind0<0?iind0+indice_max:iind0,
        uind1 = iind1<0?iind1+indice_max:iind1;
      if (uind0>uind1) { cimg::swap(uind0,uind1); cimg::swap(iind0,iind1); }
      if (uind0<0 || uind0>=(int)indice_max)
        error("Command '%s': Invalid %s %c%s%c (contains starting indice '%d', "
              "not in range -%u..%u).",
              command,stype,ctypel,string,ctyper,iind0,indice_max,indice_max-1);
      if (uind1<0 || uind1>=(int)indice_max)
        error("Command '%s': Invalid %s %c%s%c (contains ending indice '%d', "
              "not in range -%u..%u).",
              command,stype,ctypel,string,ctyper,iind1,indice_max,indice_max-1);
      const int istep = (int)cimg::round(step);
      for (int l = uind0; l<=uind1; l+=istep) is_selected[l] = true;
    }
  }
  unsigned int indice = 0;
  cimg_for(is_selected,p,bool) if (*p) ++indice;
  CImg<unsigned int> selection(1,is_inverse?indice_max-indice:indice);
  indice = 0;
  if (is_inverse) { cimg_forY(is_selected,l) if (!is_selected[l]) selection[indice++] = l; }
  else cimg_forY(is_selected,l) if (is_selected[l]) selection[indice++] = l;
  return selection;
}

// Return selection or filename strings from a set of indices.
//------------------------------------------------------------
CImg<char> gmic::selection2string(const CImg<unsigned int>& selection,
                                  const CImgList<char>& images_names,
                                  const bool display_indices) const {
  CImg<char> res(1024);
  if (display_indices) {
    switch (selection.height()) {
    case 0: cimg_snprintf(res.data(),res.width()," []"); break;
    case 1: cimg_snprintf(res.data(),res.width()," [%u]",
                          selection[0]); break;
    case 2: cimg_snprintf(res.data(),res.width(),"s [%u,%u]",
                          selection[0],selection[1]); break;
    case 3: cimg_snprintf(res.data(),res.width(),"s [%u,%u,%u]",
                          selection[0],selection[1],selection[2]); break;
    case 4: cimg_snprintf(res.data(),res.width(),"s [%u,%u,%u,%u]",
                          selection[0],selection[1],selection[2],selection[3]); break;
    default: cimg_snprintf(res.data(),res.width(),"s [%u,..,%u]",
                           selection[0],selection.back());
    }
    return res;
  }

  switch (selection.height()) {
  case 0:
    *res = 0;
    break;
  case 1:
    cimg_snprintf(res.data(),res.width(),"%s%s",
                  gmic_basename(images_names[selection[0]].data()),
                  images_names[selection[0]].back()?"*":"");
    break;
  case 2:
    cimg_snprintf(res.data(),res.width(),"%s%s, %s%s",
                  gmic_basename(images_names[selection[0]].data()),
                  images_names[selection[0]].back()?"*":"",
                  gmic_basename(images_names[selection[1]].data()),
                  images_names[selection[1]].back()?"*":"");
    break;
  case 3:
    cimg_snprintf(res.data(),res.width(),"%s%s, %s%s, %s%s",
                  gmic_basename(images_names[selection[0]].data()),
                  images_names[selection[0]].back()?"*":"",
                  gmic_basename(images_names[selection[1]].data()),
                  images_names[selection[1]].back()?"*":"",
                  gmic_basename(images_names[selection[2]].data()),
                  images_names[selection[2]].back()?"*":"");
    break;
  case 4:
    cimg_snprintf(res.data(),res.width(),"%s%s, %s%s, %s%s, %s%s",
                  gmic_basename(images_names[selection[0]].data()),
                  images_names[selection[0]].back()?"*":"",
                  gmic_basename(images_names[selection[1]].data()),
                  images_names[selection[1]].back()?"*":"",
                  gmic_basename(images_names[selection[2]].data()),
                  images_names[selection[2]].back()?"*":"",
                  gmic_basename(images_names[selection[3]].data()),
                  images_names[selection[3]].back()?"*":"");
    break;
  default:
    cimg_snprintf(res.data(),res.width(),"%s%s, .., %s%s",
                  gmic_basename(images_names[selection[0]].data()),
                  images_names[selection[0]].back()?"*":"",
                  gmic_basename(images_names[selection.back()].data()),
                  images_names[selection.back()].back()?"*":"");
  }
  return res;
}

#endif // #if defined(gmic_float) || !defined(gmic_split_compilation)
# 2540 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

// Print log message.
//-------------------
template<typename T>
gmic& gmic::print(const CImgList<T>& list, const char *format, ...) {
  if (verbosity<0 && !is_debug) return *this;
  va_list ap;
  va_start(ap,format);
  CImg<char> message(16384,1,1,1,0);
  cimg_vsnprintf(message,message.width(),format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  gmic_strreplace(message);
  if (*message!='\r')
    for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
  nb_carriages = 1;
  std::fprintf(cimg::output(),
               "[gmic]-%u%s %s",
               list.size(),scope2string().data(),message.data());
  std::fflush(cimg::output());
  return *this;
}

template<typename T>
gmic& gmic::print(const CImgList<T>& list, const CImg<unsigned int>& scope_selection,
                  const char *format, ...) {
  if (verbosity<0 && !is_debug) return *this;
  va_list ap;
  va_start(ap,format);
  CImg<char> message(16384,1,1,1,0);
  cimg_vsnprintf(message,message.width(),format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  gmic_strreplace(message);
  if (*message!='\r')
    for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
  nb_carriages = 1;
  if (scope_selection)
    std::fprintf(cimg::output(),
                 "[gmic]-%u%s %s",
                 list.size(),scope2string(scope_selection).data(),message.data());
  else std::fprintf(cimg::output(),"%s",message.data());
  std::fflush(cimg::output());
  return *this;
}

// Print warning message.
//-----------------------
template<typename T>
gmic& gmic::warn(const CImgList<T>& list, const char *format, ...) {
  if (verbosity<0 && !is_debug) return *this;
  va_list ap;
  va_start(ap,format);
  CImg<char> message(1024+512,1,1,1,0);
  cimg_snprintf(message,512,"*** Warning in %s *** ",scope2string().data());
  cimg_vsnprintf(message.data() + std::strlen(message),1024,format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  gmic_strreplace(message);
  if (*message!='\r')
    for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
  nb_carriages = 1;
  std::fprintf(cimg::output(),
               "[gmic]-%u%s %s%s%s%s",
               list.size(),scope2string().data(),cimg::t_bold,cimg::t_red,message.data(),cimg::t_normal);
  std::fflush(cimg::output());
  return *this;
}

template<typename T>
gmic& gmic::warn(const CImgList<T>& list, const CImg<unsigned int>& scope_selection,
                 const char *format, ...) {
  if (verbosity<0 && !is_debug) return *this;
  va_list ap;
  va_start(ap,format);
  CImg<char> message(1024+512,1,1,1,0);
  cimg_snprintf(message,512,"*** Warning in %s *** ",scope2string(scope_selection).data());
  cimg_vsnprintf(message.data() + std::strlen(message),1024,format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  gmic_strreplace(message);
  if (*message!='\r')
    for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
  nb_carriages = 1;
  if (scope_selection)
    std::fprintf(cimg::output(),
                 "[gmic]-%u%s %s%s%s%s",
                 list.size(),scope2string(scope_selection).data(),
                 cimg::t_bold,cimg::t_red,message.data(),cimg::t_normal);
  else std::fprintf(cimg::output(),
                    "%s%s%s%s",
                    cimg::t_bold,cimg::t_red,message.data(),cimg::t_normal);
  std::fflush(cimg::output());
  return *this;
}

// Print error message, and quit interpreter.
//-------------------------------------------
template<typename T>
gmic& gmic::error(const CImgList<T>& list, const char *const format, ...) {
  va_list ap;
  va_start(ap,format);
  CImg<char> message(1024+512,1,1,1,0);
  if (debug_filename<commands_files.size() && debug_line!=~0U)
    cimg_snprintf(message,512,"*** Error in %s (file '%s', %sline %u) *** ",
                  scope2string().data(),commands_files[debug_filename].data(),
                  is_debug_infos?"":"call from ",debug_line);
  else
    cimg_snprintf(message,512,"*** Error in %s *** ",scope2string().data());
  cimg_vsnprintf(message.data() + std::strlen(message),1024,format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  gmic_strreplace(message);
  if (verbosity>=0 || is_debug) {
    if (*message!='\r')
      for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
    nb_carriages = 1;
    std::fprintf(cimg::output(),
                 "[gmic]-%u%s %s%s%s%s",
                 list.size(),scope2string().data(),
                 cimg::t_bold,cimg::t_red,message.data(),cimg::t_normal);
    std::fflush(cimg::output());
  }
  message.move_to(status);
  throw gmic_exception(0,status);
  return *this;
}

template<typename T>
gmic& gmic::error(const char *const command, const CImgList<T>& list,
                  const char *const format, ...) {
  va_list ap;
  va_start(ap,format);
  CImg<char> message(1024+512,1,1,1,0);
  if (debug_filename<commands_files.size() && debug_line!=~0U)
    cimg_snprintf(message,512,"*** Error in %s (file '%s', %sline %u) *** ",
                  scope2string().data(),commands_files[debug_filename].data(),
                  is_debug_infos?"":"call from ",debug_line);
  else
    cimg_snprintf(message,512,"*** Error in %s *** ",scope2string().data());
  cimg_vsnprintf(message.data() + std::strlen(message),1024,format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  gmic_strreplace(message);
  if (verbosity>=0 || is_debug) {
    if (*message!='\r')
      for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
    nb_carriages = 1;
    std::fprintf(cimg::output(),
                 "[gmic]-%u%s %s%s%s%s",
                 list.size(),scope2string().data(),
                 cimg::t_bold,cimg::t_red,message.data(),cimg::t_normal);
    std::fflush(cimg::output());
  }
  message.move_to(status);
  throw gmic_exception(command,status);
  return *this;
}

template<typename T>
gmic& gmic::error(const CImgList<T>& list, const CImg<unsigned int>& scope_selection,
                  const char *const format, ...) {
  va_list ap;
  va_start(ap,format);
  CImg<char> message(1024+512,1,1,1,0);
  if (debug_filename<commands_files.size() && debug_line!=~0U)
    cimg_snprintf(message,512,"*** Error in %s (file '%s', %sline %u) *** ",
                  scope2string().data(),commands_files[debug_filename].data(),
                  is_debug_infos?"":"call from ",debug_line);
  else
    cimg_snprintf(message,512,"*** Error in %s *** ",scope2string().data());
  cimg_vsnprintf(message.data() + std::strlen(message),1024,format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  gmic_strreplace(message);
  if (verbosity>=0 || is_debug) {
    if (*message!='\r')
      for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
    nb_carriages = 1;
    if (scope_selection)
      std::fprintf(cimg::output(),
                   "[gmic]-%u%s %s%s%s%s",
                   list.size(),scope2string(scope_selection).data(),
                   cimg::t_bold,cimg::t_red,message.data(),cimg::t_normal);
    else std::fprintf(cimg::output(),"%s",message.data());
    std::fflush(cimg::output());
  }
  message.move_to(status);
  throw gmic_exception(0,status);
  return *this;
}

// Print bad-argument error message, and quit interpreter.
//--------------------------------------------------------
#define arg_error(command) _arg_error(images,command,argument_text)
template<typename T>
gmic& gmic::_arg_error(const CImgList<T>& list, const char *const command,
                       const char *const argument) {
  CImg<char> message(1024,1,1,1,0);
  if (debug_filename<commands_files.size() && debug_line!=~0U)
    cimg_snprintf(message,message.width(),
                  "*** Error in %s (file '%s', %sline %u) *** Command '-%s': Invalid argument '%s'.",
                  scope2string().data(),commands_files[debug_filename].data(),
                  is_debug_infos?"":"call from ",debug_line,command,argument);
  else
    cimg_snprintf(message,message.width(),
                  "*** Error in %s *** Command '-%s': Invalid argument '%s'.",
                  scope2string().data(),command,argument);
  gmic_ellipsize(message,message.width());
  gmic_strreplace(message);
  if (verbosity>=0 || is_debug) {
    if (*message!='\r')
      for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
    nb_carriages = 1;
    std::fprintf(cimg::output(),
                 "[gmic]-%u%s %s%s%s%s",
                 list.size(),scope2string().data(),
                 cimg::t_bold,cimg::t_red,message.data(),cimg::t_normal);
    std::fflush(cimg::output());
  }
  message.move_to(status);
  throw gmic_exception(command,status);
  return *this;
}

// Print debug message.
//---------------------
template<typename T>
gmic& gmic::debug(const CImgList<T>& list, const char *format, ...) {
  if (!is_debug) return *this;
  va_list ap;
  va_start(ap,format);
  CImg<char> message(1024,1,1,1,0);
  cimg_vsnprintf(message,message.width(),format,ap);
  gmic_ellipsize(message,message.width());
  va_end(ap);
  if (*message!='\r')
    for (unsigned int i = 0; i<nb_carriages; ++i) std::fputc('\n',cimg::output());
  nb_carriages = 1;
  std::fprintf(cimg::output(),
               "%s<gmic>-%u%s ",
               cimg::t_green,list.size(),scope2string().data());
  for (char *s = message; *s; ++s) {
    char c = *s;
    if (c<' ') {
      switch (c) {
      case _dollar : std::fprintf(cimg::output(),"\\$"); break;
      case _lbrace : std::fprintf(cimg::output(),"\\{"); break;
      case _rbrace : std::fprintf(cimg::output(),"\\}"); break;
      case _comma : std::fprintf(cimg::output(),"\\,"); break;
      case _dquote : std::fprintf(cimg::output(),"\\\""); break;
      case _arobace : std::fprintf(cimg::output(),"\\@"); break;
      default : std::fputc(c,cimg::output());
      }
    } else std::fputc(c,cimg::output());
  }
  std::fprintf(cimg::output(),
               "%s",
               cimg::t_normal);
  std::fflush(cimg::output());
  return *this;
}

// Check if a shared image of the image list is safe or not.
//----------------------------------------------------------
template<typename T>
inline bool gmic_is_valid_pointer(const T *const ptr) {
#if cimg_OS==1
  const int result = access((const char*)ptr,F_OK);
  if (result==-1 && errno==EFAULT) return false;
#elif cimg_OS==2
# 2811 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  return !IsBadReadPtr((void*)ptr,1);
#endif
# 2813 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  return true;
}

template<typename T>
CImg<T>& gmic::check_image(const CImgList<T>& list, CImg<T>& img) {
  check_image(list,(const CImg<T>&)img);
  return img;
}

template<typename T>
const CImg<T>& gmic::check_image(const CImgList<T>& list, const CImg<T>& img) {
#ifdef gmic_check_image
  if (!img.is_shared() || gmic_is_valid_pointer(img.data())) return img;
  if (is_debug) error(list,"Image list contains an invalid shared image (%p,%d,%d,%d,%d) "
                      "(references a deallocated buffer).",
                      img.data(),img.width(),img.height(),img.depth(),img.spectrum());
  else error(list,"Image list contains an invalid shared image (%d,%d,%d,%d) "
             "(references a deallocated buffer).",
             img.width(),img.height(),img.depth(),img.spectrum());
#else
# 2833 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  cimg::unused(list);
#endif
# 2835 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  return img;
}

#define gmic_check(img) check_image(images,img)

// Remove list of images in a selection.
//---------------------------------------
template<typename T>
gmic& gmic::remove_images(CImgList<T> &images, CImgList<char> &images_names,
                          const CImg<unsigned int>& selection,
                          const unsigned int start, const unsigned int end) {
  if (start==0 && end==(unsigned int)selection.height()-1 && selection.height()==images.width()) {
    images.assign();
    images_names.assign();
  } else for (int l = (int)end; l>=(int)start; ) {
      unsigned int eind = selection[l--], ind = eind;
      while (l>=(int)start && selection[l]==ind-1) ind = selection[l--];
      images.remove(ind,eind); images_names.remove(ind,eind);
    }
  return *this;
}

// Template constructors.
//-----------------------
template<typename T>
gmic::gmic(const int argc, const char *const *const argv,
           CImgList<T>& images, CImgList<char>& images_names,
           const char *custom_commands, const bool include_default_commands,
           float *const p_progress, int *const p_cancel):gmic_new_attr {
  CImgList<char> items;
  for (int l = 1; l<argc; ++l) {
    if (std::strchr(argv[l],' ')) {
      CImg<char>(1,1,1,1,'\"').move_to(items);
      CImg<char>(argv[l],std::strlen(argv[l])).move_to(items);
      CImg<char>::string("\"").move_to(items);
    } else CImg<char>::string(argv[l]).move_to(items);
    if (l<argc-1) items.back().back()=' ';
  }
  const CImg<char> commands_line(items>'x');
  _gmic(commands_line.data(),images,images_names,custom_commands,include_default_commands,
        p_progress,p_cancel);
}

template<typename T>
gmic::gmic(const char *const commands_line, CImgList<T>& images, CImgList<char>& images_names,
           const char *custom_commands, const bool include_default_commands,
           float *const p_progress, int *const p_cancel):gmic_new_attr {
  _gmic(commands_line,images,images_names,custom_commands,include_default_commands,
        p_progress,p_cancel);
}

template<typename T>
void gmic::_gmic(const char *const commands_line, CImgList<T>& images,
                 CImgList<char>& images_names,
                 const char *custom_commands, const bool include_default_commands,
                 float *const p_progress, int *const p_cancel) {

  // Initialize class variables and default G'MIC environment.
  setlocale(LC_NUMERIC,"C");
  cimg::srand();
  verbosity = 0;
  nb_carriages = 0;
  debug_filename = ~0U;
  debug_line = ~0U;
  is_released = true;
  is_debug = false;
  is_debug_infos = false;
  is_start = true;
  is_quit = false;
  is_return = false;
  is_double3d = true;
  is_default_type = true;
  check_elif = false;
  reference_time = cimg::time();
  background3d.assign(1,2,1,3).fill(32,64,32,116,64,96).resize(1,256,1,3,3);
  render3d = 4;
  renderd3d = -1;
  focale3d = 700;
  light3d.assign();
  light3d_x = light3d_y = 0;
  light3d_z = -5e8f;
  specular_lightness3d = 0.15f;
  specular_shininess3d = 0.8f;
  if (p_progress) progress = p_progress; else { _progress = -1; progress = &_progress; }
  if (p_cancel) cancel = p_cancel; else { _cancel = 0; cancel = &_cancel; }
  for (unsigned int l = 0; l<256; ++l) {
    commands_names[l].assign();
    commands[l].assign();
    commands_has_arguments[l].assign();
    _variables[l].assign();
    variables[l] = &_variables[l];
    _variables_names[l].assign();
    variables_names[l] = &_variables_names[l];
  }
  if (include_default_commands)
    add_commands(data_gmic_def,commands_names,commands,commands_has_arguments);
  add_commands(custom_commands,commands_names,commands,commands_has_arguments);

#if gmic_is_beta==1
  const char *const s_gmic_is_beta = "_gmic_is_beta";
  const unsigned int hashcode = gmic_hashcode(s_gmic_is_beta,true);
  CImg<char>::string(s_gmic_is_beta).move_to(*variables_names[hashcode]);
  CImg<char>::string("1").move_to(*variables[hashcode]);
#endif // #if gmic_is_beta==1
# 2939 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

  // Seek for a '-debug' option on the commands line.
  const CImgList<char> items = commands_line_to_CImgList(commands_line);
  cimglist_for(items,l) if (!std::strcmp("-debug",items[l].data())) { is_debug = true; break; }
  if (is_debug) {
    debug(images,"%sStart G'MIC instance, in debug mode.%s",cimg::t_bold,cimg::t_normal);
    debug(images,"Initial command line: '%s'.",commands_line);
    is_start = false;
  }
  if (is_debug) commands_line_to_CImgList(commands_line); // Do it twice, when debug enabled.

  // Launch the G'MIC interpreter.
  try {
    parse(items,images,images_names);
  } catch (gmic_exception &e) {
    print(images,"Abort G'MIC instance.\n");
    throw e;
  }
}

// Print infos on selected images.
//---------------------------------
template<typename T>
gmic& gmic::print_images(const CImgList<T>& images, const CImgList<char>& images_names,
                         const CImg<unsigned int>& selection, const bool is_header) {
  if (!images || !images_names || !selection) {
    if (is_header) print(images,"Print image [].");
    return *this;
  }
  char title[256] = { 0 };
  if (is_header) print(images,"Print image%s.\n",
                       gmic_selection);
  if (verbosity>=0 || is_debug) cimg_forY(selection,l) {
      const unsigned int ind = selection[l];
      const CImg<T>& img = images[ind];
      bool is_valid = true;
      int _verbosity = verbosity;
      bool _is_debug = is_debug;
      verbosity = -1; is_debug = false;
      try { gmic_check(img); } catch (gmic_exception&) { is_valid = false; }
      verbosity = _verbosity; is_debug = _is_debug;
      cimg_snprintf(title,sizeof(title),"[%u] = '%s'",
                    ind,images_names[ind].data());
      gmic_ellipsize(title,sizeof(title));
      img.gmic_print(title,is_debug,is_valid);
    }
  nb_carriages = 0;
  return *this;
}

// Display selected images.
//-------------------------
#ifdef gmic_float

template<typename T>
gmic& gmic::display_images(const CImgList<T>& images, const CImgList<char>& images_names,
                           const CImg<unsigned int>& selection, unsigned int *const XYZ) {
  if (!images || !images_names || !selection) { print(images,"Display image []."); return *this; }

  // Check for available display.
#if cimg_display==0
  print(images,"Display image%s",gmic_selection);
  if (verbosity>=0 || is_debug) {
    if (XYZ) std::fprintf(cimg::output(),", from point (%u,%u,%u)",XYZ[0],XYZ[1],XYZ[2]);
    std::fprintf(cimg::output()," (console output only, no display support).\n");
    std::fflush(cimg::output());
    print_images(images,images_names,selection,false);
  }
#else // #if cimg_display==0
# 3008 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  bool is_available_display = false;
  try {
    is_available_display = (bool)CImgDisplay::screen_width();
  } catch (CImgDisplayException&) {
    print(images,"Display image%s",gmic_selection);
    if (verbosity>=0 || is_debug) {
      if (XYZ) std::fprintf(cimg::output(),", from point (%u,%u,%u)",XYZ[0],XYZ[1],XYZ[2]);
      std::fprintf(cimg::output()," (console output only, no display available).\n");
      std::fflush(cimg::output());
      print_images(images,images_names,selection,false);
    }
  }
  if (!is_available_display) return *this;

  CImgList<T> visu;
  CImg<bool> is_valid(1,selection.height(),1,1,true);
  cimg_forY(selection,l) {
    const CImg<T>& img = images[selection[l]];
    int _verbosity = verbosity;
    bool _is_debug = is_debug;
    verbosity = -1; is_debug = false;
    try { gmic_check(img); } catch (gmic_exception&) { is_valid[l] = false; }
    verbosity = _verbosity; is_debug = _is_debug;
  }

  cimg_forY(selection,l) {
    const unsigned int ind = selection[l];
    const CImg<T>& img = images[ind];
    if (img && is_valid[l]) visu.insert(img,~0U,true);
    else visu.insert(1);
  }
  const CImg<char> _gmic_names = selection2string(selection,images_names,false);
  const char *const gmic_names = _gmic_names.data();
  print(images,"Display image%s = '%s'",gmic_selection,gmic_names);
  if (verbosity>=0 || is_debug) {
    if (XYZ) std::fprintf(cimg::output(),", from point (%u,%u,%u).\n",XYZ[0],XYZ[1],XYZ[2]);
    else std::fprintf(cimg::output(),".\n");
    std::fflush(cimg::output());
  }
  if (visu) {
    CImgDisplay _disp, &disp = instant_window[0]?instant_window[0]:_disp;
    char title[256] = { 0 };
    if (visu.size()==1)
      cimg_snprintf(title,sizeof(title),"%s (%dx%dx%dx%d)",
                    gmic_names,
                    visu[0].width(),visu[0].height(),visu[0].depth(),visu[0].spectrum());
    else
      cimg_snprintf(title,sizeof(title),"%s (%u)",
                    gmic_names,visu.size());
    gmic_ellipsize(title,sizeof(title));
    CImg<bool> is_shared(visu.size());
    cimglist_for(visu,l) {
      is_shared[l] = visu[l].is_shared();
      visu[l]._is_shared = images[selection[l]].is_shared();
    }
    print_images(images,images_names,selection,false);
    if (disp) visu.display(disp.set_title("%s",title),false,'x',0.5f,XYZ);
    else visu.display(title,false,'x',0.5f,XYZ);
    nb_carriages = 0;
    cimglist_for(visu,l) visu[l]._is_shared = is_shared(l);
  }
#endif // #if cimg_display==0
# 3070 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  return *this;
}

// Display plots of selected images.
//----------------------------------
template<typename T>
gmic& gmic::display_plots(const CImgList<T>& images, const CImgList<char>& images_names,
                          const CImg<unsigned int>& selection,
                          const unsigned int plot_type, const unsigned int vertex_type,
                          const double xmin, const double xmax,
                          const double ymin, const double ymax) {
  if (!images || !images_names || !selection) { print(images,"Plot image []."); return *this; }
#if cimg_display==0
  print(images,"Plot image%s (console output only, no display support).\n",gmic_selection);
  print_images(images,images_names,selection,false);
  cimg::unused(plot_type,vertex_type,xmin,xmax,ymin,ymax);
#else // #if cimg_display==0
# 3087 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  bool is_available_display = false;
  try {
    is_available_display = (bool)CImgDisplay::screen_width();
  } catch (CImgDisplayException&) {
    print(images,"Plot image%s (console output only, no display available).",gmic_selection);
    print_images(images,images_names,selection,false);
  }
  if (!is_available_display) return *this;

  CImgList<unsigned int> empty_indices;
  cimg_forY(selection,l) if (!gmic_check(images[selection(l)]))
    CImg<unsigned int>::vector(selection(l)).move_to(empty_indices);
  if (empty_indices) {
    const CImg<char> _eselec = selection2string(empty_indices>'y',images_names,true);
    const char *const eselec = _eselec.data();
    warn(images,"Command '-plot': Image%s %s empty.",
         eselec,empty_indices.size()>1?"are":"is");
  }

  CImgDisplay _disp, &disp = instant_window[0]?instant_window[0]:_disp;
  cimg_forY(selection,l) {
    const unsigned int ind = selection[l];
    const CImg<T>& img = images[ind];
    if (img) {
      print(images,"Plot image%s = '%s'.",gmic_selection,
            selection2string(selection,images_names,false).data());
      if (verbosity>=0 || is_debug) {
        std::fputc('\n',cimg::output());
        std::fflush(cimg::output());
        img.print(images_names[ind].data());
      }
      if (!disp) disp.assign(cimg_fitscreen(640,480,1),0,0);
      img.display_graph(disp.set_title("%s%s (%dx%dx%dx%d)",
                                       gmic_basename(images_names[ind].data()),
                                       images_names[ind].back()?"*":"",
                                       img.width(),img.height(),img.depth(),img.spectrum()),
                        plot_type,vertex_type,0,xmin,xmax,0,ymin,ymax);
      nb_carriages = 0;
    }
  }
#endif // #if cimg_display==0
# 3128 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  return *this;
}

// Display selected 3d objects.
//-----------------------------
template<typename T>
gmic& gmic::display_objects3d(const CImgList<T>& images, const CImgList<char>& images_names,
                              const CImg<unsigned int>& selection) {
  if (!images || !images_names || !selection) {
    print(images,"Display 3d object [].");
    return *this;
  }
  char message[1024] = { 0 };
  cimg_forY(selection,l) if (!gmic_check(images[selection[l]]).is_CImg3d(true,message))
    error(images,"Command '-display3d': Invalid 3d object [%d] in selected image%s (%s).",
          selection[l],gmic_selection,message);
#if cimg_display==0
  print(images,"Display 3d object%s (skipped, no display support).",gmic_selection);
#else // #if cimg_display==0
# 3147 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  bool is_available_display = false;
  try {
    is_available_display = (bool)CImgDisplay::screen_width();
  } catch (CImgDisplayException&) {
    print(images,"Display 3d object%s (skipped, no display available).",gmic_selection);
  }
  if (!is_available_display) return *this;

  CImgDisplay _disp, &disp = instant_window[0]?instant_window[0]:_disp;
  cimg_forY(selection,l) {
    const unsigned int ind = selection[l];
    const CImg<T>& img = images[ind];
    if (!disp) disp.assign(cimg_fitscreen(640,480,1),0,0);
    CImg<unsigned char> background = background3d.get_resize(disp.width(),disp.height(),1,3);
    background.display(disp);
    CImgList<unsigned int> primitives;
    CImgList<unsigned char> colors;
    CImgList<float> opacities;
    CImg<float> vertices(img,false);
    float _pose3d[16] = { 1,0,0,0, 0,1,0,0, 0,0,1,0, 0,0,0,1 };
    if (pose3d) std::memcpy(_pose3d,pose3d.data(),16*sizeof(float));
    vertices.CImg3dtoobject3d(primitives,colors,opacities,false);
    print(images,"Display 3d object [%u] = '%s%s' (%d vertices, %u primitives).",
          ind,images_names[ind].data(),
          images_names[ind].back()?"*":"",
          vertices.width(),primitives.size());
    disp.set_title("%s%s (%d vertices, %u primitives)",
                   gmic_basename(images_names[ind].data()),
                   images_names[ind].back()?"*":"",
                   vertices.width(),primitives.size());
    if (light3d) colors.insert(light3d,~0U,true);
    background.display_object3d(disp,vertices,primitives,colors,opacities,
                                !(bool)pose3d,render3d,renderd3d,is_double3d,focale3d,
                                light3d_x,light3d_y,light3d_z,
                                specular_lightness3d,specular_shininess3d,
                                true,_pose3d);
    print(images,"Selected 3d pose = [ %g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g,%g ].",
          _pose3d[0],_pose3d[1],_pose3d[2],_pose3d[3],
          _pose3d[4],_pose3d[5],_pose3d[6],_pose3d[7],
          _pose3d[8],_pose3d[9],_pose3d[10],_pose3d[11],
          _pose3d[12],_pose3d[13],_pose3d[14],_pose3d[15]);
    if (disp.is_closed()) break;
  }
#endif // #if cimg_display==0
# 3191 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
  return *this;
}

#endif // #ifdef gmic_float
# 3195 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

// Substitute '@', '{}' and '$' expressions in a string.
//-------------------------------------------------------
template<typename T>
CImg<char> gmic::substitute_item(const char *const source,
                                 CImgList<T>& images,
                                 CImgList<char>& images_names,
                                 unsigned int variables_sizes[256]) {
  if (!source) return CImg<char>();
  CImgList<char> substituted_items;
  CImg<char> inbraces;

  for (const char *nsource = source; *nsource; )
    if (*nsource!='@' && *nsource!='{' && *nsource!='$') {
      // If not starting with '@', '{', or '$'.
      const char *const nsource0 = nsource;
      do { ++nsource; } while (*nsource && *nsource!='@' && *nsource!='{' && *nsource!='$');
      CImg<char>(nsource0,nsource - nsource0).move_to(substituted_items);
    } else { // '@', '{}' or '$' expression found.
      CImg<char> substr(256);
      CImg<unsigned int> _ind;
      if (inbraces) *inbraces = 0; else inbraces.assign(1,1,1,1,0);
      int ind = 0, l_inbraces = 0;
      bool is_braces = false;
      char end, sep = 0;

      // '{}' expression -> Mathematical evaluation, seq. of ascii codes or strings comparison.
      if (*nsource=='{') {
        const char *const ptr_beg = nsource + 1, *ptr_end = ptr_beg;
        unsigned int p = 0;
        for (p = 1; p>0 && *ptr_end; ++ptr_end) { if (*ptr_end=='{') ++p; if (*ptr_end=='}') --p; }
        if (p) { CImg<char>(nsource++,1).move_to(substituted_items); continue; }
        l_inbraces = ptr_end - ptr_beg - 1;
        if (l_inbraces>0) {
          inbraces.assign(ptr_beg,l_inbraces + 1).back() = 0;
          substitute_item(inbraces,images,images_names,variables_sizes).move_to(inbraces);
          gmic_strreplace(inbraces);
        }
        nsource+=l_inbraces + 2;
        if (*inbraces) {
          const CImg<T>& img = images.size()?gmic_check(images.back()):CImg<T>::empty();
          bool is_substitution_done = false;

          // Special regular cases to optimize: {w},{h},{d},{s}.
          if (!inbraces[1]) {
            switch (*inbraces) {
            case 'w' :
              cimg_snprintf(substr,substr.width(),"%d",img.width());
              is_substitution_done = true;
              break;
            case 'h' :
              cimg_snprintf(substr,substr.width(),"%d",img.height());
              is_substitution_done = true;
              break;
            case 'd' :
              cimg_snprintf(substr,substr.width(),"%d",img.depth());
              is_substitution_done = true;
              break;
            case 's' :
              cimg_snprintf(substr,substr.width(),"%d",img.spectrum());
              is_substitution_done = true;
              break;
            }
            if (is_substitution_done)
              CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
          }

          // Sequence of ascii codes.
          if (!is_substitution_done && inbraces.width()>=3 && *inbraces=='\'' &&
              inbraces[inbraces.width()-2]=='\'') {
            const char *s = inbraces.data() + 1;
            if (inbraces.width()>3) {
              inbraces[inbraces.width()-2] = 0;
              for (*substr=0, cimg::strunescape(inbraces); *s; ++s) {
                cimg_snprintf(substr,substr.width(),"%d,",(int)(unsigned char)*s);
                CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
              }
              if (*substr) --(substituted_items.back()._width);
            }
            is_substitution_done = true;
          }

          // Sequence of ascii characters.
          if (!is_substitution_done && inbraces.width()>=3 && *inbraces=='`' &&
              inbraces[inbraces.width()-2]=='`') {
            if (inbraces.width()>3) {
              unsigned int nb_values = 1;
              cimg_for(inbraces,p,char) if (*p==',') ++nb_values;
              inbraces[inbraces.width()-2] = 0;
              try {
                CImg<char>(nb_values,1,1,1,inbraces.data()+1,false).move_to(substituted_items);
                is_substitution_done = true;
              } catch (CImgException &e) {
                const char *const e_ptr = std::strstr(e.what(),": ");
                error(images,"Item substitution '{`value1,..,valueN`}': %s",
                      e_ptr?e_ptr+2:e.what());
              }
            }
            is_substitution_done = true;
          }

          // Strings comparison.
          if (!is_substitution_done && inbraces.width()>=5) {
            char *const peq = std::strstr(inbraces,"'=='");
            if (peq) {
              *peq = 0;
              cimg_snprintf(substr,substr.width(),"%d",(int)!std::strcmp(inbraces,peq+4));
              CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
              is_substitution_done = true;
            } else {
              char *const pne = std::strstr(inbraces,"'!='");
              if (pne) {
                *pne = 0;
                cimg_snprintf(substr,substr.width(),"%d",(int)std::strcmp(inbraces,pne+4));
                CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
                is_substitution_done = true;
              }
            }
          }

          // Mathematical expression [truncated output].
          if (!is_substitution_done && inbraces.width()>=3 && *inbraces=='_') try {
              cimg_snprintf(substr,substr.width(),"%g",img.eval(inbraces.data(1)));
              CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
              is_substitution_done = true;
            } catch (CImgException& e) {
              const char *const e_ptr = std::strstr(e.what(),": ");
              error(images,"Item substitution '{_expression}': %s",
                    e_ptr?e_ptr+2:e.what());
            }

          // Mathematical expression [full precision output].
          if (!is_substitution_done) try {
              cimg_snprintf(substr,substr.width(),"%.16g",img.eval(inbraces.data()));
              CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
            } catch (CImgException& e) {
              const char *const e_ptr = std::strstr(e.what(),": ");
              error(images,"Item substitution '{expression}': %s",
                    e_ptr?e_ptr+2:e.what());
            }
        }
        continue;

        // '@{..}' and ${..} expressions.
      } else if (nsource[1]=='{') {
        const char *const ptr_beg = nsource + 2, *ptr_end = ptr_beg; unsigned int p = 0;
        for (p = 1; p>0 && *ptr_end; ++ptr_end) { if (*ptr_end=='{') ++p; if (*ptr_end=='}') --p; }
        if (p) { CImg<char>(nsource++,1).move_to(substituted_items); continue; }
        l_inbraces = ptr_end - ptr_beg - 1;
        if (l_inbraces>0) {
          inbraces.assign(ptr_beg,l_inbraces + 1).back() = 0;
          substitute_item(inbraces,images,images_names,variables_sizes).move_to(inbraces);
        }
        is_braces = true;
      }

      // Substitute '@#' -> number of images in the list.
      if (*nsource=='@' && nsource[1]=='#') {
        nsource+=2;
        cimg_snprintf(substr,substr.width(),"%u",images.size());
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

      // Substitute '@*' -> number of available cpus.
      } else if (*nsource=='@' && nsource[1]=='*') {
        nsource+=2;
        cimg_snprintf(substr,substr.width(),"%u",cimg::nb_cpus());
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

      // Substitute '@^' -> current level of verbosity.
      } else if (*nsource=='@' && nsource[1]=='^') {
        nsource+=2;
        cimg_snprintf(substr,substr.width(),"%d",verbosity);
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

        // Substitute '@.' -> current version number of the G'MIC interpreter.
      } else if (*nsource=='@' && nsource[1]=='.') {
        nsource+=2;
        cimg_snprintf(substr,substr.width(),"%u",gmic_version);
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

        // Substitute '@%' -> pid of the current process.
      } else if (*nsource=='@' && nsource[1]=='%') {
        nsource+=2;
#if cimg_OS==1
        cimg_snprintf(substr,substr.width(),"%u",(unsigned int)getpid());
#elif cimg_OS==2
# 3381 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        cimg_snprintf(substr,substr.width(),"%u",(unsigned int)_getpid());
#else // #if cimg_OS==1
# 3383 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        cimg_snprintf(substr,substr.width(),"0");
#endif // #if cimg_OS==1
# 3385 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

        // Substitute '@|' -> current value of the timer.
      } else if (*nsource=='@' && nsource[1]=='|') {
        nsource+=2;
        cimg_snprintf(substr,substr.width(),"%g",(cimg::time()-reference_time)/1000.);
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

        // Substitute '@?' -> current type of image pixels.
      } else if (*nsource=='@' && nsource[1]=='?') {
        nsource+=2;
        cimg_snprintf(substr,substr.width(),"%s",CImg<T>::pixel_type());
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

        // Substitute '@!' -> visibility state of the first instant display window.
      } else if (*nsource=='@' && nsource[1]=='!') {
        nsource+=2;
#if cimg_display==0
        std::strcpy(substr,"0");
#else // #if cimg_display==0
# 3405 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        cimg_snprintf(substr,substr.width(),"%d",
                      instant_window[0]?(instant_window[0].is_closed()?0:1):0);
#endif // #if cimg_display==0
# 3408 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

        // Substitute '@{!}', @{!1}, '@{!,subset}' and '@{!1,subset}'
        // -> features of an instant display window.
      } else if (*nsource=='@' && inbraces[0]=='!' &&
                 (inbraces[1]==0 ||
                  (inbraces[1]>='0' && inbraces[1]<='9' && inbraces[2]==0) ||
                  (inbraces[1]==',' && inbraces[2]) ||
                  (inbraces[1]>='0' && inbraces[1]<='9' && inbraces[2]==',' && inbraces[3]))) {
        nsource+=l_inbraces + 3;
#if cimg_display==0
        std::strcpy(substr,"0");
#else // #if cimg_display==0
# 3421 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        unsigned int wind = 0;
        bool is_substitution_done = true;
        const char *ninbraces = inbraces.data() + 1;
        if (*ninbraces>='0' && *ninbraces<='9') wind = (unsigned int)(*(ninbraces++)-'0');
        if (!*ninbraces)
          cimg_snprintf(substr,substr.width(),"%d",
                        instant_window[wind]?(instant_window[wind].is_closed()?0:1):0);
        else if (*ninbraces==',') switch (*(++ninbraces)) {
          case 'w' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",instant_window[wind].width());
            else if (ninbraces[1]=='h' && !ninbraces[2])
              cimg_snprintf(substr,substr.width(),"%d",
                            instant_window[wind].width()*instant_window[wind].height());
            else is_substitution_done = false;
            break;
          case 'h' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",instant_window[wind].height());
            else is_substitution_done = false;
            break;
          case 'd' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",instant_window[wind].window_width());
            else if (ninbraces[1]=='e' && !ninbraces[2])
              cimg_snprintf(substr,substr.width(),"%d",
                            instant_window[wind].window_width()*
                            instant_window[wind].window_height());
            else is_substitution_done = false;
            break;
          case 'e' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",instant_window[wind].window_height());
            else is_substitution_done = false;
            break;
          case 'u' :
            if (!ninbraces[1]) try {
                cimg_snprintf(substr,substr.width(),"%d",CImgDisplay::screen_width());
              } catch (CImgDisplayException&) { std::strcpy(substr,"0"); }
            else if (ninbraces[1]=='v' && !ninbraces[2]) try {
                cimg_snprintf(substr,substr.width(),"%d",
                              CImgDisplay::screen_width()*CImgDisplay::screen_height());
              } catch (CImgDisplayException&) { std::strcpy(substr,"0"); }
            else is_substitution_done = false;
            break;
          case 'v' :
            if (!ninbraces[1]) try {
                cimg_snprintf(substr,substr.width(),"%d",CImgDisplay::screen_height());
              } catch (CImgDisplayException&) { std::strcpy(substr,"0"); }
            else is_substitution_done = false;
            break;
          case 'x' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",instant_window[wind].mouse_x());
            else is_substitution_done = false;
            break;
          case 'y' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",instant_window[wind].mouse_y());
            else is_substitution_done = false;
            break;
          case 'n' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",instant_window[wind].normalization());
            else is_substitution_done = false;
            break;
          case 'b' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",instant_window[wind].button());
            else is_substitution_done = false;
            break;
          case 'o' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",instant_window[wind].wheel());
            else is_substitution_done = false;
            break;
          case 'c' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",(int)instant_window[wind].is_closed());
            else is_substitution_done = false;
            break;
          case 'r' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",(int)instant_window[wind].is_resized());
            else is_substitution_done = false;
            break;
          case 'm' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%d",(int)instant_window[wind].is_moved());
            else is_substitution_done = false;
            break;
          case 'k' :
            if (!ninbraces[1])
              cimg_snprintf(substr,substr.width(),"%u",instant_window[wind].key());
            else is_substitution_done = false;
            break;
          default :
            cimg_snprintf(substr,substr.width(),"%d",instant_window[wind].is_key(ninbraces));
          } else cimg_snprintf(substr,substr.width(),"@{!%s}",inbraces.data());
        if (!is_substitution_done) std::strcpy(substr,"0");
#endif // #if cimg_display==0
# 3522 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

        // Substitute '@/' -> number of levels in current global scope.
      } else if (*nsource=='@' && nsource[1]=='/') {
        nsource+=2;
        cimg_snprintf(substr,substr.width(),"%u",scope.size());
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

        // Substitute '@{/}' and '@{/,subset}' -> content of the global scope.
      } else if (*nsource=='@' && inbraces[0]=='/' &&
                 (inbraces[1]==0 || (inbraces[1]==',' && inbraces[2]))) {
        nsource+=l_inbraces + 3;
        const CImg<unsigned int>
          subset = selection2cimg(inbraces[1]?inbraces.data()+2:0,scope.size(),
                                  CImgList<char>::empty(),
                                  "Item substitution '@{/[,subset]}'",false,
                                  false,CImg<char>::empty());
        if (subset) cimg_foroff(subset,i)
                      substituted_items.insert(scope[subset[i]]).back().back() = '/';

        // Substitute '$/' -> current scope.
      } else if (*nsource=='$' && nsource[1]=='/') {
        cimg_snprintf(substr,substr.width(),"%s",scope.back().data());
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
        nsource+=2;

        // Substitute '@>' and '@<' -> current number of nested loops.
      } else if (*nsource=='@' && (nsource[1]=='>' || nsource[1]=='<')) {
        nsource+=2;
        cimg_snprintf(substr,substr.width(),"%u",repeatdones.size());
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

        // Substitute '@{>}', '@{<}', '@{>,subset}' and '@{<,subset}'
        // -> forward/backward indice(s) of current loop(s).
      } else if (*nsource=='@' && (*inbraces=='>' || *inbraces=='<') &&
                 (inbraces[1]==0 || (inbraces[1]==',' && inbraces[2]))) {
        nsource+=l_inbraces + 3;
        const CImg<unsigned int>
          subset = selection2cimg(inbraces[1]?inbraces.data()+2:0,repeatdones.size(),
                                  CImgList<char>::empty(),
                                  "Item substitution '@{>[,subset]}'",false,
                                  false,CImg<char>::empty());
        if (subset) {
          cimg_foroff(subset,i) {
            cimg_snprintf(substr,substr.width(),"%u",
                          *inbraces=='>'?repeatdones(subset[i],2):repeatdones(subset[i],1)-1);
            CImg<char>::string(substr.data()).move_to(substituted_items).back().back()=',';
          }
          --(substituted_items.back()._width);
        }

        // Substitute '$>', '${>}', '$<' and '${<}' -> forward/backward indice of current loop.
      } else if (*nsource=='$' &&
                 (nsource[1]=='>' || nsource[1]=='<' ||
                  ((*inbraces=='>' || *inbraces=='<') && inbraces[1]==0))) {
        const char direction = is_braces?*inbraces:nsource[1];
        if (!repeatdones)
          error(images,"Item substitution '$%s': There is no loop currently running.",
                is_braces?(direction=='>'?"{>}":"{<}"):(direction=='>'?">":"<"));
        cimg_snprintf(substr,substr.width(),"%u",
                      direction=='>'?repeatdones.back()(2):repeatdones.back()(1)-1);
        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
        nsource+=is_braces?4:2;

        // Substitute '$name' and '${name}' -> variable, image indice or environment variable.
      } else if (*nsource=='$' &&
                 (((is_braces && std::sscanf(inbraces,"%255[a-zA-Z0-9_]",substr.data())==1)) ||
                  (std::sscanf(nsource+1,"%255[a-zA-Z0-9_]",substr.data())==1)) &&
                 (*substr<'0' || *substr>'9')) {
        const CImg<char>& name = is_braces?inbraces:substr;
        const unsigned int sind = gmic_hashcode(name,true);
        const bool is_global = *name=='_';
	const int lind = is_global?0:(int)variables_sizes[sind];
        if (is_global) cimg::mutex(29);
        const CImgList<char>
          &__variables = *variables[sind],
          &__variables_names = *variables_names[sind];
        bool is_name_found = false;
	for (int l = __variables.width()-1; l>=lind; --l)
          if (!std::strcmp(__variables_names[l],name)) {
            is_name_found = true; ind = l; break;
          }
        if (is_name_found) {
          if (__variables[ind].size()>1)
            CImg<char>(__variables[ind].data(),__variables[ind].size()-1).
              move_to(substituted_items);
        } else {
	  for (int l = images.width()-1; l>=0; --l)
            if (images_names[l] && !std::strcmp(images_names[l],name)) {
              is_name_found = true; ind = l; break;
            }
          if (is_name_found) {
            char text[64];
            cimg_snprintf(text,sizeof(text),"%d",ind);
            CImg<char>(text,std::strlen(text)).move_to(substituted_items);
          } else {
            const char *const s_env = std::getenv(name);
            if (s_env) CImg<char>(s_env,std::strlen(s_env)).move_to(substituted_items);
          }
        }
        if (is_global) cimg::mutex(29,0);
        nsource+=is_braces?l_inbraces + 3:std::strlen(substr)+1;

        // Substitute '@ind', '@{ind}' and '@{ind,argument}' -> image values or feature.
      } else if (*nsource=='@' && (std::sscanf(nsource+1,"%d",&ind)==1 ||
                                   ((end=0),std::sscanf(inbraces,"%d%c",&ind,&end)==1) ||
                                   ((end=1),std::sscanf(inbraces,"%d,%c",&ind,&sep)==2) ||
                                   (std::sscanf(nsource+1,"%255[a-zA-Z0-9_]",substr.data())==1 &&
                                    (_ind=selection2cimg(substr,images.size(),images_names,
                                                         "Item substitution '@name'",true,
                                                         false,CImg<char>::empty())).height()>0) ||
                                   (((end=0),std::sscanf(inbraces,"%255[a-zA-Z0-9_]%c",
                                                         substr.data(),&end)==1) &&
                                    (_ind=selection2cimg(substr,images.size(),images_names,
                                                         "Item substitution '@{name}'",true,
                                                         false,CImg<char>::empty())).height()>0) ||
                                   (((end=1),std::sscanf(inbraces,"%255[a-zA-Z0-9_],%c",
                                                         substr.data(),&sep)==2) &&
                                    (_ind=selection2cimg(substr,images.size(),images_names,
                                                         "Item substitution '@{name,feature}'",
                                                         true,false,
                                                         CImg<char>::empty())).height()>0))) {
        if (_ind) {
          if (_ind.height()>1)
            error(images,"Item substitution '%s': Selection [%s] specifies %d items.",
                  !*inbraces?"@name":end?"@{name,feature}":"@{name}",
                  substr.data(),_ind.height());
          ind=*_ind;
        }
        const unsigned int
          l_ind = _ind?std::strlen(substr):cimg_snprintf(substr,substr.width(),"%d",ind);
        nsource+=is_braces?l_inbraces + 3:l_ind + 1;
        int nind = ind;
        if (nind<0) nind+=images.width();
        if (nind<0 || nind>=images.width()) {
          if (images.width())
            error(images,"Item substitution '%s': Invalid indice '%d' (not in range -%u..%u).",
                  !*inbraces?"@indice":end?"@{indice,feature}":"@{indice}",
                  ind,images.size(),images.size()-1);
          else
            error(images,"Item substitution '%s': Invalid indice '%d' (no image data available).",
                  !*inbraces?"@indice":end?"@{indice,feature}":"@{indice}",ind);
        }
        const CImg<T>& img = gmic_check(images[nind]);
        char argx[256], argy[256], argz[256], argc[256];
        *argx = *argy = *argz = *argc = 0;
        char sepp = 0, sepx = 0, sepy = 0, sepz = 0, sepc = 0;
        float x = 0, y = 0, z = 0, v = 0, bcond = 0;
        bool is_substitution_done = false;
        const char *subset = sep?inbraces.data() + l_ind + 1:&sep;
        *substr = 0;

        // Test for simple arguments '@{ind,arg}' where 'arg' is w,h,d,s,....
        if (*subset) {
          is_substitution_done = true;
          switch (*subset) {
          case 'w' :
            if (subset[1]=='h') {
              if (subset[2]=='d') {
                if (subset[3]=='s' && !subset[4])
                  cimg_snprintf(substr,substr.width(),"%d",
                                img.width()*img.height()*img.depth()*img.spectrum());
                else if (!subset[3])
                  cimg_snprintf(substr,substr.width(),"%d",
                                img.width()*img.height()*img.depth());
                else is_substitution_done = false;
              } else if (!subset[2])
                cimg_snprintf(substr,substr.width(),"%d",img.width()*img.height());
              else is_substitution_done = false;
            } else if (!subset[1])
              cimg_snprintf(substr,substr.width(),"%d",img.width());
            else is_substitution_done = false;
            break;
          case 'h' :
            if (!subset[1]) cimg_snprintf(substr,substr.width(),"%d",img.height());
            else is_substitution_done = false;
            break;
          case 'd' :
            if (!subset[1]) cimg_snprintf(substr,substr.width(),"%d",img.depth());
            else is_substitution_done = false;
            break;
          case 's' :
            if (!subset[1]) cimg_snprintf(substr,substr.width(),"%d",img.spectrum());
            else is_substitution_done = false;
            break;
          case 'r' :
            if (!subset[1]) cimg_snprintf(substr,substr.width(),"%d",img.is_shared());
            else is_substitution_done = false;
            break;
          case 'n' :
            if (!subset[1]) cimg_snprintf(substr,substr.width(),"%s",images_names[nind].data());
            else is_substitution_done = false;
            break;
          case 'b' :
            if (!subset[1]) {
              cimg::split_filename(images_names[nind].data(),substr);
              const char *const basename = cimg::basename(substr);
              if (substr.data()!=basename)
                substr.draw_image(CImg<char>::string(basename));
            } else is_substitution_done = false;
            break;
          case 'x' :
            if (!subset[1])
              cimg_snprintf(substr,substr.width(),"%s",
                            cimg::split_filename(images_names[nind].data()));
            else is_substitution_done = false;
            break;
          case 'f' :
            if (!subset[1]) {
              CImg<char> _substr(images_names[nind]);
              char *const basename = const_cast<char*>(cimg::basename(_substr));
              *basename = 0;
              std::strcpy(substr,_substr);
            } else is_substitution_done = false;
            break;
          case '#' :
            if (!subset[1]) cimg_snprintf(substr,substr.width(),"%lu",img.size());
            else is_substitution_done = false;
            break;
          case '+' :
            if (!subset[1]) {
              double res = img?(double)img.front():0;
              for (const T *ptrs = img.data() + 1, *ptre = img.end(); ptrs<ptre;
                   res+=(double)*ptrs++) {}
              cimg_snprintf(substr,substr.width(),"%.16g",res);
            } else is_substitution_done = false;
            break;
          case '-' :
            if (!subset[1]) {
              double res = img?(double)img.front():0;
              for (const T *ptrs = img.data() + 1, *ptre = img.end(); ptrs<ptre;
                   res-=(double)*ptrs++) {}
              cimg_snprintf(substr,substr.width(),"%.16g",res);
            } else is_substitution_done = false;
            break;
          case '*' :
            if (!subset[1]) {
              double res = img?(double)img.front():0;
              for (const T *ptrs = img.data() + 1, *ptre = img.end(); ptrs<ptre;
                   res*=(double)*ptrs++) {}
              cimg_snprintf(substr,substr.width(),"%.16g",res);
            } else is_substitution_done = false;
            break;
          case '/' : if (!subset[1]) {
              double res = img?(double)img.front():0;
              for (const T *ptrs = img.data() + 1, *ptre = img.end(); ptrs<ptre;
                   res/=(double)*ptrs++) {}
              cimg_snprintf(substr,substr.width(),"%.16g",res);
            } else is_substitution_done = false;
            break;
          case 'm' :
            if (!subset[1]) cimg_snprintf(substr,substr.width(),"%.16g",(double)img.min());
            else is_substitution_done = false;
            break;
          case 'M' :
            if (!subset[1]) cimg_snprintf(substr,substr.width(),"%.16g",(double)img.max());
            else is_substitution_done = false;
            break;
          case 'a' :
            if (!subset[1]) cimg_snprintf(substr,substr.width(),"%.16g",img.mean());
            else is_substitution_done = false;
            break;
          case 'v' :
            if (!subset[1]) cimg_snprintf(substr,substr.width(),"%.16g",img.variance());
            else is_substitution_done = false;
            break;
          case 't' :
            if (!subset[1]) {
              const unsigned int siz = (unsigned int)img.size();
              if (siz) {
                unsigned int strsiz = 0;
                cimg_for(img,ptr,T) if ((unsigned char)*ptr) ++strsiz;
                if (strsiz) {
                  CImg<char> text(strsiz+1), _text = text.get_shared_points(0,strsiz-1,0,0,0);
                  _text = CImg<T>(img.data(),strsiz,1,1,1,true);
                  text.back() = 0;
                  gmic_strreplace(text.data());
                  _text.move_to(substituted_items);
                }
              }
              *substr = 0;
            } else is_substitution_done = false;
            break;
          case 'c' :
            if (!subset[1]) {
              CImg<unsigned int> st;
              if (img) st = img.get_stats(); else st.assign(8,1,1,1,0);
              cimg_snprintf(substr,substr.width(),"%u,%u,%u,%u",st[4],st[5],st[6],st[7]);
            } else is_substitution_done = false;
            break;
          case 'C' :
            if (!subset[1]) {
              CImg<unsigned int> st;
              if (img) st = img.get_stats(); else st.assign(12,1,1,1,0);
              cimg_snprintf(substr,substr.width(),"%u,%u,%u,%u",st[8],st[9],st[10],st[11]);
            } else is_substitution_done = false;
            break;
          default : is_substitution_done = false;
          }

          // Test for access to pixel value '@{ind,(x,y,z,c,boundary)}'.
          if (is_substitution_done) {
            if (*substr) CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
          } else if ((std::sscanf(subset,"(%255[0-9.eE%+-]%c%c",
                                  argx,&sepp,&end)==2 ||
                      std::sscanf(subset,"(%255[0-9.eE%+-],%255[0-9.eE%+-]%c%c",
                                  argx,argy,&sepp,&end)==3 ||
                      std::sscanf(subset,"(%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-]%c%c",
                                  argx,argy,argz,&sepp,&end)==4 ||
                      std::sscanf(subset,"(%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                                  "%255[0-9.eE%+-]%c%c",
                                  argx,argy,argz,argc,&sepp,&end)==5 ||
                      std::sscanf(subset,"(%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                                  "%255[0-9.eE%+-],%f%c%c",
                                  argx,argy,argz,argc,&bcond,&sepp,&end)==6) &&
                     sepp==')' &&
                     (std::sscanf(argx,"%f%c",&x,&end)==1 ||
                      (std::sscanf(argx,"%f%c%c",&x,&sepx,&end)==2 && sepx=='%')) &&
                     (!*argy ||
                      std::sscanf(argy,"%f%c",&y,&end)==1 ||
                      (std::sscanf(argy,"%f%c%c",&y,&sepy,&end)==2 && sepy=='%')) &&
                     (!*argz ||
                      std::sscanf(argz,"%f%c",&z,&end)==1 ||
                      (std::sscanf(argz,"%f%c%c",&z,&sepz,&end)==2 && sepz=='%')) &&
                     (!*argc ||
                      std::sscanf(argc,"%f%c",&v,&end)==1 ||
                      (std::sscanf(argc,"%f%c%c",&v,&sepc,&end)==2 && sepc=='%'))) {
            const int
              nx = (int)cimg::round(sepx=='%'?x*(img.width()-1)/100:x),
              ny = (int)cimg::round(sepy=='%'?y*(img.height()-1)/100:y),
              nz = (int)cimg::round(sepz=='%'?z*(img.depth()-1)/100:z),
              nv = (int)cimg::round(sepc=='%'?v*(img.spectrum()-1)/100:v);
            cimg_snprintf(substr,substr.width(),"%.16g",
                          bcond?(double)img.atXYZC(nx,ny,nz,nv):(double)img.atXYZC(nx,ny,nz,nv,0));
            CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
            is_substitution_done = true;
          }
        }

        // Test for values subset, as in '@{ind,0-10}'.
        if (!is_substitution_done) {
          CImg<T> values;
          is_substitution_done = true;
          if (!*subset) values = img.get_shared();
          else {
            int _verbosity = verbosity;
            bool _is_debug = is_debug;
            verbosity = -1; is_debug = false;
            try {
              const CImg<unsigned int>
                inds = selection2cimg(subset,img.size(),
                                      CImgList<char>::empty(),"",false,false,CImg<char>::empty());
              values.assign(1,inds.height());
              cimg_foroff(inds,p) values[p] = img[inds(p)];
            } catch (gmic_exception&) {
              is_substitution_done = false;
            }
            verbosity = _verbosity; is_debug = _is_debug;
          }
          if (is_substitution_done) {
            cimg_foroff(values,p) {
              cimg_snprintf(substr,substr.width(),"%.16g",(double)values[p]);
              CImg<char>::string(substr).move_to(substituted_items).back().back() = ',';
            }
            if (values) --(substituted_items.back()._width);
          }
        }

        // -> 'argument' is considered as math expression associated to an image, as '@{ind,w/2}'.
        if (!is_substitution_done) {
          try {
            cimg_snprintf(substr,substr.width(),"%.16g",img.eval(subset));
          } catch (CImgException&) {
            error(images,"Item substitution '@{%d,%s}': Invalid argument '%s'.",
                  ind,subset,subset);
          }
          CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
        }

        // Substitute '@' by itself, if no @-pattern matches.
      } else if (!is_braces || *nsource!='@') CImg<char>(nsource++,1).move_to(substituted_items);

      // Substitute '@{command}' by the status value after command execution.
      else {
        nsource+=l_inbraces + 3;
        if (l_inbraces>0) {
          const CImgList<char>
            ncommands_line = commands_line_to_CImgList(gmic_strreplace(inbraces));
          unsigned int nposition = 0;
          CImg<char>::string("*substitute").move_to(scope);
	  unsigned int nvariables_sizes[256];
	  for (unsigned int l = 0; l<256; ++l) nvariables_sizes[l] = variables[l]->size();
          _parse(ncommands_line,nposition,images,images_names,nvariables_sizes);
	  for (unsigned int l = 0; l<255; ++l) if (variables[l]->size()>nvariables_sizes[l]) {
	      variables_names[l]->remove(nvariables_sizes[l],variables[l]->size()-1);
	      variables[l]->remove(nvariables_sizes[l],variables[l]->size()-1);
	    }
          scope.remove();
          is_return = false;
        }
        if (status.width()>1)
          CImg<char>(status.data(),status.width()-1).move_to(substituted_items);
        continue;
      }
    }
  CImg<char>::vector(0).move_to(substituted_items);
  return substituted_items>'x';
}

// Main parsing procedure.
//------------------------
template<typename T>
gmic& gmic::_parse(const CImgList<char>& commands_line, unsigned int& position,
                   CImgList<T> &images, CImgList<char> &images_names,
                   unsigned int variables_sizes[256]) {

#ifdef gmic_float
  typedef typename cimg::superset<T,float>::type Tfloat;
  typedef typename cimg::superset<T,long>::type Tlong;
#endif // #ifdef gmic_float
# 3942 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

  const unsigned int initial_scope_size = scope.size(), initial_debug_line = debug_line;
  bool is_endlocal = false;
  char end;

  // Allocate string variables, widely used afterwards
  // (prevents stack overflow on recursive calls while remaining thread-safe).
  CImgList<st_gmic_parallel<T> > threads_data;
  CImg<char> _formula(4096), _message(1024), _title(256), _indices(256),
    _argx(256), _argy(256), _argz(256), _argc(256);
  char
    *const formula = _formula.fill(0).data(),
    *const message = _message.fill(0).data(),
    *const title = _title.fill(0).data(),
    *const indices = _indices.fill(0).data(),
    *const argx = _argx.fill(0).data(),
    *const argy = _argy.fill(0).data(),
    *const argz = _argz.fill(0).data(),
    *const argc = _argc.fill(0).data();

#ifdef gmic_float
  CImg<char> _color(4096);
  char *const color = _color.data();
#endif // #ifdef gmic_float
# 3966 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

  try {

    // Init parser environment.
    cimg::exception_mode() = 0;
    if (images.size()<images_names.size())
      images_names.remove(images.size(),images_names.size()-1);
    else if (images.size()>images_names.size())
      images_names.insert(images.size() - images_names.size(),CImg<char>::string("[unnamed]"));

    is_debug_infos = false;
    if (is_debug) {
      nb_carriages = 2;
      debug(images,"%sStart G'MIC parser in scope '%s/' [%s].%s",
            cimg::t_bold,scope.back().data(),CImg<T>::pixel_type(),cimg::t_normal);
      is_start = false;
    }

    // Begin command line parsing.
    if (!commands_line && is_start) { print(images,"Start G'MIC parser."); is_start = false; }
    while (position<commands_line.size() && !is_quit && !is_return) {

      // Process debug infos.
      while (position<commands_line.size() && *commands_line[position]==1) {
        const CImg<char> &code = commands_line[position];
        if (!std::sscanf(code.data()+1,"%x,%x",&debug_line,&(debug_filename=0)))
          debug_filename = debug_line = ~0U;
        else is_debug_infos = true;
        ++position;
      }
      if (position>=commands_line.size()) continue;

      // Check consistency of the parser environment.
      if (images_names.size()!=images.size())
        error("Internal error: Images (%u) and images names (%u) have different size.",
              images_names.size(),images.size());
      if (!scope)
        error("Internal error: Scope is empty.");
      if (scope.size()>64)
        error("Internal error: Scope overflow (infinite recursion ?).");

      // Substitute expressions in current item.
      const char
        *const initial_item = commands_line[position].data(),
        *const initial_argument = position+1<commands_line.size()?commands_line[position+1].data():"";

      CImg<char> _item, _argument, _argument_text;
      substitute_item(initial_item,images,images_names,variables_sizes).move_to(_item);
      char *item = _item.data();
      const char *argument = initial_argument, *argument_text = initial_argument;

      // Split command/restriction, if necessary.
      CImg<char> _command(256), _restriction(256);
      char *const command = _command.data(), *const restriction = _restriction.data();
      *command = *restriction = 0;

      bool is_get_version = false, is_restriction = false;
      CImg<unsigned int> selection;
      CImg<char> new_name;
      if (item[0]=='-' && item[1] && item[1]!='.') {
        char sep0 = 0, sep1 = 0;
        if (item[1]=='-' && item[2] && item[2]!='[' && (item[2]!='3' || item[3]!='d')) {
          ++item; is_get_version = true;
        }
        gmic_strreplace(item);
        const int err = std::sscanf(item,"%255[^[]%c%255[a-zA-Z_0-9.eE%^,:+-]%c%c",
                                    command,&sep0,restriction,&sep1,&end);
        if (err==1) selection = CImg<unsigned int>::sequence(images.size(),0,images.size()-1);
        else if (err==2 && sep0=='[' && item[std::strlen(command)+1]==']') {
          selection.assign(); is_restriction = true;
        } else if (err==4 && sep1==']') {
          is_restriction = true;
          if ((!std::strcmp("-wait",command) || !std::strcmp("-cursor",command)) && !is_get_version)
            selection = selection2cimg(restriction,10,CImgList<char>::empty(),command,true,
                                       false,CImg<char>::empty());
          else if ((!std::strcmp("-i",command) || !std::strcmp("-input",command)) &&
                   !is_get_version)
            selection = selection2cimg(restriction,images.size()+1,images_names,command,true,
                                       true,new_name);
          else if ((!std::strcmp("-e",command) || !std::strcmp("-echo",command) ||
                    !std::strcmp("-error",command) || !std::strcmp("-warn",command)) &&
                   !is_get_version)
            selection = selection2cimg(restriction,scope.size(),CImgList<char>::empty(),
                                       command,true,false,CImg<char>::empty());
          else
            selection = selection2cimg(restriction,images.size(),images_names,command,true,
                                       false,CImg<char>::empty());
        } else {
          std::strncpy(command,item,_command.size()-1);
          command[_command.size()-1] = *restriction = 0;
        }
        if (is_get_version) --item;
      } else {
        std::strncpy(command,item,_command.size()-1);
        command[_command.size()-1] = *restriction = 0;
      }
      ++position;

      if (is_debug) {
        const char *const _initial_item = initial_item+(is_get_version?1:0);
        if (std::strcmp(item,_initial_item))
          debug(images,"Item '%s' -> '%s', indice%s.",
                _initial_item,item,gmic_selection);
        else
          debug(images,"Item '%s', indice%s.",
                _initial_item,gmic_selection);
      }

      // Check for verbosity command, prior to the first output of a log message.
      bool is_verbose_argument = false;
      const int old_verbosity = verbosity;
      if (!std::strcmp("-v",item) || !std::strcmp("-verbose",item)) {
        // Do a first fast check.
        if (*argument=='-' && !argument[1]) { --verbosity; is_verbose_argument = true; }
        else if (*argument=='+' && !argument[1]) { ++verbosity; is_verbose_argument = true; }
        else {
          gmic_substitute_args();
          if (*argument=='-' && !argument[1]) { --verbosity; is_verbose_argument = true; }
          else if (*argument=='+' && !argument[1]) { ++verbosity; is_verbose_argument = true; }
          else {
            float level = 0;
            if (std::sscanf(argument,"%f%c",&level,&end)==1) {
              verbosity = (int)cimg::round(level);
              is_verbose_argument = true;
            }
            else verbosity = 0;
          }
        }
      }
      if (is_start) { print(images,"Start G'MIC parser."); is_start = false; }

      // Check for cancellation point.
      if (*cancel) {
        if (verbosity>0 || is_debug) print(images,"Cancel G'MIC instance.\n");
        dowhiles.assign();
        repeatdones.assign();
        position = commands_line.size();
        is_released = is_quit = true;
        break;
      }

      // Begin command interpretation.
      if (*item=='-' && item[1]) {

        // Replace some shortcut names whose three first chars are different than correspondent
        // regular names (not all shortcuts are replaced, but it reduces the number of string
        // comparisons afterwards).
        char _item[16] = { 0 }, command1 = command[1];
        const char
          command2 = command1?command[2]:0, command3 = command2?command[3]:0,
          command4 = command3?command[4]:0, command5 = command4?command[5]:0;

        if (!command2) switch (command1) {  // One-char shortcuts.
          case 'm' : if (!is_get_version && !is_restriction) {
              std::strcpy(item=_item,"-command"); command1 = 'c';
            } break;
          case 'd' : std::strcpy(command,"-display"); break;
          case 'e' : std::strcpy(command,"-echo"); break;
          case 'i' : std::strcpy(command,"-input"); break;
          case 'o' : std::strcpy(command,"-output"); break;
          case 'p' : std::strcpy(command,"-print"); break;
          case 'v' : if (!is_get_version && !is_restriction)
              std::strcpy(item=_item,"-verbose"); break;
          case 'w' : std::strcpy(command,"-window"); break;
          case 'k' : std::strcpy(command,"-keep"); break;
          case '+' : std::strcpy(command,"-add"); command1 = 'a'; break;
          case '/' : std::strcpy(command,"-div"); command1 = 'd'; break;
          case '>' : std::strcpy(command,"-gt"); command1 = 'g'; break;
          case '<' : std::strcpy(command,"-lt"); command1 = 'l'; break;
          case '%' : std::strcpy(command,"-mod"); command1 = 'm'; break;
          case '*' : std::strcpy(command,"-mul"); command1 = 'm'; break;
          case '^' : std::strcpy(command,"-pow"); command1 = 'p'; break;
          case '-' : std::strcpy(command,"-sub"); command1 = 's'; break;
          case 'c' : std::strcpy(command,"-cut"); break;
          case 'f' : std::strcpy(command,"-fill"); break;
          case 'n' : std::strcpy(command,"-normalize"); break;
          case '=' : std::strcpy(command,"-set"); command1 = 's'; break;
          case 't' : std::strcpy(command,"-text"); break;
          case 'a' : std::strcpy(command,"-append"); break;
          case 'z' : std::strcpy(command,"-crop"); command1 = 'c'; break;
          case 'r' : std::strcpy(command,"-resize"); break;
          case 's' : std::strcpy(command,"-split"); break;
          case 'y' : std::strcpy(command,"-unroll"); command1 = 'u'; break;
          case 'b' : std::strcpy(command,"-blur"); break;
          case 'g' : std::strcpy(command,"-gradient"); break;
          case 'j' : std::strcpy(command,"-image"); command1 = 'i'; break;
          case 'q' : if (!is_get_version && !is_restriction)
              std::strcpy(item=_item,"-quit"); break;
          case 'l' : std::strcpy(command,"-local"); break;
          case 'u' : if (!is_get_version && !is_restriction)
              std::strcpy(item=_item,"-status"); command1 = 's'; break;
          case 'x' : if (!is_get_version && !is_restriction)
              std::strcpy(item=_item,"-exec"); command1 = 'e'; break;
          } else if (!command3) { // Two-chars shortcuts.
          if (command1=='s' && command2=='h') std::strcpy(command,"-shared");
          else if (command1=='m' && command2=='v') std::strcpy(command,"-move");
          else if (command1=='n' && command2=='m') std::strcpy(command,"-name");
          else if (command1=='r' && command2=='m') std::strcpy(command,"-remove");
          else if (command1=='r' && command2=='v') std::strcpy(command,"-reverse");
          else if (command1=='<' && command2=='<') { std::strcpy(command,"-bsl"); command1 = 'b'; }
          else if (command1=='>' && command2=='>') { std::strcpy(command,"-bsr"); command1 = 'b'; }
          else if (command1=='=' && command2=='=') { std::strcpy(command,"-eq"); command1 = 'e'; }
          else if (command1=='>' && command2=='=') { std::strcpy(command,"-ge"); command1 = 'g'; }
          else if (command1=='<' && command2=='=') { std::strcpy(command,"-le"); command1 = 'l'; }
          else if (command1=='/' && command2=='/') {
            std::strcpy(command,"-mdiv"); command1 = 'm';
          }
          else if (command1=='*' && command2=='*') {
            std::strcpy(command,"-mmul"); command1 = 'm';
          }
          else if (command1=='!' && command2=='=') { std::strcpy(command,"-neq"); command1 = 'n'; }
        } else if (!command4 && command2=='3' && command3=='d') switch (command1) {
            // Three-chars shortcuts (ending with '3d').
          case 'd' : std::strcpy(command,"-display3d"); break;
          case '+' : std::strcpy(command,"-add3d"); command1 = 'a'; break;
          case 'b' : if (!is_get_version && !is_restriction)
              std::strcpy(item=_item,"-background3d"); break;
          case '/' : std::strcpy(command,"-div3d"); command1 = 'd'; break;
          case 'f' : if (!is_get_version && !is_restriction)
              std::strcpy(item=_item,"-focale3d"); break;
          case 'l' : if (!is_get_version && !is_restriction)
              std::strcpy(item=_item,"-light3d"); break;
          case 'm' : if (!is_get_version && !is_restriction)
              std::strcpy(item=_item,"-mode3d"); break;
          case '*' : std::strcpy(command,"-mul3d"); command1 = 'm'; break;
          case 'o' : std::strcpy(command,"-opacity3d"); break;
          case 'p' : std::strcpy(command,"-primitives3d"); break;
          case 'r' : std::strcpy(command,"-rotate3d"); break;
          case 's' : std::strcpy(command,"-split3d"); break;
          case '-' : std::strcpy(command,"-sub3d"); command1 = 's'; break;
          case 't' : std::strcpy(command,"-texturize3d"); break;
          } else if (!command5 && command3=='3' && command4=='d') {
          // Four-chars shortcuts (ending with '3d').
          if (command1=='d' && command2=='b') {
            if (!is_get_version && !is_restriction) std::strcpy(item=_item,"-double3d");
          } else if (command1=='m' && command2=='d') {
            if (!is_get_version && !is_restriction) std::strcpy(item=_item,"-moded3d");
          }
          else if (command1=='r' && command2=='v') std::strcpy(command,"-reverse3d");
          else if (command1=='s' && command2=='l') {
            if (!is_get_version && !is_restriction) std::strcpy(item=_item,"-specl3d");
          }
          else if (command1=='s' && command2=='s') {
            if (!is_get_version && !is_restriction) std::strcpy(item=_item,"-specs3d");
          }
        }

        // Check if new name has been requested for a command that does not allow that.
        if (new_name && std::strcmp("-input",command) && !is_get_version)
          error(images,"Item '%s %s': Unknow name '%s'.",
                initial_item,initial_argument,new_name.data());

        //----------------------------
        // Commands starting by '-a..'
        //----------------------------
        if (command1=='a') {

          // Append.
          if (!std::strcmp("-append",command)) {
            gmic_substitute_args();
            float align = 0;
            char axis = 0, sep = 0;
            CImg<unsigned int> ind;
            if ((std::sscanf(argument,"%c%c",
                             &axis,&end)==1 ||
                 std::sscanf(argument,"%c,%f%c",
                             &axis,&align,&end)==2) &&
                (axis=='x' || axis=='y' || axis=='z' || axis=='c')) {
              print(images,"Append image%s along the '%c'-axis, with alignment %g.",
                    gmic_selection,
                    axis,align);
              if (selection) {
                CImgList<T> subimages;
                cimg_forY(selection,l) if (gmic_check(images[selection[l]]))
                  subimages.insert(gmic_check(images[selection[l]]),~0U,true);
                CImg<T> img = subimages.get_append(axis,align);
                CImg<char> name = images_names[selection[0]].get_mark();
                if (is_get_version) {
                  img.move_to(images);
                  images_names.insert(name.copymark());
                } else if (selection.height()>=2) {
                  remove_images(images,images_names,selection,1,selection.height()-1);
                  img.move_to(images[selection[0]].assign());
                  name.move_to(images_names[selection[0]]);
                }
              }
            } else if ((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c,%c%c",
                                    indices,&sep,&axis,&end)==3 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c,%c,%f%c",
                                    indices,&sep,&axis,&(align=0),&end)==4) &&
                       (axis=='x' || axis=='y' || axis=='z' || axis=='c') &&
                       sep==']' &&
                       (ind=selection2cimg(indices,images.size(),images_names,"-append",true,
                                           false,CImg<char>::empty())).height()==1) {
              print(images,"Append image [%u] to image%s, along the '%c'-axis, with alignment %g.",
                    *ind,gmic_selection,axis,align);
              const CImg<T> img0 = gmic_image_arg(*ind);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],append(img0,axis,align));
            } else arg_error("append");
            is_released = false; ++position; continue;
          }

          // Autocrop.
          if (!std::strcmp("-autocrop",command)) {
            gmic_substitute_args();
            CImg<T> is_arg;
            if (*argument && std::sscanf(argument,"%4095[0-9.,eE+-]%c",formula,&end)==1)
              try { CImg<T>(1).fill(argument,true).move_to(is_arg); }
              catch (CImgException&) { is_arg.assign(); }
            if (is_arg) {
              print(images,"Auto-crop image%s by vector '%s'.",
                    gmic_selection,
                    argument_text);
              ++position;
            } else print(images,"Auto-crop image%s.",
                         gmic_selection);
            cimg_forY(selection,l) {
              CImg<T>& img = images[selection[l]];
              if (is_arg) {
                const CImg<T> col = CImg<T>(img.spectrum()).fill(argument,true);
                gmic_apply(img,gmic_autocrop(col));
              }
              else gmic_apply(img,gmic_autocrop());
            }
            is_released = false; continue;
          }

#ifdef gmic_float

          // Add.
          gmic_arithmetic_item("-add",
                               operator+=,
                               "Add %g%s to image%s",
                               value,ssep,gmic_selection,Tfloat,
                               operator+=,
                               "Add image [%d] to image%s",
                               ind[0],gmic_selection,
                               "Add expression %s to image%s",
                               argument_text,gmic_selection,
                               "Add image%s");

          // Add 3d objects together, or shift a 3d object.
          if (!std::strcmp("-add3d",command)) {
            gmic_substitute_args();
            float tx = 0, ty = 0, tz = 0;
            CImg<unsigned int> ind;
            char sep = 0;
            if (std::sscanf(argument,"%f%c",
                            &tx,&end)==1 ||
                std::sscanf(argument,"%f,%f%c",
                            &tx,&ty,&end)==2 ||
                std::sscanf(argument,"%f,%f,%f%c",
                            &tx,&ty,&tz,&end)==3) {
              print(images,"Shift 3d object%s by displacement (%g,%g,%g).",
                    gmic_selection,
                    tx,ty,tz);
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                CImg<T>& img = gmic_check(images[ind]);
                try { gmic_apply(img,shift_CImg3d(tx,ty,tz)); }
                catch (CImgException &e) {
                  if (!img.is_CImg3d(true,message))
                    error(images,
                          "Command '-add3d': Invalid 3d object [%d], in selected image%s (%s).",
                          ind,gmic_selection,message);
                  else throw e;
                }
              }
              ++position;
            } else if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 &&
                       sep==']' &&
                       (ind=selection2cimg(indices,images.size(),images_names,"-add3d",true,
                                           false,CImg<char>::empty())).height()==1) {
              const CImg<T> img0 = gmic_image_arg(*ind);
              print(images,"Merge 3d object%s with 3d object [%u].",
                    gmic_selection,*ind);
              CImgList<T> nimages(2);
              nimages[1].assign(img0,true);
              cimg_forY(selection,l) {
                const unsigned int _ind = selection[l];
                CImg<T>& img = gmic_check(images[_ind]);
                nimages[0].assign(img,true);
                CImg<T> res;
                try { CImg<T>::append_CImg3d(nimages).move_to(res); }
                catch (CImgException &e) {
                  if (!img0.is_CImg3d(true,message))
                    error(images,"Command '-add3d': Invalid 3d object [%u], in specified "
                          "argument '%s' (%s).",
                          *ind,argument_text,message);
                  else if (!img.is_CImg3d(true,message))
                    error(images,
                          "Command '-add3d': Invalid 3d object [%d], in selected image%s (%s).",
                          _ind,gmic_selection,message);
                  else throw e;
                }
                if (is_get_version) {
                  res.move_to(images);
                  images_names[_ind].get_mark().copymark().move_to(images_names);
                } else {
                  res.move_to(images[_ind].assign());
                  images_names[_ind].mark();
                }
              }
              ++position;
            } else {
              print(images,"Merge 3d object%s.",
                    gmic_selection);
              if (selection) {
                CImgList<T> subimages(selection.height());
                cimg_forY(selection,l) subimages[l].assign(gmic_check(images[selection[l]]),true);
                CImg<T> img;
                try { CImg<T>::append_CImg3d(subimages).move_to(img); }
                catch (CImgException &e) {
                  cimg_forY(selection,l) {
                    const unsigned int ind = selection[l];
                    if (!images[ind].is_CImg3d(true,message))
                      error(images,
                            "Command '-add3d': Invalid 3d object [%d], in selected image%s (%s).",
                            ind,gmic_selection,message);
                  }
                  throw e;
                }
                CImg<char> name = images_names[selection[0]].get_mark();
                if (is_get_version) {
                  img.move_to(images);
                  images_names.insert(name.copymark());
                } else if (selection.height()>=2) {
                  remove_images(images,images_names,selection,1,selection.height()-1);
                  img.move_to(images[selection[0]].assign());
                  name.move_to(images_names[selection[0]]);
                }
              }
            }
            is_released = false; continue;
          }

          // Absolute value.
          gmic_simple_item("-abs",abs,"Compute pointwise absolute value of image%s.");

          // Bitwise and.
          gmic_arithmetic_item("-and",
                               operator&=,
                               "Compute bitwise AND of image%s by %g%s",
                               gmic_selection,value,ssep,Tlong,
                               operator&=,
                               "Compute bitwise AND of image%s by image [%d]",
                               gmic_selection,ind[0],
                               "Compute bitwise AND of image%s by expression %s",
                               gmic_selection,argument_text,
                               "Compute sequential bitwise AND of image%s");

          // Arc-tangent (two arguments).
          if (!std::strcmp("-atan2",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind;
            char sep = 0;
            if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                            indices,&sep,&end)==2 && sep==']' &&
                (ind=selection2cimg(indices,images.size(),images_names,"-atan2",true,
                                    false,CImg<char>::empty())).height()==1) {
              print(images,"Compute pointwise oriented arc-tangent of image%s, "
                    "with x-argument [%u].",
                    gmic_selection,
                    *ind);
              const CImg<T> img0 = gmic_image_arg(*ind);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],atan2(img0));
            } else arg_error("atan2");
            is_released = false; ++position; continue;
          }

          // Arc-cosine.
          gmic_simple_item("-acos",acos,"Compute pointwise arc-cosine of image%s.");

          // Arc-sine.
          gmic_simple_item("-asin",asin,"Compute pointwise arc-sine of image%s.");

          // Arc-tangent.
          gmic_simple_item("-atan",atan,"Compute pointwise arc-tangent of image%s.");

          // Draw axes.
          if (!std::strcmp("-axes",command)) {
            gmic_substitute_args();
            float xmin = 0, xmax = 0, ymin = 0, ymax = 0, opacity = 1, siz = 13;
            unsigned int pattern = ~0U;
            char seph = 0;
            *color = 0;
            if (std::sscanf(argument,"%f,%f%c",
                            &xmin,&xmax,&end)==2 ||
                std::sscanf(argument,"%f,%f,%f,%f%c",
                            &xmin,&xmax,&ymin,&ymax,&end)==4 ||
                std::sscanf(argument,"%f,%f,%f,%f,%f%c",
                            &xmin,&xmax,&ymin,&ymax,&siz,&end)==5 ||
                std::sscanf(argument,"%f,%f,%f,%f,%f,%f%c",
                            &xmin,&xmax,&ymin,&ymax,&siz,&opacity,&end)==6 ||
                (std::sscanf(argument,"%f,%f,%f,%f,%f,%f,0%c%x%c",
                             &xmin,&xmax,&ymin,&ymax,&siz,&opacity,&seph,&pattern,&end)==8 &&
                 seph=='x') ||
                (std::sscanf(argument,"%f,%f,%f,%f,%f,%f,%4095[0-9.eE,+-]%c",
                             &xmin,&xmax,&ymin,&ymax,&siz,&opacity,color,&end)==7 &&
                 (bool)(pattern=~0U)) ||
                (*color=0,std::sscanf(argument,"%f,%f,%f,%f,%f,%f,0%c%x,%4095[0-9.eE,+-]%c",
                                      &xmin,&xmax,&ymin,&ymax,&siz,&opacity,
                                      &seph,&pattern,color,&end)==9 && seph=='x')) {
              siz = cimg::round(siz);
              print(images,"Draw xy-axes on image%s, with x-range (%g,%g), y-range (%g,%g), "
                    "font height %g, opacity %g, pattern 0x%x and color (%s).",
                    gmic_selection,
                    xmin,xmax,
                    ymin,ymax,
                    siz,opacity,pattern,
                    *color?color:"default");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]], col(img.spectrum(),1,1,1,0);
                col.fill(color,true);
                gmic_apply(img,draw_axes(xmin,xmax,ymin,ymax,col.data(),opacity,
                                         -60,-60,0,0,pattern,pattern,(unsigned int)siz));
              }
            } else arg_error("axes");
            is_released = false; ++position; continue;
          }

#endif // #ifdef gmic_float
# 4488 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='a'.

        //----------------------------
        // Commands starting by '-b..'
        //----------------------------
        else if (command1=='b') {

#ifdef gmic_float

          // Blur.
          if (!std::strcmp("-blur",command)) {
            gmic_substitute_args();
            unsigned int boundary = 1, is_gaussian = 0;
            float sigma = -1;
            char sep = 0;
            if ((std::sscanf(argument,"%f%c",
                             &sigma,&end)==1 ||
                 (std::sscanf(argument,"%f%c%c",
                              &sigma,&sep,&end)==2 && sep=='%') ||
                 std::sscanf(argument,"%f,%u%c",
                             &sigma,&boundary,&end)==2 ||
                 (std::sscanf(argument,"%f%c,%u%c",
                              &sigma,&sep,&boundary,&end)==3 && sep=='%') ||
                 std::sscanf(argument,"%f,%u,%u%c",
                             &sigma,&boundary,&is_gaussian,&end)==3 ||
                 (std::sscanf(argument,"%f%c,%u,%u%c",
                              &sigma,&sep,&boundary,&is_gaussian,&end)==4 && sep=='%')) &&
                sigma>=0 && boundary<=1 && is_gaussian<=1) {
              print(images,"Blur image%s, with standard deviation %g%s, %s boundary conditions "
                    "and %s kernel.",
                    gmic_selection,
                    sigma,sep=='%'?"%":"",
                    boundary?"neumann":"dirichlet",
                    is_gaussian?"gaussian":"quasi-gaussian");
              if (sep=='%') sigma = -sigma;
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],blur(sigma,(bool)boundary,(bool)is_gaussian));
            } else arg_error("blur");
            is_released = false; ++position; continue;
          }

          // Bitwise right shift.
          gmic_arithmetic_item("-bsr",
                               operator>>=,
                               "Compute bitwise right shift of image%s by %g%s",
                               gmic_selection,value,ssep,Tlong,
                               operator>>=,
                               "Compute bitwise right shift of image%s by image [%d]",
                               gmic_selection,ind[0],
                               "Compute bitwise right shift of image%s by expression %s",
                               gmic_selection,argument_text,
                               "Compute sequential bitwise right shift of image%s");

          // Bitwise left shift.
          gmic_arithmetic_item("-bsl",
                               operator<<=,
                               "Compute bitwise left shift of image%s by %g%s",
                               gmic_selection,value,ssep,Tlong,
                               operator<<=,
                               "Compute bitwise left shift of image%s by image [%d]",
                               gmic_selection,ind[0],
                               "Compute bitwise left shift of image%s by expression %s",
                               gmic_selection,argument_text,
                               "Compute sequential bitwise left shift of image%s");

          // Bilateral filter.
          if (!std::strcmp("-bilateral",command)) {
            gmic_substitute_args();
            float sigma_s = 0, sigma_r = 0;
            CImg<unsigned int> ind;
            char sep_s =  0, sep_r = 0;
            if ((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             indices,argx,argy,&end)==3) &&
                (std::sscanf(argx,"%f%c",&sigma_s,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&sigma_s,&sep_s,&end)==2 && sep_s=='%')) &&
                (std::sscanf(argy,"%f%c",&sigma_r,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&sigma_r,&sep_r,&end)==2 && sep_r=='%')) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-bilateral",true,
                                    false,CImg<char>::empty())).height()==1 &&
                sigma_s>=0 && sigma_r>=0) {
              print(images,"Apply joint bilateral filter on image%s, with guide image [%u] "
                    "and standard deviations %g%s and %g.",
                    gmic_selection,
                    *ind,
                    sigma_s,sep_s=='%'?"%":"",
                    sigma_r,sep_r=='%'?"%":"");
              const CImg<T> guide = gmic_image_arg(*ind);
              if (sep_s=='%') sigma_s = -sigma_s;
              if (sep_r=='%') sigma_r = -sigma_r;
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],blur_bilateral(guide,sigma_s,sigma_r));
            } else if ((std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                                    argx,argy,&end)==2) &&
                       (std::sscanf(argx,"%f%c",&sigma_s,&end)==1 ||
                        (std::sscanf(argx,"%f%c%c",&sigma_s,&sep_s,&end)==2 && sep_s=='%')) &&
                       (std::sscanf(argy,"%f%c",&sigma_r,&end)==1 ||
                        (std::sscanf(argy,"%f%c%c",&sigma_r,&sep_r,&end)==2 && sep_r=='%')) &&
                       sigma_s>=0 && sigma_r>=0) {
              print(images,"Apply bilateral filter on image%s, with standard deviations %g%s "
                    "and %g.",
                    gmic_selection,
                    sigma_s,sep_s=='%'?"%":"",
                    sigma_r,sep_r=='%'?"%":"");
              if (sep_s=='%') sigma_s = -sigma_s;
              if (sep_r=='%') sigma_r = -sigma_r;
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],
                           blur_bilateral(images[selection[l]],sigma_s,sigma_r));
            } else arg_error("bilateral");
            is_released = false; ++position; continue;
          }

          // Set 3d background color.
          if (!std::strcmp("-background3d",item)) {
            gmic_substitute_args();
            float R = 0, G = 0, B = 0;
            CImg<unsigned int> ind;
            char sep = 0;
            const int nb = std::sscanf(argument,"%f,%f,%f%c",
                                       &R,&G,&B,&end);
            R = cimg::round(R);
            G = cimg::round(G);
            B = cimg::round(B);
            if (nb>=1 && nb<=3) {
              switch (nb) {
              case 1 : background3d.assign(1,1,1,3,(unsigned char)R); break;
              case 2 : background3d.assign(1,1,1,3,(unsigned char)R,(unsigned char)G,0); break;
              case 3 : background3d.assign(1,1,1,3,(unsigned char)R,(unsigned char)G,
                                           (unsigned char)B); break;
              }
              print(images,"Set 3d background color to (%u,%u,%u).",
                    (unsigned int)R,(unsigned int)G,(unsigned int)B);
              ++position;
            } else if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 &&
                       sep==']' &&
                       (ind=selection2cimg(indices,images.size(),images_names,"-background3d",true,
                                           false,CImg<char>::empty())).height()==1) {
              print(images,"Set 3d background from image [%u].",*ind);
              background3d.assign(images[*ind],false);
              ++position;
            } else {
              print(images,"Reset 3d background to default.");
              background3d.assign(1,2,1,3).fill(32,64,32,116,64,96).resize(1,256,1,3,3);
            }
            continue;
          }

#endif // #ifdef gmic_float
# 4636 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='b'.

        //----------------------------
        // Commands starting by '-c..'
        //----------------------------
        else if (command1=='c') {

          // Check expression or filename.
          if (!std::strcmp("-check",item)) {
            gmic_substitute_args();
            CImg<char> arg_check(argument,std::strlen(argument)+1);
            gmic_strreplace(arg_check);
            bool is_cond = false, is_filename = false;
            const CImg<T> &img = images.size()?images.back():CImg<T>::empty();
            try { if (img.eval(arg_check)) is_cond = true; }
            catch (CImgException&) {
              is_filename = true;
              is_cond = gmic_check_filename(arg_check);
            }
            if (verbosity>0 || is_debug) {
              print(images,"Check %s '%s' -> %s.",
                    is_filename?"file":"expression",
                    argument_text,
                    is_filename?(is_cond?"found":"not found"):(is_cond?"true":"false"));
            }
            if (!is_cond) {
              if (scope.size()>1 && scope.back()[0]!='*')
                error(scope.back().data(),images,"Command '-check': %s '%s' %s.",
                      is_filename?"file":"expression",
                      argument_text,
                      is_filename?"does not exist":"is false");
              else error(images,"Command '-check': %s '%s' %s.",
                         is_filename?"file":"expression",
                         argument_text,
                         is_filename?"does not exist":"is false");
            }
            ++position; continue;
          }

          // Crop.
          if (!std::strcmp("-crop",command)) {
            gmic_substitute_args();
            CImg<char> st0(64), st1(64), st2(64), st3(64), st4(64), st5(64), st6(64), st7(64);
            char sep0 = 0, sep1 = 0, sep2 = 0, sep3 = 0, sep4 = 0, sep5 = 0, sep6 = 0, sep7 = 0;
            float a0 = 0, a1 = 0, a2 = 0, a3 = 0, a4 = 0, a5 = 0, a6 = 0, a7 = 0;
            *st0 = *st1 = *st2 = *st3 = *st4 = *st5 = *st6 = *st7 = 0;
            unsigned int boundary = 0;
            if ((boundary=0,std::sscanf(argument,"%63[0-9.eE%+-],%63[0-9.eE%+-]%c",
                                        st0.data(),
                                        st1.data(),&end)==2 ||
                 std::sscanf(argument,"%63[0-9.eE%+-],%63[0-9.eE%+-],%u%c",
                             st0.data(),
                             st1.data(),&boundary,&end)==3) &&
                (std::sscanf(st0,"%f%c",&a0,&end)==1 ||
                 (std::sscanf(st0,"%f%c%c",&a0,&sep0,&end)==2 && sep0=='%')) &&
                (std::sscanf(st1,"%f%c",&a1,&end)==1 ||
                 (std::sscanf(st1,"%f%c%c",&a1,&sep1,&end)==2 && sep1=='%')) &&
                boundary<=1) {
              print(images,"Crop image%s with selection (%g%s) x (%g%s) and "
                    "%s boundary conditions.",
                    gmic_selection,
                    a0,sep0=='%'?"%":"",
                    a1,sep1=='%'?"%":"",
                    boundary?"neumann":"dirichlet");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  x0 = (int)cimg::round(sep0=='%'?a0*(img.width()-1)/100:a0),
                  x1 = (int)cimg::round(sep1=='%'?a1*(img.width()-1)/100:a1);
                gmic_apply(img,crop(x0,x1,(bool)boundary));
              }
              ++position;
            } else if ((boundary=0,std::sscanf(argument,
                                               "%63[0-9.eE%+-],%63[0-9.eE%+-],"
                                               "%63[0-9.eE%+-],%63[0-9.eE%+-]%c",
                                               st0.data(),st1.data(),
                                               st2.data(),st3.data(),&end)==4 ||
                        std::sscanf(argument,
                                    "%63[0-9.eE%+-],%63[0-9.eE%+-],"
                                    "%63[0-9.eE%+-],%63[0-9.eE%+-],%u%c",
                                    st0.data(),st1.data(),
                                    st2.data(),st3.data(),&boundary,&end)==5) &&
                       (std::sscanf(st0,"%f%c",&a0,&end)==1 ||
                        (std::sscanf(st0,"%f%c%c",&a0,&sep0,&end)==2 && sep0=='%')) &&
                       (std::sscanf(st1,"%f%c",&a1,&end)==1 ||
                        (std::sscanf(st1,"%f%c%c",&a1,&sep1,&end)==2 && sep1=='%')) &&
                       (std::sscanf(st2,"%f%c",&a2,&end)==1 ||
                        (std::sscanf(st2,"%f%c%c",&a2,&sep2,&end)==2 && sep2=='%')) &&
                       (std::sscanf(st3,"%f%c",&a3,&end)==1 ||
                        (std::sscanf(st3,"%f%c%c",&a3,&sep3,&end)==2 && sep3=='%')) &&
                       boundary<=1) {
              print(images,
                    "Crop image%s with selection (%g%s,%g%s) x (%g%s,%g%s) and "
                    "%s boundary conditions.",
                    gmic_selection,
                    a0,sep0=='%'?"%":"",
                    a1,sep1=='%'?"%":"",
                    a2,sep2=='%'?"%":"",
                    a3,sep3=='%'?"%":"",
                    boundary?"neumann":"dirichlet");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  x0 = (int)cimg::round(sep0=='%'?a0*(img.width()-1)/100:a0),
                  y0 = (int)cimg::round(sep1=='%'?a1*(img.height()-1)/100:a1),
                  x1 = (int)cimg::round(sep2=='%'?a2*(img.width()-1)/100:a2),
                  y1 = (int)cimg::round(sep3=='%'?a3*(img.height()-1)/100:a3);
                gmic_apply(img,crop(x0,y0,x1,y1,(bool)boundary));
              }
              ++position;
            } else if ((boundary=0,std::sscanf(argument,
                                               "%63[0-9.eE%+-],%63[0-9.eE%+-],%63[0-9.eE%+-],"
                                               "%63[0-9.eE%+-],%63[0-9.eE%+-],%63[0-9.eE%+-]%c",
                                               st0.data(),st1.data(),st2.data(),
                                               st3.data(),st4.data(),st5.data(),&end)==6 ||
                        std::sscanf(argument,"%63[0-9.eE%+-],%63[0-9.eE%+-],%63[0-9.eE%+-],"
                                    "%63[0-9.eE%+-],%63[0-9.eE%+-],%63[0-9.eE%+-],%u%c",
                                    st0.data(),st1.data(),st2.data(),
                                    st3.data(),st4.data(),st5.data(),&boundary,&end)==7) &&
                       (std::sscanf(st0,"%f%c",&a0,&end)==1 ||
                        (std::sscanf(st0,"%f%c%c",&a0,&sep0,&end)==2 && sep0=='%')) &&
                       (std::sscanf(st1,"%f%c",&a1,&end)==1 ||
                        (std::sscanf(st1,"%f%c%c",&a1,&sep1,&end)==2 && sep1=='%')) &&
                       (std::sscanf(st2,"%f%c",&a2,&end)==1 ||
                        (std::sscanf(st2,"%f%c%c",&a2,&sep2,&end)==2 && sep2=='%')) &&
                       (std::sscanf(st3,"%f%c",&a3,&end)==1 ||
                        (std::sscanf(st3,"%f%c%c",&a3,&sep3,&end)==2 && sep3=='%')) &&
                       (std::sscanf(st4,"%f%c",&a4,&end)==1 ||
                        (std::sscanf(st4,"%f%c%c",&a4,&sep4,&end)==2 && sep4=='%')) &&
                       (std::sscanf(st5,"%f%c",&a5,&end)==1 ||
                        (std::sscanf(st5,"%f%c%c",&a5,&sep5,&end)==2 && sep5=='%')) &&
                       boundary<=1) {
              print(images,"Crop image%s with selection (%g%s,%g%s,%g%s) x (%g%s,%g%s,%g%s) "
                    "and %s boundary conditions.",
                    gmic_selection,
                    a0,sep0=='%'?"%":"",
                    a1,sep1=='%'?"%":"",
                    a2,sep2=='%'?"%":"",
                    a3,sep3=='%'?"%":"",
                    a4,sep4=='%'?"%":"",
                    a5,sep5=='%'?"%":"",
                    boundary?"neumann":"dirichlet");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  x0 = (int)cimg::round(sep0=='%'?a0*(img.width()-1)/100:a0),
                  y0 = (int)cimg::round(sep1=='%'?a1*(img.height()-1)/100:a1),
                  z0 = (int)cimg::round(sep2=='%'?a2*(img.depth()-1)/100:a2),
                  x1 = (int)cimg::round(sep3=='%'?a3*(img.width()-1)/100:a3),
                  y1 = (int)cimg::round(sep4=='%'?a4*(img.height()-1)/100:a4),
                  z1 = (int)cimg::round(sep5=='%'?a5*(img.depth()-1)/100:a5);
                gmic_apply(img,crop(x0,y0,z0,x1,y1,z1,(bool)boundary));
              }
              ++position;
            } else if ((boundary=0,std::sscanf(argument,
                                               "%63[0-9.eE%+-],%63[0-9.eE%+-],%63[0-9.eE%+-],"
                                               "%63[0-9.eE%+-],%63[0-9.eE%+-],%63[0-9.eE%+-],"
                                               "%63[0-9.eE%+-],%63[0-9.eE%+-]%c",
                                               st0.data(),st1.data(),st2.data(),st3.data(),
                                               st4.data(),st5.data(),st6.data(),st7.data(),&end)==8 ||
                        std::sscanf(argument,"%63[0-9.eE%+-],%63[0-9.eE%+-],%63[0-9.eE%+-],"
                                    "%63[0-9.eE%+-],%63[0-9.eE%+-],%63[0-9.eE%+-],"
                                    "%63[0-9.eE%+-],%63[0-9.eE%+-],%u%c",
                                    st0.data(),st1.data(),st2.data(),st3.data(),
                                    st4.data(),st5.data(),st6.data(),st7.data(),&boundary,&end)==9) &&
                       (std::sscanf(st0,"%f%c",&a0,&end)==1 ||
                        (std::sscanf(st0,"%f%c%c",&a0,&sep0,&end)==2 && sep0=='%')) &&
                       (std::sscanf(st1,"%f%c",&a1,&end)==1 ||
                        (std::sscanf(st1,"%f%c%c",&a1,&sep1,&end)==2 && sep1=='%')) &&
                       (std::sscanf(st2,"%f%c",&a2,&end)==1 ||
                        (std::sscanf(st2,"%f%c%c",&a2,&sep2,&end)==2 && sep2=='%')) &&
                       (std::sscanf(st3,"%f%c",&a3,&end)==1 ||
                        (std::sscanf(st3,"%f%c%c",&a3,&sep3,&end)==2 && sep3=='%')) &&
                       (std::sscanf(st4,"%f%c",&a4,&end)==1 ||
                        (std::sscanf(st4,"%f%c%c",&a4,&sep4,&end)==2 && sep4=='%')) &&
                       (std::sscanf(st5,"%f%c",&a5,&end)==1 ||
                        (std::sscanf(st5,"%f%c%c",&a5,&sep5,&end)==2 && sep5=='%')) &&
                       (std::sscanf(st6,"%f%c",&a6,&end)==1 ||
                        (std::sscanf(st6,"%f%c%c",&a6,&sep6,&end)==2 && sep6=='%')) &&
                       (std::sscanf(st7,"%f%c",&a7,&end)==1 ||
                        (std::sscanf(st7,"%f%c%c",&a7,&sep7,&end)==2 && sep7=='%')) &&
                       boundary<=1) {
              print(images,
                    "Crop image%s with selection (%g%s,%g%s,%g%s,%g%s) x (%g%s,%g%s,%g%s,%g%s) "
                    "and %s boundary conditions.",
                    gmic_selection,
                    a0,sep0=='%'?"%":"",
                    a1,sep1=='%'?"%":"",
                    a2,sep2=='%'?"%":"",
                    a3,sep3=='%'?"%":"",
                    a4,sep4=='%'?"%":"",
                    a5,sep5=='%'?"%":"",
                    a6,sep6=='%'?"%":"",
                    a7,sep7=='%'?"%":"",
                    boundary?"neumann":"dirichlet");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  x0 = (int)cimg::round(sep0=='%'?a0*(img.width()-1)/100:a0),
                  y0 = (int)cimg::round(sep1=='%'?a1*(img.height()-1)/100:a1),
                  z0 = (int)cimg::round(sep2=='%'?a2*(img.depth()-1)/100:a2),
                  v0 = (int)cimg::round(sep3=='%'?a3*(img.spectrum()-1)/100:a3),
                  x1 = (int)cimg::round(sep4=='%'?a4*(img.width()-1)/100:a4),
                  y1 = (int)cimg::round(sep5=='%'?a5*(img.height()-1)/100:a5),
                  z1 = (int)cimg::round(sep6=='%'?a6*(img.depth()-1)/100:a6),
                  v1 = (int)cimg::round(sep7=='%'?a7*(img.spectrum()-1)/100:a7);
                gmic_apply(img,crop(x0,y0,z0,v0,x1,y1,z1,v1,(bool)boundary));
              }
              ++position;
            } else {
#if cimg_display==0
              print(images,"Crop image%s in interactive mode (skipped, no display support).",
                    gmic_selection);
#else // #if cimg_display==0
# 4850 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
              bool is_available_display = false;
              try {
                is_available_display = (bool)CImgDisplay::screen_width();
              } catch (CImgDisplayException&) {
                print(images,"Crop image%s in interactive mode (skipped, no display available).",
                      gmic_selection);
              }
              if (is_available_display) {
                print(images,"Crop image%s in interactive mode.",
                      gmic_selection);
                CImgDisplay _disp, &disp = instant_window[0]?instant_window[0]:_disp;
                cimg_forY(selection,l) {
                  CImg<T>& img = gmic_check(images[selection[l]]);
                  if (disp) disp.resize(cimg_fitscreen(img.width(),img.height(),1),false);
                  else disp.assign(cimg_fitscreen(img.width(),img.height(),1),0,1);
                  disp.set_title("%s: crop",gmic_basename(images_names[selection[l]].data()));
                  const CImg<int> s = img.get_select(disp,2);
                  print(images,"Crop image [%d] with selection (%d,%d,%d) x (%d,%d,%d).",
                        selection[l],
                        s[0],s[1],s[2],
                        s[3],s[4],s[5]);
                  gmic_apply(img,crop(s[0],s[1],s[2],s[3],s[4],s[5]));
                }
              }
#endif // #if cimg_display==0
# 4875 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            }
            is_released = false; continue;
          }

          // Keep channels.
          if (!std::strcmp("-channels",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind0, ind1;
            float value0 = 0, value1 = 0;
            char sep0 = 0, sep1 = 0;
            *argx = *argy = 0;
            if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-]%c",
                            argx,&end)==1 &&
                ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c]",indices,&sep0,&end)==2 &&
                  sep0==']' &&
                  (ind0=selection2cimg(indices,images.size(),images_names,"-channels",true,
                                       false,CImg<char>::empty())).height()==1) ||
                 std::sscanf(argx,"%f%c",&value0,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&value0,&sep0,&end)==2 && sep0=='%'))) {
              if (ind0) { value0 = images[*ind0].spectrum() - 1.0f; sep0 = 0; }
              print(images,"Keep channel %g%s of image%s.",
                    value0,sep0=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  nvalue0 = (int)cimg::round(sep0=='%'?value0*(img.spectrum()-1)/100:value0);
                gmic_apply(img,channel(nvalue0));
              }
            } else if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                                   argx,argy,&end)==2 &&
                       ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep0,&end)==2 &&
                         sep0==']' &&
                         (ind0=selection2cimg(indices,images.size(),images_names,"-channels",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        std::sscanf(argx,"%f%c",&value0,&end)==1 ||
                        (std::sscanf(argx,"%f%c%c",&value0,&sep0,&end)==2 && sep0=='%')) &&
                       ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",formula,&sep0,&end)==2 &&
                         sep0==']' &&
                         (ind1=selection2cimg(formula,images.size(),images_names,"-channels",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        std::sscanf(argy,"%f%c",&value1,&end)==1 ||
                        (std::sscanf(argy,"%f%c%c",&value1,&sep1,&end)==2 && sep1=='%'))) {
              if (ind0) { value0 = images[*ind0].spectrum() - 1.0f; sep0 = 0; }
              if (ind1) { value1 = images[*ind1].spectrum() - 1.0f; sep1 = 0; }
              print(images,"Keep channels %g%s..%g%s of image%s.",
                    value0,sep0=='%'?"%":"",
                    value1,sep1=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  nvalue0 = (int)cimg::round(sep0=='%'?value0*(img.spectrum()-1)/100:value0),
                  nvalue1 = (int)cimg::round(sep1=='%'?value1*(img.spectrum()-1)/100:value1);
                gmic_apply(img,channels(nvalue0,nvalue1));
              }
            } else arg_error("channels");
            is_released = false; ++position; continue;
          }

          // Keep columns.
          if (!std::strcmp("-columns",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind0, ind1;
            float value0 = 0, value1 = 0;
            char sep0 = 0, sep1 = 0;
            *argx = *argy = 0;
            if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-]%c",
                            argx,&end)==1 &&
                ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c]",indices,&sep0,&end)==2 &&
                  sep0==']' &&
                  (ind0=selection2cimg(indices,images.size(),images_names,"-columns",true,
                                       false,CImg<char>::empty())).height()==1) ||
                 std::sscanf(argx,"%f%c",&value0,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&value0,&sep0,&end)==2 && sep0=='%'))) {
              if (ind0) { value0 = images[*ind0].width() - 1.0f; sep0 = 0; }
              print(images,"Keep column %g%s of image%s.",
                    value0,sep0=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int nvalue0 = (int)cimg::round(sep0=='%'?value0*(img.width()-1)/100:value0);
                gmic_apply(img,column(nvalue0));
              }
            } else if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                                   argx,argy,&end)==2 &&
                       ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep0,&end)==2 &&
                         sep0==']' &&
                         (ind0=selection2cimg(indices,images.size(),images_names,"-columns",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        std::sscanf(argx,"%f%c",&value0,&end)==1 ||
                        (std::sscanf(argx,"%f%c%c",&value0,&sep0,&end)==2 && sep0=='%')) &&
                       ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",formula,&sep0,&end)==2 &&
                         sep0==']' &&
                         (ind1=selection2cimg(formula,images.size(),images_names,"-columns",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        std::sscanf(argy,"%f%c",&value1,&end)==1 ||
                        (std::sscanf(argy,"%f%c%c",&value1,&sep1,&end)==2 && sep1=='%'))) {
              if (ind0) { value0 = images[*ind0].width() - 1.0f; sep0 = 0; }
              if (ind1) { value1 = images[*ind1].width() - 1.0f; sep1 = 0; }
              print(images,"Keep columns %g%s..%g%s of image%s.",
                    value0,sep0=='%'?"%":"",
                    value1,sep1=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  nvalue0 = (int)cimg::round(sep0=='%'?value0*(img.width()-1)/100:value0),
                  nvalue1 = (int)cimg::round(sep1=='%'?value1*(img.width()-1)/100:value1);
                gmic_apply(img,columns(nvalue0,nvalue1));
              }
            } else arg_error("columns");
            is_released = false; ++position; continue;
          }

          // Import custom commands.
          if (!std::strcmp("-command",item)) {
            gmic_substitute_args();
            CImg<char> _arg_command(argument,std::strlen(argument)+1);
            const char *arg_command_text = argument_text;
            char *arg_command = _arg_command;
            gmic_strreplace(arg_command);

            unsigned int siz = 0;
            for (unsigned int l = 0; l<256; ++l) siz+=commands[l].size();

            bool add_debug_infos = true;
            if ((*arg_command=='0' || *arg_command=='1') && arg_command[1]==',') {
              add_debug_infos = (*arg_command=='1');
              arg_command+=2; arg_command_text+=2;
            }

            std::FILE *file = std::fopen(arg_command,"rb");
            if (file) {
              print(images,"Import custom commands from file '%s'%s",
                    arg_command_text,
                    !add_debug_infos?" without debug infos":"");
              add_commands(file,arg_command,commands_names,commands,commands_has_arguments,add_debug_infos);
              std::fclose(file);
            } else if (!cimg::strncasecmp(arg_command,"http://",7) ||
                       !cimg::strncasecmp(arg_command,"https://",8)) { // Try to read from network.
              print(images,"Import custom commands from URL '%s'%s",
                    arg_command_text,
                    !add_debug_infos?" without debug infos":"");
              CImg<char> filename_tmp(1024);
              try {
                file = std::fopen(cimg::load_network_external(arg_command,filename_tmp),"r");
              } catch (...) {
                file = 0;
              }
              if (file) {
                add_commands(file,arg_command,commands_names,commands,commands_has_arguments,add_debug_infos);
                std::fclose(file);
              } else
                error(images,"Command '-command': Unable to reach custom commands file '%s' "
                      "from network.",
                      arg_command_text);
              std::remove(filename_tmp);
            } else {
              print(images,"Import custom commands from expression '%s'",
                    arg_command_text);
              add_commands(arg_command,commands_names,commands,commands_has_arguments);
            }
            if (verbosity>=0 || is_debug) {
              unsigned int nb_added = 0;
              for (unsigned int l = 0; l<256; ++l) nb_added+=commands[l].size();
              nb_added-=siz;
              std::fprintf(cimg::output()," (added %u command%s, total %u).",
                           nb_added,nb_added>1?"s":"",siz+nb_added);
              std::fflush(cimg::output());
            }
            ++position; continue;
          }

          // Camera input.
          if (!std::strcmp("-camera",item)) {
            gmic_substitute_args();
            float
              cam_index = 0, nb_frames = 1, skip_frames = 0,
              capture_width = 0, capture_height = 0;
            unsigned int release_cam = 0;
            if ((std::sscanf(argument,"%f%c",
                             &cam_index,&end)==1 ||
                 std::sscanf(argument,"%f,%f%c",
                             &cam_index,&nb_frames,&end)==2 ||
                 std::sscanf(argument,"%f,%f,%f%c",
                             &cam_index,&nb_frames,&skip_frames,&end)==3 ||
                 std::sscanf(argument,"%f,%f,%f,%u%c",
                             &cam_index,&nb_frames,&skip_frames,&release_cam,&end)==4 ||
                 std::sscanf(argument,"%f,%f,%f,%u,%f,%f,%c",
                             &cam_index,&nb_frames,&skip_frames,&release_cam,
                             &capture_width,&capture_height,&end)==6) &&
                cam_index>=0 && nb_frames>=0 && skip_frames>=0 && release_cam<=1 &&
                ((!capture_width && !capture_height) || (capture_width>0 && capture_height>0)))
              ++position;
            cam_index = cimg::round(cam_index);
            nb_frames = cimg::round(nb_frames);
            skip_frames = cimg::round(skip_frames);
            capture_width = cimg::round(capture_width);
            capture_height = cimg::round(capture_height);
            if (release_cam) {
              print(images,"Release camera #%g.",cam_index);
              CImg<T>::get_load_camera((unsigned int)cam_index,0,true);
            } else {
              if (capture_width)
                print(images,"Insert %g image%s from camera #%g, with %g frames skipping "
                      "and resolution %gx%g.",
                      cam_index,nb_frames,nb_frames>1?"s":"",skip_frames,
                      capture_width,capture_height);
              else print(images,"Insert %g image%s from camera #%g, with %g frames skipping.",
                         cam_index,nb_frames,nb_frames>1?"s":"",skip_frames);
              cimg_snprintf(title,_title.size(),"[Camera #%g]",cam_index);
              const CImg<char> _title = CImg<char>::string(title);
              if (nb_frames>1) {
                std::fputc('\n',cimg::output());
                std::fflush(cimg::output());
              }
              for (unsigned int k = 0; k<(unsigned int)nb_frames; ++k) {
                if (nb_frames>1 && (verbosity>=0 || is_debug)) {
                  std::fprintf(cimg::output(),"\r  > Image %u/%u        ",
                               k+1,(unsigned int)nb_frames);
                  std::fflush(cimg::output());
                }
                CImg<T>::get_load_camera((unsigned int)cam_index,(unsigned int)skip_frames,false,
                                         (unsigned int)capture_width,(unsigned int)capture_height).
                  move_to(images);
                images_names.insert(_title);
              }
            }
            is_released = false; continue;
          }

          // Check validity of 3d object.
          if (!std::strcmp("-check3d",command) && !is_get_version) {
            gmic_substitute_args();
            bool is_full_check = true;
            if (!argument[1] && (*argument=='0' || *argument=='1')) {
              is_full_check = (*argument=='1');
              ++position;
            } else is_full_check = true;
            if (verbosity>0 || is_debug)
              print(images,"Check validity of 3d object%s (%s check)",
                    gmic_selection,
                    is_full_check?"full":"fast");
            cimg_forY(selection,l) {
              const unsigned int ind = selection[l];
              CImg<T>& img = gmic_check(images[ind]);
              if (!img.is_CImg3d(is_full_check,message)) {
                if (verbosity>0 || is_debug) {
                  std::fprintf(cimg::output()," -> invalid.");
                  std::fflush(cimg::output());
                }
                error(images,
                      "Command '-check3d': Invalid 3d object [%d], in selected image%s (%s).",
                      ind,gmic_selection,message);
              }
            }
            if (verbosity>0 || is_debug) {
              std::fprintf(cimg::output()," -> valid.");
              std::fflush(cimg::output());
            }
            continue;
          }

#ifdef gmic_float

          // Cut.
          if (!std::strcmp("-cut",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind0, ind1;
            double value0 = 0, value1 = 0;
            char sep0 = 0, sep1 = 0;
            *argx = *argy = 0;
            if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                            argx,argy,&end)==2 &&
                ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep0,&end)==2 &&
                  sep0==']' &&
                  (ind0=selection2cimg(indices,images.size(),images_names,"-cut",true,
                                       false,CImg<char>::empty())).height()==1) ||
                 (std::sscanf(argx,"%lf%c%c",&value0,&sep0,&end)==2 && sep0=='%') ||
                 std::sscanf(argx,"%lf%c",&value0,&end)==1) &&
                ((std::sscanf(argy,"[%255[a-zA-Z0-9_.%+-]%c%c",formula,&sep1,&end)==2 &&
                  sep1==']' &&
                  (ind1=selection2cimg(formula,images.size(),images_names,"-cut",true,
                                       false,CImg<char>::empty())).height()==1) ||
                 (std::sscanf(argy,"%lf%c%c",&value1,&sep1,&end)==2 && sep1=='%') ||
                 std::sscanf(argy,"%lf%c",&value1,&end)==1)) {
              if (ind0) { value0 = images[*ind0].min(); sep0 = 0; }
              if (ind1) { value1 = images[*ind1].max(); sep1 = 0; }
              print(images,"Cut image%s in range [%g%s,%g%s].",
                    gmic_selection,
                    value0,sep0=='%'?"%":"",
                    value1,sep1=='%'?"%":"");
              cimg_forY(selection,l) {
                CImg<T> &img = gmic_check(images[selection[l]]);
                double vmin = 0, vmax = 0, nvalue0 = value0, nvalue1 = value1;
                if (sep0=='%' || sep1=='%') {
                  if (img) vmax = (double)img.max_min(vmin);
                  if (sep0=='%') nvalue0 = vmin + (vmax-vmin)*value0/100;
                  if (sep1=='%') nvalue1 = vmin + (vmax-vmin)*value1/100;
                }
                gmic_apply(img,cut((T)nvalue0,(T)nvalue1));
              }
              ++position;
            } else if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep0,&end)==2 &&
                       sep0==']' &&
                       (ind0=selection2cimg(indices,images.size(),images_names,"-cut",true,
                                            false,CImg<char>::empty())).height()==1) {
              if (images[*ind0]) value1 = (double)images[*ind0].max_min(value0);
              print(images,"Cut image%s in range [%g,%g].",
                    gmic_selection,
                    value0,
                    value1);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],cut((T)value0,(T)value1));
              ++position;
            } else {
#if cimg_display==0
              print(images,"Cut image%s in interactive mode (skipped, no display support).",
                    gmic_selection);
#else // #if cimg_display==0
# 5195 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
              bool is_available_display = false;
              try {
                is_available_display = (bool)CImgDisplay::screen_width();
              } catch (CImgDisplayException&) {
                print(images,"Cut image%s in interactive mode (skipped, no display available).",
                      gmic_selection);
              }
              if (is_available_display) {
                print(images,"Cut image%s in interactive mode.",
                      gmic_selection);
                CImgDisplay _disp, &disp = instant_window[0]?instant_window[0]:_disp;
                cimg_forY(selection,l) {
                  CImg<T> &img = gmic_check(images[selection[l]]);
                  if (img) {
                    CImg<T> visu = img.depth()>1?img.get_projections2d(img.width()/2,
                                                                       img.height()/2,
                                                                       img.depth()/2).
                      channels(0,cimg::min(3,img.spectrum())-1):
                      img.get_channels(0,cimg::min(3,img.spectrum()-1));
                    const unsigned int
                      w = CImgDisplay::_fitscreen(visu.width(),visu.height(),1,256,-85,false),
                      h = CImgDisplay::_fitscreen(visu.width(),visu.height(),1,256,-85,true);
                    if (disp) disp.resize(w,h,false); else disp.assign(w,h,0,0);
                    double vmin = 0, vmax = (double)img.max_min(vmin),
                      percent0 = 0, percent1 = 100;
                    bool stopflag = false, is_clicked = false;
                    int omx = -1, omy = -1;
                    CImg<unsigned char> res;
                    for (disp.show().flush(); !stopflag; ) {
                      const unsigned char white[] = { 255,255,255 }, black[] = { 0,0,0 };
                      const unsigned int key = disp.key();
                      if (!res)
                        disp.display((res=visu.get_cut((T)(vmin + percent0*(vmax-vmin)/100),
                                                       (T)(vmin + percent1*(vmax-vmin)/100)).
                                      resize(disp).normalize((T)0,(T)255)).
                                     draw_text(0,0,"Cut [%g,%g] = [%.3g%%,%.3g%%]",
                                               white,black,0.7f,13,
                                               (double)(vmin + percent0*(vmax-vmin)/100),
                                               (double)(vmin + percent1*(vmax-vmin)/100),
                                               percent0,percent1)).
                          set_title("%s (%dx%dx%dx%d)",
                                    gmic_basename(images_names[selection[l]].data()),
                                    img.width(),img.height(),img.depth(),img.spectrum()).wait();
                      const int mx = disp.mouse_x(), my = disp.mouse_y();
                      if (disp.button()) {
                        if (mx>=0 && my>=0 && (mx!=omx || my!=omy)) {
                          percent0 = (my-16)*100.0/(disp.height()-32);
                          percent1 = (mx-16)*100.0/(disp.width()-32);
                          if (percent0<0) percent0 = 0; else if (percent0>101) percent0 = 101;
                          if (percent1<0) percent1 = 0; else if (percent1>101) percent1 = 101;
                          if (percent0>percent1) cimg::swap(percent0,percent1);
                          omx = mx; omy = my; res.assign();
                        }
                        is_clicked = true;
                      } else if (is_clicked) break;
                      if (disp.is_closed() || (key && key!=cimg::keyCTRLLEFT)) stopflag = true;
                      if (key==cimg::keyD && disp.is_keyCTRLLEFT()) {
                        disp.resize(cimg_fitscreen(3*disp.width()/2,3*disp.height()/2,1),
                                    stopflag=false).set_key(cimg::keyD,false);
                        res.assign();
                      }
                      if (key==cimg::keyC && disp.is_keyCTRLLEFT()) {
                        disp.resize(cimg_fitscreen(2*disp.width()/3,2*disp.height()/3,1),
                                    stopflag=false).set_key(cimg::keyC,false);
                        res.assign();
                      }
                      if (disp.is_resized()) { disp.resize(false); res.assign(); }
                    }
                    print(images,"Cut image [%d] in range [%g,%g] = [%.3g%%,%.3g%%].",
                          selection[l],
                          (double)(vmin + percent0*(vmax-vmin)/100),
                          (double)(vmin + percent1*(vmax-vmin)/100),
                          percent0,percent1);
                    gmic_apply(img,cut((T)(vmin + percent0*(vmax-vmin)/100),
                                       (T)(vmin + percent1*(vmax-vmin)/100)));
                  } else { gmic_apply(img,replace(img)); }
                }
              }
#endif // #if cimg_display==0
# 5274 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            }
            is_released = false; continue;
          }

          // Cosine.
          gmic_simple_item("-cos",cos,"Compute pointwise cosine of image%s.");

          // Convolve.
          if (!std::strcmp("-convolve",command)) {
            gmic_substitute_args();
            unsigned int boundary = 1, is_normalized = 0;
            CImg<unsigned int> ind;
            char sep = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                              indices,&sep,&end)==2 && sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u%c",
                             indices,&boundary,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u%c",
                             indices,&boundary,&is_normalized,&end)==3) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-convolve",true,
                                    false,CImg<char>::empty())).height()==1 &&
                boundary<=1) {
              print(images,
                    "Convolve image%s with mask [%u] and %s boundary conditions, "
                    "with%s normalization.",
                    gmic_selection,
                    *ind,
                    boundary?"neumann":"dirichlet",
                    is_normalized?"":"out");
              const CImg<T> mask = gmic_image_arg(*ind);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],convolve(mask,boundary,(bool)is_normalized));
            } else arg_error("convolve");
            is_released = false; ++position; continue;
          }

          // Correlate.
          if (!std::strcmp("-correlate",command)) {
            gmic_substitute_args();
            unsigned int boundary = 1, is_normalized = 0;
            CImg<unsigned int> ind;
            char sep = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                              indices,&sep,&end)==2 && sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u%c",
                             indices,&boundary,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u%c",
                             indices,&boundary,&is_normalized,&end)==3) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-correlate",true,
                                    false,CImg<char>::empty())).height()==1 &&
                boundary<=1) {
              print(images,
                    "Correlate image%s with mask [%u] and %s boundary conditions, "
                    "with%s normalization.",
                    gmic_selection,
                    *ind,
                    boundary?"neumann":"dirichlet",
                    is_normalized?"":"out");
              const CImg<T> mask = gmic_image_arg(*ind);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],correlate(mask,boundary,(bool)is_normalized));
            } else arg_error("correlate");
            is_released = false; ++position; continue;
          }

          // Set 3d object color.
          if (!std::strcmp("-color3d",command) || !std::strcmp("-col3d",command)) {
            gmic_substitute_args();
            float R = 200, G = 200, B = 200, opacity = -1;
            if ((std::sscanf(argument,"%f%c",
                             &R,&end)==1 && ((B=G=R),1)) ||
                (std::sscanf(argument,"%f,%f%c",
                             &R,&G,&end)==2 && ((B=0),1)) ||
                std::sscanf(argument,"%f,%f,%f%c",
                            &R,&G,&B,&end)==3 ||
                std::sscanf(argument,"%f,%f,%f,%f%c",
                            &R,&G,&B,&opacity,&end)==4) {
              const bool set_opacity = (opacity>=0);
              if (set_opacity)
                print(images,"Set colors of 3d object%s to (%g,%g,%g), with opacity %g.",
                      gmic_selection,
                      R,G,B,
                      opacity);
              else
                print(images,"Set color of 3d object%s to (%g,%g,%g).",
                      gmic_selection,
                      R,G,B);
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                CImg<T>& img = gmic_check(images[ind]);
                try { gmic_apply(img,color_CImg3d(R,G,B,opacity,true,set_opacity)); }
                catch (CImgException &e) {
                  if (!img.is_CImg3d(true,message))
                    error(images,"Command '-color3d': Invalid 3d object [%d], "
                          "in selected image%s (%s).",
                          ind,gmic_selection,message);
                  else throw e;
                }
              }
            } else arg_error("color3d");
            is_released = false; ++position; continue;
          }

          // Show/hide mouse cursor.
          if (!std::strcmp("-cursor",command) && !is_get_version) {
            gmic_substitute_args();
            if (!is_restriction)
              CImg<unsigned int>::vector(0,1,2,3,4,5,6,7,8,9).move_to(selection);
            bool value = true;
            if (!argument[1] && (*argument=='0' || *argument=='1')) {
              value = (*argument=='1'); ++position;
            } else value = true;

#if cimg_display==0
            print(images,"%s mouse cursor for instant window%s (skipped, no display support).",
                  value?"Show":"Hide",
                  gmic_selection);
#else
# 5392 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            try {
              if (value) cimg_forY(selection,l) { if (!instant_window[l].is_closed()) instant_window[selection[l]].show_mouse(); }
              else cimg_forY(selection,l) { if (!instant_window[l].is_closed()) instant_window[selection[l]].hide_mouse(); }
              print(images,"%s mouse cursor for instant window%s.",
                    value?"Show":"Hide",
                    gmic_selection);
            } catch (CImgDisplayException&) {
              print(images,"%s mouse cursor for instant window%s (skipped, no display available).",
                    value?"Show":"Hide",
                    gmic_selection);
            }
#endif
# 5404 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            continue;
          }

          // Hyperbolic cosine.
          gmic_simple_item("-cosh",cosh,"Compute pointwise hyperbolic cosine of image%s.");

#endif // #ifdef gmic_float
# 5411 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='c'.

        //----------------------------
        // Commands starting by '-d..'
        //----------------------------
        else if (command1=='d') {

          // Done.
          if (!std::strcmp("-done",item)) {
            const CImg<char> &s = scope.back();
            if (s[0]!='*' || s[1]!='r')
              error(images,"Command '-done': Not associated to a '-repeat' command "
                    "within the same scope.");
            if (--repeatdones.back()(1)) {
              ++repeatdones.back()(2);
              position = repeatdones.back()(0);
            } else {
              if (verbosity>0 || is_debug) print(images,"End 'repeat..done' block.");
              repeatdones.remove();
              scope.remove();
            }
            continue;
          }

          // Do..while.
          if (!std::strcmp("-do",item)) {
            CImg<char>::string("*do").move_to(scope);
            if (verbosity>0 || is_debug) print(images,"Start '-do..-while' block.");
            CImg<unsigned int>::vector(position).move_to(dowhiles);
            continue;
          }

          // Enable debug mode (useful when '-debug' is invoked from a custom command).
          if (!std::strcmp("-debug",item)) {
            is_debug = true;
            continue;
          }

#ifdef gmic_float

          // Divide.
          gmic_arithmetic_item("-div",
                               operator/=,
                               "Divide image%s by %g%s",
                               gmic_selection,value,ssep,Tfloat,
                               div,
                               "Divide image%s by image [%d]",
                               gmic_selection,ind[0],
                               "Divide image%s by expression %s",
                               gmic_selection,argument_text,
                               "Divide image%s");

          // Distance function.
          if (!std::strcmp("-distance",command)) {
            gmic_substitute_args();
            unsigned int algorithm = 0, off = 0;
            char sep1 = 0, sep2 = 0;
            CImg<unsigned int> ind;
            double value = 0;
            int metric = 2;
            if ((std::sscanf(argument,"%lf%c",
                             &value,&end)==1 ||
                 (std::sscanf(argument,"%lf%c%c",
                              &value,&sep1,&end)==2 && sep1=='%') ||
                 std::sscanf(argument,"%lf,%d%c",
                             &value,&metric,&end)==2 ||
                 (std::sscanf(argument,"%lf%c,%d%c",
                              &value,&sep1,&metric,&end)==3 && sep1=='%')) &&
                metric>=0 && metric<=3) {
              print(images,"Compute Euclidean distance map to isovalue %g%s in image%s, "
                    "with %s metric.",
                    value,sep1=='%'?"%":"",
                    gmic_selection,
                    metric==0?"chebyshev":metric==1?"manhattan":metric==2?"euclidean":
                    "squared-euclidean");
              cimg_forY(selection,l) {
                CImg<T> &img = gmic_check(images[selection[l]]);
                double nvalue = value;
                if (sep1=='%' && img) {
                  double vmin, vmax = (double)img.max_min(vmin);
                  nvalue = vmin + value*(vmax-vmin)/100;
                }
                gmic_apply(img,distance((T)nvalue,metric));
              }
            } else if ((((std::sscanf(argument,"%lf,[%255[a-zA-Z0-9_.%+-]%c%c",
                                      &value,indices,&sep2,&end)==3 ||
                          (std::sscanf(argument,"%lf%c,[%255[a-zA-Z0-9_.%+-]%c%c",
                                       &value,&sep1,indices,&sep2,&end)==4 && sep1=='%')) &&
                         sep2==']') ||
                        ((std::sscanf(argument,"%lf,[%255[a-zA-Z0-9_.%+-]],%u%c",
                                     &value,indices,&algorithm,&end)==3 ||
                          (std::sscanf(argument,"%lf%c,[%255[a-zA-Z0-9_.%+-]],%u%c",
                                       &value,&sep1,indices,&algorithm,&end)==4 && sep1=='%')) &&
                         algorithm<=4)) &&
                       (ind=selection2cimg(indices,images.size(),images_names,"-distance",true,
                                           false,CImg<char>::empty())).height()==1) {
              print(images,"Compute distance map%s to isovalue %g%s in image%s, "
                    "using %s algorithm, with metric [%u].",
                    selection.height()>1?(algorithm>=3?"s and return paths":"s"):
                    (algorithm>=3?" and return path":""),
                    value,sep1=='%'?"%":"",
                    gmic_selection,
                    algorithm==0?"fast-marching":algorithm==1||algorithm==3?
                    "low-connectivity dijkstra":"high-connectivity dijkstra",
                    *ind);
              const CImg<T> custom_metric = gmic_image_arg(*ind);
              if (algorithm<3) cimg_forY(selection,l) {
                  CImg<T> &img = gmic_check(images[selection[l]]);
                  double nvalue = value;
                  if (sep1=='%' && img) {
                    double vmin, vmax = (double)img.max_min(vmin);
                    nvalue = vmin + value*(vmax-vmin)/100;
                  }
                  if (!algorithm) { gmic_apply(img,distance_eikonal((T)nvalue,custom_metric)); }
                  else { gmic_apply(img,distance_dijkstra((T)nvalue,custom_metric,algorithm==2)); }
                } else cimg_forY(selection,l) {
                  const unsigned int ind = selection[l] + off;
                  CImg<T>& img = gmic_check(images[ind]);
                  double nvalue = value;
                  if (sep1=='%' && img) {
                    double vmin, vmax = (double)img.max_min(vmin);
                    nvalue = vmin + value*(vmax-vmin)/100;
                  }
                  CImg<char> name = images_names[ind].get_mark();
                  CImg<T> path(1),
                    dist = img.get_distance_dijkstra((T)nvalue,custom_metric,algorithm==4,path);
                  if (is_get_version) {
                    images_names.insert(2,name.copymark());
                    dist.move_to(images,~0U);
                    path.move_to(images,~0U);
                  } else {
                    off+=1;
                    dist.move_to(images[ind].assign());
                    path.move_to(images,ind+1);
                    images_names[ind] = name;
                    images_names.insert(name.copymark(),ind+1);
                  }
                }
            } else arg_error("distance");
            is_released = false; ++position; continue;
          }

          // Dilate.
          if (!std::strcmp("-dilate",command)) {
            gmic_substitute_args();
            float sx = 3, sy = 3, sz = 1;
            unsigned int boundary = 1, is_normalized = 0;
            CImg<unsigned int> ind;
            char sep = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                              indices,&sep,&end)==2 && sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u%c",
                             indices,&boundary,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u%c",
                             indices,&boundary,&is_normalized,&end)==3) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-dilate",true,
                                    false,CImg<char>::empty())).height()==1 &&
                boundary<=1) {
              print(images,"Dilate image%s with mask [%u] and %s boundary conditions, "
                    "with%s normalization.",
                    gmic_selection,
                    *ind,
                    boundary?"neumann":"dirichlet",
                    is_normalized?"":"out");
              const CImg<T> mask = gmic_image_arg(*ind);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],dilate(mask,boundary,
                                                                            (bool)is_normalized));
            } else if ((std::sscanf(argument,"%f%c",
                                    &sx,&end)==1) &&
                       sx>=0) {
              sx = cimg::round(sx);
              print(images,"Dilate image%s with mask of size %g and neumann boundary conditions.",
                    gmic_selection,
                    sx);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],dilate((unsigned int)sx));
            } else if ((std::sscanf(argument,"%f,%f%c",
                                    &sx,&sy,&end)==2 ||
                        std::sscanf(argument,"%f,%f,%f%c",
                                    &sx,&sy,&sz,&end)==3) &&
                       sx>=0 && sy>=0 && sz>=0) {
              sx = cimg::round(sx);
              sy = cimg::round(sy);
              sz = cimg::round(sz);
              print(images,"Dilate image%s with %gx%gx%g mask and neumann boundary conditions.",
                    gmic_selection,
                    sx,sy,sz);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],dilate((unsigned int)sx,(unsigned int)sy,
                                                       (unsigned int)sz));
            } else arg_error("dilate");
            is_released = false; ++position; continue;
          }

          // Set double-sided mode for 3d rendering.
          if (!std::strcmp("-double3d",item)) {
            gmic_substitute_args();
            bool value = true;
            if (!argument[1] && (*argument=='0' || *argument=='1')) {
              value = (*argument=='1');
              ++position;
            } else value = true;
            is_double3d = value;
            print(images,"%s double-sided mode for 3d rendering.",
                  is_double3d?"Enable":"Disable");
            continue;
          }

          // Patch-based smoothing.
          if (!std::strcmp("-denoise",command)) {
            gmic_substitute_args();
            float sigma_s = 10, sigma_r = 10, smoothness = 1;
            unsigned int is_fast_approximation = 0;
            float psize = 5, rsize = 6;
            if ((std::sscanf(argument,"%f%c",
                             &sigma_s,&end)==1 ||
                 std::sscanf(argument,"%f,%f%c",
                             &sigma_s,&sigma_r,&end)==2 ||
                 std::sscanf(argument,"%f,%f,%f%c",
                             &sigma_s,&sigma_r,&psize,&end)==3 ||
                 std::sscanf(argument,"%f,%f,%f,%f%c",
                             &sigma_s,&sigma_r,&psize,&rsize,&end)==4 ||
                 std::sscanf(argument,"%f,%f,%f,%f,%f%c",
                             &sigma_s,&sigma_r,&psize,&rsize,&smoothness,&end)==5 ||
                 std::sscanf(argument,"%f,%f,%f,%f,%f,%u%c",
                             &sigma_s,&sigma_r,&psize,&rsize,&smoothness,
                             &is_fast_approximation,&end)==6) &&
                sigma_s>=0 && sigma_r>=0 && psize>=0 && rsize>=0 && is_fast_approximation<=1) {
              psize = cimg::round(psize);
              rsize = cimg::round(rsize);
              print(images,"Denoise image%s using %gx%g patchs, with standard deviations %lg,%g, "
                    "lookup size %g and smoothness %g.",
                    gmic_selection,
                    psize,
                    psize,
                    sigma_s,
                    sigma_r,
                    rsize,
                    smoothness);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],blur_patch(sigma_s,sigma_r,
                                                           (unsigned int)psize,(unsigned int)rsize,
                                                           smoothness,
                                                           (bool)is_fast_approximation));
            } else arg_error("denoise");
            is_released = false; ++position; continue;
          }

          // Deriche filter.
          if (!std::strcmp("-deriche",command)) {
            gmic_substitute_args();
            unsigned int boundary = 1, order = 0;
            char sep = 0, axis = 0;
            float sigma = 0;
            if ((std::sscanf(argument,"%f,%u,%c%c",&sigma,&order,&axis,&end)==3 ||
                 (std::sscanf(argument,"%f%c,%u,%c%c",&sigma,&sep,&order,&axis,&end)==4 &&
                  sep=='%') ||
                 std::sscanf(argument,"%f,%u,%c,%u%c",&sigma,&order,&axis,&boundary,&end)==4 ||
                 (std::sscanf(argument,"%f%c,%u,%c,%u%c",
                              &sigma,&sep,&order,&axis,&boundary,&end)==5 && sep=='%')) &&
                sigma>=0 && order<=2 && (axis=='x' || axis=='y' || axis=='z' || axis=='c') &&
                boundary<=1) {
              print(images,"Apply Deriche filter on image%s, with standard "
                    "deviation %g%s, order %d, axis '%c' and %s boundary conditions.",
                    gmic_selection,
                    sigma,sep=='%'?"%":"",
                    order,axis,
                    boundary?"neumann":"dirichlet");
              if (sep=='%') sigma = -sigma;
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],deriche(sigma,order,axis,(bool)boundary));
            } else arg_error("deriche");
            is_released = false; ++position; continue;
          }

          // Dijkstra algorithm.
          if (!std::strcmp("-dijkstra",command)) {
            gmic_substitute_args();
            float snode = 0, enode = 0;
            if (std::sscanf(argument,"%f,%f%c",&snode,&enode,&end)==2 &&
                snode>=0 && enode>=0) {
              snode = cimg::round(snode);
              enode = cimg::round(enode);
              print(images,"Compute minimal path from adjacency matri%s%s with the "
                    "Dijkstra algorithm.",
                    selection.height()>1?"ce":"x",gmic_selection);
              unsigned int off = 0;
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l] + off;
                CImg<char> name = images_names[ind].get_mark();
                if (is_get_version) {
                  CImg<T> path, dist = gmic_check(images[ind]).get_dijkstra((unsigned int)snode,
                                                                              (unsigned int)enode,
                                                                              path);
                  images_names.insert(name.copymark());
                  name.move_to(images_names);
                  dist.move_to(images);
                  path.move_to(images);
                } else {
                  CImg<T> path;
                  gmic_check(images[ind]).dijkstra((unsigned int)snode,(unsigned int)enode,path);
                  images_names.insert(name.get_copymark(),ind+1);
                  name.move_to(images_names[ind]);
                  images.insert(path,ind+1);
                  ++off;
                }
              }
            } else arg_error("dijkstra");
            is_released = false; ++position; continue;
          }

          // Estimate displacement field.
          if (!std::strcmp("-displacement",command)) {
            gmic_substitute_args();
            float nb_scales = 0, nb_iterations = 10000, smoothness = 0.1f, precision = 5.0f;
            unsigned int is_backward = 1;
            CImg<unsigned int> ind;
            char sep = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                              indices,&sep,&end)==2 && sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f%c",
                             indices,&smoothness,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f%c",
                             indices,&smoothness,&precision,&end)==3 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f%c",
                             indices,&smoothness,&precision,&nb_scales,&end)==4 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f%c",
                             indices,&smoothness,&precision,&nb_scales,&nb_iterations,&end)==5 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f,%u%c",
                             indices,&smoothness,&precision,&nb_scales,&nb_iterations,
                             &is_backward,&end)==6) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-displacement",true,
                                    false,CImg<char>::empty())).height()==1 &&
                precision>=0 && nb_scales>=0 && nb_iterations>=0 && is_backward<=1) {
              nb_scales = cimg::round(nb_scales);
              nb_iterations = cimg::round(nb_iterations);
              print(images,"Estimate displacement field from source [%u] to image%s, with "
                    "%s smoothness %g, precision %g, %g scales, %g iterations, in %s direction.",
                    *ind,
                    gmic_selection,
                    smoothness>=0?"isotropic":"anisotropic",cimg::abs(smoothness),
                    precision,
                    nb_scales,
                    nb_iterations,
                    is_backward?"backward":"forward");
              const CImg<T> source = gmic_image_arg(*ind);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],displacement(source,smoothness,precision,
                                                             (unsigned int)nb_scales,
                                                             (unsigned int)nb_iterations,
                                                             (bool)is_backward));
            } else arg_error("displacement");
            is_released = false; ++position; continue;
          }

          // Display.
          if (!std::strcmp("-display",command) && !is_get_version) {
            gmic_substitute_args();
            unsigned int X,Y,Z, XYZ[3];
            bool is_xyz = false;
            if (std::sscanf(argument,"%u,%u,%u%c",
                            &X,&Y,&Z,&end)==3) { is_xyz = true; ++position; }
            XYZ[0] = X; XYZ[1] = Y; XYZ[2] = Z;
            display_images(images,images_names,selection,is_xyz?XYZ:0);
            is_released = true; continue;
          }

          // Display 3d object.
          if (!std::strcmp("-display3d",command) && !is_get_version) {
            display_objects3d(images,images_names,selection);
            is_released = true; continue;
          }

#endif // #ifdef gmic_float
# 5784 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='d'.

        //----------------------------
        // Commands starting by '-e..'
        //----------------------------
        else if (command1=='e') {

          // Endif.
          if (!std::strcmp("-endif",item)) {
            const CImg<char> &s = scope.back();
            if (s[0]!='*' || s[1]!='i')
              error(images,
                    "Command '-endif': Not associated to a '-if' command within the same scope.");
            if (verbosity>0 || is_debug) print(images,"End 'if..endif' block.");
            check_elif = false;
            scope.remove();
            continue;
          }

          // Else and elif.
          if (!std::strcmp("-else",item) || (!std::strcmp("-elif",item) && !check_elif)) {
            const CImg<char> &s = scope.back();
            if (s[0]!='*' || s[1]!='i')
              error(images,
                    "Command '%s': Not associated to a '-if' command within the same scope.",
                    item);
            check_elif = false;
            if (verbosity>0 || is_debug) print(images,"Reach '-else' block.");
            for (int nb_ifs = 1; nb_ifs && position<commands_line.size(); ++position) {
              const char *const it = commands_line[position].data();
              if (!std::strcmp("-if",it)) ++nb_ifs;
              else if (!std::strcmp("-endif",it)) { if (!--nb_ifs) --position; }
            }
            continue;
          }

          // End local environment.
          if (!std::strcmp("-endlocal",item) || !std::strcmp("-endl",item)) {
            const CImg<char> &s = scope.back();
            if (s[0]!='*' || s[1]!='l')
              error(images,"Command '-endlocal': Not associated to a '-local' command within "
                    "the same scope.");
            if (verbosity>0 || is_debug) print(images,"End 'local..endlocal' block.");
            is_endlocal = true;
            break;
          }

          // Echo.
          if (!std::strcmp("-echo",command) && !is_get_version) {
            if (verbosity>=0 || is_debug) {
              gmic_substitute_args();
              CImg<char> str(argument,std::strlen(argument)+1);
              cimg::strunescape(str);
              if (is_restriction) print(images,selection,"%s",str.data());
              else print(images,"%s",str.data());
            }
            ++position; continue;
          }

          // Exec.
          if (!std::strcmp("-exec",item)) {
            gmic_substitute_args();
#ifdef gmic_noexec
            print(images,"Execute external command '%s' (skipped, no exec allowed).",
                  argument_text);
#else // #ifdef gmic_noexec
# 5850 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            print(images,"Execute external command '%s'\n",
                  argument_text);
            CImg<char> arg_exec(argument,std::strlen(argument)+1);
            gmic_strreplace(arg_exec);
            cimg::mutex(31);
            const int errcode = cimg::system(arg_exec);
            cimg::mutex(31,0);
            cimg_snprintf(title,_title.size(),"%d",errcode);
            CImg<char>::string(title).move_to(status);
            if (errcode) print(images,"Command '-exec' returned error code '%d'.",
                               errcode);
#endif // #ifdef gmic_noexec
# 5862 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            ++position; continue;
          }

          // Error.
          if (!std::strcmp("-error",command) && !is_get_version) {
            gmic_substitute_args();
            CImg<char> str(argument,std::strlen(argument)+1);
            cimg::strunescape(str);
            if (is_restriction) error(images,selection,"%s",str.data());
            else error(images,"%s",str.data());
          }

          // Invert endianness.
          gmic_simple_item("-endian",invert_endianness,"Invert data endianness of image%s.");

#ifdef gmic_float

          // Exponential.
          gmic_simple_item("-exp",exp,"Compute pointwise exponential of image%s.");

          // Test equality.
          gmic_arithmetic_item("-eq",
                               operator_eq,
                               "Compute boolean equality between image%s and %g%s",
                               gmic_selection,value,ssep,T,
                               operator_eq,
                               "Compute boolean equality between image%s and image [%d]",
                               gmic_selection,ind[0],
                               "Compute boolean equality between image%s and expression %s'",
                               gmic_selection,argument_text,
                               "Compute boolean equality between image%s");

          // Draw ellipse.
          if (!std::strcmp("-ellipse",command)) {
            gmic_substitute_args();
            CImg<char> argR(256), argr(256);
            *argx = *argy = *argR = *argr = *color = 0;
            float x = 0, y = 0, R = 0, r = 0, angle = 0, opacity = 1;
            char sepx = 0, sepy = 0, sepR = 0, sepr = 0, seph = 0;
            unsigned int pattern = ~0U;
            if ((std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             argx,argy,argR.data(),&end)==3 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-]%c",
                             argx,argy,argR.data(),argr.data(),&end)==4 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-],%f%c",
                             argx,argy,argR.data(),argr.data(),&angle,&end)==5 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-],%f,%f%c",
                             argx,argy,argR.data(),argr.data(),&angle,&opacity,&end)==6 ||
                 (std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                              "%255[0-9.eE%+-],%f,%f,0%c%x%c",
                              argx,argy,argR.data(),argr.data(),&angle,&opacity,&seph,&pattern,&end)==8 &&
                  seph=='x') ||
                 (std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                              "%255[0-9.eE%+-],%f,%f,%4095[0-9.eE,+-]%c",
                              argx,argy,argR.data(),argr.data(),&angle,&opacity,color,&end)==7 && (bool)(pattern=~0U))||
                 (*color=0,std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                                       "%255[0-9.eE%+-],%f,%f,0%c%x,%4095[0-9.eE,+-]%c",
                                       argx,argy,argR.data(),argr.data(),&angle,&opacity,&seph,&pattern,
                                       color,&end)==9 &&
                  seph=='x')) &&
                (std::sscanf(argx,"%f%c",&x,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&x,&sepx,&end)==2 && sepx=='%')) &&
                (std::sscanf(argy,"%f%c",&y,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&y,&sepy,&end)==2 && sepy=='%')) &&
                (std::sscanf(argR,"%f%c",&R,&end)==1 ||
                 (std::sscanf(argR,"%f%c%c",&R,&sepR,&end)==2 && sepR=='%')) &&
                (!*argr ||
                 std::sscanf(argr,"%f%c",&r,&end)==1 ||
                 (std::sscanf(argr,"%f%c%c",&r,&sepr,&end)==2 && sepr=='%'))) {
              if (!*argr) r = R;
              print(images,"Draw %s ellipse at (%g%s,%g%s) with radii (%g%s,%g%s) on image%s, "
                    "with orientation %g°, opacity %g and color (%s).",
                    seph=='x'?"outlined":"filled",
                    x,sepx=='%'?"%":"",
                    y,sepy=='%'?"%":"",
                    R,sepR=='%'?"%":"",
                    r,sepr=='%'?"%":"",
                    gmic_selection,
                    angle,
                    opacity,
                    *color?color:"default");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]], col(img.spectrum(),1,1,1,0);
                col.fill(color,true);
                const float rmax = std::sqrt((float)cimg::sqr(img.width()) +
                                             cimg::sqr(img.height()));
                const int
                  nx = (int)cimg::round(sepx=='%'?x*(img.width()-1)/100:x),
                  ny = (int)cimg::round(sepy=='%'?y*(img.height()-1)/100:y);
                const float
                  nR = cimg::round(sepR=='%'?R*rmax/100:R),
                  nr = cimg::round(sepr=='%'?r*rmax/100:r);
                if (seph=='x') {
                  if (nR==nr) { gmic_apply(img,draw_circle(nx,ny,(int)nR,col.data(),opacity,~0U));}
                  else { gmic_apply(img,draw_ellipse(nx,ny,nR,nr,angle,col.data(),opacity,~0U)); }
                } else {
                  if (nR==nr) { gmic_apply(img,draw_circle(nx,ny,(int)nR,col.data(),opacity)); }
                  else { gmic_apply(img,draw_ellipse(nx,ny,nR,nr,angle,col.data(),opacity)); }
                }
              }
            } else arg_error("ellipse");
            is_released = false; ++position; continue;
          }

          // Equalize.
          if (!std::strcmp("-equalize",command)) {
            gmic_substitute_args();
            char sep = 0, sep0 = 0, sep1 = 0;
            double value0 = 0, value1 = 0;
            float nb_levels = 256;
            if ((std::sscanf(argument,"%f%c",
                             &nb_levels,&end)==1 ||
                 (std::sscanf(argument,"%f%c%c",
                              &nb_levels,&sep,&end)==2 && sep=='%') ||
                 std::sscanf(argument,"%f,%lf,%lf%c",
                             &nb_levels,&value0,&value1,&end)==3 ||
                 (std::sscanf(argument,"%f%c,%lf,%lf%c",
                              &nb_levels,&sep,&value0,&value1,&end)==4 && sep=='%') ||
                 (std::sscanf(argument,"%f,%lf%c,%lf%c",
                              &nb_levels,&value0,&sep0,&value1,&end)==4 && sep0=='%') ||
                 (std::sscanf(argument,"%f%c,%lf%c,%lf%c",
                              &nb_levels,&sep,&value0,&sep0,&value1,&end)==5 && sep=='%' &&
                  sep0=='%') ||
                 (std::sscanf(argument,"%f,%lf,%lf%c%c",
                              &nb_levels,&value0,&value1,&sep1,&end)==4 && sep1=='%') ||
                 (std::sscanf(argument,"%f%c,%lf,%lf%c%c",
                              &nb_levels,&sep,&value0,&value1,&sep1,&end)==5 && sep=='%' &&
                  sep1=='%') ||
                 (std::sscanf(argument,"%f,%lf%c,%lf%c%c",
                              &nb_levels,&value0,&sep0,&value1,&sep1,&end)==5 && sep0=='%' &&
                  sep1=='%') ||
                 (std::sscanf(argument,"%f%c,%lf%c,%lf%c%c",
                              &nb_levels,&sep,&value0,&sep0,&value1,&sep1,&end)==6 && sep=='%' &&
                  sep0=='%' && sep1=='%')) &&
                nb_levels>=0.5) {
              nb_levels = cimg::round(nb_levels); ++position; }
            else { nb_levels = 256; value0 = value1 = 0; sep = sep0 = sep1 = 0; }
            if (value0==value1 && value0==0) { value1 = 100; sep0 = sep1 = '%'; }
            print(images,"Equalize histogram of image%s, with %g%s levels in range [%g%s,%g%s].",
                  gmic_selection,
                  nb_levels,sep=='%'?"%":"",
                  value0,sep0=='%'?"%":"",
                  value1,sep1=='%'?"%":"");
            cimg_forY(selection,l) {
              CImg<T>& img = gmic_check(images[selection[l]]);
              double vmin = 0, vmax = 0, nvalue0 = value0, nvalue1 = value1;
              if (sep0=='%' || sep1=='%') {
                if (img) vmax = (double)img.max_min(vmin);
                if (sep0=='%') nvalue0 = vmin + (vmax-vmin)*value0/100;
                if (sep1=='%') nvalue1 = vmin + (vmax-vmin)*value1/100;
              }
              const unsigned int
                _nb_levels = cimg::max(1U,
                                       (unsigned int)cimg::round(sep=='%'?
                                                                 nb_levels*(1+nvalue1-nvalue0)/100:
                                                                 nb_levels));
              gmic_apply(images[selection[l]],equalize(_nb_levels,(T)nvalue0,(T)nvalue1));
            }
            is_released = false; continue;
          }

          // Erode.
          if (!std::strcmp("-erode",command)) {
            gmic_substitute_args();
            unsigned int boundary = 1, is_normalized = 0;
            float sx = 3, sy = 3, sz = 1;
            CImg<unsigned int> ind;
            char sep = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                              indices,&sep,&end)==2 && sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u%c",
                             indices,&boundary,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u%c",
                             indices,&boundary,&is_normalized,&end)==3) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-erode",true,
                                    false,CImg<char>::empty())).height()==1 &&
                boundary<=1) {
              print(images,"Erode image%s with mask [%u] and %s boundary conditions, "
                    "with%s normalization.",
                    gmic_selection,
                    *ind,
                    boundary?"neumann":"dirichlet",
                    is_normalized?"":"out");
              const CImg<T> mask = gmic_image_arg(*ind);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],erode(mask,boundary,(bool)is_normalized));
            } else if ((std::sscanf(argument,"%f%c",
                                    &sx,&end)==1) &&
                       sx>=0) {
              sx = cimg::round(sx);
              print(images,"Erode image%s with mask of size %g and neumann boundary conditions.",
                    gmic_selection,
                    sx);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],erode((unsigned int)sx));
            } else if ((std::sscanf(argument,"%f,%f%c",
                                    &sx,&sy,&end)==2 ||
                        std::sscanf(argument,"%f,%f,%f%c",
                                    &sx,&sy,&sz,&end)==3) &&
                       sx>=0 && sy>=0 && sz>=0) {
              sx = cimg::round(sx);
              sy = cimg::round(sy);
              sz = cimg::round(sz);
              print(images,"Erode image%s with %gx%gx%g mask and neumann boundary conditions.",
                    gmic_selection,
                    sx,sy,sz);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],erode((unsigned int)sx,(unsigned int)sy,
                                                      (unsigned int)sz));
            } else arg_error("erode");
            is_released = false; ++position; continue;
          }

          // Build 3d elevation.
          if (!std::strcmp("-elevation3d",command)) {
            gmic_substitute_args();
            CImg<typename CImg<T>::Tfloat> elev;
            CImg<unsigned int> ind;
            float fact = 1;
            char sep = 0;
            *formula = 0;
            if (std::sscanf(argument,"'%4095[^']'%c",formula,&end)==1) {
              print(images,"Build 3d elevation of image%s, with elevation formula '%s'.",
                    gmic_selection,
                    formula);
              cimg_forY(selection,l) {
                CImg<T>& img = gmic_check(images[selection[l]]);
                elev.assign(img.width(),img.height(),1,1,formula,true);
                CImgList<unsigned int> primitives;
                CImgList<float> colors;
                CImg<float> vertices = img.get_elevation3d(primitives,colors,elev);
                vertices.object3dtoCImg3d(primitives,colors,false);
                gmic_apply(img,replace(vertices));
              }
              ++position;
            } else if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 &&
                       sep==']' &&
                       (ind=selection2cimg(indices,images.size(),images_names,"-elevation3d",true,
                                           false,CImg<char>::empty())).height()==1) {
              print(images,"Build 3d elevation of image%s, with elevation map [%u].",
                    gmic_selection,
                    *ind);
              if (images[*ind].spectrum()>1) images[*ind].get_norm().move_to(elev);
              else elev = gmic_image_arg(*ind);
              cimg_forY(selection,l) {
                CImg<T>& img = gmic_check(images[selection[l]]);
                CImgList<unsigned int> primitives;
                CImgList<float> colors;
                CImg<float> vertices = img.get_elevation3d(primitives,colors,elev);
                vertices.object3dtoCImg3d(primitives,colors,false);
                gmic_apply(img,replace(vertices));
              }
              ++position;
            } else {
              if (std::sscanf(argument,"%f%c",
                              &fact,&end)==1) {
                print(images,"Build 3d elevation of image%s, with elevation factor %g.",
                      gmic_selection,
                      fact);
                ++position;
              } else
                print(images,"Build 3d elevation of image%s.",
                      gmic_selection);
              cimg_forY(selection,l) {
                CImg<T>& img = gmic_check(images[selection[l]]);
                CImgList<unsigned int> primitives;
                CImgList<float> colors;
                elev.assign();
                if (fact==1 && img.spectrum()==1) elev = img.get_shared();
                else if (img.spectrum()>1) (img.get_norm().move_to(elev))*=fact;
                else (elev = img)*=fact;
                CImg<float> vertices = img.get_elevation3d(primitives,colors,elev);
                vertices.object3dtoCImg3d(primitives,colors,false);
                gmic_apply(img,replace(vertices));
              }
            }
            is_released = false; continue;
          }

          // Eigenvalues/eigenvectors.
          if (!std::strcmp("-eigen",command)) {
            print(images,"Compute eigen-values/vectors of symmetric matri%s or matrix field%s.",
                  selection.height()>1?"ce":"x",gmic_selection);
            CImg<float> val, vec;
            unsigned int off = 0;
            cimg_forY(selection,l) {
              const unsigned int ind = selection[l] + off;
              CImg<char> name = images_names[ind].get_mark();
              gmic_check(images[ind]).gmic_symmetric_eigen(val,vec);
              if (is_get_version) {
                images_names.insert(name.copymark());
                name.move_to(images_names);
                val.move_to(images);
                vec.move_to(images);
              } else {
                images_names.insert(name.get_copymark(),ind+1); name.move_to(images_names[ind]);
                val.move_to(images[ind].assign()); images.insert(vec,ind+1);
                ++off;
              }
            }
            is_released = false; continue;
          }

#endif // #ifdef gmic_float
# 6168 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='e'.

        //----------------------------
        // Commands starting by '-f..'
        //----------------------------
        else if (command1=='f') {

#ifdef gmic_float

          // Fill.
          if (!std::strcmp("-fill",command)) {
            gmic_substitute_args();
            double value = 0;
            CImg<unsigned int> ind;
            char sep = 0;
            if (std::sscanf(argument,"%lf%c",
                            &value,&end)==1) {
              print(images,"Fill image%s with %g.",
                    gmic_selection,
                    value);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],fill((T)value));
            } else if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 &&
                       sep==']' &&
                       (ind=selection2cimg(indices,images.size(),images_names,"-fill",true,
                                           false,CImg<char>::empty())).height()==1) {
              print(images,"Fill image%s with values from image [%u].",
                    gmic_selection,
                    *ind);
              const CImg<T> values = gmic_image_arg(*ind);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],fill(values));
            } else {
              CImg<char> arg_fill_text(argument_text,std::strlen(argument_text)+1);
              cimg::strpare(arg_fill_text,'\'',true,false);
              print(images,"Fill image%s with expression '%s'.",
                    gmic_selection,
                    arg_fill_text.data());
              CImg<char> arg_fill(argument,std::strlen(argument)+1);
              cimg::strpare(arg_fill,'\'',true,false);
              gmic_strreplace(arg_fill);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],fill(arg_fill.data(),true));
            }
            is_released = false; ++position; continue;
          }

          // Flood fill.
          if (!std::strcmp("-flood",command)) {
            gmic_substitute_args();
            float x = 0, y = 0, z = 0, tolerance = 0, opacity = 1;
            unsigned int is_high_connectivity = 0;
            char sepx = 0, sepy = 0, sepz = 0;
            *argx = *argy = *argz = *color = 0;
            if ((std::sscanf(argument,"%255[0-9.eE%+-]%c",
                             argx,&end)==1 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             argx,argy,&end)==2 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             argx,argy,argz,&end)==3 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f%c",
                             argx,argy,argz,&tolerance,&end)==4 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f,%u%c",
                             argx,argy,argz,&tolerance,&is_high_connectivity,&end)==5 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f,%u,%f%c",
                             argx,argy,argz,&tolerance,&is_high_connectivity,&opacity,&end)==6 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f,%u,%f,"
                             "%4095[0-9.eE,+-]%c",
                             argx,argy,argz,&tolerance,&is_high_connectivity,
                             &opacity,color,&end)==7) &&
                (std::sscanf(argx,"%f%c",&x,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&x,&sepx,&end)==2 && sepx=='%')) &&
                (!*argy ||
                 std::sscanf(argy,"%f%c",&y,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&y,&sepy,&end)==2 && sepy=='%')) &&
                (!*argz ||
                 std::sscanf(argz,"%f%c",&z,&end)==1 ||
                 (std::sscanf(argz,"%f%c%c",&z,&sepz,&end)==2 && sepz=='%')) &&
                tolerance>=0) {
              print(images,
                    "Flood fill image%s from (%g%s,%g%s,%g%s), with tolerance %g, %s connectivity,"
                    "opacity %g and color (%s).",
                    gmic_selection,
                    x,sepx=='%'?"%":"",
                    y,sepy=='%'?"%":"",
                    z,sepz=='%'?"%":"",
                    tolerance,
                    is_high_connectivity?"high":"low",
                    opacity,
                    *color?color:"default");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]], col(img.spectrum(),1,1,1,0);
                col.fill(color,true);
                const int
                  nx = (int)cimg::round(sepx=='%'?x*(img.width()-1)/100:x),
                  ny = (int)cimg::round(sepy=='%'?y*(img.height()-1)/100:y),
                  nz = (int)cimg::round(sepz=='%'?z*(img.depth()-1)/100:z);
                gmic_apply(img,draw_fill(nx,ny,nz,col.data(),opacity,tolerance,
                                         (bool)is_high_connectivity));
              }
            } else arg_error("flood");
            is_released = false; ++position; continue;
          }

          // Set 3d focale.
          if (!std::strcmp("-focale3d",item)) {
            gmic_substitute_args();
            float value = 700;
            if (std::sscanf(argument,"%f%c",&value,&end)==1) ++position;
            else value = 700;
            focale3d = value;
            print(images,"Set 3d focale to %g.",
                  focale3d);
            continue;
          }

#endif // #ifdef gmic_float
# 6282 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='f'.

        //----------------------------
        // Commands starting by '-g..'
        //----------------------------
        else if (command1=='g') {

#ifdef gmic_float

          // Greater or equal.
          gmic_arithmetic_item("-ge",
                               operator_ge,
                               "Compute boolean 'greater or equal than' between image%s and %g%s",
                               gmic_selection,value,ssep,T,
                               operator_ge,
                               "Compute boolean 'greater or equal than' between image%s "
                               "and image [%d]",
                               gmic_selection,ind[0],
                               "Compute boolean 'greater or equal than' between image%s "
                               "and expression %s'",
                               gmic_selection,argument_text,
                               "Compute boolean 'greater or equal than' between image%s");

          // Greater than.
          gmic_arithmetic_item("-gt",
                               operator_gt,
                               "Compute boolean 'greater than' between image%s and %g%s",
                               gmic_selection,value,ssep,T,
                               operator_gt,
                               "Compute boolean 'greater than' between image%s and image [%d]",
                               gmic_selection,ind[0],
                               "Compute boolean 'greater than' between image%s and expression %s'",
                               gmic_selection,argument_text,
                               "Compute boolean 'greater than' between image%s");

          // Compute gradient.
          if (!std::strcmp("-gradient",command)) {
            gmic_substitute_args();
            char axes[16];
            int scheme = 3;
            *axes = 0;
            if ((std::sscanf(argument,"%15[xyz]%c",
                             axes,&end)==1 ||
                 std::sscanf(argument,"%15[xyz],%d%c",
                             axes,&scheme,&end)==2) &&
                scheme>=-1 && scheme<=5) {
              ++position;
              print(images,"Compute gradient of image%s along axes '%s', with %s scheme.",
                    gmic_selection,
                    axes,
                    scheme==-1?"backward differences":scheme==4?"deriche":scheme==5?"vanvliet":
                    scheme==1?"forward differences":scheme==2?"sobel":
                    scheme==3?"rotation invariant":"centered differences");
            } else print(images,"Compute gradient of image%s, with rotation invariant scheme.",
                         gmic_selection);
            unsigned int off = 0;
            cimg_forY(selection,l) {
              const unsigned int ind = selection[l] + off;
              CImg<T>& img = gmic_check(images[ind]);
              CImg<char> name = images_names[ind].get_mark();
              CImgList<T> gradient = img.get_gradient(*axes?axes:0,scheme);
              if (is_get_version) {
                images_names.insert(gradient.size(),name.copymark());
                gradient.move_to(images,~0U);
              } else {
                off+=gradient.size() - 1;
                gradient[0].move_to(images[ind].assign());
                for (unsigned int i = 1; i<gradient.size(); ++i) gradient[i].move_to(images,ind+i);
                images_names[ind] = name;
                if (gradient.size()>1)
                  images_names.insert(gradient.size()-1,name.copymark(),ind+1);
              }
            }
            is_released = false; continue;
          }

          // Draw graph.
          if (!std::strcmp("-graph",command)) {
            gmic_substitute_args();
            double ymin = 0, ymax = 0, xmin = 0, xmax = 0;
            unsigned int plot_type = 1, vertex_type = 1;
            float resolution = 65536, opacity = 1;
            unsigned int pattern = ~0U;
            CImg<unsigned int> ind;
            char sep = 0, seph = 0;
            *formula = *color = 0;
            if (((std::sscanf(argument,"'%1023[^']%c%c",
                              formula,&sep,&end)==2 && sep=='\'') ||
                 std::sscanf(argument,"'%1023[^']',%f%c",
                             formula,&resolution,&end)==2 ||
                 std::sscanf(argument,"'%1023[^']',%f,%u%c",
                             formula,&resolution,&plot_type,&end)==3 ||
                 std::sscanf(argument,"'%1023[^']',%f,%u,%u%c",
                             formula,&resolution,&plot_type,&vertex_type,&end)==4 ||
                 std::sscanf(argument,"'%1023[^']',%f,%u,%u,%lf,%lf%c",
                             formula,&resolution,&plot_type,&vertex_type,&xmin,&xmax,&end)==6 ||
                 std::sscanf(argument,"'%1023[^']',%f,%u,%u,%lf,%lf,%lf,%lf%c",
                             formula,&resolution,&plot_type,&vertex_type,&xmin,&xmax,
                             &ymin,&ymax,&end)==8 ||
                 std::sscanf(argument,"'%1023[^']',%f,%u,%u,%lf,%lf,%lf,%lf,%f%c",
                             formula,&resolution,&plot_type,&vertex_type,
                             &xmin,&xmax,&ymin,&ymax,&opacity,&end)==9 ||
                 (std::sscanf(argument,"'%1023[^']',%f,%u,%u,%lf,%lf,%lf,%lf,%f,0%c%x%c",
                              formula,&resolution,&plot_type,&vertex_type,&xmin,&xmax,
                              &ymin,&ymax,&opacity,&seph,&pattern,&end)==11 && seph=='x') ||
                 (std::sscanf(argument,"'%1023[^']',%f,%u,%u,%lf,%lf,%lf,%lf,%f,%4095[0-9.eE,+-]%c",
                              formula,&resolution,&plot_type,&vertex_type,&xmin,&xmax,&ymin,&ymax,
                              &opacity,color,&end)==10 && (bool)(pattern=~0U)) ||
                 (*color=0,std::sscanf(argument,"'%1023[^']',%f,%u,%u,%lf,%lf,%lf,%lf,%f,0%c%x,"
                                       "%4095[0-9.eE,+-]%c",
                                       formula,&resolution,&plot_type,&vertex_type,&xmin,&xmax,
                                       &ymin,&ymax,&opacity,&seph,&pattern,color,&end)==12 &&
                  seph=='x')) &&
                resolution>0 && plot_type<=3 && vertex_type<=7) {
              resolution = cimg::round(resolution);
              gmic_strreplace(formula);
              print(images,
                    "Draw graph of formula '%s' on image%s, with resolution %g, %s contours, "
                    "%s vertices, x-range = (%g,%g), y-range = (%g,%g), opacity %g, "
                    "pattern 0x%x and color (%s).",
                    formula,
                    gmic_selection,
                    resolution,
                    plot_type==0?"no":plot_type==1?"linear":plot_type==2?"spline":"bar",
                    vertex_type==0?"no":vertex_type==1?"dot":vertex_type==2?"straight cross":
                    vertex_type==3?"diagonal cross":vertex_type==4?"filled circle":
                    vertex_type==5?"outlined circle":vertex_type==6?"square":"diamond",
                    xmin,xmax,
                    ymin,ymax,
                    opacity,pattern,
                    *color?color:"default");
              if (xmin==0 && xmax==0) { xmin = -4; xmax = 4; }
              if (!plot_type && !vertex_type) plot_type = 1;
              if (resolution<1) resolution = 65536;

              CImg<double> values(4,(unsigned int)resolution--,1,1,0);
              const double dx = xmax - xmin;
              cimg_forY(values,X) values(0,X) = xmin + X*dx/resolution;
              cimg::eval(formula,values).move_to(values);

              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]], col(img.spectrum(),1,1,1,0);
                col.fill(color,true);
                gmic_apply(img,draw_graph(values,col.data(),opacity,plot_type,vertex_type,
                                          ymin,ymax,pattern));
              }
            } else if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                                     indices,&sep,&end)==2 && sep==']') ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u%c",
                                    indices,&plot_type,&end)==2 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u%c",
                                    indices,&plot_type,&vertex_type,&end)==3 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u,%lf,%lf%c",
                                    indices,&plot_type,&vertex_type,&ymin,&ymax,&end)==5 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u,%lf,%lf,%f%c",
                                    indices,&plot_type,&vertex_type,&ymin,&ymax,&opacity,&end)==6||
                        (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u,%lf,%lf,%f,0%c%x%c",
                                     indices,&plot_type,&vertex_type,&ymin,&ymax,&opacity,&seph,
                                     &pattern,&end)==8 &&
                         seph=='x') ||
                        (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u,%lf,%lf,%f,"
                                     "%4095[0-9.eE,+-]%c",
                                     indices,&plot_type,&vertex_type,&ymin,&ymax,&opacity,
                                     color,&end)==7 &&
                         (bool)(pattern=~0U)) ||
                        (*color=0,std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u,%lf,%lf,"
                                              "%f,0%c%x,%4095[0-9.eE,+-]%c",
                                              indices,&plot_type,&vertex_type,&ymin,&ymax,
                                              &opacity,&seph,&pattern,color,&end)==9 &&
                         seph=='x')) &&
                       (ind=selection2cimg(indices,images.size(),images_names,"-graph",true,
                                           false,CImg<char>::empty())).height()==1 &&
                       plot_type<=3 && vertex_type<=7) {
              if (!plot_type && !vertex_type) plot_type = 1;
              print(images,"Draw graph of dataset [%u] on image%s, with %s contours, %s vertices, "
                    "y-range = (%g,%g), opacity %g, pattern 0x%x and color (%s).",
                    *ind,
                    gmic_selection,
                    plot_type==0?"no":plot_type==1?"linear":plot_type==2?"spline":"bar",
                    vertex_type==0?"no":vertex_type==1?"dot":vertex_type==2?"straight cross":
                    vertex_type==3?"diagonal cross":vertex_type==4?"filled circle":
                    vertex_type==5?"outlined circle":vertex_type==6?"square":"diamond",
                    ymin,ymax,
                    opacity,pattern,
                    *color?color:"default");
              const CImg<T> values = gmic_image_arg(*ind);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]], col(img.spectrum(),1,1,1,0);
                col.fill(color,true);
                gmic_apply(img,draw_graph(values,col.data(),opacity,plot_type,vertex_type,
                                          ymin,ymax,pattern));
              }
            } else arg_error("graph");
            is_released = false; ++position; continue;
          }

#endif // #ifdef gmic_float
# 6479 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='g'.

        //----------------------------
        // Commands starting by '-h..'
        //----------------------------
        else if (command1=='h') {

#ifdef gmic_float

          // Histogram.
          if (!std::strcmp("-histogram",command)) {
            gmic_substitute_args();
            char sep = 0, sep0 = 0, sep1 = 0;
            double value0 = 0, value1 = 0;
            float nb_levels = 256;
            if ((std::sscanf(argument,"%f%c",
                             &nb_levels,&end)==1 ||
                 (std::sscanf(argument,"%f%c%c",
                              &nb_levels,&sep,&end)==2 && sep=='%') ||
                 std::sscanf(argument,"%f,%lf,%lf%c",
                             &nb_levels,&value0,&value1,&end)==3 ||
                 (std::sscanf(argument,"%f%c,%lf,%lf%c",
                              &nb_levels,&sep,&value0,&value1,&end)==4 && sep=='%') ||
                 (std::sscanf(argument,"%f,%lf%c,%lf%c",
                              &nb_levels,&value0,&sep0,&value1,&end)==4 && sep0=='%') ||
                 (std::sscanf(argument,"%f%c,%lf%c,%lf%c",
                              &nb_levels,&sep,&value0,&sep0,&value1,&end)==5 && sep=='%' &&
                  sep0=='%') ||
                 (std::sscanf(argument,"%f,%lf,%lf%c%c",
                              &nb_levels,&value0,&value1,&sep1,&end)==4 && sep1=='%') ||
                 (std::sscanf(argument,"%f%c,%lf,%lf%c%c",
                              &nb_levels,&sep,&value0,&value1,&sep1,&end)==5 && sep=='%' &&
                  sep1=='%') ||
                 (std::sscanf(argument,"%f,%lf%c,%lf%c%c",
                              &nb_levels,&value0,&sep0,&value1,&sep1,&end)==5 && sep0=='%' &&
                  sep1=='%') ||
                 (std::sscanf(argument,"%f%c,%lf%c,%lf%c%c",
                              &nb_levels,&sep,&value0,&sep0,&value1,&sep1,&end)==6 && sep=='%' &&
                  sep0=='%' && sep1=='%')) &&
                nb_levels>0) { nb_levels = cimg::round(nb_levels); ++position; }
            else { nb_levels = 256; value0 = value1 = 0; sep = sep0 = sep1 = 0; }
            if (value0==value1 && value0==0) { value1 = 100; sep0 = sep1 = '%'; }
            print(images,"Compute histogram of image%s, using %g%s level%s in range [%g%s,%g%s].",
                  gmic_selection,
                  nb_levels,sep=='%'?"%":"",
                  nb_levels>1?"s":"",
                  value0,sep0=='%'?"%":"",
                  value1,sep1=='%'?"%":"");
            cimg_forY(selection,l) {
              CImg<T> &img = gmic_check(images[selection[l]]);
              double vmin = 0, vmax = 0, nvalue0 = value0, nvalue1 = value1;
              if (sep0=='%' || sep1=='%') {
                if (img) vmax = (double)img.max_min(vmin);
                if (sep0=='%') nvalue0 = vmin + (vmax-vmin)*value0/100;
                if (sep1=='%') nvalue1 = vmin + (vmax-vmin)*value1/100;
              }
              const unsigned int
                _nb_levels = cimg::max(1U,
                                       (unsigned int)cimg::round(sep=='%'?
                                                                 nb_levels*(1+nvalue1-nvalue0)/100:
                                                                 nb_levels));
              gmic_apply(images[selection[l]],histogram(_nb_levels,(T)nvalue0,(T)nvalue1));
            }
            is_released = false; continue;
          }

          // HSI to RGB.
          gmic_simple_item("-hsi2rgb",HSItoRGB,"Convert image%s from HSI to RGB color bases.");

          // HSL to RGB.
          gmic_simple_item("-hsl2rgb",HSLtoRGB,"Convert image%s from HSL to RGB color bases.");

          // HSV to RGB.
          gmic_simple_item("-hsv2rgb",HSVtoRGB,"Convert image%s from HSV to RGB color bases.");

          // Compute Hessian.
          if (!std::strcmp("-hessian",command)) {
            gmic_substitute_args();
            CImg<char> axes(64);
            *axes = 0;
            if (std::sscanf(argument,"%63[xyz]%c",
                            axes.data(),&end)==1) {
              ++position;
              print(images,"Compute Hessian of image%s along axes '%s'.",
                    gmic_selection,
                    axes.data());
            } else
              print(images,"Compute Hessian of image%s.",
                    gmic_selection);
            unsigned int off = 0;
            cimg_forY(selection,l) {
              const unsigned int ind = selection[l] + off;
              CImg<T>& img = gmic_check(images[ind]);
              CImg<char> name = images_names[ind].get_mark();
              CImgList<T> hessian = img.get_hessian(*axes?axes.data():0);
              if (is_get_version) {
                images_names.insert(hessian.size(),name.copymark());
                hessian.move_to(images,~0U);
              } else {
                off+=hessian.size() - 1;
                hessian[0].move_to(images[ind].assign());
                for (unsigned int i = 1; i<hessian.size(); ++i) hessian[i].move_to(images,ind+i);
                images_names[ind] = name;
                if (hessian.size()>1) images_names.insert(hessian.size()-1,name.copymark(),ind+1);
              }
            }
            is_released = false; continue;
          }

#endif // #ifdef gmic_float
# 6589 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='h'.

        //----------------------------
        // Commands starting by '-i..'
        //----------------------------
        else if (command1=='i' && !(command[2]=='f' && !command[3])) {   // (Skip for '-if').

#ifdef gmic_float

          // Draw image.
          if (!std::strcmp("-image",command)) {
            gmic_substitute_args();
            char sep = 0, sepx = 0, sepy = 0, sepz = 0, sepc = 0;
            CImg<char> indicesm(256);
            float x = 0, y = 0, z = 0, c = 0, opacity = 1, max_opacity_mask = 1;
            CImg<unsigned int> ind, indm;
            *indices = *indicesm = *argx = *argy = *argz = *argc = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                              indices,&sep,&end)==2 && sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-]%c",
                             indices,argx,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             indices,argx,argy,&end)==3 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-]%c",
                             indices,argx,argy,argz,&end)==4 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-]%c",
                             indices,argx,argy,argz,argc,&end)==5 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-],%255[0-9.eE%+-],%f%c",
                             indices,argx,argy,argz,argc,&opacity,&end)==6 ||
                 (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                              "%255[0-9.eE%+-],%255[0-9.eE%+-],%f,[%255[a-zA-Z0-9_.%+-]%c%c",
                              indices,argx,argy,argz,argc,&opacity,indicesm.data(),&sep,&end)==8 &&
                  sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-],%255[0-9.eE%+-],%f,[%255[a-zA-Z0-9_.%+-]],%f%c",
                             indices,argx,argy,argz,argc,&opacity,indicesm.data(),
                             &max_opacity_mask,&end)==8) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-image",true,
                                    false,CImg<char>::empty())).height()==1 &&
                (!*indicesm ||
                 (indm = selection2cimg(indicesm,images.size(),images_names,"-image",true,
                                        false,CImg<char>::empty())).height()==1) &&
                (!*argx ||
                 std::sscanf(argx,"%f%c",&x,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&x,&sepx,&end)==2 && sepx=='%')) &&
                (!*argy ||
                 std::sscanf(argy,"%f%c",&y,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&y,&sepy,&end)==2 && sepy=='%')) &&
                (!*argz ||
                 std::sscanf(argz,"%f%c",&z,&end)==1 ||
                 (std::sscanf(argz,"%f%c%c",&z,&sepz,&end)==2 && sepz=='%')) &&
                (!*argc ||
                 std::sscanf(argc,"%f%c",&c,&end)==1 ||
                 (std::sscanf(argc,"%f%c%c",&c,&sepc,&end)==2 && sepc=='%'))) {
              const CImg<T> sprite = gmic_image_arg(*ind);
              CImg<T> mask;
              if (indm) {
                mask = gmic_image_arg(*indm);
                print(images,"Draw image [%u] at (%g%s,%g%s,%g%s,%g%s) on image%s, "
                      "with opacity %g and mask [%u].",
                      *ind,
                      x,sepx=='%'?"%":"",
                      y,sepy=='%'?"%":"",
                      z,sepz=='%'?"%":"",
                      c,sepc=='%'?"%":"",
                      gmic_selection,
                      opacity,
                      *indm);
              } else print(images,"Draw image [%u] at (%g%s,%g%s,%g%s,%g%s) on image%s, "
                           "with opacity %g.",
                           *ind,
                           x,sepx=='%'?"%":"",
                           y,sepy=='%'?"%":"",
                           z,sepz=='%'?"%":"",
                           c,sepc=='%'?"%":"",
                           gmic_selection,
                           opacity);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  nx = (int)cimg::round(sepx=='%'?x*(img.width()-1)/100:x),
                  ny = (int)cimg::round(sepy=='%'?y*(img.height()-1)/100:y),
                  nz = (int)cimg::round(sepz=='%'?z*(img.depth()-1)/100:z),
                  nc = (int)cimg::round(sepc=='%'?c*(img.spectrum()-1)/100:c);
                if (indm) {
                  gmic_apply(img,draw_image(nx,ny,nz,nc,sprite,mask,opacity,max_opacity_mask));
                } else {
                  gmic_apply(img,draw_image(nx,ny,nz,nc,sprite,opacity));
                }
              }
            } else arg_error("image");
            is_released = false; ++position; continue;
          }

          // Index image with a LUT.
          if (!std::strcmp("-index",command)) {
            gmic_substitute_args();
            unsigned int lut_type = 0, map_indexes = 0;
            float dithering = 0;
            CImg<unsigned int> ind;
            char sep = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                            indices,&sep,&end)==2 && sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f%c",
                             indices,&dithering,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%u%c",
                             indices,&dithering,&map_indexes,&end)==3) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-index",true,
                                    false,CImg<char>::empty())).height()==1) {
              const float ndithering = dithering<0?0:dithering>1?1:dithering;
              print(images,"Index values in image%s by LUT [%u], with dithering level %g%s.",
                    gmic_selection,
                    *ind,
                    ndithering,
                    map_indexes?" and index mapping":"");
              const CImg<T> palette = gmic_image_arg(*ind);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],index(palette,ndithering,(bool)map_indexes));
            } else if ((std::sscanf(argument,"%u%c",&lut_type,&end)==1 ||
                        std::sscanf(argument,"%u,%f%c",&lut_type,&dithering,&end)==2 ||
                        std::sscanf(argument,"%u,%f,%u%c",
                                    &lut_type,&dithering,&map_indexes,&end)==3) &&
                       lut_type<=7) {
              const float ndithering = dithering<0?0:dithering>1?1:dithering;
              print(images,"Index values in image%s by %s color LUT, with dithering level %g%s.",
                    gmic_selection,
                    lut_type==0?"default":lut_type==1?"HSV":lut_type==2?"lines":lut_type==3?"hot":
                    lut_type==4?"cool":lut_type==5?"jet":lut_type==6?"flag":"cube",
                    ndithering,map_indexes?" and index mapping":"");
              const CImg<T>
                palette = lut_type==0?CImg<T>::default_LUT256():lut_type==1?CImg<T>::HSV_LUT256():
                lut_type==2?CImg<T>::lines_LUT256():lut_type==3?CImg<T>::hot_LUT256():
                lut_type==4?CImg<T>::cool_LUT256():lut_type==5?CImg<T>::jet_LUT256():
                lut_type==6?CImg<T>::flag_LUT256():CImg<T>::cube_LUT256();
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],index(palette,ndithering,(bool)map_indexes));
            } else arg_error("index");
            is_released = false; ++position; continue;
          }

          // Matrix inverse.
          gmic_simple_item("-invert",invert,"Invert matrix image%s.");

          // Extract 3d isoline.
          if (!std::strcmp("-isoline3d",command)) {
            gmic_substitute_args();
            float x0 = -3, y0 = -3, x1 = 3, y1 = 3, value = 0, dx = 256, dy = 256;
            char sep = 0, sepx = 0, sepy = 0;
            *formula = 0;
            if (std::sscanf(argument,"%f%c",
                            &value,&end)==1 ||
                std::sscanf(argument,"%f%c%c",
                            &value,&sep,&end)==2) {
              print(images,"Extract 3d isolines from image%s, using isovalue %g%s.",
                    gmic_selection,
                    value,sep=='%'?"%":"");
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                CImg<T>& img = gmic_check(images[ind]);
                if (img) {
                  CImg<float> vertices;
                  CImgList<unsigned int> primitives;
                  CImgList<unsigned char> colors;
                  CImg<unsigned char> palette;
                  palette.assign(3,img.spectrum(),1,1,220).noise(35,1);
                  if (img.spectrum()==1) palette(0) = palette(1) = palette(2) = 200;
                  else {
                    palette(0,0) = 255; palette(1,0) = palette(2,0) = 30;
                    palette(0,1) = palette(2,1) = 30; palette(1,1) = 255;
                    if (img.spectrum()>=3) palette(0,2) = palette(1,2) = 30; palette(2,2) = 255;
                  }
                  cimg_forC(img,k) {
                    const CImg<T> channel = img.get_shared_channel(k);
                    float nvalue = value;
                    if (sep=='%') {
                      float vmin = 0, vmax = (float)channel.max_min(vmin);
                      nvalue = vmin + (vmax-vmin)*value/100;
                    }
                    CImgList<unsigned int> prims;
                    const CImg<float> pts = img.get_shared_channel(k).get_isoline3d(prims,nvalue);
                    vertices.append_object3d(primitives,pts,prims);
                    colors.insert(prims.size(),CImg<unsigned char>::vector(palette(0,k),
                                                                           palette(1,k),
                                                                           palette(2,k)));
                  }
                  if (!vertices)
                    warn(images,"Command '-isoline3d': Isovalue %g%s not found in image [%u].",
                         value,sep=='%'?"%":"",ind);
                  vertices.object3dtoCImg3d(primitives,colors,false);
                  gmic_apply(img,replace(vertices));
                } else { gmic_apply(img,replace(img)); }
              }
            } else if ((std::sscanf(argument,"'%4095[^']',%f%c",
                                    formula,&value,&end)==2 ||
                        std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f%c",
                                    formula,&value,&x0,&y0,&x1,&y1,&end)==6 ||
                        std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f%c",
                                    formula,&value,&x0,&y0,&x1,&y1,&dx,&dy,&end)==8 ||
                        (std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f%c,%f%c",
                                     formula,&value,&x0,&y0,&x1,&y1,&dx,&sepx,&dy,&end)==9 &&
                         sepx=='%') ||
                        (std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f%c%c",
                                     formula,&value,&x0,&y0,&x1,&y1,&dx,&dy,&sepy,&end)==9 &&
                         sepy=='%') ||
                        (std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f%c,%f%c%c",
                                     formula,&value,&x0,&y0,&x1,&y1,&dx,&sepx,&dy,&sepy,&end)==10&&
                         sepx=='%' && sepy=='%')) &&
                       dx>0 && dy>0) {
              dx = cimg::round(dx);
              dy = cimg::round(dy);
              gmic_strreplace(formula);
              print(images,"Extract 3d isoline %g from formula '%s', in range (%g,%g)-(%g,%g) "
                    "with size %g%sx%g%s.",
                    value,
                    formula,
                    x0,y0,
                    x1,y1,
                    dx,sepx=='%'?"%":"",
                    dy,sepy=='%'?"%":"");
              if (sepx=='%') dx = -dx;
              if (sepy=='%') dy = -dy;
              CImgList<unsigned int> primitives;
              CImg<T> vertices = CImg<T>::isoline3d(primitives,(const char*)formula,value,
                                                    x0,y0,x1,y1,(int)dx,(int)dy);
              vertices.object3dtoCImg3d(primitives,false).move_to(images);
              cimg_snprintf(title,_title.size(),"[3d isoline %g of '%s']",value,formula);
              gmic_ellipsize(title,_title.size());
              CImg<char>::string(title).move_to(images_names);
            } else arg_error("isoline3d");
            is_released = false; ++position; continue;
          }

          // Extract 3d isosurface.
          if (!std::strcmp("-isosurface3d",command)) {
            gmic_substitute_args();
            float x0 = -3, y0 = -3, z0 = -3, x1 = 3, y1 = 3, z1 = 3, value = 0,
              dx = 32, dy = 32, dz = 32;
            char sep = 0, sepx = 0, sepy = 0, sepz = 0;
            *formula = 0;
            if (std::sscanf(argument,"%f%c",
                            &value,&end)==1 ||
                std::sscanf(argument,"%f%c%c",
                            &value,&sep,&end)==2) {
              print(images,"Extract 3d isosurface from image%s, using isovalue %g%s.",
                    gmic_selection,
                    value,sep=='%'?"%":"");
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                CImg<T>& img = gmic_check(images[ind]);
                if (img) {
                  CImg<float> vertices;
                  CImgList<unsigned int> primitives;
                  CImgList<unsigned char> colors;
                  CImg<unsigned char> palette;
                  palette.assign(3,img.spectrum(),1,1,220).noise(35,1);
                  if (img.spectrum()==1) palette(0) = palette(1) = palette(2) = 200;
                  else {
                    palette(0,0) = 255; palette(1,0) = palette(2,0) = 30;
                    palette(0,1) = palette(2,1) = 30; palette(1,1) = 255;
                    if (img.spectrum()>=3) palette(0,2) = palette(1,2) = 30; palette(2,2) = 255;
                  }
                  cimg_forC(img,k) {
                    const CImg<T> channel = img.get_shared_channel(k);
                    float nvalue = value;
                    if (sep=='%') {
                      float vmin = 0, vmax = (float)channel.max_min(vmin);
                      nvalue = vmin + (vmax-vmin)*value/100;
                    }
                    CImgList<unsigned int> prims;
                    const CImg<float> pts = channel.get_isosurface3d(prims,nvalue);
                    vertices.append_object3d(primitives,pts,prims);
                    colors.insert(prims.size(),CImg<unsigned char>::vector(palette(0,k),
                                                                           palette(1,k),
                                                                           palette(2,k)));
                  }
                  if (!vertices) {
                    if (img.depth()>1)
                      warn(images,
                           "Command '-isosurface3d': Isovalue %g%s not found in image [%u].",
                           value,sep=='%'?"%":"",ind);
                    else
                      warn(images,
                           "Command '-isosurface3d': Image [%u] has a single slice, "
                           "isovalue %g%s not found.",
                           ind,value,sep=='%'?"%":"");
                  }
                  vertices.object3dtoCImg3d(primitives,colors,false);
                  gmic_apply(img,replace(vertices));
                } else { gmic_apply(img,replace(img)); }
              }
            } else if ((std::sscanf(argument,"'%4095[^']',%f%c",
                                    formula,&value,&end)==2 ||
                        std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f%c",
                                    formula,&value,&x0,&y0,&z0,&x1,&y1,&z1,&end)==8 ||
                        std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f,%f,%f,%f%c",
                                    formula,&value,&x0,&y0,&z0,&x1,&y1,&z1,&dx,&dy,&dz,&end)==11 ||
                        (std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f,%f%c,%f,%f%c",
                                     formula,&value,&x0,&y0,&z0,&x1,&y1,&z1,
                                     &dx,&sepx,&dy,&dz,&end)==12 &&
                         sepx=='%') ||
                        (std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f,%f,%f%c,%f%c",
                                     formula,&value,&x0,&y0,&z0,&x1,&y1,&z1,
                                     &dx,&dy,&sepy,&dz,&end)==12 &&
                         sepy=='%') ||
                        (std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f,%f,%f,%f%c%c",
                                     formula,&value,&x0,&y0,&z0,&x1,&y1,&z1,
                                     &dx,&dy,&dz,&sepz,&end)==12 &&
                         sepz=='%') ||
                        (std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f,%f%c,%f%c,%f%c",
                                     formula,&value,&x0,&y0,&z0,&x1,&y1,&z1,
                                     &dx,&sepx,&dy,&sepy,&dz,&end)==13 &&
                         sepx=='%' && sepy=='%') ||
                        (std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f,%f%c,%f,%f%c%c",
                                     formula,&value,&x0,&y0,&z0,&x1,&y1,&z1,
                                     &dx,&sepx,&dy,&dz,&sepz,&end)==13 &&
                         sepx=='%' && sepz=='%') ||
                        (std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f,%f,%f%c,%f%c%c",
                                     formula,&value,&x0,&y0,&z0,&x1,&y1,&z1,
                                     &dx,&dy,&sepy,&dz,&sepz,&end)==13 &&
                         sepy=='%' && sepz=='%') ||
                        (std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%f,%f,%f%c,%f%c,%f%c%c",
                                     formula,&value,&x0,&y0,&z0,&x1,&y1,&z1,
                                     &dx,&sepx,&dy,&sepy,&dz,&sepz,&end)==14 &&
                         sepx=='%' && sepy=='%' && sepz=='%')) &&
                       dx>0 && dy>0 && dz>0) {
              dx = cimg::round(dx);
              dy = cimg::round(dy);
              dz = cimg::round(dz);
              gmic_strreplace(formula);
              print(images,"Extract 3d isosurface %g from formula '%s', "
                    "in range (%g,%g,%g)-(%g,%g,%g) with size %g%sx%g%sx%g%s.",
                    value,
                    formula,
                    x0,y0,z0,
                    x1,y1,z1,
                    dx,sepx=='%'?"%":"",
                    dy,sepy=='%'?"%":"",
                    dz,sepz=='%'?"%":"");
              if (sepx=='%') dx = -dx;
              if (sepy=='%') dy = -dy;
              if (sepz=='%') dz = -dz;
              CImgList<unsigned int> primitives;
              CImg<T> vertices = CImg<T>::isosurface3d(primitives,(const char*)formula,value,
                                                       x0,y0,z0,x1,y1,z1,(int)dx,(int)dy,(int)dz);
              vertices.object3dtoCImg3d(primitives,false).move_to(images);
              cimg_snprintf(title,_title.size(),"[3d isosurface %g of '%s']",value,formula);
              gmic_ellipsize(title,_title.size());
              CImg<char>::string(title).move_to(images_names);
            } else arg_error("isosurface3d");
            is_released = false; ++position; continue;
          }

          // Inpaint.
          if (!std::strcmp("-inpaint",command)) {
            gmic_substitute_args();
            float patch_size = 11, lookup_size = 22, lookup_factor = 0.5, lookup_increment = 1,
              blend_size = 0, blend_threshold = 0, blend_decay = 0.05f, blend_scales = 10;
            unsigned int is_blend_outer = 1, method = 1;
            CImg<unsigned int> ind;
            char sep = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 && sep==']') ||
                 (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%c%c",indices,&sep,&end)==2 && sep=='0') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],0,%u%c",indices,&method,&end)==2) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-inpaint",true,
                                    false,CImg<char>::empty())).height()==1 &&
                method<=3) {
              print(images,"Inpaint image%s masked by image [%u], with %s algorithm.",
                    gmic_selection,
                    *ind,
                    method==0?"low-connectivity average":method==1?"high-connectivity average":
                    method==2?"low-connectivity median":"high-connectivity median");
              const CImg<T> mask = gmic_image_arg(*ind);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],inpaint(mask,method));
            } else if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                                     indices,&sep,&end)==2 && sep==']') ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f%c",
                                    indices,&patch_size,&end)==2 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f%c",
                                    indices,&patch_size,&lookup_size,&end)==3 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f%c",
                                    indices,&patch_size,&lookup_size,&lookup_factor,&end)==4 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f%c",
                                    indices,&patch_size,&lookup_size,&lookup_factor,&lookup_increment,&end)==5 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f,%f%c",
                                    indices,&patch_size,&lookup_size,&lookup_factor,&lookup_increment,
                                    &blend_size,&end)==6 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f,%f,%f%c",
                                    indices,&patch_size,&lookup_size,&lookup_factor,&lookup_increment,
                                    &blend_size,&blend_threshold,&end)==7 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f,%f,%f,%f%c",
                                    indices,&patch_size,&lookup_size,&lookup_factor,&lookup_increment,
                                    &blend_size,&blend_threshold,&blend_decay,&end)==8 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f,%f,%f,%f,%f%c",
                                    indices,&patch_size,&lookup_size,&lookup_factor,&lookup_increment,
                                    &blend_size,&blend_threshold,&blend_decay,&blend_scales,&end)==9 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f,%f,%f,%f,%f,%u%c",
                                    indices,&patch_size,&lookup_size,&lookup_factor,&lookup_increment,
                                    &blend_size,&blend_threshold,&blend_decay,&blend_scales,
                                    &is_blend_outer,&end)==10) &&
                       (ind=selection2cimg(indices,images.size(),images_names,"-inpaint",true,
                                           false,CImg<char>::empty())).height()==1 &&
                       patch_size>=0.5 && lookup_size>=0.5 && lookup_factor>=0 &&
                       blend_size>=0 && blend_threshold>=0 && blend_threshold<=1 &&
                       blend_decay>=0 && blend_scales>=0.5 && is_blend_outer<=1) {
              const CImg<T> mask = gmic_image_arg(*ind);
              patch_size = cimg::round(patch_size);
              lookup_size = cimg::round(lookup_size);
              lookup_increment = cimg::round(lookup_increment);
              blend_size = cimg::round(blend_size);
              blend_scales = cimg::round(blend_scales);
              print(images,"Inpaint image%s masked by image [%d], with patch size %g, "
                    "lookup size %g, lookup factor %g, lookup_increment %g, blend size %g, blend threshold %g, "
                    "blend decay %g, %g blend scale%s and outer blending %s.",
                    gmic_selection,*ind,
                    patch_size,lookup_size,lookup_factor,lookup_increment,
                    blend_size,blend_threshold,blend_decay,blend_scales,blend_scales!=1?"s":"",
                    is_blend_outer?"enabled":"disabled");
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],
                           inpaint_patch(mask,
                                         (unsigned int)patch_size,(unsigned int)lookup_size,
                                         lookup_factor,
                                         (unsigned int)lookup_increment,
                                         (unsigned int)blend_size,blend_threshold,blend_decay,
                                         (unsigned int)blend_scales,(bool)is_blend_outer));
            } else arg_error("inpaint");
            is_released = false; ++position; continue;
          }

#endif // #ifdef gmic_float
# 7023 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='i'.

        //----------------------------
        // Commands starting by '-k..'
        //----------------------------
        else if (command1=='k') {

          // Keep images.
          if (!std::strcmp("-keep",command)) {
            print(images,"Keep image%s",
                  gmic_selection);
            CImgList<T> _images, nimages(selection.height());
            CImgList<char> _images_names, nimages_names(selection.height());
            if (is_get_version) { _images.assign(images); _images_names.assign(images_names); }
            cimg_forY(selection,l) {
              nimages[l].swap(images[selection[l]]);
              nimages_names[l].swap(images_names[selection[l]]);
            }
            nimages.move_to(images);
            nimages_names.move_to(images_names);
            if (is_get_version) {
              _images.move_to(images,0);
              _images_names.move_to(images_names,0);
            }
            if (verbosity>=0 || is_debug) {
              std::fprintf(cimg::output()," (%u image%s left).",
                           images.size(),images.size()==1?"":"s");
              std::fflush(cimg::output());
            }
            is_released = false; continue;
          }

        } // command1=='k'.

        //----------------------------
        // Commands starting by '-l..'
        //----------------------------
        else if (command1=='l') {

          // Start local environnement.
          if (!std::strcmp("-local",command)) {
            CImg<char>::string("*local").move_to(scope);
            if (verbosity>0 || is_debug)
              print(images,"Start '-local..-endlocal' block, with image%s.",
                    gmic_selection);
            CImgList<T> nimages(selection.height());
            CImgList<char> nimages_names(selection.height());
            if (is_get_version) cimg_forY(selection,l) {
                nimages[l].assign(images[selection[l]]);
                nimages_names[l].assign(images_names[selection[l]]).copymark();
              } else cimg_forY(selection,l) {
                if (images[selection[l]].is_shared())
                  nimages[l] = CImg<T>(images[selection[l]],true);
                else nimages[l].swap(images[selection[l]]);
                nimages_names[l].swap(images_names[selection[l]]);
              }
            const unsigned int local_scope_size = scope.size();
            CImg<char> exception_message, exception_command;
            try {
              _parse(commands_line,position,nimages,nimages_names,variables_sizes);
            } catch (gmic_exception &e) {
              int nb_locals = 0;
              for (nb_locals = 1; nb_locals && position<commands_line.size(); ++position) {
                const char *const it = commands_line[position].data();
                if (!std::strcmp("-local",it) || !std::strcmp("-l",it) ||
                    !std::strcmp("--local",it) || !std::strcmp("--l",it) ||
                    !std::strncmp("-local[",it,7) || !std::strncmp("-l[",it,3) ||
                    !std::strncmp("--local[",it,8) || !std::strncmp("--l[",it,4)) ++nb_locals;
                else if (!std::strcmp("-endlocal",it) || !std::strcmp("-endl",it)) --nb_locals;
                else if (nb_locals==1 && !std::strcmp("-onfail",it)) break;
              }
              if (scope.size()>local_scope_size) scope.remove(local_scope_size,scope.size()-1);
              if (nb_locals==1 && position<commands_line.size()) { // Onfail block found.
                if (verbosity>0 || is_debug) print(images,"Reach '-onfail' block.");
                _parse(commands_line,++position,nimages,nimages_names,variables_sizes);
              } else { // Onfail block not found.
                exception_message.assign(e._message);
                exception_command.assign(e._command_help);
              }
            }
            scope.remove();
            if (is_get_version) {
              nimages.move_to(images,~0U);
              nimages_names.move_to(images_names,~0U);
            } else {
              const unsigned int nb = cimg::min((unsigned int)selection.height(),nimages.size());
              if (nb>0) {
                for (unsigned int i = 0; i<nb; ++i) {
                  if (images[selection[i]].is_shared()) {
                    images[selection[i]] = nimages[i];
                    nimages[i].assign();
                  } else images[selection[i]].swap(nimages[i]);
                  images_names[selection[i]].swap(nimages_names[i]);
                }
                nimages.remove(0,nb-1);
                nimages_names.remove(0,nb-1);
              }
              if (nb<(unsigned int)selection.height())
                remove_images(images,images_names,selection,nb,selection.height()-1);
              else if (nimages) {
                const unsigned int ind0 = selection?selection.back()+1:images.size();
                images.insert(nimages,ind0);
                nimages_names.move_to(images_names,ind0);
              }
            }
            if (exception_message || exception_command)
              throw gmic_exception(exception_command.data(),exception_message.data());
            continue;
          }

#ifdef gmic_float

          // Less or equal.
          gmic_arithmetic_item("-le",
                               operator_le,"Compute boolean 'less or equal than' between image%s "
                               "and %g%s",
                               gmic_selection,value,ssep,T,
                               operator_le,"Compute boolean 'less or equal than' between image%s "
                               "and image [%d]",
                               gmic_selection,ind[0],
                               "Compute boolean 'less or equal than' between image%s and "
                               "expression %s'",
                               gmic_selection,argument_text,
                               "Compute boolean 'less or equal than' between image%s");

          // Less than.
          gmic_arithmetic_item("-lt",
                               operator_lt,
                               "Compute boolean 'less than' between image%s and %g%s",
                               gmic_selection,value,ssep,T,
                               operator_lt,
                               "Compute boolean 'less than' between image%s and image [%d]",
                               gmic_selection,ind[0],
                               "Compute boolean 'less than' between image%s and expression %s'",
                               gmic_selection,argument_text,
                               "Compute boolean 'less than' between image%s");

          // Logarithm, base-e.
          gmic_simple_item("-log",log,"Compute pointwise base-e logarithm of image%s.");

          // Logarithm, base-2.
          gmic_simple_item("-log2",log2,"Compute pointwise base-2 logarithm of image%s.");

          // Logarithm, base-10.
          gmic_simple_item("-log10",log10,"Compute pointwise base-10 logarithm of image%s.");

          // Draw line.
          if (!std::strcmp("-line",command)) {
            gmic_substitute_args();
            *argx = *argy = *argz = *argc = *color = 0;
            float x0 = 0, y0 = 0, x1 = 0, y1 = 0, opacity = 1;
            char sepx0 = 0, sepy0 = 0, sepx1 = 0, sepy1 = 0, seph = 0;
            unsigned int pattern = ~0U;
            if ((std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-]%c",
                             argx,argy,argz,argc,&end)==4 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-],%f%c",
                             argx,argy,argz,argc,&opacity,&end)==5 ||
                 (std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                              "%255[0-9.eE%+-],%f,0%c%x%c",
                              argx,argy,argz,argc,&opacity,&seph,&pattern,&end)==7 &&
                  seph=='x') ||
                 (std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                              "%255[0-9.eE%+-],%f,%4095[0-9.eE,+-]%c",
                              argx,argy,argz,argc,&opacity,color,&end)==6 && (bool)(pattern=~0U)) ||
                 (*color=0,std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                                       "%255[0-9.eE%+-],%f,0%c%x,%4095[0-9.eE,+-]%c",
                                       argx,argy,argz,argc,&opacity,&seph,
                                       &pattern,color,&end)==8 && seph=='x')) &&
                (std::sscanf(argx,"%f%c",&x0,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&x0,&sepx0,&end)==2 && sepx0=='%')) &&
                (std::sscanf(argy,"%f%c",&y0,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&y0,&sepy0,&end)==2 && sepy0=='%')) &&
                (std::sscanf(argz,"%f%c",&x1,&end)==1 ||
                 (std::sscanf(argz,"%f%c%c",&x1,&sepx1,&end)==2 && sepx1=='%')) &&
                (std::sscanf(argc,"%f%c",&y1,&end)==1 ||
                 (std::sscanf(argc,"%f%c%c",&y1,&sepy1,&end)==2 && sepy1=='%'))) {
              print(images,"Draw line (%g%s,%g%s) - (%g%s,%g%s) on image%s, with opacity %g, "
                    "pattern 0x%x and color (%s).",
                    x0,sepx0=='%'?"%":"",
                    y0,sepy0=='%'?"%":"",
                    x1,sepx1=='%'?"%":"",
                    y1,sepy1=='%'?"%":"",
                    gmic_selection,
                    opacity,pattern,
                    *color?color:"default");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]], col(img.spectrum(),1,1,1,0);
                col.fill(color,true);
                const int
                  nx0 = (int)cimg::round(sepx0=='%'?x0*(img.width()-1)/100:x0),
                  ny0 = (int)cimg::round(sepy0=='%'?y0*(img.height()-1)/100:y0),
                  nx1 = (int)cimg::round(sepx1=='%'?x1*(img.width()-1)/100:x1),
                  ny1 = (int)cimg::round(sepy1=='%'?y1*(img.height()-1)/100:y1);
                gmic_apply(img,draw_line(nx0,ny0,nx1,ny1,col.data(),opacity,pattern));
              }
            } else arg_error("line");
            is_released = false; ++position; continue;
          }

          // Lab to RGB
          gmic_simple_item("-lab2rgb",LabtoRGB,"Convert image%s from Lab to RGB color bases.");

          // Label connected components.
          if (!std::strcmp("-label",command)) {
            gmic_substitute_args();
            unsigned int is_high_connectivity = 0;
            float tolerance = 0;
            if ((std::sscanf(argument,"%f%c",&tolerance,&end)==1 ||
                 std::sscanf(argument,"%f,%u%c",&tolerance,&is_high_connectivity,&end)==2) &&
                tolerance>=0) ++position;
            else { tolerance = 0; is_high_connectivity = 0; }
            print(images,
                  "Label connected components on image%s, with tolerance %g and "
                  "%s connectivity.",
                  gmic_selection,tolerance,is_high_connectivity?"high":"low");
            cimg_forY(selection,l)
              gmic_apply(images[selection[l]],label((bool)is_high_connectivity,tolerance));
            is_released = false; continue;
          }

          // Set 3d light position.
          if (!std::strcmp("-light3d",item)) {
            gmic_substitute_args();
            float lx = 0, ly = 0, lz = -5e8f;
            CImg<unsigned int> ind;
            char sep = 0;
            if (std::sscanf(argument,"%f,%f,%f%c",
                            &lx,&ly,&lz,&end)==3) {
              print(images,"Set 3d light position to (%g,%g,%g).",
                    lx,ly,lz);
              light3d_x = lx;
              light3d_y = ly;
              light3d_z = lz;
              ++position;
            } else if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 &&
                       sep==']' &&
                       (ind=selection2cimg(indices,images.size(),images_names,"-light3d",true,
                                           false,CImg<char>::empty())).height()==1) {
              print(images,"Set 3d light texture from image [%u].",*ind);
              light3d.assign(images[*ind],false);
              ++position;
            } else {
              print(images,"Reset 3d light to default.");
              light3d.assign();
              light3d_x = light3d_y = 0; light3d_z = -5e8f;
            }
            continue;
          }

#endif // #ifdef gmic_float
# 7275 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='l'.

        //----------------------------
        // Commands starting by '-m..'
        //----------------------------
        else if (command1=='m') {

          // Move images.
          if (!std::strcmp("-move",command)) {
            gmic_substitute_args();
            float pos = 0;
            char sep = 0;
            if (std::sscanf(argument,"%f%c",&pos,&end)==1 ||
                (std::sscanf(argument,"%f%c%c",&pos,&sep,&end)==2 && sep=='%')) {
              const int
                _ind0 = (int)cimg::round(sep=='%'?pos*images.size()/100:pos),
                ind0 = _ind0<0?_ind0+(int)images.size():_ind0;
              if (ind0<0 || ind0>(int)images.size())
                error(images,"Command '-move': Invalid position '%d' (not in range -%u..%u).",
                      _ind0,images.size(),images.size()-1);
              print(images,"Move image%s to position %d.",
                    gmic_selection,
                    ind0);
              CImgList<T> _images, nimages;
              CImgList<char> _images_names, nimages_names;
              if (is_get_version) {
                _images.insert(images.size());
                // Copy original list while preserving shared state of each item.
                cimglist_for(_images,l) _images[l].assign(images[l],images[l].is_shared());
                _images_names.assign(images_names);
              }
              nimages.insert(selection.height());
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                if (is_get_version) images[ind].move_to(nimages[l]);
                else images[ind].swap(nimages[l]);
                // Empty shared image as a special item to be removed later.
                images[ind]._is_shared = true;
                images_names[ind].move_to(nimages_names);
              }
              images.insert(nimages.size(),ind0);
              cimglist_for(nimages,l) nimages[l].swap(images[ind0+l]);
              nimages_names.move_to(images_names,ind0);
              cimglist_for(images,l) if (!images[l] && images[l].is_shared()) {
                images.remove(l); images_names.remove(l--); // Remove special items.
              }
              if (is_get_version) {
                cimglist_for(images,l) // Replace shared items by non-shared one for a get version.
                  if (images[l].is_shared()) {
                    CImg<T> tmp; (images[l].move_to(tmp)).swap(images[l]);
                  }
                images.insert(_images.size(),0);
                cimglist_for(_images,l) images[l].swap(_images[l]);
                _images_names.move_to(images_names,0);
              }
            } else arg_error("move");
            is_released = false; ++position; continue;
          }

          // Mirror.
          if (!std::strcmp("-mirror",command)) {
            gmic_substitute_args();
            bool is_valid_argument = true;
            for (const char *s = argument; *s; ++s) {
              const char _s = *s;
              if (_s!='x' && _s!='y' && _s!='z' && _s!='c') { is_valid_argument = false; break; }
            }
            if (*argument && is_valid_argument) {
              print(images,"Mirror image%s along the '%s'-ax%cs.",
                    gmic_selection,
                    argument_text,
                    std::strlen(argument)>1?'e':'i');
              cimg_forY(selection,l) gmic_apply(images[selection[l]],mirror(argument));
            } else arg_error("mirror");
            is_released = false; ++position; continue;
          }

          // Manage mutexes.
          if (!std::strcmp("-mutex",item)) {
            gmic_substitute_args();
            unsigned int number, is_lock = 1;
            if ((std::sscanf(argument,"%u%c",
                             &number,&end)==1 ||
                 std::sscanf(argument,"%u,%u%c",
                             &number,&is_lock,&end)==2) &&
                number<256 && is_lock<=1) {
              print(images,"%s mutex #%u.",
                    is_lock?"Lock":"Unlock",number);
              if (is_lock) gmic_mutex().lock(number);
              else gmic_mutex().unlock(number);
            } else arg_error("mutex");
            ++position; continue;
          }

#ifdef gmic_float

          // Multiplication.
          gmic_arithmetic_item("-mul",
                               operator*=,
                               "Multiply image%s by %g%s",
                               gmic_selection,value,ssep,Tfloat,
                               mul,
                               "Multiply image%s by image [%d]",
                               gmic_selection,ind[0],
                               "Multiply image%s by expression %s",
                               gmic_selection,argument_text,
                               "Multiply image%s");
          // Modulo.
          gmic_arithmetic_item("-mod",
                               operator%=,
                               "Compute pointwise modulo of image%s by %g%s",
                               gmic_selection,value,ssep,T,
                               operator%=,
                               "Compute pointwise modulo of image%s by image [%d]",
                               gmic_selection,ind[0],
                               "Compute pointwise modulo of image%s by expression %s",
                               gmic_selection,argument_text,
                               "Compute sequential pointwise modulo of image%s");

          // Max.
          gmic_arithmetic_item("-max",
                               max,
                               "Compute pointwise maximum between image%s and %g%s",
                               gmic_selection,value,ssep,T,
                               max,
                               "Compute pointwise maximum between image%s and image [%d]",
                               gmic_selection,ind[0],
                               "Compute pointwise maximum between image%s and expression %s",
                               gmic_selection,argument_text,
                               "Compute pointwise maximum of all image%s together");
          // Min.
          gmic_arithmetic_item("-min",
                               min,
                               "Compute pointwise minimum between image%s and %g%s",
                               gmic_selection,value,ssep,T,
                               min,
                               "Compute pointwise minimum between image%s and image [%d]",
                               gmic_selection,ind[0],
                               "Compute pointwise minimum between image%s and expression %s",
                               gmic_selection,argument_text,
                               "Compute pointwise minimum of image%s");

          // Matrix multiplication.
          gmic_arithmetic_item("-mmul",
                               operator*=,
                               "Multiply matrix/vector%s by %g%s",
                               gmic_selection,value,ssep,Tfloat,
                               operator*=,
                               "Multiply matrix/vector%s by matrix/vector image [%d]",
                               gmic_selection,ind[0],
                               "Multiply matrix/vector%s by expression %s",
                               gmic_selection,argument_text,
                               "Multiply matrix/vector%s");

          // Set 3d rendering modes.
          if (!std::strcmp("-mode3d",item)) {
            gmic_substitute_args();
            int value = 4;
            if (std::sscanf(argument,"%d%c",
                            &value,&end)==1 &&
                value>=-1 && value<=5) ++position;
            else value = 4;
            render3d = value;
            print(images,"Set static 3d rendering mode to %s.",
                  render3d==-1?"bounding-box":
                  render3d==0?"pointwise":render3d==1?"linear":render3d==2?"flat":
                  render3d==3?"flat-shaded":render3d==4?"Gouraud-shaded":
                  render3d==5?"Phong-shaded":"none");
            continue;
          }

          if (!std::strcmp("-moded3d",item)) {
            gmic_substitute_args();
            int value = -1;
            if (std::sscanf(argument,"%d%c",
                            &value,&end)==1 &&
                value>=-1 && value<=5) ++position;
            else value = -1;
            renderd3d = value;
            print(images,"Set dynamic 3d rendering mode to %s.",
                  renderd3d==-1?"bounding-box":
                  renderd3d==0?"pointwise":renderd3d==1?"linear":renderd3d==2?"flat":
                  renderd3d==3?"flat-shaded":renderd3d==4?"Gouraud-shaded":
                  renderd3d==5?"Phong-shaded":"none");
            continue;
          }

          // Map LUT.
          if (!std::strcmp("-map",command)) {
            gmic_substitute_args();
            unsigned int lut_type = 0;
            CImg<unsigned int> ind;
            char sep = 0;
            if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 &&
                sep==']' &&
                (ind=selection2cimg(indices,images.size(),images_names,"-map",true,
                                    false,CImg<char>::empty())).height()==1) {
              print(images,"Map LUT [%u] on image%s.",
                    *ind,
                    gmic_selection);
              const CImg<T> palette = gmic_image_arg(*ind);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],map(palette));
            } else if (std::sscanf(argument,"%u%c",&lut_type,&end)==1 &&
                       lut_type<=7) {
              print(images,"Map %s color LUT on image%s.",
                    lut_type==0?"default":lut_type==1?"HSV":lut_type==2?"lines":lut_type==3?"hot":
                    lut_type==4?"cool":lut_type==5?"jet":lut_type==6?"flag":"cube",
                    gmic_selection);
              const CImg<T>
                palette = lut_type==0?CImg<T>::default_LUT256():lut_type==1?CImg<T>::HSV_LUT256():
                lut_type==2?CImg<T>::lines_LUT256():lut_type==3?CImg<T>::hot_LUT256():
                lut_type==4?CImg<T>::cool_LUT256():lut_type==5?CImg<T>::jet_LUT256():
                lut_type==6?CImg<T>::flag_LUT256():CImg<T>::cube_LUT256();
              cimg_forY(selection,l) gmic_apply(images[selection[l]],map(palette));
            } else arg_error("map");
            is_released = false; ++position; continue;
          }

          // Median filter.
          if (!std::strcmp("-median",command)) {
            gmic_substitute_args();
            float siz = 3;
            if (std::sscanf(argument,"%f%c",
                            &siz,&end)==1 &&
                siz>=0) {
              siz = cimg::round(siz);
              print(images,"Apply median filter of size %g, on image%s.",
                    siz,
                    gmic_selection);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],blur_median((unsigned int)siz));
            } else arg_error("median");
            is_released = false; ++position; continue;
          }

          // Matrix division.
          gmic_arithmetic_item("-mdiv",
                               operator/=,
                               "Divide matrix/vector%s by %g%s",
                               gmic_selection,value,ssep,Tfloat,
                               operator/=,
                               "Divide matrix/vector%s by matrix/vector image [%d]",
                               gmic_selection,ind[0],
                               "Divide matrix/vector%s by expression %s",
                               gmic_selection,argument_text,
                               "Divide matrix/vector%s");

          // MSE.
          if (!std::strcmp("-mse",command)) {
            print(images,"Compute the %dx%d matrix of MSE values, from image%s.",
                  selection.height(),selection.height(),
                  gmic_selection);
            if (selection) {
              CImgList<T> subimages(selection.height());
              cimg_forY(selection,l) subimages[l].assign(gmic_check(images[selection[l]]),true);
              CImg<T> img(subimages.size(),subimages.size(),1,1,(T)0);
              cimg_forXY(img,x,y) if (x>y) img(x,y) = img(y,x) = (T)subimages[x].MSE(subimages[y]);
              CImg<char> name = CImg<char>::string("[MSE]");
              if (is_get_version) {
                img.move_to(images);
                name.move_to(images_names);
              } else {
                remove_images(images,images_names,selection,1,selection.height()-1);
                img.move_to(images[selection[0]].assign());
                name.move_to(images_names[selection[0]]);
              }
            }
            is_released = false; continue;
          }

          // Draw mandelbrot/julia fractal.
          if (!std::strcmp("-mandelbrot",command)) {
            gmic_substitute_args();
            double z0r = -2, z0i = -2, z1r = 2, z1i = 2, paramr = 0, parami = 0;
            unsigned int is_julia = 0;
            float opacity = 1, itermax = 100;
            if ((std::sscanf(argument,"%lf,%lf,%lf,%lf%c",
                             &z0r,&z0i,&z1r,&z1i,&end)==4 ||
                 std::sscanf(argument,"%lf,%lf,%lf,%lf,%f%c",
                             &z0r,&z0i,&z1r,&z1i,&itermax,&end)==5 ||
                 std::sscanf(argument,"%lf,%lf,%lf,%lf,%f,%u%c",
                             &z0r,&z0i,&z1r,&z1i,&itermax,&is_julia,&end)==6 ||
                 std::sscanf(argument,"%lf,%lf,%lf,%lf,%f,%u,%lf,%lf%c",
                             &z0r,&z0i,&z1r,&z1i,&itermax,&is_julia,&paramr,
                             &parami,&end)==8 ||
                 std::sscanf(argument,"%lf,%lf,%lf,%lf,%f,%u,%lf,%lf,%f%c",
                             &z0r,&z0i,&z1r,&z1i,&itermax,&is_julia,
                             &paramr,&parami,&opacity,&end)==9) &&
                itermax>=0 && is_julia<=1) {
              itermax = cimg::round(itermax);
              print(images,"Draw %s fractal on image%s, from complex area (%g,%g)-(%g,%g) "
                    "with c0 = (%g,%g) and %g iterations.",
                    is_julia?"julia":"mandelbrot",
                    gmic_selection,
                    z0r,z0i,
                    z1r,z1i,
                    paramr,parami,
                    itermax);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],draw_mandelbrot(CImg<T>(),opacity,z0r,z0i,z1r,z1i,
                                                                (unsigned int)itermax,true,
                                                                (bool)is_julia,
                                                                paramr,parami));
            } else arg_error("mandelbrot");
            is_released = false; ++position; continue;
          }

#endif // #ifdef gmic_float
# 7583 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='m'.

        //----------------------------
        // Commands starting by '-n..'
        //----------------------------
        else if (command1=='n') {

          // Set image name.
          if (!std::strcmp("-name",command) && !is_get_version) {
            gmic_substitute_args();
            const unsigned int l = std::strlen(argument);
            CImg<char> name(argument,l+1);
            unsigned int is_modified=0;
            if (l>=2 && name[l-2]==',' && (name[l-1]=='0' || name[l-1]=='1')) {
              is_modified = name[l-1]!='0';
              name[l-2] = 0;
            }
            print(images,"Set name of image%s to '%s'%s.",
                  gmic_selection,name.data(),is_modified?" (modified)":"");
            gmic_strreplace(name);
            if (is_modified) name.mark();
            cimg_forY(selection,l) images_names[selection[l]].assign(name);
            ++position; continue;
          }

#ifdef gmic_float

          // Normalize.
          if (!std::strcmp("-normalize",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind0, ind1;
            double value0 = 0, value1 = 0;
            char sep0 = 0, sep1 = 0;
            *argx = *argy = 0;
            if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                            argx,argy,&end)==2 &&
                ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep0,&end)==2 &&
                  sep0==']' &&
                  (ind0=selection2cimg(indices,images.size(),images_names,"-normalize",true,
                                       false,CImg<char>::empty())).height()==1) ||
                 (std::sscanf(argx,"%lf%c%c",&value0,&sep0,&end)==2 && sep0=='%') ||
                 std::sscanf(argx,"%lf%c",&value0,&end)==1) &&
                ((std::sscanf(argy,"[%255[a-zA-Z0-9_.%+-]%c%c",formula,&sep1,&end)==2 &&
                  sep1==']' &&
                  (ind1=selection2cimg(formula,images.size(),images_names,"-normalize",true,
                                       false,CImg<char>::empty())).height()==1) ||
                 (std::sscanf(argy,"%lf%c%c",&value1,&sep1,&end)==2 && sep1=='%') ||
                 std::sscanf(argy,"%lf%c",&value1,&end)==1)) {
              if (ind0) { value0 = images[*ind0].min(); sep0 = 0; }
              if (ind1) { value1 = images[*ind1].max(); sep1 = 0; }
              print(images,"Normalize image%s in range [%g%s,%g%s].",
                    gmic_selection,
                    value0,sep0=='%'?"%":"",
                    value1,sep1=='%'?"%":"");
              cimg_forY(selection,l) {
                CImg<T>& img = gmic_check(images[selection[l]]);
                double vmin = 0, vmax = 0, nvalue0 = value0, nvalue1 = value1;
                if (sep0=='%' || sep1=='%') {
                  if (img) vmax = (double)img.max_min(vmin);
                  if (sep0=='%') nvalue0 = vmin + (vmax-vmin)*value0/100;
                  if (sep1=='%') nvalue1 = vmin + (vmax-vmin)*value1/100;
                }
                gmic_apply(img,normalize((T)nvalue0,(T)nvalue1));
              }
            } else if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep0,&end)==2 &&
                       sep0==']' &&
                       (ind0=selection2cimg(indices,images.size(),images_names,"-normalize",true,
                                            false,CImg<char>::empty())).height()==1) {
              if (images[*ind0]) value1 = (double)images[*ind0].max_min(value0);
              print(images,"Normalize image%s in range [%g,%g].",
                    gmic_selection,
                    value0,
                    value1);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],normalize((T)value0,(T)value1));
            } else arg_error("normalize");
            is_released = false; ++position; continue;
          }

          // Test difference.
          gmic_arithmetic_item("-neq",
                               operator_neq,
                               "Compute boolean inequality between image%s and %g%s",
                               gmic_selection,value,ssep,T,
                               operator_neq,
                               "Compute boolean inequality between image%s and image [%d]",
                               gmic_selection,ind[0],
                               "Compute boolean inequality between image%s and expression %s'",
                               gmic_selection,argument_text,
                               "Compute boolean inequality between image%s");

          // Add noise.
          if (!std::strcmp("-noise",command)) {
            gmic_substitute_args();
            int noise_type = 0;
            float sigma = 0;
            char sep = 0;
            if ((std::sscanf(argument,"%f%c",
                             &sigma,&end)==1 ||
                 (std::sscanf(argument,"%f%c%c",
                              &sigma,&sep,&end)==2 && sep=='%') ||
                 std::sscanf(argument,"%f,%d%c",
                             &sigma,&noise_type,&end)==2 ||
                 (std::sscanf(argument,"%f%c,%d%c",
                              &sigma,&sep,&noise_type,&end)==3 && sep=='%')) &&
                sigma>=0 && noise_type>=0 && noise_type<=4) {
              const char *s_type = noise_type==0?"gaussian":
                noise_type==1?"uniform":
                noise_type==2?"salt&pepper":
                noise_type==3?"poisson":"rice";
              if (sep=='%') sigma = -sigma;
              print(images,"Add %s noise to image%s, with standard deviation %g%s.",
                    s_type,
                    gmic_selection,
                    cimg::abs(sigma),sep=='%'?"%":"");
              cimg_forY(selection,l) gmic_apply(images[selection[l]],noise(sigma,noise_type));
            } else arg_error("noise");
            is_released = false; ++position; continue;
          }

#endif // #ifdef gmic_float
# 7704 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='n'.

        //----------------------------
        // Commands starting by '-o..'
        //----------------------------
        else if (command1=='o') {

          // Output.
          if (!std::strcmp("-output",command) && !is_get_version) {
            gmic_substitute_args();
            char cext[8];
            CImg<char> _filename(4096), filename_tmp(1024), options(256);
            *cext = *_filename = *filename_tmp = *options = 0;
            if (std::sscanf(argument,"%8[a-zA-Z]:%4095[^,],%255s",cext,_filename.data(),options.data())<2 ||
                !cext[1]) {  // length of 'ext' must be >=2 (avoid case 'C:\\..' on Windows).
              *cext = *_filename = *options = 0;
              if (std::sscanf(argument,"%4095[^,],%255s",_filename.data(),options.data())!=2) {
                std::strncpy(_filename,argument,_filename.width()-1);
                _filename[_filename.width()-1] = 0;
              }
            }
            gmic_strreplace(_filename);
            gmic_strreplace(options);

            if (*cext) { // Force output to be written as a '.ext' file : generate random filename.
              if (*_filename=='-' && (!_filename[1] || _filename[1]=='.')) {
                // Simplify filename 'ext:-.foo' as '-.ext'.
                cimg_snprintf(_filename,_filename.width(),"-.%s",cext);
                *cext = 0;
              } else {
                std::FILE *file = 0;
                do {
                  cimg_snprintf(filename_tmp,filename_tmp.width(),"%s%c%s.%s",
                                cimg::temporary_path(),cimg_file_separator,
                                cimg::filenamerand(),cext);
                  if ((file=std::fopen(filename_tmp,"rb"))!=0) std::fclose(file);
                } while (file);
              }
            }
            const char
              *const filename = *cext?filename_tmp:_filename,
              *const ext = cimg::split_filename(filename);

            if (!cimg::strcasecmp(ext,"off")) {
              CImg<char> nfilename(4096);
              *nfilename = 0;
              std::strncpy(nfilename,filename,nfilename.width()-1);
              nfilename[nfilename.width()-1] = 0;
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                const CImg<T>& img = gmic_check(images[ind]);
                if (selection.height()!=1) cimg::number_filename(filename,l,6,nfilename);
                CImgList<unsigned int> primitives;
                CImgList<float> colors, opacities;
                CImg<float> vertices(img,false);
                try {
                  vertices.CImg3dtoobject3d(primitives,colors,opacities,false).
                    save_off(primitives,colors,nfilename);
                } catch (CImgException &e) {
                  if (!vertices.is_CImg3d(true,message))
                    error(images,
                          "Command '-output': 3d object file '%s', invalid 3d object [%u] "
                          "in selected image%s (%s).",
                          nfilename.data(),ind,gmic_selection,message);
                  else throw e;
                }
                print(images,"Output 3d object [%u] as file '%s'.",
                      ind,
                      nfilename.data());
              }
            } else if (!cimg::strcasecmp(ext,"tiff") || !cimg::strcasecmp(ext,"tif")) {
              float _compression = 0;
              if (std::sscanf(options,"%f%c",&_compression,&end)!=1) _compression = 0;
              if (_compression<0) _compression = 0; else if (_compression>6) _compression = 6;
              const unsigned int compression = (unsigned int)cimg::round(_compression);
              CImgList<T> output_images(selection.height());
              CImgList<unsigned int> empty_indices;
              cimg_forY(selection,l) if (!gmic_check(images[selection(l)]))
                CImg<unsigned int>::vector(selection(l)).move_to(empty_indices);
              if (empty_indices) {
                const CImg<char> _eselec = selection2string(empty_indices>'y',images_names,true);
                const char *const eselec = _eselec.data();
                warn(images,"Command '-output': Image%s %s empty.",
                     eselec,empty_indices.size()>1?"are":"is");
              }
              cimg_forY(selection,l)
                output_images[l].assign(images[selection[l]],output_images[l]?true:false);
              if (output_images.size()==1)
                print(images,"Output image%s as file '%s', with %s compression "
                      "(1 image %dx%dx%dx%d).",
                      gmic_selection,
                      _filename.data(),
                      compression==0?"no":compression==1?"CCITTRLE":compression==2?"CCITT4":
                      compression==3?"CCITT6":compression==4?"LZW":compression==5?"JPEG1":"JPEG2",
                      output_images[0].width(),output_images[0].height(),
                      output_images[0].depth(),output_images[0].spectrum());
              else print(images,"Output image%s as file '%s', with %s compression.",
                         gmic_selection,
                         _filename.data(),
                         compression==0?"no":compression==1?"CCITTRLE":compression==2?"CCITT4":
                         compression==3?"CCITT6":compression==4?"LZW":compression==5?"JPEG1":
                         "JPEG2");
              if (!output_images)
                error(images,"Command '-output': File '%s', instance list (%u,%p) is empty.",
                      _filename.data(),output_images.size(),output_images.data());
              if (output_images.size()==1) output_images[0].save_tiff(filename,compression);
              else output_images.save_tiff(filename,compression);
            } else if (!cimg::strcasecmp(ext,"gif")) {
              float _fps = 0, _nb_loops = 0;
              CImgList<T> output_images(selection.height());
              CImgList<unsigned int> empty_indices;
              cimg_forY(selection,l) if (!gmic_check(images[selection(l)]))
                CImg<unsigned int>::vector(selection(l)).move_to(empty_indices);
              if (empty_indices) {
                const CImg<char> _eselec = selection2string(empty_indices>'y',images_names,true);
                const char *const eselec = _eselec.data();
                warn(images,"Command '-output': Image%s %s empty.",
                     eselec,empty_indices.size()>1?"are":"is");
              }
              cimg_forY(selection,l)
                output_images[l].assign(images[selection[l]],output_images[l]?true:false);
              if (output_images.size()>1 && std::sscanf(options,"%f,%f",&_fps,&_nb_loops)>=1) {
                // Save animated .gif file.
                const unsigned int
                  fps = (unsigned int)cimg::round(_fps),
                  nb_loops = (unsigned int)cimg::round(_nb_loops);
                if (nb_loops)
                  print(images,
                        "Output image%s as animated file '%s', with %u fps and %u loops.",
                        gmic_selection,_filename.data(),fps,nb_loops);
                else
                  print(images,
                        "Output image%s as animated file '%s', with %u fps.",
                        gmic_selection,_filename.data(),fps);
                output_images.save_gif_external(filename,fps,nb_loops);
              } else {
                if (output_images.size()==1)
                  print(images,"Output image%s as file '%s' (1 image %dx%dx%dx%d).",
                        gmic_selection,
                        _filename.data(),
                        output_images[0].width(),output_images[0].height(),
                        output_images[0].depth(),output_images[0].spectrum());
                else print(images,"Output image%s as file '%s'.",
                           gmic_selection,
                           _filename.data());
                output_images.save(filename); // Save distinct .gif files.
              }
            } else if (!cimg::strcasecmp(ext,"jpeg") || !cimg::strcasecmp(ext,"jpg")) {
              float quality = 100;
              if (std::sscanf(options,"%f%c",&quality,&end)!=1) quality = 100;
              if (quality<0) quality = 0; else if (quality>100) quality = 100;
              CImgList<T> output_images(selection.height());
              CImgList<unsigned int> empty_indices;
              cimg_forY(selection,l) if (!gmic_check(images[selection(l)]))
                CImg<unsigned int>::vector(selection(l)).move_to(empty_indices);
              if (empty_indices) {
                const CImg<char> _eselec = selection2string(empty_indices>'y',images_names,true);
                const char *const eselec = _eselec.data();
                warn(images,"Command '-output': Image%s %s empty.",
                     eselec,empty_indices.size()>1?"are":"is");
              }
              cimg_forY(selection,l)
                output_images[l].assign(images[selection[l]],output_images[l]?true:false);
              if (output_images.size()==1)
                print(images,
                      "Output image%s as file '%s', with quality %g%% (1 image %dx%dx%dx%d).",
                      gmic_selection,
                      _filename.data(),
                      quality,
                      output_images[0].width(),output_images[0].height(),
                      output_images[0].depth(),output_images[0].spectrum());
              else print(images,"Output image%s as file '%s', with quality %g%%.",
                         gmic_selection,
                         _filename.data(),
                         quality);
              if (!output_images)
                error(images,"Command '-output': File '%s', instance list (%u,%p) is empty.",
                      _filename.data(),output_images.size(),output_images.data());
              if (output_images.size()==1)
                output_images[0].save_jpeg(filename,(unsigned int)cimg::round(quality));
              else {
                CImg<char> nfilename(4096);
                cimglist_for(output_images,l) {
                  cimg::number_filename(filename,l,6,nfilename);
                  output_images[l].save_jpeg(nfilename,(unsigned int)cimg::round(quality));
                }
              }
            } else if (!cimg::strcasecmp(ext,"mnc") && *options) {
              CImgList<T> output_images(selection.height());
              CImgList<unsigned int> empty_indices;
              cimg_forY(selection,l) if (!gmic_check(images[selection(l)]))
                CImg<unsigned int>::vector(selection(l)).move_to(empty_indices);
              if (empty_indices) {
                const CImg<char> _eselec = selection2string(empty_indices>'y',images_names,true);
                const char *const eselec = _eselec.data();
                warn(images,"Command '-output': Image%s %s empty.",
                     eselec,empty_indices.size()>1?"are":"is");
              }
              cimg_forY(selection,l)
                output_images[l].assign(images[selection[l]],output_images[l]?true:false);
              if (output_images.size()==1)
                print(images,
                      "Output image%s as file '%s', with header get from file '%s' "
                      "(1 image %dx%dx%dx%d).",
                      gmic_selection,
                      _filename.data(),
                      options.data(),
                      output_images[0].width(),output_images[0].height(),
                      output_images[0].depth(),output_images[0].spectrum());
              else
                print(images,
                      "Output image%s as file '%s', with header get from file '%s'.",
                      gmic_selection,
                      _filename.data(),
                      options.data());
              if (output_images.size()==1)
                output_images[0].save_minc2(filename,options);
              else {
                CImg<char> nfilename(4096);
                cimglist_for(output_images,l) {
                  cimg::number_filename(filename,l,6,nfilename);
                  output_images[l].save_minc2(nfilename,options);
                }
              }
            } else if (!cimg::strcasecmp(ext,"raw")) {
              const char *const stype = std::sscanf(options,"%255[A-zA-Z]%c",argx,&end)==1?argx:
                cimg::type<T>::string();
              CImgList<T> output_images(selection.height());
              CImgList<unsigned int> empty_indices;
              cimg_forY(selection,l) if (!gmic_check(images[selection(l)]))
                CImg<unsigned int>::vector(selection(l)).move_to(empty_indices);
              if (empty_indices) {
                const CImg<char> _eselec = selection2string(empty_indices>'y',images_names,true);
                const char *const eselec = _eselec.data();
                warn(images,"Command '-output': Image%s %s empty.",
                     eselec,empty_indices.size()>1?"are":"is");
              }
              cimg_forY(selection,l)
                output_images[l].assign(images[selection[l]],images[selection[l]]?true:false);
              if (output_images.size()==1)
                print(images,
                      "Output image%s as file '%s', with pixel type '%s' (1 image %dx%dx%dx%d).",
                      gmic_selection,
                      _filename.data(),
                      stype,
                      output_images[0].width(),output_images[0].height(),
                      output_images[0].depth(),output_images[0].spectrum());
              else print(images,"Output image%s as file '%s', with pixel type '%s'.",
                         gmic_selection,
                         _filename.data(),
                         stype);
              if (!output_images)
                error(images,"Command '-output': File '%s', instance list (%u,%p) is empty.",
                      _filename.data(),output_images.size(),output_images.data());

#define gmic_save_raw(value_type,svalue_type)                           \
              if (!std::strcmp(stype,svalue_type)) {                    \
                if (output_images.size()==1)                            \
                  CImg<value_type>(output_images[0]).save_raw(filename); \
                else {                                                  \
                  CImg<char> nfilename(4096);                           \
                  cimglist_for(output_images,l) {                       \
                    cimg::number_filename(filename,l,6,nfilename);      \
                    CImg<value_type>(output_images[l]).save_raw(nfilename); \
                  }                                                     \
                }                                                       \
              }
              gmic_save_raw(bool,"bool")
              else gmic_save_raw(unsigned char,"uchar")
                else gmic_save_raw(unsigned char,"unsigned char")
                  else gmic_save_raw(char,"char")
                    else gmic_save_raw(unsigned short,"ushort")
                      else gmic_save_raw(unsigned short,"unsigned short")
                        else gmic_save_raw(short,"short")
                          else gmic_save_raw(unsigned int,"uint")
                            else gmic_save_raw(unsigned int,"unsigned int")
                              else gmic_save_raw(int,"int")
                                else gmic_save_raw(float,"float")
                                  else gmic_save_raw(double,"double")
                                    else error(images,
                                               "Command '-output': File '%s', invalid specified "
                                               "pixel type '%s'.",
                                               _filename.data(),stype);
            } else
              if (!cimg::strcasecmp(ext,"avi") || !cimg::strcasecmp(ext,"mov") ||
                  !cimg::strcasecmp(ext,"asf") || !cimg::strcasecmp(ext,"divx") ||
                  !cimg::strcasecmp(ext,"flv") || !cimg::strcasecmp(ext,"mpg") ||
                  !cimg::strcasecmp(ext,"m1v") || !cimg::strcasecmp(ext,"m2v") ||
                  !cimg::strcasecmp(ext,"m4v") || !cimg::strcasecmp(ext,"mjp") ||
                  !cimg::strcasecmp(ext,"mkv") || !cimg::strcasecmp(ext,"mpe") ||
                  !cimg::strcasecmp(ext,"movie") || !cimg::strcasecmp(ext,"ogm") ||
                  !cimg::strcasecmp(ext,"qt") || !cimg::strcasecmp(ext,"rm") ||
                  !cimg::strcasecmp(ext,"vob") || !cimg::strcasecmp(ext,"wmv") ||
                  !cimg::strcasecmp(ext,"xvid") || !cimg::strcasecmp(ext,"mpeg") ||
                  !cimg::strcasecmp(ext,"ogg")) {
                float fps = 0, bitrate = 0;
                std::sscanf(options,"%f,%f",&fps,&bitrate);
                fps = cimg::round(fps);
                bitrate = cimg::round(bitrate);
                if (!fps) fps = 25;
                if (!bitrate) bitrate = 2048;
                CImgList<T> output_images(selection.height());
                CImgList<unsigned int> empty_indices;
                cimg_forY(selection,l) if (!gmic_check(images[selection(l)]))
                  CImg<unsigned int>::vector(selection(l)).move_to(empty_indices);
                if (empty_indices) {
                  const CImg<char> _eselec = selection2string(empty_indices>'y',images_names,true);
                  const char *const eselec = _eselec.data();
                  warn(images,"Command '-output': Image%s %s empty.",
                       eselec,empty_indices.size()>1?"are":"is");
                }
                cimg_forY(selection,l)
                  output_images[l].assign(images[selection[l]],output_images[l]?true:false);
                print(images,"Output image%s as file '%s', with %g fps and bitrate %gk.",
                      gmic_selection,
                      _filename.data(),
                      fps,bitrate);
                if (!output_images)
                  error(images,"Command '-output': File '%s, instance list (%u,%p) is empty.",
                        _filename.data(),output_images.size(),output_images.data());
                output_images.save_ffmpeg(filename,(unsigned int)fps,(unsigned int)bitrate);
              } else {
                CImgList<T> output_images(selection.height());
                CImgList<unsigned int> empty_indices;
                cimg_forY(selection,l) if (!gmic_check(images[selection(l)]))
                  CImg<unsigned int>::vector(selection(l)).move_to(empty_indices);
                if (empty_indices) {
                  const CImg<char> _eselec = selection2string(empty_indices>'y',images_names,true);
                  const char *const eselec = _eselec.data();
                  warn(images,"Command '-output': Image%s %s empty.",
                       eselec,empty_indices.size()>1?"are":"is");
                }
                cimg_forY(selection,l)
                  output_images[l].assign(images[selection[l]],output_images[l]?true:false);
                if (output_images.size()==1)
                  print(images,"Output image%s as file '%s' (1 image %dx%dx%dx%d).",
                        gmic_selection,
                        _filename.data(),
                        output_images[0].width(),output_images[0].height(),
                        output_images[0].depth(),output_images[0].spectrum());
                else print(images,"Output image%s as file '%s'.",
                           gmic_selection,
                           _filename.data());
                output_images.save(filename);
              }

            if (*cext) { // When output forced to 'ext' : copy final file to specified location.
              try {
                CImg<unsigned char>::get_load_raw(filename_tmp).save_raw(_filename);
                std::remove(filename_tmp);
              } catch (...) {
                error(images,
                      "Command '-output': Invalid write of file '%s from temporary file '%s'.",
                      _filename.data(),filename_tmp.data());
              }
            }
            is_released = true; ++position; continue;
          }

          // Exception handling in local environments.
          if (!std::strcmp("-onfail",item)) {
            const CImg<char> &s = scope.back();
            if (s[0]!='*' || s[1]!='l')
              error(images,"Command '-onfail': Not associated to a '-local' command within "
                    "the same scope.");
            for (int nb_locals = 1; nb_locals && position<commands_line.size(); ++position) {
              const char *const it = commands_line[position].data();
              if (!std::strcmp("-local",it) || !std::strcmp("-l",it) ||
                  !std::strcmp("--local",it) || !std::strcmp("--l",it) ||
                  !std::strncmp("-local[",it,7) || !std::strncmp("-l[",it,3) ||
                  !std::strncmp("--local[",it,8) || !std::strncmp("--l[",it,4)) ++nb_locals;
              else if (!std::strcmp("-endlocal",it) || !std::strcmp("-endl",it)) {
                --nb_locals; if (!nb_locals) --position;
              }
            }
            continue;
          }

#ifdef gmic_float

          // Draw 3d object.
          if (!std::strcmp("-object3d",command)) {
            gmic_substitute_args();
            float x = 0, y = 0, z = 0, opacity = 1;
            char sep = 0, sepx = 0, sepy = 0;
            unsigned int
              is_zbuffer = 1,
              _render3d = (unsigned int)cimg::max(0,render3d),
              _is_double3d = is_double3d?1:0;
            float
              _focale3d = focale3d,
              _light3d_x = light3d_x,
              _light3d_y = light3d_y,
              _light3d_z = light3d_z,
              _specular_lightness3d = specular_lightness3d,
              _specular_shininess3d = specular_shininess3d;
            CImg<unsigned int> ind;
            *argx = *argy = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                              indices,&sep,&end)==2 && sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-]%c",
                             indices,argx,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             indices,argx,argy,&end)==3 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%f%c",
                             indices,argx,argy,&z,&end)==4 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%f,%f%c",
                             indices,argx,argy,&z,&opacity,&end)==5 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%f,%f,%u%c",
                             indices,argx,argy,&z,&opacity,&_render3d,&end)==6 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%f,%f,%u,%u%c",
                             indices,argx,argy,&z,&opacity,&_render3d,&_is_double3d,&end)==7 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%f,%f,%u,%u,%u%c",
                             indices,argx,argy,&z,&opacity,&_render3d,&_is_double3d,&is_zbuffer,
                             &end)==8 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%f,%f,%u,%u,%u,%f%c",
                             indices,argx,argy,&z,&opacity,&_render3d,&_is_double3d,&is_zbuffer,
                             &_focale3d,&end)==9 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%f,%f,%u,%u,%u,%f,%f,%f,%f%c",
                             indices,argx,argy,&z,&opacity,&_render3d,&_is_double3d,&is_zbuffer,
                             &_focale3d,&_light3d_x,&_light3d_y,&_light3d_z,&end)==12 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%f,%f,%u,%u,%u,%f,%f,%f,%f,%f,%f%c",
                             indices,argx,argy,&z,&opacity,&_render3d,&_is_double3d,&is_zbuffer,
                             &_focale3d,&_light3d_x,&_light3d_y,&_light3d_z,
                             &_specular_lightness3d,&_specular_shininess3d,&end)==14) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-object3d",true,
                                    false,CImg<char>::empty())).height()==1 &&
                (!*argx ||
                 std::sscanf(argx,"%f%c",&x,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&x,&sepx,&end)==2 && sepx=='%')) &&
                (!*argy ||
                 std::sscanf(argy,"%f%c",&y,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&y,&sepy,&end)==2 && sepy=='%')) &&
                _render3d<=5 && is_zbuffer<=1 && _is_double3d<=1) {
              const CImg<T> img0 = gmic_image_arg(*ind);

              print(images,"Draw 3d object [%u] at (%g%s,%g%s,%g) on image%s, with opacity %g, "
                    "%s rendering, %s-sided mode, %sz-buffer, focale %g, 3d light at (%g,%g,%g) "
                    "and specular properties (%g,%g)",
                    *ind,
                    x,sepx=='%'?"%":"",
                    y,sepy=='%'?"%":"",
                    z,
                    gmic_selection,
                    opacity,
                    _render3d==0?"dot":_render3d==1?"wireframe":_render3d==2?"flat":
                    _render3d==3?"flat-shaded":_render3d==4?"gouraud-shaded":"phong-shaded",
                    _is_double3d?"double":"simple",
                    is_zbuffer?"":"no ",
                    _focale3d,_light3d_x,_light3d_y,_light3d_z,
                    _specular_lightness3d,_specular_shininess3d);
              CImgList<unsigned int> primitives;
              CImgList<float> colors, opacities;
              CImgList<unsigned char> _colors;  // 'uchar' colors when rendering with light.
              CImg<float> vertices(img0,false);
              try {
                if (_render3d>=3) {
                  vertices.CImg3dtoobject3d(primitives,_colors,opacities,false);
                  if (light3d) _colors.insert(light3d,~0U,true);
                } else vertices.CImg3dtoobject3d(primitives,colors,opacities,false);
              }
              catch (CImgException &e) {
                if (!vertices.is_CImg3d(true,message))
                  error(images,"Command '-object3d': Invalid 3d object [%u], specified "
                        "in argument '%s' (%s).",
                        *ind,argument_text,message);
                else throw e;
              }
              cimglist_for(opacities,o) if (!opacities[o].is_shared()) opacities[o]*=opacity;

              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const float
                  nx = sepx=='%'?x*(img.width()-1)/100:x,
                  ny = sepy=='%'?y*(img.height()-1)/100:y;
                CImg<float> zbuffer(is_zbuffer?img.width():0,is_zbuffer?img.height():0,1,1,0);
                if (colors) {
                  gmic_apply(img,draw_object3d(nx,ny,z,vertices,primitives,colors,opacities,
                                               _render3d,_is_double3d,_focale3d,
                                               _light3d_x,_light3d_y,_light3d_z,
                                               _specular_lightness3d,_specular_shininess3d,
                                               zbuffer));
                } else {
                  gmic_apply(img,draw_object3d(nx,ny,z,vertices,primitives,_colors,opacities,
                                               _render3d,_is_double3d,_focale3d,
                                               _light3d_x,_light3d_y,_light3d_z,
                                               _specular_lightness3d,_specular_shininess3d,
                                               zbuffer));
                }
              }
            } else arg_error("object3d");
            is_released = false; ++position; continue;
          }

          // Bitwise or.
          gmic_arithmetic_item("-or",
                               operator|=,
                               "Compute bitwise OR of image%s by %g%s",
                               gmic_selection,value,ssep,Tlong,
                               operator|=,
                               "Compute bitwise OR of image%s by image [%d]",
                               gmic_selection,ind[0],
                               "Compute bitwise OR of image%s by expression %s",
                               gmic_selection,argument_text,
                               "Compute sequential bitwise OR of image%s");

          // Set 3d object opacity.
          if (!std::strcmp("-opacity3d",command)) {
            gmic_substitute_args();
            float value = 1;
            if (std::sscanf(argument,"%f%c",
                            &value,&end)==1) ++position;
            else value = 1;
            print(images,"Set opacity of 3d object%s to %g.",
                  gmic_selection,
                  value);
            cimg_forY(selection,l) {
              const unsigned int ind = selection[l];
              CImg<T>& img = gmic_check(images[ind]);
              try { gmic_apply(img,color_CImg3d(0,0,0,value,false,true)); }
              catch (CImgException &e) {
                if (!img.is_CImg3d(true,message))
                  error(images,"Command '-opacity3d': Invalid 3d object [%d], "
                        "in selected image%s (%s).",
                        ind,gmic_selection,message);
                else throw e;
              }
            }
            is_released = false; continue;
          }

#endif // #ifdef gmic_float
# 8244 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='o'.

        //----------------------------
        // Commands starting by '-p..'
        //----------------------------
        else if (command1=='p') {

          // Run multiple commands in parallel.
          if (!std::strcmp("-parallel",item)) {
            gmic_substitute_args();
            const char *_arg = argument, *_arg_text = argument_text;
            unsigned int wait_mode = 2;
            if ((*_arg=='0' || *_arg=='1' || *_arg=='2') && (_arg[1]==',' || !_arg[1])) {
              wait_mode = (unsigned int)(*_arg-'0'); _arg+=2; _arg_text+=2;
            }
            CImgList<char> arguments = CImg<char>::string(_arg).get_split(',',false,false);
            CImg<st_gmic_parallel<T> >(1,arguments.width()).move_to(threads_data);
            CImg<st_gmic_parallel<T> > &_threads_data = threads_data.back();

#ifdef gmic_is_parallel
            print(images,"Execute %d command%s '%s' in parallel%s.",
                  arguments.width(),arguments.width()>1?"s":"",_arg_text,
                  wait_mode==2?(arguments.width()>1?" and wait immediately they finish":
                                " and wait immediately it finishes"):
                  wait_mode==1?" and defer thread waiting at return point":"");
#else
# 8270 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            print(images,"Execute %d commands '%s' (run sequentially, "
                  "parallel computing disabled).",
                  arguments.width(),_arg_text);
#endif // #ifdef gmic_is_parallel
# 8274 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

            cimg_forY(_threads_data,l) {
              gmic &gi = _threads_data[l].gmic_instance;
              for (unsigned int i = 0; i<256; ++i) {
                gi.commands[i].assign(commands[i],true);
                gi.commands_names[i].assign(commands_names[i],true);
                gi.commands_has_arguments[i].assign(commands_has_arguments[i],true);
                gi.variables[i] = &gi._variables[i];
                gi.variables_names[i] = &gi._variables_names[i];
                _threads_data[l].variables_sizes[i] = 0;
              }

              gi.variables[255] = variables[255];  // Share global variables between all threads.
              gi.variables_names[255] = variables_names[255];
              gi.scope.assign(scope);
              gi.commands_files.assign(commands_files,true);
              cimg_snprintf(title,_title.size(),"*thread%d",l);
              CImg<char>::string(title).move_to(gi.scope);
              gi.background3d.assign(background3d);
              gi.light3d.assign(light3d);
              gi.pose3d.assign(pose3d);
              gi.status.assign(status);
              gi.debug_filename = debug_filename;
              gi.debug_line = debug_line;
              gi.focale3d = focale3d;
              gi.light3d_x = light3d_x;
              gi.light3d_y = light3d_y;
              gi.light3d_z = light3d_z;
              gi.specular_lightness3d = specular_lightness3d;
              gi.specular_shininess3d = specular_shininess3d;
              gi._progress = 0;
              gi.progress = &gi._progress;
              gi.is_released = is_released;
              gi.is_debug = is_debug;
              gi.is_start = false;
              gi.is_quit = false;
              gi.is_return = false;
              gi.is_double3d = is_double3d;
              gi.is_default_type = is_default_type;
              gi.check_elif = false;
              gi.verbosity = verbosity;
              gi.render3d = render3d;
              gi.renderd3d = renderd3d;
              gi._cancel = _cancel;
              gi.cancel = cancel;
              gi.nb_carriages = nb_carriages;
              gi.reference_time = reference_time;
              _threads_data[l].images = &images;
              _threads_data[l].images_names = &images_names;
              _threads_data[l].wait_mode = wait_mode;

              // Substitute special characters codes appearing outside strings.
              arguments[l].resize(1,arguments[l].height()+1,1,1,0);
              bool is_dquoted = false;
              for (char *s = arguments[l].data(); *s; ++s) {
                const char c = *s;
                if (c=='\"') is_dquoted = !is_dquoted;
                if (!is_dquoted) *s = c<' '?(c==_dollar?'$':c==_lbrace?'{':c==_rbrace?'}':
                                             c==_comma?',':c==_dquote?'\"':c==_arobace?'@':c):c;
              }
              gi.commands_line_to_CImgList(arguments[l].data()).
               move_to(_threads_data[l].commands_line);

#ifdef gmic_is_parallel
#if cimg_OS!=2
              pthread_create(&_threads_data[l].thread_id,0,gmic_parallel<T>,
                             (void*)&_threads_data[l]);
#else
# 8342 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
              _threads_data[l].thread_id = CreateThread(0,0,gmic_parallel<T>,
                                                        (void*)&_threads_data[l],0,0);
#endif // #if cimg_OS!=2
# 8345 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#else
# 8346 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
              gmic_parallel<T>((void*)&_threads_data[l]);

#endif // #ifdef gmic_is_parallel
# 8349 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
          }

            if (wait_mode==2) { // Wait for thread termination.
              cimg_forY(_threads_data,l) {
#ifdef gmic_is_parallel
#if cimg_OS!=2
                pthread_join(_threads_data[l].thread_id,0);
#else
# 8357 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
                WaitForSingleObject(_threads_data[l].thread_id,INFINITE);
                CloseHandle(_threads_data[l].thread_id);
#endif // #if cimg_OS!=2
# 8360 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#endif // #ifdef gmic_is_parallel
# 8361 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
                is_released&=_threads_data[l].gmic_instance.is_released;
              }

              // Get status modified by first thread.
              _threads_data[0].gmic_instance.status.move_to(status);

              // Check for possible exceptions thrown by threads.
              cimg_forY(_threads_data,l) if (_threads_data[l].exception._message)
                throw _threads_data[l].exception;

              threads_data.remove();
            }

            ++position; continue;
          }

          // Permute axes.
          if (!std::strcmp("-permute",command)) {
            gmic_substitute_args();
            print(images,"Permute axes of image%s, with permutation '%s'.",
                  gmic_selection,argument_text);
            cimg_forY(selection,l) gmic_apply(images[selection[l]],permute_axes(argument));
            is_released = false; ++position; continue;
          }

          // Set progress indice.
          if (!std::strcmp("-progress",item)) {
            gmic_substitute_args();
            float value = -1;
            if (std::sscanf(argument,"%f%c",
                            &value,&end)==1) {
              if (value<0) value = -1; else if (value>100) value = 100;
              if (value>=0)
                print(images,"Set progress indice to %g%%.",
                      value);
              else
                print(images,"Disable progress indice.");
              *progress = value;
            } else arg_error("progress");
            ++position; continue;
          }

          // Print.
          if (!std::strcmp("-print",command) && !is_get_version) {
            print_images(images,images_names,selection);
            is_released = true; continue;
          }

#ifdef gmic_float

          // Power.
          gmic_arithmetic_item("-pow",
                               pow,
                               "Compute image%s to the power of %g%s",
                               gmic_selection,value,ssep,Tfloat,
                               pow,
                               "Compute image%s to the power of image [%d]",
                               gmic_selection,ind[0],
                               "Compute image%s to the power of expression %s",
                               gmic_selection,argument_text,
                               "Compute sequential power of image%s");

          // Draw point.
          if (!std::strcmp("-point",command)) {
            gmic_substitute_args();
            float x = 0, y = 0, z = 0, opacity = 1;
            char sepx = 0, sepy = 0, sepz = 0;
            *argx = *argy = *argz = *color = 0;
            if ((std::sscanf(argument,"%255[0-9.eE%+-]%c",
                             argx,&end)==1 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             argx,argy,&end)==2 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             argx,argy,argz,&end)==3 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f%c",
                             argx,argy,argz,&opacity,&end)==4 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f,"
                             "%4095[0-9.eE,+-]%c",
                             argx,argy,argz,&opacity,color,&end)==5) &&
                (std::sscanf(argx,"%f%c",&x,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&x,&sepx,&end)==2 && sepx=='%')) &&
                (!*argy ||
                 std::sscanf(argy,"%f%c",&y,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&y,&sepy,&end)==2 && sepy=='%')) &&
                (!*argz ||
                 std::sscanf(argz,"%f%c",&z,&end)==1 ||
                 (std::sscanf(argz,"%f%c%c",&z,&sepz,&end)==2 && sepz=='%'))) {
              print(images,
                    "Draw point (%g%s,%g%s,%g%s) on image%s, with opacity %g and color (%s).",
                    x,sepx=='%'?"%":"",
                    y,sepy=='%'?"%":"",
                    z,sepz=='%'?"%":"",
                    gmic_selection,
                    opacity,
                    *color?color:"default");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]], col(img.spectrum(),1,1,1,0);
                col.fill(color,true);
                const int
                  nx = (int)cimg::round(sepx=='%'?x*(img.width()-1)/100:x),
                  ny = (int)cimg::round(sepy=='%'?y*(img.height()-1)/100:y),
                  nz = (int)cimg::round(sepz=='%'?z*(img.depth()-1)/100:z);
                gmic_apply(img,draw_point(nx,ny,nz,col.data(),opacity));
              }
            } else arg_error("point");
            is_released = false; ++position; continue;
          }

          // Draw polygon.
          if (!std::strcmp("-polygon",command)) {
            gmic_substitute_args();
            CImg<char> strint(256);
            *strint = *color = 0;
            float N = 0, x0 = 0, y0 = 0, opacity = 1;
            char sepx = 0, sepy = 0, seph = 0;
            unsigned int pattern = 0;
            if (std::sscanf(argument,"%f%c",
                            &N,&end)==2 && N>=1) {
              N = cimg::round(N);
              const char
                *nargument = argument + cimg_snprintf(strint,strint.width(),"%u",
                                                      (unsigned int)N) + 1,
                *const eargument = argument + std::strlen(argument);
              CImg<float> coords0((unsigned int)N,2,1,1,0);
              CImg<bool> percents((unsigned int)N,2,1,1,0);
              for (unsigned int n = 0; n<(unsigned int)N; ++n) if (nargument<eargument) {
                  sepx = sepy = 0;
                  if (std::sscanf(nargument,"%255[0-9.eE%+-],%255[0-9.eE%+-]",
                                  argx,argy)==2 &&
                      (std::sscanf(argx,"%f%c",&x0,&end)==1 ||
                       (std::sscanf(argx,"%f%c%c",&x0,&sepx,&end)==2 && sepx=='%')) &&
                      (std::sscanf(argy,"%f%c",&y0,&end)==1 ||
                       (std::sscanf(argy,"%f%c%c",&y0,&sepy,&end)==2 && sepy=='%'))) {
                    coords0(n,0) = x0; percents(n,0) = (sepx=='%');
                    coords0(n,1) = y0; percents(n,1) = (sepy=='%');
                    nargument+=std::strlen(argx) + std::strlen(argy) + 2;
                  } else arg_error("polygon");
                } else arg_error("polygon");
              if (nargument<eargument &&
                  std::sscanf(nargument,"%4095[0-9.eE+-]",color)==1 &&
                  std::sscanf(color,"%f",&opacity)==1) {
                nargument+=std::strlen(color) + 1;
                *color = 0;
              }
              if (nargument<eargument &&
                  std::sscanf(nargument,"0%c%4095[0-9a-fA-F]",&seph,color)==2 && seph=='x' &&
                  std::sscanf(color,"%x%c",&pattern,&end)==1) {
                nargument+=std::strlen(color)+3;
                *color = 0;
              }
              const char *const _color = nargument<eargument?nargument:&(end=0);
              if (seph=='x')
                print(images,"Draw %g-vertices outlined polygon on image%s, with opacity %g, "
                      "pattern 0x%x and color (%s).",
                      N,
                      gmic_selection,
                      opacity,pattern,
                      *_color?_color:"default");
              else
                print(images,"Draw %g-vertices filled polygon on image%s, with opacity %g "
                      "and color (%s).",
                      N,
                      gmic_selection,
                      opacity,
                      *_color?_color:"default");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                CImg<int> coords(coords0);
                cimg_forX(coords,p) {
                  if (percents(p,0))
                    coords(p,0) = (int)cimg::round(coords0(p,0)*(img.width()-1)/100);
                  else coords(p,0) = (int)cimg::round(coords(p,0));
                  if (percents(p,1))
                    coords(p,1) = (int)cimg::round(coords0(p,1)*(img.height()-1)/100);
                  else coords(p,1) = (int)cimg::round(coords(p,1));
                }
                CImg<T> col(img.spectrum(),1,1,1,0);
                col.fill(_color,true);
                if (seph=='x') { gmic_apply(img,draw_polygon(coords,col.data(),opacity,pattern)); }
                else { gmic_apply(img,draw_polygon(coords,col.data(),opacity)); }
              }
            } else arg_error("polygon");
            is_released = false; ++position; continue;
          }

          // Draw plasma fractal.
          if (!std::strcmp("-plasma",command)) {
            gmic_substitute_args();
            float alpha = 1, beta = 1, scale = 8;
            if ((std::sscanf(argument,"%f%c",
                             &alpha,&end)==1 ||
                 std::sscanf(argument,"%f,%f%c",
                             &alpha,&beta,&end)==2 ||
                 std::sscanf(argument,"%f,%f,%f%c",
                             &alpha,&beta,&scale,&end)==3) &&
                scale>=0) ++position;
            else { alpha = beta = 1; scale = 8; }
            const unsigned int _scale = (unsigned int)cimg::round(scale);
            print(images,"Draw plasma fractal on image%s, with alpha %g, beta %g and scale %u.",
                  gmic_selection,
                  alpha,
                  beta,
                  _scale);
            cimg_forY(selection,l)
              gmic_apply(images[selection[l]],draw_plasma(alpha,beta,_scale));
            is_released = false; continue;
          }

          // Set 3d pose.
          if (!std::strcmp("-pose3d",item)) {
            gmic_substitute_args();
            CImg<float> _p3d(16,1,1,1,0);
            float *const p3d = _p3d.data();
            if (std::sscanf(argument,"%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f,%f%c",
                            p3d,p3d+1,p3d+2,p3d+3,p3d+4,p3d+5,p3d+6,p3d+7,
                            p3d+8,p3d+9,p3d+10,p3d+11,p3d+12,p3d+13,p3d+14,p3d+15,
                            &end)==16) {
              print(images,"Set 3d pose matrix to [ %g,%g,%g,%g; %g,%g,%g,%g; %g,%g,%g,%g; "
                    "%g,%g,%g,%g ].",
                    p3d[0],p3d[1],p3d[2],p3d[3],
                    p3d[4],p3d[5],p3d[6],p3d[7],
                    p3d[8],p3d[9],p3d[10],p3d[11],
                    p3d[12],p3d[13],p3d[14],p3d[15]);
              pose3d.assign(p3d,4,4,1,1,false);
              ++position;
            } else {
              print(images,"Reset 3d pose matrix to default.");
              pose3d.assign();
            }
            continue;
          }

          // Convert 3d object primitives.
          if (!std::strcmp("-primitives3d",command)) {
            gmic_substitute_args();
            unsigned int mode = 0;
            if (std::sscanf(argument,"%u%c",
                            &mode,&end)==1 &&
                mode<=2) {
              print(images,"Convert primitives of 3d object%s to %s.",
                    gmic_selection,
                    mode==0?"points":mode==1?"segments":"no-textures");
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                CImg<T> &img = gmic_check(images[ind]);
                try { gmic_apply(img,convert_primitives_CImg3d(mode)); }
                catch (CImgException &e) {
                  if (!img.is_CImg3d(true,message))
                    error(images,"Command '-primitives3d': Invalid 3d object [%d], "
                          "in selected image%s (%s).",
                          ind,gmic_selection,message);
                  else throw e;
                }
              }
            } else arg_error("primitives3d");
            is_released = false; ++position; continue;
          }

          // Display as a graph plot.
          if (!std::strcmp("-plot",command) && !is_get_version) {
            gmic_substitute_args();
            double ymin = 0, ymax = 0, xmin = 0, xmax = 0;
            unsigned int plot_type = 1, vertex_type = 1;
            float resolution = 65536;
            char sep = 0;
            *formula = 0;
            if (((std::sscanf(argument,"'%1023[^']%c%c",
                              formula,&sep,&end)==2 && sep=='\'') ||
                 std::sscanf(argument,"'%1023[^']',%f%c",
                             formula,&resolution,&end)==2 ||
                 std::sscanf(argument,"'%1023[^']',%f,%u%c",
                             formula,&resolution,&plot_type,&end)==3 ||
                 std::sscanf(argument,"'%1023[^']',%f,%u,%u%c",
                             formula,&resolution,&plot_type,&vertex_type,&end)==4 ||
                 std::sscanf(argument,"'%1023[^']',%f,%u,%u,%lf,%lf%c",
                             formula,&resolution,&plot_type,&vertex_type,&xmin,&xmax,&end)==6 ||
                 std::sscanf(argument,"'%1023[^']',%f,%u,%u,%lf,%lf,%lf,%lf%c",
                             formula,&resolution,&plot_type,&vertex_type,
                             &xmin,&xmax,&ymin,&ymax,&end)==8) &&
                resolution>0 && plot_type<=3 && vertex_type<=7) {
              resolution = cimg::round(resolution);
              gmic_strreplace(formula);
              if (xmin==0 && xmax==0) { xmin = -4; xmax = 4; }
              if (!plot_type && !vertex_type) plot_type = 1;
              if (resolution<1) resolution = 65536;
              CImgList<double> tmp_img(1);
              CImg<double> &values = tmp_img[0];

              values.assign(4,(unsigned int)resolution--,1,1,0);
              const double dx = xmax - xmin;
              cimg_forY(values,X) values(0,X) = xmin + X*dx/resolution;
              cimg::eval(formula,values).move_to(values);

              CImgList<char> tmp_name;
              cimg_snprintf(message,_message.size(),"[Plot of '%s']",formula);
              CImg<char>::string(message).move_to(tmp_name);
              display_plots(tmp_img,tmp_name,CImg<unsigned int>::vector(0),
                            plot_type,vertex_type,xmin,xmax,ymin,ymax);
              ++position;
            } else {
              plot_type = 1; vertex_type = 0; ymin = ymax = xmin = xmax = 0;
              if ((std::sscanf(argument,"%u%c",
                               &plot_type,&end)==1 ||
                   std::sscanf(argument,"%u,%u%c",
                               &plot_type,&vertex_type,&end)==2 ||
                   std::sscanf(argument,"%u,%u,%lf,%lf%c",
                               &plot_type,&vertex_type,&xmin,&xmax,&end)==4 ||
                   std::sscanf(argument,"%u,%u,%lf,%lf,%lf,%lf%c",
                               &plot_type,&vertex_type,&xmin,&xmax,&ymin,&ymax,&end)==6) &&
                  plot_type<=3 && vertex_type<=7) ++position;
              if (!plot_type && !vertex_type) plot_type = 1;
              display_plots(images,images_names,selection,plot_type,vertex_type,
                            xmin,xmax,ymin,ymax);
            }
            is_released = true; continue;
          }

#endif // #ifdef gmic_float
# 8679 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='p'.

        //----------------------------
        // Commands starting by '-q..'
        //----------------------------
        else if (command1=='q') {

#ifdef gmic_float

          // Draw quiver.
          if (!std::strcmp("-quiver",command)) {
            gmic_substitute_args();
            float sampling = 25, factor = -20, opacity = 1;
            unsigned int is_arrows = 1, pattern = ~0U;
            CImg<unsigned int> ind;
            char seph = 0;
            *color = 0;
            if ((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]]%c",
                             indices,&end)==1 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f%c",
                             indices,&sampling,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f%c",
                             indices,&sampling,&factor,&end)==3 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%u%c",
                             indices,&sampling,&factor,&is_arrows,&end)==4 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%u,%f%c",
                             indices,&sampling,&factor,&is_arrows,&opacity,&end)==5 ||
                 (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%u,%f,0%c%x%c",
                              indices,&sampling,&factor,&is_arrows,
                              &opacity,&seph,&pattern,&end)==7 && seph=='x') ||
                 (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%u,%f,%4095[0-9.eE,+-]%c",
                              indices,&sampling,&factor,&is_arrows,&opacity,color,&end)==6 &&
                  (bool)(pattern=~0U)) ||
                 (*color=0,std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%u,"
                                       "%f,0%c%x,%4095[0-9.eE,+-]%c",
                                       indices,&sampling,&factor,&is_arrows,
                                       &opacity,&seph,&pattern,color,&end)==8 &&
                  seph=='x')) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-quiver",true,
                                    false,CImg<char>::empty())).height()==1 &&
                sampling>0 && is_arrows<=1) {
              sampling = cimg::round(sampling);
              print(images,"Draw 2d vector field [%u] on image%s, with sampling %g, factor %g, "
                    "arrows %s, opacity %g, pattern 0x%x and color (%s).",
                    *ind,
                    gmic_selection,
                    sampling,
                    factor,
                    is_arrows?"enabled":"disabled",
                    opacity,pattern,
                    *color?color:"default");
              const CImg<T> flow = gmic_image_arg(*ind);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]], col(img.spectrum(),1,1,1,0);
                col.fill(color,true);
                gmic_apply(img,draw_quiver(flow,col.data(),opacity,(unsigned int)sampling,
                                           factor,(bool)is_arrows,pattern));
              }
            } else arg_error("quiver");
            is_released = false; ++position; continue;
          }

#endif // #ifdef gmic_float
# 8742 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='q'.

        //----------------------------
        // Commands starting by '-r..'
        //----------------------------
        else if (command1=='r') {

          // Remove images.
          if (!std::strcmp("-remove",command)) {
            print(images,"Remove image%s",
                  gmic_selection);
            CImgList<T> _images;
            CImgList<char> _images_names;
            if (is_get_version) { _images.assign(images); _images_names.assign(images_names); }
            remove_images(images,images_names,selection,0,selection.height()-1);
            if (is_get_version) {
              _images.move_to(images,0);
              _images_names.move_to(images_names,0);
            }
            if (verbosity>=0 || is_debug) {
              std::fprintf(cimg::output()," (%u image%s left).",
                           images.size(),images.size()==1?"":"s");
              std::fflush(cimg::output());
            }
            is_released = false; continue;
          }

          // Repeat.
          if (!std::strcmp("-repeat",item)) {
            gmic_substitute_args();
            float number = 0;
            if (std::sscanf(argument,"%f%c",
                            &number,&end)==1) {
              const unsigned int nb = number>0?(unsigned int)cimg::round(number):0U;
              if (nb) {
                CImg<char>::string("*repeat").move_to(scope);
                if (verbosity>0 || is_debug)
                  print(images,"Start '-repeat..-done' block (%u iteration%s).",
                        nb,nb>1?"s":"");
                CImg<unsigned int>::vector(position+1,nb,0).move_to(repeatdones);
              } else {
                if (verbosity>0 || is_debug)
                  print(images,"Skip 'repeat..done' block (0 iteration).",
                        nb);
                int nb_repeats = 0;
                for (nb_repeats = 1; nb_repeats && position<commands_line.size(); ++position) {
                  const char *it = commands_line[position].data();
                  if (!std::strcmp("-repeat",it)) ++nb_repeats;
                  else if (!std::strcmp("-done",it)) --nb_repeats;
                }
                if (nb_repeats && position>=commands_line.size())
                  error(images,"Command '-repeat': Missing associated '-done' command.");
                continue;
              }
            } else arg_error("repeat");
            ++position; continue;
          }

          // Resize.
          if (!std::strcmp("-resize",command)) {
            gmic_substitute_args();
            float valx = 100, valy = 100, valz = 100, valc = 100, cx = 0, cy = 0, cz = 0, cc = 0;
            char sep = 0, sepx = '%', sepy = '%', sepz = '%', sepc = '%';
            CImg<char> indicesy(256), indicesz(256), indicesc(256);
            CImg<unsigned int> ind, indx, indy, indz, indc;
            unsigned int boundary = 0;
            int interpolation = 1;
            *indices = *indicesy = *indicesz = *indicesc = *argx = *argy = *argz = *argc = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                              indices,&sep,&end)==2 && sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%d%c",
                             indices,&interpolation,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%d,%u%c",
                             indices,&interpolation,&boundary,&end)==3 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%d,%u,%f%c",
                             indices,&interpolation,&boundary,&cx,&end)==4 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%d,%u,%f,%f%c",
                             indices,&interpolation,&boundary,&cx,&cy,&end)==5 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%d,%u,%f,%f,%f%c",
                             indices,&interpolation,&boundary,&cx,&cy,&cz,&end)==6 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%d,%u,%f,%f,%f,%f%c",
                             indices,&interpolation,&boundary,&cx,&cy,&cz,&cc,&end)==7) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-resize",true,
                                    false,CImg<char>::empty())).height()==1 &&
                interpolation>=-1 && interpolation<=6 && boundary<=2 &&
                cx>=0 && cx<=1 && cy>=0 && cy<=1 && cz>=0 && cz<=1 && cc>=0 && cc<=1) {
              const int
                nvalx = images[*ind].width(),
                nvaly = images[*ind].height(),
                nvalz = images[*ind].depth(),
                nvalc = images[*ind].spectrum();
              print(images,"Resize image%s to %dx%dx%dx%d, with %s interpolation, "
                    "%s boundary conditions and alignment (%g,%g,%g,%g).",
                    gmic_selection,
                    nvalx,nvaly,nvalz,nvalc,
                    interpolation<=0?"no":interpolation==1?"nearest-neighbor":
                    interpolation==2?"moving average":interpolation==3?"linear":
                    interpolation==4?"grid":interpolation==5?"cubic":"lanczos",
                    boundary<=0?"dirichlet":boundary==1?"neumann":"cyclic",
                    cx,cy,cz,cc);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],resize(nvalx,nvaly,nvalz,nvalc,interpolation,
                                                       boundary,cx,cy,cz,cc));
              ++position;
            } else if ((cx=cy=cz=cc=0, interpolation=1, boundary=0, true) &&
                       (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-]%c",
                                    argx,&end)==1 ||
                        std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                                    argx,argy,&end)==2 ||
                        std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
                                    "%255[][a-zA-Z0-9_.eE%+-]%c",
                                    argx,argy,argz,&end)==3 ||
                        std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
                                    "%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                                    argx,argy,argz,argc,&end)==4 ||
                        std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
                                    "%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],%d%c",
                                    argx,argy,argz,argc,&interpolation,&end)==5 ||
                        std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
                                    "%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],%d,%u%c",
                                    argx,argy,argz,argc,&interpolation,&boundary,&end)==6 ||
                        std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
                                    "%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],%d,%u,%f%c",
                                    argx,argy,argz,argc,&interpolation,&boundary,&cx,&end)==7 ||
                        std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
                                    "%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],%d,%u,%f,"
                                    "%f%c",
                                    argx,argy,argz,argc,&interpolation,&boundary,&cx,&cy,&end)==8||
                        std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
                                    "%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],%d,%u,%f,"
                                    "%f,%f%c",
                                    argx,argy,argz,argc,&interpolation,&boundary,
                                    &cx,&cy,&cz,&end)==9 ||
                        std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
                                    "%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],%d,%u,%f,"
                                    "%f,%f,%f%c",
                                    argx,argy,argz,argc,&interpolation,&boundary,
                                    &cx,&cy,&cz,&cc,&end)==10) &&
                       ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sepx,&end)==2 &&
                         sepx==']' &&
                         (indx=selection2cimg(indices,images.size(),images_names,"-resize",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        (sepx=0,std::sscanf(argx,"%f%c",&valx,&sepx)==1 && valx>=1) ||
                        (std::sscanf(argx,"%f%c%c",&valx,&sepx,&end)==2 && sepx=='%')) &&
                       (!*argy ||
                        (std::sscanf(argy,"[%255[a-zA-Z0-9_.%+-]%c%c",indicesy.data(),&sepy,&end)==2 &&
                         sepy==']' &&
                         (indy=selection2cimg(indicesy,images.size(),images_names,"-resize",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        (sepy=0,std::sscanf(argy,"%f%c",&valy,&sepy)==1 && valy>=1) ||
                        (std::sscanf(argy,"%f%c%c",&valy,&sepy,&end)==2 && sepy=='%')) &&
                       (!*argz ||
                        (std::sscanf(argz,"[%255[a-zA-Z0-9_.%+-]%c%c",indicesz.data(),&sepz,&end)==2 &&
                         sepz==']' &&
                         (indz=selection2cimg(indicesz,images.size(),images_names,"-resize",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        (sepz=0,std::sscanf(argz,"%f%c",&valz,&sepz)==1 && valz>=1) ||
                        (std::sscanf(argz,"%f%c%c",&valz,&sepz,&end)==2 && sepz=='%')) &&
                       (!*argc ||
                        (std::sscanf(argc,"[%255[a-zA-Z0-9_.%+-]%c%c",indicesc.data(),&sepc,&end)==2 &&
                         sepc==']' &&
                         (indc=selection2cimg(indicesc,images.size(),images_names,"-resize",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        (sepc=0,std::sscanf(argc,"%f%c",&valc,&sepc)==1 && valc>=1) ||
                        (std::sscanf(argc,"%f%c%c",&valc,&sepc,&end)==2 && sepc=='%')) &&
                     valx>0 && valy>0 && valz>0 && valc>0 &&
                       interpolation>=-1 && interpolation<=6 && boundary<=2 &&
                       cx>=0 && cx<=1 && cy>=0 && cy<=1 && cz>=0 && cz<=1 && cc>=0 && cc<=1) {
              if (indx) { valx = (float)images[*indx].width(); sepx = 0; }
              if (indy) { valy = (float)images[*indy].height(); sepy = 0; }
              if (indz) { valz = (float)images[*indz].depth(); sepz = 0; }
              if (indc) { valc = (float)images[*indc].spectrum(); sepc = 0; }
              print(images,
                    "Resize image%s to %g%s%g%s%g%s%g%s, with %s interpolation, "
                    "%s boundary conditions and alignment (%g,%g,%g,%g).",
                    gmic_selection,
                    valx,sepx=='%'?"%x":"x",
                    valy,sepy=='%'?"%x":"x",
                    valz,sepz=='%'?"%x":"x",
                    valc,sepc=='%'?"% ":"",
                    interpolation<=0?"no":interpolation==1?"nearest neighbor":
                    interpolation==2?"moving average":interpolation==3?"linear":
                    interpolation==4?"grid":interpolation==5?"cubic":"lanczos",
                    boundary<=0?"dirichlet":boundary==1?"neumann":"cyclic",
                    cx,cy,cz,cc);
              cimg_forY(selection,l) {
                CImg<T>& img = images[selection[l]];
                const int
                  _nvalx = (int)cimg::round(sepx=='%'?valx*img.width()/100:valx),
                  _nvaly = (int)cimg::round(sepy=='%'?valy*img.height()/100:valy),
                  _nvalz = (int)cimg::round(sepz=='%'?valz*img.depth()/100:valz),
                  _nvalc = (int)cimg::round(sepc=='%'?valc*img.spectrum()/100:valc),
                  nvalx = _nvalx?_nvalx:1,
                  nvaly = _nvaly?_nvaly:1,
                  nvalz = _nvalz?_nvalz:1,
                  nvalc = _nvalc?_nvalc:1;
                gmic_apply(img,resize(nvalx,nvaly,nvalz,nvalc,interpolation,boundary,cx,cy,cz,cc));
              }
              ++position;
            } else {
#if cimg_display==0
              print(images,"Resize image%s in interactive mode (skipped, no display support).",
                    gmic_selection);
#else // #if cimg_display==0
# 8946 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
              bool is_available_display = false;
              try {
                is_available_display = (bool)CImgDisplay::screen_width();
              } catch (CImgDisplayException&) {
                print(images,"Resize image%s in interactive mode (skipped, no display available).",
                      gmic_selection);
              }
              if (is_available_display) {
                print(images,"Resize image%s in interactive mode.",
                      gmic_selection);
                CImgDisplay _disp, &disp = instant_window[0]?instant_window[0]:_disp;
                cimg_forY(selection,l) {
                  CImg<T>& img = gmic_check(images[selection[l]]);
                  if (img) {
                    if (disp) disp.resize(cimg_fitscreen(img.width(),img.height(),1),false);
                    else disp.assign(cimg_fitscreen(img.width(),img.height(),1),0,1);
                    disp.set_title("%s: resize",gmic_basename(images_names[selection[l]].data()));
                    img.get_select(disp,0);
                    print(images,
                          "Resize image [%d] to %dx%d, with nearest-neighbor interpolation.",
                          selection[l],
                          disp.width(),
                          disp.height());
                    gmic_apply(img,resize(disp));
                  } else { gmic_apply(img,replace(img)); }
                }
              }
#endif // #if cimg_display==0
# 8974 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            }
            is_released = false; continue;
          }

          // Reverse positions.
          if (!std::strcmp("-reverse",command)) {
            print(images,"Reverse positions of image%s.",
                  gmic_selection);
            CImgList<T> _images, nimages(selection.height());
            CImgList<char> _images_names, nimages_names(selection.height());
            if (is_get_version) { _images.assign(images); _images_names.assign(images_names); }
            cimg_forY(selection,l) {
              nimages[l].swap(images[selection[l]]);
              nimages_names[l].swap(images_names[selection[l]]);
            }
            nimages.reverse(); nimages_names.reverse();
            cimg_forY(selection,l) {
              nimages[l].swap(images[selection[l]]);
              nimages_names[l].swap(images_names[selection[l]]);
            }
            if (is_get_version) {
              _images.move_to(images,0);
              _images_names.move_to(images_names,0);
            }
            is_released = false; continue;
          }

          // Return.
          if (!std::strcmp("-return",item)) {
            if (verbosity>0 || is_debug) print(images,"Return.");
            position = commands_line.size();
            while (scope && scope.back()[0]=='*') {
              const char c = scope.back()[1];
              if (c=='d') dowhiles.remove();
              else if (c=='r') repeatdones.remove();
              else if (c=='l' || c=='>' || c=='s') break;
              scope.remove();
            }
            is_return = true;
            break;
          }

          // Keep rows.
          if (!std::strcmp("-rows",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind0, ind1;
            float value0 = 0, value1 = 0;
            char sep0 = 0, sep1 = 0;
            *argx = *argy = 0;
            if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-]%c",
                            argx,&end)==1 &&
                ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c]",indices,&sep0,&end)==2 &&
                  sep0==']' &&
                  (ind0=selection2cimg(indices,images.size(),images_names,"-rows",true,
                                       false,CImg<char>::empty())).height()==1) ||
                 std::sscanf(argx,"%f%c",&value0,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&value0,&sep0,&end)==2 && sep0=='%'))) {
              if (ind0) { value0 = images[*ind0].height() - 1.0f; sep0 = 0; }
              print(images,"Keep rows %g%s of image%s.",
                    value0,sep0=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int nvalue0 = (int)cimg::round(sep0=='%'?value0*(img.height()-1)/100:value0);
                gmic_apply(img,row(nvalue0));
              }
            } else if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                                   argx,argy,&end)==2 &&
                       ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep0,&end)==2 &&
                         sep0==']' &&
                         (ind0=selection2cimg(indices,images.size(),images_names,"-rows",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        std::sscanf(argx,"%f%c",&value0,&end)==1 ||
                        (std::sscanf(argx,"%f%c%c",&value0,&sep0,&end)==2 && sep0=='%')) &&
                       ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",formula,&sep0,&end)==2 &&
                         sep0==']' &&
                         (ind1=selection2cimg(formula,images.size(),images_names,"-rows",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        std::sscanf(argy,"%f%c",&value1,&end)==1 ||
                        (std::sscanf(argy,"%f%c%c",&value1,&sep1,&end)==2 && sep1=='%'))) {
              if (ind0) { value0 = images[*ind0].height() - 1.0f; sep0 = 0; }
              if (ind1) { value1 = images[*ind1].height() - 1.0f; sep1 = 0; }
              print(images,"Keep rows %g%s..%g%s of image%s.",
                    value0,sep0=='%'?"%":"",
                    value1,sep1=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  nvalue0 = (int)cimg::round(sep0=='%'?value0*(img.height()-1)/100:value0),
                  nvalue1 = (int)cimg::round(sep1=='%'?value1*(img.height()-1)/100:value1);
                gmic_apply(img,rows(nvalue0,nvalue1));
              }
            } else arg_error("rows");
            is_released = false; ++position; continue;
          }

          // Rotate.
          if (!std::strcmp("-rotate",command)) {
            gmic_substitute_args();
            float angle = 0, zoom = 1, cx = 0, cy = 0;
            unsigned int interpolation = 1, boundary = 0;
            char sepx = 0, sepy = 0;
            *argx = *argy = 0;
            if ((std::sscanf(argument,"%f%c",
                             &angle,&end)==1 ||
                 std::sscanf(argument,"%f,%u%c",
                             &angle,&interpolation,&end)==2 ||
                 std::sscanf(argument,"%f,%u,%u%c",
                             &angle,&interpolation,&boundary,&end)==3 ||
                 std::sscanf(argument,"%f,%u,%u,%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             &angle,&interpolation,&boundary,argx,argy,&end)==5 ||
                 std::sscanf(argument,"%f,%u,%u,%255[0-9.eE%+-],%255[0-9.eE%+-],%f%c",
                             &angle,&interpolation,&boundary,argx,argy,&zoom,&end)==6) &&
                (!*argx ||
                 std::sscanf(argx,"%f%c",&cx,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&cx,&sepx,&end)==2 && sepx=='%')) &&
                (!*argy ||
                 std::sscanf(argy,"%f%c",&cy,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&cy,&sepy,&end)==2 && sepy=='%')) &&
                interpolation<=2 && boundary<=2) {
              if (*argx) {
                print(images,"Rotate image%s of %g°, %s interpolation, %s boundary conditions "
                      "with center at (%g%s,%g%s).",
                      gmic_selection,angle,
                      interpolation==0?"nearest-neighbor":interpolation==1?"linear":"cubic",
                      boundary==0?"dirichlet":boundary==1?"neumann":"cyclic",
                      cx,sepx=='%'?"%":"",cy,sepy=='%'?"%":"");
                cimg_forY(selection,l) {
                  CImg<T> &img = images[selection[l]];
                  const float
                    ncx = sepx=='%'?cx*(img.width()-1)/100:cx,
                    ncy = sepy=='%'?cy*(img.height()-1)/100:cy;
                  gmic_apply(img,rotate(angle,ncx,ncy,zoom,interpolation,boundary));
                }
              } else {
                print(images,"Rotate image%s of %g°, %s interpolation and %s boundary conditions.",
                      gmic_selection,angle,
                      interpolation==0?"nearest-neighbor":interpolation==1?"linear":"cubic",
                      boundary==0?"dirichlet":boundary==1?"neumann":"cyclic");
                cimg_forY(selection,l)
                  gmic_apply(images[selection[l]],rotate(angle,interpolation,boundary));
              }
            } else arg_error("rotate");
            is_released = false; ++position; continue;
          }

#ifdef gmic_float

          // Round.
          if (!std::strcmp("-round",command)) {
            gmic_substitute_args();
            double rounding_value = 1;
            int rounding_type = 0;
            if ((std::sscanf(argument,"%lf%c",
                             &rounding_value,&end)==1 ||
                 std::sscanf(argument,"%lf,%d%c",
                             &rounding_value,&rounding_type,&end)==2) &&
                rounding_value>=0 && rounding_type>=-1 && rounding_type<=1) ++position;
            else { rounding_value = 1; rounding_type = 0; }
            print(images,"Round values of image%s by %g and %s rounding.",
                  gmic_selection,
                  rounding_value,
                  rounding_type<0?"backward":rounding_type>0?"forward":"nearest");
            cimg_forY(selection,l)
              gmic_apply(images[selection[l]],round(rounding_value,rounding_type));
            is_released = false; continue;
          }

          // Fill with random values.
          if (!std::strcmp("-rand",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind0, ind1;
            double value0 = 0, value1 = 0;
            char sep0 = 0, sep1 = 0;
            *argx = *argy = 0;
            if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                            argx,argy,&end)==2 &&
                ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep0,&end)==2 &&
                  sep0==']' &&
                  (ind0=selection2cimg(indices,images.size(),images_names,"-rand",true,
                                       false,CImg<char>::empty())).height()==1) ||
                 (std::sscanf(argx,"%lf%c%c",&value0,&sep0,&end)==2 && sep0=='%') ||
                 std::sscanf(argx,"%lf%c",&value0,&end)==1) &&
                ((std::sscanf(argy,"[%255[a-zA-Z0-9_.%+-]%c%c",formula,&sep1,&end)==2 &&
                  sep1==']' &&
                  (ind1=selection2cimg(formula,images.size(),images_names,"-rand",true,
                                       false,CImg<char>::empty())).height()==1) ||
                 (std::sscanf(argy,"%lf%c%c",&value1,&sep1,&end)==2 && sep1=='%') ||
                 std::sscanf(argy,"%lf%c",&value1,&end)==1)) {
              if (ind0) { value0 = images[*ind0].min(); sep0 = 0; }
              if (ind1) { value1 = images[*ind1].max(); sep1 = 0; }
              print(images,"Fill image%s with random values, in range [%g%s,%g%s].",
                    gmic_selection,
                    value0,sep0=='%'?"%":"",
                    value1,sep1=='%'?"%":"");
              cimg_forY(selection,l) {
                CImg<T>& img = gmic_check(images[selection[l]]);
                double vmin = 0, vmax = 0, nvalue0 = value0, nvalue1 = value1;
                if (sep0=='%' || sep1=='%') {
                  if (img) vmax = (double)img.max_min(vmin);
                  if (sep0=='%') nvalue0 = vmin + (vmax-vmin)*value0/100;
                  if (sep1=='%') nvalue1 = vmin + (vmax-vmin)*value1/100;
                }
                gmic_apply(img,rand((T)nvalue0,(T)nvalue1));
              }
            } else if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep0,&end)==2 &&
                       sep0==']' &&
                       (ind0=selection2cimg(indices,images.size(),images_names,"-rand",true,
                                            false,CImg<char>::empty())).height()==1) {
              if (images[*ind0]) value1 = (double)images[*ind0].max_min(value0);
              print(images,"Fill image%s with random values, in range [%g,%g] from image [%d].",
                    gmic_selection,
                    value0,
                    value1,
                    *ind0);
              cimg_forY(selection,l) gmic_apply(images[selection[l]],rand((T)value0,(T)value1));
            } else arg_error("rand");
            is_released = false; ++position; continue;
          }

          // Rotate 3d object.
          if (!std::strcmp("-rotate3d",command)) {
            gmic_substitute_args();
            float u = 0, v = 0, w = 1, angle = 0;
            if (std::sscanf(argument,"%f,%f,%f,%f%c",
                            &u,&v,&w,&angle,&end)==4) {
              print(images,"Rotate 3d object%s around axis (%g,%g,%g), with angle %g°.",
                    gmic_selection,
                    u,v,w,
                    angle);
              const CImg<float> rot = CImg<float>::rotation_matrix(u,v,w,
                                                                   (float)(angle*cimg::PI/180));
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                CImg<T>& img = gmic_check(images[ind]);
                try { gmic_apply(img,rotate_CImg3d(rot)); }
                catch (CImgException &e) {
                  if (!img.is_CImg3d(true,message))
                    error(images,"Command '-rotate3d': Invalid 3d object [%d], "
                          "in selected image%s (%s).",
                          ind,gmic_selection,message);
                  else throw e;
                }
              }
            } else arg_error("rotate3d");
            is_released = false; ++position; continue;
          }

          // RGB to other color base.
          gmic_simple_item("-rgb2hsi",RGBtoHSI,"Convert image%s from RGB to HSI color bases.");
          gmic_simple_item("-rgb2hsl",RGBtoHSL,"Convert image%s from RGB to HSL color bases.");
          gmic_simple_item("-rgb2hsv",RGBtoHSV,"Convert image%s from RGB to HSV color bases.");
          gmic_simple_item("-rgb2lab",RGBtoLab,"Convert image%s from RGB to Lab color bases.");
          gmic_simple_item("-rgb2srgb",RGBtosRGB,"Convert image%s from RGB to sRGB color bases.");

          // Bitwise left rotation.
          gmic_arithmetic_item("-rol",
                               rol,
                               "Compute bitwise left rotation of image%s by %g%s",
                               gmic_selection,value,ssep,unsigned int,
                               rol,
                               "Compute bitwise left rotation of image%s by image [%d]",
                               gmic_selection,ind[0],
                               "Compute bitwise left rotation of image%s by expression %s",
                               gmic_selection,argument_text,
                               "Compute sequential bitwise left rotation of image%s");

          // Bitwise right rotation.
          gmic_arithmetic_item("-ror",
                               ror,
                               "Compute bitwise right rotation of image%s by %g%s",
                               gmic_selection,value,ssep,unsigned int,
                               ror,
                               "Compute bitwise right rotation of image%s by image [%d]",
                               gmic_selection,ind[0],
                               "Compute bitwise left rotation of image%s by expression %s",
                               gmic_selection,argument_text,
                               "Compute sequential bitwise left rotation of image%s");

          // Reverse 3d object orientation.
          if (!std::strcmp("-reverse3d",command)) {
            print(images,"Reverse orientation of 3d object%s.",
                  gmic_selection);
            cimg_forY(selection,l) {
              const unsigned int ind = selection[l];
              CImg<T> &img = gmic_check(images[ind]);
              try { gmic_apply(img,reverse_CImg3d()); }
              catch (CImgException &e) {
                if (!img.is_CImg3d(true,message))
                  error(images,"Command '-reverse3d': Invalid 3d object [%d], "
                        "in selected image%s (%s).",
                        ind,gmic_selection,message);
                else throw e;
              }
            }
            is_released = false; continue;
          }

#endif // #ifdef gmic_float
# 9274 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='r'.

        //----------------------------
        // Commands starting by '-s..'
        //----------------------------
        else if (command1=='s') {

          // Set status.
          if (!std::strcmp("-status",item)) {
            gmic_substitute_args();
            print(images,"Set status to '%s'.",argument_text);
            CImg<char>::string(argument).move_to(status);
            ++position; continue;
          }

          // Skip argument.
          if (!std::strcmp("-skip",item)) {
            gmic_substitute_args();
            if (verbosity>0 || is_debug)
              print(images,"Skip argument '%s'.",
                    argument_text);
            ++position;
            continue;
          }

          // Set pixel value.
          if (!std::strcmp("-set",command)) {
            gmic_substitute_args();
            char sepx = 0, sepy = 0, sepz = 0, sepc = 0;
            float x = 0, y = 0, z = 0, c = 0;
            double value = 0;
            *argx = *argy = *argz = *argc = 0;
            if ((std::sscanf(argument,"%lf%c",
                             &value,&end)==1 ||
                 std::sscanf(argument,"%lf,%255[0-9.eE%+-]%c",
                             &value,argx,&end)==2 ||
                 std::sscanf(argument,"%lf,%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             &value,argx,argy,&end)==3 ||
                 std::sscanf(argument,"%lf,%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             &value,argx,argy,argz,&end)==4 ||
                 std::sscanf(argument,"%lf,%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-]%c",
                             &value,argx,argy,argz,argc,&end)==5) &&
                (!*argx ||
                 (std::sscanf(argx,"%f%c%c",&x,&sepx,&end)==2 && sepx=='%') ||
                 std::sscanf(argx,"%f%c",&x,&end)==1) &&
                (!*argy ||
                 (std::sscanf(argy,"%f%c%c",&y,&sepy,&end)==2 && sepy=='%') ||
                 std::sscanf(argy,"%f%c",&y,&end)==1) &&
                (!*argz ||
                 (std::sscanf(argz,"%f%c%c",&z,&sepz,&end)==2 && sepz=='%') ||
                 std::sscanf(argz,"%f%c",&z,&end)==1) &&
                (!*argc ||
                 (std::sscanf(argc,"%f%c%c",&c,&sepc,&end)==2 && sepc=='%') ||
                 std::sscanf(argc,"%f%c",&c,&end)==1)) {
              print(images,"Set value %g in image%s, at coordinates (%g%s,%g%s,%g%s,%g%s).",
                    value,
                    gmic_selection,
                    x,sepx=='%'?"%":"",
                    y,sepy=='%'?"%":"",
                    z,sepz=='%'?"%":"",
                    c,sepc=='%'?"%":"");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  nx = (int)cimg::round(sepx=='%'?x*(img.width()-1)/100:x),
                  ny = (int)cimg::round(sepy=='%'?y*(img.height()-1)/100:y),
                  nz = (int)cimg::round(sepz=='%'?z*(img.depth()-1)/100:z),
                  nc = (int)cimg::round(sepc=='%'?c*(img.spectrum()-1)/100:c);
                gmic_apply(images[selection[l]],gmic_set(value,nx,ny,nz,nc));
              }
            } else arg_error("set");
            is_released = false; ++position; continue;
          }

          // Split.
          if (!std::strcmp("-split",command)) {
            gmic_substitute_args();
            const char *axis_arg = 0;
            char keep_values = '+';
            CImgList<char> axes;
            float nb = 0;
            for (axis_arg = argument; *axis_arg && *axis_arg!=','; ++axis_arg) {
              const char _s = *axis_arg;
              if (_s!='x' && _s!='y' && _s!='z' && _s!='c') { axis_arg = 0; break; }
              CImg<char>::vector(_s).move_to(axes);
            }
            if (axis_arg && *axis_arg==',') {
              if (std::sscanf(++axis_arg,"%f%c",&nb,&end)!=1) axis_arg = 0;
              else nb = cimg::round(nb);
            }
            if (axes && axis_arg) {
              const CImg<char> _axes = (axes,CImg<char>::vector(0))>'x';
              axes.remove();
              if (nb>0)
                print(images,"Split image%s along the '%s'-ax%cs, into %g parts.",
                      gmic_selection,
                      _axes.data(),
                      axes.size()>1?'e':'i',
                      nb);
              else if (nb<0)
                print(images,"Split image%s along the '%s'-ax%cs, into blocs of %g pixels.",
                      gmic_selection,
                      _axes.data(),
                      axes.size()>1?'e':'i',
                      -nb);
              else
                print(images,"Split image%s along the '%s'-ax%cs.",
                      gmic_selection,
                      _axes.data(),
                      axes.size()>1?'e':'i');
              int off = 0;
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l] + off;
                const CImg<T>& img = gmic_check(images[ind]);
                if (!img) {
                  if (!is_get_version) { images.remove(ind); images_names.remove(ind); off-=1; }
                } else {
                  CImg<char> name = images_names[ind].get_mark();
                  CImgList<T> split(img,true);
                  cimglist_for(axes,i) {
                    const unsigned int N = split.size();
                    for (unsigned int l = 0; l<N; ++l) {
                      split[0].get_split(axes(i,0),(int)nb).move_to(split,~0U);
                      split.remove(0);
                    }
                  }
                  if (is_get_version) {
                    images_names.insert(split.size(),name.copymark());
                    split.move_to(images,~0U);
                  } else {
                    images.remove(ind); images_names.remove(ind);
                    off+=(int)split.size() - 1;
                    images_names.insert(split.size(),name.get_copymark(),ind);
                    name.move_to(images_names[ind]);
                    split.move_to(images,ind);
                  }
                }
              }
              ++position;
            } else if ((std::sscanf(argument,"%c,%c",
                                    &keep_values,&end)==2) &&
                       (keep_values=='+' || keep_values=='-')) {
              print(images,"Split image%s in %s mode, according to value sequence '%s'.",
                    gmic_selection,
                    keep_values=='-'?"discard":"keep",
                    argument_text+2);
              unsigned int nb_values = 1;
              int off = 0;
              for (const char *s = argument+2; *s; ++s) if (*s==',') ++nb_values;
              const CImg<T> values(nb_values,1,1,1,argument+2,true);
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l] + off;
                const CImg<T>& img = gmic_check(images[ind]);
                if (!img) {
                  if (!is_get_version) { images.remove(ind); images_names.remove(ind); off-=1; }
                } else {
                  CImg<char> name = images_names[ind].get_mark();
                  CImgList<T> split = img.get_split(values,keep_values=='+',false);
                  if (is_get_version) {
                    if (split) {
                      images_names.insert(split.size(),name.copymark());
                      split.move_to(images,~0U);
                    }
                  } else {
                    images.remove(ind);
                    images_names.remove(ind);
                    if (split) {
                      off+=(int)split.size() - 1;
                      images_names.insert(split.size(),name.get_copymark(),ind);
                      name.move_to(images_names[ind]);
                      split.move_to(images,ind);
                    }
                  }
                }
              }
              ++position;
            } else {
              print(images,"Split image%s as a set of constant sub-vectors.",
                    gmic_selection);
              int off = 0;
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l] + off;
                const CImg<T>& img = gmic_check(images[ind]);
                if (!img) {
                  if (!is_get_version) { images.remove(ind); images_names.remove(ind); off-=1; }
                } else {
                  CImg<char> name = images_names[ind].get_mark();
                  CImgList<T> split = img.get_split(false);
                  if (is_get_version) {
                    if (split) {
                      images_names.insert(split.size(),name.copymark());
                      split.move_to(images,~0U);
                    }
                  } else {
                    images.remove(ind);
                    images_names.remove(ind);
                    if (split) {
                      off+=(int)split.size() - 1;
                      images_names.insert(split.size(),name.get_copymark(),ind);
                      name.move_to(images_names[ind]);
                      split.move_to(images,ind);
                    }
                  }
                }
              }
            }
            is_released = false; continue;
          }

          // Shared input.
          if (!std::strcmp("-shared",command)) {
            gmic_substitute_args();
            CImg<char> st0(256), st1(256), st2(256), st3(256), st4(256);
            char sep0 = 0, sep1 = 0, sep2 = 0, sep3 = 0, sep4 = 0;
            float a0 = 0, a1 = 0, a2 = 0, a3 = 0, a4 = 0;
            *st0 = *st1 = *st2 = *st3 = *st4 = 0;
            if (std::sscanf(argument,
                            "%255[0-9.eE%+],%255[0-9.eE%+],%255[0-9.eE%+],%255[0-9.eE%+],"
                            "%255[0-9.eE%+]%c",
                            st0.data(),st1.data(),st2.data(),st3.data(),st4.data(),&end)==5 &&
                (std::sscanf(st0,"%f%c",&a0,&end)==1 ||
                 (std::sscanf(st0,"%f%c%c",&a0,&sep0,&end)==2 && sep0=='%')) &&
                (std::sscanf(st1,"%f%c",&a1,&end)==1 ||
                 (std::sscanf(st1,"%f%c%c",&a1,&sep1,&end)==2 && sep1=='%')) &&
                (std::sscanf(st2,"%f%c",&a2,&end)==1 ||
                 (std::sscanf(st2,"%f%c%c",&a2,&sep2,&end)==2 && sep2=='%')) &&
                (std::sscanf(st3,"%f%c",&a3,&end)==1 ||
                 (std::sscanf(st3,"%f%c%c",&a3,&sep3,&end)==2 && sep3=='%')) &&
                (std::sscanf(st4,"%f%c",&a4,&end)==1 ||
                 (std::sscanf(st4,"%f%c%c",&a4,&sep4,&end)==2 && sep4=='%'))) {
              print(images,
                    "Insert shared buffer%s from points (%g%s->%g%s,%g%s,%g%s,%g%s) of image%s.",
                    selection.height()>1?"s":"",
                    a0,sep0=='%'?"%":"",
                    a1,sep1=='%'?"%":"",
                    a2,sep2=='%'?"%":"",
                    a3,sep3=='%'?"%":"",
                    a4,sep4=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T>& img = images[selection[l]];
                const unsigned int
                  s0 = (unsigned int)cimg::round(sep0=='%'?a0*(img.width()-1)/100:a0),
                  s1 = (unsigned int)cimg::round(sep1=='%'?a1*(img.width()-1)/100:a1),
                  y =  (unsigned int)cimg::round(sep2=='%'?a2*(img.height()-1)/100:a2),
                  z =  (unsigned int)cimg::round(sep3=='%'?a3*(img.depth()-1)/100:a3),
                  c =  (unsigned int)cimg::round(sep4=='%'?a4*(img.spectrum()-1)/100:a4);
                images.insert(img.get_shared_points(s0,s1,y,z,c),~0U,true);
                images_names.insert(images_names[selection[l]].get_copymark());
              }
              ++position;
            } else if (std::sscanf(argument,
                                   "%255[0-9.eE%+],%255[0-9.eE%+],%255[0-9.eE%+],"
                                   "%255[0-9.eE%+],%c",
                                   st0.data(),st1.data(),st2.data(),st3.data(),&end)==4 &&
                       (std::sscanf(st0,"%f%c",&a0,&end)==1 ||
                        (std::sscanf(st0,"%f%c%c",&a0,&sep0,&end)==2 && sep0=='%')) &&
                       (std::sscanf(st1,"%f%c",&a1,&end)==1 ||
                        (std::sscanf(st1,"%f%c%c",&a1,&sep1,&end)==2 && sep1=='%')) &&
                       (std::sscanf(st2,"%f%c",&a2,&end)==1 ||
                        (std::sscanf(st2,"%f%c%c",&a2,&sep2,&end)==2 && sep2=='%')) &&
                       (std::sscanf(st3,"%f%c",&a3,&end)==1 ||
                        (std::sscanf(st3,"%f%c%c",&a3,&sep3,&end)==2 && sep3=='%'))) {
              print(images,"Insert shared buffer%s from lines (%g%s->%g%s,%g%s,%g%s) of image%s.",
                    selection.height()>1?"s":"",
                    a0,sep0=='%'?"%":"",
                    a1,sep1=='%'?"%":"",
                    a2,sep2=='%'?"%":"",
                    a3,sep3=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T>& img = images[selection[l]];
                const unsigned int
                  s0 = (unsigned int)cimg::round(sep0=='%'?a0*(img.height()-1)/100:a0),
                  s1 = (unsigned int)cimg::round(sep1=='%'?a1*(img.height()-1)/100:a1),
                  z =  (unsigned int)cimg::round(sep2=='%'?a2*(img.depth()-1)/100:a2),
                  c =  (unsigned int)cimg::round(sep3=='%'?a3*(img.spectrum()-1)/100:a3);
                images.insert(img.get_shared_rows(s0,s1,z,c),~0U,true);
                images_names.insert(images_names[selection[l]].get_copymark());
              }
              ++position;
            } else if (std::sscanf(argument,"%255[0-9.eE%+],%255[0-9.eE%+],%255[0-9.eE%+]%c",
                                   st0.data(),st1.data(),st2.data(),&end)==3 &&
                       (std::sscanf(st0,"%f%c",&a0,&end)==1 ||
                        (std::sscanf(st0,"%f%c%c",&a0,&sep0,&end)==2 && sep0=='%')) &&
                       (std::sscanf(st1,"%f%c",&a1,&end)==1 ||
                        (std::sscanf(st1,"%f%c%c",&a1,&sep1,&end)==2 && sep1=='%')) &&
                       (std::sscanf(st2,"%f%c",&a2,&end)==1 ||
                        (std::sscanf(st2,"%f%c%c",&a2,&sep2,&end)==2 && sep2=='%'))) {
              print(images,"Insert shared buffer%s from planes (%g%s->%g%s,%g%s) of image%s.",
                    selection.height()>1?"s":"",
                    a0,sep0=='%'?"%":"",
                    a1,sep1=='%'?"%":"",
                    a2,sep2=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T>& img = images[selection[l]];
                const unsigned int
                  s0 = (unsigned int)cimg::round(sep0=='%'?a0*(img.depth()-1)/100:a0),
                  s1 = (unsigned int)cimg::round(sep1=='%'?a1*(img.depth()-1)/100:a1),
                  c =  (unsigned int)cimg::round(sep2=='%'?a2*(img.spectrum()-1)/100:a2);
                images.insert(img.get_shared_slices(s0,s1,c),~0U,true);
                images_names.insert(images_names[selection[l]].get_copymark());
              }
              ++position;
            } else if (std::sscanf(argument,"%255[0-9.eE%+],%255[0-9.eE%+]%c",
                                   st0.data(),st1.data(),&end)==2 &&
                       (std::sscanf(st0,"%f%c",&a0,&end)==1 ||
                        (std::sscanf(st0,"%f%c%c",&a0,&sep0,&end)==2 && sep0=='%')) &&
                       (std::sscanf(st1,"%f%c",&a1,&end)==1 ||
                        (std::sscanf(st1,"%f%c%c",&a1,&sep1,&end)==2 && sep1=='%'))) {
              print(images,"Insert shared buffer%s from channels (%g%s->%g%s) of image%s.",
                    selection.height()>1?"s":"",
                    a0,sep0=='%'?"%":"",
                    a1,sep1=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T>& img = images[selection[l]];
                const unsigned int
                  s0 = (unsigned int)cimg::round(sep0=='%'?a0*(img.spectrum()-1)/100:a0),
                  s1 = (unsigned int)cimg::round(sep1=='%'?a1*(img.spectrum()-1)/100:a1);
                images.insert(img.get_shared_channels(s0,s1),~0U,true);
                images_names.insert(images_names[selection[l]].get_copymark());
              }
              ++position;
            } else {
              print(images,"Insert shared buffer%s from image%s.",
                    selection.height()>1?"s":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                images.insert(img,~0U,true);
                images_names.insert(images_names[selection[l]].get_copymark());
              }
            }
            is_released = false; continue;
          }

          // Shift.
          if (!std::strcmp("-shift",command)) {
            gmic_substitute_args();
            char sepx = 0, sepy = 0, sepz = 0, sepc = 0;
            float dx = 0, dy = 0, dz = 0, dc = 0;
            unsigned int boundary = 0;
            *argx = *argy = *argz = *argc = 0;
            if ((std::sscanf(argument,"%255[0-9.eE%+-]%c",
                             argx,&end)==1 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             argx,argy,&end)==2 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             argx,argy,argz,&end)==3 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-]%c",
                             argx,argy,argz,argc,&end)==4 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-],%u%c",
                             argx,argy,argz,argc,&boundary,&end)==5) &&
                (std::sscanf(argx,"%f%c",&dx,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&dx,&sepx,&end)==2 && sepx=='%')) &&
                (!*argy ||
                 std::sscanf(argy,"%f%c",&dy,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&dy,&sepy,&end)==2 && sepy=='%')) &&
                (!*argz ||
                 std::sscanf(argz,"%f%c",&dz,&end)==1 ||
                 (std::sscanf(argz,"%f%c%c",&dz,&sepz,&end)==2 && sepz=='%')) &&
                (!*argc ||
                 std::sscanf(argc,"%f%c",&dc,&end)==1 ||
                 (std::sscanf(argc,"%f%c%c",&dc,&sepc,&end)==2 && sepc=='%')) &&
                boundary<=2) {
              print(images,
                    "Shift image%s by displacement vector (%g%s,%g%s,%g%s,%g%s) and "
                    "%s boundary conditions.",
                    gmic_selection,
                    dx,sepx=='%'?"%":"",
                    dy,sepy=='%'?"%":"",
                    dz,sepz=='%'?"%":"",
                    dc,sepc=='%'?"%":"",
                    boundary==0?"dirichlet":boundary==1?"neumann":"cyclic");
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  ndx = (int)cimg::round(sepx=='%'?dx*img.width()/100:dx),
                  ndy = (int)cimg::round(sepy=='%'?dy*img.height()/100:dy),
                  ndz = (int)cimg::round(sepz=='%'?dz*img.depth()/100:dz),
                  ndc = (int)cimg::round(sepc=='%'?dc*img.spectrum()/100:dc);
                gmic_apply(images[selection[l]],shift(ndx,ndy,ndz,ndc,boundary));
              }
            } else arg_error("shift");
            is_released = false; ++position; continue;
          }

          // Keep slices.
          if (!std::strcmp("-slices",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind0, ind1;
            float value0 = 0, value1 = 0;
            char sep0 = 0, sep1 = 0;
            *argx = *argy = 0;
            if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-]%c",
                            argx,&end)==1 &&
                ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c]",indices,&sep0,&end)==2 &&
                  sep0==']' &&
                  (ind0=selection2cimg(indices,images.size(),images_names,"-slices",true,
                                       false,CImg<char>::empty())).height()==1) ||
                 std::sscanf(argx,"%f%c",&value0,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&value0,&sep0,&end)==2 && sep0=='%'))) {
              if (ind0) { value0 = images[*ind0].depth() - 1.0f; sep0 = 0; }
              print(images,"Keep slice %g%s of image%s.",
                    value0,sep0=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int nvalue0 = (int)cimg::round(sep0=='%'?value0*(img.depth()-1)/100:value0);
                gmic_apply(img,slice(nvalue0));
              }
            } else if (std::sscanf(argument,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                                   argx,argy,&end)==2 &&
                       ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep0,&end)==2 &&
                         sep0==']' &&
                         (ind0=selection2cimg(indices,images.size(),images_names,"-slices",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        std::sscanf(argx,"%f%c",&value0,&end)==1 ||
                        (std::sscanf(argx,"%f%c%c",&value0,&sep0,&end)==2 && sep0=='%')) &&
                       ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",formula,&sep0,&end)==2 &&
                         sep0==']' &&
                         (ind1=selection2cimg(formula,images.size(),images_names,"-slices",true,
                                              false,CImg<char>::empty())).height()==1) ||
                        std::sscanf(argy,"%f%c",&value1,&end)==1 ||
                        (std::sscanf(argy,"%f%c%c",&value1,&sep1,&end)==2 && sep1=='%'))) {
              if (ind0) { value0 = images[*ind0].depth() - 1.0f; sep0 = 0; }
              if (ind1) { value1 = images[*ind1].depth() - 1.0f; sep1 = 0; }
              print(images,"Keep slices %g%s..%g%s of image%s.",
                    value0,sep0=='%'?"%":"",
                    value1,sep1=='%'?"%":"",
                    gmic_selection);
              cimg_forY(selection,l) {
                CImg<T> &img = images[selection[l]];
                const int
                  nvalue0 = (int)cimg::round(sep0=='%'?value0*(img.depth()-1)/100:value0),
                  nvalue1 = (int)cimg::round(sep1=='%'?value1*(img.depth()-1)/100:value1);
                gmic_apply(img,slices(nvalue0,nvalue1));
              }
            } else arg_error("slices");
            is_released = false; ++position; continue;
          }

          // Set random generator seed.
          if (!std::strcmp("-srand",item)) {
            gmic_substitute_args();
            double value = 0;
            if (std::sscanf(argument,"%lf%c",
                            &value,&end)==1) {
              value = cimg::round(value);
              print(images,"Set random generator seed to %u.",
                    (unsigned int)value);
              cimg::srand((unsigned int)value);
              ++position;
            } else {
              print(images,"Set random generator seed to random.");
              cimg::srand();
            }
            continue;
          }

#ifdef gmic_float

          // Sub.
          gmic_arithmetic_item("-sub",
                               operator-=,
                               "Subtract %g%s to image%s",
                               value,ssep,gmic_selection,Tfloat,
                               operator-=,
                               "Subtract image [%d] to image%s",
                               ind[0],gmic_selection,
                               "Subtract expression %s to image%s",
                               argument_text,gmic_selection,
                               "Subtract image%s");
          // Square root.
          gmic_simple_item("-sqrt",sqrt,"Compute pointwise square root of image%s.");

          // Square.
          gmic_simple_item("-sqr",sqr,"Compute pointwise square function of image%s.");

          // Sign.
          gmic_simple_item("-sign",sign,"Compute pointwise sign of image%s.");

          // Sine.
          gmic_simple_item("-sin",sin,"Compute pointwise sine of image%s.");

          // Sort.
          if (!std::strcmp("-sort",command)) {
            gmic_substitute_args();
            char order = '+', axis = 0;
            if ((std::sscanf(argument,"%c%c",&order,&end)==1 ||
                 (std::sscanf(argument,"%c,%c%c",&order,&axis,&end)==2 &&
                  (axis=='x' || axis=='y' || axis=='z' || axis=='c'))) &&
                (order=='+' || order=='-')) ++position;
            else { order = '+'; axis = 0; }
            if (axis) print(images,"Sort values of image%s in %s order, according to axis '%c'.",
                            gmic_selection,order=='+'?"ascending":"descending",axis);
            else print(images,"Sort values of image%s in %s order.",
                       gmic_selection,order=='+'?"ascending":"descending");
            cimg_forY(selection,l) gmic_apply(images[selection[l]],sort(order=='+',axis));
            is_released = false; continue;
          }

          // Solve.
          if (!std::strcmp("-solve",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind;
            char sep = 0;
            if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 &&
                sep==']' &&
                (ind=selection2cimg(indices,images.size(),images_names,"-solve",true,
                                    false,CImg<char>::empty())).height()==1) {
              print(images,"Solve linear system AX = B, with B-vector%s and A-matrix [%d].",
                    gmic_selection,*ind);
              const CImg<T> A = gmic_image_arg(*ind);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],solve(A));
            } else arg_error("solve");
            is_released = false; ++position; continue;
          }

          // Shift 3d object, with opposite displacement.
          if (!std::strcmp("-sub3d",command)) {
            gmic_substitute_args();
            float tx = 0, ty = 0, tz = 0;
            if (std::sscanf(argument,"%f%c",
                            &tx,&end)==1 ||
                std::sscanf(argument,"%f,%f%c",
                            &tx,&ty,&end)==2 ||
                std::sscanf(argument,"%f,%f,%f%c",
                            &tx,&ty,&tz,&end)==3) {
              print(images,"Shift 3d object%s with displacement -(%g,%g,%g).",
                    gmic_selection,
                    tx,ty,tz);
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                CImg<T>& img = gmic_check(images[ind]);
                try { gmic_apply(img,shift_CImg3d(-tx,-ty,-tz)); }
                catch (CImgException &e) {
                  if (!img.is_CImg3d(true,message))
                    error(images,
                          "Command '-sub3d': Invalid 3d object [%d], in selected image%s (%s).",
                          ind,gmic_selection,message);
                  else throw e;
                }
              }
            } else arg_error("sub3d");
            is_released = false; ++position; continue;
          }

          // Sharpen.
          if (!std::strcmp("-sharpen",command)) {
            gmic_substitute_args();
            float amplitude = 0, edge = -1, alpha = 0, sigma = 0;
            if ((std::sscanf(argument,"%f%c",
                             &amplitude,&end)==1 ||
                 std::sscanf(argument,"%f,%f%c",
                             &amplitude,&edge,&end)==2 ||
                 std::sscanf(argument,"%f,%f,%f%c",
                             &amplitude,&edge,&alpha,&end)==3 ||
                 std::sscanf(argument,"%f,%f,%f,%f%c",
                             &amplitude,&edge,&alpha,&sigma,&end)==4) &&
                amplitude>=0 && (edge==-1 || edge>=0)) {
              if (edge>=0)
                print(images,"Sharpen image%s with shock filters, amplitude %g, edge %g, "
                      "alpha %g and sigma %g.",
                      gmic_selection,
                      amplitude,
                      edge,
                      alpha,
                      sigma);
              else
                print(images,"Sharpen image%s with inverse diffusion and amplitude %g.",
                      gmic_selection,
                      amplitude);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],sharpen(amplitude,(bool)(edge>=0),
                                                        edge,alpha,sigma));
            } else arg_error("sharpen");
            is_released = false; ++position; continue;
          }

          // Anisotropic PDE-based smoothing.
          if (!std::strcmp("-smooth",command)) {
            gmic_substitute_args();
            float amplitude = 0, sharpness = 0.7f, anisotropy = 0.3f, alpha = 0.6f,
              sigma = 1.1f, dl =0.8f, da = 30.0f, gauss_prec = 2.0f;
            unsigned int interpolation = 0, is_fast_approximation = 1;
            CImg<unsigned int> ind;
            char sep = 0;
            if ((std::sscanf(argument,"%f%c",
                             &amplitude,&end)==1 ||
                 std::sscanf(argument,"%f,%f%c",
                             &amplitude,&sharpness,&end)==2 ||
                 std::sscanf(argument,"%f,%f,%f%c",
                             &amplitude,&sharpness,&anisotropy,&end)==3 ||
                 std::sscanf(argument,"%f,%f,%f,%f%c",
                             &amplitude,&sharpness,&anisotropy,&alpha,&end)==4 ||
                 std::sscanf(argument,"%f,%f,%f,%f,%f%c",
                             &amplitude,&sharpness,&anisotropy,&alpha,&sigma,&end)==5 ||
                 std::sscanf(argument,"%f,%f,%f,%f,%f,%f%c",
                             &amplitude,&sharpness,&anisotropy,&alpha,&sigma,&dl,&end)==6 ||
                 std::sscanf(argument,"%f,%f,%f,%f,%f,%f,%f%c",
                             &amplitude,&sharpness,&anisotropy,&alpha,&sigma,&dl,&da,&end)==7 ||
                 std::sscanf(argument,"%f,%f,%f,%f,%f,%f,%f,%f%c",
                             &amplitude,&sharpness,&anisotropy,&alpha,&sigma,&dl,&da,&gauss_prec,
                             &end)==8 ||
                 std::sscanf(argument,"%f,%f,%f,%f,%f,%f,%f,%f,%u%c",
                             &amplitude,&sharpness,&anisotropy,&alpha,&sigma,&dl,&da,&gauss_prec,
                             &interpolation,&end)==9 ||
                 std::sscanf(argument,"%f,%f,%f,%f,%f,%f,%f,%f,%u,%u%c",
                             &amplitude,&sharpness,&anisotropy,&alpha,&sigma,&dl,&da,&gauss_prec,
                             &interpolation,&is_fast_approximation,&end)==10) &&
                amplitude>=0 && sharpness>=0 && anisotropy>=0 && anisotropy<=1 && dl>0 &&
                da>=0 && gauss_prec>0 && interpolation<=2 && is_fast_approximation<=1) {
              if (da>0)
                print(images,"Smooth image%s anisotropically, with amplitude %g, sharpness %g, "
                      "anisotropy %g, alpha %g, sigma %g, dl %g, da %g, precision %g, "
                      "%s interpolation and fast approximation %s.",
                      gmic_selection,
                      amplitude,
                      sharpness,
                      anisotropy,
                      alpha,
                      sigma,
                      dl,
                      da,
                      gauss_prec,
                      interpolation==0?"nearest-neighbor":interpolation==1?"linear":"runge-kutta",
                      is_fast_approximation?"enabled":"disabled");
              else
                print(images,"Smooth image%s anisotropically, with %d iterations, sharpness %g, "
                      "anisotropy %g, alpha %g, sigma %g and dt %g.",
                      gmic_selection,
                      (int)amplitude,
                      sharpness,
                      anisotropy,
                      alpha,
                      sigma,
                      dl);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],blur_anisotropic(amplitude,sharpness,anisotropy,
                                                                 alpha,sigma,dl,da,gauss_prec,
                                                                 interpolation,
                                                                 (bool)is_fast_approximation));
            } else if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                                     indices,&sep,&end)==2 && sep==']') ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f%c",
                                    indices,&amplitude,&end)==2 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f%c",
                                    indices,&amplitude,&dl,&end)==3 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f%c",
                                    indices,&amplitude,&dl,&da,&end)==4 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f%c",
                                    indices,&amplitude,&dl,&da,&gauss_prec,&end)==5 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f,%u%c",
                                    indices,&amplitude,&dl,&da,&gauss_prec,
                                    &interpolation,&end)==6 ||
                        std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%f,%f,%f,%f,%u,%u%c",
                                    indices,&amplitude,&dl,&da,&gauss_prec,&interpolation,
                                    &is_fast_approximation,&end)==7) &&
                       (ind=selection2cimg(indices,images.size(),images_names,"-smooth",true,
                                           false,CImg<char>::empty())).height()==1 &&
                       amplitude>=0 && dl>0 && da>=0 && gauss_prec>0 && interpolation<=2 &&
                       is_fast_approximation<=1) {
              const CImg<T> tensors = gmic_image_arg(*ind);
              if (da>0)
                print(images,
                      "Smooth image%s anisotropically, with tensor field [%u], amplitude %g, "
                      "dl %g, da %g, precision %g, %s interpolation and fast approximation %s.",
                      gmic_selection,
                      *ind,
                      amplitude,
                      dl,
                      da,
                      gauss_prec,
                      interpolation==0?"nearest-neighbor":interpolation==1?"linear":"runge-kutta",
                      is_fast_approximation?"enabled":"disabled");
              else
                print(images,
                      "Smooth image%s anisotropically, with tensor field [%u], %d iterations "
                      "and dt %g.",
                      gmic_selection,
                      *ind,
                      (int)amplitude,
                      dl);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],blur_anisotropic(tensors,amplitude,dl,da,
                                                                 gauss_prec,interpolation,
                                                                 is_fast_approximation));
            } else arg_error("smooth");
            is_released = false; ++position; continue;
          }

          // Split 3d objects, into 6 vector images
          // { header,N,vertices,primitives,colors,opacities }
          if (!std::strcmp("-split3d",command)) {
            bool keep_shared = true;
            gmic_substitute_args();
            if ((*argument=='0' || *argument=='1') && !argument[1]) {
              keep_shared = *argument=='1';
              ++position;
            }
            print(images,"Split 3d object%s into 6 property vectors%s.",
                  gmic_selection,
                  keep_shared?"":" and clone shared data");
            unsigned int off = 0;
            cimg_forY(selection,l) {
              const unsigned int ind = selection[l] + off;
              const CImg<T> &img = gmic_check(images[ind]);
              CImg<char> name = images_names[ind].get_mark();
              CImgList<T> split;
              try {
                if (!keep_shared) {
                  CImg<T> vertices;
                  CImgList<unsigned int> primitives;
                  CImgList<T> colors, opacities;
                  img.get_CImg3dtoobject3d(primitives,colors,opacities,false).move_to(vertices);
                  CImgList<T> _colors(colors,false), _opacities(opacities,false);
                  _colors.move_to(colors.assign());
                  _opacities.move_to(opacities.assign());
                  vertices.object3dtoCImg3d(primitives,colors,opacities,false).get_split_CImg3d().
                    move_to(split);
                } else img.get_split_CImg3d().move_to(split);
              } catch (CImgException &e) {
                if (!img.is_CImg3d(true,message))
                  error(images,
                        "Command '-split3d': Invalid 3d object [%d], in selected image%s (%s).",
                        ind-off,gmic_selection,message);
                else throw e;
              }
              if (is_get_version) {
                images_names.insert(split.size(),name.copymark());
                split.move_to(images,~0U);
              } else {
                images.remove(ind);
                images_names.remove(ind);
                off+=split.size() - 1;
                images_names.insert(split.size(),name.get_copymark(),ind);
                name.move_to(images_names[ind]);
                split.move_to(images,ind);
              }
            }
            is_released = false; continue;
          }

          // SVD.
          if (!std::strcmp("-svd",command)) {
            print(images,"Compute SVD decomposition%s of matri%s%s.",
                  selection.height()>1?"s":"",selection.height()>1?"ce":"x",gmic_selection);
            CImg<float> U, S, V;
            unsigned int off = 0;
            cimg_forY(selection,l) {
              const unsigned int ind = selection[l] + off;
              const CImg<T>& img = gmic_check(images[ind]);
              CImg<char> name = images_names[ind].get_mark();
              img.SVD(U,S,V,true,100);
              if (is_get_version) {
                images_names.insert(2,name.copymark());
                name.move_to(images_names);
                U.move_to(images);
                S.move_to(images);
                V.move_to(images);
              } else {
                images_names.insert(2,name.get_copymark(),ind+1);
                name.move_to(images_names[ind]);
                U.move_to(images[ind].assign());
                images.insert(S,ind+1);
                images.insert(V,ind+2);
                off+=2;
              }
            }
            is_released = false; continue;
          }

          // Input 3d sphere.
          if (!std::strcmp("-sphere3d",item)) {
            gmic_substitute_args();
            float radius = 100, recursions = 3;
            if ((std::sscanf(argument,"%f%c",
                             &radius,&end)==1 ||
                 std::sscanf(argument,"%f,%f%c",
                             &radius,&recursions,&end)==2) &&
                recursions>=0) {
              recursions = cimg::round(recursions);
              print(images,"Input 3d sphere, with radius %g and %g recursions.",
                    radius,
                    recursions);
              CImgList<unsigned int> primitives;
              CImg<float> vertices = CImg<T>::sphere3d(primitives,radius,(unsigned int)recursions);
              vertices.object3dtoCImg3d(primitives,false).move_to(images);
              CImg<char>::string("[3d sphere]").move_to(images_names);
            } else arg_error("sphere3d");
            is_released = false; ++position; continue;
          }

          // Set 3d specular light parameters.
          if (!std::strcmp("-specl3d",item)) {
            gmic_substitute_args();
            float value = 0.15f;
            if (std::sscanf(argument,"%f%c",
                            &value,&end)==1 && value>=0) ++position;
            else value = 0.15f;
            specular_lightness3d = value;
            print(images,"Set lightness of 3d specular light to %g.",
                  specular_lightness3d);
            continue;
          }

          if (!std::strcmp("-specs3d",item)) {
            gmic_substitute_args();
            float value = 0.8f;
            if (std::sscanf(argument,"%f%c",
                            &value,&end)==1 && value>=0) ++position;
            else value = 0.8f;
            specular_shininess3d = value;
            print(images,"Set shininess of 3d specular light to %g.",
                  specular_shininess3d);
            continue;
          }

          // Sine-cardinal.
          gmic_simple_item("-sinc",sinc,"Compute pointwise sinc function of image%s.");

          // Hyperbolic sine.
          gmic_simple_item("-sinh",sinh,"Compute pointwise hyperpolic sine of image%s.");

          // sRGB to RGB.
          gmic_simple_item("-srgb2rgb",sRGBtoRGB,"Convert image%s from sRGB to RGB color bases.");

          // Extract 3d streamline.
          if (!std::strcmp("-streamline3d",command)) {
            gmic_substitute_args();
            unsigned int interp = 2, is_backward = 0, is_oriented_only = 0;
            float x = 0, y = 0, z = 0, L = 100, dl = 0.1f;
            char sepx = 0, sepy = 0, sepz = 0;
            *formula = 0;
            if ((std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             argx,argy,argz,&end)==3 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f%c",
                             argx,argy,argz,&L,&end)==4 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f,%f%c",
                             argx,argy,argz,&L,&dl,&end)==5 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f,%f,%u%c",
                             argx,argy,argz,&L,&dl,&interp,&end)==6 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f,%f,%u,"
                             "%u%c",
                             argx,argy,argz,&L,&dl,&interp,&is_backward,&end)==7 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[0-9.eE%+-],%f,%f,%u,"
                             "%u,%u%c",
                             argx,argy,argz,&L,&dl,&interp,&is_backward,
                             &is_oriented_only,&end)==8) &&
                (std::sscanf(argx,"%f%c",&x,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&x,&sepx,&end)==2 && sepx=='%')) &&
                (!*argy ||
                 std::sscanf(argy,"%f%c",&y,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&y,&sepy,&end)==2 && sepy=='%')) &&
                (!*argz ||
                 std::sscanf(argz,"%f%c",&z,&end)==1 ||
                 (std::sscanf(argz,"%f%c%c",&z,&sepz,&end)==2 && sepz=='%')) &&
                L>=0 && dl>0 && interp<4 && is_backward<=1 && is_oriented_only<=1) {
              print(images,"Extract 3d streamline from image%s, starting from (%g%s,%g%s,%g%s).",
                    gmic_selection,
                    x,sepx=='%'?"%":"",
                    y,sepy=='%'?"%":"",
                    z,sepz=='%'?"%":"");
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                CImg<T>& img = gmic_check(images[ind]);
                const float
                  nx = cimg::round(sepx=='%'?x*(img.width()-1)/100:x),
                  ny = cimg::round(sepy=='%'?y*(img.height()-1)/100:y),
                  nz = cimg::round(sepz=='%'?z*(img.depth()-1)/100:z);
                CImg<T> vertices = img.get_streamline(nx,ny,nz,L,dl,interp,
                                                      (bool)is_backward,(bool)is_oriented_only);
                CImgList<unsigned int> primitives;
                CImgList<unsigned char> colors;
                if (vertices.width()>1) {
                  primitives.assign(vertices.width()-1,1,2);
                  cimglist_for(primitives,l) { primitives(l,0) = l; primitives(l,1) = l+1; }
                  colors.assign(primitives.size(),1,3,1,1,200);
                } else {
                  vertices.assign();
                  warn(images,
                       "Command '-streamline3d': Empty streamline starting from "
                       "(%g%s,%g%s,%g%s) in image [%u].",
                       x,sepx=='%'?"%":"",
                       y,sepy=='%'?"%":"",
                       z,sepz=='%'?"%":"",
                       ind);
                }
                vertices.object3dtoCImg3d(primitives,colors,false);
                gmic_apply(img,replace(vertices));
              }
            } else if ((std::sscanf(argument,"'%4095[^']',%f,%f,%f%c",
                                    formula,&x,&y,&z,&end)==4 ||
                        std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f%c",
                                    formula,&x,&y,&z,&L,&end)==5 ||
                        std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f%c",
                                    formula,&x,&y,&z,&L,&dl,&end)==6 ||
                        std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%u%c",
                                    formula,&x,&y,&z,&L,&dl,&interp,&end)==7 ||
                        std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%u,%u%c",
                                    formula,&x,&y,&z,&L,&dl,&interp,&is_backward,&end)==8 ||
                        std::sscanf(argument,"'%4095[^']',%f,%f,%f,%f,%f,%u,%u,%u%c",
                                    formula,&x,&y,&z,&L,&dl,&interp,&is_backward,
                                    &is_oriented_only,&end)==9) &&
                       dl>0 && interp<4) {
              gmic_strreplace(formula);
              print(images,"Extract 3d streamline from formula '%s', starting from (%g,%g,%g).",
                    formula,
                    x,y,z);
              CImg<T> vertices = CImg<T>::streamline((const char *)formula,x,y,z,L,dl,interp,
                                                     (bool)is_backward,(bool)is_oriented_only);
              CImgList<unsigned int> primitives;
              CImgList<unsigned char> colors;
              if (vertices.width()>1) {
                primitives.assign(vertices.width()-1,1,2);
                cimglist_for(primitives,l) { primitives(l,0) = l; primitives(l,1) = l+1; }
                colors.assign(primitives.size(),1,3,1,1,200);
              } else {
                vertices.assign();
                warn(images,
                     "Command '-streamline3d': Empty streamline starting from (%g,%g,%g) "
                     "in expression '%s'.",
                     x,y,z,formula);
              }
              vertices.object3dtoCImg3d(primitives,colors,false).move_to(images);
              cimg_snprintf(title,_title.size(),"[3d streamline of '%s' at (%g,%g,%g)]",
                            formula,x,y,z);
              gmic_ellipsize(title,_title.size());
              CImg<char>::string(title).move_to(images_names);
            } else arg_error("streamline3d");
            is_released = false; ++position; continue;
          }

          // Compute structure tensor field.
          if (!std::strcmp("-structuretensors",command)) {
            gmic_substitute_args();
            unsigned int scheme = 0;
            if (std::sscanf(argument,"%u%c",&scheme,&end)==1 &&
                scheme<=2) ++position;
            else scheme = 2;
            print(images,"Compute structure tensor field of image%s, with %s scheme.",
                  gmic_selection,
                  scheme==0?"centered":scheme==1?"forward-backward1":"forward-backward2");
            cimg_forY(selection,l) gmic_apply(images[selection[l]],structure_tensors(scheme));
            is_released = false; continue;
          }

          // Select image feature.
          if (!std::strcmp("-select",command)) {
            gmic_substitute_args();
            unsigned int feature_type = 0, X=~0U, Y=~0U, Z=~0U;
            bool is_xyz = false;
            if ((std::sscanf(argument,"%u%c",&feature_type,&end)==1 ||
                 (is_xyz=std::sscanf(argument,"%u,%u,%u,%u%c",&feature_type,&X,&Y,&Z,&end)==4)) &&
                feature_type<=3) {
#if cimg_display==0
              print(images,"Select %s in image%s in interactive mode",
                    feature_type==0?"point":feature_type==1?"segment":feature_type==2?"rectangle":
                    "ellipse",gmic_selection);
              if (verbosity>=0 || is_debug) {
                if (is_xyz) std::fprintf(cimg::output(),", from point (%u,%u,%u)",X,Y,Z);
                std::fprintf(cimg::output()," (skipped, no display support).");
                std::fflush(cimg::output());
              }
#else // #if cimg_display==0
# 10246 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
              bool is_available_display = false;
              try {
                is_available_display = (bool)CImgDisplay::screen_width();
              } catch (CImgDisplayException&) {
                print(images,
                      "Select %s in image%s in interactive mode",
                      feature_type==0?"point":feature_type==1?"segment":
                      feature_type==2?"rectangle":"ellipse",gmic_selection);
                if (verbosity>=0 || is_debug) {
                  if (is_xyz) std::fprintf(cimg::output(),", from point (%u,%u,%u)",X,Y,Z);
                  std::fprintf(cimg::output()," (skipped, no display available).");
                  std::fflush(cimg::output());
                }
              }
              if (is_available_display) {
                print(images,"Select %s in image%s in interactive mode",
                      feature_type==0?"point":feature_type==1?"segment":
                      feature_type==2?"rectangle":"ellipse",gmic_selection);
                if (verbosity>=0 || is_debug) {
                  if (is_xyz) std::fprintf(cimg::output(),", from point (%u,%u,%u).",X,Y,Z);
                  else std::fprintf(cimg::output(),".");
                  std::fflush(cimg::output());
                }
                unsigned int XYZ[3];
                XYZ[0] = X; XYZ[1] = Y; XYZ[2] = Z;
                if (instant_window[0])
                  cimg_forY(selection,l) {
                    gmic_apply(images[selection[l]],select(instant_window[0],feature_type,
                                                           is_xyz?XYZ:0));
                  }
                else
                  cimg_forY(selection,l) {
                    gmic_apply(images[selection[l]],select(images_names[selection[l]].data(),
                                                           feature_type,is_xyz?XYZ:0));
                  }
              }
#endif // #if cimg_display==0
# 10283 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            } else arg_error("select");
            is_released = false; ++position; continue;
          }

#endif // #ifdef gmic_float
# 10288 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='s'.

        //----------------------------
        // Commands starting by '-t..'
        //----------------------------
        else if (command1=='t') {

          // Set datatype.
          if (!std::strcmp("-type",item)) {
            gmic_substitute_args();
#ifndef gmic_float_only
            typedef unsigned char uchar;
            typedef unsigned short ushort;
            typedef unsigned int uint;
            gmic_cast(bool,"bool");
            gmic_cast(uchar,"unsigned char");
            gmic_cast(char,"char");
            gmic_cast(ushort,"unsigned short");
            gmic_cast(short,"short");
            gmic_cast(uint,"unsigned int");
            gmic_cast(int,"int");
            gmic_cast(double,"double");
#endif // #ifndef gmic_float_only
# 10311 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            gmic_cast(float,"float");
            arg_error("type");
          }

#ifdef gmic_float

          // Threshold.
          if (!std::strcmp("-threshold",command)) {
            gmic_substitute_args();
            unsigned int is_soft = 0;
            double value = 0;
            char sep = 0;
            if ((std::sscanf(argument,"%lf%c",
                             &value,&end)==1 ||
                 (std::sscanf(argument,"%lf%c%c",
                              &value,&sep,&end)==2 && sep=='%') ||
                 std::sscanf(argument,"%lf,%u%c",
                             &value,&is_soft,&end)==2 ||
                 (std::sscanf(argument,"%lf%c,%u%c",
                              &value,&sep,&is_soft,&end)==3 && sep=='%')) &&
                is_soft<=1) {
              print(images,"%s-threshold image%s by %g%s.",
                    is_soft?"Soft":"Hard",
                    gmic_selection,
                    value,sep=='%'?"%":"");
              cimg_forY(selection,l) {
                CImg<T>& img = gmic_check(images[selection[l]]);
                double nvalue = value;
                if (sep=='%' && img) {
                  double vmin = 0, vmax = (double)img.max_min(vmin);
                  nvalue = vmin + (vmax-vmin)*value/100;
                }
                gmic_apply(img,threshold((T)nvalue,(bool)is_soft));
              }
              ++position;
            } else {
#if cimg_display==0
              print(images,
                    "Threshold image%s in interactive mode (skipped, no display support).",
                    gmic_selection);
#else // #if cimg_display==0
# 10352 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
              bool is_available_display = false;
              try {
                is_available_display = (bool)CImgDisplay::screen_width();
              } catch (CImgDisplayException&) {
                print(images,
                      "Threshold image%s in interactive mode (skipped, no display available).",
                      gmic_selection);
              }
              if (is_available_display) {
                print(images,"Threshold image%s in interactive mode.",
                      gmic_selection);
                CImgDisplay _disp, &disp = instant_window[0]?instant_window[0]:_disp;
                cimg_forY(selection,l) {
                  CImg<T>& img = gmic_check(images[selection[l]]);
                  if (img) {
                    CImg<T> visu = img.depth()>1?img.get_projections2d(img.width()/2,
                                                                       img.height()/2,
                                                                       img.depth()/2).
                      channels(0,cimg::min(3,img.spectrum())-1):
                      img.get_channels(0,cimg::min(3,img.spectrum()-1));
                    const unsigned int
                      w = CImgDisplay::_fitscreen(visu.width(),visu.height(),1,256,-85,false),
                      h = CImgDisplay::_fitscreen(visu.width(),visu.height(),1,256,-85,true);
                    if (disp) disp.resize(w,h,false); else disp.assign(w,h,0,0);
                    double vmin = 0, vmax = (double)img.max_min(vmin), percent = 50;
                    bool stopflag = false, is_clicked = false;
                    int omx = -1, omy = -1;
                    CImg<unsigned char> res;
                    for (disp.show().flush(); !stopflag; ) {
                      const unsigned char white[] = { 255,255,255 }, black[] = { 0,0,0 };
                      const unsigned int key = disp.key();
                      if (!res)
                        disp.display(((res=visu.get_threshold((T)(vmin + percent*(vmax-vmin)/100)).
                                       resize(disp))*=255).
                                     draw_text(0,0,"Threshold %g = %.3g%%",
                                               white,black,0.7f,13,
                                               (double)(vmin + percent*(vmax-vmin)/100),
                                               percent)).
                          set_title("%s (%dx%dx%dx%d)",
                                    gmic_basename(images_names[selection[l]].data()),
                                    img.width(),img.height(),img.depth(),img.spectrum()).wait();
                      const int mx = disp.mouse_x(), my = disp.mouse_y();
                      if (disp.button()) {
                        if (mx>=0 && my>=0 && (mx!=omx || my!=omy)) {
                          percent = (my-16)*100.0/(disp.height()-32);
                          if (percent<0) percent = 0; else if (percent>101) percent = 101;
                          omx = mx; omy = my; res.assign();
                        }
                        is_clicked = true;
                      } else if (is_clicked) break;
                      if (disp.is_closed() || (key && key!=cimg::keyCTRLLEFT)) stopflag = true;
                      if (key==cimg::keyD && disp.is_keyCTRLLEFT()) {
                        disp.resize(cimg_fitscreen(3*disp.width()/2,3*disp.height()/2,1),
                                    stopflag=false).set_key(cimg::keyD,false);
                        res.assign();
                      }
                      if (key==cimg::keyC && disp.is_keyCTRLLEFT()) {
                        disp.resize(cimg_fitscreen(2*disp.width()/3,2*disp.height()/3,1),
                                    stopflag=false).set_key(cimg::keyC,false);
                        res.assign();
                      }
                      if (disp.is_resized()) { disp.resize(false); res.assign(); }
                    }
                    print(images,"Hard-threshold image [%d] by %g = %.3g%%.",
                          selection[l],(double)(vmin + percent*(vmax-vmin)/100),percent);
                    gmic_apply(img,threshold((T)(vmin + percent*(vmax-vmin)/100)));
                  } else { gmic_apply(img,replace(img)); }
                }
              }

#endif // #if cimg_display==0
# 10423 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            }
            is_released = false; continue;
          }

          // Tangent.
          gmic_simple_item("-tan",tan,"Compute pointwise tangent of image%s.");

          // Draw text.
          if (!std::strcmp("-text",command)) {
            gmic_substitute_args();
            CImg<char> text(4096);
            *argx = *argy = *text = *color = 0;
            float x = 0, y = 0, opacity = 1, siz = 13;
            char sepx = 0, sepy = 0;
            if ((std::sscanf(argument,"%4095[^,]%c",
                             text.data(),&end)==1 ||
                 std::sscanf(argument,"%4095[^,],%255[0-9.eE%+-]%c",
                             text.data(),argx,&end)==2 ||
                 std::sscanf(argument,"%4095[^,],%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             text.data(),argx,argy,&end)==3 ||
                 std::sscanf(argument,"%4095[^,],%255[0-9.eE%+-],%255[0-9.eE%+-],%f%c",
                             text.data(),argx,argy,&siz,&end)==4 ||
                 std::sscanf(argument,"%4095[^,],%255[0-9.eE%+-],%255[0-9.eE%+-],%f,%f%c",
                             text.data(),argx,argy,&siz,&opacity,&end)==5 ||
                 std::sscanf(argument,"%4095[^,],%255[0-9.eE%+-],%255[0-9.eE%+-],%f,%f,"
                             "%4095[0-9.eE,+-]%c",
                             text.data(),argx,argy,&siz,&opacity,color,&end)==6) &&
                (!*argx ||
                 std::sscanf(argx,"%f%c",&x,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&x,&sepx,&end)==2 && sepx=='%')) &&
                (!*argy ||
                 std::sscanf(argy,"%f%c",&y,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&y,&sepy,&end)==2 && sepy=='%')) &&
                siz>=0) {
              siz = cimg::round(siz);
              gmic_strreplace(text);
              print(images,"Draw text '%s' at position (%g%s,%g%s) on image%s, with font "
                    "height %g, opacity %g and color (%s).",
                    text.data(),
                    x,sepx=='%'?"%":"",
                    y,sepy=='%'?"%":"",
                    gmic_selection,
                    siz,
                    opacity,
                    *color?color:"default");
              cimg::strunescape(text);
              unsigned int nb_cols = 1;
              for (const char *s = color; *s; ++s) if (*s==',') ++nb_cols;
              cimg_forY(selection,l) {
                CImg<T>
                  &img = images[selection[l]],
                  col(cimg::max(img.spectrum(),(int)nb_cols),1,1,1,0);
                col.fill(color,true);
                const int
                  nx = (int)cimg::round(sepx=='%'?x*(img.width()-1)/100:x),
                  ny = (int)cimg::round(sepy=='%'?y*(img.height()-1)/100:y);
                gmic_apply(img,gmic_draw_text(nx,ny,text,col,0,opacity,(unsigned int)siz,nb_cols));
              }
            } else arg_error("text");
            is_released = false; ++position; continue;
          }

          // Texturize 3d object.
          if (!std::strcmp("-texturize3d",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind_texture, ind_coords;
            char sep = 0;
            *argx = *argy = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                              argx,&sep,&end)==2 && sep==']') ||
                 (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],[%255[a-zA-Z0-9_.%+-]%c%c",
                              argx,argy,&sep,&end)==3 && sep==']')) &&
                (ind_texture=selection2cimg(argx,images.size(),images_names,"-texturize3d",true,
                                            false,CImg<char>::empty())).height()==1 &&
                (!*argy || (ind_coords=selection2cimg(argy,images.size(),images_names,
                                                      "-texturize3d",true,
                                                      false,CImg<char>::empty())).height()==1)) {
              if (ind_coords)
                print(images,
                      "Texturize 3d object%s with texture [%u] and texture coordinates [%u].",
                      gmic_selection,*ind_texture,*ind_coords);
              else
                print(images,"Texturize 3d object%s with texture [%u].",
                      gmic_selection,*ind_texture);
              const CImg<T>
                texture = gmic_image_arg(*ind_texture),
                coords = ind_coords?gmic_image_arg(*ind_coords):CImg<T>();
              cimg_forY(selection,l) {
                const unsigned int ind = selection[l];
                CImg<T>& img = gmic_check(images[ind]);
                try { gmic_apply(img,texturize_CImg3d(texture,coords)); }
                catch (CImgException &e) {
                  if (!img.is_CImg3d(true,message))
                    error(images,"Command '-texturize3d': Invalid 3d object [%d], "
                          "in selected image%s (%s).",
                          ind,gmic_selection,message);
                  else throw e;
                }
              }
            } else arg_error("texturize3d");
            is_released = false; ++position; continue;
          }

          // Tridiagonal solve.
          if (!std::strcmp("-trisolve",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind;
            char sep = 0;
            if (std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 &&
                sep==']' &&
                (ind=selection2cimg(indices,images.size(),images_names,"-trisolve",true,
                                    false,CImg<char>::empty())).height()==1) {
              print(images,"Solve tridiagonal system AX = B, with B-vector%s and tridiagonal "
                    "A-matrix [%d].",
                    gmic_selection,*ind);
              const CImg<T> A = gmic_image_arg(*ind);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],solve_tridiagonal(A));
            } else arg_error("trisolve");
            is_released = false; ++position; continue;
          }

          // Hyperbolic tangent.
          gmic_simple_item("-tanh",tanh,"Compute pointwise hyperbolic tangent of image%s.");

#endif // #ifdef gmic_float
# 10549 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='t'.

        //----------------------------
        // Commands starting by '-u..'
        //----------------------------
        else if (command1=='u') {

          // Unroll.
          if (!std::strcmp("-unroll",command)) {
            gmic_substitute_args();
            char axis = 'y';
            if ((*argument=='x' || *argument=='y' ||
                 *argument=='z' || *argument=='c') && !argument[1]) {
              axis = *argument;
              ++position;
            }
            else axis = 'y';
            print(images,"Unroll image%s along the '%c'-axis.",
                  gmic_selection,
                  axis);
            cimg_forY(selection,l) gmic_apply(images[selection[l]],unroll(axis));
            is_released = false; continue;
          }

          // Remove custom command.
          if (!std::strcmp("-uncommand",item)) {
            gmic_substitute_args();
            if (argument[0]=='*' && !argument[1]) { // Discard all custom commands.
              unsigned int nb_commands = 0;
              for (unsigned int i = 0; i<256; ++i) {
                nb_commands+=commands[i].size();
                commands[i].assign();
                commands_names[i].assign();
                commands_has_arguments[i].assign();
              }
              print(images,"Discard definitions of all custom commmands (%u command%s discarded).",
                    nb_commands,nb_commands>1?"s":"");
            } else { // Discard a single custom command.
              print(images,"Discard last definition of custom command '%s'",argument_text);
              CImg<char> arg_command(argument,std::strlen(argument)+1);
              gmic_strreplace(arg_command);
              bool is_removed = false;
              if (*arg_command) {
                const int ind = gmic_hashcode(arg_command,false);
                cimglist_for(commands_names[ind],l)
                  if (!std::strcmp(commands_names[ind][l],arg_command)) {
                    commands_names[ind].remove(l);
                    commands[ind].remove(l);
                    commands_has_arguments[ind].remove(l);
                    is_removed = true; break;
                  }
              }
              if (verbosity>=0 || is_debug) {
                unsigned int siz = 0;
                for (unsigned int l = 0; l<256; ++l) siz+=commands[l].size();
                std::fprintf(cimg::output()," (%s, %u command%s left).",
                             is_removed?"found":"not found",siz,siz>1?"s":"");
                std::fflush(cimg::output());
              }
            }
            ++position; continue;
          }

        } // command1=='u'.

        //----------------------------
        // Commands starting by '-v..'
        //----------------------------
        else if (command1=='v') {

          // Set verbosity
          // (actually only display a log message, since it has been already processed before).
          if (!std::strcmp("-verbose",item)) {
            if (*argument=='-' && !argument[1])
              print(images,"Decrement verbosity level (set to %d).",
                    verbosity);
            else if (*argument=='+' && !argument[1]) {
              if (verbosity>0) print(images,"Increment verbosity level (set to %d).",
                                     verbosity);
            } else if (verbosity>=0 && old_verbosity>=0)
              print(images,"Set verbosity level to %d.",
                    verbosity);
            if (is_verbose_argument) ++position;
            continue;
          }

          // Vanvliet filter.
          if (!std::strcmp("-vanvliet",command)) {
            gmic_substitute_args();
            unsigned int boundary = 1, order = 0;
            char sep = 0, axis = 0;
            float sigma = 0;
            if ((std::sscanf(argument,"%f,%u,%c%c",&sigma,&order,&axis,&end)==3 ||
                 (std::sscanf(argument,"%f%c,%u,%c%c",&sigma,&sep,&order,&axis,&end)==4 &&
                  sep=='%') ||
                 std::sscanf(argument,"%f,%u,%c,%u%c",&sigma,&order,&axis,&boundary,&end)==4 ||
                 (std::sscanf(argument,"%f%c,%u,%c,%u%c",
                              &sigma,&sep,&order,&axis,&boundary,&end)==5 && sep=='%')) &&
                sigma>=0 && order<=3 && (axis=='x' || axis=='y' || axis=='z' || axis=='c') &&
                boundary<=1) {
              print(images,"Apply Vanvliet filter on image%s, with standard "
                    "deviation %g%s, order %d, axis '%c' and %s boundary conditions.",
                    gmic_selection,
                    sigma,sep=='%'?"%":"",
                    order,axis,
                    boundary?"neumann":"dirichlet");
              if (sep=='%') sigma = -sigma;
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],vanvliet(sigma,order,axis,(bool)boundary));
            } else arg_error("vanvliet");
            is_released = false; ++position; continue;
          }

        } // command1=='v'.

        //----------------------------
        // Commands starting by '-w..'
        //----------------------------
        else if (command1=='w') {

          // While.
          if (!std::strcmp("-while",item)) {
            gmic_substitute_args();
            const CImg<char> &s = scope.back();
            if (s[0]!='*' || s[1]!='d')
              error(images,
                    "Command '-while': Not associated to a '-do' command within the same scope.");
            float _is_cond = 0;
            bool is_filename = false;
            if (std::sscanf(argument,"%f%c",&_is_cond,&end)!=1) {
              is_filename = true;
              CImg<char> arg_while(argument,std::strlen(argument)+1);
              gmic_strreplace(arg_while);
              _is_cond = (float)gmic_check_filename(arg_while);
            }
            const bool is_cond = (bool)_is_cond;
            if (verbosity>0 || is_debug) print(images,"Reach '-while' command -> %s '%s' %s.",
                                               is_filename?"file":"boolean",
                                               argument_text,
                                               is_filename?(is_cond?"exists":
                                                            "does not exist"):
                                               (is_cond?"is true":"is false"));
            if (is_cond) { position = dowhiles.back()(0); continue; }
            else {
              if (verbosity>0 || is_debug) print(images,"End 'do..while' block.");
              dowhiles.remove();
              scope.remove();
            }
            ++position; continue;
          }

          // Warning.
          if (!std::strcmp("-warn",command) && !is_get_version) {
            gmic_substitute_args();
            CImg<char> str(argument,std::strlen(argument)+1);
            cimg::strunescape(str);
            if (is_restriction) warn(images,selection,"%s",str.data());
            else warn(images,"%s",str.data());
            ++position; continue;
          }

#ifdef gmic_float

          // Display images in instant display window.
          unsigned int wind = 0;
          if ((!std::strcmp("-window",command) ||
               std::sscanf(command,"-window%u%c",&wind,&end)==1 ||
               std::sscanf(command,"-w%u%c",&wind,&end)==1) &&
              wind<10 && !is_get_version) {
            gmic_substitute_args();
            int norm = -1, fullscreen = -1;
            float dimw = -1, dimh = -1, posx = -1, posy = -1;
            char sepw = 0, seph = 0, sepx = 0, sepy = 0;
            *argx = *argy = *argz = *argc = *title = 0;
            if ((std::sscanf(argument,"%255[0-9.eE%+-]%c",
                             argx,&end)==1 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-]%c",
                             argx,argy,&end)==2 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%d%c",
                             argx,argy,&norm,&end)==3 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%d,%d%c",
                             argx,argy,&norm,&fullscreen,&end)==4 ||
                 std::sscanf(argument,
                             "%255[0-9.eE%+-],%255[0-9.eE%+-],%d,%d,%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-]%c",
                             argx,argy,&norm,&fullscreen,argz,argc,&end)==6 ||
                 std::sscanf(argument,
                             "%255[0-9.eE%+-],%255[0-9.eE%+-],%d,%d,%255[0-9.eE%+-],"
                             "%255[0-9.eE%+-],%255[^\n]",
                             argx,argy,&norm,&fullscreen,argz,argc,title)==7 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%d,%d,%255[^\n]",
                             &(*argx=*argz=*argc=0),argy,&norm,&fullscreen,title)==5 ||
                 std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%d,%255[^\n]",
                             argx,argy,&(norm=fullscreen=-1),title)==4 ||
                 (norm=fullscreen=-1,std::sscanf(argument,"%255[0-9.eE%+-],%255[0-9.eE%+-],%255[^\n]",
                                                 argx,argy,title))==3) &&
                (std::sscanf(argx,"%f%c",&dimw,&end)==1 ||
                 (std::sscanf(argx,"%f%c%c",&dimw,&sepw,&end)==2 && sepw=='%')) &&
                (!*argy ||
                 std::sscanf(argy,"%f%c",&dimh,&end)==1 ||
                 (std::sscanf(argy,"%f%c%c",&dimh,&seph,&end)==2 && seph=='%')) &&
                (!*argz ||
                 std::sscanf(argz,"%f%c",&posx,&end)==1 ||
                 (std::sscanf(argz,"%f%c%c",&posx,&sepx,&end)==2 && sepx=='%')) &&
                (!*argc ||
                 std::sscanf(argc,"%f%c",&posy,&end)==1 ||
                 (std::sscanf(argc,"%f%c%c",&posy,&sepy,&end)==2 && sepy=='%')) &&
                (dimw>=0 || dimw==-1) &&
                (dimh>=0 || dimh==-1) &&
                norm>=-1 && norm<=3) ++position;
            else {
              dimw = dimh = -1;
              norm = fullscreen = -1;
              posx = posy = -1;
              sepw = seph = 0;
            }
            if (dimh==0) dimw = 0;
            gmic_strreplace(title);
            cimg::strunescape(title);

            // Get images to display and compute associated optimal size.
            unsigned int optw = 0, opth = 0;
            CImgList<T> subimages;
            if (dimw && dimh) cimg_forY(selection,l) {
                const CImg<T>& img = gmic_check(images[selection[l]]);
                if (img) {
                  subimages.insert(img,~0U,true);
                  optw+=img.width() + (img.depth()>1?img.depth():0);
                  if (img.height()>(int)opth) opth = img.height() + (img.depth()>1?img.depth():0);
                }
              }
            optw = optw?optw:sepw=='%'?CImgDisplay::screen_width():256;
            opth = opth?opth:seph=='%'?CImgDisplay::screen_height():256;
            dimw = dimw<0?-1:cimg::round(sepw=='%'?optw*dimw/100:dimw);
            dimh = dimh<0?-1:cimg::round(seph=='%'?opth*dimh/100:dimh);

#if cimg_display==0
            print(images,
                  "Display image%s in instant window [%d] (skipped, no display support).",
                  gmic_selection,
                  wind);
#else // #if cimg_display==0
# 10791 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            const bool is_move = posx!=-1 || posy!=-1;
            bool is_available_display = false;
            try {
              is_available_display = (bool)CImgDisplay::screen_width();
            } catch (CImgDisplayException&) {
              print(images,
                    "Display image%s in instant window [%d] (skipped, no display available).",
                    gmic_selection,
                    wind);
            }
            if (is_available_display) {

              if (!dimw || !dimh) { // Close.
                print(images,"Close instant window [%d].",
                      wind);
                instant_window[wind].assign();
              } else {
                if (instant_window[wind]) { // Update.
                  instant_window[wind].resize(dimw>0?(int)dimw:instant_window[wind].window_width(),
                                              dimh>0?(int)dimh:instant_window[wind].window_height(),
                                              false);
                  if (is_move) {
                    if (sepx=='%') posx*=(CImgDisplay::screen_width()-
                                          instant_window[wind].window_width())/100.0f;
                    if (sepy=='%') posy*=(CImgDisplay::screen_height()-
                                          instant_window[wind].window_height())/100.0f;
                    instant_window[wind].move((int)posx,(int)posy);
                  }
                  if (norm>=0) instant_window[wind]._normalization = norm;
                  if (*title && std::strcmp(instant_window[wind].title(),title))
                    instant_window[wind].set_title("%s",title);
                  if (fullscreen>=0 && (bool)fullscreen!=instant_window[wind].is_fullscreen())
                    instant_window[wind].toggle_fullscreen(false);
                } else { // Create.
                  instant_window[wind].assign(dimw>0?(int)dimw:optw,
                                              dimh>0?(int)dimh:opth,
                                              title,norm<0?3:norm,
                                              fullscreen<0?false:(bool)fullscreen,
                                              is_move);
                  if (is_move) {
                    if (sepx=='%') posx*=(CImgDisplay::screen_width()-
                                          instant_window[wind].window_width())/100.0f;
                    if (sepy=='%') posy*=(CImgDisplay::screen_height()-
                                          instant_window[wind].window_height())/100.0f;
                    instant_window[wind].move((int)posx,(int)posy);
                  }
                  if (norm==2) {
                    if (subimages)
                      instant_window[wind]._max =
                        (float)subimages.max_min(instant_window[wind]._min);
                    else { instant_window[wind]._min = 0; instant_window[wind]._max = 255; }
                  }
                }
                if (is_move) print(images,
                                   "Display image%s in %dx%d %sinstant window [%d], "
                                   "with%snormalization, "
                                   "%sfullscreen, at position (%s,%s) and title '%s'.",
                                   gmic_selection,
                                   instant_window[wind].width(),
                                   instant_window[wind].height(),
                                   instant_window[wind].is_fullscreen()?"fullscreen ":"",
                                   wind,
                                   instant_window[wind].normalization()==0?"out ":
                                   instant_window[wind].normalization()==1?" ":
                                   instant_window[wind].normalization()==2?" 1st-time ":" auto-",
                                   instant_window[wind].is_fullscreen()?"":"no ",
                                   argz,argc,
                                   instant_window[wind].title());
                else print(images,
                           "Display image%s in %dx%d %sinstant window [%d], with%snormalization, "
                           "%sfullscreen and title '%s'.",
                           gmic_selection,
                           instant_window[wind].width(),
                           instant_window[wind].height(),
                           instant_window[wind].is_fullscreen()?"fullscreen ":"",
                           wind,
                           instant_window[wind].normalization()==0?"out ":
                           instant_window[wind].normalization()==1?" ":
                           instant_window[wind].normalization()==2?" 1st-time ":" auto-",
                           instant_window[wind].is_fullscreen()?"":"no ",
                           instant_window[wind].title());
                if (subimages) subimages.display(instant_window[wind]);
              }
            }

#endif // #if cimg_display==0
# 10877 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            is_released = true; continue;
          }

          // Warp.
          if (!std::strcmp("-warp",command)) {
            gmic_substitute_args();
            unsigned int interpolation = 1, is_relative = 0, boundary = 1;
            CImg<unsigned int> ind;
            float nb_frames = 1;
            char sep = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",
                              indices,&sep,&end)==2 && sep==']')||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u%c",
                             indices,&is_relative,&end)==2 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u%c",
                             indices,&is_relative,&interpolation,&end)==3 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u,%u%c",
                             indices,&is_relative,&interpolation,&boundary,&end)==4 ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u,%u,%u,%f%c",
                             indices,&is_relative,&interpolation,&boundary,&nb_frames,&end)==5) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-warp",true,
                                    false,CImg<char>::empty())).height()==1 &&
                is_relative<=1 && interpolation<=2 && boundary<=2 && nb_frames>=0.5) {
              const CImg<T> warping_field = gmic_image_arg(*ind);
              nb_frames = cimg::round(nb_frames);
              if (nb_frames==1) {
                print(images,"Warp image%s with %s displacement field [%u], %s interpolation, "
                      "%s boundary conditions.",
                      gmic_selection,
                      is_relative?"relative":"absolute",*ind,
                      interpolation==2?"cubic":interpolation==1?"linear":"nearest-neighbor",
                      boundary==0?"dirichlet":boundary==1?"neumann":"cyclic");
                cimg_forY(selection,l)
                  gmic_apply(images[selection[l]],warp(warping_field,(bool)is_relative,
                                                       interpolation,boundary));
              } else {
                print(images,"Warp image%s with %s displacement field [%u], %s interpolation, "
                      "%s boundary conditions and %d frames.",
                      gmic_selection,
                      is_relative?"relative":"absolute",*ind,
                      interpolation==2?"cubic":interpolation==1?"linear":"nearest-neighbor",
                      boundary==0?"dirichlet":boundary==1?"neumann":"cyclic",
                      (int)nb_frames);
                unsigned int off = 0;
                cimg_forY(selection,l) {
                  const unsigned int _ind = selection[l] + off;
                  CImg<T>& img = gmic_check(images[_ind]);
                  CImg<char> name = images_names[_ind].get_mark();
                  CImgList<T> frames((int)nb_frames);
                  cimglist_for(frames,t)
                    frames[t] = img.get_warp(warping_field*((t+1.0f)/nb_frames),(bool)is_relative,
                                             interpolation,boundary);
                  if (is_get_version) {
                    images_names.insert((int)nb_frames,name.copymark());
                    frames.move_to(images,~0U);
                  } else {
                    off+=(int)nb_frames - 1;
                    images_names.insert((int)nb_frames - 1,name.get_copymark(),_ind);
                    images.remove(_ind); frames.move_to(images,_ind);
                  }
                }
              }
            } else arg_error("warp");
            is_released = false; ++position; continue;
          }

          // Watershed transform.
          if (!std::strcmp("-watershed",command)) {
            gmic_substitute_args();
            CImg<unsigned int> ind;
            unsigned int is_filled = 1;
            char sep = 0;
            if (((std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sep,&end)==2 &&
                  sep==']') ||
                 std::sscanf(argument,"[%255[a-zA-Z0-9_.%+-]],%u%c",
                             indices,&is_filled,&end)==2) &&
                (ind=selection2cimg(indices,images.size(),images_names,"-watershed",true,
                                    false,CImg<char>::empty())).height()==1 &&
                is_filled<=1) {
              print(images,"Compute watershed transform of image%s with priority map [%u] and "
                    "%sfilling.",
                    gmic_selection,*ind,is_filled?"":"no ");
              const CImg<T> priority = gmic_image_arg(*ind);
              cimg_forY(selection,l)
                gmic_apply(images[selection[l]],watershed(priority,(bool)is_filled));
            } else arg_error("watershed");
            is_released = false; ++position; continue;
          }

          // Wait for a given delay of for user events on instant window.
          if (!std::strcmp("-wait",command) && !is_get_version) {
            gmic_substitute_args();
            if (!is_restriction)
              CImg<unsigned int>::vector(0,1,2,3,4,5,6,7,8,9).move_to(selection);
            float delay = 0;
            if (std::sscanf(argument,"%f%c",
                            &delay,&end)==1) ++position;
            else delay = 0;
            delay = cimg::round(delay);
#if cimg_display==0
            if (!delay)
              print(images,
                    "Wait for user events on instant window%s (skipped, no display support).",
                    gmic_selection);
            else {
              print(images,
                    "%s for %g milliseconds according to instant window%s.",
                    delay<0?"Sleep":"Wait",delay,
                    gmic_selection);
              if (delay<0) cimg::sleep((unsigned int)-delay);
              else cimg::wait((unsigned int)delay);
            }
#else // #if cimg_display==0
# 10990 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            if (!delay) {
              print(images,"Wait for user events on instant window%s.",
                    gmic_selection);
              CImgDisplay *const iw = instant_window;
              switch (selection.height()) {
              case 1 : CImgDisplay::wait(iw[selection[0]]); break;
              case 2 : CImgDisplay::wait(iw[selection[0]],iw[selection[1]]); break;
              case 3 : CImgDisplay::wait(iw[selection[0]],iw[selection[1]],iw[selection[2]]);
                break;
              case 4 : CImgDisplay::wait(iw[selection[0]],iw[selection[1]],iw[selection[2]],
                                         iw[selection[3]]);
                break;
              case 5 : CImgDisplay::wait(iw[selection[0]],iw[selection[1]],iw[selection[2]],
                                         iw[selection[3]],iw[selection[4]]);
                break;
              case 6 : CImgDisplay::wait(iw[selection[0]],iw[selection[1]],iw[selection[2]],
                                         iw[selection[3]],iw[selection[4]],iw[selection[5]]);
                break;
              case 7 : CImgDisplay::wait(iw[selection[0]],iw[selection[1]],iw[selection[2]],
                                         iw[selection[3]],iw[selection[4]],iw[selection[5]],
                                         iw[selection[6]]);
                break;
              case 8 : CImgDisplay::wait(iw[selection[0]],iw[selection[1]],iw[selection[2]],
                                         iw[selection[3]],iw[selection[4]],iw[selection[5]],
                                         iw[selection[6]],iw[selection[7]]);
                break;
              case 9 : CImgDisplay::wait(iw[selection[0]],iw[selection[1]],iw[selection[2]],
                                         iw[selection[3]],iw[selection[4]],iw[selection[5]],
                                         iw[selection[6]],iw[selection[7]],iw[selection[8]]);
                break;
              case 10 : CImgDisplay::wait(iw[selection[0]],iw[selection[1]],iw[selection[2]],
                                          iw[selection[3]],iw[selection[4]],iw[selection[5]],
                                          iw[selection[6]],iw[selection[7]],iw[selection[8]],
                                          iw[selection[9]]);
                break;
              }
            } else if (delay<0) {
              print(images,
                    "Flush display events of instant window%s and wait for %g milliseconds.",
                    gmic_selection,-delay);
              cimg_forY(selection,l) instant_window[selection[l]].flush();
              if (selection && instant_window[selection[0]])
                instant_window[selection[0]].wait((unsigned int)-delay);
              else cimg::sleep((unsigned int)-delay);
            } else {
              print(images,"Wait for %g milliseconds according to instant window%s.",
                    delay,
                    gmic_selection);
              if (selection && instant_window[selection[0]])
                instant_window[selection[0]].wait((unsigned int)delay);
              else cimg::wait((unsigned int)delay);
            }
#endif // #if cimg_display==0
# 11043 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            continue;
          }

#endif // #ifdef gmic_float
# 11047 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='w'.

        //----------------------------
        // Commands starting by '-x..'
        //----------------------------
        else if (command1=='x') {

#ifdef gmic_float

          // Bitwise xor.
          gmic_arithmetic_item("-xor",
                               operator^=,
                               "Compute bitwise XOR of image%s by %g%s",
                               gmic_selection,value,ssep,Tlong,
                               operator^=,
                               "Compute bitwise XOR of image%s by image [%d]",
                               gmic_selection,ind[0],
                               "Compute bitwise XOR of image%s by expression %s",
                               gmic_selection,argument_text,
                               "Compute sequential bitwise XOR of image%s");

#endif // #ifdef gmic_float
# 11069 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
        } // command1=='x'.

        //----------------------------
        // Other (special) commands.
        //----------------------------

        // If..[elif]..[else]..endif.
        if (!std::strcmp("-if",item) || (!std::strcmp("-elif",item) && check_elif)) {
          gmic_substitute_args();
          check_elif = false;
          float _is_cond = 0;
          bool is_filename = false;
          if (std::sscanf(argument,"%f%c",&_is_cond,&end)!=1) {
            is_filename = true;
            CImg<char> arg_if(argument,std::strlen(argument)+1);
            gmic_strreplace(arg_if);
            _is_cond = (float)gmic_check_filename(arg_if);
          }
          const bool is_cond = (bool)_is_cond;
          if (item[1]=='i') {
            CImg<char>::string("*if").move_to(scope);
            if (verbosity>0 || is_debug) print(images,"Start '-if..-endif' block -> %s '%s' %s.",
                                               is_filename?"file":"boolean",
                                               argument_text,
                                               is_filename?(is_cond?"exists":"does not exist"):
                                               (is_cond?"is true":"is false"));
          } else if (verbosity>0 || is_debug) print(images,"Reach '-elif' block -> %s '%s' %s.",
                                                    is_filename?"file":"boolean",
                                                    argument_text,
                                                    is_filename?(is_cond?"exists":
								 "does not exist"):
                                                    (is_cond?"is true":"is false"));
          if (!is_cond) {
            for (int nb_ifs = 1; nb_ifs && position<commands_line.size(); ++position) {
              const char *const it = commands_line[position].data();
              if (!std::strcmp("-if",it)) ++nb_ifs;
              else if (!std::strcmp("-endif",it)) { --nb_ifs; if (!nb_ifs) --position; }
              else if (nb_ifs==1) {
                if (!std::strcmp("-else",it)) --nb_ifs;
                else if (!std::strcmp("-elif",it)) { --nb_ifs; check_elif = true; --position;}
              }
            }
            continue;
          }
          ++position; continue;
        }

        // Break and continue.
        bool is_continue = false;
        if (!std::strcmp("-break",item) ||
            (!std::strcmp("-continue",item) && (is_continue=true)==true)) {
          const char
	    *const com = is_continue?"continue":"break",
	    *const Com = is_continue?"Continue":"Break";
          unsigned int scope_repeat = 0, scope_do = 0, scope_local = 0;
          for (unsigned int l = scope.size() - 1; l; --l) {
            const char *const s = scope[l].data();
            if (s[0]=='*' && s[1]=='r') { scope_repeat = l; break; }
            else if (s[0]=='*' && s[1]=='d') { scope_do = l; break; }
            else if (s[0]=='*' && s[1]=='l') { scope_local = l; break; }
            else if (s[0]!='*' || s[1]!='i') break;
          }
          const char *stb = 0, *ste = 0;
          unsigned int scope_ind = 0;
          int level = 0;
          if (scope_repeat) {
            print(images,"%s %scurrent 'repeat..done' block.",
                  Com,is_continue?"to next iteration of ":"");
            for (level = 1; level && position<commands_line.size(); ++position) {
              const char *it = commands_line[position].data();
              if (!std::strcmp("-repeat",it)) ++level;
              else if (!std::strcmp("-done",it)) --level;
            }
            scope_ind = scope_repeat;
            stb = "repeat"; ste = "done";
          } else if (scope_do) {
            print(images,"%s %scurrent 'do..while' block.",
                  Com,is_continue?"to next iteration of ":"");
            for (level = 1; level && position<commands_line.size(); ++position) {
              const char *it = commands_line[position].data();
              if (!std::strcmp("-do",it)) ++level;
              else if (!std::strcmp("-while",it)) --level;
            }
            scope_ind = scope_do;
            stb = "do"; ste = "while";
          } else if (scope_local) {
            print(images,"%s %scurrent local environment.",
                  Com,is_continue?"to end of ":"");
            for (level = 1; level && position<commands_line.size(); ++position) {
              const char *it = commands_line[position].data();
              if (!std::strcmp("-local",it) || !std::strcmp("-l",it) ||
                  !std::strcmp("--local",it) || !std::strcmp("--l",it) ||
                  !std::strncmp("-local[",it,7) || !std::strncmp("-l[",it,3) ||
                  !std::strncmp("--local[",it,8) || !std::strncmp("--l[",it,4)) ++level;
              else if (!std::strcmp("-endlocal",it) || !std::strcmp("-endl",it)) --level;
            }
            scope_ind = scope_local;
            stb = "local"; ste = "endlocal";
          } else {
            print(images,"%s",Com);
            error(images,"Command '-%s': There are no loops or local environment to %s.",com,com);
            continue;
          }
          if (level && position>=commands_line.size())
            error(images,"Command '-%s': Missing associated '-%s' command.",stb,ste);
          if (is_continue || scope_local) {
	    if (scope_ind<scope.size()-1) scope.remove(scope_ind+1,scope.size()-1);
	    --position;
	  } else {
            scope.remove(scope_ind,scope.size()-1);
            if (scope_do) { dowhiles.remove(); ++position; } else repeatdones.remove();
          }
          continue;
        }

        // Quit.
        if (!std::strcmp("-quit",item)) {
          print(images,"Quit G'MIC instance.\n");
          dowhiles.assign();
          repeatdones.assign();
          position = commands_line.size();
          is_released = is_quit = true;
          break;
        }

#ifdef gmic_float

        // Compute direct or inverse FFT.
        const bool inv_fft = !std::strcmp("-ifft",command);
        if (!std::strcmp("-fft",command) || inv_fft) {
          print(images,"Compute %sfourier transform of image%s with complex pair%s",
                inv_fft?"inverse ":"",
                gmic_selection,
                selection.height()>2?"s":"");
          cimg_forY(selection,l) {
            const unsigned int
	      ind0 = selection[l],
	      ind1 = l+1<selection.height()?selection[l+1]:~0U;
            CImg<T> &img0 = gmic_check(images[ind0]),
                    &img1 = ind1!=~0U?gmic_check(images[ind1]):CImg<T>::empty();
            CImg<char> name = images_names[ind0].get_mark();
            if (ind1!=~0U) { // Complex transform.
              if (verbosity>=0 || is_debug) {
                std::fprintf(cimg::output()," ([%u],[%u])%c",ind0,ind1,
			     l>=selection.height()-2?'.':',');
                std::fflush(cimg::output());
              }
              if (is_get_version) {
                CImgList<T> fft(img0,img1);
                fft.FFT(inv_fft);
                fft.move_to(images,~0U);
                images_names.insert(2,name.copymark());
              } else {
                CImgList<T> fft(2);
                fft[0].swap(img0);
                fft[1].swap(img1);
                fft.FFT(inv_fft);
                fft[0].swap(img0);
                fft[1].swap(img1);
                name.get_copymark().move_to(images_names[ind1]);
                name.move_to(images_names[ind0]);
              }
              ++l;
            } else { // Real transform.
              if (verbosity>=0 || is_debug) {
                std::fprintf(cimg::output()," ([%u],0)",ind0);
                std::fflush(cimg::output());
              }
              if (is_get_version) {
                CImgList<T> fft(img0);
                CImg<T>(fft[0].width(),fft[0].height(),fft[0].depth(),fft[0].spectrum(),0).
                  move_to(fft);
                fft.FFT(inv_fft);
                fft.move_to(images,~0U);
                images_names.insert(2,name.copymark());
              } else {
                CImgList<T> fft(1);
                fft[0].swap(img0);
                CImg<T>(fft[0].width(),fft[0].height(),fft[0].depth(),fft[0].spectrum(),0).
                  move_to(fft);
                fft.FFT(inv_fft);
                fft[0].swap(img0);
                fft[1].move_to(images,ind0+1);
                name.get_copymark().move_to(images_names,ind0+1);
                name.move_to(images_names[ind0]);
              }
            }
          }
          is_released = false; continue;
        }

        // Inverse scale of a 3d object.
        const bool divide3d = !std::strcmp("-div3d",command);
        if (!std::strcmp("-mul3d",command) || divide3d) {
          gmic_substitute_args();
          float sx = 0, sy = 1, sz = 1;
          if ((std::sscanf(argument,"%f%c",
                           &sx,&end)==1 && ((sz=sy=sx),1)) ||
              std::sscanf(argument,"%f,%f%c",
                          &sx,&sy,&end)==2 ||
              std::sscanf(argument,"%f,%f,%f%c",
                          &sx,&sy,&sz,&end)==3) {
            if (divide3d)
              print(images,"Scale 3d object%s with factors (1/%g,1/%g,1/%g).",
                    gmic_selection,
                    sx,sy,sz);
            else
              print(images,"Scale 3d object%s with factors (%g,%g,%g).",
                    gmic_selection,
                    sx,sy,sz);
            cimg_forY(selection,l) {
              const unsigned int ind = selection[l];
              CImg<T>& img = gmic_check(images[ind]);
              try {
                if (divide3d) { gmic_apply(img,scale_CImg3d(1/sx,1/sy,1/sz)); }
                else { gmic_apply(img,scale_CImg3d(sx,sy,sz)); }
              } catch (CImgException &e) {
                if (!img.is_CImg3d(true,message))
                  error(images,"Command '-%s3d': Invalid 3d object [%d], in selected image%s "
                        "(%s).",
                        divide3d?"div":"mul",ind,gmic_selection,message);
                else throw e;
              }
            }
          } else { if (divide3d) arg_error("div3d"); else arg_error("mul3d"); }
          is_released = false; ++position; continue;
        }

#endif // #ifdef gmic_float
# 11298 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

        // Check for a custom command, and execute it, if found.
        if (std::strcmp("-input",command)) {
          const char *custom_command = 0, cc = *(command+1);
          bool custom_command_found = false, has_arguments = false;
          CImg<char> substituted_command;
          if ((cc>='a' && cc<='z') || (cc>='A' && cc<='Z') || cc=='_') {
            const int ind = gmic_hashcode(command+1,false);
            cimglist_for(commands_names[ind],l) {
              custom_command = commands_names[ind][l].data();
              const char *const command_code = commands[ind][l].data();
              if (!std::strcmp(command+1,custom_command)) {
                custom_command_found = true;
                if (is_debug) {
                  CImg<char> command_code_text(264);
                  const unsigned int ls = std::strlen(command_code);
                  if (ls>=264) {
                    std::memcpy(command_code_text.data(),command_code,128);
                    std::memcpy(command_code_text.data()+128," ... ",5);
                    std::memcpy(command_code_text.data()+133,command_code+ls-130,131);
                  } else std::strcpy(command_code_text.data(),command_code);
                  for (char *ptrs = command_code_text, *ptrd = ptrs; *ptrs || (bool)(*ptrd=0); ++ptrs)
                    if (*ptrs==1) while (*ptrs!=' ') ++ptrs; else *(ptrd++) = *ptrs;
                  debug(images,"Found custom command '%s: %s' (%s).",
                        custom_command,command_code_text.data(),
                        commands_has_arguments[ind](l,0)?"takes arguments":"takes no arguments");
                }
                CImgList<char> arguments(32);
                // Set $0 to be the command name.
                CImg<char>::string(custom_command).move_to(arguments[0]);
                unsigned int nb_arguments = 0;

                if (commands_has_arguments[ind](l,0)) { // Command takes arguments.
                  gmic_substitute_args();

                  // Extract possible command arguments.
                  for (const char *ss = argument, *_ss = ss; _ss; ss =_ss+1)
                    if ((_ss=std::strchr(ss,','))!=0) {
                      if (ss==_ss) ++nb_arguments;
                      else {
                        if (++nb_arguments>=arguments.size())
                          arguments.insert(2+2*nb_arguments-arguments.size());
                        CImg<char> arg_item(ss,_ss-ss+1);
                        arg_item.back() = 0;
                        arg_item.move_to(arguments[nb_arguments]);
                      }
                    } else {
                      if (*ss) {
                        if (++nb_arguments>=arguments.size())
                          arguments.insert(1+nb_arguments-arguments.size());
                        if (*ss!=',') CImg<char>::string(ss).move_to(arguments[nb_arguments]);
                      }
                      break;
                    }

                  if (is_debug) {
                    debug(images,"Found %d given argument%s for command '%s'%s",
                          nb_arguments,nb_arguments!=1?"s":"",
                          custom_command,nb_arguments>0?":":".");
                    for (unsigned int i = 1; i<=nb_arguments; ++i)
                      if (arguments[i]) debug(images,"  $%d = '%s'",i,arguments[i].data());
                      else debug(images,"  $%d = (undefined)",i);
                  }
                }

                // Substitute arguments in custom command expression.
                CImgList<char> substituted_items;
                CImg<char> inbraces;
                for (const char *nsource = command_code; *nsource;)
                  if (*nsource!='$') {
                    // If not starting with '$'.
                    const char *const nsource0 = nsource;
                    nsource = std::strchr(nsource0,'$');
                    if (!nsource) nsource = &commands[ind][l].back();
                    CImg<char>(nsource0,nsource-nsource0).move_to(substituted_items);
                  } else { // '$' expression found.
                    CImg<char> substr(324);
                    inbraces.assign(1,1,1,1,0);
                    int ind = 0, ind1 = 0, l_inbraces = 0;
                    bool is_braces = false;
                    char sep = 0;

                    if (nsource[1]=='{') {
                      const char *const ptr_beg = nsource + 2, *ptr_end = ptr_beg;
                      unsigned int p = 0;
                      for (p = 1; p>0 && *ptr_end; ++ptr_end) {
                        if (*ptr_end=='{') ++p;
                        if (*ptr_end=='}') --p;
                      }
                      if (p) { CImg<char>(nsource++,1).move_to(substituted_items); continue; }
                      l_inbraces = ptr_end - ptr_beg - 1;
                      if (l_inbraces>0) inbraces.assign(ptr_beg,l_inbraces + 1).back() = 0;
                      is_braces = true;
                    }

                    // Substitute $? -> string describing image indices.
                    if (nsource[1]=='?') {
                      nsource+=2;
                      cimg_snprintf(substr,substr.width(),"%s",gmic_selection);
                      CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);

                      // Substitute $# -> maximum indice of known arguments.
                    } else if (nsource[1]=='#') {
                      nsource+=2;
                      cimg_snprintf(substr,substr.width(),"%u",nb_arguments);
                      CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
                      has_arguments = true;

                      // Substitute $* -> copy of the specified arguments string.
                    } else if (nsource[1]=='*') {
                      nsource+=2;
                      CImg<char>(argument,std::strlen(argument)).move_to(substituted_items);
                      has_arguments = true;

                      // Substitute $"*" -> copy of the specified "quoted" arguments string.
                    } else if (nsource[1]=='\"' && nsource[2]=='*' && nsource[3]=='\"') {
                      nsource+=4;
                      for (unsigned int i = 1; i<=nb_arguments; ++i) {
                        CImg<char>(1,1,1,1,'\"').move_to(substituted_items);
                        CImg<char>(arguments[i].data(),arguments[i].width()-1).
                          move_to(substituted_items);
                        if (i==nb_arguments) CImg<char>(1,1,1,1,'\"').move_to(substituted_items);
                        else CImg<char>(2,1,1,1,'\"',',').move_to(substituted_items);
                      }
                      has_arguments = true;

                      // Substitute $= -> transfer (quoted) arguments to named variables.
                    } else if (nsource[1]=='=' &&
                               std::sscanf(nsource+2,"%255[a-zA-Z0-9_]",title)==1 &&
                               (*title<'0' || *title>'9')) {
                      nsource+=2+std::strlen(title);
                      for (unsigned int i = 0; i<=nb_arguments; ++i) {
                        cimg_snprintf(substr,substr.width()," %s%u=\"",title,i);
                        CImg<char>(substr.data(),std::strlen(substr)).move_to(substituted_items);
                        CImg<char>(arguments[i].data(),arguments[i].width()-1).
                          move_to(substituted_items);
                        CImg<char>(2,1,1,1,'\"',' ').move_to(substituted_items);
                      }
                      has_arguments = true;

                      // Substitute $i and ${i} -> value of the i^th argument.
                    } else if ((std::sscanf(nsource,"$%d",&ind)==1 ||
                                (std::sscanf(nsource,"${%d%c",&ind,&sep)==2 && sep=='}'))) {
                      const int nind = ind + (ind<0?(int)nb_arguments+1:0);
                      if ((nind<=0 && ind) || nind>=arguments.width() || !arguments[nind]) {
                        error(custom_command,images,
                              "Command '-%s': Undefined argument '$%d', in expression '$%s%d%s' "
                              "(for %u argument%s specified).",
                              custom_command,ind,sep=='}'?"{":"",ind,sep=='}'?"}":"",
                              nb_arguments,nb_arguments!=1?"s":"");
                      }
                      nsource+=cimg_snprintf(substr,substr.width(),"$%d",ind) + (sep=='}'?2:0);
                      if (arguments[nind].width()>1)
                        CImg<char>(arguments[nind].data(),arguments[nind].width()-1).
                          move_to(substituted_items);
                      if (nind!=0) has_arguments = true;

                      // Substitute ${i=$j} -> value of the i^th argument, or the default value,
                      // i.e. the value of another argument.
                    } else if (std::sscanf(nsource,"${%d=$%d%c",&ind,&ind1,&sep)==3 && sep=='}' &&
                               ind>0) {
                      const int nind1 = ind1 + (ind1<0?(int)nb_arguments+1:0);
                      if (nind1<=0 || nind1>=arguments.width() || !arguments[nind1])
                        error(custom_command,images,
                              "Command '-%s': Undefined argument '$%d', in expression '${%d=$%d}' "
                              "(for %u argument%s specified).",
                              custom_command,ind1,ind,ind1,
                              nb_arguments,nb_arguments!=1?"s":"");
                      nsource+=cimg_snprintf(substr,substr.width(),"${%d=$%d}",ind,ind1);
                      if (ind>=arguments.width()) arguments.insert(2+2*ind-arguments.size());
                      if (!arguments[ind]) {
                        arguments[ind] = arguments[nind1];
                        if (ind>(int)nb_arguments) nb_arguments = ind;
                      }
                      if (arguments[ind].width()>1)
                        CImg<char>(arguments[ind].data(),arguments[ind].width()-1).
                          move_to(substituted_items);
                      has_arguments = true;

                      // Substitute ${i=$#} -> value of the i^th argument, or the default value,
                      // i.e. the maximum indice of known arguments.
                    } else if (std::sscanf(nsource,"${%d=$#%c",&ind,&sep)==2 && sep=='}' &&
                               ind>0) {
                      if (ind>=arguments.width()) arguments.insert(2+2*ind-arguments.size());
                      if (!arguments[ind]) {
                        cimg_snprintf(substr,substr.width(),"%u",nb_arguments);
                        CImg<char>::string(substr).move_to(arguments[ind]);
                        if (ind>(int)nb_arguments) nb_arguments = ind;
                      }
                      nsource+=cimg_snprintf(substr,substr.width(),"${%d=$#}",ind);
                      if (arguments[ind].width()>1)
                        CImg<char>(arguments[ind].data(),arguments[ind].width()-1).
                          move_to(substituted_items);
                      has_arguments = true;

                      // Substitute ${i=default} -> value of the i^th argument,
                      // or the specified default value.
                    } else if (std::sscanf(inbraces,"%d%c",&ind,&sep)==2 && sep=='=' &&
                               ind>0) {
                      nsource+=l_inbraces + 3;
                      if (ind>=arguments.width()) arguments.insert(2+2*ind-arguments.size());
                      if (!arguments[ind]) {
                        CImg<char>::string(inbraces.data() +
                                           cimg_snprintf(substr,substr.width(),"%d=",ind)).
                          move_to(arguments[ind]);
                        if (ind>(int)nb_arguments) nb_arguments = ind;
                      }
                      if (arguments[ind].width()>1)
                        CImg<char>(arguments[ind].data(),arguments[ind].width()-1).
                          move_to(substituted_items);
                      has_arguments = true;

                      // Substitute any other expression starting by '$'.
                    } else {

                      // Substitute ${subset} -> values of the selected subset of arguments,
                      // separated by ','.
                      if (is_braces) {
                        if ((*inbraces>='a' && *inbraces<='z') ||
                            (*inbraces>='A' && *inbraces<='Z') ||
                            *inbraces=='_') {
                          CImg<char>(nsource++,1).move_to(substituted_items);
                        } else if (*inbraces) {
                          CImg<unsigned int> inds;
                          const int _verbosity = verbosity;
                          const bool _is_debug = is_debug;
                          bool is_valid_subset = true;
                          verbosity = -16384; is_debug = false;
                          try {
                            inds = selection2cimg(inbraces,nb_arguments+1,
                                                  CImgList<char>::empty(),"",false,
                                                  false,CImg<char>::empty());
                          } catch (...) { inds.assign(); is_valid_subset = false; }
                          verbosity = _verbosity; is_debug = _is_debug;
                          if (is_valid_subset) {
                            nsource+=l_inbraces + 3;
                            if (inds) {
                              cimg_forY(inds,j) {
                                const unsigned int ind = inds[j];
                                if (ind) has_arguments = true;
                                if (!arguments[ind])
                                  error(custom_command,images,
                                        "Command '-%s': Undefined argument '$%d', "
                                        "in expression '${%s}'.",
                                        custom_command,ind,inbraces.data());
                                substituted_items.insert(arguments[ind]);
                                substituted_items.back().back() = ',';
                              }
                              if (substituted_items.back().width()>1)
                                --(substituted_items.back()._width);
                              else substituted_items.remove();
                              has_arguments = true;
                            }
                          } else CImg<char>(nsource++,1).move_to(substituted_items);
                        } else nsource+=3; // Substitute '${}' by ''.
                      } else CImg<char>(nsource++,1).move_to(substituted_items);
                    }
                  }
                CImg<char>::vector(0).move_to(substituted_items);
                (substituted_items>'x').move_to(substituted_command);

                // Substitute special character codes appearing outside strings.
                bool is_dquoted = false;
                for (char *s = substituted_command.data(); *s; ++s) {
                  const char c = *s;
                  if (c=='\"') is_dquoted = !is_dquoted;
                  if (!is_dquoted) *s = c<' '?(c==_dollar?'$':c==_lbrace?'{':c==_rbrace?'}':
                                               c==_comma?',':c==_dquote?'\"':c==_arobace?'@':c):c;
                }

                if (is_debug) {
                  CImg<char> command_code_text(264);
                  const unsigned int l = std::strlen(substituted_command.data());
                  if (l>=264) {
                    std::memcpy(command_code_text.data(),substituted_command.data(),128);
                    std::memcpy(command_code_text.data()+128," ... ",5);
                    std::memcpy(command_code_text.data()+133,substituted_command.data()+l-130,131);
                  } else std::strcpy(command_code_text.data(),substituted_command.data());
                  for (char *ptrs = command_code_text, *ptrd = ptrs; *ptrs || (bool)(*ptrd=0); ++ptrs)
                    if (*ptrs==1) while (*ptrs!=' ') ++ptrs; else *(ptrd++) = *ptrs;
                  debug(images,"Expand command line for command '%s' to: '%s'.",
                        custom_command,command_code_text.data());
                }
                break;
              }
            }
          }

          if (custom_command_found) {
            const CImgList<char>
	      ncommands_line = commands_line_to_CImgList(substituted_command.data());
            unsigned int nvariables_sizes[256];
	    for (unsigned int l = 0; l<256; ++l) nvariables_sizes[l] = variables[l]->size();
            CImgList<char> nimages_names(selection.height());
            CImgList<T> nimages(selection.height());
            unsigned int nposition = 0;
            CImg<char>::string(custom_command).move_to(scope);
            if (is_get_version) {
              cimg_forY(selection,l) {
                nimages[l] = images[selection[l]];
                nimages_names[l] = images_names[selection[l]];
              }
              _parse(ncommands_line,nposition,nimages,nimages_names,nvariables_sizes);
              nimages.move_to(images,~0U);
              cimglist_for(nimages_names,l) nimages_names[l].copymark();
              nimages_names.move_to(images_names,~0U);
            } else {
              cimg_forY(selection,l) {
                if (images[selection[l]].is_shared())
                  nimages[l] = CImg<T>(images[selection[l]],true);
                else nimages[l].swap(images[selection[l]]);
                nimages_names[l].swap(images_names[selection[l]]);
              }
              _parse(ncommands_line,nposition,nimages,nimages_names,nvariables_sizes);
              const unsigned int nb = cimg::min((unsigned int)selection.height(),nimages.size());
              if (nb>0) {
                for (unsigned int i = 0; i<nb; ++i) {
                  if (images[selection[i]].is_shared()) {
                    images[selection[i]] = nimages[i];
                    nimages[i].assign();
                  } else images[selection[i]].swap(nimages[i]);
                  images_names[selection[i]].swap(nimages_names[i]);
                }
                nimages.remove(0,nb-1);
                nimages_names.remove(0,nb-1);
              }
              if (nb<(unsigned int)selection.height())
                remove_images(images,images_names,selection,nb,selection.height()-1);
              else if (nimages) {
                const unsigned int ind0 = selection?selection.back()+1:images.size();
                nimages_names.move_to(images_names,ind0);
                nimages.move_to(images,ind0);
              }
            }
	    for (unsigned int l = 0; l<255; ++l) if (variables[l]->size()>nvariables_sizes[l]) {
		variables_names[l]->remove(nvariables_sizes[l],variables[l]->size()-1);
		variables[l]->remove(nvariables_sizes[l],variables[l]->size()-1);
	      }
            scope.remove();
            is_return = false;
            if (has_arguments) ++position;
            continue;
          }
        }
      }  // if (*item=='-') {

      // Variable assignment.
      char sep = 0;
      if (std::strchr(item,'=') && std::sscanf(item,"%255[a-zA-Z0-9_]%c",title,&sep)==2 &&
          sep=='=' && (*title<'0' || *title>'9')) {
        CImg<char>
          name(title,std::strlen(title)+1),
          value = CImg<char>::string(item+name.width());
        int ind = 0; bool is_name_found = false;
        const bool is_global = *name=='_';
        const unsigned int sind = gmic_hashcode(name,true);
	const int lind = is_global?0:variables_sizes[sind];
        if (is_global) cimg::mutex(29);
        CImgList<char>
	  &__variables = *variables[sind],
	  &__variables_names = *variables_names[sind];
	for (int l = __variables.size()-1; l>=lind; --l)
	  if (!std::strcmp(__variables_names[l],name)) {
	    is_name_found = true; ind = l; break;
	  }
        print(images,"Set %s variable %s='%s'.",
              *name=='_'?"global":"local",
              name.data(),value.data());
        if (is_name_found) value.move_to(__variables[ind]);
        else { name.move_to(__variables_names); value.move_to(__variables); }
        if (is_global) cimg::mutex(29,0);
        continue;
      }

      // Input.
      if (!std::strcmp("-input",command) && !is_get_version) ++position;
      else { std::strcpy(command,"-input"); argument = item; *restriction = 0; }
      gmic_substitute_args();
      if (!is_restriction || !selection) selection.assign(1,1,1,1,images.size());
      CImg<char> indicesy(256), indicesz(256), indicesc(256);
      float dx = 0, dy = 1, dz = 1, dc = 1, nb = 1;
      char sepx = 0, sepy = 0, sepz = 0, sepc = 0;
      CImg<unsigned int> indx, indy, indz, indc;
      CImgList<char> input_images_names;
      CImgList<T> input_images;
      *indices = *indicesy = *indicesz = *indicesc = *argx = *argy = *argz = *argc = 0;

      CImg<char> arg_input(argument,std::strlen(argument)+1);
      gmic_strreplace(arg_input);

      if (*arg_input=='0' && !arg_input[1]) {

        // Empty image.
        print(images,"Input empty image at position%s",
              gmic_selection);
        input_images.assign(1);
        CImg<char>::string("[empty]").move_to(input_images_names);


      } else if ((std::sscanf(arg_input,"[%255[a-zA-Z_0-9%.eE%^,:+-]%c%c",indices,&sep,&end)==2 &&
                  sep==']') ||
                 std::sscanf(arg_input,"[%255[a-zA-Z_0-9%.eE%^,:+-]]x%f%c",indices,&nb,&end)==2) {

        // Nb copies of existing images.
        nb = cimg::round(nb);
        const CImg<unsigned int> inds = selection2cimg(indices,images.size(),images_names,
						       "-input",true,false,CImg<char>::empty());
        CImg<char> s_tmp(256);
        std::strncpy(s_tmp,selection2string(inds,images_names,true).data(),s_tmp.width()-1);
        s_tmp[s_tmp.width()-1] = 0;
        if (nb<=0) arg_error("input");
        if (nb!=1)
          print(images,"Input %u copies of image%s at position%s",
                (unsigned int)nb,
                s_tmp.data(),
                gmic_selection);
        else
          print(images,"Input copy of image%s at position%s",
                s_tmp.data(),
                gmic_selection);
        for (unsigned int i = 0; i<(unsigned int)nb; ++i) cimg_foroff(inds,l) {
            input_images.insert(gmic_check(images[inds[l]]));
            input_images_names.insert(images_names[inds[l]].get_copymark());
          }
      } else if ((sep=0,true) &&
                 (std::sscanf(arg_input,"%255[][a-zA-Z0-9_.eE%+-]%c",
                              argx,&end)==1 ||
                  std::sscanf(arg_input,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                              argx,argy,&end)==2 ||
                  std::sscanf(arg_input,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
			      "%255[][a-zA-Z0-9_.eE%+-]%c",
                              argx,argy,argz,&end)==3 ||
                  std::sscanf(arg_input,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
			      "%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-]%c",
                              argx,argy,argz,argc,&end)==4 ||
                  std::sscanf(arg_input,"%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],"
			      "%255[][a-zA-Z0-9_.eE%+-],%255[][a-zA-Z0-9_.eE%+-],%c",
                              argx,argy,argz,argc,&sep)==5) &&
                 ((std::sscanf(argx,"[%255[a-zA-Z0-9_.%+-]%c%c",indices,&sepx,&end)==2 &&
		   sepx==']' &&
                   (indx=selection2cimg(indices,images.size(),images_names,"-input",true,
                                        false,CImg<char>::empty())).height()==1) ||
                  (std::sscanf(argx,"%f%c",&dx,&end)==1 && dx>=1) ||
                  (std::sscanf(argx,"%f%c%c",&dx,&sepx,&end)==2 && dx>0 && sepx=='%')) &&
                 (!*argy ||
                  (std::sscanf(argy,"[%255[a-zA-Z0-9_.%+-]%c%c",indicesy.data(),&sepy,&end)==2 &&
		   sepy==']' &&
                   (indy=selection2cimg(indicesy,images.size(),images_names,"-input",true,
                                        false,CImg<char>::empty())).height()==1) ||
                  (std::sscanf(argy,"%f%c",&dy,&end)==1 && dy>=1) ||
                  (std::sscanf(argy,"%f%c%c",&dy,&sepy,&end)==2 && dy>0 && sepy=='%')) &&
                 (!*argz ||
                  (std::sscanf(argz,"[%255[a-zA-Z0-9_.%+-]%c%c",indicesz.data(),&sepz,&end)==2 &&
		   sepz==']' &&
                   (indz=selection2cimg(indicesz,images.size(),images_names,"-input",true,
                                        false,CImg<char>::empty())).height()==1) ||
                  (std::sscanf(argz,"%f%c",&dz,&end)==1 && dz>=1) ||
                  (std::sscanf(argz,"%f%c%c",&dz,&sepz,&end)==2 && dz>0 && sepz=='%')) &&
                 (!*argc ||
                  (std::sscanf(argc,"[%255[a-zA-Z0-9_.%+-]%c%c",indicesc.data(),&sepc,&end)==2 &&
		   sepc==']' &&
                   (indc=selection2cimg(indicesc,images.size(),images_names,"-input",true,
                                        false,CImg<char>::empty())).height()==1) ||
                  (std::sscanf(argc,"%f%c",&dc,&end)==1 && dc>=1) ||
                  (std::sscanf(argc,"%f%c%c",&dc,&sepc,&end)==2 && dc>0 && sepc=='%'))) {

        // New image with specified dimensions and optionally values.
        if (indx) { dx = (float)gmic_check(images[*indx]).width(); sepx = 0; }
        if (indy) { dy = (float)gmic_check(images[*indy]).height(); sepy = 0; }
        if (indz) { dz = (float)gmic_check(images[*indz]).depth(); sepz = 0; }
        if (indc) { dc = (float)gmic_check(images[*indc]).spectrum(); sepc = 0; }
        int idx = 0, idy = 0, idz = 0, idc = 0;
        const CImg<T>& img = images.size()?gmic_check(images.back()):CImg<T>::empty();
        if (sepx=='%') { idx = (int)cimg::round(dx*img.width()/100); if (!idx) ++idx; }
        else idx = (int)cimg::round(dx);
        if (sepy=='%') { idy = (int)cimg::round(dy*img.height()/100); if (!idy) ++idy; }
        else idy = (int)cimg::round(dy);
        if (sepz=='%') { idz = (int)cimg::round(dz*img.depth()/100); if (!idz) ++idz; }
        else idz = (int)cimg::round(dz);
        if (sepc=='%') { idc = (int)cimg::round(dc*img.spectrum()/100); if (!idc) ++idc; }
        else idc = (int)cimg::round(dc);
        if (idx<=0 || idy<=0 || idz<=0 || idc<=0) arg_error("input");
        CImg<char> s_values;
        if (sep) {
          const char *_s_values = arg_input.data() + std::strlen(argx) + std::strlen(argy) +
            std::strlen(argz) + std::strlen(argc) + 4;
          s_values.assign(_s_values,std::strlen(_s_values)+1);
          cimg::strpare(s_values,'\'',true,false);
          gmic_strreplace(s_values);
          CImg<char> s_values_text(72);
          *s_values_text = 0;
          const unsigned int l = std::strlen(s_values);
          if (l>=72) {
            std::memcpy(s_values_text.data(),s_values.data(),32);
            std::memcpy(s_values_text.data()+32," ... ",5);
            std::memcpy(s_values_text.data()+37,s_values.data()+l-34,35);  // Last '\0' is included.
          } else std::strcpy(s_values_text,s_values);
          print(images,"Input image at position%s, with values '%s'",
                gmic_selection,s_values_text.data());
        } else
          print(images,"Input black image at position%s",
                gmic_selection);
        CImg<T> new_image(idx,idy,idz,idc,0);
        if (s_values) {
          new_image.fill(s_values.data(),true);
          cimg_snprintf(title,_title.size(),"[image of '%s']",s_values.data());
          gmic_ellipsize(title,_title.size());
          CImg<char>::string(title).move_to(input_images_names);
        } else CImg<char>::string("[unnamed]").move_to(input_images_names);
        new_image.move_to(input_images);

      } else if (*arg_input=='(' && arg_input[std::strlen(arg_input)-1]==')') {

        // New IxJxKxL image specified as array.
        unsigned int cx = 0, cy = 0, cz = 0, cc = 0, maxcx = 0, maxcy = 0, maxcz = 0;
        const char *nargument = 0;
        for (nargument = arg_input.data() + 1; *nargument; ) {
          CImg<char> s_value(256);
          *s_value = 0;
          char separator = 0;
          double value = 0;
          if (std::sscanf(nargument,"%255[0-9.eE+-]%c",s_value.data(),&separator)==2 &&
              std::sscanf(s_value,"%lf%c",&value,&end)==1) {
            if (cx>maxcx) maxcx = cx;
            if (cy>maxcy) maxcy = cy;
            if (cz>maxcz) maxcz = cz;
            switch (separator) {
            case '^' : cx = cy = cz = 0; ++cc; break;
            case '/' : cx = cy = 0; ++cz; break;
            case ';' : cx = 0; ++cy; break;
            case ',' : ++cx; break;
            case ')' : break;
            default : arg_error("input");
            }
            nargument+=std::strlen(s_value) + 1;
          } else break;
        }
        if (*nargument) arg_error("input");
        CImg<T> img(maxcx+1,maxcy+1,maxcz+1,cc+1,0);
        cx = cy = cz = cc = 0;
        for (nargument = arg_input.data() + 1; *nargument; ) {
          CImg<char> s_value(256);
          *s_value = 0;
          char separator = 0;
          double value = 0;
          if (std::sscanf(nargument,"%255[0-9.eE+-]%c",s_value.data(),&separator)==2 &&
              std::sscanf(s_value,"%lf%c",&value,&end)==1) {
            img(cx,cy,cz,cc) = (T)value;
            switch (separator) {
            case '^' : cx = cy = cz = 0; ++cc; break;
            case '/' : cx = cy = 0; ++cz; break;
            case ';' : cx = 0; ++cy; break;
            default : ++cx;
            }
            nargument+=std::strlen(s_value) + (separator?1:0);
          } else break;
        }
        print(images,"Input image at position%s, with values '%s'",
              gmic_selection,
              argument_text);
        img.move_to(input_images);
        arg_input.move_to(input_images_names);

      } else {

        // Input filename.
        char cext[8];
        CImg<char> _filename(4096), filename_tmp(512), options(256);
        *cext = *_filename = *filename_tmp = *options = 0;
        bool is_network_file = false;
        if (std::sscanf(argument,"%8[a-zA-Z]:%4095[^,],%255s",cext,_filename.data(),options.data())<2 ||
            !cext[1] || // length of 'ext' must be >=2 (avoid case 'C:\\..' on Windows).
            !cimg::strcasecmp(cext,"http") || !cimg::strcasecmp(cext,"https")) {
          *cext = *_filename = *options = 0;
          if (std::sscanf(argument,"%4095[^,],%255s",_filename.data(),options.data())!=2) {
            std::strncpy(_filename,argument,_filename.width()-1);
            _filename[_filename.width()-1] = 0;
          }
        }
        gmic_strreplace(_filename);
        gmic_strreplace(options);
        CImg<char> __filename0 = CImg<char>::string(_filename);
        const char *const _filename0 = __filename0.data();

        // Test for network file requests.
        if (!cimg::strncasecmp(_filename,"http://",7) ||
            !cimg::strncasecmp(_filename,"https://",8)) {
          cimg::load_network_external(_filename,filename_tmp);
          std::strncpy(_filename,filename_tmp,_filename.width()-1);
          _filename[_filename.width()-1] = 0;
          *filename_tmp = 0;
          is_network_file = true;
        }

        if (*cext) { // Force output to be read as a '.ext' file : generate random filename.
          if (*_filename=='-' && (!_filename[1] || _filename[1]=='.')) {
            // Simplify filename 'ext:-.foo' as '-.ext'.
            cimg_snprintf(_filename,_filename.width(),"-.%s",cext);
            *cext = 0;
          } else {
            std::FILE *file = 0;
            do {
              cimg_snprintf(filename_tmp,filename_tmp.width(),"%s%c%s.%s",
                            cimg::temporary_path(),cimg_file_separator,
                            cimg::filenamerand(),cext);
              if ((file=std::fopen(filename_tmp,"rb"))!=0) std::fclose(file);
            } while (file);

            // Make a temporary copy (or link) of the original file.
#if cimg_OS==1
            const char *const _filename_path = realpath(_filename,0);
            if (symlink(_filename_path,filename_tmp))
              CImg<unsigned char>::get_load_raw(_filename).save_raw(filename_tmp);
            std::free((void*)_filename_path);
#else // #if cimg_OS==1
# 11913 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
            CImg<unsigned char>::get_load_raw(_filename).save_raw(filename_tmp);
#endif // #if cimg_OS==1
# 11915 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
          }
        }

        const char
          *const filename = *filename_tmp?filename_tmp:_filename,
          *const ext = cimg::split_filename(filename);

        std::FILE *const file = std::fopen(filename,"rb");
        long siz = 0;
        if (file) { std::fseek(file,0,SEEK_END); siz = std::ftell(file); std::fclose(file); }
        if (file && siz==0) { // Empty file -> Insert an empty image.
          input_images_names.insert(__filename0);
          input_images.insert(1);
        } else if (!cimg::strcasecmp("off",ext)) {

          // 3d object .off file.
          print(images,"Input 3d object '%s' at position%s",
                _filename0,gmic_selection);
          CImgList<unsigned int> primitives;
          CImgList<float> colors;
          CImg<float> vertices = CImg<float>::get_load_off(primitives,colors,filename);
          const CImg<float> opacities(1,primitives.size(),1,1,1);
          vertices.object3dtoCImg3d(primitives,colors,opacities,false).move_to(input_images);
          input_images_names.insert(__filename0);
        } else if (!cimg::strcasecmp(ext,"cimg") && *options) {

          // .cimg file (non-compressed).
          float
            n0 = -1, x0 = -1, y0 = -1, z0 = -1, c0 = -1,
            n1 = -1, x1 = -1, y1 = -1, z1 = -1, c1 = -1;
          if ((std::sscanf(options,"%f,%f%c",
                           &n0,&n1,&end)==2 ||
               std::sscanf(options,"%f,%f,%f,%f%c",
                           &n0,&n1,&x0,&x1,&end)==4 ||
               std::sscanf(options,"%f,%f,%f,%f,%f,%f%c",
                           &n0,&n1,&x0,&y0,&x1,&y1,&end)==6 ||
               std::sscanf(options,"%f,%f,%f,%f,%f,%f,%f,%f%c",
                           &n0,&n1,&x0,&y0,&z0,&x1,&y1,&z1,&end)==8 ||
               std::sscanf(options,"%f,%f,%f,%f,%f,%f,%f,%f,%f,%f%c",
                           &n0,&n1,&x0,&y0,&z0,&c0,&x1,&y1,&z1,&c1,&end)==10) &&
              (n0==-1 || n0>=0) && (n1==-1 || n1>=0) &&
              (x0==-1 || x0>=0) && (x1==-1 || x1>=0) &&
              (y0==-1 || y0>=0) && (y1==-1 || y1>=0) &&
              (z0==-1 || z0>=0) && (z1==-1 || z1>=0) &&
              (c0==-1 || c0>=0) && (c1==-1 || c1>=0)) {
            n0 = cimg::round(n0); n1 = cimg::round(n1);
            x0 = cimg::round(x0); x1 = cimg::round(x1);
            y0 = cimg::round(y0); y1 = cimg::round(y1);
            z0 = cimg::round(z0); z1 = cimg::round(z1);
            c0 = cimg::round(c0); c1 = cimg::round(c1);
            if (c0==-1 && c1==-1) {
              if (z0==-1 && z1==-1) {
                if (y0==-1 && y1==-1) {
                  if (x0==-1 && x1==-1) {
                    print(images,"Input crop [%d] -> [%d] of file '%s' at position%s",
                          (int)n0,(int)n1,
                          _filename0,gmic_selection);
                    input_images.load_cimg(filename,
                                           (unsigned int)n0,(unsigned int)n1,
                                           0U,0U,0U,0U,~0U,~0U,~0U,~0U);
                  } else {
                    print(images,"Input crop [%d](%d) -> [%d](%d) of file '%s' at position%s",
                          (int)n0,(int)x0,(int)n1,(int)x1,
                          _filename0,gmic_selection);
                    input_images.load_cimg(filename,
                                           (unsigned int)n0,(unsigned int)n1,
                                           (unsigned int)x0,0U,0U,0U,
                                           (unsigned int)x1,~0U,~0U,~0U);
                  }
                } else {
                  print(images,"Input crop [%d](%d,%d) -> [%d](%d,%d) of file '%s' at position%s",
                        (int)n0,(int)n1,(int)x0,(int)y0,(int)x1,(int)y1,
                        _filename0,gmic_selection);
                  input_images.load_cimg(filename,
                                         (unsigned int)n0,(unsigned int)n1,
                                         (unsigned int)x0,(unsigned int)y0,0U,0U,
                                         (unsigned int)x1,(unsigned int)y1,~0U,~0U);
                }
              } else {
                print(images,"Input crop [%d](%d,%d,%d) -> [%d](%d,%d,%d) of file '%s' at position%s",
                      (int)n0,(int)n1,(int)x0,(int)y0,(int)z0,(int)x1,(int)y1,(int)z1,
                      _filename0,gmic_selection);
                input_images.load_cimg(filename,
                                       (unsigned int)n0,(unsigned int)n1,
                                       (unsigned int)x0,(unsigned int)y0,(unsigned int)z0,0U,
                                       (unsigned int)x1,(unsigned int)y1,(unsigned int)z1,~0U);
              }
            } else {
                print(images,"Input crop [%d](%d,%d,%d,%d) -> [%d](%d,%d,%d,%d) of file '%s' at position%s",
                      (int)n0,(int)n1,(int)x0,(int)y0,(int)z0,(int)c0,(int)x1,(int)y1,(int)z1,(int)c1,
                      _filename0,gmic_selection);
                input_images.load_cimg(filename,
                                       (unsigned int)n0,(unsigned int)n1,
                                       (unsigned int)x0,(unsigned int)y0,(unsigned int)z0,(unsigned int)c0,
                                       (unsigned int)x1,(unsigned int)y1,(unsigned int)z1,(unsigned int)c1);
            }

            if (input_images) {
              input_images_names.insert(__filename0);
              if (input_images.size()>1)
                input_images_names.insert(input_images.size()-1,__filename0.copymark());
            }
          } else
            error(images,"Command '-input': .cimg file '%s', invalid file options '%s'.",
                  _filename0,options.data());

        } else if (!cimg::strcasecmp(ext,"avi") ||
                   !cimg::strcasecmp(ext,"mov") ||
                   !cimg::strcasecmp(ext,"asf") ||
                   !cimg::strcasecmp(ext,"divx") ||
                   !cimg::strcasecmp(ext,"flv") ||
                   !cimg::strcasecmp(ext,"mpg") ||
                   !cimg::strcasecmp(ext,"m1v") ||
                   !cimg::strcasecmp(ext,"m2v") ||
                   !cimg::strcasecmp(ext,"m4v") ||
                   !cimg::strcasecmp(ext,"mjp") ||
                   !cimg::strcasecmp(ext,"mkv") ||
                   !cimg::strcasecmp(ext,"mpe") ||
                   !cimg::strcasecmp(ext,"movie") ||
                   !cimg::strcasecmp(ext,"ogm") ||
                   !cimg::strcasecmp(ext,"ogg") ||
                   !cimg::strcasecmp(ext,"qt") ||
                   !cimg::strcasecmp(ext,"rm") ||
                   !cimg::strcasecmp(ext,"vob") ||
                   !cimg::strcasecmp(ext,"wmv") ||
                   !cimg::strcasecmp(ext,"xvid") ||
                   !cimg::strcasecmp(ext,"mpeg")) {

          // Image sequence file.
          float first_frame = 0, last_frame = 0, step = 1;
          char first_sep = 0, last_sep = 0;
          if ((std::sscanf(options,"%f%c,%f%c,%f%c",
                           &first_frame,&first_sep,&last_frame,&last_sep,&step,&end)==5 &&
               first_sep=='%' && last_sep=='%') ||
              (std::sscanf(options,"%f%c,%f,%f%c",
                           &first_frame,&first_sep,&last_frame,&step,&end)==4 &&
               first_sep=='%') ||
              (std::sscanf(options,"%f,%f%c,%f%c",
                           &first_frame,&last_frame,&last_sep,&step,&end)==4 &&
               last_sep=='%') ||
              std::sscanf(options,"%f,%f,%f%c",&first_frame,&last_frame,&step,&end)==3 ||
              (std::sscanf(options,"%f%c,%f%c%c",
                           &first_frame,&first_sep,&last_frame,&last_sep,&end)==4 &&
               first_sep=='%' && last_sep=='%') ||
              (std::sscanf(options,"%f%c,%f%c",&first_frame,&first_sep,&last_frame,&end)==3 &&
               first_sep=='%') ||
              (std::sscanf(options,"%f,%f%c%c",&first_frame,&last_frame,&last_sep,&end)==3 &&
               last_sep=='%') ||
              std::sscanf(options,"%f,%f%c",
                          &first_frame,&last_frame,&end)==2) { // Read several frames
            if (first_frame>last_frame) cimg::swap(first_frame,last_frame,first_sep,last_sep);
            step = cimg::round(step);
            print(images,"Input frames %g%s..%g%s with step %g of file '%s' at position%s",
                  first_frame,first_sep=='%'?"%":"",
                  last_frame,last_sep=='%'?"%":"",
                  step,
                  _filename0,
                  gmic_selection);
            if (first_sep=='%' || last_sep=='%') {
              const unsigned int
		nb_frames = CImg<unsigned int>::get_load_ffmpeg(filename,0,0,0)[0];
              first_frame = cimg::round(first_sep=='%'?first_frame*nb_frames/100:first_frame);
              last_frame = cimg::round(last_sep=='%'?last_frame*nb_frames/100:last_frame);
            }
            input_images.load_ffmpeg(filename,(unsigned int)first_frame,
                                     (unsigned int)last_frame,(unsigned int)step);
          } else if ((std::sscanf(options,"%f%c%c",&first_frame,&first_sep,&end)==2 &&
                      first_sep=='%') ||
                     std::sscanf(options,"%f%c",&first_frame,&end)==1) { // Read a single frame
            step = cimg::round(step);
            print(images,"Input frame %g%s of file '%s' at position%s",
                  first_frame,first_sep=='%'?"%":"",
                  _filename0,
                  gmic_selection);
            if (first_sep=='%') {
              const unsigned int
		nb_frames = CImg<unsigned int>::get_load_ffmpeg(filename,0,0,0)[0];
              first_frame = cimg::round(first_frame*nb_frames/100.0f);
            }
            input_images.load_ffmpeg(filename,(unsigned int)first_frame,(unsigned int)first_frame);
          } else { // Read all frames
            print(images,"Input all frames of file '%s' at position%s",
                  _filename0,
                  gmic_selection);
            input_images.load_ffmpeg(filename);
          }
          if (input_images) {
            input_images_names.insert(__filename0);
            if (input_images.size()>1)
              input_images_names.insert(input_images.size()-1,__filename0.copymark());
          }
        } else if (!cimg::strcasecmp("raw",ext)) {

          // Raw file.
          float dx = 0, dy = 1, dz = 1, dc = 1;
          unsigned long offset = 0;
          *argx = 0;
          if (!*options ||
              std::sscanf(options,"%f%c",&dx,&end)==1 ||
              std::sscanf(options,"%f,%f%c",&dx,&dy,&end)==2 ||
              std::sscanf(options,"%f,%f,%f%c",&dx,&dy,&dz,&end)==3 ||
              std::sscanf(options,"%f,%f,%f,%f%c",&dx,&dy,&dz,&dc,&end)==4 ||
              std::sscanf(options,"%f,%f,%f,%f,%lu%c",&dx,&dy,&dz,&dc,&offset,&end)==5 ||
              std::sscanf(options,"%255[a-zA-Z]%c",argx,&end)==1 ||
              std::sscanf(options,"%255[a-zA-Z],%f%c",argx,&dx,&end)==2 ||
              std::sscanf(options,"%255[a-zA-Z],%f,%f%c",argx,&dx,&dy,&end)==3 ||
              std::sscanf(options,"%255[a-zA-Z],%f,%f,%f%c",argx,&dx,&dy,&dz,&end)==4 ||
              std::sscanf(options,"%255[a-zA-Z],%f,%f,%f,%f%c",argx,&dx,&dy,&dz,&dc,&end)==5 ||
              std::sscanf(options,"%255[a-zA-Z],%f,%f,%f,%f,%lu%c",argx,&dx,&dy,&dz,&dc,&offset,&end)==6) {
            const char *const stype = *argx?argx:cimg::type<T>::string();
            dx = cimg::round(dx);
            dy = cimg::round(dy);
            dz = cimg::round(dz);
            dc = cimg::round(dc);
            if (dx<0 || dy<=0 || dz<=0 || dc<=0)
              error(images,"Command '-input': raw file '%s', invalid specified "
		    "dimensions %gx%gx%gx%g.",
                    _filename0,dx,dy,dz,dc);

            if (offset)
              print(images,"Input raw file '%s' (offset: %lu) with type '%s' at position%s",
                    _filename0,offset,stype,
                    gmic_selection);
            else
              print(images,"Input raw file '%s' with type '%s' at position%s",
                    _filename0,stype,
                    gmic_selection);

#define gmic_load_raw(value_type,svalue_type) \
            if (!cimg::strcasecmp(stype,svalue_type)) \
              CImg<value_type>::get_load_raw(filename,(unsigned int)dx,(unsigned int)dy,\
                                             (unsigned int)dz,(unsigned int)dc,false,false,offset). \
                move_to(input_images);
            gmic_load_raw(bool,"bool")
            else gmic_load_raw(unsigned char,"uchar")
              else gmic_load_raw(unsigned char,"unsigned char")
                else gmic_load_raw(char,"char")
                  else gmic_load_raw(unsigned short,"ushort")
                    else gmic_load_raw(unsigned short,"unsigned short")
                      else gmic_load_raw(short,"short")
                        else gmic_load_raw(unsigned int,"uint")
                          else gmic_load_raw(unsigned int,"unsigned int")
                            else gmic_load_raw(int,"int")
                              else gmic_load_raw(float,"float")
                                else gmic_load_raw(double,"double")
                                  else error(images,"Command '-input': raw file '%s', "
                                             "invalid specified pixel type '%s'.\n",
                                             _filename0,stype);
            input_images_names.insert(__filename0);
          } else
            error(images,"Command '-input': raw file '%s', invalid file options '%s'.",
                  _filename0,options.data());
        } else if (!cimg::strcasecmp("yuv",ext)) {

          // YUV file.
          float first_frame = 0, last_frame = 0, step = 1, dx = 0, dy = 1;
          int err = 0;
          if ((err=std::sscanf(options,"%f,%f,%f,%f,%f",
                               &dx,&dy,&first_frame,&last_frame,&step))>=1) {
            dx = cimg::round(dx);
            dy = cimg::round(dy);
            if (dx<=0 || dy<=0)
              error(images,"Command '-input': YUV file '%s', invalid specified dimensions %gx%g.",
                    _filename0,dx,dy);
            first_frame = cimg::round(first_frame);
            if (err>3) { // Load multiple frames.
              last_frame = cimg::round(last_frame);
              step = cimg::round(step);
              print(images,"Input frames %g..%g with step %g of YUV file '%s' at position%s",
                    first_frame,last_frame,step,
                    _filename0,
                    gmic_selection);
              input_images.load_yuv(filename,(unsigned int)dx,(unsigned int)dy,
                                    (unsigned int)first_frame,(unsigned int)last_frame,
                                    (unsigned int)step);
            } else if (err==3) { // Load a single frame.
              print(images,"Input frames %g of YUV file '%s' at position%s",
                    first_frame,
                    _filename0,
                    gmic_selection);
              input_images.load_yuv(filename,(unsigned int)dx,(unsigned int)dy,
                                    (unsigned int)first_frame,(unsigned int)first_frame);
            } else { // Load all frames.
              print(images,"Input all frames of YUV file '%s' at position%s",
                    _filename0,
                    gmic_selection);
              input_images.load_yuv(filename,(unsigned int)dx,(unsigned int)dy);
            }
            if (input_images) {
              input_images_names.insert(__filename0);
              if (input_images.size()>1)
                input_images_names.insert(input_images.size()-1,__filename0.copymark());
            }
          } else
            error(images,"Command '-input': YUV file '%s', invalid or missing file options '%s'.",
                  _filename0,options.data());

        } else if (!cimg::strcasecmp("tif",ext) || !cimg::strcasecmp("tiff",ext)) {

          // TIFF file.
          float first_frame = 0, last_frame = 0, step = 1;
          int err = 0;
#ifdef cimg_use_tiff
          static const TIFFErrorHandler default_handler = TIFFSetWarningHandler(0);
          if (verbosity>0 || is_debug) TIFFSetWarningHandler(default_handler);
          else TIFFSetWarningHandler(0);
#endif
# 12222 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
          if ((err=std::sscanf(options,"%f,%f,%f",&first_frame,&last_frame,&step))>0) {
            first_frame = cimg::round(first_frame);
            if (err>1) { // Load multiple frames.
              last_frame = cimg::round(last_frame);
              step = cimg::round(step);
              print(images,"Input frames %g..%g with step %g of TIFF file '%s' at position%s",
                    first_frame,last_frame,step,
                    _filename0,
                    gmic_selection);
              input_images.load_tiff(filename,(unsigned int)first_frame,(unsigned int)last_frame,
                                     (unsigned int)step);
            } else if (err==1) { // Load a single frame.
              print(images,"Input frames %g of TIFF file '%s' at position%s",
                    first_frame,
                    _filename0,
                    gmic_selection);
              input_images.load_tiff(filename,(unsigned int)first_frame,(unsigned int)first_frame);
            }
          } else { // Load all frames.
            if (*options) error(images,"Command '-input': TIFF file '%s', "
                                "invalid file options '%s'.",
                                _filename0,options.data());
            print(images,"Input all frames of TIFF file '%s' at position%s",
                  _filename0,
                  gmic_selection);
            input_images.load_tiff(filename);
          }
          if (input_images) {
            input_images_names.insert(__filename0);
            if (input_images.size()>1)
              input_images_names.insert(input_images.size()-1,__filename0.copymark());
          }
        } else if (!cimg::strcasecmp("gmic",ext)) {

          // G'MIC custom commands file
          const bool add_debug_infos = (*options!='0');
          print(images,"Input custom commands file '%s'%s",
                _filename0,!add_debug_infos?" without debug infos":"");
          unsigned int siz = 0;
          for (unsigned int l = 0; l<256; ++l) siz+=commands[l].size();
          std::FILE *const file = cimg::fopen(filename,"rb");
          add_commands(file,filename,commands_names,commands,commands_has_arguments,add_debug_infos);
          cimg::fclose(file);
          if (verbosity>=0 || is_debug) {
            unsigned int nb_added = 0;
            for (unsigned int l = 0; l<256; ++l) nb_added+=commands[l].size();
            nb_added-=siz;
            std::fprintf(cimg::output()," (added %u command%s, total %u).",
                         nb_added,nb_added>1?"s":"",siz+nb_added);
            std::fflush(cimg::output());
          }
          continue;
        } else {

          // Other file types.
          print(images,"Input file '%s' at position%s",
                _filename0,
                gmic_selection);
          try { input_images.load(filename); }
          catch (CImgException&) {
            std::FILE *file = 0;
            if (!(file=std::fopen(filename,"r"))) {
              if (cimg::type<T>::string()==cimg::type<float>::string() || *ext || *filename!='-') {
                if (*filename=='-' && filename[1]) { // Check for command misspelling.
                  const char *native_commands_names[] = {
                    "a","b","c","d","e","f","g","h","i","j","k","l","m","n","o","p","q","r","s",
                    "t","u","v","w","x","y","z",
                    "+","-","*","/",">","<","%","^","=","sh","mv","rm","rv","<<",">>","==",">=",
                    "<=","//","**","!=",
                    "d3d","+3d","b3d","/3d","f3d","l3d","m3d","*3d","o3d","p3d","r3d","s3d","-3d",
                    "t3d","db3d","md3d","rv3d","sl3d","ss3d","div3d",
                    "append","autocrop","add","add3d","abs","and","atan2","acos","asin","atan",
                    "axes",
                    "blur","bsr","bsl","bilateral","background3d","break",
                    "check","check3d","crop","channels","columns","command","camera","cut","cos",
                    "convolve","correlate","color3d","col3d","cosh","continue","cursor",
                    "done","do","debug","divide","distance","dilate","double3d","denoise",
                    "deriche","dijkstra","displacement","display","display3d",
                    "endif","else","elif","endlocal","endl","echo","exec","error","endian","exp",
                    "eq","ellipse","equalize","erode","elevation3d","eigen","eikonal",
                    "fill","flood","focale3d","fft",
                    "ge","gt","gradient","graph",
                    "histogram","hsi2rgb","hsl2rgb","hsv2rgb","hessian",
                    "input","if","image","index","invert","isoline3d","isosurface3d","inpaint",
                    "ifft",
                    "keep",
                    "local","le","lt","log","log2","log10","line","lab2rgb","label","light3d",
                    "move","mirror","mul","mutex","mod","max","min","mmul","mode3d","moded3d",
                    "map","median","mdiv","mse","mandelbrot","mul3d",
                    "name","normalize","neq","noise",
                    "output","onfail","object3d","or","opacity3d",
                    "parallel","permute","progress","print","pow","point","polygon","plasma",
                    "pose3d","primitives3d","plot",
                    "quiver","quit",
                    "remove","repeat","resize","reverse","return","rows","rotate",
                    "round","rand","rotate3d","rgb2hsi","rgb2hsl","rgb2hsv","rgb2lab",
                    "rgb2srgb","rol","ror","reverse3d",
                    "status","skip","set","split","shared","shift","slices","srand","sub","sqrt",
                    "sqr","sign","sin","sort","solve","sub3d","sharpen","smooth","split3d",
                    "svd","sphere3d","specl3d","specs3d","sinc","sinh","srgb2rgb","streamline3d",
                    "structuretensors","select",
                    "type","threshold","tan","text","texturize3d","trisolve","tanh",
                    "unroll","uncommand",
                    "vanvliet","verbose",
                    "while","warning","window","warp","watershed","wait",
                    "xor",0
                  };
                  const char *misspelled = 0;
                  const unsigned int foff = filename[1]=='-'?2:1;
                  int dmin = 4;
                  for (unsigned int l = 0; native_commands_names[l]; ++l) {
                    // Look in native commands.
                    const char *const c = native_commands_names[l];
                    const int d = gmic_levenshtein(c,filename+foff);
                    if (d<dmin) { dmin = d; misspelled = native_commands_names[l]; }
                  }
                  for (unsigned int i = 0; i<256; ++i)
                    // Look in custom commands.
                    cimglist_for(commands_names[i],l) {
                      const char *const c = commands_names[i][l].data();
                      const int d = gmic_levenshtein(c,filename+foff);
                      if (d<dmin) { dmin = d; misspelled = commands_names[i][l].data(); }
                    }
                  if (misspelled)
                    error(images,"Unknown command or filename '%s' (did you mean '-%s' ?).",
                          argument_text,misspelled);
                  else error(images,"Unknown command or filename '%s'.",
                             argument_text);
                } else error(images,"Unknown %s '%s'.",
                             *filename=='-'?"command or filename":"filename",
                             argument_text);
              } else
                error(images,"Unknown command '%s' in '%s' type mode "
                      "(command defined only in 'float' type mode ?).",
                      argument_text,cimg::type<T>::string());
            } else throw;
          }
          input_images_names.insert(__filename0);
          if (input_images.size()>1)
            input_images_names.insert(input_images.size()-1,__filename0.copymark());
        }

        if (*filename_tmp) std::remove(filename_tmp);  // Clean temporary file if used.
        if (is_network_file) std::remove(_filename);   // Clean temporary file if network input.
      }

      if (verbosity>=0 || is_debug) {
        if (input_images) {
          const unsigned int last = input_images.size() - 1;
          if (input_images.size()==1) {
            if (input_images[0].is_CImg3d(false))
              std::fprintf(cimg::output()," (%u vertices, %u primitives).",
                           cimg::float2uint((float)input_images(0,6)),
                           cimg::float2uint((float)input_images(0,7)));
            else
              std::fprintf(cimg::output()," (1 image %dx%dx%dx%d).",
                           input_images[0].width(),input_images[0].height(),
                           input_images[0].depth(),input_images[0].spectrum());
          } else
            std::fprintf(cimg::output()," (%u images [0] = %dx%dx%dx%d, %s[%u] = %dx%dx%dx%d).",
                         input_images.size(),
                         input_images[0].width(),input_images[0].height(),
                         input_images[0].depth(),input_images[0].spectrum(),
                         last==1?"":"..,",last,
                         input_images[last].width(),input_images[last].height(),
                         input_images[last].depth(),input_images[last].spectrum());
        } else {
          std::fprintf(cimg::output()," (no available data).");
          input_images_names.assign();
        }
        std::fflush(cimg::output());
      }

      for (unsigned int l = 0, siz = selection.height()-1U, off = 0; l<=siz; ++l) {
        const unsigned int ind = selection[l] + off;
        off+=input_images.size();
        if (l!=siz) {
          images.insert(input_images,ind);
          images_names.insert(input_images_names,ind);
        } else {
          input_images.move_to(images,ind);
          input_images_names.move_to(images_names,ind);
        }
      }

      if (new_name) new_name.move_to(images_names[selection[0]]);
      is_released = false;
    }

    // Wait for remaining threads to finish.
#ifdef gmic_is_parallel
    cimglist_for(threads_data,i) cimg_forY(threads_data[i],l) {
      if (!threads_data(i,l).wait_mode) {
        cimg::mutex(30);
        *(threads_data(i,l).gmic_instance.cancel) = 1;
        cimg::mutex(30,0);
      }
#if cimg_OS!=2
      pthread_join(threads_data(i,l).thread_id,0);
#else
# 12422 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
      WaitForSingleObject(threads_data(i,l).thread_id,INFINITE);
      CloseHandle(threads_data(i,l).thread_id);
#endif // #if cimg_OS!=2
# 12425 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
      is_released&=threads_data(i,l).gmic_instance.is_released;
    }
    // Check for possible exceptions thrown by threads.
    cimglist_for(threads_data,i) cimg_forY(threads_data[i],l)
      if (threads_data(i,l).exception._message)
        throw threads_data(i,l).exception;
#endif // #ifdef gmic_is_parallel
# 12432 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

    // Post-check global environment consistency.
    if (images_names.size()!=images.size())
      error(images,"Internal error: Images (%u) and images names (%u) have different size, "
	    "at return point.",
            images_names.size(),images.size());
    if (!scope)
      error(images,"Internal error: Scope is empty, at return point.");

    // Post-check local environment consistency.
    if (!is_quit && !is_return) {
      const CImg<char> &s = scope.back();
      if (is_default_type &&
          s[0]=='*' && (s[1]=='d' || s[1]=='i' || s[1]=='r' || (s[1]=='l' && !is_endlocal)))
        error(images,"A '-%s' command is missing, before return point.",
              s[1]=='d'?"while":s[1]=='i'?"endif":s[1]=='r'?"done":"endlocal");
    } else if (initial_scope_size<scope.size()) scope.remove(initial_scope_size,scope.size()-1);

    // Post-check validity of shared images.
    cimglist_for(images,l) gmic_check(images[l]);

    // Display or print result, if not 'released' before.
#if defined(gmic_float) && cimg_display!=0

    if (!is_released && scope.size()==1 && images) {
      CImgList<unsigned int> lselection, lselection3d;
      bool is_first3d = false;
#if cimg_display!=0
      instant_window[0].assign();
#endif
# 12462 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
      cimglist_for(images,l) {
        const bool is_3d = images[l].is_CImg3d(false);
        if (!l) is_first3d = is_3d;
        CImg<unsigned int>::vector(l).move_to(is_3d?lselection3d:lselection);
      }
      if (is_first3d) {
        display_objects3d(images,images_names,lselection3d>'y');
        if (lselection) display_images(images,images_names,lselection>'y',0);
      } else {
        if (lselection) display_images(images,images_names,lselection>'y',0);
        if (lselection3d) display_objects3d(images,images_names,lselection3d>'y');
      }
      is_released = true;
    }

#endif // #if defined(gmic_float)
# 12478 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

    if (is_debug) debug(images,"%sEnd G'MIC parser in scope '%s/' [%s].%s\n",
                        cimg::t_bold,scope.back().data(),CImg<T>::pixel_type(),cimg::t_normal);
    if (!is_debug && !is_quit && scope.size()==1 && is_default_type) {
      print(images,"End G'MIC parser.\n");
      is_quit = true;
    }
  } catch (CImgException &e) {
    CImg<char> error_message(e.what(),std::strlen(e.what())+1);
    for (char *cimg = std::strstr(error_message,"CImg"); cimg; cimg = std::strstr(cimg,"CImg")) {
      cimg[0] = 'g'; cimg[1] = 'm'; cimg[2] = 'i'; cimg[3] = 'c';
    }
    error(images,error_message);
  }
  debug_line = initial_debug_line;
  return *this;
}

// Small hack to separate the compilation of G'MIC for different pixel types.
// (only intended to save computer memory when compiling!)
//--------------------------------------------------------------------------
#if !defined(gmic_float_only) && (defined(gmic_bool) || !defined(gmic_split_compilation))
gmic& gmic::_parse_bool(const CImgList<char>& commands_line, unsigned int& position,
                        CImgList<bool>& images, CImgList<char>& images_names,
                        unsigned int variables_sizes[256]) {
  return _parse(commands_line,position,images,images_names,variables_sizes);
}
template gmic::gmic(const int, const char *const *const, CImgList<bool>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
template gmic::gmic(const char *const, CImgList<bool>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
#endif // #if !defined(gmic_float_only) && (defined(gmic_bool) || !defined(gmic_split_compilation))
# 12512 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#if !defined(gmic_float_only) && (defined(gmic_uchar) || !defined(gmic_split_compilation))
gmic& gmic::_parse_uchar(const CImgList<char>& commands_line, unsigned int& position,
                        CImgList<unsigned char>& images, CImgList<char>& images_names,
			unsigned int variables_sizes[256]) {
  return _parse(commands_line,position,images,images_names,variables_sizes);
}
template gmic::gmic(const int, const char *const *const, CImgList<unsigned char>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
template gmic::gmic(const char *const, CImgList<unsigned char>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
#endif // #if !defined(gmic_float_only) && (defined(gmic_uchar) || !defined(gmic_split_compilation))
# 12525 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#if !defined(gmic_float_only) && (defined(gmic_char) || !defined(gmic_split_compilation))
gmic& gmic::_parse_char(const CImgList<char>& commands_line, unsigned int& position,
                        CImgList<char>& images, CImgList<char>& images_names,
                        unsigned int variables_sizes[256]) {
  return _parse(commands_line,position,images,images_names,variables_sizes);
}
template gmic::gmic(const int, const char *const *const, CImgList<char>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
template gmic::gmic(const char *const, CImgList<char>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
#endif // #if !defined(gmic_float_only) && (defined(gmic_char) || !defined(gmic_split_compilation))
# 12538 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#if !defined(gmic_float_only) && (defined(gmic_ushort) || !defined(gmic_split_compilation))
gmic& gmic::_parse_ushort(const CImgList<char>& commands_line, unsigned int& position,
                          CImgList<unsigned short>& images, CImgList<char>& images_names,
                          unsigned int variables_sizes[256]) {
  return _parse(commands_line,position,images,images_names,variables_sizes);
}
template gmic::gmic(const int, const char *const *const, CImgList<unsigned short>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
template gmic::gmic(const char *const, CImgList<unsigned short>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
#endif // #if !defined(gmic_float_only) && (defined(gmic_ushort) || !defined(gmic_split_compilation))
# 12551 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#if !defined(gmic_float_only) && (defined(gmic_short) || !defined(gmic_split_compilation))
gmic& gmic::_parse_short(const CImgList<char>& commands_line, unsigned int& position,
                         CImgList<short>& images, CImgList<char>& images_names,
                         unsigned int variables_sizes[256]) {
  return _parse(commands_line,position,images,images_names,variables_sizes);
}
template gmic::gmic(const int, const char *const *const, CImgList<short>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
template gmic::gmic(const char *const, CImgList<short>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
#endif // #if !defined(gmic_float_only) && (defined(gmic_short) || !defined(gmic_split_compilation))
# 12564 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#if !defined(gmic_float_only) && (defined(gmic_uint) || !defined(gmic_split_compilation))
gmic& gmic::_parse_uint(const CImgList<char>& commands_line, unsigned int& position,
                        CImgList<unsigned int>& images, CImgList<char>& images_names,
                        unsigned int variables_sizes[256]) {
  return _parse(commands_line,position,images,images_names,variables_sizes);
}
template gmic::gmic(const int, const char *const *const, CImgList<unsigned int>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
template gmic::gmic(const char *const, CImgList<unsigned int>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
#endif // #if !defined(gmic_float_only) && (defined(gmic_uint) || !defined(gmic_split_compilation))
# 12577 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#if !defined(gmic_float_only) && (defined(gmic_int) || !defined(gmic_split_compilation))
gmic& gmic::_parse_int(const CImgList<char>& commands_line, unsigned int& position,
                       CImgList<int>& images, CImgList<char>& images_names,
                       unsigned int variables_sizes[256]) {
  return _parse(commands_line,position,images,images_names,variables_sizes);
}
template gmic::gmic(const int, const char *const *const, CImgList<int>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
template gmic::gmic(const char *const, CImgList<int>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
#endif // #if !defined(gmic_float_only) && (defined(gmic_int) || !defined(gmic_split_compilation))
# 12590 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#if defined(gmic_float) || !defined(gmic_split_compilation)
gmic& gmic::_parse_float(const CImgList<char>& commands_line, unsigned int& position,
                         CImgList<float>& images, CImgList<char>& images_names,
                         unsigned int variables_sizes[256]) {
  return _parse(commands_line,position,images,images_names,variables_sizes);
}
template gmic::gmic(const int, const char *const *const, CImgList<float>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
template gmic::gmic(const char *const, CImgList<float>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
#endif // #if defined(gmic_float) || !defined(gmic_split_compilation)
# 12603 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
#if !defined(gmic_float_only) && (defined(gmic_double) || !defined(gmic_split_compilation))
gmic& gmic::_parse_double(const CImgList<char>& commands_line, unsigned int& position,
                          CImgList<double>& images, CImgList<char>& images_names,
                          unsigned int variables_sizes[256]) {
  return _parse(commands_line,position,images,images_names,variables_sizes);
}
template gmic::gmic(const int, const char *const *const, CImgList<double>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
template gmic::gmic(const char *const, CImgList<double>&, CImgList<char>&,
                    const char *const custom_commands, const bool include_default_commands,
                    float *const p_progress, int *const p_cancel);
#endif // #if !defined(gmic_float_only) && (defined(gmic_double) || !defined(gmic_split_compilation))
# 12616 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

#ifdef gmic_main

//-----------------------
// Start main procedure.
//-----------------------
int main(int argc, char **argv) {

  cimg::output(stdout);
  if (argc==1) {
    std::fprintf(cimg::output(),
                 "[gmic] No commands, options or data provided (type '%s -h' to get help).\n",
                 cimg::basename(argv[0]));
    std::fflush(cimg::output());
    std::exit(0);
  }

  // Check if help has been requested.
  char command_line[256] = { 0 };
  const char
    *const is_help1 = cimg_option("-h",(char*)0,0),
    *const is_help2 = cimg_option("--h",(char*)0,0),
    *const is_help3 = cimg_option("-help",(char*)0,0),
    *const is_help4 = cimg_option("--help",(char*)0,0);
  if (is_help1 || is_help2 || is_help3 || is_help4) {

    // Load all specified commands definitions data.
    CImgList<> images;
    CImgList<char> images_names;
    CImg<unsigned char>(data_gmic_def,1,size_data_gmic_def,1,1).move_to(images);
    const unsigned int omode = cimg::exception_mode();
    cimg::exception_mode() = 0;
    for (int i = 1; i<argc; ++i) {
      std::FILE *file = 0;
      char filename_tmp[1024] = { 0 };
      if ((!std::strcmp("-m",argv[i]) || !std::strcmp("-command",argv[i])) && i<argc-1) {
        const char *const filename = argv[++i];
        if (!cimg::strncasecmp(filename,"http://",7) || !cimg::strncasecmp(filename,"https://",8))
          try {
            file = std::fopen(cimg::load_network_external(filename,filename_tmp),"r");
          } catch (CImgException&) { file = 0; }
        else file = std::fopen(filename,"r");
      } else if (!cimg::strcasecmp("gmic",cimg::split_filename(argv[i]))) {
        const char *const filename = argv[i];
        if (!cimg::strncasecmp(filename,"http://",7) || !cimg::strncasecmp(filename,"https://",8))
          try {
            file = std::fopen(cimg::load_network_external(filename,filename_tmp),"r");
          } catch (CImgException&) { file = 0; }
        else file = std::fopen(filename,"r");
      }
      if (file) {
        CImg<unsigned char>::get_load_raw(file).move_to(images,0);
        CImg<unsigned char>::vector('\n').move_to(images,1);
        cimg::fclose(file);
        if (*filename_tmp) std::remove(filename_tmp);
      }
    }
    cimg::exception_mode() = omode;

    const char
      *const is_help = is_help1?"-h":is_help2?"--h":is_help3?"-help":"--help",
      *const command = is_help1?is_help1:is_help2?is_help2:is_help3?is_help3:is_help4;
    if (!std::strcmp(is_help,command)) gmic("-v - -help",images,images_names); // Global help.
    else { // Help for a specified command.
      cimg_snprintf(command_line,sizeof(command_line),"-v - -help \"%s\",1",command);
      gmic(command_line,images,images_names);
    }
    std::exit(0);
  }

  // Launch G'MIC instance.
  const char *const is_debug = cimg_option("-debug",(char*)0,0);
  cimg::output(is_debug?stdout:stderr);
  CImgList<float> images;
  CImgList<char> images_names;
  try { gmic(argc,argv,images,images_names); }
  catch (gmic_exception &e) {
    std::fprintf(cimg::output(),"\n[gmic] %s%s%s%s",
                 cimg::t_red,cimg::t_bold,e.what(),cimg::t_normal);
    if (*e.command_help()) {
      std::fprintf(cimg::output(),"\n[gmic] Command '-%s' has the following description: \n",
		   e.command_help());
      images.assign(); images_names.assign();
      CImg<unsigned char>(data_gmic_def,1,size_data_gmic_def,1,1).move_to(images);
      cimg_snprintf(command_line,sizeof(command_line),"-v - -help \"%s\",0",e.command_help());
      gmic(command_line,images,images_names);
    } else { std::fprintf(cimg::output(),"\n\n"); std::fflush(cimg::output()); }
    return -1;
  }
  return 0;
}
#endif // #ifdef gmic_main
# 12708 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"

#endif // #ifdef cimg_plugin
# 12710 "/s/kde/src/calligra/krita/plugins/extensions/gmic/gmic.cpp"
